/* ----------------------------------------------------------------------------
 * This file was automatically generated by SWIG (http://www.swig.org).
 * Version 4.0.1
 *
 * This file is not intended to be easily readable and contains a number of
 * coding conventions designed to improve portability and efficiency. Do not make
 * changes to this file unless you know what you are doing--modify the SWIG
 * interface file instead.
 * ----------------------------------------------------------------------------- */


#ifndef SWIGPYTHON
#define SWIGPYTHON
#endif

#define SWIG_DIRECTORS
#define SWIG_PYTHON_DIRECTOR_NO_VTABLE


#ifdef __cplusplus
/* SwigValueWrapper is described in swig.swg */
template<typename T> class SwigValueWrapper {
  struct SwigMovePointer {
    T *ptr;
    SwigMovePointer(T *p) : ptr(p) { }
    ~SwigMovePointer() { delete ptr; }
    SwigMovePointer& operator=(SwigMovePointer& rhs) { T* oldptr = ptr; ptr = 0; delete oldptr; ptr = rhs.ptr; rhs.ptr = 0; return *this; }
  } pointer;
  SwigValueWrapper& operator=(const SwigValueWrapper<T>& rhs);
  SwigValueWrapper(const SwigValueWrapper<T>& rhs);
public:
  SwigValueWrapper() : pointer(0) { }
  SwigValueWrapper& operator=(const T& t) { SwigMovePointer tmp(new T(t)); pointer = tmp; return *this; }
  operator T&() const { return *pointer.ptr; }
  T *operator&() { return pointer.ptr; }
};

template <typename T> T SwigValueInit() {
  return T();
}
#endif

/* -----------------------------------------------------------------------------
 *  This section contains generic SWIG labels for method/variable
 *  declarations/attributes, and other compiler dependent labels.
 * ----------------------------------------------------------------------------- */

/* template workaround for compilers that cannot correctly implement the C++ standard */
#ifndef SWIGTEMPLATEDISAMBIGUATOR
# if defined(__SUNPRO_CC) && (__SUNPRO_CC <= 0x560)
#  define SWIGTEMPLATEDISAMBIGUATOR template
# elif defined(__HP_aCC)
/* Needed even with `aCC -AA' when `aCC -V' reports HP ANSI C++ B3910B A.03.55 */
/* If we find a maximum version that requires this, the test would be __HP_aCC <= 35500 for A.03.55 */
#  define SWIGTEMPLATEDISAMBIGUATOR template
# else
#  define SWIGTEMPLATEDISAMBIGUATOR
# endif
#endif

/* inline attribute */
#ifndef SWIGINLINE
# if defined(__cplusplus) || (defined(__GNUC__) && !defined(__STRICT_ANSI__))
#   define SWIGINLINE inline
# else
#   define SWIGINLINE
# endif
#endif

/* attribute recognised by some compilers to avoid 'unused' warnings */
#ifndef SWIGUNUSED
# if defined(__GNUC__)
#   if !(defined(__cplusplus)) || (__GNUC__ > 3 || (__GNUC__ == 3 && __GNUC_MINOR__ >= 4))
#     define SWIGUNUSED __attribute__ ((__unused__))
#   else
#     define SWIGUNUSED
#   endif
# elif defined(__ICC)
#   define SWIGUNUSED __attribute__ ((__unused__))
# else
#   define SWIGUNUSED
# endif
#endif

#ifndef SWIG_MSC_UNSUPPRESS_4505
# if defined(_MSC_VER)
#   pragma warning(disable : 4505) /* unreferenced local function has been removed */
# endif
#endif

#ifndef SWIGUNUSEDPARM
# ifdef __cplusplus
#   define SWIGUNUSEDPARM(p)
# else
#   define SWIGUNUSEDPARM(p) p SWIGUNUSED
# endif
#endif

/* internal SWIG method */
#ifndef SWIGINTERN
# define SWIGINTERN static SWIGUNUSED
#endif

/* internal inline SWIG method */
#ifndef SWIGINTERNINLINE
# define SWIGINTERNINLINE SWIGINTERN SWIGINLINE
#endif

/* exporting methods */
#if defined(__GNUC__)
#  if (__GNUC__ >= 4) || (__GNUC__ == 3 && __GNUC_MINOR__ >= 4)
#    ifndef GCC_HASCLASSVISIBILITY
#      define GCC_HASCLASSVISIBILITY
#    endif
#  endif
#endif

#ifndef SWIGEXPORT
# if defined(_WIN32) || defined(__WIN32__) || defined(__CYGWIN__)
#   if defined(STATIC_LINKED)
#     define SWIGEXPORT
#   else
#     define SWIGEXPORT __declspec(dllexport)
#   endif
# else
#   if defined(__GNUC__) && defined(GCC_HASCLASSVISIBILITY)
#     define SWIGEXPORT __attribute__ ((visibility("default")))
#   else
#     define SWIGEXPORT
#   endif
# endif
#endif

/* calling conventions for Windows */
#ifndef SWIGSTDCALL
# if defined(_WIN32) || defined(__WIN32__) || defined(__CYGWIN__)
#   define SWIGSTDCALL __stdcall
# else
#   define SWIGSTDCALL
# endif
#endif

/* Deal with Microsoft's attempt at deprecating C standard runtime functions */
#if !defined(SWIG_NO_CRT_SECURE_NO_DEPRECATE) && defined(_MSC_VER) && !defined(_CRT_SECURE_NO_DEPRECATE)
# define _CRT_SECURE_NO_DEPRECATE
#endif

/* Deal with Microsoft's attempt at deprecating methods in the standard C++ library */
#if !defined(SWIG_NO_SCL_SECURE_NO_DEPRECATE) && defined(_MSC_VER) && !defined(_SCL_SECURE_NO_DEPRECATE)
# define _SCL_SECURE_NO_DEPRECATE
#endif

/* Deal with Apple's deprecated 'AssertMacros.h' from Carbon-framework */
#if defined(__APPLE__) && !defined(__ASSERT_MACROS_DEFINE_VERSIONS_WITHOUT_UNDERSCORES)
# define __ASSERT_MACROS_DEFINE_VERSIONS_WITHOUT_UNDERSCORES 0
#endif

/* Intel's compiler complains if a variable which was never initialised is
 * cast to void, which is a common idiom which we use to indicate that we
 * are aware a variable isn't used.  So we just silence that warning.
 * See: https://github.com/swig/swig/issues/192 for more discussion.
 */
#ifdef __INTEL_COMPILER
# pragma warning disable 592
#endif


#if defined(__GNUC__) && defined(_WIN32) && !defined(SWIG_PYTHON_NO_HYPOT_WORKAROUND)
/* Workaround for '::hypot' has not been declared', see https://bugs.python.org/issue11566 */
# include <math.h>
#endif

#if defined(_DEBUG) && defined(SWIG_PYTHON_INTERPRETER_NO_DEBUG)
/* Use debug wrappers with the Python release dll */
# undef _DEBUG
# include <Python.h>
# define _DEBUG 1
#else
# include <Python.h>
#endif

/* -----------------------------------------------------------------------------
 * swigrun.swg
 *
 * This file contains generic C API SWIG runtime support for pointer
 * type checking.
 * ----------------------------------------------------------------------------- */

/* This should only be incremented when either the layout of swig_type_info changes,
   or for whatever reason, the runtime changes incompatibly */
#define SWIG_RUNTIME_VERSION "4"

/* define SWIG_TYPE_TABLE_NAME as "SWIG_TYPE_TABLE" */
#ifdef SWIG_TYPE_TABLE
# define SWIG_QUOTE_STRING(x) #x
# define SWIG_EXPAND_AND_QUOTE_STRING(x) SWIG_QUOTE_STRING(x)
# define SWIG_TYPE_TABLE_NAME SWIG_EXPAND_AND_QUOTE_STRING(SWIG_TYPE_TABLE)
#else
# define SWIG_TYPE_TABLE_NAME
#endif

/*
  You can use the SWIGRUNTIME and SWIGRUNTIMEINLINE macros for
  creating a static or dynamic library from the SWIG runtime code.
  In 99.9% of the cases, SWIG just needs to declare them as 'static'.

  But only do this if strictly necessary, ie, if you have problems
  with your compiler or suchlike.
*/

#ifndef SWIGRUNTIME
# define SWIGRUNTIME SWIGINTERN
#endif

#ifndef SWIGRUNTIMEINLINE
# define SWIGRUNTIMEINLINE SWIGRUNTIME SWIGINLINE
#endif

/*  Generic buffer size */
#ifndef SWIG_BUFFER_SIZE
# define SWIG_BUFFER_SIZE 1024
#endif

/* Flags for pointer conversions */
#define SWIG_POINTER_DISOWN        0x1
#define SWIG_CAST_NEW_MEMORY       0x2
#define SWIG_POINTER_NO_NULL       0x4

/* Flags for new pointer objects */
#define SWIG_POINTER_OWN           0x1


/*
   Flags/methods for returning states.

   The SWIG conversion methods, as ConvertPtr, return an integer
   that tells if the conversion was successful or not. And if not,
   an error code can be returned (see swigerrors.swg for the codes).

   Use the following macros/flags to set or process the returning
   states.

   In old versions of SWIG, code such as the following was usually written:

     if (SWIG_ConvertPtr(obj,vptr,ty.flags) != -1) {
       // success code
     } else {
       //fail code
     }

   Now you can be more explicit:

    int res = SWIG_ConvertPtr(obj,vptr,ty.flags);
    if (SWIG_IsOK(res)) {
      // success code
    } else {
      // fail code
    }

   which is the same really, but now you can also do

    Type *ptr;
    int res = SWIG_ConvertPtr(obj,(void **)(&ptr),ty.flags);
    if (SWIG_IsOK(res)) {
      // success code
      if (SWIG_IsNewObj(res) {
        ...
	delete *ptr;
      } else {
        ...
      }
    } else {
      // fail code
    }

   I.e., now SWIG_ConvertPtr can return new objects and you can
   identify the case and take care of the deallocation. Of course that
   also requires SWIG_ConvertPtr to return new result values, such as

      int SWIG_ConvertPtr(obj, ptr,...) {
        if (<obj is ok>) {
          if (<need new object>) {
            *ptr = <ptr to new allocated object>;
            return SWIG_NEWOBJ;
          } else {
            *ptr = <ptr to old object>;
            return SWIG_OLDOBJ;
          }
        } else {
          return SWIG_BADOBJ;
        }
      }

   Of course, returning the plain '0(success)/-1(fail)' still works, but you can be
   more explicit by returning SWIG_BADOBJ, SWIG_ERROR or any of the
   SWIG errors code.

   Finally, if the SWIG_CASTRANK_MODE is enabled, the result code
   allows to return the 'cast rank', for example, if you have this

       int food(double)
       int fooi(int);

   and you call

      food(1)   // cast rank '1'  (1 -> 1.0)
      fooi(1)   // cast rank '0'

   just use the SWIG_AddCast()/SWIG_CheckState()
*/

#define SWIG_OK                    (0)
#define SWIG_ERROR                 (-1)
#define SWIG_IsOK(r)               (r >= 0)
#define SWIG_ArgError(r)           ((r != SWIG_ERROR) ? r : SWIG_TypeError)

/* The CastRankLimit says how many bits are used for the cast rank */
#define SWIG_CASTRANKLIMIT         (1 << 8)
/* The NewMask denotes the object was created (using new/malloc) */
#define SWIG_NEWOBJMASK            (SWIG_CASTRANKLIMIT  << 1)
/* The TmpMask is for in/out typemaps that use temporal objects */
#define SWIG_TMPOBJMASK            (SWIG_NEWOBJMASK << 1)
/* Simple returning values */
#define SWIG_BADOBJ                (SWIG_ERROR)
#define SWIG_OLDOBJ                (SWIG_OK)
#define SWIG_NEWOBJ                (SWIG_OK | SWIG_NEWOBJMASK)
#define SWIG_TMPOBJ                (SWIG_OK | SWIG_TMPOBJMASK)
/* Check, add and del mask methods */
#define SWIG_AddNewMask(r)         (SWIG_IsOK(r) ? (r | SWIG_NEWOBJMASK) : r)
#define SWIG_DelNewMask(r)         (SWIG_IsOK(r) ? (r & ~SWIG_NEWOBJMASK) : r)
#define SWIG_IsNewObj(r)           (SWIG_IsOK(r) && (r & SWIG_NEWOBJMASK))
#define SWIG_AddTmpMask(r)         (SWIG_IsOK(r) ? (r | SWIG_TMPOBJMASK) : r)
#define SWIG_DelTmpMask(r)         (SWIG_IsOK(r) ? (r & ~SWIG_TMPOBJMASK) : r)
#define SWIG_IsTmpObj(r)           (SWIG_IsOK(r) && (r & SWIG_TMPOBJMASK))

/* Cast-Rank Mode */
#if defined(SWIG_CASTRANK_MODE)
#  ifndef SWIG_TypeRank
#    define SWIG_TypeRank             unsigned long
#  endif
#  ifndef SWIG_MAXCASTRANK            /* Default cast allowed */
#    define SWIG_MAXCASTRANK          (2)
#  endif
#  define SWIG_CASTRANKMASK          ((SWIG_CASTRANKLIMIT) -1)
#  define SWIG_CastRank(r)           (r & SWIG_CASTRANKMASK)
SWIGINTERNINLINE int SWIG_AddCast(int r) {
  return SWIG_IsOK(r) ? ((SWIG_CastRank(r) < SWIG_MAXCASTRANK) ? (r + 1) : SWIG_ERROR) : r;
}
SWIGINTERNINLINE int SWIG_CheckState(int r) {
  return SWIG_IsOK(r) ? SWIG_CastRank(r) + 1 : 0;
}
#else /* no cast-rank mode */
#  define SWIG_AddCast(r) (r)
#  define SWIG_CheckState(r) (SWIG_IsOK(r) ? 1 : 0)
#endif


#include <string.h>

#ifdef __cplusplus
extern "C" {
#endif

typedef void *(*swig_converter_func)(void *, int *);
typedef struct swig_type_info *(*swig_dycast_func)(void **);

/* Structure to store information on one type */
typedef struct swig_type_info {
  const char             *name;			/* mangled name of this type */
  const char             *str;			/* human readable name of this type */
  swig_dycast_func        dcast;		/* dynamic cast function down a hierarchy */
  struct swig_cast_info  *cast;			/* linked list of types that can cast into this type */
  void                   *clientdata;		/* language specific type data */
  int                    owndata;		/* flag if the structure owns the clientdata */
} swig_type_info;

/* Structure to store a type and conversion function used for casting */
typedef struct swig_cast_info {
  swig_type_info         *type;			/* pointer to type that is equivalent to this type */
  swig_converter_func     converter;		/* function to cast the void pointers */
  struct swig_cast_info  *next;			/* pointer to next cast in linked list */
  struct swig_cast_info  *prev;			/* pointer to the previous cast */
} swig_cast_info;

/* Structure used to store module information
 * Each module generates one structure like this, and the runtime collects
 * all of these structures and stores them in a circularly linked list.*/
typedef struct swig_module_info {
  swig_type_info         **types;		/* Array of pointers to swig_type_info structures that are in this module */
  size_t                 size;		        /* Number of types in this module */
  struct swig_module_info *next;		/* Pointer to next element in circularly linked list */
  swig_type_info         **type_initial;	/* Array of initially generated type structures */
  swig_cast_info         **cast_initial;	/* Array of initially generated casting structures */
  void                    *clientdata;		/* Language specific module data */
} swig_module_info;

/*
  Compare two type names skipping the space characters, therefore
  "char*" == "char *" and "Class<int>" == "Class<int >", etc.

  Return 0 when the two name types are equivalent, as in
  strncmp, but skipping ' '.
*/
SWIGRUNTIME int
SWIG_TypeNameComp(const char *f1, const char *l1,
		  const char *f2, const char *l2) {
  for (;(f1 != l1) && (f2 != l2); ++f1, ++f2) {
    while ((*f1 == ' ') && (f1 != l1)) ++f1;
    while ((*f2 == ' ') && (f2 != l2)) ++f2;
    if (*f1 != *f2) return (*f1 > *f2) ? 1 : -1;
  }
  return (int)((l1 - f1) - (l2 - f2));
}

/*
  Check type equivalence in a name list like <name1>|<name2>|...
  Return 0 if equal, -1 if nb < tb, 1 if nb > tb
*/
SWIGRUNTIME int
SWIG_TypeCmp(const char *nb, const char *tb) {
  int equiv = 1;
  const char* te = tb + strlen(tb);
  const char* ne = nb;
  while (equiv != 0 && *ne) {
    for (nb = ne; *ne; ++ne) {
      if (*ne == '|') break;
    }
    equiv = SWIG_TypeNameComp(nb, ne, tb, te);
    if (*ne) ++ne;
  }
  return equiv;
}

/*
  Check type equivalence in a name list like <name1>|<name2>|...
  Return 0 if not equal, 1 if equal
*/
SWIGRUNTIME int
SWIG_TypeEquiv(const char *nb, const char *tb) {
  return SWIG_TypeCmp(nb, tb) == 0 ? 1 : 0;
}

/*
  Check the typename
*/
SWIGRUNTIME swig_cast_info *
SWIG_TypeCheck(const char *c, swig_type_info *ty) {
  if (ty) {
    swig_cast_info *iter = ty->cast;
    while (iter) {
      if (strcmp(iter->type->name, c) == 0) {
        if (iter == ty->cast)
          return iter;
        /* Move iter to the top of the linked list */
        iter->prev->next = iter->next;
        if (iter->next)
          iter->next->prev = iter->prev;
        iter->next = ty->cast;
        iter->prev = 0;
        if (ty->cast) ty->cast->prev = iter;
        ty->cast = iter;
        return iter;
      }
      iter = iter->next;
    }
  }
  return 0;
}

/*
  Identical to SWIG_TypeCheck, except strcmp is replaced with a pointer comparison
*/
SWIGRUNTIME swig_cast_info *
SWIG_TypeCheckStruct(swig_type_info *from, swig_type_info *ty) {
  if (ty) {
    swig_cast_info *iter = ty->cast;
    while (iter) {
      if (iter->type == from) {
        if (iter == ty->cast)
          return iter;
        /* Move iter to the top of the linked list */
        iter->prev->next = iter->next;
        if (iter->next)
          iter->next->prev = iter->prev;
        iter->next = ty->cast;
        iter->prev = 0;
        if (ty->cast) ty->cast->prev = iter;
        ty->cast = iter;
        return iter;
      }
      iter = iter->next;
    }
  }
  return 0;
}

/*
  Cast a pointer up an inheritance hierarchy
*/
SWIGRUNTIMEINLINE void *
SWIG_TypeCast(swig_cast_info *ty, void *ptr, int *newmemory) {
  return ((!ty) || (!ty->converter)) ? ptr : (*ty->converter)(ptr, newmemory);
}

/*
   Dynamic pointer casting. Down an inheritance hierarchy
*/
SWIGRUNTIME swig_type_info *
SWIG_TypeDynamicCast(swig_type_info *ty, void **ptr) {
  swig_type_info *lastty = ty;
  if (!ty || !ty->dcast) return ty;
  while (ty && (ty->dcast)) {
    ty = (*ty->dcast)(ptr);
    if (ty) lastty = ty;
  }
  return lastty;
}

/*
  Return the name associated with this type
*/
SWIGRUNTIMEINLINE const char *
SWIG_TypeName(const swig_type_info *ty) {
  return ty->name;
}

/*
  Return the pretty name associated with this type,
  that is an unmangled type name in a form presentable to the user.
*/
SWIGRUNTIME const char *
SWIG_TypePrettyName(const swig_type_info *type) {
  /* The "str" field contains the equivalent pretty names of the
     type, separated by vertical-bar characters.  We choose
     to print the last name, as it is often (?) the most
     specific. */
  if (!type) return NULL;
  if (type->str != NULL) {
    const char *last_name = type->str;
    const char *s;
    for (s = type->str; *s; s++)
      if (*s == '|') last_name = s+1;
    return last_name;
  }
  else
    return type->name;
}

/*
   Set the clientdata field for a type
*/
SWIGRUNTIME void
SWIG_TypeClientData(swig_type_info *ti, void *clientdata) {
  swig_cast_info *cast = ti->cast;
  /* if (ti->clientdata == clientdata) return; */
  ti->clientdata = clientdata;

  while (cast) {
    if (!cast->converter) {
      swig_type_info *tc = cast->type;
      if (!tc->clientdata) {
	SWIG_TypeClientData(tc, clientdata);
      }
    }
    cast = cast->next;
  }
}
SWIGRUNTIME void
SWIG_TypeNewClientData(swig_type_info *ti, void *clientdata) {
  SWIG_TypeClientData(ti, clientdata);
  ti->owndata = 1;
}

/*
  Search for a swig_type_info structure only by mangled name
  Search is a O(log #types)

  We start searching at module start, and finish searching when start == end.
  Note: if start == end at the beginning of the function, we go all the way around
  the circular list.
*/
SWIGRUNTIME swig_type_info *
SWIG_MangledTypeQueryModule(swig_module_info *start,
                            swig_module_info *end,
		            const char *name) {
  swig_module_info *iter = start;
  do {
    if (iter->size) {
      size_t l = 0;
      size_t r = iter->size - 1;
      do {
	/* since l+r >= 0, we can (>> 1) instead (/ 2) */
	size_t i = (l + r) >> 1;
	const char *iname = iter->types[i]->name;
	if (iname) {
	  int compare = strcmp(name, iname);
	  if (compare == 0) {
	    return iter->types[i];
	  } else if (compare < 0) {
	    if (i) {
	      r = i - 1;
	    } else {
	      break;
	    }
	  } else if (compare > 0) {
	    l = i + 1;
	  }
	} else {
	  break; /* should never happen */
	}
      } while (l <= r);
    }
    iter = iter->next;
  } while (iter != end);
  return 0;
}

/*
  Search for a swig_type_info structure for either a mangled name or a human readable name.
  It first searches the mangled names of the types, which is a O(log #types)
  If a type is not found it then searches the human readable names, which is O(#types).

  We start searching at module start, and finish searching when start == end.
  Note: if start == end at the beginning of the function, we go all the way around
  the circular list.
*/
SWIGRUNTIME swig_type_info *
SWIG_TypeQueryModule(swig_module_info *start,
                     swig_module_info *end,
		     const char *name) {
  /* STEP 1: Search the name field using binary search */
  swig_type_info *ret = SWIG_MangledTypeQueryModule(start, end, name);
  if (ret) {
    return ret;
  } else {
    /* STEP 2: If the type hasn't been found, do a complete search
       of the str field (the human readable name) */
    swig_module_info *iter = start;
    do {
      size_t i = 0;
      for (; i < iter->size; ++i) {
	if (iter->types[i]->str && (SWIG_TypeEquiv(iter->types[i]->str, name)))
	  return iter->types[i];
      }
      iter = iter->next;
    } while (iter != end);
  }

  /* neither found a match */
  return 0;
}

/*
   Pack binary data into a string
*/
SWIGRUNTIME char *
SWIG_PackData(char *c, void *ptr, size_t sz) {
  static const char hex[17] = "0123456789abcdef";
  const unsigned char *u = (unsigned char *) ptr;
  const unsigned char *eu =  u + sz;
  for (; u != eu; ++u) {
    unsigned char uu = *u;
    *(c++) = hex[(uu & 0xf0) >> 4];
    *(c++) = hex[uu & 0xf];
  }
  return c;
}

/*
   Unpack binary data from a string
*/
SWIGRUNTIME const char *
SWIG_UnpackData(const char *c, void *ptr, size_t sz) {
  unsigned char *u = (unsigned char *) ptr;
  const unsigned char *eu = u + sz;
  for (; u != eu; ++u) {
    char d = *(c++);
    unsigned char uu;
    if ((d >= '0') && (d <= '9'))
      uu = (unsigned char)((d - '0') << 4);
    else if ((d >= 'a') && (d <= 'f'))
      uu = (unsigned char)((d - ('a'-10)) << 4);
    else
      return (char *) 0;
    d = *(c++);
    if ((d >= '0') && (d <= '9'))
      uu |= (unsigned char)(d - '0');
    else if ((d >= 'a') && (d <= 'f'))
      uu |= (unsigned char)(d - ('a'-10));
    else
      return (char *) 0;
    *u = uu;
  }
  return c;
}

/*
   Pack 'void *' into a string buffer.
*/
SWIGRUNTIME char *
SWIG_PackVoidPtr(char *buff, void *ptr, const char *name, size_t bsz) {
  char *r = buff;
  if ((2*sizeof(void *) + 2) > bsz) return 0;
  *(r++) = '_';
  r = SWIG_PackData(r,&ptr,sizeof(void *));
  if (strlen(name) + 1 > (bsz - (r - buff))) return 0;
  strcpy(r,name);
  return buff;
}

SWIGRUNTIME const char *
SWIG_UnpackVoidPtr(const char *c, void **ptr, const char *name) {
  if (*c != '_') {
    if (strcmp(c,"NULL") == 0) {
      *ptr = (void *) 0;
      return name;
    } else {
      return 0;
    }
  }
  return SWIG_UnpackData(++c,ptr,sizeof(void *));
}

SWIGRUNTIME char *
SWIG_PackDataName(char *buff, void *ptr, size_t sz, const char *name, size_t bsz) {
  char *r = buff;
  size_t lname = (name ? strlen(name) : 0);
  if ((2*sz + 2 + lname) > bsz) return 0;
  *(r++) = '_';
  r = SWIG_PackData(r,ptr,sz);
  if (lname) {
    strncpy(r,name,lname+1);
  } else {
    *r = 0;
  }
  return buff;
}

SWIGRUNTIME const char *
SWIG_UnpackDataName(const char *c, void *ptr, size_t sz, const char *name) {
  if (*c != '_') {
    if (strcmp(c,"NULL") == 0) {
      memset(ptr,0,sz);
      return name;
    } else {
      return 0;
    }
  }
  return SWIG_UnpackData(++c,ptr,sz);
}

#ifdef __cplusplus
}
#endif

/*  Errors in SWIG */
#define  SWIG_UnknownError    	   -1
#define  SWIG_IOError        	   -2
#define  SWIG_RuntimeError   	   -3
#define  SWIG_IndexError     	   -4
#define  SWIG_TypeError      	   -5
#define  SWIG_DivisionByZero 	   -6
#define  SWIG_OverflowError  	   -7
#define  SWIG_SyntaxError    	   -8
#define  SWIG_ValueError     	   -9
#define  SWIG_SystemError    	   -10
#define  SWIG_AttributeError 	   -11
#define  SWIG_MemoryError    	   -12
#define  SWIG_NullReferenceError   -13



/* Compatibility macros for Python 3 */
#if PY_VERSION_HEX >= 0x03000000

#define PyClass_Check(obj) PyObject_IsInstance(obj, (PyObject *)&PyType_Type)
#define PyInt_Check(x) PyLong_Check(x)
#define PyInt_AsLong(x) PyLong_AsLong(x)
#define PyInt_FromLong(x) PyLong_FromLong(x)
#define PyInt_FromSize_t(x) PyLong_FromSize_t(x)
#define PyString_Check(name) PyBytes_Check(name)
#define PyString_FromString(x) PyUnicode_FromString(x)
#define PyString_Format(fmt, args)  PyUnicode_Format(fmt, args)
#define PyString_AsString(str) PyBytes_AsString(str)
#define PyString_Size(str) PyBytes_Size(str)	
#define PyString_InternFromString(key) PyUnicode_InternFromString(key)
#define Py_TPFLAGS_HAVE_CLASS Py_TPFLAGS_BASETYPE
#define PyString_AS_STRING(x) PyUnicode_AS_STRING(x)
#define _PyLong_FromSsize_t(x) PyLong_FromSsize_t(x)

#endif

#ifndef Py_TYPE
#  define Py_TYPE(op) ((op)->ob_type)
#endif

/* SWIG APIs for compatibility of both Python 2 & 3 */

#if PY_VERSION_HEX >= 0x03000000
#  define SWIG_Python_str_FromFormat PyUnicode_FromFormat
#else
#  define SWIG_Python_str_FromFormat PyString_FromFormat
#endif


/* Warning: This function will allocate a new string in Python 3,
 * so please call SWIG_Python_str_DelForPy3(x) to free the space.
 */
SWIGINTERN char*
SWIG_Python_str_AsChar(PyObject *str)
{
#if PY_VERSION_HEX >= 0x03000000
  char *newstr = 0;
  str = PyUnicode_AsUTF8String(str);
  if (str) {
    char *cstr;
    Py_ssize_t len;
    PyBytes_AsStringAndSize(str, &cstr, &len);
    newstr = (char *) malloc(len+1);
    memcpy(newstr, cstr, len+1);
    Py_XDECREF(str);
  }
  return newstr;
#else
  return PyString_AsString(str);
#endif
}

#if PY_VERSION_HEX >= 0x03000000
#  define SWIG_Python_str_DelForPy3(x) free( (void*) (x) )
#else
#  define SWIG_Python_str_DelForPy3(x) 
#endif


SWIGINTERN PyObject*
SWIG_Python_str_FromChar(const char *c)
{
#if PY_VERSION_HEX >= 0x03000000
  return PyUnicode_FromString(c); 
#else
  return PyString_FromString(c);
#endif
}

#ifndef PyObject_DEL
# define PyObject_DEL PyObject_Del
#endif

// SWIGPY_USE_CAPSULE is no longer used within SWIG itself, but some user
// interface files check for it.
# define SWIGPY_USE_CAPSULE
# define SWIGPY_CAPSULE_NAME ("swig_runtime_data" SWIG_RUNTIME_VERSION ".type_pointer_capsule" SWIG_TYPE_TABLE_NAME)

#if PY_VERSION_HEX < 0x03020000
#define PyDescr_TYPE(x) (((PyDescrObject *)(x))->d_type)
#define PyDescr_NAME(x) (((PyDescrObject *)(x))->d_name)
#define Py_hash_t long
#endif

/* -----------------------------------------------------------------------------
 * error manipulation
 * ----------------------------------------------------------------------------- */

SWIGRUNTIME PyObject*
SWIG_Python_ErrorType(int code) {
  PyObject* type = 0;
  switch(code) {
  case SWIG_MemoryError:
    type = PyExc_MemoryError;
    break;
  case SWIG_IOError:
    type = PyExc_IOError;
    break;
  case SWIG_RuntimeError:
    type = PyExc_RuntimeError;
    break;
  case SWIG_IndexError:
    type = PyExc_IndexError;
    break;
  case SWIG_TypeError:
    type = PyExc_TypeError;
    break;
  case SWIG_DivisionByZero:
    type = PyExc_ZeroDivisionError;
    break;
  case SWIG_OverflowError:
    type = PyExc_OverflowError;
    break;
  case SWIG_SyntaxError:
    type = PyExc_SyntaxError;
    break;
  case SWIG_ValueError:
    type = PyExc_ValueError;
    break;
  case SWIG_SystemError:
    type = PyExc_SystemError;
    break;
  case SWIG_AttributeError:
    type = PyExc_AttributeError;
    break;
  default:
    type = PyExc_RuntimeError;
  }
  return type;
}


SWIGRUNTIME void
SWIG_Python_AddErrorMsg(const char* mesg)
{
  PyObject *type = 0;
  PyObject *value = 0;
  PyObject *traceback = 0;

  if (PyErr_Occurred())
    PyErr_Fetch(&type, &value, &traceback);
  if (value) {
    PyObject *old_str = PyObject_Str(value);
    const char *tmp = SWIG_Python_str_AsChar(old_str);
    PyErr_Clear();
    Py_XINCREF(type);
    if (tmp)
      PyErr_Format(type, "%s %s", tmp, mesg);
    else
      PyErr_Format(type, "%s", mesg);
    SWIG_Python_str_DelForPy3(tmp);
    Py_DECREF(old_str);
    Py_DECREF(value);
  } else {
    PyErr_SetString(PyExc_RuntimeError, mesg);
  }
}

SWIGRUNTIME int
SWIG_Python_TypeErrorOccurred(PyObject *obj)
{
  PyObject *error;
  if (obj)
    return 0;
  error = PyErr_Occurred();
  return error && PyErr_GivenExceptionMatches(error, PyExc_TypeError);
}

SWIGRUNTIME void
SWIG_Python_RaiseOrModifyTypeError(const char *message)
{
  if (SWIG_Python_TypeErrorOccurred(NULL)) {
    /* Use existing TypeError to preserve stacktrace and enhance with given message */
    PyObject *newvalue;
    PyObject *type = NULL, *value = NULL, *traceback = NULL;
    PyErr_Fetch(&type, &value, &traceback);
#if PY_VERSION_HEX >= 0x03000000
    newvalue = PyUnicode_FromFormat("%S\nAdditional information:\n%s", value, message);
#else
    newvalue = PyString_FromFormat("%s\nAdditional information:\n%s", PyString_AsString(value), message);
#endif
    Py_XDECREF(value);
    PyErr_Restore(type, newvalue, traceback);
  } else {
    /* Raise TypeError using given message */
    PyErr_SetString(PyExc_TypeError, message);
  }
}

#if defined(SWIG_PYTHON_NO_THREADS)
#  if defined(SWIG_PYTHON_THREADS)
#    undef SWIG_PYTHON_THREADS
#  endif
#endif
#if defined(SWIG_PYTHON_THREADS) /* Threading support is enabled */
#  if !defined(SWIG_PYTHON_USE_GIL) && !defined(SWIG_PYTHON_NO_USE_GIL)
#    define SWIG_PYTHON_USE_GIL
#  endif
#  if defined(SWIG_PYTHON_USE_GIL) /* Use PyGILState threads calls */
#    ifndef SWIG_PYTHON_INITIALIZE_THREADS
#     define SWIG_PYTHON_INITIALIZE_THREADS  PyEval_InitThreads() 
#    endif
#    ifdef __cplusplus /* C++ code */
       class SWIG_Python_Thread_Block {
         bool status;
         PyGILState_STATE state;
       public:
         void end() { if (status) { PyGILState_Release(state); status = false;} }
         SWIG_Python_Thread_Block() : status(true), state(PyGILState_Ensure()) {}
         ~SWIG_Python_Thread_Block() { end(); }
       };
       class SWIG_Python_Thread_Allow {
         bool status;
         PyThreadState *save;
       public:
         void end() { if (status) { PyEval_RestoreThread(save); status = false; }}
         SWIG_Python_Thread_Allow() : status(true), save(PyEval_SaveThread()) {}
         ~SWIG_Python_Thread_Allow() { end(); }
       };
#      define SWIG_PYTHON_THREAD_BEGIN_BLOCK   SWIG_Python_Thread_Block _swig_thread_block
#      define SWIG_PYTHON_THREAD_END_BLOCK     _swig_thread_block.end()
#      define SWIG_PYTHON_THREAD_BEGIN_ALLOW   SWIG_Python_Thread_Allow _swig_thread_allow
#      define SWIG_PYTHON_THREAD_END_ALLOW     _swig_thread_allow.end()
#    else /* C code */
#      define SWIG_PYTHON_THREAD_BEGIN_BLOCK   PyGILState_STATE _swig_thread_block = PyGILState_Ensure()
#      define SWIG_PYTHON_THREAD_END_BLOCK     PyGILState_Release(_swig_thread_block)
#      define SWIG_PYTHON_THREAD_BEGIN_ALLOW   PyThreadState *_swig_thread_allow = PyEval_SaveThread()
#      define SWIG_PYTHON_THREAD_END_ALLOW     PyEval_RestoreThread(_swig_thread_allow)
#    endif
#  else /* Old thread way, not implemented, user must provide it */
#    if !defined(SWIG_PYTHON_INITIALIZE_THREADS)
#      define SWIG_PYTHON_INITIALIZE_THREADS
#    endif
#    if !defined(SWIG_PYTHON_THREAD_BEGIN_BLOCK)
#      define SWIG_PYTHON_THREAD_BEGIN_BLOCK
#    endif
#    if !defined(SWIG_PYTHON_THREAD_END_BLOCK)
#      define SWIG_PYTHON_THREAD_END_BLOCK
#    endif
#    if !defined(SWIG_PYTHON_THREAD_BEGIN_ALLOW)
#      define SWIG_PYTHON_THREAD_BEGIN_ALLOW
#    endif
#    if !defined(SWIG_PYTHON_THREAD_END_ALLOW)
#      define SWIG_PYTHON_THREAD_END_ALLOW
#    endif
#  endif
#else /* No thread support */
#  define SWIG_PYTHON_INITIALIZE_THREADS
#  define SWIG_PYTHON_THREAD_BEGIN_BLOCK
#  define SWIG_PYTHON_THREAD_END_BLOCK
#  define SWIG_PYTHON_THREAD_BEGIN_ALLOW
#  define SWIG_PYTHON_THREAD_END_ALLOW
#endif

/* -----------------------------------------------------------------------------
 * Python API portion that goes into the runtime
 * ----------------------------------------------------------------------------- */

#ifdef __cplusplus
extern "C" {
#endif

/* -----------------------------------------------------------------------------
 * Constant declarations
 * ----------------------------------------------------------------------------- */

/* Constant Types */
#define SWIG_PY_POINTER 4
#define SWIG_PY_BINARY  5

/* Constant information structure */
typedef struct swig_const_info {
  int type;
  const char *name;
  long lvalue;
  double dvalue;
  void   *pvalue;
  swig_type_info **ptype;
} swig_const_info;

#ifdef __cplusplus
}
#endif


/* -----------------------------------------------------------------------------
 * pyrun.swg
 *
 * This file contains the runtime support for Python modules
 * and includes code for managing global variables and pointer
 * type checking.
 *
 * ----------------------------------------------------------------------------- */

#if PY_VERSION_HEX < 0x02070000 /* 2.7.0 */
# error "This version of SWIG only supports Python >= 2.7"
#endif

#if PY_VERSION_HEX >= 0x03000000 && PY_VERSION_HEX < 0x03020000
# error "This version of SWIG only supports Python 3 >= 3.2"
#endif

/* Common SWIG API */

/* for raw pointers */
#define SWIG_Python_ConvertPtr(obj, pptr, type, flags)  SWIG_Python_ConvertPtrAndOwn(obj, pptr, type, flags, 0)
#define SWIG_ConvertPtr(obj, pptr, type, flags)         SWIG_Python_ConvertPtr(obj, pptr, type, flags)
#define SWIG_ConvertPtrAndOwn(obj,pptr,type,flags,own)  SWIG_Python_ConvertPtrAndOwn(obj, pptr, type, flags, own)

#ifdef SWIGPYTHON_BUILTIN
#define SWIG_NewPointerObj(ptr, type, flags)            SWIG_Python_NewPointerObj(self, ptr, type, flags)
#else
#define SWIG_NewPointerObj(ptr, type, flags)            SWIG_Python_NewPointerObj(NULL, ptr, type, flags)
#endif

#define SWIG_InternalNewPointerObj(ptr, type, flags)	SWIG_Python_NewPointerObj(NULL, ptr, type, flags)

#define SWIG_CheckImplicit(ty)                          SWIG_Python_CheckImplicit(ty) 
#define SWIG_AcquirePtr(ptr, src)                       SWIG_Python_AcquirePtr(ptr, src)
#define swig_owntype                                    int

/* for raw packed data */
#define SWIG_ConvertPacked(obj, ptr, sz, ty)            SWIG_Python_ConvertPacked(obj, ptr, sz, ty)
#define SWIG_NewPackedObj(ptr, sz, type)                SWIG_Python_NewPackedObj(ptr, sz, type)

/* for class or struct pointers */
#define SWIG_ConvertInstance(obj, pptr, type, flags)    SWIG_ConvertPtr(obj, pptr, type, flags)
#define SWIG_NewInstanceObj(ptr, type, flags)           SWIG_NewPointerObj(ptr, type, flags)

/* for C or C++ function pointers */
#define SWIG_ConvertFunctionPtr(obj, pptr, type)        SWIG_Python_ConvertFunctionPtr(obj, pptr, type)
#define SWIG_NewFunctionPtrObj(ptr, type)               SWIG_Python_NewPointerObj(NULL, ptr, type, 0)

/* for C++ member pointers, ie, member methods */
#define SWIG_ConvertMember(obj, ptr, sz, ty)            SWIG_Python_ConvertPacked(obj, ptr, sz, ty)
#define SWIG_NewMemberObj(ptr, sz, type)                SWIG_Python_NewPackedObj(ptr, sz, type)


/* Runtime API */

#define SWIG_GetModule(clientdata)                      SWIG_Python_GetModule(clientdata)
#define SWIG_SetModule(clientdata, pointer)             SWIG_Python_SetModule(pointer)
#define SWIG_NewClientData(obj)                         SwigPyClientData_New(obj)

#define SWIG_SetErrorObj                                SWIG_Python_SetErrorObj                            
#define SWIG_SetErrorMsg                        	SWIG_Python_SetErrorMsg				   
#define SWIG_ErrorType(code)                    	SWIG_Python_ErrorType(code)                        
#define SWIG_Error(code, msg)            		SWIG_Python_SetErrorMsg(SWIG_ErrorType(code), msg) 
#define SWIG_fail                        		goto fail					   


/* Runtime API implementation */

/* Error manipulation */

SWIGINTERN void 
SWIG_Python_SetErrorObj(PyObject *errtype, PyObject *obj) {
  SWIG_PYTHON_THREAD_BEGIN_BLOCK; 
  PyErr_SetObject(errtype, obj);
  Py_DECREF(obj);
  SWIG_PYTHON_THREAD_END_BLOCK;
}

SWIGINTERN void 
SWIG_Python_SetErrorMsg(PyObject *errtype, const char *msg) {
  SWIG_PYTHON_THREAD_BEGIN_BLOCK;
  PyErr_SetString(errtype, msg);
  SWIG_PYTHON_THREAD_END_BLOCK;
}

#define SWIG_Python_Raise(obj, type, desc)  SWIG_Python_SetErrorObj(SWIG_Python_ExceptionType(desc), obj)

/* Set a constant value */

#if defined(SWIGPYTHON_BUILTIN)

SWIGINTERN void
SwigPyBuiltin_AddPublicSymbol(PyObject *seq, const char *key) {
  PyObject *s = PyString_InternFromString(key);
  PyList_Append(seq, s);
  Py_DECREF(s);
}

SWIGINTERN void
SWIG_Python_SetConstant(PyObject *d, PyObject *public_interface, const char *name, PyObject *obj) {   
  PyDict_SetItemString(d, name, obj);
  Py_DECREF(obj);
  if (public_interface)
    SwigPyBuiltin_AddPublicSymbol(public_interface, name);
}

#else

SWIGINTERN void
SWIG_Python_SetConstant(PyObject *d, const char *name, PyObject *obj) {   
  PyDict_SetItemString(d, name, obj);
  Py_DECREF(obj);                            
}

#endif

/* Append a value to the result obj */

SWIGINTERN PyObject*
SWIG_Python_AppendOutput(PyObject* result, PyObject* obj) {
  if (!result) {
    result = obj;
  } else if (result == Py_None) {
    Py_DECREF(result);
    result = obj;
  } else {
    if (!PyList_Check(result)) {
      PyObject *o2 = result;
      result = PyList_New(1);
      PyList_SetItem(result, 0, o2);
    }
    PyList_Append(result,obj);
    Py_DECREF(obj);
  }
  return result;
}

/* Unpack the argument tuple */

SWIGINTERN Py_ssize_t
SWIG_Python_UnpackTuple(PyObject *args, const char *name, Py_ssize_t min, Py_ssize_t max, PyObject **objs)
{
  if (!args) {
    if (!min && !max) {
      return 1;
    } else {
      PyErr_Format(PyExc_TypeError, "%s expected %s%d arguments, got none", 
		   name, (min == max ? "" : "at least "), (int)min);
      return 0;
    }
  }  
  if (!PyTuple_Check(args)) {
    if (min <= 1 && max >= 1) {
      Py_ssize_t i;
      objs[0] = args;
      for (i = 1; i < max; ++i) {
	objs[i] = 0;
      }
      return 2;
    }
    PyErr_SetString(PyExc_SystemError, "UnpackTuple() argument list is not a tuple");
    return 0;
  } else {
    Py_ssize_t l = PyTuple_GET_SIZE(args);
    if (l < min) {
      PyErr_Format(PyExc_TypeError, "%s expected %s%d arguments, got %d", 
		   name, (min == max ? "" : "at least "), (int)min, (int)l);
      return 0;
    } else if (l > max) {
      PyErr_Format(PyExc_TypeError, "%s expected %s%d arguments, got %d", 
		   name, (min == max ? "" : "at most "), (int)max, (int)l);
      return 0;
    } else {
      Py_ssize_t i;
      for (i = 0; i < l; ++i) {
	objs[i] = PyTuple_GET_ITEM(args, i);
      }
      for (; l < max; ++l) {
	objs[l] = 0;
      }
      return i + 1;
    }    
  }
}

/* A functor is a function object with one single object argument */
#define SWIG_Python_CallFunctor(functor, obj)	        PyObject_CallFunctionObjArgs(functor, obj, NULL);

/*
  Helper for static pointer initialization for both C and C++ code, for example
  static PyObject *SWIG_STATIC_POINTER(MyVar) = NewSomething(...);
*/
#ifdef __cplusplus
#define SWIG_STATIC_POINTER(var)  var
#else
#define SWIG_STATIC_POINTER(var)  var = 0; if (!var) var
#endif

/* -----------------------------------------------------------------------------
 * Pointer declarations
 * ----------------------------------------------------------------------------- */

/* Flags for new pointer objects */
#define SWIG_POINTER_NOSHADOW       (SWIG_POINTER_OWN      << 1)
#define SWIG_POINTER_NEW            (SWIG_POINTER_NOSHADOW | SWIG_POINTER_OWN)

#define SWIG_POINTER_IMPLICIT_CONV  (SWIG_POINTER_DISOWN   << 1)

#define SWIG_BUILTIN_TP_INIT	    (SWIG_POINTER_OWN << 2)
#define SWIG_BUILTIN_INIT	    (SWIG_BUILTIN_TP_INIT | SWIG_POINTER_OWN)

#ifdef __cplusplus
extern "C" {
#endif

/* The python void return value */

SWIGRUNTIMEINLINE PyObject * 
SWIG_Py_Void(void)
{
  PyObject *none = Py_None;
  Py_INCREF(none);
  return none;
}

/* SwigPyClientData */

typedef struct {
  PyObject *klass;
  PyObject *newraw;
  PyObject *newargs;
  PyObject *destroy;
  int delargs;
  int implicitconv;
  PyTypeObject *pytype;
} SwigPyClientData;

SWIGRUNTIMEINLINE int 
SWIG_Python_CheckImplicit(swig_type_info *ty)
{
  SwigPyClientData *data = (SwigPyClientData *)ty->clientdata;
  int fail = data ? data->implicitconv : 0;
  if (fail)
    PyErr_SetString(PyExc_TypeError, "Implicit conversion is prohibited for explicit constructors.");
  return fail;
}

SWIGRUNTIMEINLINE PyObject *
SWIG_Python_ExceptionType(swig_type_info *desc) {
  SwigPyClientData *data = desc ? (SwigPyClientData *) desc->clientdata : 0;
  PyObject *klass = data ? data->klass : 0;
  return (klass ? klass : PyExc_RuntimeError);
}


SWIGRUNTIME SwigPyClientData * 
SwigPyClientData_New(PyObject* obj)
{
  if (!obj) {
    return 0;
  } else {
    SwigPyClientData *data = (SwigPyClientData *)malloc(sizeof(SwigPyClientData));
    /* the klass element */
    data->klass = obj;
    Py_INCREF(data->klass);
    /* the newraw method and newargs arguments used to create a new raw instance */
    if (PyClass_Check(obj)) {
      data->newraw = 0;
      data->newargs = obj;
      Py_INCREF(obj);
    } else {
      data->newraw = PyObject_GetAttrString(data->klass, "__new__");
      if (data->newraw) {
	Py_INCREF(data->newraw);
	data->newargs = PyTuple_New(1);
	PyTuple_SetItem(data->newargs, 0, obj);
      } else {
	data->newargs = obj;
      }
      Py_INCREF(data->newargs);
    }
    /* the destroy method, aka as the C++ delete method */
    data->destroy = PyObject_GetAttrString(data->klass, "__swig_destroy__");
    if (PyErr_Occurred()) {
      PyErr_Clear();
      data->destroy = 0;
    }
    if (data->destroy) {
      int flags;
      Py_INCREF(data->destroy);
      flags = PyCFunction_GET_FLAGS(data->destroy);
      data->delargs = !(flags & (METH_O));
    } else {
      data->delargs = 0;
    }
    data->implicitconv = 0;
    data->pytype = 0;
    return data;
  }
}

SWIGRUNTIME void 
SwigPyClientData_Del(SwigPyClientData *data) {
  Py_XDECREF(data->newraw);
  Py_XDECREF(data->newargs);
  Py_XDECREF(data->destroy);
}

/* =============== SwigPyObject =====================*/

typedef struct {
  PyObject_HEAD
  void *ptr;
  swig_type_info *ty;
  int own;
  PyObject *next;
#ifdef SWIGPYTHON_BUILTIN
  PyObject *dict;
#endif
} SwigPyObject;


#ifdef SWIGPYTHON_BUILTIN

SWIGRUNTIME PyObject *
SwigPyObject_get___dict__(PyObject *v, PyObject *SWIGUNUSEDPARM(args))
{
  SwigPyObject *sobj = (SwigPyObject *)v;

  if (!sobj->dict)
    sobj->dict = PyDict_New();

  Py_INCREF(sobj->dict);
  return sobj->dict;
}

#endif

SWIGRUNTIME PyObject *
SwigPyObject_long(SwigPyObject *v)
{
  return PyLong_FromVoidPtr(v->ptr);
}

SWIGRUNTIME PyObject *
SwigPyObject_format(const char* fmt, SwigPyObject *v)
{
  PyObject *res = NULL;
  PyObject *args = PyTuple_New(1);
  if (args) {
    if (PyTuple_SetItem(args, 0, SwigPyObject_long(v)) == 0) {
      PyObject *ofmt = SWIG_Python_str_FromChar(fmt);
      if (ofmt) {
#if PY_VERSION_HEX >= 0x03000000
	res = PyUnicode_Format(ofmt,args);
#else
	res = PyString_Format(ofmt,args);
#endif
	Py_DECREF(ofmt);
      }
      Py_DECREF(args);
    }
  }
  return res;
}

SWIGRUNTIME PyObject *
SwigPyObject_oct(SwigPyObject *v)
{
  return SwigPyObject_format("%o",v);
}

SWIGRUNTIME PyObject *
SwigPyObject_hex(SwigPyObject *v)
{
  return SwigPyObject_format("%x",v);
}

SWIGRUNTIME PyObject *
SwigPyObject_repr(SwigPyObject *v)
{
  const char *name = SWIG_TypePrettyName(v->ty);
  PyObject *repr = SWIG_Python_str_FromFormat("<Swig Object of type '%s' at %p>", (name ? name : "unknown"), (void *)v);
  if (v->next) {
    PyObject *nrep = SwigPyObject_repr((SwigPyObject *)v->next);
# if PY_VERSION_HEX >= 0x03000000
    PyObject *joined = PyUnicode_Concat(repr, nrep);
    Py_DecRef(repr);
    Py_DecRef(nrep);
    repr = joined;
# else
    PyString_ConcatAndDel(&repr,nrep);
# endif
  }
  return repr;  
}

/* We need a version taking two PyObject* parameters so it's a valid
 * PyCFunction to use in swigobject_methods[]. */
SWIGRUNTIME PyObject *
SwigPyObject_repr2(PyObject *v, PyObject *SWIGUNUSEDPARM(args))
{
  return SwigPyObject_repr((SwigPyObject*)v);
}

SWIGRUNTIME int
SwigPyObject_compare(SwigPyObject *v, SwigPyObject *w)
{
  void *i = v->ptr;
  void *j = w->ptr;
  return (i < j) ? -1 : ((i > j) ? 1 : 0);
}

/* Added for Python 3.x, would it also be useful for Python 2.x? */
SWIGRUNTIME PyObject*
SwigPyObject_richcompare(SwigPyObject *v, SwigPyObject *w, int op)
{
  PyObject* res;
  if( op != Py_EQ && op != Py_NE ) {
    Py_INCREF(Py_NotImplemented);
    return Py_NotImplemented;
  }
  res = PyBool_FromLong( (SwigPyObject_compare(v, w)==0) == (op == Py_EQ) ? 1 : 0);
  return res;  
}


SWIGRUNTIME PyTypeObject* SwigPyObject_TypeOnce(void);

#ifdef SWIGPYTHON_BUILTIN
static swig_type_info *SwigPyObject_stype = 0;
SWIGRUNTIME PyTypeObject*
SwigPyObject_type(void) {
    SwigPyClientData *cd;
    assert(SwigPyObject_stype);
    cd = (SwigPyClientData*) SwigPyObject_stype->clientdata;
    assert(cd);
    assert(cd->pytype);
    return cd->pytype;
}
#else
SWIGRUNTIME PyTypeObject*
SwigPyObject_type(void) {
  static PyTypeObject *SWIG_STATIC_POINTER(type) = SwigPyObject_TypeOnce();
  return type;
}
#endif

SWIGRUNTIMEINLINE int
SwigPyObject_Check(PyObject *op) {
#ifdef SWIGPYTHON_BUILTIN
  PyTypeObject *target_tp = SwigPyObject_type();
  if (PyType_IsSubtype(op->ob_type, target_tp))
    return 1;
  return (strcmp(op->ob_type->tp_name, "SwigPyObject") == 0);
#else
  return (Py_TYPE(op) == SwigPyObject_type())
    || (strcmp(Py_TYPE(op)->tp_name,"SwigPyObject") == 0);
#endif
}

SWIGRUNTIME PyObject *
SwigPyObject_New(void *ptr, swig_type_info *ty, int own);

SWIGRUNTIME void
SwigPyObject_dealloc(PyObject *v)
{
  SwigPyObject *sobj = (SwigPyObject *) v;
  PyObject *next = sobj->next;
  if (sobj->own == SWIG_POINTER_OWN) {
    swig_type_info *ty = sobj->ty;
    SwigPyClientData *data = ty ? (SwigPyClientData *) ty->clientdata : 0;
    PyObject *destroy = data ? data->destroy : 0;
    if (destroy) {
      /* destroy is always a VARARGS method */
      PyObject *res;

      /* PyObject_CallFunction() has the potential to silently drop
         the active exception.  In cases of unnamed temporary
         variable or where we just finished iterating over a generator
         StopIteration will be active right now, and this needs to
         remain true upon return from SwigPyObject_dealloc.  So save
         and restore. */
      
      PyObject *type = NULL, *value = NULL, *traceback = NULL;
      PyErr_Fetch(&type, &value, &traceback);

      if (data->delargs) {
        /* we need to create a temporary object to carry the destroy operation */
        PyObject *tmp = SwigPyObject_New(sobj->ptr, ty, 0);
        res = SWIG_Python_CallFunctor(destroy, tmp);
        Py_DECREF(tmp);
      } else {
        PyCFunction meth = PyCFunction_GET_FUNCTION(destroy);
        PyObject *mself = PyCFunction_GET_SELF(destroy);
        res = ((*meth)(mself, v));
      }
      if (!res)
        PyErr_WriteUnraisable(destroy);

      PyErr_Restore(type, value, traceback);

      Py_XDECREF(res);
    } 
#if !defined(SWIG_PYTHON_SILENT_MEMLEAK)
    else {
      const char *name = SWIG_TypePrettyName(ty);
      printf("swig/python detected a memory leak of type '%s', no destructor found.\n", (name ? name : "unknown"));
    }
#endif
  } 
  Py_XDECREF(next);
  PyObject_DEL(v);
}

SWIGRUNTIME PyObject* 
SwigPyObject_append(PyObject* v, PyObject* next)
{
  SwigPyObject *sobj = (SwigPyObject *) v;
  if (!SwigPyObject_Check(next)) {
    PyErr_SetString(PyExc_TypeError, "Attempt to append a non SwigPyObject");
    return NULL;
  }
  sobj->next = next;
  Py_INCREF(next);
  return SWIG_Py_Void();
}

SWIGRUNTIME PyObject* 
SwigPyObject_next(PyObject* v, PyObject *SWIGUNUSEDPARM(args))
{
  SwigPyObject *sobj = (SwigPyObject *) v;
  if (sobj->next) {    
    Py_INCREF(sobj->next);
    return sobj->next;
  } else {
    return SWIG_Py_Void();
  }
}

SWIGINTERN PyObject*
SwigPyObject_disown(PyObject* v, PyObject *SWIGUNUSEDPARM(args))
{
  SwigPyObject *sobj = (SwigPyObject *)v;
  sobj->own = 0;
  return SWIG_Py_Void();
}

SWIGINTERN PyObject*
SwigPyObject_acquire(PyObject* v, PyObject *SWIGUNUSEDPARM(args))
{
  SwigPyObject *sobj = (SwigPyObject *)v;
  sobj->own = SWIG_POINTER_OWN;
  return SWIG_Py_Void();
}

SWIGINTERN PyObject*
SwigPyObject_own(PyObject *v, PyObject *args)
{
  PyObject *val = 0;
  if (!PyArg_UnpackTuple(args, "own", 0, 1, &val)) {
    return NULL;
  } else {
    SwigPyObject *sobj = (SwigPyObject *)v;
    PyObject *obj = PyBool_FromLong(sobj->own);
    if (val) {
      if (PyObject_IsTrue(val)) {
        SwigPyObject_acquire(v,args);
      } else {
        SwigPyObject_disown(v,args);
      }
    } 
    return obj;
  }
}

static PyMethodDef
swigobject_methods[] = {
  {"disown",  SwigPyObject_disown,  METH_NOARGS,  "releases ownership of the pointer"},
  {"acquire", SwigPyObject_acquire, METH_NOARGS,  "acquires ownership of the pointer"},
  {"own",     SwigPyObject_own,     METH_VARARGS, "returns/sets ownership of the pointer"},
  {"append",  SwigPyObject_append,  METH_O,       "appends another 'this' object"},
  {"next",    SwigPyObject_next,    METH_NOARGS,  "returns the next 'this' object"},
  {"__repr__",SwigPyObject_repr2,   METH_NOARGS,  "returns object representation"},
  {0, 0, 0, 0}  
};

SWIGRUNTIME PyTypeObject*
SwigPyObject_TypeOnce(void) {
  static char swigobject_doc[] = "Swig object carries a C/C++ instance pointer";

  static PyNumberMethods SwigPyObject_as_number = {
    (binaryfunc)0, /*nb_add*/
    (binaryfunc)0, /*nb_subtract*/
    (binaryfunc)0, /*nb_multiply*/
    /* nb_divide removed in Python 3 */
#if PY_VERSION_HEX < 0x03000000
    (binaryfunc)0, /*nb_divide*/
#endif
    (binaryfunc)0, /*nb_remainder*/
    (binaryfunc)0, /*nb_divmod*/
    (ternaryfunc)0,/*nb_power*/
    (unaryfunc)0,  /*nb_negative*/
    (unaryfunc)0,  /*nb_positive*/
    (unaryfunc)0,  /*nb_absolute*/
    (inquiry)0,    /*nb_nonzero*/
    0,		   /*nb_invert*/
    0,		   /*nb_lshift*/
    0,		   /*nb_rshift*/
    0,		   /*nb_and*/
    0,		   /*nb_xor*/
    0,		   /*nb_or*/
#if PY_VERSION_HEX < 0x03000000
    0,   /*nb_coerce*/
#endif
    (unaryfunc)SwigPyObject_long, /*nb_int*/
#if PY_VERSION_HEX < 0x03000000
    (unaryfunc)SwigPyObject_long, /*nb_long*/
#else
    0, /*nb_reserved*/
#endif
    (unaryfunc)0,                 /*nb_float*/
#if PY_VERSION_HEX < 0x03000000
    (unaryfunc)SwigPyObject_oct,  /*nb_oct*/
    (unaryfunc)SwigPyObject_hex,  /*nb_hex*/
#endif
#if PY_VERSION_HEX >= 0x03050000 /* 3.5 */
    0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0 /* nb_inplace_add -> nb_inplace_matrix_multiply */
#elif PY_VERSION_HEX >= 0x03000000 /* 3.0 */
    0,0,0,0,0,0,0,0,0,0,0,0,0,0,0 /* nb_inplace_add -> nb_index, nb_inplace_divide removed */
#else
    0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0 /* nb_inplace_add -> nb_index */
#endif
  };

  static PyTypeObject swigpyobject_type;
  static int type_init = 0;
  if (!type_init) {
    const PyTypeObject tmp = {
#if PY_VERSION_HEX >= 0x03000000
      PyVarObject_HEAD_INIT(NULL, 0)
#else
      PyObject_HEAD_INIT(NULL)
      0,                                    /* ob_size */
#endif
      "SwigPyObject",                       /* tp_name */
      sizeof(SwigPyObject),                 /* tp_basicsize */
      0,                                    /* tp_itemsize */
      (destructor)SwigPyObject_dealloc,     /* tp_dealloc */
      0,                                    /* tp_print */
      (getattrfunc)0,                       /* tp_getattr */
      (setattrfunc)0,                       /* tp_setattr */
#if PY_VERSION_HEX >= 0x03000000
      0, /* tp_reserved in 3.0.1, tp_compare in 3.0.0 but not used */
#else
      (cmpfunc)SwigPyObject_compare,        /* tp_compare */
#endif
      (reprfunc)SwigPyObject_repr,          /* tp_repr */
      &SwigPyObject_as_number,              /* tp_as_number */
      0,                                    /* tp_as_sequence */
      0,                                    /* tp_as_mapping */
      (hashfunc)0,                          /* tp_hash */
      (ternaryfunc)0,                       /* tp_call */
      0,                                    /* tp_str */
      PyObject_GenericGetAttr,              /* tp_getattro */
      0,                                    /* tp_setattro */
      0,                                    /* tp_as_buffer */
      Py_TPFLAGS_DEFAULT,                   /* tp_flags */
      swigobject_doc,                       /* tp_doc */
      0,                                    /* tp_traverse */
      0,                                    /* tp_clear */
      (richcmpfunc)SwigPyObject_richcompare,/* tp_richcompare */
      0,                                    /* tp_weaklistoffset */
      0,                                    /* tp_iter */
      0,                                    /* tp_iternext */
      swigobject_methods,                   /* tp_methods */
      0,                                    /* tp_members */
      0,                                    /* tp_getset */
      0,                                    /* tp_base */
      0,                                    /* tp_dict */
      0,                                    /* tp_descr_get */
      0,                                    /* tp_descr_set */
      0,                                    /* tp_dictoffset */
      0,                                    /* tp_init */
      0,                                    /* tp_alloc */
      0,                                    /* tp_new */
      0,                                    /* tp_free */
      0,                                    /* tp_is_gc */
      0,                                    /* tp_bases */
      0,                                    /* tp_mro */
      0,                                    /* tp_cache */
      0,                                    /* tp_subclasses */
      0,                                    /* tp_weaklist */
      0,                                    /* tp_del */
      0,                                    /* tp_version_tag */
#if PY_VERSION_HEX >= 0x03040000
      0,                                    /* tp_finalize */
#endif
#ifdef COUNT_ALLOCS
      0,                                    /* tp_allocs */
      0,                                    /* tp_frees */
      0,                                    /* tp_maxalloc */
      0,                                    /* tp_prev */
      0                                     /* tp_next */
#endif
    };
    swigpyobject_type = tmp;
    type_init = 1;
    if (PyType_Ready(&swigpyobject_type) < 0)
      return NULL;
  }
  return &swigpyobject_type;
}

SWIGRUNTIME PyObject *
SwigPyObject_New(void *ptr, swig_type_info *ty, int own)
{
  SwigPyObject *sobj = PyObject_NEW(SwigPyObject, SwigPyObject_type());
  if (sobj) {
    sobj->ptr  = ptr;
    sobj->ty   = ty;
    sobj->own  = own;
    sobj->next = 0;
  }
  return (PyObject *)sobj;
}

/* -----------------------------------------------------------------------------
 * Implements a simple Swig Packed type, and use it instead of string
 * ----------------------------------------------------------------------------- */

typedef struct {
  PyObject_HEAD
  void *pack;
  swig_type_info *ty;
  size_t size;
} SwigPyPacked;

SWIGRUNTIME PyObject *
SwigPyPacked_repr(SwigPyPacked *v)
{
  char result[SWIG_BUFFER_SIZE];
  if (SWIG_PackDataName(result, v->pack, v->size, 0, sizeof(result))) {
    return SWIG_Python_str_FromFormat("<Swig Packed at %s%s>", result, v->ty->name);
  } else {
    return SWIG_Python_str_FromFormat("<Swig Packed %s>", v->ty->name);
  }  
}

SWIGRUNTIME PyObject *
SwigPyPacked_str(SwigPyPacked *v)
{
  char result[SWIG_BUFFER_SIZE];
  if (SWIG_PackDataName(result, v->pack, v->size, 0, sizeof(result))){
    return SWIG_Python_str_FromFormat("%s%s", result, v->ty->name);
  } else {
    return SWIG_Python_str_FromChar(v->ty->name);
  }  
}

SWIGRUNTIME int
SwigPyPacked_compare(SwigPyPacked *v, SwigPyPacked *w)
{
  size_t i = v->size;
  size_t j = w->size;
  int s = (i < j) ? -1 : ((i > j) ? 1 : 0);
  return s ? s : strncmp((const char *)v->pack, (const char *)w->pack, 2*v->size);
}

SWIGRUNTIME PyTypeObject* SwigPyPacked_TypeOnce(void);

SWIGRUNTIME PyTypeObject*
SwigPyPacked_type(void) {
  static PyTypeObject *SWIG_STATIC_POINTER(type) = SwigPyPacked_TypeOnce();
  return type;
}

SWIGRUNTIMEINLINE int
SwigPyPacked_Check(PyObject *op) {
  return ((op)->ob_type == SwigPyPacked_TypeOnce()) 
    || (strcmp((op)->ob_type->tp_name,"SwigPyPacked") == 0);
}

SWIGRUNTIME void
SwigPyPacked_dealloc(PyObject *v)
{
  if (SwigPyPacked_Check(v)) {
    SwigPyPacked *sobj = (SwigPyPacked *) v;
    free(sobj->pack);
  }
  PyObject_DEL(v);
}

SWIGRUNTIME PyTypeObject*
SwigPyPacked_TypeOnce(void) {
  static char swigpacked_doc[] = "Swig object carries a C/C++ instance pointer";
  static PyTypeObject swigpypacked_type;
  static int type_init = 0;
  if (!type_init) {
    const PyTypeObject tmp = {
#if PY_VERSION_HEX>=0x03000000
      PyVarObject_HEAD_INIT(NULL, 0)
#else
      PyObject_HEAD_INIT(NULL)
      0,                                    /* ob_size */
#endif
      "SwigPyPacked",                       /* tp_name */
      sizeof(SwigPyPacked),                 /* tp_basicsize */
      0,                                    /* tp_itemsize */
      (destructor)SwigPyPacked_dealloc,     /* tp_dealloc */
      0,                                    /* tp_print */
      (getattrfunc)0,                       /* tp_getattr */
      (setattrfunc)0,                       /* tp_setattr */
#if PY_VERSION_HEX>=0x03000000
      0, /* tp_reserved in 3.0.1 */
#else
      (cmpfunc)SwigPyPacked_compare,        /* tp_compare */
#endif
      (reprfunc)SwigPyPacked_repr,          /* tp_repr */
      0,                                    /* tp_as_number */
      0,                                    /* tp_as_sequence */
      0,                                    /* tp_as_mapping */
      (hashfunc)0,                          /* tp_hash */
      (ternaryfunc)0,                       /* tp_call */
      (reprfunc)SwigPyPacked_str,           /* tp_str */
      PyObject_GenericGetAttr,              /* tp_getattro */
      0,                                    /* tp_setattro */
      0,                                    /* tp_as_buffer */
      Py_TPFLAGS_DEFAULT,                   /* tp_flags */
      swigpacked_doc,                       /* tp_doc */
      0,                                    /* tp_traverse */
      0,                                    /* tp_clear */
      0,                                    /* tp_richcompare */
      0,                                    /* tp_weaklistoffset */
      0,                                    /* tp_iter */
      0,                                    /* tp_iternext */
      0,                                    /* tp_methods */
      0,                                    /* tp_members */
      0,                                    /* tp_getset */
      0,                                    /* tp_base */
      0,                                    /* tp_dict */
      0,                                    /* tp_descr_get */
      0,                                    /* tp_descr_set */
      0,                                    /* tp_dictoffset */
      0,                                    /* tp_init */
      0,                                    /* tp_alloc */
      0,                                    /* tp_new */
      0,                                    /* tp_free */
      0,                                    /* tp_is_gc */
      0,                                    /* tp_bases */
      0,                                    /* tp_mro */
      0,                                    /* tp_cache */
      0,                                    /* tp_subclasses */
      0,                                    /* tp_weaklist */
      0,                                    /* tp_del */
      0,                                    /* tp_version_tag */
#if PY_VERSION_HEX >= 0x03040000
      0,                                    /* tp_finalize */
#endif
#ifdef COUNT_ALLOCS
      0,                                    /* tp_allocs */
      0,                                    /* tp_frees */
      0,                                    /* tp_maxalloc */
      0,                                    /* tp_prev */
      0                                     /* tp_next */
#endif
    };
    swigpypacked_type = tmp;
    type_init = 1;
    if (PyType_Ready(&swigpypacked_type) < 0)
      return NULL;
  }
  return &swigpypacked_type;
}

SWIGRUNTIME PyObject *
SwigPyPacked_New(void *ptr, size_t size, swig_type_info *ty)
{
  SwigPyPacked *sobj = PyObject_NEW(SwigPyPacked, SwigPyPacked_type());
  if (sobj) {
    void *pack = malloc(size);
    if (pack) {
      memcpy(pack, ptr, size);
      sobj->pack = pack;
      sobj->ty   = ty;
      sobj->size = size;
    } else {
      PyObject_DEL((PyObject *) sobj);
      sobj = 0;
    }
  }
  return (PyObject *) sobj;
}

SWIGRUNTIME swig_type_info *
SwigPyPacked_UnpackData(PyObject *obj, void *ptr, size_t size)
{
  if (SwigPyPacked_Check(obj)) {
    SwigPyPacked *sobj = (SwigPyPacked *)obj;
    if (sobj->size != size) return 0;
    memcpy(ptr, sobj->pack, size);
    return sobj->ty;
  } else {
    return 0;
  }
}

/* -----------------------------------------------------------------------------
 * pointers/data manipulation
 * ----------------------------------------------------------------------------- */

static PyObject *Swig_This_global = NULL;

SWIGRUNTIME PyObject *
SWIG_This(void)
{
  if (Swig_This_global == NULL)
    Swig_This_global = SWIG_Python_str_FromChar("this");
  return Swig_This_global;
}

/* #define SWIG_PYTHON_SLOW_GETSET_THIS */

/* TODO: I don't know how to implement the fast getset in Python 3 right now */
#if PY_VERSION_HEX>=0x03000000
#define SWIG_PYTHON_SLOW_GETSET_THIS 
#endif

SWIGRUNTIME SwigPyObject *
SWIG_Python_GetSwigThis(PyObject *pyobj) 
{
  PyObject *obj;

  if (SwigPyObject_Check(pyobj))
    return (SwigPyObject *) pyobj;

#ifdef SWIGPYTHON_BUILTIN
  (void)obj;
# ifdef PyWeakref_CheckProxy
  if (PyWeakref_CheckProxy(pyobj)) {
    pyobj = PyWeakref_GET_OBJECT(pyobj);
    if (pyobj && SwigPyObject_Check(pyobj))
      return (SwigPyObject*) pyobj;
  }
# endif
  return NULL;
#else

  obj = 0;

#if !defined(SWIG_PYTHON_SLOW_GETSET_THIS)
  if (PyInstance_Check(pyobj)) {
    obj = _PyInstance_Lookup(pyobj, SWIG_This());      
  } else {
    PyObject **dictptr = _PyObject_GetDictPtr(pyobj);
    if (dictptr != NULL) {
      PyObject *dict = *dictptr;
      obj = dict ? PyDict_GetItem(dict, SWIG_This()) : 0;
    } else {
#ifdef PyWeakref_CheckProxy
      if (PyWeakref_CheckProxy(pyobj)) {
	PyObject *wobj = PyWeakref_GET_OBJECT(pyobj);
	return wobj ? SWIG_Python_GetSwigThis(wobj) : 0;
      }
#endif
      obj = PyObject_GetAttr(pyobj,SWIG_This());
      if (obj) {
	Py_DECREF(obj);
      } else {
	if (PyErr_Occurred()) PyErr_Clear();
	return 0;
      }
    }
  }
#else
  obj = PyObject_GetAttr(pyobj,SWIG_This());
  if (obj) {
    Py_DECREF(obj);
  } else {
    if (PyErr_Occurred()) PyErr_Clear();
    return 0;
  }
#endif
  if (obj && !SwigPyObject_Check(obj)) {
    /* a PyObject is called 'this', try to get the 'real this'
       SwigPyObject from it */ 
    return SWIG_Python_GetSwigThis(obj);
  }
  return (SwigPyObject *)obj;
#endif
}

/* Acquire a pointer value */

SWIGRUNTIME int
SWIG_Python_AcquirePtr(PyObject *obj, int own) {
  if (own == SWIG_POINTER_OWN) {
    SwigPyObject *sobj = SWIG_Python_GetSwigThis(obj);
    if (sobj) {
      int oldown = sobj->own;
      sobj->own = own;
      return oldown;
    }
  }
  return 0;
}

/* Convert a pointer value */

SWIGRUNTIME int
SWIG_Python_ConvertPtrAndOwn(PyObject *obj, void **ptr, swig_type_info *ty, int flags, int *own) {
  int res;
  SwigPyObject *sobj;
  int implicit_conv = (flags & SWIG_POINTER_IMPLICIT_CONV) != 0;

  if (!obj)
    return SWIG_ERROR;
  if (obj == Py_None && !implicit_conv) {
    if (ptr)
      *ptr = 0;
    return (flags & SWIG_POINTER_NO_NULL) ? SWIG_NullReferenceError : SWIG_OK;
  }

  res = SWIG_ERROR;

  sobj = SWIG_Python_GetSwigThis(obj);
  if (own)
    *own = 0;
  while (sobj) {
    void *vptr = sobj->ptr;
    if (ty) {
      swig_type_info *to = sobj->ty;
      if (to == ty) {
        /* no type cast needed */
        if (ptr) *ptr = vptr;
        break;
      } else {
        swig_cast_info *tc = SWIG_TypeCheck(to->name,ty);
        if (!tc) {
          sobj = (SwigPyObject *)sobj->next;
        } else {
          if (ptr) {
            int newmemory = 0;
            *ptr = SWIG_TypeCast(tc,vptr,&newmemory);
            if (newmemory == SWIG_CAST_NEW_MEMORY) {
              assert(own); /* badly formed typemap which will lead to a memory leak - it must set and use own to delete *ptr */
              if (own)
                *own = *own | SWIG_CAST_NEW_MEMORY;
            }
          }
          break;
        }
      }
    } else {
      if (ptr) *ptr = vptr;
      break;
    }
  }
  if (sobj) {
    if (own)
      *own = *own | sobj->own;
    if (flags & SWIG_POINTER_DISOWN) {
      sobj->own = 0;
    }
    res = SWIG_OK;
  } else {
    if (implicit_conv) {
      SwigPyClientData *data = ty ? (SwigPyClientData *) ty->clientdata : 0;
      if (data && !data->implicitconv) {
        PyObject *klass = data->klass;
        if (klass) {
          PyObject *impconv;
          data->implicitconv = 1; /* avoid recursion and call 'explicit' constructors*/
          impconv = SWIG_Python_CallFunctor(klass, obj);
          data->implicitconv = 0;
          if (PyErr_Occurred()) {
            PyErr_Clear();
            impconv = 0;
          }
          if (impconv) {
            SwigPyObject *iobj = SWIG_Python_GetSwigThis(impconv);
            if (iobj) {
              void *vptr;
              res = SWIG_Python_ConvertPtrAndOwn((PyObject*)iobj, &vptr, ty, 0, 0);
              if (SWIG_IsOK(res)) {
                if (ptr) {
                  *ptr = vptr;
                  /* transfer the ownership to 'ptr' */
                  iobj->own = 0;
                  res = SWIG_AddCast(res);
                  res = SWIG_AddNewMask(res);
                } else {
                  res = SWIG_AddCast(res);		    
                }
              }
            }
            Py_DECREF(impconv);
          }
        }
      }
      if (!SWIG_IsOK(res) && obj == Py_None) {
        if (ptr)
          *ptr = 0;
        if (PyErr_Occurred())
          PyErr_Clear();
        res = SWIG_OK;
      }
    }
  }
  return res;
}

/* Convert a function ptr value */

SWIGRUNTIME int
SWIG_Python_ConvertFunctionPtr(PyObject *obj, void **ptr, swig_type_info *ty) {
  if (!PyCFunction_Check(obj)) {
    return SWIG_ConvertPtr(obj, ptr, ty, 0);
  } else {
    void *vptr = 0;
    swig_cast_info *tc;

    /* here we get the method pointer for callbacks */
    const char *doc = (((PyCFunctionObject *)obj) -> m_ml -> ml_doc);
    const char *desc = doc ? strstr(doc, "swig_ptr: ") : 0;
    if (desc)
      desc = ty ? SWIG_UnpackVoidPtr(desc + 10, &vptr, ty->name) : 0;
    if (!desc)
      return SWIG_ERROR;
    tc = SWIG_TypeCheck(desc,ty);
    if (tc) {
      int newmemory = 0;
      *ptr = SWIG_TypeCast(tc,vptr,&newmemory);
      assert(!newmemory); /* newmemory handling not yet implemented */
    } else {
      return SWIG_ERROR;
    }
    return SWIG_OK;
  }
}

/* Convert a packed pointer value */

SWIGRUNTIME int
SWIG_Python_ConvertPacked(PyObject *obj, void *ptr, size_t sz, swig_type_info *ty) {
  swig_type_info *to = SwigPyPacked_UnpackData(obj, ptr, sz);
  if (!to) return SWIG_ERROR;
  if (ty) {
    if (to != ty) {
      /* check type cast? */
      swig_cast_info *tc = SWIG_TypeCheck(to->name,ty);
      if (!tc) return SWIG_ERROR;
    }
  }
  return SWIG_OK;
}  

/* -----------------------------------------------------------------------------
 * Create a new pointer object
 * ----------------------------------------------------------------------------- */

/*
  Create a new instance object, without calling __init__, and set the
  'this' attribute.
*/

SWIGRUNTIME PyObject* 
SWIG_Python_NewShadowInstance(SwigPyClientData *data, PyObject *swig_this)
{
  PyObject *inst = 0;
  PyObject *newraw = data->newraw;
  if (newraw) {
    inst = PyObject_Call(newraw, data->newargs, NULL);
    if (inst) {
#if !defined(SWIG_PYTHON_SLOW_GETSET_THIS)
      PyObject **dictptr = _PyObject_GetDictPtr(inst);
      if (dictptr != NULL) {
	PyObject *dict = *dictptr;
	if (dict == NULL) {
	  dict = PyDict_New();
	  *dictptr = dict;
	  PyDict_SetItem(dict, SWIG_This(), swig_this);
	}
      }
#else
      PyObject *key = SWIG_This();
      PyObject_SetAttr(inst, key, swig_this);
#endif
    }
  } else {
#if PY_VERSION_HEX >= 0x03000000
    PyObject *empty_args = PyTuple_New(0);
    if (empty_args) {
      PyObject *empty_kwargs = PyDict_New();
      if (empty_kwargs) {
        inst = ((PyTypeObject *)data->newargs)->tp_new((PyTypeObject *)data->newargs, empty_args, empty_kwargs);
        Py_DECREF(empty_kwargs);
        if (inst) {
          PyObject_SetAttr(inst, SWIG_This(), swig_this);
          Py_TYPE(inst)->tp_flags &= ~Py_TPFLAGS_VALID_VERSION_TAG;
        }
      }
      Py_DECREF(empty_args);
    }
#else
    PyObject *dict = PyDict_New();
    if (dict) {
      PyDict_SetItem(dict, SWIG_This(), swig_this);
      inst = PyInstance_NewRaw(data->newargs, dict);
      Py_DECREF(dict);
    }
#endif
  }
  return inst;
}

SWIGRUNTIME void
SWIG_Python_SetSwigThis(PyObject *inst, PyObject *swig_this)
{
 PyObject *dict;
#if !defined(SWIG_PYTHON_SLOW_GETSET_THIS)
 PyObject **dictptr = _PyObject_GetDictPtr(inst);
 if (dictptr != NULL) {
   dict = *dictptr;
   if (dict == NULL) {
     dict = PyDict_New();
     *dictptr = dict;
   }
   PyDict_SetItem(dict, SWIG_This(), swig_this);
   return;
 }
#endif
 dict = PyObject_GetAttrString(inst, "__dict__");
 PyDict_SetItem(dict, SWIG_This(), swig_this);
 Py_DECREF(dict);
} 


SWIGINTERN PyObject *
SWIG_Python_InitShadowInstance(PyObject *args) {
  PyObject *obj[2];
  if (!SWIG_Python_UnpackTuple(args, "swiginit", 2, 2, obj)) {
    return NULL;
  } else {
    SwigPyObject *sthis = SWIG_Python_GetSwigThis(obj[0]);
    if (sthis) {
      SwigPyObject_append((PyObject*) sthis, obj[1]);
    } else {
      SWIG_Python_SetSwigThis(obj[0], obj[1]);
    }
    return SWIG_Py_Void();
  }
}

/* Create a new pointer object */

SWIGRUNTIME PyObject *
SWIG_Python_NewPointerObj(PyObject *self, void *ptr, swig_type_info *type, int flags) {
  SwigPyClientData *clientdata;
  PyObject * robj;
  int own;

  if (!ptr)
    return SWIG_Py_Void();

  clientdata = type ? (SwigPyClientData *)(type->clientdata) : 0;
  own = (flags & SWIG_POINTER_OWN) ? SWIG_POINTER_OWN : 0;
  if (clientdata && clientdata->pytype) {
    SwigPyObject *newobj;
    if (flags & SWIG_BUILTIN_TP_INIT) {
      newobj = (SwigPyObject*) self;
      if (newobj->ptr) {
        PyObject *next_self = clientdata->pytype->tp_alloc(clientdata->pytype, 0);
        while (newobj->next)
	  newobj = (SwigPyObject *) newobj->next;
        newobj->next = next_self;
        newobj = (SwigPyObject *)next_self;
#ifdef SWIGPYTHON_BUILTIN
        newobj->dict = 0;
#endif
      }
    } else {
      newobj = PyObject_New(SwigPyObject, clientdata->pytype);
#ifdef SWIGPYTHON_BUILTIN
      newobj->dict = 0;
#endif
    }
    if (newobj) {
      newobj->ptr = ptr;
      newobj->ty = type;
      newobj->own = own;
      newobj->next = 0;
      return (PyObject*) newobj;
    }
    return SWIG_Py_Void();
  }

  assert(!(flags & SWIG_BUILTIN_TP_INIT));

  robj = SwigPyObject_New(ptr, type, own);
  if (robj && clientdata && !(flags & SWIG_POINTER_NOSHADOW)) {
    PyObject *inst = SWIG_Python_NewShadowInstance(clientdata, robj);
    Py_DECREF(robj);
    robj = inst;
  }
  return robj;
}

/* Create a new packed object */

SWIGRUNTIMEINLINE PyObject *
SWIG_Python_NewPackedObj(void *ptr, size_t sz, swig_type_info *type) {
  return ptr ? SwigPyPacked_New((void *) ptr, sz, type) : SWIG_Py_Void();
}

/* -----------------------------------------------------------------------------*
 *  Get type list 
 * -----------------------------------------------------------------------------*/

#ifdef SWIG_LINK_RUNTIME
void *SWIG_ReturnGlobalTypeList(void *);
#endif

SWIGRUNTIME swig_module_info *
SWIG_Python_GetModule(void *SWIGUNUSEDPARM(clientdata)) {
  static void *type_pointer = (void *)0;
  /* first check if module already created */
  if (!type_pointer) {
#ifdef SWIG_LINK_RUNTIME
    type_pointer = SWIG_ReturnGlobalTypeList((void *)0);
#else
    type_pointer = PyCapsule_Import(SWIGPY_CAPSULE_NAME, 0);
    if (PyErr_Occurred()) {
      PyErr_Clear();
      type_pointer = (void *)0;
    }
#endif
  }
  return (swig_module_info *) type_pointer;
}

SWIGRUNTIME void
SWIG_Python_DestroyModule(PyObject *obj)
{
  swig_module_info *swig_module = (swig_module_info *) PyCapsule_GetPointer(obj, SWIGPY_CAPSULE_NAME);
  swig_type_info **types = swig_module->types;
  size_t i;
  for (i =0; i < swig_module->size; ++i) {
    swig_type_info *ty = types[i];
    if (ty->owndata) {
      SwigPyClientData *data = (SwigPyClientData *) ty->clientdata;
      if (data) SwigPyClientData_Del(data);
    }
  }
  Py_DECREF(SWIG_This());
  Swig_This_global = NULL;
}

SWIGRUNTIME void
SWIG_Python_SetModule(swig_module_info *swig_module) {
#if PY_VERSION_HEX >= 0x03000000
 /* Add a dummy module object into sys.modules */
  PyObject *module = PyImport_AddModule("swig_runtime_data" SWIG_RUNTIME_VERSION);
#else
  static PyMethodDef swig_empty_runtime_method_table[] = { {NULL, NULL, 0, NULL} }; /* Sentinel */
  PyObject *module = Py_InitModule("swig_runtime_data" SWIG_RUNTIME_VERSION, swig_empty_runtime_method_table);
#endif
  PyObject *pointer = PyCapsule_New((void *) swig_module, SWIGPY_CAPSULE_NAME, SWIG_Python_DestroyModule);
  if (pointer && module) {
    PyModule_AddObject(module, "type_pointer_capsule" SWIG_TYPE_TABLE_NAME, pointer);
  } else {
    Py_XDECREF(pointer);
  }
}

/* The python cached type query */
SWIGRUNTIME PyObject *
SWIG_Python_TypeCache(void) {
  static PyObject *SWIG_STATIC_POINTER(cache) = PyDict_New();
  return cache;
}

SWIGRUNTIME swig_type_info *
SWIG_Python_TypeQuery(const char *type)
{
  PyObject *cache = SWIG_Python_TypeCache();
  PyObject *key = SWIG_Python_str_FromChar(type); 
  PyObject *obj = PyDict_GetItem(cache, key);
  swig_type_info *descriptor;
  if (obj) {
    descriptor = (swig_type_info *) PyCapsule_GetPointer(obj, NULL);
  } else {
    swig_module_info *swig_module = SWIG_GetModule(0);
    descriptor = SWIG_TypeQueryModule(swig_module, swig_module, type);
    if (descriptor) {
      obj = PyCapsule_New((void*) descriptor, NULL, NULL);
      PyDict_SetItem(cache, key, obj);
      Py_DECREF(obj);
    }
  }
  Py_DECREF(key);
  return descriptor;
}

/* 
   For backward compatibility only
*/
#define SWIG_POINTER_EXCEPTION  0
#define SWIG_arg_fail(arg)      SWIG_Python_ArgFail(arg)
#define SWIG_MustGetPtr(p, type, argnum, flags)  SWIG_Python_MustGetPtr(p, type, argnum, flags)

SWIGRUNTIME int
SWIG_Python_AddErrMesg(const char* mesg, int infront)
{  
  if (PyErr_Occurred()) {
    PyObject *type = 0;
    PyObject *value = 0;
    PyObject *traceback = 0;
    PyErr_Fetch(&type, &value, &traceback);
    if (value) {
      PyObject *old_str = PyObject_Str(value);
      const char *tmp = SWIG_Python_str_AsChar(old_str);
      const char *errmesg = tmp ? tmp : "Invalid error message";
      Py_XINCREF(type);
      PyErr_Clear();
      if (infront) {
	PyErr_Format(type, "%s %s", mesg, errmesg);
      } else {
	PyErr_Format(type, "%s %s", errmesg, mesg);
      }
      SWIG_Python_str_DelForPy3(tmp);
      Py_DECREF(old_str);
    }
    return 1;
  } else {
    return 0;
  }
}
  
SWIGRUNTIME int
SWIG_Python_ArgFail(int argnum)
{
  if (PyErr_Occurred()) {
    /* add information about failing argument */
    char mesg[256];
    PyOS_snprintf(mesg, sizeof(mesg), "argument number %d:", argnum);
    return SWIG_Python_AddErrMesg(mesg, 1);
  } else {
    return 0;
  }
}

SWIGRUNTIMEINLINE const char *
SwigPyObject_GetDesc(PyObject *self)
{
  SwigPyObject *v = (SwigPyObject *)self;
  swig_type_info *ty = v ? v->ty : 0;
  return ty ? ty->str : "";
}

SWIGRUNTIME void
SWIG_Python_TypeError(const char *type, PyObject *obj)
{
  if (type) {
#if defined(SWIG_COBJECT_TYPES)
    if (obj && SwigPyObject_Check(obj)) {
      const char *otype = (const char *) SwigPyObject_GetDesc(obj);
      if (otype) {
	PyErr_Format(PyExc_TypeError, "a '%s' is expected, 'SwigPyObject(%s)' is received",
		     type, otype);
	return;
      }
    } else 
#endif      
    {
      const char *otype = (obj ? obj->ob_type->tp_name : 0); 
      if (otype) {
	PyObject *str = PyObject_Str(obj);
	const char *cstr = str ? SWIG_Python_str_AsChar(str) : 0;
	if (cstr) {
	  PyErr_Format(PyExc_TypeError, "a '%s' is expected, '%s(%s)' is received",
		       type, otype, cstr);
          SWIG_Python_str_DelForPy3(cstr);
	} else {
	  PyErr_Format(PyExc_TypeError, "a '%s' is expected, '%s' is received",
		       type, otype);
	}
	Py_XDECREF(str);
	return;
      }
    }   
    PyErr_Format(PyExc_TypeError, "a '%s' is expected", type);
  } else {
    PyErr_Format(PyExc_TypeError, "unexpected type is received");
  }
}


/* Convert a pointer value, signal an exception on a type mismatch */
SWIGRUNTIME void *
SWIG_Python_MustGetPtr(PyObject *obj, swig_type_info *ty, int SWIGUNUSEDPARM(argnum), int flags) {
  void *result;
  if (SWIG_Python_ConvertPtr(obj, &result, ty, flags) == -1) {
    PyErr_Clear();
#if SWIG_POINTER_EXCEPTION
    if (flags) {
      SWIG_Python_TypeError(SWIG_TypePrettyName(ty), obj);
      SWIG_Python_ArgFail(argnum);
    }
#endif
  }
  return result;
}

#ifdef SWIGPYTHON_BUILTIN
SWIGRUNTIME int
SWIG_Python_NonDynamicSetAttr(PyObject *obj, PyObject *name, PyObject *value) {
  PyTypeObject *tp = obj->ob_type;
  PyObject *descr;
  PyObject *encoded_name;
  descrsetfunc f;
  int res = -1;

# ifdef Py_USING_UNICODE
  if (PyString_Check(name)) {
    name = PyUnicode_Decode(PyString_AsString(name), PyString_Size(name), NULL, NULL);
    if (!name)
      return -1;
  } else if (!PyUnicode_Check(name))
# else
  if (!PyString_Check(name))
# endif
  {
    PyErr_Format(PyExc_TypeError, "attribute name must be string, not '%.200s'", name->ob_type->tp_name);
    return -1;
  } else {
    Py_INCREF(name);
  }

  if (!tp->tp_dict) {
    if (PyType_Ready(tp) < 0)
      goto done;
  }

  descr = _PyType_Lookup(tp, name);
  f = NULL;
  if (descr != NULL)
    f = descr->ob_type->tp_descr_set;
  if (!f) {
    if (PyString_Check(name)) {
      encoded_name = name;
      Py_INCREF(name);
    } else {
      encoded_name = PyUnicode_AsUTF8String(name);
      if (!encoded_name)
        return -1;
    }
    PyErr_Format(PyExc_AttributeError, "'%.100s' object has no attribute '%.200s'", tp->tp_name, PyString_AsString(encoded_name));
    Py_DECREF(encoded_name);
  } else {
    res = f(descr, obj, value);
  }
  
  done:
  Py_DECREF(name);
  return res;
}
#endif


#ifdef __cplusplus
}
#endif



#define SWIG_exception_fail(code, msg) do { SWIG_Error(code, msg); SWIG_fail; } while(0) 

#define SWIG_contract_assert(expr, msg) if (!(expr)) { SWIG_Error(SWIG_RuntimeError, msg); SWIG_fail; } else 



#ifdef __cplusplus
extern "C" {
#endif

/* Method creation and docstring support functions */

SWIGINTERN PyMethodDef *SWIG_PythonGetProxyDoc(const char *name);
SWIGINTERN PyObject *SWIG_PyInstanceMethod_New(PyObject *SWIGUNUSEDPARM(self), PyObject *func);
SWIGINTERN PyObject *SWIG_PyStaticMethod_New(PyObject *SWIGUNUSEDPARM(self), PyObject *func);

#ifdef __cplusplus
}
#endif


  #define SWIG_exception(code, msg) do { SWIG_Error(code, msg); SWIG_fail;; } while(0) 

/* -----------------------------------------------------------------------------
 * director_common.swg
 *
 * This file contains support for director classes which is common between
 * languages.
 * ----------------------------------------------------------------------------- */

/*
  Use -DSWIG_DIRECTOR_STATIC if you prefer to avoid the use of the
  'Swig' namespace. This could be useful for multi-modules projects.
*/
#ifdef SWIG_DIRECTOR_STATIC
/* Force anonymous (static) namespace */
#define Swig
#endif
/* -----------------------------------------------------------------------------
 * director.swg
 *
 * This file contains support for director classes so that Python proxy
 * methods can be called from C++.
 * ----------------------------------------------------------------------------- */

#ifndef SWIG_DIRECTOR_PYTHON_HEADER_
#define SWIG_DIRECTOR_PYTHON_HEADER_

#include <string>
#include <iostream>
#include <exception>
#include <vector>
#include <map>


/*
  Use -DSWIG_PYTHON_DIRECTOR_NO_VTABLE if you don't want to generate a 'virtual
  table', and avoid multiple GetAttr calls to retrieve the python
  methods.
*/

#ifndef SWIG_PYTHON_DIRECTOR_NO_VTABLE
#ifndef SWIG_PYTHON_DIRECTOR_VTABLE
#define SWIG_PYTHON_DIRECTOR_VTABLE
#endif
#endif



/*
  Use -DSWIG_DIRECTOR_NO_UEH if you prefer to avoid the use of the
  Undefined Exception Handler provided by swig.
*/
#ifndef SWIG_DIRECTOR_NO_UEH
#ifndef SWIG_DIRECTOR_UEH
#define SWIG_DIRECTOR_UEH
#endif
#endif


/*
  Use -DSWIG_DIRECTOR_NORTTI if you prefer to avoid the use of the
  native C++ RTTI and dynamic_cast<>. But be aware that directors
  could stop working when using this option.
*/
#ifdef SWIG_DIRECTOR_NORTTI
/*
   When we don't use the native C++ RTTI, we implement a minimal one
   only for Directors.
*/
# ifndef SWIG_DIRECTOR_RTDIR
# define SWIG_DIRECTOR_RTDIR

namespace Swig {
  class Director;
  SWIGINTERN std::map<void *, Director *>& get_rtdir_map() {
    static std::map<void *, Director *> rtdir_map;
    return rtdir_map;
  }

  SWIGINTERNINLINE void set_rtdir(void *vptr, Director *rtdir) {
    get_rtdir_map()[vptr] = rtdir;
  }

  SWIGINTERNINLINE Director *get_rtdir(void *vptr) {
    std::map<void *, Director *>::const_iterator pos = get_rtdir_map().find(vptr);
    Director *rtdir = (pos != get_rtdir_map().end()) ? pos->second : 0;
    return rtdir;
  }
}
# endif /* SWIG_DIRECTOR_RTDIR */

# define SWIG_DIRECTOR_CAST(ARG) Swig::get_rtdir(static_cast<void *>(ARG))
# define SWIG_DIRECTOR_RGTR(ARG1, ARG2) Swig::set_rtdir(static_cast<void *>(ARG1), ARG2)

#else

# define SWIG_DIRECTOR_CAST(ARG) dynamic_cast<Swig::Director *>(ARG)
# define SWIG_DIRECTOR_RGTR(ARG1, ARG2)

#endif /* SWIG_DIRECTOR_NORTTI */

extern "C" {
  struct swig_type_info;
}

namespace Swig {

  /* memory handler */
  struct GCItem {
    virtual ~GCItem() {}

    virtual int get_own() const {
      return 0;
    }
  };

  struct GCItem_var {
    GCItem_var(GCItem *item = 0) : _item(item) {
    }

    GCItem_var& operator=(GCItem *item) {
      GCItem *tmp = _item;
      _item = item;
      delete tmp;
      return *this;
    }

    ~GCItem_var() {
      delete _item;
    }

    GCItem * operator->() const {
      return _item;
    }

  private:
    GCItem *_item;
  };

  struct GCItem_Object : GCItem {
    GCItem_Object(int own) : _own(own) {
    }

    virtual ~GCItem_Object() {
    }

    int get_own() const {
      return _own;
    }

  private:
    int _own;
  };

  template <typename Type>
  struct GCItem_T : GCItem {
    GCItem_T(Type *ptr) : _ptr(ptr) {
    }

    virtual ~GCItem_T() {
      delete _ptr;
    }

  private:
    Type *_ptr;
  };

  template <typename Type>
  struct GCArray_T : GCItem {
    GCArray_T(Type *ptr) : _ptr(ptr) {
    }

    virtual ~GCArray_T() {
      delete[] _ptr;
    }

  private:
    Type *_ptr;
  };

  /* base class for director exceptions */
  class DirectorException : public std::exception {
  protected:
    std::string swig_msg;
  public:
    DirectorException(PyObject *error, const char *hdr ="", const char *msg ="") : swig_msg(hdr) {
      SWIG_PYTHON_THREAD_BEGIN_BLOCK;
      if (msg[0]) {
        swig_msg += " ";
        swig_msg += msg;
      }
      if (!PyErr_Occurred()) {
        PyErr_SetString(error, what());
      }
      SWIG_PYTHON_THREAD_END_BLOCK;
    }

    virtual ~DirectorException() throw() {
    }

    /* Deprecated, use what() instead */
    const char *getMessage() const {
      return what();
    }

    const char *what() const throw() {
      return swig_msg.c_str();
    }

    static void raise(PyObject *error, const char *msg) {
      throw DirectorException(error, msg);
    }

    static void raise(const char *msg) {
      raise(PyExc_RuntimeError, msg);
    }
  };

  /* type mismatch in the return value from a python method call */
  class DirectorTypeMismatchException : public DirectorException {
  public:
    DirectorTypeMismatchException(PyObject *error, const char *msg="")
      : DirectorException(error, "SWIG director type mismatch", msg) {
    }

    DirectorTypeMismatchException(const char *msg="")
      : DirectorException(PyExc_TypeError, "SWIG director type mismatch", msg) {
    }

    static void raise(PyObject *error, const char *msg) {
      throw DirectorTypeMismatchException(error, msg);
    }

    static void raise(const char *msg) {
      throw DirectorTypeMismatchException(msg);
    }
  };

  /* any python exception that occurs during a director method call */
  class DirectorMethodException : public DirectorException {
  public:
    DirectorMethodException(const char *msg = "")
      : DirectorException(PyExc_RuntimeError, "SWIG director method error.", msg) {
    }

    static void raise(const char *msg) {
      throw DirectorMethodException(msg);
    }
  };

  /* attempt to call a pure virtual method via a director method */
  class DirectorPureVirtualException : public DirectorException {
  public:
    DirectorPureVirtualException(const char *msg = "")
      : DirectorException(PyExc_RuntimeError, "SWIG director pure virtual method called", msg) {
    }

    static void raise(const char *msg) {
      throw DirectorPureVirtualException(msg);
    }
  };


#if defined(SWIG_PYTHON_THREADS)
/*  __THREAD__ is the old macro to activate some thread support */
# if !defined(__THREAD__)
#   define __THREAD__ 1
# endif
#endif

#ifdef __THREAD__
# include "pythread.h"
  class Guard {
    PyThread_type_lock &mutex_;

  public:
    Guard(PyThread_type_lock & mutex) : mutex_(mutex) {
      PyThread_acquire_lock(mutex_, WAIT_LOCK);
    }

    ~Guard() {
      PyThread_release_lock(mutex_);
    }
  };
# define SWIG_GUARD(mutex) Guard _guard(mutex)
#else
# define SWIG_GUARD(mutex)
#endif

  /* director base class */
  class Director {
  private:
    /* pointer to the wrapped python object */
    PyObject *swig_self;
    /* flag indicating whether the object is owned by python or c++ */
    mutable bool swig_disown_flag;

    /* decrement the reference count of the wrapped python object */
    void swig_decref() const {
      if (swig_disown_flag) {
        SWIG_PYTHON_THREAD_BEGIN_BLOCK;
        Py_DECREF(swig_self);
        SWIG_PYTHON_THREAD_END_BLOCK;
      }
    }

  public:
    /* wrap a python object. */
    Director(PyObject *self) : swig_self(self), swig_disown_flag(false) {
    }

    /* discard our reference at destruction */
    virtual ~Director() {
      swig_decref();
    }

    /* return a pointer to the wrapped python object */
    PyObject *swig_get_self() const {
      return swig_self;
    }

    /* acquire ownership of the wrapped python object (the sense of "disown" is from python) */
    void swig_disown() const {
      if (!swig_disown_flag) {
        swig_disown_flag=true;
        swig_incref();
      }
    }

    /* increase the reference count of the wrapped python object */
    void swig_incref() const {
      if (swig_disown_flag) {
        Py_INCREF(swig_self);
      }
    }

    /* methods to implement pseudo protected director members */
    virtual bool swig_get_inner(const char * /* swig_protected_method_name */) const {
      return true;
    }

    virtual void swig_set_inner(const char * /* swig_protected_method_name */, bool /* swig_val */) const {
    }

  /* ownership management */
  private:
    typedef std::map<void *, GCItem_var> swig_ownership_map;
    mutable swig_ownership_map swig_owner;
#ifdef __THREAD__
    static PyThread_type_lock swig_mutex_own;
#endif

  public:
    template <typename Type>
    void swig_acquire_ownership_array(Type *vptr) const {
      if (vptr) {
        SWIG_GUARD(swig_mutex_own);
        swig_owner[vptr] = new GCArray_T<Type>(vptr);
      }
    }

    template <typename Type>
    void swig_acquire_ownership(Type *vptr) const {
      if (vptr) {
        SWIG_GUARD(swig_mutex_own);
        swig_owner[vptr] = new GCItem_T<Type>(vptr);
      }
    }

    void swig_acquire_ownership_obj(void *vptr, int own) const {
      if (vptr && own) {
        SWIG_GUARD(swig_mutex_own);
        swig_owner[vptr] = new GCItem_Object(own);
      }
    }

    int swig_release_ownership(void *vptr) const {
      int own = 0;
      if (vptr) {
        SWIG_GUARD(swig_mutex_own);
        swig_ownership_map::iterator iter = swig_owner.find(vptr);
        if (iter != swig_owner.end()) {
          own = iter->second->get_own();
          swig_owner.erase(iter);
        }
      }
      return own;
    }

    template <typename Type>
    static PyObject *swig_pyobj_disown(PyObject *pyobj, PyObject *SWIGUNUSEDPARM(args)) {
      SwigPyObject *sobj = (SwigPyObject *)pyobj;
      sobj->own = 0;
      Director *d = SWIG_DIRECTOR_CAST(reinterpret_cast<Type *>(sobj->ptr));
      if (d)
        d->swig_disown();
      return PyWeakref_NewProxy(pyobj, NULL);
    }
  };

#ifdef __THREAD__
  PyThread_type_lock Director::swig_mutex_own = PyThread_allocate_lock();
#endif
}

#endif

/* -------- TYPES TABLE (BEGIN) -------- */

#define SWIGTYPE_p_allocator_type swig_types[0]
#define SWIGTYPE_p_char swig_types[1]
#define SWIGTYPE_p_difference_type swig_types[2]
#define SWIGTYPE_p_int swig_types[3]
#define SWIGTYPE_p_key_type swig_types[4]
#define SWIGTYPE_p_mapped_type swig_types[5]
#define SWIGTYPE_p_p_PyObject swig_types[6]
#define SWIGTYPE_p_p_void swig_types[7]
#define SWIGTYPE_p_pj__Account swig_types[8]
#define SWIGTYPE_p_pj__AccountCallConfig swig_types[9]
#define SWIGTYPE_p_pj__AccountConfig swig_types[10]
#define SWIGTYPE_p_pj__AccountInfo swig_types[11]
#define SWIGTYPE_p_pj__AccountIpChangeConfig swig_types[12]
#define SWIGTYPE_p_pj__AccountMediaConfig swig_types[13]
#define SWIGTYPE_p_pj__AccountMwiConfig swig_types[14]
#define SWIGTYPE_p_pj__AccountNatConfig swig_types[15]
#define SWIGTYPE_p_pj__AccountPresConfig swig_types[16]
#define SWIGTYPE_p_pj__AccountRegConfig swig_types[17]
#define SWIGTYPE_p_pj__AccountSipConfig swig_types[18]
#define SWIGTYPE_p_pj__AccountVideoConfig swig_types[19]
#define SWIGTYPE_p_pj__AudDevErrorEvent swig_types[20]
#define SWIGTYPE_p_pj__AudDevManager swig_types[21]
#define SWIGTYPE_p_pj__AudioDevInfo swig_types[22]
#define SWIGTYPE_p_pj__AudioMedia swig_types[23]
#define SWIGTYPE_p_pj__AudioMediaPlayer swig_types[24]
#define SWIGTYPE_p_pj__AudioMediaPlayerInfo swig_types[25]
#define SWIGTYPE_p_pj__AudioMediaRecorder swig_types[26]
#define SWIGTYPE_p_pj__AudioMediaTransmitParam swig_types[27]
#define SWIGTYPE_p_pj__AuthCredInfo swig_types[28]
#define SWIGTYPE_p_pj__Buddy swig_types[29]
#define SWIGTYPE_p_pj__BuddyConfig swig_types[30]
#define SWIGTYPE_p_pj__BuddyInfo swig_types[31]
#define SWIGTYPE_p_pj__Call swig_types[32]
#define SWIGTYPE_p_pj__CallInfo swig_types[33]
#define SWIGTYPE_p_pj__CallMediaInfo swig_types[34]
#define SWIGTYPE_p_pj__CallOpParam swig_types[35]
#define SWIGTYPE_p_pj__CallSendDtmfParam swig_types[36]
#define SWIGTYPE_p_pj__CallSendRequestParam swig_types[37]
#define SWIGTYPE_p_pj__CallSetting swig_types[38]
#define SWIGTYPE_p_pj__CallVidSetStreamParam swig_types[39]
#define SWIGTYPE_p_pj__CodecFmtp swig_types[40]
#define SWIGTYPE_p_pj__CodecInfo swig_types[41]
#define SWIGTYPE_p_pj__CodecOpusConfig swig_types[42]
#define SWIGTYPE_p_pj__CodecParam swig_types[43]
#define SWIGTYPE_p_pj__CodecParamInfo swig_types[44]
#define SWIGTYPE_p_pj__CodecParamSetting swig_types[45]
#define SWIGTYPE_p_pj__ConfPortInfo swig_types[46]
#define SWIGTYPE_p_pj__ContainerNode swig_types[47]
#define SWIGTYPE_p_pj__DigestChallenge swig_types[48]
#define SWIGTYPE_p_pj__DigestCredential swig_types[49]
#define SWIGTYPE_p_pj__Endpoint swig_types[50]
#define SWIGTYPE_p_pj__EpConfig swig_types[51]
#define SWIGTYPE_p_pj__Error swig_types[52]
#define SWIGTYPE_p_pj__ExtraAudioDevice swig_types[53]
#define SWIGTYPE_p_pj__FindBuddyMatch swig_types[54]
#define SWIGTYPE_p_pj__IpChangeParam swig_types[55]
#define SWIGTYPE_p_pj__JbufState swig_types[56]
#define SWIGTYPE_p_pj__JsonDocument swig_types[57]
#define SWIGTYPE_p_pj__LogConfig swig_types[58]
#define SWIGTYPE_p_pj__LogEntry swig_types[59]
#define SWIGTYPE_p_pj__LogWriter swig_types[60]
#define SWIGTYPE_p_pj__LossType swig_types[61]
#define SWIGTYPE_p_pj__MathStat swig_types[62]
#define SWIGTYPE_p_pj__Media swig_types[63]
#define SWIGTYPE_p_pj__MediaConfig swig_types[64]
#define SWIGTYPE_p_pj__MediaCoordinate swig_types[65]
#define SWIGTYPE_p_pj__MediaEvent swig_types[66]
#define SWIGTYPE_p_pj__MediaEventData swig_types[67]
#define SWIGTYPE_p_pj__MediaFmtChangedEvent swig_types[68]
#define SWIGTYPE_p_pj__MediaFormat swig_types[69]
#define SWIGTYPE_p_pj__MediaFormatAudio swig_types[70]
#define SWIGTYPE_p_pj__MediaFormatVideo swig_types[71]
#define SWIGTYPE_p_pj__MediaSize swig_types[72]
#define SWIGTYPE_p_pj__MediaTransportInfo swig_types[73]
#define SWIGTYPE_p_pj__OnBuddyEvSubStateParam swig_types[74]
#define SWIGTYPE_p_pj__OnCallMediaEventParam swig_types[75]
#define SWIGTYPE_p_pj__OnCallMediaStateParam swig_types[76]
#define SWIGTYPE_p_pj__OnCallMediaTransportStateParam swig_types[77]
#define SWIGTYPE_p_pj__OnCallRedirectedParam swig_types[78]
#define SWIGTYPE_p_pj__OnCallReplaceRequestParam swig_types[79]
#define SWIGTYPE_p_pj__OnCallReplacedParam swig_types[80]
#define SWIGTYPE_p_pj__OnCallRxOfferParam swig_types[81]
#define SWIGTYPE_p_pj__OnCallRxReinviteParam swig_types[82]
#define SWIGTYPE_p_pj__OnCallSdpCreatedParam swig_types[83]
#define SWIGTYPE_p_pj__OnCallStateParam swig_types[84]
#define SWIGTYPE_p_pj__OnCallTransferRequestParam swig_types[85]
#define SWIGTYPE_p_pj__OnCallTransferStatusParam swig_types[86]
#define SWIGTYPE_p_pj__OnCallTsxStateParam swig_types[87]
#define SWIGTYPE_p_pj__OnCallTxOfferParam swig_types[88]
#define SWIGTYPE_p_pj__OnCreateMediaTransportParam swig_types[89]
#define SWIGTYPE_p_pj__OnCreateMediaTransportSrtpParam swig_types[90]
#define SWIGTYPE_p_pj__OnCredAuthParam swig_types[91]
#define SWIGTYPE_p_pj__OnDtmfDigitParam swig_types[92]
#define SWIGTYPE_p_pj__OnDtmfEventParam swig_types[93]
#define SWIGTYPE_p_pj__OnIncomingCallParam swig_types[94]
#define SWIGTYPE_p_pj__OnIncomingSubscribeParam swig_types[95]
#define SWIGTYPE_p_pj__OnInstantMessageParam swig_types[96]
#define SWIGTYPE_p_pj__OnInstantMessageStatusParam swig_types[97]
#define SWIGTYPE_p_pj__OnIpChangeProgressParam swig_types[98]
#define SWIGTYPE_p_pj__OnMediaEventParam swig_types[99]
#define SWIGTYPE_p_pj__OnMwiInfoParam swig_types[100]
#define SWIGTYPE_p_pj__OnNatCheckStunServersCompleteParam swig_types[101]
#define SWIGTYPE_p_pj__OnNatDetectionCompleteParam swig_types[102]
#define SWIGTYPE_p_pj__OnRegStartedParam swig_types[103]
#define SWIGTYPE_p_pj__OnRegStateParam swig_types[104]
#define SWIGTYPE_p_pj__OnSelectAccountParam swig_types[105]
#define SWIGTYPE_p_pj__OnStreamCreatedParam swig_types[106]
#define SWIGTYPE_p_pj__OnStreamDestroyedParam swig_types[107]
#define SWIGTYPE_p_pj__OnStreamPreCreateParam swig_types[108]
#define SWIGTYPE_p_pj__OnTimerParam swig_types[109]
#define SWIGTYPE_p_pj__OnTransportStateParam swig_types[110]
#define SWIGTYPE_p_pj__OnTypingIndicationParam swig_types[111]
#define SWIGTYPE_p_pj__PendingJob swig_types[112]
#define SWIGTYPE_p_pj__PersistentDocument swig_types[113]
#define SWIGTYPE_p_pj__PersistentObject swig_types[114]
#define SWIGTYPE_p_pj__PresNotifyParam swig_types[115]
#define SWIGTYPE_p_pj__PresenceStatus swig_types[116]
#define SWIGTYPE_p_pj__RegProgressParam swig_types[117]
#define SWIGTYPE_p_pj__RtcpFbCap swig_types[118]
#define SWIGTYPE_p_pj__RtcpFbConfig swig_types[119]
#define SWIGTYPE_p_pj__RtcpSdes swig_types[120]
#define SWIGTYPE_p_pj__RtcpStat swig_types[121]
#define SWIGTYPE_p_pj__RtcpStreamStat swig_types[122]
#define SWIGTYPE_p_pj__RxMsgEvent swig_types[123]
#define SWIGTYPE_p_pj__SdpSession swig_types[124]
#define SWIGTYPE_p_pj__SendInstantMessageParam swig_types[125]
#define SWIGTYPE_p_pj__SendTypingIndicationParam swig_types[126]
#define SWIGTYPE_p_pj__SipEvent swig_types[127]
#define SWIGTYPE_p_pj__SipEventBody swig_types[128]
#define SWIGTYPE_p_pj__SipHeader swig_types[129]
#define SWIGTYPE_p_pj__SipMediaType swig_types[130]
#define SWIGTYPE_p_pj__SipMultipartPart swig_types[131]
#define SWIGTYPE_p_pj__SipRxData swig_types[132]
#define SWIGTYPE_p_pj__SipTransaction swig_types[133]
#define SWIGTYPE_p_pj__SipTxData swig_types[134]
#define SWIGTYPE_p_pj__SipTxOption swig_types[135]
#define SWIGTYPE_p_pj__SrtpCrypto swig_types[136]
#define SWIGTYPE_p_pj__SrtpOpt swig_types[137]
#define SWIGTYPE_p_pj__SslCertInfo swig_types[138]
#define SWIGTYPE_p_pj__SslCertName swig_types[139]
#define SWIGTYPE_p_pj__StreamInfo swig_types[140]
#define SWIGTYPE_p_pj__StreamStat swig_types[141]
#define SWIGTYPE_p_pj__TimeVal swig_types[142]
#define SWIGTYPE_p_pj__TimerEvent swig_types[143]
#define SWIGTYPE_p_pj__TlsConfig swig_types[144]
#define SWIGTYPE_p_pj__TlsInfo swig_types[145]
#define SWIGTYPE_p_pj__ToneDesc swig_types[146]
#define SWIGTYPE_p_pj__ToneDigit swig_types[147]
#define SWIGTYPE_p_pj__ToneDigitMapDigit swig_types[148]
#define SWIGTYPE_p_pj__ToneGenerator swig_types[149]
#define SWIGTYPE_p_pj__TransportConfig swig_types[150]
#define SWIGTYPE_p_pj__TransportInfo swig_types[151]
#define SWIGTYPE_p_pj__TsxStateEvent swig_types[152]
#define SWIGTYPE_p_pj__TsxStateEventSrc swig_types[153]
#define SWIGTYPE_p_pj__TxErrorEvent swig_types[154]
#define SWIGTYPE_p_pj__TxMsgEvent swig_types[155]
#define SWIGTYPE_p_pj__UaConfig swig_types[156]
#define SWIGTYPE_p_pj__UserEvent swig_types[157]
#define SWIGTYPE_p_pj__Version swig_types[158]
#define SWIGTYPE_p_pj__VidCodecParam swig_types[159]
#define SWIGTYPE_p_pj__VidConfPortInfo swig_types[160]
#define SWIGTYPE_p_pj__VidDevManager swig_types[161]
#define SWIGTYPE_p_pj__VideoDevInfo swig_types[162]
#define SWIGTYPE_p_pj__VideoMedia swig_types[163]
#define SWIGTYPE_p_pj__VideoMediaTransmitParam swig_types[164]
#define SWIGTYPE_p_pj__VideoPreview swig_types[165]
#define SWIGTYPE_p_pj__VideoPreviewOpParam swig_types[166]
#define SWIGTYPE_p_pj__VideoSwitchParam swig_types[167]
#define SWIGTYPE_p_pj__VideoWindow swig_types[168]
#define SWIGTYPE_p_pj__VideoWindowHandle swig_types[169]
#define SWIGTYPE_p_pj__VideoWindowInfo swig_types[170]
#define SWIGTYPE_p_pj__WindowHandle swig_types[171]
#define SWIGTYPE_p_pj_ice_sess_trickle swig_types[172]
#define SWIGTYPE_p_pj_qos_flag swig_types[173]
#define SWIGTYPE_p_pj_qos_params swig_types[174]
#define SWIGTYPE_p_pj_qos_type swig_types[175]
#define SWIGTYPE_p_pj_qos_wmm_prio swig_types[176]
#define SWIGTYPE_p_pj_ssl_cert_name_type swig_types[177]
#define SWIGTYPE_p_pj_ssl_cert_verify_flag_t swig_types[178]
#define SWIGTYPE_p_pj_ssl_cipher swig_types[179]
#define SWIGTYPE_p_pj_ssl_sock_proto swig_types[180]
#define SWIGTYPE_p_pj_stun_nat_type swig_types[181]
#define SWIGTYPE_p_pj_turn_tp_type swig_types[182]
#define SWIGTYPE_p_pjmedia_aud_dev_cap swig_types[183]
#define SWIGTYPE_p_pjmedia_aud_dev_route swig_types[184]
#define SWIGTYPE_p_pjmedia_dir swig_types[185]
#define SWIGTYPE_p_pjmedia_echo_flag swig_types[186]
#define SWIGTYPE_p_pjmedia_event_type swig_types[187]
#define SWIGTYPE_p_pjmedia_format_id swig_types[188]
#define SWIGTYPE_p_pjmedia_jb_discard_algo swig_types[189]
#define SWIGTYPE_p_pjmedia_orient swig_types[190]
#define SWIGTYPE_p_pjmedia_rtcp_fb_type swig_types[191]
#define SWIGTYPE_p_pjmedia_srtp_crypto_option swig_types[192]
#define SWIGTYPE_p_pjmedia_srtp_keying_method swig_types[193]
#define SWIGTYPE_p_pjmedia_srtp_use swig_types[194]
#define SWIGTYPE_p_pjmedia_tone_desc swig_types[195]
#define SWIGTYPE_p_pjmedia_tone_digit swig_types[196]
#define SWIGTYPE_p_pjmedia_tone_digit_map swig_types[197]
#define SWIGTYPE_p_pjmedia_tp_proto swig_types[198]
#define SWIGTYPE_p_pjmedia_type swig_types[199]
#define SWIGTYPE_p_pjmedia_vid_dev_cap swig_types[200]
#define SWIGTYPE_p_pjmedia_vid_dev_fullscreen_flag swig_types[201]
#define SWIGTYPE_p_pjmedia_vid_dev_hwnd_type swig_types[202]
#define SWIGTYPE_p_pjmedia_vid_packing swig_types[203]
#define SWIGTYPE_p_pjmedia_vid_stream_rc_method swig_types[204]
#define SWIGTYPE_p_pjrpid_activity swig_types[205]
#define SWIGTYPE_p_pjsip_cred_data_type swig_types[206]
#define SWIGTYPE_p_pjsip_dialog_cap_status swig_types[207]
#define SWIGTYPE_p_pjsip_event_id_e swig_types[208]
#define SWIGTYPE_p_pjsip_evsub_state swig_types[209]
#define SWIGTYPE_p_pjsip_hdr_e swig_types[210]
#define SWIGTYPE_p_pjsip_inv_state swig_types[211]
#define SWIGTYPE_p_pjsip_redirect_op swig_types[212]
#define SWIGTYPE_p_pjsip_role_e swig_types[213]
#define SWIGTYPE_p_pjsip_ssl_method swig_types[214]
#define SWIGTYPE_p_pjsip_status_code swig_types[215]
#define SWIGTYPE_p_pjsip_transport_state swig_types[216]
#define SWIGTYPE_p_pjsip_transport_type_e swig_types[217]
#define SWIGTYPE_p_pjsip_tsx_state_e swig_types[218]
#define SWIGTYPE_p_pjsua_100rel_use swig_types[219]
#define SWIGTYPE_p_pjsua_buddy_status swig_types[220]
#define SWIGTYPE_p_pjsua_call_flag swig_types[221]
#define SWIGTYPE_p_pjsua_call_hold_type swig_types[222]
#define SWIGTYPE_p_pjsua_call_media_status swig_types[223]
#define SWIGTYPE_p_pjsua_call_vid_strm_op swig_types[224]
#define SWIGTYPE_p_pjsua_create_media_transport_flag swig_types[225]
#define SWIGTYPE_p_pjsua_destroy_flag swig_types[226]
#define SWIGTYPE_p_pjsua_dtmf_method swig_types[227]
#define SWIGTYPE_p_pjsua_ip_change_op swig_types[228]
#define SWIGTYPE_p_pjsua_ipv6_use swig_types[229]
#define SWIGTYPE_p_pjsua_med_tp_st swig_types[230]
#define SWIGTYPE_p_pjsua_nat64_opt swig_types[231]
#define SWIGTYPE_p_pjsua_sip_timer_use swig_types[232]
#define SWIGTYPE_p_pjsua_snd_dev_id swig_types[233]
#define SWIGTYPE_p_pjsua_snd_dev_mode swig_types[234]
#define SWIGTYPE_p_pjsua_state swig_types[235]
#define SWIGTYPE_p_pjsua_stun_use swig_types[236]
#define SWIGTYPE_p_pjsua_vid_req_keyframe_method swig_types[237]
#define SWIGTYPE_p_size_type swig_types[238]
#define SWIGTYPE_p_std__allocatorT_int_t swig_types[239]
#define SWIGTYPE_p_std__allocatorT_pj__AudioDevInfo_p_t swig_types[240]
#define SWIGTYPE_p_std__allocatorT_pj__AudioDevInfo_t swig_types[241]
#define SWIGTYPE_p_std__allocatorT_pj__AudioMedia_p_t swig_types[242]
#define SWIGTYPE_p_std__allocatorT_pj__AudioMedia_t swig_types[243]
#define SWIGTYPE_p_std__allocatorT_pj__AuthCredInfo_t swig_types[244]
#define SWIGTYPE_p_std__allocatorT_pj__Buddy_p_t swig_types[245]
#define SWIGTYPE_p_std__allocatorT_pj__Buddy_t swig_types[246]
#define SWIGTYPE_p_std__allocatorT_pj__CallMediaInfo_t swig_types[247]
#define SWIGTYPE_p_std__allocatorT_pj__CodecFmtp_t swig_types[248]
#define SWIGTYPE_p_std__allocatorT_pj__CodecInfo_p_t swig_types[249]
#define SWIGTYPE_p_std__allocatorT_pj__CodecInfo_t swig_types[250]
#define SWIGTYPE_p_std__allocatorT_pj__MediaFormatAudio_t swig_types[251]
#define SWIGTYPE_p_std__allocatorT_pj__MediaFormatVideo_t swig_types[252]
#define SWIGTYPE_p_std__allocatorT_pj__RtcpFbCap_t swig_types[253]
#define SWIGTYPE_p_std__allocatorT_pj__SipHeader_t swig_types[254]
#define SWIGTYPE_p_std__allocatorT_pj__SipMultipartPart_t swig_types[255]
#define SWIGTYPE_p_std__allocatorT_pj__SrtpCrypto_t swig_types[256]
#define SWIGTYPE_p_std__allocatorT_pj__SslCertName_t swig_types[257]
#define SWIGTYPE_p_std__allocatorT_pj__ToneDesc_t swig_types[258]
#define SWIGTYPE_p_std__allocatorT_pj__ToneDigitMapDigit_t swig_types[259]
#define SWIGTYPE_p_std__allocatorT_pj__ToneDigit_t swig_types[260]
#define SWIGTYPE_p_std__allocatorT_pj__VideoDevInfo_p_t swig_types[261]
#define SWIGTYPE_p_std__allocatorT_pj__VideoDevInfo_t swig_types[262]
#define SWIGTYPE_p_std__allocatorT_pj__VideoMedia_t swig_types[263]
#define SWIGTYPE_p_std__allocatorT_std__pairT_std__string_const_std__string_t_t swig_types[264]
#define SWIGTYPE_p_std__allocatorT_std__string_t swig_types[265]
#define SWIGTYPE_p_std__invalid_argument swig_types[266]
#define SWIGTYPE_p_std__lessT_std__string_t swig_types[267]
#define SWIGTYPE_p_std__mapT_std__string_std__string_std__lessT_std__string_t_std__allocatorT_std__pairT_std__string_const_std__string_t_t_t swig_types[268]
#define SWIGTYPE_p_std__string swig_types[269]
#define SWIGTYPE_p_std__vectorT_int_std__allocatorT_int_t_t swig_types[270]
#define SWIGTYPE_p_std__vectorT_pj__AudioDevInfo_p_std__allocatorT_pj__AudioDevInfo_p_t_t swig_types[271]
#define SWIGTYPE_p_std__vectorT_pj__AudioDevInfo_std__allocatorT_pj__AudioDevInfo_t_t swig_types[272]
#define SWIGTYPE_p_std__vectorT_pj__AudioMedia_p_std__allocatorT_pj__AudioMedia_p_t_t swig_types[273]
#define SWIGTYPE_p_std__vectorT_pj__AudioMedia_std__allocatorT_pj__AudioMedia_t_t swig_types[274]
#define SWIGTYPE_p_std__vectorT_pj__AuthCredInfo_std__allocatorT_pj__AuthCredInfo_t_t swig_types[275]
#define SWIGTYPE_p_std__vectorT_pj__Buddy_p_std__allocatorT_pj__Buddy_p_t_t swig_types[276]
#define SWIGTYPE_p_std__vectorT_pj__Buddy_std__allocatorT_pj__Buddy_t_t swig_types[277]
#define SWIGTYPE_p_std__vectorT_pj__CallMediaInfo_std__allocatorT_pj__CallMediaInfo_t_t swig_types[278]
#define SWIGTYPE_p_std__vectorT_pj__CodecFmtp_std__allocatorT_pj__CodecFmtp_t_t swig_types[279]
#define SWIGTYPE_p_std__vectorT_pj__CodecInfo_p_std__allocatorT_pj__CodecInfo_p_t_t swig_types[280]
#define SWIGTYPE_p_std__vectorT_pj__CodecInfo_std__allocatorT_pj__CodecInfo_t_t swig_types[281]
#define SWIGTYPE_p_std__vectorT_pj__MediaFormatAudio_std__allocatorT_pj__MediaFormatAudio_t_t swig_types[282]
#define SWIGTYPE_p_std__vectorT_pj__MediaFormatVideo_std__allocatorT_pj__MediaFormatVideo_t_t swig_types[283]
#define SWIGTYPE_p_std__vectorT_pj__RtcpFbCap_std__allocatorT_pj__RtcpFbCap_t_t swig_types[284]
#define SWIGTYPE_p_std__vectorT_pj__SipHeader_std__allocatorT_pj__SipHeader_t_t swig_types[285]
#define SWIGTYPE_p_std__vectorT_pj__SipMultipartPart_std__allocatorT_pj__SipMultipartPart_t_t swig_types[286]
#define SWIGTYPE_p_std__vectorT_pj__SrtpCrypto_std__allocatorT_pj__SrtpCrypto_t_t swig_types[287]
#define SWIGTYPE_p_std__vectorT_pj__SslCertName_std__allocatorT_pj__SslCertName_t_t swig_types[288]
#define SWIGTYPE_p_std__vectorT_pj__ToneDesc_std__allocatorT_pj__ToneDesc_t_t swig_types[289]
#define SWIGTYPE_p_std__vectorT_pj__ToneDigitMapDigit_std__allocatorT_pj__ToneDigitMapDigit_t_t swig_types[290]
#define SWIGTYPE_p_std__vectorT_pj__ToneDigit_std__allocatorT_pj__ToneDigit_t_t swig_types[291]
#define SWIGTYPE_p_std__vectorT_pj__VideoDevInfo_p_std__allocatorT_pj__VideoDevInfo_p_t_t swig_types[292]
#define SWIGTYPE_p_std__vectorT_pj__VideoDevInfo_std__allocatorT_pj__VideoDevInfo_t_t swig_types[293]
#define SWIGTYPE_p_std__vectorT_pj__VideoMedia_std__allocatorT_pj__VideoMedia_t_t swig_types[294]
#define SWIGTYPE_p_std__vectorT_std__string_std__allocatorT_std__string_t_t swig_types[295]
#define SWIGTYPE_p_swig__SwigPyIterator swig_types[296]
#define SWIGTYPE_p_unsigned_char swig_types[297]
#define SWIGTYPE_p_unsigned_int swig_types[298]
#define SWIGTYPE_p_unsigned_short swig_types[299]
#define SWIGTYPE_p_value_type swig_types[300]
#define SWIGTYPE_p_void swig_types[301]
static swig_type_info *swig_types[303];
static swig_module_info swig_module = {swig_types, 302, 0, 0, 0, 0};
#define SWIG_TypeQuery(name) SWIG_TypeQueryModule(&swig_module, &swig_module, name)
#define SWIG_MangledTypeQuery(name) SWIG_MangledTypeQueryModule(&swig_module, &swig_module, name)

/* -------- TYPES TABLE (END) -------- */

#ifdef SWIG_TypeQuery
# undef SWIG_TypeQuery
#endif
#define SWIG_TypeQuery SWIG_Python_TypeQuery

/*-----------------------------------------------
              @(target):= _pjsua2.so
  ------------------------------------------------*/
#if PY_VERSION_HEX >= 0x03000000
#  define SWIG_init    PyInit__pjsua2

#else
#  define SWIG_init    init_pjsua2

#endif
#define SWIG_name    "_pjsua2"

#define SWIGVERSION 0x040001 
#define SWIG_VERSION SWIGVERSION


#define SWIG_as_voidptr(a) const_cast< void * >(static_cast< const void * >(a)) 
#define SWIG_as_voidptrptr(a) ((void)SWIG_as_voidptr(*a),reinterpret_cast< void** >(a)) 


#include <stdexcept>


namespace swig {
  class SwigPtr_PyObject {
  protected:
    PyObject *_obj;

  public:
    SwigPtr_PyObject() :_obj(0)
    {
    }

    SwigPtr_PyObject(const SwigPtr_PyObject& item) : _obj(item._obj)
    {
      SWIG_PYTHON_THREAD_BEGIN_BLOCK;
      Py_XINCREF(_obj);      
      SWIG_PYTHON_THREAD_END_BLOCK;
    }
    
    SwigPtr_PyObject(PyObject *obj, bool initial_ref = true) :_obj(obj)
    {
      if (initial_ref) {
        SWIG_PYTHON_THREAD_BEGIN_BLOCK;
        Py_XINCREF(_obj);
        SWIG_PYTHON_THREAD_END_BLOCK;
      }
    }
    
    SwigPtr_PyObject & operator=(const SwigPtr_PyObject& item) 
    {
      SWIG_PYTHON_THREAD_BEGIN_BLOCK;
      Py_XINCREF(item._obj);
      Py_XDECREF(_obj);
      _obj = item._obj;
      SWIG_PYTHON_THREAD_END_BLOCK;
      return *this;      
    }
    
    ~SwigPtr_PyObject() 
    {
      SWIG_PYTHON_THREAD_BEGIN_BLOCK;
      Py_XDECREF(_obj);
      SWIG_PYTHON_THREAD_END_BLOCK;
    }
    
    operator PyObject *() const
    {
      return _obj;
    }

    PyObject *operator->() const
    {
      return _obj;
    }
  };
}


namespace swig {
  struct SwigVar_PyObject : SwigPtr_PyObject {
    SwigVar_PyObject(PyObject* obj = 0) : SwigPtr_PyObject(obj, false) { }
    
    SwigVar_PyObject & operator = (PyObject* obj)
    {
      Py_XDECREF(_obj);
      _obj = obj;
      return *this;      
    }
  };
}


#include "pjsua2.hpp"
using namespace std;
using namespace pj;


SWIGINTERNINLINE PyObject*
  SWIG_From_int  (int value)
{
  return PyInt_FromLong((long) value);
}


#include <limits.h>
#if !defined(SWIG_NO_LLONG_MAX)
# if !defined(LLONG_MAX) && defined(__GNUC__) && defined (__LONG_LONG_MAX__)
#   define LLONG_MAX __LONG_LONG_MAX__
#   define LLONG_MIN (-LLONG_MAX - 1LL)
#   define ULLONG_MAX (LLONG_MAX * 2ULL + 1ULL)
# endif
#endif


SWIGINTERN int
SWIG_AsVal_double (PyObject *obj, double *val)
{
  int res = SWIG_TypeError;
  if (PyFloat_Check(obj)) {
    if (val) *val = PyFloat_AsDouble(obj);
    return SWIG_OK;
#if PY_VERSION_HEX < 0x03000000
  } else if (PyInt_Check(obj)) {
    if (val) *val = (double) PyInt_AsLong(obj);
    return SWIG_OK;
#endif
  } else if (PyLong_Check(obj)) {
    double v = PyLong_AsDouble(obj);
    if (!PyErr_Occurred()) {
      if (val) *val = v;
      return SWIG_OK;
    } else {
      PyErr_Clear();
    }
  }
#ifdef SWIG_PYTHON_CAST_MODE
  {
    int dispatch = 0;
    double d = PyFloat_AsDouble(obj);
    if (!PyErr_Occurred()) {
      if (val) *val = d;
      return SWIG_AddCast(SWIG_OK);
    } else {
      PyErr_Clear();
    }
    if (!dispatch) {
      long v = PyLong_AsLong(obj);
      if (!PyErr_Occurred()) {
	if (val) *val = v;
	return SWIG_AddCast(SWIG_AddCast(SWIG_OK));
      } else {
	PyErr_Clear();
      }
    }
  }
#endif
  return res;
}


#include <float.h>


#include <math.h>


SWIGINTERNINLINE int
SWIG_CanCastAsInteger(double *d, double min, double max) {
  double x = *d;
  if ((min <= x && x <= max)) {
   double fx = floor(x);
   double cx = ceil(x);
   double rd =  ((x - fx) < 0.5) ? fx : cx; /* simple rint */
   if ((errno == EDOM) || (errno == ERANGE)) {
     errno = 0;
   } else {
     double summ, reps, diff;
     if (rd < x) {
       diff = x - rd;
     } else if (rd > x) {
       diff = rd - x;
     } else {
       return 1;
     }
     summ = rd + x;
     reps = diff/summ;
     if (reps < 8*DBL_EPSILON) {
       *d = rd;
       return 1;
     }
   }
  }
  return 0;
}


SWIGINTERN int
SWIG_AsVal_unsigned_SS_long (PyObject *obj, unsigned long *val) 
{
#if PY_VERSION_HEX < 0x03000000
  if (PyInt_Check(obj)) {
    long v = PyInt_AsLong(obj);
    if (v >= 0) {
      if (val) *val = v;
      return SWIG_OK;
    } else {
      return SWIG_OverflowError;
    }
  } else
#endif
  if (PyLong_Check(obj)) {
    unsigned long v = PyLong_AsUnsignedLong(obj);
    if (!PyErr_Occurred()) {
      if (val) *val = v;
      return SWIG_OK;
    } else {
      PyErr_Clear();
      return SWIG_OverflowError;
    }
  }
#ifdef SWIG_PYTHON_CAST_MODE
  {
    int dispatch = 0;
    unsigned long v = PyLong_AsUnsignedLong(obj);
    if (!PyErr_Occurred()) {
      if (val) *val = v;
      return SWIG_AddCast(SWIG_OK);
    } else {
      PyErr_Clear();
    }
    if (!dispatch) {
      double d;
      int res = SWIG_AddCast(SWIG_AsVal_double (obj,&d));
      if (SWIG_IsOK(res) && SWIG_CanCastAsInteger(&d, 0, ULONG_MAX)) {
	if (val) *val = (unsigned long)(d);
	return res;
      }
    }
  }
#endif
  return SWIG_TypeError;
}


SWIGINTERN int
SWIG_AsVal_unsigned_SS_char (PyObject * obj, unsigned char *val)
{
  unsigned long v;
  int res = SWIG_AsVal_unsigned_SS_long (obj, &v);
  if (SWIG_IsOK(res)) {
    if ((v > UCHAR_MAX)) {
      return SWIG_OverflowError;
    } else {
      if (val) *val = static_cast< unsigned char >(v);
    }
  }  
  return res;
}


  #define SWIG_From_long   PyInt_FromLong 


SWIGINTERNINLINE PyObject* 
SWIG_From_unsigned_SS_long  (unsigned long value)
{
  return (value > LONG_MAX) ?
    PyLong_FromUnsignedLong(value) : PyInt_FromLong(static_cast< long >(value));
}


SWIGINTERNINLINE PyObject *
SWIG_From_unsigned_SS_char  (unsigned char value)
{    
  return SWIG_From_unsigned_SS_long  (value);
}


SWIGINTERN int
SWIG_AsVal_long (PyObject *obj, long* val)
{
#if PY_VERSION_HEX < 0x03000000
  if (PyInt_Check(obj)) {
    if (val) *val = PyInt_AsLong(obj);
    return SWIG_OK;
  } else
#endif
  if (PyLong_Check(obj)) {
    long v = PyLong_AsLong(obj);
    if (!PyErr_Occurred()) {
      if (val) *val = v;
      return SWIG_OK;
    } else {
      PyErr_Clear();
      return SWIG_OverflowError;
    }
  }
#ifdef SWIG_PYTHON_CAST_MODE
  {
    int dispatch = 0;
    long v = PyInt_AsLong(obj);
    if (!PyErr_Occurred()) {
      if (val) *val = v;
      return SWIG_AddCast(SWIG_OK);
    } else {
      PyErr_Clear();
    }
    if (!dispatch) {
      double d;
      int res = SWIG_AddCast(SWIG_AsVal_double (obj,&d));
      if (SWIG_IsOK(res) && SWIG_CanCastAsInteger(&d, LONG_MIN, LONG_MAX)) {
	if (val) *val = (long)(d);
	return res;
      }
    }
  }
#endif
  return SWIG_TypeError;
}


SWIGINTERN int
SWIG_AsVal_int (PyObject * obj, int *val)
{
  long v;
  int res = SWIG_AsVal_long (obj, &v);
  if (SWIG_IsOK(res)) {
    if ((v < INT_MIN || v > INT_MAX)) {
      return SWIG_OverflowError;
    } else {
      if (val) *val = static_cast< int >(v);
    }
  }  
  return res;
}


SWIGINTERN swig_type_info*
SWIG_pchar_descriptor(void)
{
  static int init = 0;
  static swig_type_info* info = 0;
  if (!init) {
    info = SWIG_TypeQuery("_p_char");
    init = 1;
  }
  return info;
}


SWIGINTERN int
SWIG_AsCharPtrAndSize(PyObject *obj, char** cptr, size_t* psize, int *alloc)
{
#if PY_VERSION_HEX>=0x03000000
#if defined(SWIG_PYTHON_STRICT_BYTE_CHAR)
  if (PyBytes_Check(obj))
#else
  if (PyUnicode_Check(obj))
#endif
#else  
  if (PyString_Check(obj))
#endif
  {
    char *cstr; Py_ssize_t len;
    int ret = SWIG_OK;
#if PY_VERSION_HEX>=0x03000000
#if !defined(SWIG_PYTHON_STRICT_BYTE_CHAR)
    if (!alloc && cptr) {
        /* We can't allow converting without allocation, since the internal
           representation of string in Python 3 is UCS-2/UCS-4 but we require
           a UTF-8 representation.
           TODO(bhy) More detailed explanation */
        return SWIG_RuntimeError;
    }
    obj = PyUnicode_AsUTF8String(obj);
    if (!obj)
      return SWIG_TypeError;
    if (alloc)
      *alloc = SWIG_NEWOBJ;
#endif
    PyBytes_AsStringAndSize(obj, &cstr, &len);
#else
    PyString_AsStringAndSize(obj, &cstr, &len);
#endif
    if (cptr) {
      if (alloc) {
	if (*alloc == SWIG_NEWOBJ) {
	  *cptr = reinterpret_cast< char* >(memcpy(new char[len + 1], cstr, sizeof(char)*(len + 1)));
	  *alloc = SWIG_NEWOBJ;
	} else {
	  *cptr = cstr;
	  *alloc = SWIG_OLDOBJ;
	}
      } else {
#if PY_VERSION_HEX>=0x03000000
#if defined(SWIG_PYTHON_STRICT_BYTE_CHAR)
	*cptr = PyBytes_AsString(obj);
#else
	assert(0); /* Should never reach here with Unicode strings in Python 3 */
#endif
#else
	*cptr = SWIG_Python_str_AsChar(obj);
        if (!*cptr)
          ret = SWIG_TypeError;
#endif
      }
    }
    if (psize) *psize = len + 1;
#if PY_VERSION_HEX>=0x03000000 && !defined(SWIG_PYTHON_STRICT_BYTE_CHAR)
    Py_XDECREF(obj);
#endif
    return ret;
  } else {
#if defined(SWIG_PYTHON_2_UNICODE)
#if defined(SWIG_PYTHON_STRICT_BYTE_CHAR)
#error "Cannot use both SWIG_PYTHON_2_UNICODE and SWIG_PYTHON_STRICT_BYTE_CHAR at once"
#endif
#if PY_VERSION_HEX<0x03000000
    if (PyUnicode_Check(obj)) {
      char *cstr; Py_ssize_t len;
      if (!alloc && cptr) {
        return SWIG_RuntimeError;
      }
      obj = PyUnicode_AsUTF8String(obj);
      if (!obj)
        return SWIG_TypeError;
      if (PyString_AsStringAndSize(obj, &cstr, &len) != -1) {
        if (cptr) {
          if (alloc) *alloc = SWIG_NEWOBJ;
          *cptr = reinterpret_cast< char* >(memcpy(new char[len + 1], cstr, sizeof(char)*(len + 1)));
        }
        if (psize) *psize = len + 1;

        Py_XDECREF(obj);
        return SWIG_OK;
      } else {
        Py_XDECREF(obj);
      }
    }
#endif
#endif

    swig_type_info* pchar_descriptor = SWIG_pchar_descriptor();
    if (pchar_descriptor) {
      void* vptr = 0;
      if (SWIG_ConvertPtr(obj, &vptr, pchar_descriptor, 0) == SWIG_OK) {
	if (cptr) *cptr = (char *) vptr;
	if (psize) *psize = vptr ? (strlen((char *)vptr) + 1) : 0;
	if (alloc) *alloc = SWIG_OLDOBJ;
	return SWIG_OK;
      }
    }
  }
  return SWIG_TypeError;
}


SWIGINTERN int
SWIG_AsCharArray(PyObject * obj, char *val, size_t size)
{ 
  char* cptr = 0; size_t csize = 0; int alloc = SWIG_OLDOBJ;
  int res = SWIG_AsCharPtrAndSize(obj, &cptr, &csize, &alloc);
  if (SWIG_IsOK(res)) {
    /* special case of single char conversion when we don't need space for NUL */
    if (size == 1 && csize == 2 && cptr && !cptr[1]) --csize;
    if (csize <= size) {
      if (val) {
	if (csize) memcpy(val, cptr, csize*sizeof(char));
	if (csize < size) memset(val + csize, 0, (size - csize)*sizeof(char));
      }
      if (alloc == SWIG_NEWOBJ) {
	delete[] cptr;
	res = SWIG_DelNewMask(res);
      }      
      return res;
    }
    if (alloc == SWIG_NEWOBJ) delete[] cptr;
  }
  return SWIG_TypeError;
}


SWIGINTERN int
SWIG_AsVal_char (PyObject * obj, char *val)
{    
  int res = SWIG_AsCharArray(obj, val, 1);
  if (!SWIG_IsOK(res)) {
    long v;
    res = SWIG_AddCast(SWIG_AsVal_long (obj, &v));
    if (SWIG_IsOK(res)) {
      if ((CHAR_MIN <= v) && (v <= CHAR_MAX)) {
	if (val) *val = static_cast< char >(v);
      } else {
	res = SWIG_OverflowError;
      }
    }
  }
  return res;
}


SWIGINTERNINLINE PyObject *
SWIG_FromCharPtrAndSize(const char* carray, size_t size)
{
  if (carray) {
    if (size > INT_MAX) {
      swig_type_info* pchar_descriptor = SWIG_pchar_descriptor();
      return pchar_descriptor ? 
	SWIG_InternalNewPointerObj(const_cast< char * >(carray), pchar_descriptor, 0) : SWIG_Py_Void();
    } else {
#if PY_VERSION_HEX >= 0x03000000
#if defined(SWIG_PYTHON_STRICT_BYTE_CHAR)
      return PyBytes_FromStringAndSize(carray, static_cast< Py_ssize_t >(size));
#else
      return PyUnicode_DecodeUTF8(carray, static_cast< Py_ssize_t >(size), "surrogateescape");
#endif
#else
      return PyString_FromStringAndSize(carray, static_cast< Py_ssize_t >(size));
#endif
    }
  } else {
    return SWIG_Py_Void();
  }
}


SWIGINTERNINLINE PyObject *
SWIG_From_char  (char c) 
{ 
  return SWIG_FromCharPtrAndSize(&c,1);
}


SWIGINTERN int
SWIG_AsVal_short (PyObject * obj, short *val)
{
  long v;
  int res = SWIG_AsVal_long (obj, &v);
  if (SWIG_IsOK(res)) {
    if ((v < SHRT_MIN || v > SHRT_MAX)) {
      return SWIG_OverflowError;
    } else {
      if (val) *val = static_cast< short >(v);
    }
  }  
  return res;
}


SWIGINTERNINLINE PyObject *
SWIG_From_short  (short value)
{    
  return SWIG_From_long  (value);
}


SWIGINTERN int
SWIG_AsVal_unsigned_SS_int (PyObject * obj, unsigned int *val)
{
  unsigned long v;
  int res = SWIG_AsVal_unsigned_SS_long (obj, &v);
  if (SWIG_IsOK(res)) {
    if ((v > UINT_MAX)) {
      return SWIG_OverflowError;
    } else {
      if (val) *val = static_cast< unsigned int >(v);
    }
  }  
  return res;
}


SWIGINTERNINLINE PyObject*
  SWIG_From_unsigned_SS_int  (unsigned int value)
{
  return PyInt_FromSize_t((size_t) value);
}


#include <string>


#include <iostream>

#if PY_VERSION_HEX >= 0x03020000
# define SWIGPY_SLICE_ARG(obj) ((PyObject*) (obj))
#else
# define SWIGPY_SLICE_ARG(obj) ((PySliceObject*) (obj))
#endif


#include <typeinfo>
#include <stdexcept>


#if defined(__GNUC__)
#  if __GNUC__ == 2 && __GNUC_MINOR <= 96
#     define SWIG_STD_NOMODERN_STL
#  endif
#endif


#include <stddef.h>


namespace swig {
  struct stop_iteration {
  };

  struct SwigPyIterator {
  private:
    SwigPtr_PyObject _seq;

  protected:
    SwigPyIterator(PyObject *seq) : _seq(seq)
    {
    }
      
  public:
    virtual ~SwigPyIterator() {}

    // Access iterator method, required by Python
    virtual PyObject *value() const = 0;

    // Forward iterator method, required by Python
    virtual SwigPyIterator *incr(size_t n = 1) = 0;
    
    // Backward iterator method, very common in C++, but not required in Python
    virtual SwigPyIterator *decr(size_t /*n*/ = 1)
    {
      throw stop_iteration();
    }

    // Random access iterator methods, but not required in Python
    virtual ptrdiff_t distance(const SwigPyIterator &/*x*/) const
    {
      throw std::invalid_argument("operation not supported");
    }

    virtual bool equal (const SwigPyIterator &/*x*/) const
    {
      throw std::invalid_argument("operation not supported");
    }
    
    // C++ common/needed methods
    virtual SwigPyIterator *copy() const = 0;

    PyObject *next()     
    {
      SWIG_PYTHON_THREAD_BEGIN_BLOCK; // disable threads       
      PyObject *obj = value();
      incr();       
      SWIG_PYTHON_THREAD_END_BLOCK; // re-enable threads
      return obj;     
    }

    /* Make an alias for Python 3.x */
    PyObject *__next__()
    {
      return next();
    }

    PyObject *previous()
    {
      SWIG_PYTHON_THREAD_BEGIN_BLOCK; // disable threads       
      decr();
      PyObject *obj = value();
      SWIG_PYTHON_THREAD_END_BLOCK; // re-enable threads       
      return obj;
    }

    SwigPyIterator *advance(ptrdiff_t n)
    {
      return  (n > 0) ?  incr(n) : decr(-n);
    }
      
    bool operator == (const SwigPyIterator& x)  const
    {
      return equal(x);
    }
      
    bool operator != (const SwigPyIterator& x) const
    {
      return ! operator==(x);
    }
      
    SwigPyIterator& operator += (ptrdiff_t n)
    {
      return *advance(n);
    }

    SwigPyIterator& operator -= (ptrdiff_t n)
    {
      return *advance(-n);
    }
      
    SwigPyIterator* operator + (ptrdiff_t n) const
    {
      return copy()->advance(n);
    }

    SwigPyIterator* operator - (ptrdiff_t n) const
    {
      return copy()->advance(-n);
    }
      
    ptrdiff_t operator - (const SwigPyIterator& x) const
    {
      return x.distance(*this);
    }
      
    static swig_type_info* descriptor() {
      static int init = 0;
      static swig_type_info* desc = 0;
      if (!init) {
	desc = SWIG_TypeQuery("swig::SwigPyIterator *");
	init = 1;
      }	
      return desc;
    }    
  };

#if defined(SWIGPYTHON_BUILTIN)
  inline PyObject* make_output_iterator_builtin (PyObject *pyself)
  {
    Py_INCREF(pyself);
    return pyself;
  }
#endif
}


#if defined(LLONG_MAX) && !defined(SWIG_LONG_LONG_AVAILABLE)
#  define SWIG_LONG_LONG_AVAILABLE
#endif


#ifdef SWIG_LONG_LONG_AVAILABLE
SWIGINTERN int
SWIG_AsVal_unsigned_SS_long_SS_long (PyObject *obj, unsigned long long *val)
{
  int res = SWIG_TypeError;
  if (PyLong_Check(obj)) {
    unsigned long long v = PyLong_AsUnsignedLongLong(obj);
    if (!PyErr_Occurred()) {
      if (val) *val = v;
      return SWIG_OK;
    } else {
      PyErr_Clear();
      res = SWIG_OverflowError;
    }
  } else {
    unsigned long v;
    res = SWIG_AsVal_unsigned_SS_long (obj,&v);
    if (SWIG_IsOK(res)) {
      if (val) *val = v;
      return res;
    }
  }
#ifdef SWIG_PYTHON_CAST_MODE
  {
    const double mant_max = 1LL << DBL_MANT_DIG;
    double d;
    res = SWIG_AsVal_double (obj,&d);
    if (SWIG_IsOK(res) && !SWIG_CanCastAsInteger(&d, 0, mant_max))
      return SWIG_OverflowError;
    if (SWIG_IsOK(res) && SWIG_CanCastAsInteger(&d, 0, mant_max)) {
      if (val) *val = (unsigned long long)(d);
      return SWIG_AddCast(res);
    }
    res = SWIG_TypeError;
  }
#endif
  return res;
}
#endif


SWIGINTERNINLINE int
SWIG_AsVal_size_t (PyObject * obj, size_t *val)
{
  int res = SWIG_TypeError;
#ifdef SWIG_LONG_LONG_AVAILABLE
  if (sizeof(size_t) <= sizeof(unsigned long)) {
#endif
    unsigned long v;
    res = SWIG_AsVal_unsigned_SS_long (obj, val ? &v : 0);
    if (SWIG_IsOK(res) && val) *val = static_cast< size_t >(v);
#ifdef SWIG_LONG_LONG_AVAILABLE
  } else if (sizeof(size_t) <= sizeof(unsigned long long)) {
    unsigned long long v;
    res = SWIG_AsVal_unsigned_SS_long_SS_long (obj, val ? &v : 0);
    if (SWIG_IsOK(res) && val) *val = static_cast< size_t >(v);
  }
#endif
  return res;
}


#ifdef SWIG_LONG_LONG_AVAILABLE
SWIGINTERNINLINE PyObject* 
SWIG_From_long_SS_long  (long long value)
{
  return ((value < LONG_MIN) || (value > LONG_MAX)) ?
    PyLong_FromLongLong(value) : PyInt_FromLong(static_cast< long >(value));
}
#endif


SWIGINTERNINLINE PyObject *
SWIG_From_ptrdiff_t  (ptrdiff_t value)
{    
#ifdef SWIG_LONG_LONG_AVAILABLE
  if (sizeof(ptrdiff_t) <= sizeof(long)) {
#endif
    return SWIG_From_long  (static_cast< long >(value));
#ifdef SWIG_LONG_LONG_AVAILABLE
  } else {
    /* assume sizeof(ptrdiff_t) <= sizeof(long long) */
    return SWIG_From_long_SS_long  (static_cast< long long >(value));
  }
#endif
}


SWIGINTERNINLINE PyObject*
  SWIG_From_bool  (bool value)
{
  return PyBool_FromLong(value ? 1 : 0);
}


#ifdef SWIG_LONG_LONG_AVAILABLE
SWIGINTERN int
SWIG_AsVal_long_SS_long (PyObject *obj, long long *val)
{
  int res = SWIG_TypeError;
  if (PyLong_Check(obj)) {
    long long v = PyLong_AsLongLong(obj);
    if (!PyErr_Occurred()) {
      if (val) *val = v;
      return SWIG_OK;
    } else {
      PyErr_Clear();
      res = SWIG_OverflowError;
    }
  } else {
    long v;
    res = SWIG_AsVal_long (obj,&v);
    if (SWIG_IsOK(res)) {
      if (val) *val = v;
      return res;
    }
  }
#ifdef SWIG_PYTHON_CAST_MODE
  {
    const double mant_max = 1LL << DBL_MANT_DIG;
    const double mant_min = -mant_max;
    double d;
    res = SWIG_AsVal_double (obj,&d);
    if (SWIG_IsOK(res) && !SWIG_CanCastAsInteger(&d, mant_min, mant_max))
      return SWIG_OverflowError;
    if (SWIG_IsOK(res) && SWIG_CanCastAsInteger(&d, mant_min, mant_max)) {
      if (val) *val = (long long)(d);
      return SWIG_AddCast(res);
    }
    res = SWIG_TypeError;
  }
#endif
  return res;
}
#endif


SWIGINTERNINLINE int
SWIG_AsVal_ptrdiff_t (PyObject * obj, ptrdiff_t *val)
{
  int res = SWIG_TypeError;
#ifdef SWIG_LONG_LONG_AVAILABLE
  if (sizeof(ptrdiff_t) <= sizeof(long)) {
#endif
    long v;
    res = SWIG_AsVal_long (obj, val ? &v : 0);
    if (SWIG_IsOK(res) && val) *val = static_cast< ptrdiff_t >(v);
#ifdef SWIG_LONG_LONG_AVAILABLE
  } else if (sizeof(ptrdiff_t) <= sizeof(long long)) {
    long long v;
    res = SWIG_AsVal_long_SS_long (obj, val ? &v : 0);
    if (SWIG_IsOK(res) && val) *val = static_cast< ptrdiff_t >(v);
  }
#endif
  return res;
}


#include <algorithm>


#include <vector>


#include <utility>


#include <map>


#include <algorithm>


namespace swig {
  template <class Type>
  struct noconst_traits {
    typedef Type noconst_type;
  };

  template <class Type>
  struct noconst_traits<const Type> {
    typedef Type noconst_type;
  };

  /*
    type categories
  */
  struct pointer_category { };
  struct value_category { };

  /*
    General traits that provides type_name and type_info
  */
  template <class Type> struct traits { };

  template <class Type>
  inline const char* type_name() {
    return traits<typename noconst_traits<Type >::noconst_type >::type_name();
  }

  template <class Type> struct traits_info {
    static swig_type_info *type_query(std::string name) {
      name += " *";
      return SWIG_TypeQuery(name.c_str());
    }
    static swig_type_info *type_info() {
      static swig_type_info *info = type_query(type_name<Type>());
      return info;
    }
  };

  /*
    Partial specialization for pointers (traits_info)
  */
  template <class Type> struct traits_info<Type *> {
    static swig_type_info *type_query(std::string name) {
      name += " *";
      return SWIG_TypeQuery(name.c_str());
    }
    static swig_type_info *type_info() {
      static swig_type_info *info = type_query(type_name<Type>());
      return info;
    }
  };

  template <class Type>
  inline swig_type_info *type_info() {
    return traits_info<Type>::type_info();
  }

  /*
    Partial specialization for pointers (traits)
  */
  template <class Type> struct traits <Type *> {
    typedef pointer_category category;
    static std::string make_ptr_name(const char* name) {
      std::string ptrname = name;
      ptrname += " *";
      return ptrname;
    }
    static const char* type_name() {
      static std::string name = make_ptr_name(swig::type_name<Type>());
      return name.c_str();
    }
  };

  template <class Type, class Category>
  struct traits_as { };

  template <class Type, class Category>
  struct traits_check { };

}


namespace swig {  
  /*
    Traits that provides the from method
  */
  template <class Type> struct traits_from_ptr {
    static PyObject *from(Type *val, int owner = 0) {
      return SWIG_InternalNewPointerObj(val, type_info<Type>(), owner);
    }
  };

  template <class Type> struct traits_from {
    static PyObject *from(const Type& val) {
      return traits_from_ptr<Type>::from(new Type(val), 1);
    }
  };

  template <class Type> struct traits_from<Type *> {
    static PyObject *from(Type* val) {
      return traits_from_ptr<Type>::from(val, 0);
    }
  };

  template <class Type> struct traits_from<const Type *> {
    static PyObject *from(const Type* val) {
      return traits_from_ptr<Type>::from(const_cast<Type*>(val), 0);
    }
  };


  template <class Type>
  inline PyObject *from(const Type& val) {
    return traits_from<Type>::from(val);
  }

  template <class Type>
  inline PyObject *from_ptr(Type* val, int owner) {
    return traits_from_ptr<Type>::from(val, owner);
  }

  /*
    Traits that provides the asval/as/check method
  */
  template <class Type>
  struct traits_asptr {   
    static int asptr(PyObject *obj, Type **val) {
      Type *p = 0;
      swig_type_info *descriptor = type_info<Type>();
      int res = descriptor ? SWIG_ConvertPtr(obj, (void **)&p, descriptor, 0) : SWIG_ERROR;
      if (SWIG_IsOK(res)) {
	if (val) *val = p;
      }
      return res;
    }
  }; 

  template <class Type>
  inline int asptr(PyObject *obj, Type **vptr) {
    return traits_asptr<Type>::asptr(obj, vptr);
  }

  template <class Type> 
  struct traits_asval {
    static int asval(PyObject *obj, Type *val) {
      if (val) {
	Type *p = 0;
	int res = traits_asptr<Type>::asptr(obj, &p);
	if (!SWIG_IsOK(res)) return res;	
	if (p) {
	  typedef typename noconst_traits<Type>::noconst_type noconst_type;
	  *(const_cast<noconst_type*>(val)) = *p;
	  if (SWIG_IsNewObj(res)){
	    delete p;
	    res = SWIG_DelNewMask(res);
	  }
	  return res;
	} else {
	  return SWIG_ERROR;
	}
      } else {
	return traits_asptr<Type>::asptr(obj, (Type **)(0));
      }
    }
  };

  template <class Type> struct traits_asval<Type*> {
    static int asval(PyObject *obj, Type **val) {
      if (val) {
        typedef typename noconst_traits<Type>::noconst_type noconst_type;
        noconst_type *p = 0;
        int res = traits_asptr<noconst_type>::asptr(obj,  &p);
        if (SWIG_IsOK(res)) {
          *(const_cast<noconst_type**>(val)) = p;
	}
	return res;
      } else {
	return traits_asptr<Type>::asptr(obj, (Type **)(0));
      }
    }
  };
  
  template <class Type>
  inline int asval(PyObject *obj, Type *val) {
    return traits_asval<Type>::asval(obj, val);
  }

  template <class Type> 
  struct traits_as<Type, value_category> {
    static Type as(PyObject *obj) {
      Type v;
      int res = asval(obj, &v);
      if (!obj || !SWIG_IsOK(res)) {
	if (!PyErr_Occurred()) {
	  ::SWIG_Error(SWIG_TypeError,  swig::type_name<Type>());
	}
	throw std::invalid_argument("bad type");
      }
      return v;
    }
  };

  template <class Type> 
  struct traits_as<Type, pointer_category> {
    static Type as(PyObject *obj) {
      Type *v = 0;      
      int res = (obj ? traits_asptr<Type>::asptr(obj, &v) : SWIG_ERROR);
      if (SWIG_IsOK(res) && v) {
	if (SWIG_IsNewObj(res)) {
	  Type r(*v);
	  delete v;
	  return r;
	} else {
	  return *v;
	}
      } else {
	if (!PyErr_Occurred()) {
	  SWIG_Error(SWIG_TypeError,  swig::type_name<Type>());
	}
	throw std::invalid_argument("bad type");
      }
    }
  };

  template <class Type> 
  struct traits_as<Type*, pointer_category> {
    static Type* as(PyObject *obj) {
      Type *v = 0;      
      int res = (obj ? traits_asptr<Type>::asptr(obj, &v) : SWIG_ERROR);
      if (SWIG_IsOK(res)) {
	return v;
      } else {
	if (!PyErr_Occurred()) {
	  SWIG_Error(SWIG_TypeError,  swig::type_name<Type>());
	}
	throw std::invalid_argument("bad type");
      }
    }
  };
    
  template <class Type>
  inline Type as(PyObject *obj) {
    return traits_as<Type, typename traits<Type>::category>::as(obj);
  }

  template <class Type> 
  struct traits_check<Type, value_category> {
    static bool check(PyObject *obj) {
      int res = obj ? asval(obj, (Type *)(0)) : SWIG_ERROR;
      return SWIG_IsOK(res) ? true : false;
    }
  };

  template <class Type> 
  struct traits_check<Type, pointer_category> {
    static bool check(PyObject *obj) {
      int res = obj ? asptr(obj, (Type **)(0)) : SWIG_ERROR;
      return SWIG_IsOK(res) ? true : false;
    }
  };

  template <class Type>
  inline bool check(PyObject *obj) {
    return traits_check<Type, typename traits<Type>::category>::check(obj);
  }
}


#include <functional>

namespace std {
  template <>
  struct less <PyObject *>
  {
    bool
    operator()(PyObject * v, PyObject *w) const
    { 
      bool res;
      SWIG_PYTHON_THREAD_BEGIN_BLOCK;
      res = PyObject_RichCompareBool(v, w, Py_LT) ? true : false;
      /* This may fall into a case of inconsistent
               eg. ObjA > ObjX > ObjB
               but ObjA < ObjB
      */
      if( PyErr_Occurred() && PyErr_ExceptionMatches(PyExc_TypeError) )
      {
        /* Objects can't be compared, this mostly occurred in Python 3.0 */
        /* Compare their ptr directly for a workaround */
        res = (v < w);
        PyErr_Clear();
      }
      SWIG_PYTHON_THREAD_END_BLOCK;
      return res;
    }
  };

  template <>
  struct less <swig::SwigPtr_PyObject>
  {
    bool
    operator()(const swig::SwigPtr_PyObject& v, const swig::SwigPtr_PyObject& w) const
    {
      return std::less<PyObject *>()(v, w);
    }
  };

  template <>
  struct less <swig::SwigVar_PyObject>
  {
    bool
    operator()(const swig::SwigVar_PyObject& v, const swig::SwigVar_PyObject& w) const
    {
      return std::less<PyObject *>()(v, w);
    }
  };

}

namespace swig {
  template <> struct traits<PyObject *> {
    typedef value_category category;
    static const char* type_name() { return "PyObject *"; }
  };  

  template <>  struct traits_asval<PyObject * > {   
    typedef PyObject * value_type;
    static int asval(PyObject *obj, value_type *val) {
      if (val) *val = obj;
      return SWIG_OK;
    }
  };

  template <> 
  struct traits_check<PyObject *, value_category> {
    static bool check(PyObject *) {
      return true;
    }
  };

  template <>  struct traits_from<PyObject *> {
    typedef PyObject * value_type;
    static PyObject *from(const value_type& val) {
      Py_XINCREF(val);
      return val;
    }
  };
  
}

namespace swig {
  template <class Difference>
  inline size_t
  check_index(Difference i, size_t size, bool insert = false) {
    if ( i < 0 ) {
      if ((size_t) (-i) <= size)
	return (size_t) (i + size);
    } else if ( (size_t) i < size ) {
      return (size_t) i;
    } else if (insert && ((size_t) i == size)) {
      return size;
    }
    throw std::out_of_range("index out of range");
  }

  template <class Difference>
  void
  slice_adjust(Difference i, Difference j, Py_ssize_t step, size_t size, Difference &ii, Difference &jj, bool insert = false) {
    if (step == 0) {
      throw std::invalid_argument("slice step cannot be zero");
    } else if (step > 0) {
      // Required range: 0 <= i < size, 0 <= j < size, i <= j
      if (i < 0) {
        ii = 0;
      } else if (i < (Difference)size) {
        ii = i;
      } else if (insert && (i >= (Difference)size)) {
        ii = (Difference)size;
      }
      if (j < 0) {
        jj = 0;
      } else {
        jj = (j < (Difference)size) ? j : (Difference)size;
      }
      if (jj < ii)
        jj = ii;
    } else {
      // Required range: -1 <= i < size-1, -1 <= j < size-1, i >= j
      if (i < -1) {
        ii = -1;
      } else if (i < (Difference) size) {
        ii = i;
      } else if (i >= (Difference)(size-1)) {
        ii = (Difference)(size-1);
      }
      if (j < -1) {
        jj = -1;
      } else {
        jj = (j < (Difference)size ) ? j : (Difference)(size-1);
      }
      if (ii < jj)
        ii = jj;
    }
  }

  template <class Sequence, class Difference>
  inline typename Sequence::iterator
  getpos(Sequence* self, Difference i)  {
    typename Sequence::iterator pos = self->begin();
    std::advance(pos, check_index(i,self->size()));
    return pos;
  }

  template <class Sequence, class Difference>
  inline typename Sequence::const_iterator
  cgetpos(const Sequence* self, Difference i)  {
    typename Sequence::const_iterator pos = self->begin();
    std::advance(pos, check_index(i,self->size()));
    return pos;
  }

  template <class Sequence>
  inline void
  erase(Sequence* seq, const typename Sequence::iterator& position) {
    seq->erase(position);
  }

  template <class Sequence>
  struct traits_reserve {
    static void reserve(Sequence & /*seq*/, typename Sequence::size_type /*n*/) {
      // This should be specialized for types that support reserve
    }
  };

  template <class Sequence, class Difference>
  inline Sequence*
  getslice(const Sequence* self, Difference i, Difference j, Py_ssize_t step) {
    typename Sequence::size_type size = self->size();
    Difference ii = 0;
    Difference jj = 0;
    swig::slice_adjust(i, j, step, size, ii, jj);

    if (step > 0) {
      typename Sequence::const_iterator sb = self->begin();
      typename Sequence::const_iterator se = self->begin();
      std::advance(sb,ii);
      std::advance(se,jj);
      if (step == 1) {
        return new Sequence(sb, se);
      } else {
        Sequence *sequence = new Sequence();
        swig::traits_reserve<Sequence>::reserve(*sequence, (jj - ii + step - 1) / step);
        typename Sequence::const_iterator it = sb;
        while (it!=se) {
          sequence->push_back(*it);
          for (Py_ssize_t c=0; c<step && it!=se; ++c)
            it++;
        }
        return sequence;
      } 
    } else {
      Sequence *sequence = new Sequence();
      swig::traits_reserve<Sequence>::reserve(*sequence, (ii - jj - step - 1) / -step);
      typename Sequence::const_reverse_iterator sb = self->rbegin();
      typename Sequence::const_reverse_iterator se = self->rbegin();
      std::advance(sb,size-ii-1);
      std::advance(se,size-jj-1);
      typename Sequence::const_reverse_iterator it = sb;
      while (it!=se) {
        sequence->push_back(*it);
        for (Py_ssize_t c=0; c<-step && it!=se; ++c)
          it++;
      }
      return sequence;
    }
  }

  template <class Sequence, class Difference, class InputSeq>
  inline void
  setslice(Sequence* self, Difference i, Difference j, Py_ssize_t step, const InputSeq& is = InputSeq()) {
    typename Sequence::size_type size = self->size();
    Difference ii = 0;
    Difference jj = 0;
    swig::slice_adjust(i, j, step, size, ii, jj, true);
    if (step > 0) {
      if (step == 1) {
        size_t ssize = jj - ii;
        if (ssize <= is.size()) {
          // expanding/staying the same size
          swig::traits_reserve<Sequence>::reserve(*self, self->size() - ssize + is.size());
          typename Sequence::iterator sb = self->begin();
          typename InputSeq::const_iterator isit = is.begin();
          std::advance(sb,ii);
          std::advance(isit, jj - ii);
          self->insert(std::copy(is.begin(), isit, sb), isit, is.end());
        } else {
          // shrinking
          typename Sequence::iterator sb = self->begin();
          typename Sequence::iterator se = self->begin();
          std::advance(sb,ii);
          std::advance(se,jj);
          self->erase(sb,se);
          sb = self->begin();
          std::advance(sb,ii);
          self->insert(sb, is.begin(), is.end());
        }
      } else {
        size_t replacecount = (jj - ii + step - 1) / step;
        if (is.size() != replacecount) {
          char msg[1024];
          sprintf(msg, "attempt to assign sequence of size %lu to extended slice of size %lu", (unsigned long)is.size(), (unsigned long)replacecount);
          throw std::invalid_argument(msg);
        }
        typename Sequence::const_iterator isit = is.begin();
        typename Sequence::iterator it = self->begin();
        std::advance(it,ii);
        for (size_t rc=0; rc<replacecount && it != self->end(); ++rc) {
          *it++ = *isit++;
          for (Py_ssize_t c=0; c<(step-1) && it != self->end(); ++c)
            it++;
        }
      }
    } else {
      size_t replacecount = (ii - jj - step - 1) / -step;
      if (is.size() != replacecount) {
        char msg[1024];
        sprintf(msg, "attempt to assign sequence of size %lu to extended slice of size %lu", (unsigned long)is.size(), (unsigned long)replacecount);
        throw std::invalid_argument(msg);
      }
      typename Sequence::const_iterator isit = is.begin();
      typename Sequence::reverse_iterator it = self->rbegin();
      std::advance(it,size-ii-1);
      for (size_t rc=0; rc<replacecount && it != self->rend(); ++rc) {
        *it++ = *isit++;
        for (Py_ssize_t c=0; c<(-step-1) && it != self->rend(); ++c)
          it++;
      }
    }
  }

  template <class Sequence, class Difference>
  inline void
  delslice(Sequence* self, Difference i, Difference j, Py_ssize_t step) {
    typename Sequence::size_type size = self->size();
    Difference ii = 0;
    Difference jj = 0;
    swig::slice_adjust(i, j, step, size, ii, jj, true);
    if (step > 0) {
      typename Sequence::iterator sb = self->begin();
      std::advance(sb,ii);
      if (step == 1) {
        typename Sequence::iterator se = self->begin();
        std::advance(se,jj);
        self->erase(sb,se);
      } else {
        typename Sequence::iterator it = sb;
        size_t delcount = (jj - ii + step - 1) / step;
        while (delcount) {
          it = self->erase(it);
          for (Py_ssize_t c=0; c<(step-1) && it != self->end(); ++c)
            it++;
          delcount--;
        }
      }
    } else {
      typename Sequence::reverse_iterator sb = self->rbegin();
      std::advance(sb,size-ii-1);
      typename Sequence::reverse_iterator it = sb;
      size_t delcount = (ii - jj - step - 1) / -step;
      while (delcount) {
        it = typename Sequence::reverse_iterator(self->erase((++it).base()));
        for (Py_ssize_t c=0; c<(-step-1) && it != self->rend(); ++c)
          it++;
        delcount--;
      }
    }
  }
}


#if defined(__SUNPRO_CC) && defined(_RWSTD_VER)
#  if !defined(SWIG_NO_STD_NOITERATOR_TRAITS_STL)
#    define SWIG_STD_NOITERATOR_TRAITS_STL
#  endif
#endif

#if !defined(SWIG_STD_NOITERATOR_TRAITS_STL)
#include <iterator>
#else
namespace std {
  template <class Iterator>
  struct iterator_traits {
    typedef ptrdiff_t difference_type;
    typedef typename Iterator::value_type value_type;
  };

  template <class Iterator, class Category,class T, class Reference, class Pointer, class Distance>
  struct iterator_traits<__reverse_bi_iterator<Iterator,Category,T,Reference,Pointer,Distance> > {
    typedef Distance difference_type;
    typedef T value_type;
  };

  template <class T>
  struct iterator_traits<T*> {
    typedef T value_type;
    typedef ptrdiff_t difference_type;
  };

  template<typename _InputIterator>
  inline typename iterator_traits<_InputIterator>::difference_type
  distance(_InputIterator __first, _InputIterator __last)
  {
    typename iterator_traits<_InputIterator>::difference_type __n = 0;
    while (__first != __last) {
      ++__first; ++__n;
    }
    return __n;
  }
}
#endif


namespace swig {
  template<typename OutIterator>
  class SwigPyIterator_T :  public SwigPyIterator
  {
  public:
    typedef OutIterator out_iterator;
    typedef typename std::iterator_traits<out_iterator>::value_type value_type;    
    typedef SwigPyIterator_T<out_iterator> self_type;

    SwigPyIterator_T(out_iterator curr, PyObject *seq)
      : SwigPyIterator(seq), current(curr)
    {
    }

    const out_iterator& get_current() const
    {
      return current;
    }

    
    bool equal (const SwigPyIterator &iter) const
    {
      const self_type *iters = dynamic_cast<const self_type *>(&iter);
      if (iters) {
	return (current == iters->get_current());
      } else {
	throw std::invalid_argument("bad iterator type");
      }
    }
    
    ptrdiff_t distance(const SwigPyIterator &iter) const
    {
      const self_type *iters = dynamic_cast<const self_type *>(&iter);
      if (iters) {
	return std::distance(current, iters->get_current());
      } else {
	throw std::invalid_argument("bad iterator type");
      }
    }    
    
  protected:
    out_iterator current;
  };
  
  template <class ValueType>
  struct from_oper 
  {
    typedef const ValueType& argument_type;
    typedef PyObject *result_type;
    result_type operator()(argument_type v) const
    {
      return swig::from(v);
    }
  };

  template<typename OutIterator, 
	   typename ValueType = typename std::iterator_traits<OutIterator>::value_type,
	   typename FromOper = from_oper<ValueType> >
  class SwigPyForwardIteratorOpen_T :  public SwigPyIterator_T<OutIterator>
  {
  public:
    FromOper from;
    typedef OutIterator out_iterator;
    typedef ValueType value_type;
    typedef SwigPyIterator_T<out_iterator>  base;
    typedef SwigPyForwardIteratorOpen_T<OutIterator, ValueType, FromOper> self_type;
    
    SwigPyForwardIteratorOpen_T(out_iterator curr, PyObject *seq)
      : SwigPyIterator_T<OutIterator>(curr, seq)
    {
    }
    
    PyObject *value() const {
      return from(static_cast<const value_type&>(*(base::current)));
    }
    
    SwigPyIterator *copy() const
    {
      return new self_type(*this);
    }

    SwigPyIterator *incr(size_t n = 1)
    {
      while (n--) {
	++base::current;
      }
      return this;
    }

  };

  template<typename OutIterator, 
	   typename ValueType = typename std::iterator_traits<OutIterator>::value_type,
	   typename FromOper = from_oper<ValueType> >
  class SwigPyIteratorOpen_T :  public SwigPyForwardIteratorOpen_T<OutIterator, ValueType, FromOper>
  {
  public:
    FromOper from;
    typedef OutIterator out_iterator;
    typedef ValueType value_type;
    typedef SwigPyIterator_T<out_iterator>  base;
    typedef SwigPyIteratorOpen_T<OutIterator, ValueType, FromOper> self_type;
    
    SwigPyIteratorOpen_T(out_iterator curr, PyObject *seq)
      : SwigPyForwardIteratorOpen_T<OutIterator>(curr, seq)
    {
    }

    SwigPyIterator *decr(size_t n = 1)
    {
      while (n--) {
	--base::current;
      }
      return this;
    }
  };

  template<typename OutIterator, 
	   typename ValueType = typename std::iterator_traits<OutIterator>::value_type,
	   typename FromOper = from_oper<ValueType> >
  class SwigPyForwardIteratorClosed_T :  public SwigPyIterator_T<OutIterator>
  {
  public:
    FromOper from;
    typedef OutIterator out_iterator;
    typedef ValueType value_type;
    typedef SwigPyIterator_T<out_iterator>  base;    
    typedef SwigPyForwardIteratorClosed_T<OutIterator, ValueType, FromOper> self_type;
    
    SwigPyForwardIteratorClosed_T(out_iterator curr, out_iterator first, out_iterator last, PyObject *seq)
      : SwigPyIterator_T<OutIterator>(curr, seq), begin(first), end(last)
    {
    }
    
    PyObject *value() const {
      if (base::current == end) {
	throw stop_iteration();
      } else {
	return from(static_cast<const value_type&>(*(base::current)));
      }
    }
    
    SwigPyIterator *copy() const
    {
      return new self_type(*this);
    }

    SwigPyIterator *incr(size_t n = 1)
    {
      while (n--) {
	if (base::current == end) {
	  throw stop_iteration();
	} else {
	  ++base::current;
	}
      }
      return this;
    }

  protected:
    out_iterator begin;
    out_iterator end;
  };

  template<typename OutIterator, 
	   typename ValueType = typename std::iterator_traits<OutIterator>::value_type,
	   typename FromOper = from_oper<ValueType> >
  class SwigPyIteratorClosed_T :  public SwigPyForwardIteratorClosed_T<OutIterator,ValueType,FromOper>
  {
  public:
    FromOper from;
    typedef OutIterator out_iterator;
    typedef ValueType value_type;
    typedef SwigPyIterator_T<out_iterator>  base;
    typedef SwigPyForwardIteratorClosed_T<OutIterator, ValueType, FromOper> base0;
    typedef SwigPyIteratorClosed_T<OutIterator, ValueType, FromOper> self_type;
    
    SwigPyIteratorClosed_T(out_iterator curr, out_iterator first, out_iterator last, PyObject *seq)
      : SwigPyForwardIteratorClosed_T<OutIterator,ValueType,FromOper>(curr, first, last, seq)
    {
    }

    SwigPyIterator *decr(size_t n = 1)
    {
      while (n--) {
	if (base::current == base0::begin) {
	  throw stop_iteration();
	} else {
	  --base::current;
	}
      }
      return this;
    }
  };


  template<typename OutIter>
  inline SwigPyIterator*
  make_output_forward_iterator(const OutIter& current, const OutIter& begin,const OutIter& end, PyObject *seq = 0)
  {
    return new SwigPyForwardIteratorClosed_T<OutIter>(current, begin, end, seq);
  }

  template<typename OutIter>
  inline SwigPyIterator*
  make_output_iterator(const OutIter& current, const OutIter& begin,const OutIter& end, PyObject *seq = 0)
  {
    return new SwigPyIteratorClosed_T<OutIter>(current, begin, end, seq);
  }

  template<typename OutIter>
  inline SwigPyIterator*
  make_output_forward_iterator(const OutIter& current, PyObject *seq = 0)
  {
    return new SwigPyForwardIteratorOpen_T<OutIter>(current, seq);
  }

  template<typename OutIter>
  inline SwigPyIterator*
  make_output_iterator(const OutIter& current, PyObject *seq = 0)
  {
    return new SwigPyIteratorOpen_T<OutIter>(current, seq);
  }

}


namespace swig
{
  template <class T>
  struct SwigPySequence_Ref
  {
    SwigPySequence_Ref(PyObject* seq, Py_ssize_t index)
      : _seq(seq), _index(index)
    {
    }
    
    operator T () const
    {
      swig::SwigVar_PyObject item = PySequence_GetItem(_seq, _index);
      try {
	return swig::as<T>(item);
      } catch (const std::invalid_argument& e) {
	char msg[1024];
	sprintf(msg, "in sequence element %d ", (int)_index);
	if (!PyErr_Occurred()) {
	  ::SWIG_Error(SWIG_TypeError,  swig::type_name<T>());
	}
	SWIG_Python_AddErrorMsg(msg);
	SWIG_Python_AddErrorMsg(e.what());
	throw;
      }
    }

    SwigPySequence_Ref& operator=(const T& v)
    {
      PySequence_SetItem(_seq, _index, swig::from<T>(v));
      return *this;
    }

  private:
    PyObject* _seq;
    Py_ssize_t _index;
  };

  template <class T>
  struct SwigPySequence_ArrowProxy
  {
    SwigPySequence_ArrowProxy(const T& x): m_value(x) {}
    const T* operator->() const { return &m_value; }
    operator const T*() const { return &m_value; }
    T m_value;
  };

  template <class T, class Reference >
  struct SwigPySequence_InputIterator
  {
    typedef SwigPySequence_InputIterator<T, Reference > self;

    typedef std::random_access_iterator_tag iterator_category;
    typedef Reference reference;
    typedef T value_type;
    typedef T* pointer;
    typedef Py_ssize_t difference_type;

    SwigPySequence_InputIterator()
    {
    }

    SwigPySequence_InputIterator(PyObject* seq, Py_ssize_t index)
      : _seq(seq), _index(index)
    {
    }

    reference operator*() const
    {
      return reference(_seq, _index);
    }

    SwigPySequence_ArrowProxy<T>
    operator->() const {
      return SwigPySequence_ArrowProxy<T>(operator*());
    }

    bool operator==(const self& ri) const
    {
      return (_index == ri._index) && (_seq == ri._seq);
    }

    bool operator!=(const self& ri) const
    {
      return !(operator==(ri));
    }

    self& operator ++ ()
    {
      ++_index;
      return *this;
    }

    self& operator -- ()
    {
      --_index;
      return *this;
    }

    self& operator += (difference_type n)
    {
      _index += n;
      return *this;
    }

    self operator +(difference_type n) const
    {
      return self(_seq, _index + n);
    }

    self& operator -= (difference_type n)
    {
      _index -= n;
      return *this;
    }

    self operator -(difference_type n) const
    {
      return self(_seq, _index - n);
    }

    difference_type operator - (const self& ri) const
    {
      return _index - ri._index;
    }

    bool operator < (const self& ri) const
    {
      return _index < ri._index;
    }

    reference
    operator[](difference_type n) const
    {
      return reference(_seq, _index + n);
    }

  private:
    PyObject* _seq;
    difference_type _index;
  };

  // STL container wrapper around a Python sequence
  template <class T>
  struct SwigPySequence_Cont
  {
    typedef SwigPySequence_Ref<T> reference;
    typedef const SwigPySequence_Ref<T> const_reference;
    typedef T value_type;
    typedef T* pointer;
    typedef Py_ssize_t difference_type;
    typedef size_t size_type;
    typedef const pointer const_pointer;
    typedef SwigPySequence_InputIterator<T, reference> iterator;
    typedef SwigPySequence_InputIterator<T, const_reference> const_iterator;

    SwigPySequence_Cont(PyObject* seq) : _seq(0)
    {
      if (!PySequence_Check(seq)) {
	throw std::invalid_argument("a sequence is expected");
      }
      _seq = seq;
      Py_INCREF(_seq);
    }

    ~SwigPySequence_Cont()
    {
      Py_XDECREF(_seq);
    }

    size_type size() const
    {
      return static_cast<size_type>(PySequence_Size(_seq));
    }

    bool empty() const
    {
      return size() == 0;
    }

    iterator begin()
    {
      return iterator(_seq, 0);
    }

    const_iterator begin() const
    {
      return const_iterator(_seq, 0);
    }

    iterator end()
    {
      return iterator(_seq, size());
    }

    const_iterator end() const
    {
      return const_iterator(_seq, size());
    }

    reference operator[](difference_type n)
    {
      return reference(_seq, n);
    }

    const_reference operator[](difference_type n)  const
    {
      return const_reference(_seq, n);
    }

    bool check() const
    {
      Py_ssize_t s = size();
      for (Py_ssize_t i = 0; i < s; ++i) {
	swig::SwigVar_PyObject item = PySequence_GetItem(_seq, i);
	if (!swig::check<value_type>(item))
	  return false;
      }
      return true;
    }

  private:
    PyObject* _seq;
  };

}


SWIGINTERN int
SWIG_AsPtr_std_string (PyObject * obj, std::string **val) 
{
  char* buf = 0 ; size_t size = 0; int alloc = SWIG_OLDOBJ;
  if (SWIG_IsOK((SWIG_AsCharPtrAndSize(obj, &buf, &size, &alloc)))) {
    if (buf) {
      if (val) *val = new std::string(buf, size - 1);
      if (alloc == SWIG_NEWOBJ) delete[] buf;
      return SWIG_NEWOBJ;
    } else {
      if (val) *val = 0;
      return SWIG_OLDOBJ;
    }
  } else {
    static int init = 0;
    static swig_type_info* descriptor = 0;
    if (!init) {
      descriptor = SWIG_TypeQuery("std::string" " *");
      init = 1;
    }
    if (descriptor) {
      std::string *vptr;
      int res = SWIG_ConvertPtr(obj, (void**)&vptr, descriptor, 0);
      if (SWIG_IsOK(res) && val) *val = vptr;
      return res;
    }
  }
  return SWIG_ERROR;
}


SWIGINTERN int
SWIG_AsVal_std_string (PyObject * obj, std::string *val)
{
  std::string* v = (std::string *) 0;
  int res = SWIG_AsPtr_std_string (obj, &v);
  if (!SWIG_IsOK(res)) return res;
  if (v) {
    if (val) *val = *v;
    if (SWIG_IsNewObj(res)) {
      delete v;
      res = SWIG_DelNewMask(res);
    }
    return res;
  }
  return SWIG_ERROR;
}


SWIGINTERNINLINE PyObject *
SWIG_From_std_string  (const std::string& s)
{
  return SWIG_FromCharPtrAndSize(s.data(), s.size());
}


namespace swig {
  template <> struct traits< std::string > {
    typedef value_category category;
    static const char* type_name() { return"std::string"; }
  };
  template <>  struct traits_asval< std::string > {
    typedef std::string value_type;
    static int asval(PyObject *obj, value_type *val) {
      return SWIG_AsVal_std_string (obj, val);
    }
  };
  template <>  struct traits_from< std::string > {
    typedef std::string value_type;
    static PyObject *from(const value_type& val) {
      return SWIG_From_std_string  (val);
    }
  };
}


namespace swig {
  template <class SwigPySeq, class Seq>
  inline void
  assign(const SwigPySeq& swigpyseq, Seq* seq) {
    // seq->assign(swigpyseq.begin(), swigpyseq.end()); // not used as not always implemented
    typedef typename SwigPySeq::value_type value_type;
    typename SwigPySeq::const_iterator it = swigpyseq.begin();
    for (;it != swigpyseq.end(); ++it) {
      seq->insert(seq->end(),(value_type)(*it));
    }
  }

  template <class Seq, class T = typename Seq::value_type >
  struct traits_asptr_stdseq {
    typedef Seq sequence;
    typedef T value_type;

    static int asptr(PyObject *obj, sequence **seq) {
      if (obj == Py_None || SWIG_Python_GetSwigThis(obj)) {
	sequence *p;
	swig_type_info *descriptor = swig::type_info<sequence>();
	if (descriptor && SWIG_IsOK(::SWIG_ConvertPtr(obj, (void **)&p, descriptor, 0))) {
	  if (seq) *seq = p;
	  return SWIG_OLDOBJ;
	}
      } else if (PySequence_Check(obj)) {
	try {
	  SwigPySequence_Cont<value_type> swigpyseq(obj);
	  if (seq) {
	    sequence *pseq = new sequence();
	    assign(swigpyseq, pseq);
	    *seq = pseq;
	    return SWIG_NEWOBJ;
	  } else {
	    return swigpyseq.check() ? SWIG_OK : SWIG_ERROR;
	  }
	} catch (std::exception& e) {
	  if (seq) {
	    if (!PyErr_Occurred()) {
	      PyErr_SetString(PyExc_TypeError, e.what());
	    }
	  }
	  return SWIG_ERROR;
	}
      }
      return SWIG_ERROR;
    }
  };

  template <class Seq, class T = typename Seq::value_type >
  struct traits_from_stdseq {
    typedef Seq sequence;
    typedef T value_type;
    typedef typename Seq::size_type size_type;
    typedef typename sequence::const_iterator const_iterator;

    static PyObject *from(const sequence& seq) {
#ifdef SWIG_PYTHON_EXTRA_NATIVE_CONTAINERS
      swig_type_info *desc = swig::type_info<sequence>();
      if (desc && desc->clientdata) {
	return SWIG_InternalNewPointerObj(new sequence(seq), desc, SWIG_POINTER_OWN);
      }
#endif
      size_type size = seq.size();
      if (size <= (size_type)INT_MAX) {
	PyObject *obj = PyTuple_New((Py_ssize_t)size);
	Py_ssize_t i = 0;
	for (const_iterator it = seq.begin(); it != seq.end(); ++it, ++i) {
	  PyTuple_SetItem(obj,i,swig::from<value_type>(*it));
	}
	return obj;
      } else {
	PyErr_SetString(PyExc_OverflowError,"sequence size not valid in python");
	return NULL;
      }
    }
  };
}


  namespace swig {
    template <class T>
    struct traits_reserve<std::vector<T> > {
      static void reserve(std::vector<T> &seq, typename std::vector<T>::size_type n) {
        seq.reserve(n);
      }
    };

    template <class T>
    struct traits_asptr<std::vector<T> >  {
      static int asptr(PyObject *obj, std::vector<T> **vec) {
	return traits_asptr_stdseq<std::vector<T> >::asptr(obj, vec);
      }
    };
    
    template <class T>
    struct traits_from<std::vector<T> > {
      static PyObject *from(const std::vector<T>& vec) {
	return traits_from_stdseq<std::vector<T> >::from(vec);
      }
    };
  }


      namespace swig {
	template <>  struct traits<std::vector< std::string, std::allocator< std::string > > > {
	  typedef pointer_category category;
	  static const char* type_name() {
	    return "std::vector<" "std::string" "," "std::allocator< std::string >" " >";
	  }
	};
      }
    
SWIGINTERN swig::SwigPyIterator *std_vector_Sl_std_string_Sg__iterator(std::vector< std::string > *self,PyObject **PYTHON_SELF){
      return swig::make_output_iterator(self->begin(), self->begin(), self->end(), *PYTHON_SELF);
    }
SWIGINTERN bool std_vector_Sl_std_string_Sg____nonzero__(std::vector< std::string > const *self){
      return !(self->empty());
    }
SWIGINTERN bool std_vector_Sl_std_string_Sg____bool__(std::vector< std::string > const *self){
      return !(self->empty());
    }
SWIGINTERN std::vector< std::string >::size_type std_vector_Sl_std_string_Sg____len__(std::vector< std::string > const *self){
      return self->size();
    }

#ifdef SWIG_LONG_LONG_AVAILABLE
SWIGINTERNINLINE PyObject* 
SWIG_From_unsigned_SS_long_SS_long  (unsigned long long value)
{
  return (value > LONG_MAX) ?
    PyLong_FromUnsignedLongLong(value) : PyInt_FromLong(static_cast< long >(value));
}
#endif


SWIGINTERNINLINE PyObject *
SWIG_From_size_t  (size_t value)
{    
#ifdef SWIG_LONG_LONG_AVAILABLE
  if (sizeof(size_t) <= sizeof(unsigned long)) {
#endif
    return SWIG_From_unsigned_SS_long  (static_cast< unsigned long >(value));
#ifdef SWIG_LONG_LONG_AVAILABLE
  } else {
    /* assume sizeof(size_t) <= sizeof(unsigned long long) */
    return SWIG_From_unsigned_SS_long_SS_long  (static_cast< unsigned long long >(value));
  }
#endif
}

SWIGINTERN std::vector< std::string,std::allocator< std::string > > *std_vector_Sl_std_string_Sg____getslice__(std::vector< std::string > *self,std::vector< std::string >::difference_type i,std::vector< std::string >::difference_type j){
      return swig::getslice(self, i, j, 1);
    }
SWIGINTERN void std_vector_Sl_std_string_Sg____setslice____SWIG_0(std::vector< std::string > *self,std::vector< std::string >::difference_type i,std::vector< std::string >::difference_type j){
      swig::setslice(self, i, j, 1, std::vector< std::string,std::allocator< std::string > >());
    }
SWIGINTERN void std_vector_Sl_std_string_Sg____setslice____SWIG_1(std::vector< std::string > *self,std::vector< std::string >::difference_type i,std::vector< std::string >::difference_type j,std::vector< std::string,std::allocator< std::string > > const &v){
      swig::setslice(self, i, j, 1, v);
    }
SWIGINTERN void std_vector_Sl_std_string_Sg____delslice__(std::vector< std::string > *self,std::vector< std::string >::difference_type i,std::vector< std::string >::difference_type j){
      swig::delslice(self, i, j, 1);
    }
SWIGINTERN void std_vector_Sl_std_string_Sg____delitem____SWIG_0(std::vector< std::string > *self,std::vector< std::string >::difference_type i){
      swig::erase(self, swig::getpos(self, i));
    }
SWIGINTERN std::vector< std::string,std::allocator< std::string > > *std_vector_Sl_std_string_Sg____getitem____SWIG_0(std::vector< std::string > *self,PySliceObject *slice){
      Py_ssize_t i, j, step;
      if( !PySlice_Check(slice) ) {
        SWIG_Error(SWIG_TypeError, "Slice object expected.");
        return NULL;
      }
      PySlice_GetIndices(SWIGPY_SLICE_ARG(slice), (Py_ssize_t)self->size(), &i, &j, &step);
      std::vector< std::string,std::allocator< std::string > >::difference_type id = i;
      std::vector< std::string,std::allocator< std::string > >::difference_type jd = j;
      return swig::getslice(self, id, jd, step);
    }
SWIGINTERN void std_vector_Sl_std_string_Sg____setitem____SWIG_0(std::vector< std::string > *self,PySliceObject *slice,std::vector< std::string,std::allocator< std::string > > const &v){
      Py_ssize_t i, j, step;
      if( !PySlice_Check(slice) ) {
        SWIG_Error(SWIG_TypeError, "Slice object expected.");
        return;
      }
      PySlice_GetIndices(SWIGPY_SLICE_ARG(slice), (Py_ssize_t)self->size(), &i, &j, &step);
      std::vector< std::string,std::allocator< std::string > >::difference_type id = i;
      std::vector< std::string,std::allocator< std::string > >::difference_type jd = j;
      swig::setslice(self, id, jd, step, v);
    }
SWIGINTERN void std_vector_Sl_std_string_Sg____setitem____SWIG_1(std::vector< std::string > *self,PySliceObject *slice){
      Py_ssize_t i, j, step;
      if( !PySlice_Check(slice) ) {
        SWIG_Error(SWIG_TypeError, "Slice object expected.");
        return;
      }
      PySlice_GetIndices(SWIGPY_SLICE_ARG(slice), (Py_ssize_t)self->size(), &i, &j, &step);
      std::vector< std::string,std::allocator< std::string > >::difference_type id = i;
      std::vector< std::string,std::allocator< std::string > >::difference_type jd = j;
      swig::delslice(self, id, jd, step);
    }
SWIGINTERN void std_vector_Sl_std_string_Sg____delitem____SWIG_1(std::vector< std::string > *self,PySliceObject *slice){
      Py_ssize_t i, j, step;
      if( !PySlice_Check(slice) ) {
        SWIG_Error(SWIG_TypeError, "Slice object expected.");
        return;
      }
      PySlice_GetIndices(SWIGPY_SLICE_ARG(slice), (Py_ssize_t)self->size(), &i, &j, &step);
      std::vector< std::string,std::allocator< std::string > >::difference_type id = i;
      std::vector< std::string,std::allocator< std::string > >::difference_type jd = j;
      swig::delslice(self, id, jd, step);
    }
SWIGINTERN std::vector< std::string >::value_type const &std_vector_Sl_std_string_Sg____getitem____SWIG_1(std::vector< std::string > const *self,std::vector< std::string >::difference_type i){
      return *(swig::cgetpos(self, i));
    }

namespace swig {
  static PyObject* container_owner_attribute() {
    static PyObject* attr = SWIG_Python_str_FromChar("__swig_container");
    return attr;
  }

  template <typename T>
  struct container_owner {
    // By default, do not add the back-reference (for value types)
    // Specialization below will check the reference for pointer types.
    static bool back_reference(PyObject* child, PyObject* owner) {
      return false;
    }
  };

  template <>
  struct container_owner<swig::pointer_category> {  
    /*
     * Call to add a back-reference to the owning object when returning a 
     * reference from a container.  Will only set the reference if child
     * is a SWIG wrapper object that does not own the pointer.
     *
     * returns whether the reference was set or not
     */
    static bool back_reference(PyObject* child, PyObject* owner) {
      SwigPyObject* swigThis = SWIG_Python_GetSwigThis(child);
      if (swigThis && (swigThis->own & SWIG_POINTER_OWN) != SWIG_POINTER_OWN) {
        PyObject_SetAttr(child, container_owner_attribute(), owner);
        return true;
      }
      return false;
    }
  };
}

SWIGINTERN void std_vector_Sl_std_string_Sg____setitem____SWIG_2(std::vector< std::string > *self,std::vector< std::string >::difference_type i,std::vector< std::string >::value_type const &x){
      *(swig::getpos(self,i)) = x;
    }
SWIGINTERN std::vector< std::string >::value_type std_vector_Sl_std_string_Sg__pop(std::vector< std::string > *self){
      if (self->size() == 0)
	throw std::out_of_range("pop from empty container");
      std::vector< std::string,std::allocator< std::string > >::value_type x = self->back();
      self->pop_back();
      return x;
    }
SWIGINTERN void std_vector_Sl_std_string_Sg__append(std::vector< std::string > *self,std::vector< std::string >::value_type const &x){
      self->push_back(x);
    }
SWIGINTERN std::vector< std::string >::iterator std_vector_Sl_std_string_Sg__erase__SWIG_0(std::vector< std::string > *self,std::vector< std::string >::iterator pos){ return self->erase(pos); }
SWIGINTERN std::vector< std::string >::iterator std_vector_Sl_std_string_Sg__erase__SWIG_1(std::vector< std::string > *self,std::vector< std::string >::iterator first,std::vector< std::string >::iterator last){ return self->erase(first, last); }
SWIGINTERN std::vector< std::string >::iterator std_vector_Sl_std_string_Sg__insert__SWIG_0(std::vector< std::string > *self,std::vector< std::string >::iterator pos,std::vector< std::string >::value_type const &x){ return self->insert(pos, x); }
SWIGINTERN void std_vector_Sl_std_string_Sg__insert__SWIG_1(std::vector< std::string > *self,std::vector< std::string >::iterator pos,std::vector< std::string >::size_type n,std::vector< std::string >::value_type const &x){ self->insert(pos, n, x); }

namespace swig {
  template <> struct traits< int > {
    typedef value_category category;
    static const char* type_name() { return"int"; }
  };
  template <>  struct traits_asval< int > {
    typedef int value_type;
    static int asval(PyObject *obj, value_type *val) {
      return SWIG_AsVal_int (obj, val);
    }
  };
  template <>  struct traits_from< int > {
    typedef int value_type;
    static PyObject *from(const value_type& val) {
      return SWIG_From_int  (val);
    }
  };
}


      namespace swig {
	template <>  struct traits<std::vector< int, std::allocator< int > > > {
	  typedef pointer_category category;
	  static const char* type_name() {
	    return "std::vector<" "int" "," "std::allocator< int >" " >";
	  }
	};
      }
    
SWIGINTERN swig::SwigPyIterator *std_vector_Sl_int_Sg__iterator(std::vector< int > *self,PyObject **PYTHON_SELF){
      return swig::make_output_iterator(self->begin(), self->begin(), self->end(), *PYTHON_SELF);
    }
SWIGINTERN bool std_vector_Sl_int_Sg____nonzero__(std::vector< int > const *self){
      return !(self->empty());
    }
SWIGINTERN bool std_vector_Sl_int_Sg____bool__(std::vector< int > const *self){
      return !(self->empty());
    }
SWIGINTERN std::vector< int >::size_type std_vector_Sl_int_Sg____len__(std::vector< int > const *self){
      return self->size();
    }
SWIGINTERN std::vector< int,std::allocator< int > > *std_vector_Sl_int_Sg____getslice__(std::vector< int > *self,std::vector< int >::difference_type i,std::vector< int >::difference_type j){
      return swig::getslice(self, i, j, 1);
    }
SWIGINTERN void std_vector_Sl_int_Sg____setslice____SWIG_0(std::vector< int > *self,std::vector< int >::difference_type i,std::vector< int >::difference_type j){
      swig::setslice(self, i, j, 1, std::vector< int,std::allocator< int > >());
    }
SWIGINTERN void std_vector_Sl_int_Sg____setslice____SWIG_1(std::vector< int > *self,std::vector< int >::difference_type i,std::vector< int >::difference_type j,std::vector< int,std::allocator< int > > const &v){
      swig::setslice(self, i, j, 1, v);
    }
SWIGINTERN void std_vector_Sl_int_Sg____delslice__(std::vector< int > *self,std::vector< int >::difference_type i,std::vector< int >::difference_type j){
      swig::delslice(self, i, j, 1);
    }
SWIGINTERN void std_vector_Sl_int_Sg____delitem____SWIG_0(std::vector< int > *self,std::vector< int >::difference_type i){
      swig::erase(self, swig::getpos(self, i));
    }
SWIGINTERN std::vector< int,std::allocator< int > > *std_vector_Sl_int_Sg____getitem____SWIG_0(std::vector< int > *self,PySliceObject *slice){
      Py_ssize_t i, j, step;
      if( !PySlice_Check(slice) ) {
        SWIG_Error(SWIG_TypeError, "Slice object expected.");
        return NULL;
      }
      PySlice_GetIndices(SWIGPY_SLICE_ARG(slice), (Py_ssize_t)self->size(), &i, &j, &step);
      std::vector< int,std::allocator< int > >::difference_type id = i;
      std::vector< int,std::allocator< int > >::difference_type jd = j;
      return swig::getslice(self, id, jd, step);
    }
SWIGINTERN void std_vector_Sl_int_Sg____setitem____SWIG_0(std::vector< int > *self,PySliceObject *slice,std::vector< int,std::allocator< int > > const &v){
      Py_ssize_t i, j, step;
      if( !PySlice_Check(slice) ) {
        SWIG_Error(SWIG_TypeError, "Slice object expected.");
        return;
      }
      PySlice_GetIndices(SWIGPY_SLICE_ARG(slice), (Py_ssize_t)self->size(), &i, &j, &step);
      std::vector< int,std::allocator< int > >::difference_type id = i;
      std::vector< int,std::allocator< int > >::difference_type jd = j;
      swig::setslice(self, id, jd, step, v);
    }
SWIGINTERN void std_vector_Sl_int_Sg____setitem____SWIG_1(std::vector< int > *self,PySliceObject *slice){
      Py_ssize_t i, j, step;
      if( !PySlice_Check(slice) ) {
        SWIG_Error(SWIG_TypeError, "Slice object expected.");
        return;
      }
      PySlice_GetIndices(SWIGPY_SLICE_ARG(slice), (Py_ssize_t)self->size(), &i, &j, &step);
      std::vector< int,std::allocator< int > >::difference_type id = i;
      std::vector< int,std::allocator< int > >::difference_type jd = j;
      swig::delslice(self, id, jd, step);
    }
SWIGINTERN void std_vector_Sl_int_Sg____delitem____SWIG_1(std::vector< int > *self,PySliceObject *slice){
      Py_ssize_t i, j, step;
      if( !PySlice_Check(slice) ) {
        SWIG_Error(SWIG_TypeError, "Slice object expected.");
        return;
      }
      PySlice_GetIndices(SWIGPY_SLICE_ARG(slice), (Py_ssize_t)self->size(), &i, &j, &step);
      std::vector< int,std::allocator< int > >::difference_type id = i;
      std::vector< int,std::allocator< int > >::difference_type jd = j;
      swig::delslice(self, id, jd, step);
    }
SWIGINTERN std::vector< int >::value_type const &std_vector_Sl_int_Sg____getitem____SWIG_1(std::vector< int > const *self,std::vector< int >::difference_type i){
      return *(swig::cgetpos(self, i));
    }
SWIGINTERN void std_vector_Sl_int_Sg____setitem____SWIG_2(std::vector< int > *self,std::vector< int >::difference_type i,std::vector< int >::value_type const &x){
      *(swig::getpos(self,i)) = x;
    }
SWIGINTERN std::vector< int >::value_type std_vector_Sl_int_Sg__pop(std::vector< int > *self){
      if (self->size() == 0)
	throw std::out_of_range("pop from empty container");
      std::vector< int,std::allocator< int > >::value_type x = self->back();
      self->pop_back();
      return x;
    }
SWIGINTERN void std_vector_Sl_int_Sg__append(std::vector< int > *self,std::vector< int >::value_type const &x){
      self->push_back(x);
    }
SWIGINTERN std::vector< int >::iterator std_vector_Sl_int_Sg__erase__SWIG_0(std::vector< int > *self,std::vector< int >::iterator pos){ return self->erase(pos); }
SWIGINTERN std::vector< int >::iterator std_vector_Sl_int_Sg__erase__SWIG_1(std::vector< int > *self,std::vector< int >::iterator first,std::vector< int >::iterator last){ return self->erase(first, last); }
SWIGINTERN std::vector< int >::iterator std_vector_Sl_int_Sg__insert__SWIG_0(std::vector< int > *self,std::vector< int >::iterator pos,std::vector< int >::value_type const &x){ return self->insert(pos, x); }
SWIGINTERN void std_vector_Sl_int_Sg__insert__SWIG_1(std::vector< int > *self,std::vector< int >::iterator pos,std::vector< int >::size_type n,std::vector< int >::value_type const &x){ self->insert(pos, n, x); }

  namespace swig {


















































    template <class T, class U >
    struct traits_asptr<std::pair<T,U> >  {
      typedef std::pair<T,U> value_type;

      static int get_pair(PyObject* first, PyObject* second,
			  std::pair<T,U> **val) 
      {
	if (val) {
	  value_type *vp = (new std::pair<T,U>());
	  T *pfirst = &(vp->first);
	  int res1 = swig::asval((PyObject*)first, pfirst);
	  if (!SWIG_IsOK(res1)) {
	    delete vp;
	    return res1;
	  }
	  U *psecond = &(vp->second);
	  int res2 = swig::asval((PyObject*)second, psecond);
	  if (!SWIG_IsOK(res2)) {
	    delete vp;
	    return res2;
	  }
	  *val = vp;
	  return SWIG_AddNewMask(res1 > res2 ? res1 : res2);
	} else {
	  T *pfirst = 0;
	  int res1 = swig::asval((PyObject*)first, pfirst);
	  if (!SWIG_IsOK(res1)) return res1;
	  U *psecond = 0;
	  int res2 = swig::asval((PyObject*)second, psecond);
	  if (!SWIG_IsOK(res2)) return res2;
	  return res1 > res2 ? res1 : res2;
	}
      }

      static int asptr(PyObject *obj, std::pair<T,U> **val) {
	int res = SWIG_ERROR;
	if (PyTuple_Check(obj)) {
	  if (PyTuple_GET_SIZE(obj) == 2) {
	    res = get_pair(PyTuple_GET_ITEM(obj,0),PyTuple_GET_ITEM(obj,1), val);
	  }
	} else if (PySequence_Check(obj)) {
	  if (PySequence_Size(obj) == 2) {
	    swig::SwigVar_PyObject first = PySequence_GetItem(obj,0);
	    swig::SwigVar_PyObject second = PySequence_GetItem(obj,1);
	    res = get_pair(first, second, val);
	  }
	} else {
	  value_type *p;
	  swig_type_info *descriptor = swig::type_info<value_type>();
	  res = descriptor ? SWIG_ConvertPtr(obj, (void **)&p, descriptor, 0) : SWIG_ERROR;
	  if (SWIG_IsOK(res) && val)  *val = p;
	}
	return res;
      }
    };


    template <class T, class U >
    struct traits_from<std::pair<T,U> >   {
      static PyObject *from(const std::pair<T,U>& val) {
	PyObject* obj = PyTuple_New(2);
	PyTuple_SetItem(obj,0,swig::from(val.first));
	PyTuple_SetItem(obj,1,swig::from(val.second));
	return obj;
      }
    };
  }





































      namespace swig {
	template <>  struct traits<std::pair< std::string, std::string > > {
	  typedef pointer_category category;
	  static const char* type_name() {
	    return "std::pair<" "std::string" "," "std::string" " >";
	  }
	};
      }
    

  namespace swig {
    template <class ValueType>
    struct from_key_oper 
    {
      typedef const ValueType& argument_type;
      typedef  PyObject *result_type;
      result_type operator()(argument_type v) const
      {
	return swig::from(v.first);
      }
    };

    template <class ValueType>
    struct from_value_oper 
    {
      typedef const ValueType& argument_type;
      typedef  PyObject *result_type;
      result_type operator()(argument_type v) const
      {
	return swig::from(v.second);
      }
    };

    template<class OutIterator, class FromOper, class ValueType = typename OutIterator::value_type>
    struct SwigPyMapIterator_T : SwigPyIteratorClosed_T<OutIterator, ValueType, FromOper>
    {
      SwigPyMapIterator_T(OutIterator curr, OutIterator first, OutIterator last, PyObject *seq)
	: SwigPyIteratorClosed_T<OutIterator,ValueType,FromOper>(curr, first, last, seq)
      {
      }
    };


    template<class OutIterator,
	     class FromOper = from_key_oper<typename OutIterator::value_type> >
    struct SwigPyMapKeyIterator_T : SwigPyMapIterator_T<OutIterator, FromOper>
    {
      SwigPyMapKeyIterator_T(OutIterator curr, OutIterator first, OutIterator last, PyObject *seq)
	: SwigPyMapIterator_T<OutIterator, FromOper>(curr, first, last, seq)
      {
      }
    };

    template<typename OutIter>
    inline SwigPyIterator*
    make_output_key_iterator(const OutIter& current, const OutIter& begin, const OutIter& end, PyObject *seq = 0)
    {
      return new SwigPyMapKeyIterator_T<OutIter>(current, begin, end, seq);
    }

    template<class OutIterator,
	     class FromOper = from_value_oper<typename OutIterator::value_type> >
    struct SwigPyMapValueIterator_T : SwigPyMapIterator_T<OutIterator, FromOper>
    {
      SwigPyMapValueIterator_T(OutIterator curr, OutIterator first, OutIterator last, PyObject *seq)
	: SwigPyMapIterator_T<OutIterator, FromOper>(curr, first, last, seq)
      {
      }
    };
    

    template<typename OutIter>
    inline SwigPyIterator*
    make_output_value_iterator(const OutIter& current, const OutIter& begin, const OutIter& end, PyObject *seq = 0)
    {
      return new SwigPyMapValueIterator_T<OutIter>(current, begin, end, seq);
    }
  }


  namespace swig {
    template <class SwigPySeq, class K, class T, class Compare, class Alloc >
    inline void
    assign(const SwigPySeq& swigpyseq, std::map<K,T,Compare,Alloc > *map) {
      typedef typename std::map<K,T,Compare,Alloc >::value_type value_type;
      typename SwigPySeq::const_iterator it = swigpyseq.begin();
      for (;it != swigpyseq.end(); ++it) {
	map->insert(value_type(it->first, it->second));
      }
    }

    template <class K, class T, class Compare, class Alloc>
    struct traits_asptr<std::map<K,T,Compare,Alloc > >  {
      typedef std::map<K,T,Compare,Alloc > map_type;
      static int asptr(PyObject *obj, map_type **val) {
	int res = SWIG_ERROR;
	SWIG_PYTHON_THREAD_BEGIN_BLOCK;
	if (PyDict_Check(obj)) {
	  SwigVar_PyObject items = PyObject_CallMethod(obj,(char *)"items",NULL);
#if PY_VERSION_HEX >= 0x03000000
          /* In Python 3.x the ".items()" method returns a dict_items object */
          items = PySequence_Fast(items, ".items() didn't return a sequence!");
#endif
	  res = traits_asptr_stdseq<map_type, std::pair<K, T> >::asptr(items, val);
	} else {
	  map_type *p;
	  swig_type_info *descriptor = swig::type_info<map_type>();
	  res = descriptor ? SWIG_ConvertPtr(obj, (void **)&p, descriptor, 0) : SWIG_ERROR;
	  if (SWIG_IsOK(res) && val)  *val = p;
	}
	SWIG_PYTHON_THREAD_END_BLOCK;
	return res;
      }      
    };
      
    template <class K, class T, class Compare, class Alloc >
    struct traits_from<std::map<K,T,Compare,Alloc > >  {
      typedef std::map<K,T,Compare,Alloc > map_type;
      typedef typename map_type::const_iterator const_iterator;
      typedef typename map_type::size_type size_type;

      static PyObject *asdict(const map_type& map) {
	SWIG_PYTHON_THREAD_BEGIN_BLOCK;
	size_type size = map.size();
	Py_ssize_t pysize = (size <= (size_type) INT_MAX) ? (Py_ssize_t) size : -1;
	if (pysize < 0) {
	  PyErr_SetString(PyExc_OverflowError, "map size not valid in python");
	  SWIG_PYTHON_THREAD_END_BLOCK;
	  return NULL;
	}
	PyObject *obj = PyDict_New();
	for (const_iterator i= map.begin(); i!= map.end(); ++i) {
	  swig::SwigVar_PyObject key = swig::from(i->first);
	  swig::SwigVar_PyObject val = swig::from(i->second);
	  PyDict_SetItem(obj, key, val);
	}
	SWIG_PYTHON_THREAD_END_BLOCK;
	return obj;
      }
                
      static PyObject *from(const map_type& map) {
	swig_type_info *desc = swig::type_info<map_type>();
	if (desc && desc->clientdata) {
	  return SWIG_InternalNewPointerObj(new map_type(map), desc, SWIG_POINTER_OWN);
	} else {
	  return asdict(map);
	}
      }
    };
  }


      namespace swig {
	template <>  struct traits<std::map< std::string, std::string, std::less< std::string >, std::allocator< std::pair< std::string const,std::string > > > > {
	  typedef pointer_category category;
	  static const char* type_name() {
	    return "std::map<" "std::string" "," "std::string" "," "std::less< std::string >" "," "std::allocator< std::pair< std::string const,std::string > >" " >";
	  }
	};
      }
    
SWIGINTERN swig::SwigPyIterator *std_map_Sl_string_Sc_string_Sg__iterator(std::map< string,string > *self,PyObject **PYTHON_SELF){
      return swig::make_output_iterator(self->begin(), self->begin(), self->end(), *PYTHON_SELF);
    }
SWIGINTERN bool std_map_Sl_string_Sc_string_Sg____nonzero__(std::map< string,string > const *self){
      return !(self->empty());
    }
SWIGINTERN bool std_map_Sl_string_Sc_string_Sg____bool__(std::map< string,string > const *self){
      return !(self->empty());
    }
SWIGINTERN std::map< string,string >::size_type std_map_Sl_string_Sc_string_Sg____len__(std::map< string,string > const *self){
      return self->size();
    }
SWIGINTERN std::map< string,string >::mapped_type const &std_map_Sl_string_Sc_string_Sg____getitem__(std::map< string,string > *self,std::map< string,string >::key_type const &key){
      std::map< std::string,std::string,std::less< std::string >,std::allocator< std::pair< std::string const,std::string > > >::const_iterator i = self->find(key);
      if (i != self->end())
	return i->second;
      else
	throw std::out_of_range("key not found");
    }
SWIGINTERN void std_map_Sl_string_Sc_string_Sg____delitem__(std::map< string,string > *self,std::map< string,string >::key_type const &key){
      std::map< std::string,std::string,std::less< std::string >,std::allocator< std::pair< std::string const,std::string > > >::iterator i = self->find(key);
      if (i != self->end())
	self->erase(i);
      else
	throw std::out_of_range("key not found");
    }
SWIGINTERN bool std_map_Sl_string_Sc_string_Sg__has_key(std::map< string,string > const *self,std::map< string,string >::key_type const &key){
      std::map< std::string,std::string,std::less< std::string >,std::allocator< std::pair< std::string const,std::string > > >::const_iterator i = self->find(key);
      return i != self->end();
    }
SWIGINTERN PyObject *std_map_Sl_string_Sc_string_Sg__keys(std::map< string,string > *self){
      std::map< std::string,std::string,std::less< std::string >,std::allocator< std::pair< std::string const,std::string > > >::size_type size = self->size();
      Py_ssize_t pysize = (size <= (std::map< std::string,std::string,std::less< std::string >,std::allocator< std::pair< std::string const,std::string > > >::size_type) INT_MAX) ? (Py_ssize_t) size : -1;
      SWIG_PYTHON_THREAD_BEGIN_BLOCK;
      if (pysize < 0) {
	PyErr_SetString(PyExc_OverflowError, "map size not valid in python");
	SWIG_PYTHON_THREAD_END_BLOCK;
	return NULL;
      }
      PyObject* keyList = PyList_New(pysize);
      std::map< std::string,std::string,std::less< std::string >,std::allocator< std::pair< std::string const,std::string > > >::const_iterator i = self->begin();
      for (Py_ssize_t j = 0; j < pysize; ++i, ++j) {
	PyList_SET_ITEM(keyList, j, swig::from(i->first));
      }
      SWIG_PYTHON_THREAD_END_BLOCK;
      return keyList;
    }
SWIGINTERN PyObject *std_map_Sl_string_Sc_string_Sg__values(std::map< string,string > *self){
      std::map< std::string,std::string,std::less< std::string >,std::allocator< std::pair< std::string const,std::string > > >::size_type size = self->size();
      Py_ssize_t pysize = (size <= (std::map< std::string,std::string,std::less< std::string >,std::allocator< std::pair< std::string const,std::string > > >::size_type) INT_MAX) ? (Py_ssize_t) size : -1;
      SWIG_PYTHON_THREAD_BEGIN_BLOCK;
      if (pysize < 0) {
	PyErr_SetString(PyExc_OverflowError, "map size not valid in python");
	SWIG_PYTHON_THREAD_END_BLOCK;
	return NULL;
      }
      PyObject* valList = PyList_New(pysize);
      std::map< std::string,std::string,std::less< std::string >,std::allocator< std::pair< std::string const,std::string > > >::const_iterator i = self->begin();
      for (Py_ssize_t j = 0; j < pysize; ++i, ++j) {
	PyList_SET_ITEM(valList, j, swig::from(i->second));
      }
      SWIG_PYTHON_THREAD_END_BLOCK;
      return valList;
    }
SWIGINTERN PyObject *std_map_Sl_string_Sc_string_Sg__items(std::map< string,string > *self){
      std::map< std::string,std::string,std::less< std::string >,std::allocator< std::pair< std::string const,std::string > > >::size_type size = self->size();
      Py_ssize_t pysize = (size <= (std::map< std::string,std::string,std::less< std::string >,std::allocator< std::pair< std::string const,std::string > > >::size_type) INT_MAX) ? (Py_ssize_t) size : -1;
      SWIG_PYTHON_THREAD_BEGIN_BLOCK;
      if (pysize < 0) {
	PyErr_SetString(PyExc_OverflowError, "map size not valid in python");
	SWIG_PYTHON_THREAD_END_BLOCK;
	return NULL;
      }    
      PyObject* itemList = PyList_New(pysize);
      std::map< std::string,std::string,std::less< std::string >,std::allocator< std::pair< std::string const,std::string > > >::const_iterator i = self->begin();
      for (Py_ssize_t j = 0; j < pysize; ++i, ++j) {
	PyList_SET_ITEM(itemList, j, swig::from(*i));
      }
      SWIG_PYTHON_THREAD_END_BLOCK;
      return itemList;
    }
SWIGINTERN bool std_map_Sl_string_Sc_string_Sg____contains__(std::map< string,string > *self,std::map< string,string >::key_type const &key){
      return self->find(key) != self->end();
    }
SWIGINTERN swig::SwigPyIterator *std_map_Sl_string_Sc_string_Sg__key_iterator(std::map< string,string > *self,PyObject **PYTHON_SELF){
      return swig::make_output_key_iterator(self->begin(), self->begin(), self->end(), *PYTHON_SELF);
    }
SWIGINTERN swig::SwigPyIterator *std_map_Sl_string_Sc_string_Sg__value_iterator(std::map< string,string > *self,PyObject **PYTHON_SELF){
      return swig::make_output_value_iterator(self->begin(), self->begin(), self->end(), *PYTHON_SELF);
    }
SWIGINTERN void std_map_Sl_string_Sc_string_Sg____setitem____SWIG_0(std::map< string,string > *self,std::map< string,string >::key_type const &key){
      self->erase(key);
    }
SWIGINTERN void std_map_Sl_string_Sc_string_Sg____setitem____SWIG_1(std::map< string,string > *self,std::map< string,string >::key_type const &key,std::map< string,string >::mapped_type const &x){
      (*self)[key] = x;
    }
SWIGINTERN PyObject *std_map_Sl_string_Sc_string_Sg__asdict(std::map< string,string > *self){
      return swig::traits_from< std::map< std::string,std::string,std::less< std::string >,std::allocator< std::pair< std::string const,std::string > > > >::asdict(*self);
    }
SWIGINTERN void std_map_Sl_string_Sc_string_Sg__erase__SWIG_1(std::map< string,string > *self,std::map< string,string >::iterator position){ self->erase(position); }
SWIGINTERN void std_map_Sl_string_Sc_string_Sg__erase__SWIG_2(std::map< string,string > *self,std::map< string,string >::iterator first,std::map< string,string >::iterator last){ self->erase(first, last); }

SWIGINTERN int
SWIG_AsVal_bool (PyObject *obj, bool *val)
{
  int r;
  if (!PyBool_Check(obj))
    return SWIG_ERROR;
  r = PyObject_IsTrue(obj);
  if (r == -1)
    return SWIG_ERROR;
  if (val) *val = r ? true : false;
  return SWIG_OK;
}


  #define SWIG_From_double   PyFloat_FromDouble 


SWIGINTERNINLINE PyObject *
SWIG_From_float  (float value)
{    
  return SWIG_From_double  (value);
}


/* Getting isfinite working pre C99 across multiple platforms is non-trivial. Users can provide SWIG_isfinite on older platforms. */
#ifndef SWIG_isfinite
/* isfinite() is a macro for C99 */
# if defined(isfinite)
#  define SWIG_isfinite(X) (isfinite(X))
# elif defined(__cplusplus) && __cplusplus >= 201103L
/* Use a template so that this works whether isfinite() is std::isfinite() or
 * in the global namespace.  The reality seems to vary between compiler
 * versions.
 *
 * Make sure namespace std exists to avoid compiler warnings.
 *
 * extern "C++" is required as this fragment can end up inside an extern "C" { } block
 */
namespace std { }
extern "C++" template<typename T>
inline int SWIG_isfinite_func(T x) {
  using namespace std;
  return isfinite(x);
}
#  define SWIG_isfinite(X) (SWIG_isfinite_func(X))
# elif defined(__GNUC__) && (__GNUC__ > 4 || (__GNUC__ == 4 && __GNUC_MINOR__ >= 2))
#  define SWIG_isfinite(X) (__builtin_isfinite(X))
# elif defined(__clang__) && defined(__has_builtin)
#  if __has_builtin(__builtin_isfinite)
#   define SWIG_isfinite(X) (__builtin_isfinite(X))
#  endif
# elif defined(_MSC_VER)
#  define SWIG_isfinite(X) (_finite(X))
# elif defined(__sun) && defined(__SVR4)
#  include <ieeefp.h>
#  define SWIG_isfinite(X) (finite(X))
# endif
#endif


/* Accept infinite as a valid float value unless we are unable to check if a value is finite */
#ifdef SWIG_isfinite
# define SWIG_Float_Overflow_Check(X) ((X < -FLT_MAX || X > FLT_MAX) && SWIG_isfinite(X))
#else
# define SWIG_Float_Overflow_Check(X) ((X < -FLT_MAX || X > FLT_MAX))
#endif


SWIGINTERN int
SWIG_AsVal_float (PyObject * obj, float *val)
{
  double v;
  int res = SWIG_AsVal_double (obj, &v);
  if (SWIG_IsOK(res)) {
    if (SWIG_Float_Overflow_Check(v)) {
      return SWIG_OverflowError;
    } else {
      if (val) *val = static_cast< float >(v);
    }
  }  
  return res;
}


  namespace swig {
    template <>  struct traits< pj::SipHeader > {
      typedef pointer_category category;
      static const char* type_name() { return"pj::SipHeader"; }
    };
  }


      namespace swig {
	template <>  struct traits<std::vector< pj::SipHeader, std::allocator< pj::SipHeader > > > {
	  typedef pointer_category category;
	  static const char* type_name() {
	    return "std::vector<" "pj::SipHeader" "," "std::allocator< pj::SipHeader >" " >";
	  }
	};
      }
    
SWIGINTERN swig::SwigPyIterator *std_vector_Sl_pj_SipHeader_Sg__iterator(std::vector< pj::SipHeader > *self,PyObject **PYTHON_SELF){
      return swig::make_output_iterator(self->begin(), self->begin(), self->end(), *PYTHON_SELF);
    }
SWIGINTERN bool std_vector_Sl_pj_SipHeader_Sg____nonzero__(std::vector< pj::SipHeader > const *self){
      return !(self->empty());
    }
SWIGINTERN bool std_vector_Sl_pj_SipHeader_Sg____bool__(std::vector< pj::SipHeader > const *self){
      return !(self->empty());
    }
SWIGINTERN std::vector< pj::SipHeader >::size_type std_vector_Sl_pj_SipHeader_Sg____len__(std::vector< pj::SipHeader > const *self){
      return self->size();
    }
SWIGINTERN std::vector< pj::SipHeader,std::allocator< pj::SipHeader > > *std_vector_Sl_pj_SipHeader_Sg____getslice__(std::vector< pj::SipHeader > *self,std::vector< pj::SipHeader >::difference_type i,std::vector< pj::SipHeader >::difference_type j){
      return swig::getslice(self, i, j, 1);
    }
SWIGINTERN void std_vector_Sl_pj_SipHeader_Sg____setslice____SWIG_0(std::vector< pj::SipHeader > *self,std::vector< pj::SipHeader >::difference_type i,std::vector< pj::SipHeader >::difference_type j){
      swig::setslice(self, i, j, 1, std::vector< pj::SipHeader,std::allocator< pj::SipHeader > >());
    }
SWIGINTERN void std_vector_Sl_pj_SipHeader_Sg____setslice____SWIG_1(std::vector< pj::SipHeader > *self,std::vector< pj::SipHeader >::difference_type i,std::vector< pj::SipHeader >::difference_type j,std::vector< pj::SipHeader,std::allocator< pj::SipHeader > > const &v){
      swig::setslice(self, i, j, 1, v);
    }
SWIGINTERN void std_vector_Sl_pj_SipHeader_Sg____delslice__(std::vector< pj::SipHeader > *self,std::vector< pj::SipHeader >::difference_type i,std::vector< pj::SipHeader >::difference_type j){
      swig::delslice(self, i, j, 1);
    }
SWIGINTERN void std_vector_Sl_pj_SipHeader_Sg____delitem____SWIG_0(std::vector< pj::SipHeader > *self,std::vector< pj::SipHeader >::difference_type i){
      swig::erase(self, swig::getpos(self, i));
    }
SWIGINTERN std::vector< pj::SipHeader,std::allocator< pj::SipHeader > > *std_vector_Sl_pj_SipHeader_Sg____getitem____SWIG_0(std::vector< pj::SipHeader > *self,PySliceObject *slice){
      Py_ssize_t i, j, step;
      if( !PySlice_Check(slice) ) {
        SWIG_Error(SWIG_TypeError, "Slice object expected.");
        return NULL;
      }
      PySlice_GetIndices(SWIGPY_SLICE_ARG(slice), (Py_ssize_t)self->size(), &i, &j, &step);
      std::vector< pj::SipHeader,std::allocator< pj::SipHeader > >::difference_type id = i;
      std::vector< pj::SipHeader,std::allocator< pj::SipHeader > >::difference_type jd = j;
      return swig::getslice(self, id, jd, step);
    }
SWIGINTERN void std_vector_Sl_pj_SipHeader_Sg____setitem____SWIG_0(std::vector< pj::SipHeader > *self,PySliceObject *slice,std::vector< pj::SipHeader,std::allocator< pj::SipHeader > > const &v){
      Py_ssize_t i, j, step;
      if( !PySlice_Check(slice) ) {
        SWIG_Error(SWIG_TypeError, "Slice object expected.");
        return;
      }
      PySlice_GetIndices(SWIGPY_SLICE_ARG(slice), (Py_ssize_t)self->size(), &i, &j, &step);
      std::vector< pj::SipHeader,std::allocator< pj::SipHeader > >::difference_type id = i;
      std::vector< pj::SipHeader,std::allocator< pj::SipHeader > >::difference_type jd = j;
      swig::setslice(self, id, jd, step, v);
    }
SWIGINTERN void std_vector_Sl_pj_SipHeader_Sg____setitem____SWIG_1(std::vector< pj::SipHeader > *self,PySliceObject *slice){
      Py_ssize_t i, j, step;
      if( !PySlice_Check(slice) ) {
        SWIG_Error(SWIG_TypeError, "Slice object expected.");
        return;
      }
      PySlice_GetIndices(SWIGPY_SLICE_ARG(slice), (Py_ssize_t)self->size(), &i, &j, &step);
      std::vector< pj::SipHeader,std::allocator< pj::SipHeader > >::difference_type id = i;
      std::vector< pj::SipHeader,std::allocator< pj::SipHeader > >::difference_type jd = j;
      swig::delslice(self, id, jd, step);
    }
SWIGINTERN void std_vector_Sl_pj_SipHeader_Sg____delitem____SWIG_1(std::vector< pj::SipHeader > *self,PySliceObject *slice){
      Py_ssize_t i, j, step;
      if( !PySlice_Check(slice) ) {
        SWIG_Error(SWIG_TypeError, "Slice object expected.");
        return;
      }
      PySlice_GetIndices(SWIGPY_SLICE_ARG(slice), (Py_ssize_t)self->size(), &i, &j, &step);
      std::vector< pj::SipHeader,std::allocator< pj::SipHeader > >::difference_type id = i;
      std::vector< pj::SipHeader,std::allocator< pj::SipHeader > >::difference_type jd = j;
      swig::delslice(self, id, jd, step);
    }
SWIGINTERN std::vector< pj::SipHeader >::value_type const &std_vector_Sl_pj_SipHeader_Sg____getitem____SWIG_1(std::vector< pj::SipHeader > const *self,std::vector< pj::SipHeader >::difference_type i){
      return *(swig::cgetpos(self, i));
    }
SWIGINTERN void std_vector_Sl_pj_SipHeader_Sg____setitem____SWIG_2(std::vector< pj::SipHeader > *self,std::vector< pj::SipHeader >::difference_type i,std::vector< pj::SipHeader >::value_type const &x){
      *(swig::getpos(self,i)) = x;
    }
SWIGINTERN std::vector< pj::SipHeader >::value_type std_vector_Sl_pj_SipHeader_Sg__pop(std::vector< pj::SipHeader > *self){
      if (self->size() == 0)
	throw std::out_of_range("pop from empty container");
      std::vector< pj::SipHeader,std::allocator< pj::SipHeader > >::value_type x = self->back();
      self->pop_back();
      return x;
    }
SWIGINTERN void std_vector_Sl_pj_SipHeader_Sg__append(std::vector< pj::SipHeader > *self,std::vector< pj::SipHeader >::value_type const &x){
      self->push_back(x);
    }
SWIGINTERN std::vector< pj::SipHeader >::iterator std_vector_Sl_pj_SipHeader_Sg__erase__SWIG_0(std::vector< pj::SipHeader > *self,std::vector< pj::SipHeader >::iterator pos){ return self->erase(pos); }
SWIGINTERN std::vector< pj::SipHeader >::iterator std_vector_Sl_pj_SipHeader_Sg__erase__SWIG_1(std::vector< pj::SipHeader > *self,std::vector< pj::SipHeader >::iterator first,std::vector< pj::SipHeader >::iterator last){ return self->erase(first, last); }
SWIGINTERN std::vector< pj::SipHeader >::iterator std_vector_Sl_pj_SipHeader_Sg__insert__SWIG_0(std::vector< pj::SipHeader > *self,std::vector< pj::SipHeader >::iterator pos,std::vector< pj::SipHeader >::value_type const &x){ return self->insert(pos, x); }
SWIGINTERN void std_vector_Sl_pj_SipHeader_Sg__insert__SWIG_1(std::vector< pj::SipHeader > *self,std::vector< pj::SipHeader >::iterator pos,std::vector< pj::SipHeader >::size_type n,std::vector< pj::SipHeader >::value_type const &x){ self->insert(pos, n, x); }

  namespace swig {
    template <>  struct traits< pj::AuthCredInfo > {
      typedef pointer_category category;
      static const char* type_name() { return"pj::AuthCredInfo"; }
    };
  }


      namespace swig {
	template <>  struct traits<std::vector< pj::AuthCredInfo, std::allocator< pj::AuthCredInfo > > > {
	  typedef pointer_category category;
	  static const char* type_name() {
	    return "std::vector<" "pj::AuthCredInfo" "," "std::allocator< pj::AuthCredInfo >" " >";
	  }
	};
      }
    
SWIGINTERN swig::SwigPyIterator *std_vector_Sl_pj_AuthCredInfo_Sg__iterator(std::vector< pj::AuthCredInfo > *self,PyObject **PYTHON_SELF){
      return swig::make_output_iterator(self->begin(), self->begin(), self->end(), *PYTHON_SELF);
    }
SWIGINTERN bool std_vector_Sl_pj_AuthCredInfo_Sg____nonzero__(std::vector< pj::AuthCredInfo > const *self){
      return !(self->empty());
    }
SWIGINTERN bool std_vector_Sl_pj_AuthCredInfo_Sg____bool__(std::vector< pj::AuthCredInfo > const *self){
      return !(self->empty());
    }
SWIGINTERN std::vector< pj::AuthCredInfo >::size_type std_vector_Sl_pj_AuthCredInfo_Sg____len__(std::vector< pj::AuthCredInfo > const *self){
      return self->size();
    }
SWIGINTERN std::vector< pj::AuthCredInfo,std::allocator< pj::AuthCredInfo > > *std_vector_Sl_pj_AuthCredInfo_Sg____getslice__(std::vector< pj::AuthCredInfo > *self,std::vector< pj::AuthCredInfo >::difference_type i,std::vector< pj::AuthCredInfo >::difference_type j){
      return swig::getslice(self, i, j, 1);
    }
SWIGINTERN void std_vector_Sl_pj_AuthCredInfo_Sg____setslice____SWIG_0(std::vector< pj::AuthCredInfo > *self,std::vector< pj::AuthCredInfo >::difference_type i,std::vector< pj::AuthCredInfo >::difference_type j){
      swig::setslice(self, i, j, 1, std::vector< pj::AuthCredInfo,std::allocator< pj::AuthCredInfo > >());
    }
SWIGINTERN void std_vector_Sl_pj_AuthCredInfo_Sg____setslice____SWIG_1(std::vector< pj::AuthCredInfo > *self,std::vector< pj::AuthCredInfo >::difference_type i,std::vector< pj::AuthCredInfo >::difference_type j,std::vector< pj::AuthCredInfo,std::allocator< pj::AuthCredInfo > > const &v){
      swig::setslice(self, i, j, 1, v);
    }
SWIGINTERN void std_vector_Sl_pj_AuthCredInfo_Sg____delslice__(std::vector< pj::AuthCredInfo > *self,std::vector< pj::AuthCredInfo >::difference_type i,std::vector< pj::AuthCredInfo >::difference_type j){
      swig::delslice(self, i, j, 1);
    }
SWIGINTERN void std_vector_Sl_pj_AuthCredInfo_Sg____delitem____SWIG_0(std::vector< pj::AuthCredInfo > *self,std::vector< pj::AuthCredInfo >::difference_type i){
      swig::erase(self, swig::getpos(self, i));
    }
SWIGINTERN std::vector< pj::AuthCredInfo,std::allocator< pj::AuthCredInfo > > *std_vector_Sl_pj_AuthCredInfo_Sg____getitem____SWIG_0(std::vector< pj::AuthCredInfo > *self,PySliceObject *slice){
      Py_ssize_t i, j, step;
      if( !PySlice_Check(slice) ) {
        SWIG_Error(SWIG_TypeError, "Slice object expected.");
        return NULL;
      }
      PySlice_GetIndices(SWIGPY_SLICE_ARG(slice), (Py_ssize_t)self->size(), &i, &j, &step);
      std::vector< pj::AuthCredInfo,std::allocator< pj::AuthCredInfo > >::difference_type id = i;
      std::vector< pj::AuthCredInfo,std::allocator< pj::AuthCredInfo > >::difference_type jd = j;
      return swig::getslice(self, id, jd, step);
    }
SWIGINTERN void std_vector_Sl_pj_AuthCredInfo_Sg____setitem____SWIG_0(std::vector< pj::AuthCredInfo > *self,PySliceObject *slice,std::vector< pj::AuthCredInfo,std::allocator< pj::AuthCredInfo > > const &v){
      Py_ssize_t i, j, step;
      if( !PySlice_Check(slice) ) {
        SWIG_Error(SWIG_TypeError, "Slice object expected.");
        return;
      }
      PySlice_GetIndices(SWIGPY_SLICE_ARG(slice), (Py_ssize_t)self->size(), &i, &j, &step);
      std::vector< pj::AuthCredInfo,std::allocator< pj::AuthCredInfo > >::difference_type id = i;
      std::vector< pj::AuthCredInfo,std::allocator< pj::AuthCredInfo > >::difference_type jd = j;
      swig::setslice(self, id, jd, step, v);
    }
SWIGINTERN void std_vector_Sl_pj_AuthCredInfo_Sg____setitem____SWIG_1(std::vector< pj::AuthCredInfo > *self,PySliceObject *slice){
      Py_ssize_t i, j, step;
      if( !PySlice_Check(slice) ) {
        SWIG_Error(SWIG_TypeError, "Slice object expected.");
        return;
      }
      PySlice_GetIndices(SWIGPY_SLICE_ARG(slice), (Py_ssize_t)self->size(), &i, &j, &step);
      std::vector< pj::AuthCredInfo,std::allocator< pj::AuthCredInfo > >::difference_type id = i;
      std::vector< pj::AuthCredInfo,std::allocator< pj::AuthCredInfo > >::difference_type jd = j;
      swig::delslice(self, id, jd, step);
    }
SWIGINTERN void std_vector_Sl_pj_AuthCredInfo_Sg____delitem____SWIG_1(std::vector< pj::AuthCredInfo > *self,PySliceObject *slice){
      Py_ssize_t i, j, step;
      if( !PySlice_Check(slice) ) {
        SWIG_Error(SWIG_TypeError, "Slice object expected.");
        return;
      }
      PySlice_GetIndices(SWIGPY_SLICE_ARG(slice), (Py_ssize_t)self->size(), &i, &j, &step);
      std::vector< pj::AuthCredInfo,std::allocator< pj::AuthCredInfo > >::difference_type id = i;
      std::vector< pj::AuthCredInfo,std::allocator< pj::AuthCredInfo > >::difference_type jd = j;
      swig::delslice(self, id, jd, step);
    }
SWIGINTERN std::vector< pj::AuthCredInfo >::value_type const &std_vector_Sl_pj_AuthCredInfo_Sg____getitem____SWIG_1(std::vector< pj::AuthCredInfo > const *self,std::vector< pj::AuthCredInfo >::difference_type i){
      return *(swig::cgetpos(self, i));
    }
SWIGINTERN void std_vector_Sl_pj_AuthCredInfo_Sg____setitem____SWIG_2(std::vector< pj::AuthCredInfo > *self,std::vector< pj::AuthCredInfo >::difference_type i,std::vector< pj::AuthCredInfo >::value_type const &x){
      *(swig::getpos(self,i)) = x;
    }
SWIGINTERN std::vector< pj::AuthCredInfo >::value_type std_vector_Sl_pj_AuthCredInfo_Sg__pop(std::vector< pj::AuthCredInfo > *self){
      if (self->size() == 0)
	throw std::out_of_range("pop from empty container");
      std::vector< pj::AuthCredInfo,std::allocator< pj::AuthCredInfo > >::value_type x = self->back();
      self->pop_back();
      return x;
    }
SWIGINTERN void std_vector_Sl_pj_AuthCredInfo_Sg__append(std::vector< pj::AuthCredInfo > *self,std::vector< pj::AuthCredInfo >::value_type const &x){
      self->push_back(x);
    }
SWIGINTERN std::vector< pj::AuthCredInfo >::iterator std_vector_Sl_pj_AuthCredInfo_Sg__erase__SWIG_0(std::vector< pj::AuthCredInfo > *self,std::vector< pj::AuthCredInfo >::iterator pos){ return self->erase(pos); }
SWIGINTERN std::vector< pj::AuthCredInfo >::iterator std_vector_Sl_pj_AuthCredInfo_Sg__erase__SWIG_1(std::vector< pj::AuthCredInfo > *self,std::vector< pj::AuthCredInfo >::iterator first,std::vector< pj::AuthCredInfo >::iterator last){ return self->erase(first, last); }
SWIGINTERN std::vector< pj::AuthCredInfo >::iterator std_vector_Sl_pj_AuthCredInfo_Sg__insert__SWIG_0(std::vector< pj::AuthCredInfo > *self,std::vector< pj::AuthCredInfo >::iterator pos,std::vector< pj::AuthCredInfo >::value_type const &x){ return self->insert(pos, x); }
SWIGINTERN void std_vector_Sl_pj_AuthCredInfo_Sg__insert__SWIG_1(std::vector< pj::AuthCredInfo > *self,std::vector< pj::AuthCredInfo >::iterator pos,std::vector< pj::AuthCredInfo >::size_type n,std::vector< pj::AuthCredInfo >::value_type const &x){ self->insert(pos, n, x); }

  namespace swig {
    template <>  struct traits< pj::SrtpCrypto > {
      typedef pointer_category category;
      static const char* type_name() { return"pj::SrtpCrypto"; }
    };
  }


      namespace swig {
	template <>  struct traits<std::vector< pj::SrtpCrypto, std::allocator< pj::SrtpCrypto > > > {
	  typedef pointer_category category;
	  static const char* type_name() {
	    return "std::vector<" "pj::SrtpCrypto" "," "std::allocator< pj::SrtpCrypto >" " >";
	  }
	};
      }
    
SWIGINTERN swig::SwigPyIterator *std_vector_Sl_pj_SrtpCrypto_Sg__iterator(std::vector< pj::SrtpCrypto > *self,PyObject **PYTHON_SELF){
      return swig::make_output_iterator(self->begin(), self->begin(), self->end(), *PYTHON_SELF);
    }
SWIGINTERN bool std_vector_Sl_pj_SrtpCrypto_Sg____nonzero__(std::vector< pj::SrtpCrypto > const *self){
      return !(self->empty());
    }
SWIGINTERN bool std_vector_Sl_pj_SrtpCrypto_Sg____bool__(std::vector< pj::SrtpCrypto > const *self){
      return !(self->empty());
    }
SWIGINTERN std::vector< pj::SrtpCrypto >::size_type std_vector_Sl_pj_SrtpCrypto_Sg____len__(std::vector< pj::SrtpCrypto > const *self){
      return self->size();
    }
SWIGINTERN std::vector< pj::SrtpCrypto,std::allocator< pj::SrtpCrypto > > *std_vector_Sl_pj_SrtpCrypto_Sg____getslice__(std::vector< pj::SrtpCrypto > *self,std::vector< pj::SrtpCrypto >::difference_type i,std::vector< pj::SrtpCrypto >::difference_type j){
      return swig::getslice(self, i, j, 1);
    }
SWIGINTERN void std_vector_Sl_pj_SrtpCrypto_Sg____setslice____SWIG_0(std::vector< pj::SrtpCrypto > *self,std::vector< pj::SrtpCrypto >::difference_type i,std::vector< pj::SrtpCrypto >::difference_type j){
      swig::setslice(self, i, j, 1, std::vector< pj::SrtpCrypto,std::allocator< pj::SrtpCrypto > >());
    }
SWIGINTERN void std_vector_Sl_pj_SrtpCrypto_Sg____setslice____SWIG_1(std::vector< pj::SrtpCrypto > *self,std::vector< pj::SrtpCrypto >::difference_type i,std::vector< pj::SrtpCrypto >::difference_type j,std::vector< pj::SrtpCrypto,std::allocator< pj::SrtpCrypto > > const &v){
      swig::setslice(self, i, j, 1, v);
    }
SWIGINTERN void std_vector_Sl_pj_SrtpCrypto_Sg____delslice__(std::vector< pj::SrtpCrypto > *self,std::vector< pj::SrtpCrypto >::difference_type i,std::vector< pj::SrtpCrypto >::difference_type j){
      swig::delslice(self, i, j, 1);
    }
SWIGINTERN void std_vector_Sl_pj_SrtpCrypto_Sg____delitem____SWIG_0(std::vector< pj::SrtpCrypto > *self,std::vector< pj::SrtpCrypto >::difference_type i){
      swig::erase(self, swig::getpos(self, i));
    }
SWIGINTERN std::vector< pj::SrtpCrypto,std::allocator< pj::SrtpCrypto > > *std_vector_Sl_pj_SrtpCrypto_Sg____getitem____SWIG_0(std::vector< pj::SrtpCrypto > *self,PySliceObject *slice){
      Py_ssize_t i, j, step;
      if( !PySlice_Check(slice) ) {
        SWIG_Error(SWIG_TypeError, "Slice object expected.");
        return NULL;
      }
      PySlice_GetIndices(SWIGPY_SLICE_ARG(slice), (Py_ssize_t)self->size(), &i, &j, &step);
      std::vector< pj::SrtpCrypto,std::allocator< pj::SrtpCrypto > >::difference_type id = i;
      std::vector< pj::SrtpCrypto,std::allocator< pj::SrtpCrypto > >::difference_type jd = j;
      return swig::getslice(self, id, jd, step);
    }
SWIGINTERN void std_vector_Sl_pj_SrtpCrypto_Sg____setitem____SWIG_0(std::vector< pj::SrtpCrypto > *self,PySliceObject *slice,std::vector< pj::SrtpCrypto,std::allocator< pj::SrtpCrypto > > const &v){
      Py_ssize_t i, j, step;
      if( !PySlice_Check(slice) ) {
        SWIG_Error(SWIG_TypeError, "Slice object expected.");
        return;
      }
      PySlice_GetIndices(SWIGPY_SLICE_ARG(slice), (Py_ssize_t)self->size(), &i, &j, &step);
      std::vector< pj::SrtpCrypto,std::allocator< pj::SrtpCrypto > >::difference_type id = i;
      std::vector< pj::SrtpCrypto,std::allocator< pj::SrtpCrypto > >::difference_type jd = j;
      swig::setslice(self, id, jd, step, v);
    }
SWIGINTERN void std_vector_Sl_pj_SrtpCrypto_Sg____setitem____SWIG_1(std::vector< pj::SrtpCrypto > *self,PySliceObject *slice){
      Py_ssize_t i, j, step;
      if( !PySlice_Check(slice) ) {
        SWIG_Error(SWIG_TypeError, "Slice object expected.");
        return;
      }
      PySlice_GetIndices(SWIGPY_SLICE_ARG(slice), (Py_ssize_t)self->size(), &i, &j, &step);
      std::vector< pj::SrtpCrypto,std::allocator< pj::SrtpCrypto > >::difference_type id = i;
      std::vector< pj::SrtpCrypto,std::allocator< pj::SrtpCrypto > >::difference_type jd = j;
      swig::delslice(self, id, jd, step);
    }
SWIGINTERN void std_vector_Sl_pj_SrtpCrypto_Sg____delitem____SWIG_1(std::vector< pj::SrtpCrypto > *self,PySliceObject *slice){
      Py_ssize_t i, j, step;
      if( !PySlice_Check(slice) ) {
        SWIG_Error(SWIG_TypeError, "Slice object expected.");
        return;
      }
      PySlice_GetIndices(SWIGPY_SLICE_ARG(slice), (Py_ssize_t)self->size(), &i, &j, &step);
      std::vector< pj::SrtpCrypto,std::allocator< pj::SrtpCrypto > >::difference_type id = i;
      std::vector< pj::SrtpCrypto,std::allocator< pj::SrtpCrypto > >::difference_type jd = j;
      swig::delslice(self, id, jd, step);
    }
SWIGINTERN std::vector< pj::SrtpCrypto >::value_type const &std_vector_Sl_pj_SrtpCrypto_Sg____getitem____SWIG_1(std::vector< pj::SrtpCrypto > const *self,std::vector< pj::SrtpCrypto >::difference_type i){
      return *(swig::cgetpos(self, i));
    }
SWIGINTERN void std_vector_Sl_pj_SrtpCrypto_Sg____setitem____SWIG_2(std::vector< pj::SrtpCrypto > *self,std::vector< pj::SrtpCrypto >::difference_type i,std::vector< pj::SrtpCrypto >::value_type const &x){
      *(swig::getpos(self,i)) = x;
    }
SWIGINTERN std::vector< pj::SrtpCrypto >::value_type std_vector_Sl_pj_SrtpCrypto_Sg__pop(std::vector< pj::SrtpCrypto > *self){
      if (self->size() == 0)
	throw std::out_of_range("pop from empty container");
      std::vector< pj::SrtpCrypto,std::allocator< pj::SrtpCrypto > >::value_type x = self->back();
      self->pop_back();
      return x;
    }
SWIGINTERN void std_vector_Sl_pj_SrtpCrypto_Sg__append(std::vector< pj::SrtpCrypto > *self,std::vector< pj::SrtpCrypto >::value_type const &x){
      self->push_back(x);
    }
SWIGINTERN std::vector< pj::SrtpCrypto >::iterator std_vector_Sl_pj_SrtpCrypto_Sg__erase__SWIG_0(std::vector< pj::SrtpCrypto > *self,std::vector< pj::SrtpCrypto >::iterator pos){ return self->erase(pos); }
SWIGINTERN std::vector< pj::SrtpCrypto >::iterator std_vector_Sl_pj_SrtpCrypto_Sg__erase__SWIG_1(std::vector< pj::SrtpCrypto > *self,std::vector< pj::SrtpCrypto >::iterator first,std::vector< pj::SrtpCrypto >::iterator last){ return self->erase(first, last); }
SWIGINTERN std::vector< pj::SrtpCrypto >::iterator std_vector_Sl_pj_SrtpCrypto_Sg__insert__SWIG_0(std::vector< pj::SrtpCrypto > *self,std::vector< pj::SrtpCrypto >::iterator pos,std::vector< pj::SrtpCrypto >::value_type const &x){ return self->insert(pos, x); }
SWIGINTERN void std_vector_Sl_pj_SrtpCrypto_Sg__insert__SWIG_1(std::vector< pj::SrtpCrypto > *self,std::vector< pj::SrtpCrypto >::iterator pos,std::vector< pj::SrtpCrypto >::size_type n,std::vector< pj::SrtpCrypto >::value_type const &x){ self->insert(pos, n, x); }

  namespace swig {
    template <>  struct traits< pj::SipMultipartPart > {
      typedef pointer_category category;
      static const char* type_name() { return"pj::SipMultipartPart"; }
    };
  }


      namespace swig {
	template <>  struct traits<std::vector< pj::SipMultipartPart, std::allocator< pj::SipMultipartPart > > > {
	  typedef pointer_category category;
	  static const char* type_name() {
	    return "std::vector<" "pj::SipMultipartPart" "," "std::allocator< pj::SipMultipartPart >" " >";
	  }
	};
      }
    
SWIGINTERN swig::SwigPyIterator *std_vector_Sl_pj_SipMultipartPart_Sg__iterator(std::vector< pj::SipMultipartPart > *self,PyObject **PYTHON_SELF){
      return swig::make_output_iterator(self->begin(), self->begin(), self->end(), *PYTHON_SELF);
    }
SWIGINTERN bool std_vector_Sl_pj_SipMultipartPart_Sg____nonzero__(std::vector< pj::SipMultipartPart > const *self){
      return !(self->empty());
    }
SWIGINTERN bool std_vector_Sl_pj_SipMultipartPart_Sg____bool__(std::vector< pj::SipMultipartPart > const *self){
      return !(self->empty());
    }
SWIGINTERN std::vector< pj::SipMultipartPart >::size_type std_vector_Sl_pj_SipMultipartPart_Sg____len__(std::vector< pj::SipMultipartPart > const *self){
      return self->size();
    }
SWIGINTERN std::vector< pj::SipMultipartPart,std::allocator< pj::SipMultipartPart > > *std_vector_Sl_pj_SipMultipartPart_Sg____getslice__(std::vector< pj::SipMultipartPart > *self,std::vector< pj::SipMultipartPart >::difference_type i,std::vector< pj::SipMultipartPart >::difference_type j){
      return swig::getslice(self, i, j, 1);
    }
SWIGINTERN void std_vector_Sl_pj_SipMultipartPart_Sg____setslice____SWIG_0(std::vector< pj::SipMultipartPart > *self,std::vector< pj::SipMultipartPart >::difference_type i,std::vector< pj::SipMultipartPart >::difference_type j){
      swig::setslice(self, i, j, 1, std::vector< pj::SipMultipartPart,std::allocator< pj::SipMultipartPart > >());
    }
SWIGINTERN void std_vector_Sl_pj_SipMultipartPart_Sg____setslice____SWIG_1(std::vector< pj::SipMultipartPart > *self,std::vector< pj::SipMultipartPart >::difference_type i,std::vector< pj::SipMultipartPart >::difference_type j,std::vector< pj::SipMultipartPart,std::allocator< pj::SipMultipartPart > > const &v){
      swig::setslice(self, i, j, 1, v);
    }
SWIGINTERN void std_vector_Sl_pj_SipMultipartPart_Sg____delslice__(std::vector< pj::SipMultipartPart > *self,std::vector< pj::SipMultipartPart >::difference_type i,std::vector< pj::SipMultipartPart >::difference_type j){
      swig::delslice(self, i, j, 1);
    }
SWIGINTERN void std_vector_Sl_pj_SipMultipartPart_Sg____delitem____SWIG_0(std::vector< pj::SipMultipartPart > *self,std::vector< pj::SipMultipartPart >::difference_type i){
      swig::erase(self, swig::getpos(self, i));
    }
SWIGINTERN std::vector< pj::SipMultipartPart,std::allocator< pj::SipMultipartPart > > *std_vector_Sl_pj_SipMultipartPart_Sg____getitem____SWIG_0(std::vector< pj::SipMultipartPart > *self,PySliceObject *slice){
      Py_ssize_t i, j, step;
      if( !PySlice_Check(slice) ) {
        SWIG_Error(SWIG_TypeError, "Slice object expected.");
        return NULL;
      }
      PySlice_GetIndices(SWIGPY_SLICE_ARG(slice), (Py_ssize_t)self->size(), &i, &j, &step);
      std::vector< pj::SipMultipartPart,std::allocator< pj::SipMultipartPart > >::difference_type id = i;
      std::vector< pj::SipMultipartPart,std::allocator< pj::SipMultipartPart > >::difference_type jd = j;
      return swig::getslice(self, id, jd, step);
    }
SWIGINTERN void std_vector_Sl_pj_SipMultipartPart_Sg____setitem____SWIG_0(std::vector< pj::SipMultipartPart > *self,PySliceObject *slice,std::vector< pj::SipMultipartPart,std::allocator< pj::SipMultipartPart > > const &v){
      Py_ssize_t i, j, step;
      if( !PySlice_Check(slice) ) {
        SWIG_Error(SWIG_TypeError, "Slice object expected.");
        return;
      }
      PySlice_GetIndices(SWIGPY_SLICE_ARG(slice), (Py_ssize_t)self->size(), &i, &j, &step);
      std::vector< pj::SipMultipartPart,std::allocator< pj::SipMultipartPart > >::difference_type id = i;
      std::vector< pj::SipMultipartPart,std::allocator< pj::SipMultipartPart > >::difference_type jd = j;
      swig::setslice(self, id, jd, step, v);
    }
SWIGINTERN void std_vector_Sl_pj_SipMultipartPart_Sg____setitem____SWIG_1(std::vector< pj::SipMultipartPart > *self,PySliceObject *slice){
      Py_ssize_t i, j, step;
      if( !PySlice_Check(slice) ) {
        SWIG_Error(SWIG_TypeError, "Slice object expected.");
        return;
      }
      PySlice_GetIndices(SWIGPY_SLICE_ARG(slice), (Py_ssize_t)self->size(), &i, &j, &step);
      std::vector< pj::SipMultipartPart,std::allocator< pj::SipMultipartPart > >::difference_type id = i;
      std::vector< pj::SipMultipartPart,std::allocator< pj::SipMultipartPart > >::difference_type jd = j;
      swig::delslice(self, id, jd, step);
    }
SWIGINTERN void std_vector_Sl_pj_SipMultipartPart_Sg____delitem____SWIG_1(std::vector< pj::SipMultipartPart > *self,PySliceObject *slice){
      Py_ssize_t i, j, step;
      if( !PySlice_Check(slice) ) {
        SWIG_Error(SWIG_TypeError, "Slice object expected.");
        return;
      }
      PySlice_GetIndices(SWIGPY_SLICE_ARG(slice), (Py_ssize_t)self->size(), &i, &j, &step);
      std::vector< pj::SipMultipartPart,std::allocator< pj::SipMultipartPart > >::difference_type id = i;
      std::vector< pj::SipMultipartPart,std::allocator< pj::SipMultipartPart > >::difference_type jd = j;
      swig::delslice(self, id, jd, step);
    }
SWIGINTERN std::vector< pj::SipMultipartPart >::value_type const &std_vector_Sl_pj_SipMultipartPart_Sg____getitem____SWIG_1(std::vector< pj::SipMultipartPart > const *self,std::vector< pj::SipMultipartPart >::difference_type i){
      return *(swig::cgetpos(self, i));
    }
SWIGINTERN void std_vector_Sl_pj_SipMultipartPart_Sg____setitem____SWIG_2(std::vector< pj::SipMultipartPart > *self,std::vector< pj::SipMultipartPart >::difference_type i,std::vector< pj::SipMultipartPart >::value_type const &x){
      *(swig::getpos(self,i)) = x;
    }
SWIGINTERN std::vector< pj::SipMultipartPart >::value_type std_vector_Sl_pj_SipMultipartPart_Sg__pop(std::vector< pj::SipMultipartPart > *self){
      if (self->size() == 0)
	throw std::out_of_range("pop from empty container");
      std::vector< pj::SipMultipartPart,std::allocator< pj::SipMultipartPart > >::value_type x = self->back();
      self->pop_back();
      return x;
    }
SWIGINTERN void std_vector_Sl_pj_SipMultipartPart_Sg__append(std::vector< pj::SipMultipartPart > *self,std::vector< pj::SipMultipartPart >::value_type const &x){
      self->push_back(x);
    }
SWIGINTERN std::vector< pj::SipMultipartPart >::iterator std_vector_Sl_pj_SipMultipartPart_Sg__erase__SWIG_0(std::vector< pj::SipMultipartPart > *self,std::vector< pj::SipMultipartPart >::iterator pos){ return self->erase(pos); }
SWIGINTERN std::vector< pj::SipMultipartPart >::iterator std_vector_Sl_pj_SipMultipartPart_Sg__erase__SWIG_1(std::vector< pj::SipMultipartPart > *self,std::vector< pj::SipMultipartPart >::iterator first,std::vector< pj::SipMultipartPart >::iterator last){ return self->erase(first, last); }
SWIGINTERN std::vector< pj::SipMultipartPart >::iterator std_vector_Sl_pj_SipMultipartPart_Sg__insert__SWIG_0(std::vector< pj::SipMultipartPart > *self,std::vector< pj::SipMultipartPart >::iterator pos,std::vector< pj::SipMultipartPart >::value_type const &x){ return self->insert(pos, x); }
SWIGINTERN void std_vector_Sl_pj_SipMultipartPart_Sg__insert__SWIG_1(std::vector< pj::SipMultipartPart > *self,std::vector< pj::SipMultipartPart >::iterator pos,std::vector< pj::SipMultipartPart >::size_type n,std::vector< pj::SipMultipartPart >::value_type const &x){ self->insert(pos, n, x); }

  namespace swig {
    template <>  struct traits< pj::Buddy > {
      typedef pointer_category category;
      static const char* type_name() { return"pj::Buddy"; }
    };
  }


      namespace swig {
	template <>  struct traits<std::vector< pj::Buddy*, std::allocator< pj::Buddy * > > > {
	  typedef value_category category;
	  static const char* type_name() {
	    return "std::vector<" "pj::Buddy" " *," "std::allocator< pj::Buddy * >" " >";
	  }
	};
      }
    
SWIGINTERN swig::SwigPyIterator *std_vector_Sl_pj_Buddy_Sm__Sg__iterator(std::vector< pj::Buddy * > *self,PyObject **PYTHON_SELF){
      return swig::make_output_iterator(self->begin(), self->begin(), self->end(), *PYTHON_SELF);
    }
SWIGINTERN bool std_vector_Sl_pj_Buddy_Sm__Sg____nonzero__(std::vector< pj::Buddy * > const *self){
      return !(self->empty());
    }
SWIGINTERN bool std_vector_Sl_pj_Buddy_Sm__Sg____bool__(std::vector< pj::Buddy * > const *self){
      return !(self->empty());
    }
SWIGINTERN std::vector< pj::Buddy * >::size_type std_vector_Sl_pj_Buddy_Sm__Sg____len__(std::vector< pj::Buddy * > const *self){
      return self->size();
    }
SWIGINTERN std::vector< pj::Buddy *,std::allocator< pj::Buddy * > > *std_vector_Sl_pj_Buddy_Sm__Sg____getslice__(std::vector< pj::Buddy * > *self,std::vector< pj::Buddy * >::difference_type i,std::vector< pj::Buddy * >::difference_type j){
      return swig::getslice(self, i, j, 1);
    }
SWIGINTERN void std_vector_Sl_pj_Buddy_Sm__Sg____setslice____SWIG_0(std::vector< pj::Buddy * > *self,std::vector< pj::Buddy * >::difference_type i,std::vector< pj::Buddy * >::difference_type j){
      swig::setslice(self, i, j, 1, std::vector< pj::Buddy*,std::allocator< pj::Buddy * > >());
    }
SWIGINTERN void std_vector_Sl_pj_Buddy_Sm__Sg____setslice____SWIG_1(std::vector< pj::Buddy * > *self,std::vector< pj::Buddy * >::difference_type i,std::vector< pj::Buddy * >::difference_type j,std::vector< pj::Buddy *,std::allocator< pj::Buddy * > > const &v){
      swig::setslice(self, i, j, 1, v);
    }
SWIGINTERN void std_vector_Sl_pj_Buddy_Sm__Sg____delslice__(std::vector< pj::Buddy * > *self,std::vector< pj::Buddy * >::difference_type i,std::vector< pj::Buddy * >::difference_type j){
      swig::delslice(self, i, j, 1);
    }
SWIGINTERN void std_vector_Sl_pj_Buddy_Sm__Sg____delitem____SWIG_0(std::vector< pj::Buddy * > *self,std::vector< pj::Buddy * >::difference_type i){
      swig::erase(self, swig::getpos(self, i));
    }
SWIGINTERN std::vector< pj::Buddy *,std::allocator< pj::Buddy * > > *std_vector_Sl_pj_Buddy_Sm__Sg____getitem____SWIG_0(std::vector< pj::Buddy * > *self,PySliceObject *slice){
      Py_ssize_t i, j, step;
      if( !PySlice_Check(slice) ) {
        SWIG_Error(SWIG_TypeError, "Slice object expected.");
        return NULL;
      }
      PySlice_GetIndices(SWIGPY_SLICE_ARG(slice), (Py_ssize_t)self->size(), &i, &j, &step);
      std::vector< pj::Buddy*,std::allocator< pj::Buddy * > >::difference_type id = i;
      std::vector< pj::Buddy*,std::allocator< pj::Buddy * > >::difference_type jd = j;
      return swig::getslice(self, id, jd, step);
    }
SWIGINTERN void std_vector_Sl_pj_Buddy_Sm__Sg____setitem____SWIG_0(std::vector< pj::Buddy * > *self,PySliceObject *slice,std::vector< pj::Buddy *,std::allocator< pj::Buddy * > > const &v){
      Py_ssize_t i, j, step;
      if( !PySlice_Check(slice) ) {
        SWIG_Error(SWIG_TypeError, "Slice object expected.");
        return;
      }
      PySlice_GetIndices(SWIGPY_SLICE_ARG(slice), (Py_ssize_t)self->size(), &i, &j, &step);
      std::vector< pj::Buddy*,std::allocator< pj::Buddy * > >::difference_type id = i;
      std::vector< pj::Buddy*,std::allocator< pj::Buddy * > >::difference_type jd = j;
      swig::setslice(self, id, jd, step, v);
    }
SWIGINTERN void std_vector_Sl_pj_Buddy_Sm__Sg____setitem____SWIG_1(std::vector< pj::Buddy * > *self,PySliceObject *slice){
      Py_ssize_t i, j, step;
      if( !PySlice_Check(slice) ) {
        SWIG_Error(SWIG_TypeError, "Slice object expected.");
        return;
      }
      PySlice_GetIndices(SWIGPY_SLICE_ARG(slice), (Py_ssize_t)self->size(), &i, &j, &step);
      std::vector< pj::Buddy*,std::allocator< pj::Buddy * > >::difference_type id = i;
      std::vector< pj::Buddy*,std::allocator< pj::Buddy * > >::difference_type jd = j;
      swig::delslice(self, id, jd, step);
    }
SWIGINTERN void std_vector_Sl_pj_Buddy_Sm__Sg____delitem____SWIG_1(std::vector< pj::Buddy * > *self,PySliceObject *slice){
      Py_ssize_t i, j, step;
      if( !PySlice_Check(slice) ) {
        SWIG_Error(SWIG_TypeError, "Slice object expected.");
        return;
      }
      PySlice_GetIndices(SWIGPY_SLICE_ARG(slice), (Py_ssize_t)self->size(), &i, &j, &step);
      std::vector< pj::Buddy*,std::allocator< pj::Buddy * > >::difference_type id = i;
      std::vector< pj::Buddy*,std::allocator< pj::Buddy * > >::difference_type jd = j;
      swig::delslice(self, id, jd, step);
    }
SWIGINTERN std::vector< pj::Buddy * >::value_type std_vector_Sl_pj_Buddy_Sm__Sg____getitem____SWIG_1(std::vector< pj::Buddy * > *self,std::vector< pj::Buddy * >::difference_type i){
      return *(swig::cgetpos(self, i));
    }
SWIGINTERN void std_vector_Sl_pj_Buddy_Sm__Sg____setitem____SWIG_2(std::vector< pj::Buddy * > *self,std::vector< pj::Buddy * >::difference_type i,std::vector< pj::Buddy * >::value_type x){
      *(swig::getpos(self,i)) = x;
    }
SWIGINTERN std::vector< pj::Buddy * >::value_type std_vector_Sl_pj_Buddy_Sm__Sg__pop(std::vector< pj::Buddy * > *self){
      if (self->size() == 0)
	throw std::out_of_range("pop from empty container");
      std::vector< pj::Buddy*,std::allocator< pj::Buddy * > >::value_type x = self->back();
      self->pop_back();
      return x;
    }
SWIGINTERN void std_vector_Sl_pj_Buddy_Sm__Sg__append(std::vector< pj::Buddy * > *self,std::vector< pj::Buddy * >::value_type x){
      self->push_back(x);
    }
SWIGINTERN std::vector< pj::Buddy * >::iterator std_vector_Sl_pj_Buddy_Sm__Sg__erase__SWIG_0(std::vector< pj::Buddy * > *self,std::vector< pj::Buddy * >::iterator pos){ return self->erase(pos); }
SWIGINTERN std::vector< pj::Buddy * >::iterator std_vector_Sl_pj_Buddy_Sm__Sg__erase__SWIG_1(std::vector< pj::Buddy * > *self,std::vector< pj::Buddy * >::iterator first,std::vector< pj::Buddy * >::iterator last){ return self->erase(first, last); }
SWIGINTERN std::vector< pj::Buddy * >::iterator std_vector_Sl_pj_Buddy_Sm__Sg__insert__SWIG_0(std::vector< pj::Buddy * > *self,std::vector< pj::Buddy * >::iterator pos,std::vector< pj::Buddy * >::value_type x){ return self->insert(pos, x); }
SWIGINTERN void std_vector_Sl_pj_Buddy_Sm__Sg__insert__SWIG_1(std::vector< pj::Buddy * > *self,std::vector< pj::Buddy * >::iterator pos,std::vector< pj::Buddy * >::size_type n,std::vector< pj::Buddy * >::value_type x){ self->insert(pos, n, x); }

      namespace swig {
	template <>  struct traits<std::vector< pj::Buddy, std::allocator< pj::Buddy > > > {
	  typedef pointer_category category;
	  static const char* type_name() {
	    return "std::vector<" "pj::Buddy" "," "std::allocator< pj::Buddy >" " >";
	  }
	};
      }
    
SWIGINTERN swig::SwigPyIterator *std_vector_Sl_pj_Buddy_Sg__iterator(std::vector< pj::Buddy > *self,PyObject **PYTHON_SELF){
      return swig::make_output_iterator(self->begin(), self->begin(), self->end(), *PYTHON_SELF);
    }
SWIGINTERN bool std_vector_Sl_pj_Buddy_Sg____nonzero__(std::vector< pj::Buddy > const *self){
      return !(self->empty());
    }
SWIGINTERN bool std_vector_Sl_pj_Buddy_Sg____bool__(std::vector< pj::Buddy > const *self){
      return !(self->empty());
    }
SWIGINTERN std::vector< pj::Buddy >::size_type std_vector_Sl_pj_Buddy_Sg____len__(std::vector< pj::Buddy > const *self){
      return self->size();
    }
SWIGINTERN std::vector< pj::Buddy,std::allocator< pj::Buddy > > *std_vector_Sl_pj_Buddy_Sg____getslice__(std::vector< pj::Buddy > *self,std::vector< pj::Buddy >::difference_type i,std::vector< pj::Buddy >::difference_type j){
      return swig::getslice(self, i, j, 1);
    }
SWIGINTERN void std_vector_Sl_pj_Buddy_Sg____setslice____SWIG_0(std::vector< pj::Buddy > *self,std::vector< pj::Buddy >::difference_type i,std::vector< pj::Buddy >::difference_type j){
      swig::setslice(self, i, j, 1, std::vector< pj::Buddy,std::allocator< pj::Buddy > >());
    }
SWIGINTERN void std_vector_Sl_pj_Buddy_Sg____setslice____SWIG_1(std::vector< pj::Buddy > *self,std::vector< pj::Buddy >::difference_type i,std::vector< pj::Buddy >::difference_type j,std::vector< pj::Buddy,std::allocator< pj::Buddy > > const &v){
      swig::setslice(self, i, j, 1, v);
    }
SWIGINTERN void std_vector_Sl_pj_Buddy_Sg____delslice__(std::vector< pj::Buddy > *self,std::vector< pj::Buddy >::difference_type i,std::vector< pj::Buddy >::difference_type j){
      swig::delslice(self, i, j, 1);
    }
SWIGINTERN void std_vector_Sl_pj_Buddy_Sg____delitem____SWIG_0(std::vector< pj::Buddy > *self,std::vector< pj::Buddy >::difference_type i){
      swig::erase(self, swig::getpos(self, i));
    }
SWIGINTERN std::vector< pj::Buddy,std::allocator< pj::Buddy > > *std_vector_Sl_pj_Buddy_Sg____getitem____SWIG_0(std::vector< pj::Buddy > *self,PySliceObject *slice){
      Py_ssize_t i, j, step;
      if( !PySlice_Check(slice) ) {
        SWIG_Error(SWIG_TypeError, "Slice object expected.");
        return NULL;
      }
      PySlice_GetIndices(SWIGPY_SLICE_ARG(slice), (Py_ssize_t)self->size(), &i, &j, &step);
      std::vector< pj::Buddy,std::allocator< pj::Buddy > >::difference_type id = i;
      std::vector< pj::Buddy,std::allocator< pj::Buddy > >::difference_type jd = j;
      return swig::getslice(self, id, jd, step);
    }
SWIGINTERN void std_vector_Sl_pj_Buddy_Sg____setitem____SWIG_0(std::vector< pj::Buddy > *self,PySliceObject *slice,std::vector< pj::Buddy,std::allocator< pj::Buddy > > const &v){
      Py_ssize_t i, j, step;
      if( !PySlice_Check(slice) ) {
        SWIG_Error(SWIG_TypeError, "Slice object expected.");
        return;
      }
      PySlice_GetIndices(SWIGPY_SLICE_ARG(slice), (Py_ssize_t)self->size(), &i, &j, &step);
      std::vector< pj::Buddy,std::allocator< pj::Buddy > >::difference_type id = i;
      std::vector< pj::Buddy,std::allocator< pj::Buddy > >::difference_type jd = j;
      swig::setslice(self, id, jd, step, v);
    }
SWIGINTERN void std_vector_Sl_pj_Buddy_Sg____setitem____SWIG_1(std::vector< pj::Buddy > *self,PySliceObject *slice){
      Py_ssize_t i, j, step;
      if( !PySlice_Check(slice) ) {
        SWIG_Error(SWIG_TypeError, "Slice object expected.");
        return;
      }
      PySlice_GetIndices(SWIGPY_SLICE_ARG(slice), (Py_ssize_t)self->size(), &i, &j, &step);
      std::vector< pj::Buddy,std::allocator< pj::Buddy > >::difference_type id = i;
      std::vector< pj::Buddy,std::allocator< pj::Buddy > >::difference_type jd = j;
      swig::delslice(self, id, jd, step);
    }
SWIGINTERN void std_vector_Sl_pj_Buddy_Sg____delitem____SWIG_1(std::vector< pj::Buddy > *self,PySliceObject *slice){
      Py_ssize_t i, j, step;
      if( !PySlice_Check(slice) ) {
        SWIG_Error(SWIG_TypeError, "Slice object expected.");
        return;
      }
      PySlice_GetIndices(SWIGPY_SLICE_ARG(slice), (Py_ssize_t)self->size(), &i, &j, &step);
      std::vector< pj::Buddy,std::allocator< pj::Buddy > >::difference_type id = i;
      std::vector< pj::Buddy,std::allocator< pj::Buddy > >::difference_type jd = j;
      swig::delslice(self, id, jd, step);
    }
SWIGINTERN std::vector< pj::Buddy >::value_type const &std_vector_Sl_pj_Buddy_Sg____getitem____SWIG_1(std::vector< pj::Buddy > const *self,std::vector< pj::Buddy >::difference_type i){
      return *(swig::cgetpos(self, i));
    }
SWIGINTERN void std_vector_Sl_pj_Buddy_Sg____setitem____SWIG_2(std::vector< pj::Buddy > *self,std::vector< pj::Buddy >::difference_type i,std::vector< pj::Buddy >::value_type const &x){
      *(swig::getpos(self,i)) = x;
    }
SWIGINTERN std::vector< pj::Buddy >::value_type std_vector_Sl_pj_Buddy_Sg__pop(std::vector< pj::Buddy > *self){
      if (self->size() == 0)
	throw std::out_of_range("pop from empty container");
      std::vector< pj::Buddy,std::allocator< pj::Buddy > >::value_type x = self->back();
      self->pop_back();
      return x;
    }
SWIGINTERN void std_vector_Sl_pj_Buddy_Sg__append(std::vector< pj::Buddy > *self,std::vector< pj::Buddy >::value_type const &x){
      self->push_back(x);
    }
SWIGINTERN std::vector< pj::Buddy >::iterator std_vector_Sl_pj_Buddy_Sg__erase__SWIG_0(std::vector< pj::Buddy > *self,std::vector< pj::Buddy >::iterator pos){ return self->erase(pos); }
SWIGINTERN std::vector< pj::Buddy >::iterator std_vector_Sl_pj_Buddy_Sg__erase__SWIG_1(std::vector< pj::Buddy > *self,std::vector< pj::Buddy >::iterator first,std::vector< pj::Buddy >::iterator last){ return self->erase(first, last); }
SWIGINTERN std::vector< pj::Buddy >::iterator std_vector_Sl_pj_Buddy_Sg__insert__SWIG_0(std::vector< pj::Buddy > *self,std::vector< pj::Buddy >::iterator pos,std::vector< pj::Buddy >::value_type const &x){ return self->insert(pos, x); }
SWIGINTERN void std_vector_Sl_pj_Buddy_Sg__insert__SWIG_1(std::vector< pj::Buddy > *self,std::vector< pj::Buddy >::iterator pos,std::vector< pj::Buddy >::size_type n,std::vector< pj::Buddy >::value_type const &x){ self->insert(pos, n, x); }

  namespace swig {
    template <>  struct traits< pj::AudioMedia > {
      typedef pointer_category category;
      static const char* type_name() { return"pj::AudioMedia"; }
    };
  }


      namespace swig {
	template <>  struct traits<std::vector< pj::AudioMedia*, std::allocator< pj::AudioMedia * > > > {
	  typedef value_category category;
	  static const char* type_name() {
	    return "std::vector<" "pj::AudioMedia" " *," "std::allocator< pj::AudioMedia * >" " >";
	  }
	};
      }
    
SWIGINTERN swig::SwigPyIterator *std_vector_Sl_pj_AudioMedia_Sm__Sg__iterator(std::vector< pj::AudioMedia * > *self,PyObject **PYTHON_SELF){
      return swig::make_output_iterator(self->begin(), self->begin(), self->end(), *PYTHON_SELF);
    }
SWIGINTERN bool std_vector_Sl_pj_AudioMedia_Sm__Sg____nonzero__(std::vector< pj::AudioMedia * > const *self){
      return !(self->empty());
    }
SWIGINTERN bool std_vector_Sl_pj_AudioMedia_Sm__Sg____bool__(std::vector< pj::AudioMedia * > const *self){
      return !(self->empty());
    }
SWIGINTERN std::vector< pj::AudioMedia * >::size_type std_vector_Sl_pj_AudioMedia_Sm__Sg____len__(std::vector< pj::AudioMedia * > const *self){
      return self->size();
    }
SWIGINTERN std::vector< pj::AudioMedia *,std::allocator< pj::AudioMedia * > > *std_vector_Sl_pj_AudioMedia_Sm__Sg____getslice__(std::vector< pj::AudioMedia * > *self,std::vector< pj::AudioMedia * >::difference_type i,std::vector< pj::AudioMedia * >::difference_type j){
      return swig::getslice(self, i, j, 1);
    }
SWIGINTERN void std_vector_Sl_pj_AudioMedia_Sm__Sg____setslice____SWIG_0(std::vector< pj::AudioMedia * > *self,std::vector< pj::AudioMedia * >::difference_type i,std::vector< pj::AudioMedia * >::difference_type j){
      swig::setslice(self, i, j, 1, std::vector< pj::AudioMedia*,std::allocator< pj::AudioMedia * > >());
    }
SWIGINTERN void std_vector_Sl_pj_AudioMedia_Sm__Sg____setslice____SWIG_1(std::vector< pj::AudioMedia * > *self,std::vector< pj::AudioMedia * >::difference_type i,std::vector< pj::AudioMedia * >::difference_type j,std::vector< pj::AudioMedia *,std::allocator< pj::AudioMedia * > > const &v){
      swig::setslice(self, i, j, 1, v);
    }
SWIGINTERN void std_vector_Sl_pj_AudioMedia_Sm__Sg____delslice__(std::vector< pj::AudioMedia * > *self,std::vector< pj::AudioMedia * >::difference_type i,std::vector< pj::AudioMedia * >::difference_type j){
      swig::delslice(self, i, j, 1);
    }
SWIGINTERN void std_vector_Sl_pj_AudioMedia_Sm__Sg____delitem____SWIG_0(std::vector< pj::AudioMedia * > *self,std::vector< pj::AudioMedia * >::difference_type i){
      swig::erase(self, swig::getpos(self, i));
    }
SWIGINTERN std::vector< pj::AudioMedia *,std::allocator< pj::AudioMedia * > > *std_vector_Sl_pj_AudioMedia_Sm__Sg____getitem____SWIG_0(std::vector< pj::AudioMedia * > *self,PySliceObject *slice){
      Py_ssize_t i, j, step;
      if( !PySlice_Check(slice) ) {
        SWIG_Error(SWIG_TypeError, "Slice object expected.");
        return NULL;
      }
      PySlice_GetIndices(SWIGPY_SLICE_ARG(slice), (Py_ssize_t)self->size(), &i, &j, &step);
      std::vector< pj::AudioMedia*,std::allocator< pj::AudioMedia * > >::difference_type id = i;
      std::vector< pj::AudioMedia*,std::allocator< pj::AudioMedia * > >::difference_type jd = j;
      return swig::getslice(self, id, jd, step);
    }
SWIGINTERN void std_vector_Sl_pj_AudioMedia_Sm__Sg____setitem____SWIG_0(std::vector< pj::AudioMedia * > *self,PySliceObject *slice,std::vector< pj::AudioMedia *,std::allocator< pj::AudioMedia * > > const &v){
      Py_ssize_t i, j, step;
      if( !PySlice_Check(slice) ) {
        SWIG_Error(SWIG_TypeError, "Slice object expected.");
        return;
      }
      PySlice_GetIndices(SWIGPY_SLICE_ARG(slice), (Py_ssize_t)self->size(), &i, &j, &step);
      std::vector< pj::AudioMedia*,std::allocator< pj::AudioMedia * > >::difference_type id = i;
      std::vector< pj::AudioMedia*,std::allocator< pj::AudioMedia * > >::difference_type jd = j;
      swig::setslice(self, id, jd, step, v);
    }
SWIGINTERN void std_vector_Sl_pj_AudioMedia_Sm__Sg____setitem____SWIG_1(std::vector< pj::AudioMedia * > *self,PySliceObject *slice){
      Py_ssize_t i, j, step;
      if( !PySlice_Check(slice) ) {
        SWIG_Error(SWIG_TypeError, "Slice object expected.");
        return;
      }
      PySlice_GetIndices(SWIGPY_SLICE_ARG(slice), (Py_ssize_t)self->size(), &i, &j, &step);
      std::vector< pj::AudioMedia*,std::allocator< pj::AudioMedia * > >::difference_type id = i;
      std::vector< pj::AudioMedia*,std::allocator< pj::AudioMedia * > >::difference_type jd = j;
      swig::delslice(self, id, jd, step);
    }
SWIGINTERN void std_vector_Sl_pj_AudioMedia_Sm__Sg____delitem____SWIG_1(std::vector< pj::AudioMedia * > *self,PySliceObject *slice){
      Py_ssize_t i, j, step;
      if( !PySlice_Check(slice) ) {
        SWIG_Error(SWIG_TypeError, "Slice object expected.");
        return;
      }
      PySlice_GetIndices(SWIGPY_SLICE_ARG(slice), (Py_ssize_t)self->size(), &i, &j, &step);
      std::vector< pj::AudioMedia*,std::allocator< pj::AudioMedia * > >::difference_type id = i;
      std::vector< pj::AudioMedia*,std::allocator< pj::AudioMedia * > >::difference_type jd = j;
      swig::delslice(self, id, jd, step);
    }
SWIGINTERN std::vector< pj::AudioMedia * >::value_type std_vector_Sl_pj_AudioMedia_Sm__Sg____getitem____SWIG_1(std::vector< pj::AudioMedia * > *self,std::vector< pj::AudioMedia * >::difference_type i){
      return *(swig::cgetpos(self, i));
    }
SWIGINTERN void std_vector_Sl_pj_AudioMedia_Sm__Sg____setitem____SWIG_2(std::vector< pj::AudioMedia * > *self,std::vector< pj::AudioMedia * >::difference_type i,std::vector< pj::AudioMedia * >::value_type x){
      *(swig::getpos(self,i)) = x;
    }
SWIGINTERN std::vector< pj::AudioMedia * >::value_type std_vector_Sl_pj_AudioMedia_Sm__Sg__pop(std::vector< pj::AudioMedia * > *self){
      if (self->size() == 0)
	throw std::out_of_range("pop from empty container");
      std::vector< pj::AudioMedia*,std::allocator< pj::AudioMedia * > >::value_type x = self->back();
      self->pop_back();
      return x;
    }
SWIGINTERN void std_vector_Sl_pj_AudioMedia_Sm__Sg__append(std::vector< pj::AudioMedia * > *self,std::vector< pj::AudioMedia * >::value_type x){
      self->push_back(x);
    }
SWIGINTERN std::vector< pj::AudioMedia * >::iterator std_vector_Sl_pj_AudioMedia_Sm__Sg__erase__SWIG_0(std::vector< pj::AudioMedia * > *self,std::vector< pj::AudioMedia * >::iterator pos){ return self->erase(pos); }
SWIGINTERN std::vector< pj::AudioMedia * >::iterator std_vector_Sl_pj_AudioMedia_Sm__Sg__erase__SWIG_1(std::vector< pj::AudioMedia * > *self,std::vector< pj::AudioMedia * >::iterator first,std::vector< pj::AudioMedia * >::iterator last){ return self->erase(first, last); }
SWIGINTERN std::vector< pj::AudioMedia * >::iterator std_vector_Sl_pj_AudioMedia_Sm__Sg__insert__SWIG_0(std::vector< pj::AudioMedia * > *self,std::vector< pj::AudioMedia * >::iterator pos,std::vector< pj::AudioMedia * >::value_type x){ return self->insert(pos, x); }
SWIGINTERN void std_vector_Sl_pj_AudioMedia_Sm__Sg__insert__SWIG_1(std::vector< pj::AudioMedia * > *self,std::vector< pj::AudioMedia * >::iterator pos,std::vector< pj::AudioMedia * >::size_type n,std::vector< pj::AudioMedia * >::value_type x){ self->insert(pos, n, x); }

      namespace swig {
	template <>  struct traits<std::vector< pj::AudioMedia, std::allocator< pj::AudioMedia > > > {
	  typedef pointer_category category;
	  static const char* type_name() {
	    return "std::vector<" "pj::AudioMedia" "," "std::allocator< pj::AudioMedia >" " >";
	  }
	};
      }
    
SWIGINTERN swig::SwigPyIterator *std_vector_Sl_pj_AudioMedia_Sg__iterator(std::vector< pj::AudioMedia > *self,PyObject **PYTHON_SELF){
      return swig::make_output_iterator(self->begin(), self->begin(), self->end(), *PYTHON_SELF);
    }
SWIGINTERN bool std_vector_Sl_pj_AudioMedia_Sg____nonzero__(std::vector< pj::AudioMedia > const *self){
      return !(self->empty());
    }
SWIGINTERN bool std_vector_Sl_pj_AudioMedia_Sg____bool__(std::vector< pj::AudioMedia > const *self){
      return !(self->empty());
    }
SWIGINTERN std::vector< pj::AudioMedia >::size_type std_vector_Sl_pj_AudioMedia_Sg____len__(std::vector< pj::AudioMedia > const *self){
      return self->size();
    }
SWIGINTERN std::vector< pj::AudioMedia,std::allocator< pj::AudioMedia > > *std_vector_Sl_pj_AudioMedia_Sg____getslice__(std::vector< pj::AudioMedia > *self,std::vector< pj::AudioMedia >::difference_type i,std::vector< pj::AudioMedia >::difference_type j){
      return swig::getslice(self, i, j, 1);
    }
SWIGINTERN void std_vector_Sl_pj_AudioMedia_Sg____setslice____SWIG_0(std::vector< pj::AudioMedia > *self,std::vector< pj::AudioMedia >::difference_type i,std::vector< pj::AudioMedia >::difference_type j){
      swig::setslice(self, i, j, 1, std::vector< pj::AudioMedia,std::allocator< pj::AudioMedia > >());
    }
SWIGINTERN void std_vector_Sl_pj_AudioMedia_Sg____setslice____SWIG_1(std::vector< pj::AudioMedia > *self,std::vector< pj::AudioMedia >::difference_type i,std::vector< pj::AudioMedia >::difference_type j,std::vector< pj::AudioMedia,std::allocator< pj::AudioMedia > > const &v){
      swig::setslice(self, i, j, 1, v);
    }
SWIGINTERN void std_vector_Sl_pj_AudioMedia_Sg____delslice__(std::vector< pj::AudioMedia > *self,std::vector< pj::AudioMedia >::difference_type i,std::vector< pj::AudioMedia >::difference_type j){
      swig::delslice(self, i, j, 1);
    }
SWIGINTERN void std_vector_Sl_pj_AudioMedia_Sg____delitem____SWIG_0(std::vector< pj::AudioMedia > *self,std::vector< pj::AudioMedia >::difference_type i){
      swig::erase(self, swig::getpos(self, i));
    }
SWIGINTERN std::vector< pj::AudioMedia,std::allocator< pj::AudioMedia > > *std_vector_Sl_pj_AudioMedia_Sg____getitem____SWIG_0(std::vector< pj::AudioMedia > *self,PySliceObject *slice){
      Py_ssize_t i, j, step;
      if( !PySlice_Check(slice) ) {
        SWIG_Error(SWIG_TypeError, "Slice object expected.");
        return NULL;
      }
      PySlice_GetIndices(SWIGPY_SLICE_ARG(slice), (Py_ssize_t)self->size(), &i, &j, &step);
      std::vector< pj::AudioMedia,std::allocator< pj::AudioMedia > >::difference_type id = i;
      std::vector< pj::AudioMedia,std::allocator< pj::AudioMedia > >::difference_type jd = j;
      return swig::getslice(self, id, jd, step);
    }
SWIGINTERN void std_vector_Sl_pj_AudioMedia_Sg____setitem____SWIG_0(std::vector< pj::AudioMedia > *self,PySliceObject *slice,std::vector< pj::AudioMedia,std::allocator< pj::AudioMedia > > const &v){
      Py_ssize_t i, j, step;
      if( !PySlice_Check(slice) ) {
        SWIG_Error(SWIG_TypeError, "Slice object expected.");
        return;
      }
      PySlice_GetIndices(SWIGPY_SLICE_ARG(slice), (Py_ssize_t)self->size(), &i, &j, &step);
      std::vector< pj::AudioMedia,std::allocator< pj::AudioMedia > >::difference_type id = i;
      std::vector< pj::AudioMedia,std::allocator< pj::AudioMedia > >::difference_type jd = j;
      swig::setslice(self, id, jd, step, v);
    }
SWIGINTERN void std_vector_Sl_pj_AudioMedia_Sg____setitem____SWIG_1(std::vector< pj::AudioMedia > *self,PySliceObject *slice){
      Py_ssize_t i, j, step;
      if( !PySlice_Check(slice) ) {
        SWIG_Error(SWIG_TypeError, "Slice object expected.");
        return;
      }
      PySlice_GetIndices(SWIGPY_SLICE_ARG(slice), (Py_ssize_t)self->size(), &i, &j, &step);
      std::vector< pj::AudioMedia,std::allocator< pj::AudioMedia > >::difference_type id = i;
      std::vector< pj::AudioMedia,std::allocator< pj::AudioMedia > >::difference_type jd = j;
      swig::delslice(self, id, jd, step);
    }
SWIGINTERN void std_vector_Sl_pj_AudioMedia_Sg____delitem____SWIG_1(std::vector< pj::AudioMedia > *self,PySliceObject *slice){
      Py_ssize_t i, j, step;
      if( !PySlice_Check(slice) ) {
        SWIG_Error(SWIG_TypeError, "Slice object expected.");
        return;
      }
      PySlice_GetIndices(SWIGPY_SLICE_ARG(slice), (Py_ssize_t)self->size(), &i, &j, &step);
      std::vector< pj::AudioMedia,std::allocator< pj::AudioMedia > >::difference_type id = i;
      std::vector< pj::AudioMedia,std::allocator< pj::AudioMedia > >::difference_type jd = j;
      swig::delslice(self, id, jd, step);
    }
SWIGINTERN std::vector< pj::AudioMedia >::value_type const &std_vector_Sl_pj_AudioMedia_Sg____getitem____SWIG_1(std::vector< pj::AudioMedia > const *self,std::vector< pj::AudioMedia >::difference_type i){
      return *(swig::cgetpos(self, i));
    }
SWIGINTERN void std_vector_Sl_pj_AudioMedia_Sg____setitem____SWIG_2(std::vector< pj::AudioMedia > *self,std::vector< pj::AudioMedia >::difference_type i,std::vector< pj::AudioMedia >::value_type const &x){
      *(swig::getpos(self,i)) = x;
    }
SWIGINTERN std::vector< pj::AudioMedia >::value_type std_vector_Sl_pj_AudioMedia_Sg__pop(std::vector< pj::AudioMedia > *self){
      if (self->size() == 0)
	throw std::out_of_range("pop from empty container");
      std::vector< pj::AudioMedia,std::allocator< pj::AudioMedia > >::value_type x = self->back();
      self->pop_back();
      return x;
    }
SWIGINTERN void std_vector_Sl_pj_AudioMedia_Sg__append(std::vector< pj::AudioMedia > *self,std::vector< pj::AudioMedia >::value_type const &x){
      self->push_back(x);
    }
SWIGINTERN std::vector< pj::AudioMedia >::iterator std_vector_Sl_pj_AudioMedia_Sg__erase__SWIG_0(std::vector< pj::AudioMedia > *self,std::vector< pj::AudioMedia >::iterator pos){ return self->erase(pos); }
SWIGINTERN std::vector< pj::AudioMedia >::iterator std_vector_Sl_pj_AudioMedia_Sg__erase__SWIG_1(std::vector< pj::AudioMedia > *self,std::vector< pj::AudioMedia >::iterator first,std::vector< pj::AudioMedia >::iterator last){ return self->erase(first, last); }
SWIGINTERN std::vector< pj::AudioMedia >::iterator std_vector_Sl_pj_AudioMedia_Sg__insert__SWIG_0(std::vector< pj::AudioMedia > *self,std::vector< pj::AudioMedia >::iterator pos,std::vector< pj::AudioMedia >::value_type const &x){ return self->insert(pos, x); }
SWIGINTERN void std_vector_Sl_pj_AudioMedia_Sg__insert__SWIG_1(std::vector< pj::AudioMedia > *self,std::vector< pj::AudioMedia >::iterator pos,std::vector< pj::AudioMedia >::size_type n,std::vector< pj::AudioMedia >::value_type const &x){ self->insert(pos, n, x); }

  namespace swig {
    template <>  struct traits< pj::VideoMedia > {
      typedef pointer_category category;
      static const char* type_name() { return"pj::VideoMedia"; }
    };
  }


      namespace swig {
	template <>  struct traits<std::vector< pj::VideoMedia, std::allocator< pj::VideoMedia > > > {
	  typedef pointer_category category;
	  static const char* type_name() {
	    return "std::vector<" "pj::VideoMedia" "," "std::allocator< pj::VideoMedia >" " >";
	  }
	};
      }
    
SWIGINTERN swig::SwigPyIterator *std_vector_Sl_pj_VideoMedia_Sg__iterator(std::vector< pj::VideoMedia > *self,PyObject **PYTHON_SELF){
      return swig::make_output_iterator(self->begin(), self->begin(), self->end(), *PYTHON_SELF);
    }
SWIGINTERN bool std_vector_Sl_pj_VideoMedia_Sg____nonzero__(std::vector< pj::VideoMedia > const *self){
      return !(self->empty());
    }
SWIGINTERN bool std_vector_Sl_pj_VideoMedia_Sg____bool__(std::vector< pj::VideoMedia > const *self){
      return !(self->empty());
    }
SWIGINTERN std::vector< pj::VideoMedia >::size_type std_vector_Sl_pj_VideoMedia_Sg____len__(std::vector< pj::VideoMedia > const *self){
      return self->size();
    }
SWIGINTERN std::vector< pj::VideoMedia,std::allocator< pj::VideoMedia > > *std_vector_Sl_pj_VideoMedia_Sg____getslice__(std::vector< pj::VideoMedia > *self,std::vector< pj::VideoMedia >::difference_type i,std::vector< pj::VideoMedia >::difference_type j){
      return swig::getslice(self, i, j, 1);
    }
SWIGINTERN void std_vector_Sl_pj_VideoMedia_Sg____setslice____SWIG_0(std::vector< pj::VideoMedia > *self,std::vector< pj::VideoMedia >::difference_type i,std::vector< pj::VideoMedia >::difference_type j){
      swig::setslice(self, i, j, 1, std::vector< pj::VideoMedia,std::allocator< pj::VideoMedia > >());
    }
SWIGINTERN void std_vector_Sl_pj_VideoMedia_Sg____setslice____SWIG_1(std::vector< pj::VideoMedia > *self,std::vector< pj::VideoMedia >::difference_type i,std::vector< pj::VideoMedia >::difference_type j,std::vector< pj::VideoMedia,std::allocator< pj::VideoMedia > > const &v){
      swig::setslice(self, i, j, 1, v);
    }
SWIGINTERN void std_vector_Sl_pj_VideoMedia_Sg____delslice__(std::vector< pj::VideoMedia > *self,std::vector< pj::VideoMedia >::difference_type i,std::vector< pj::VideoMedia >::difference_type j){
      swig::delslice(self, i, j, 1);
    }
SWIGINTERN void std_vector_Sl_pj_VideoMedia_Sg____delitem____SWIG_0(std::vector< pj::VideoMedia > *self,std::vector< pj::VideoMedia >::difference_type i){
      swig::erase(self, swig::getpos(self, i));
    }
SWIGINTERN std::vector< pj::VideoMedia,std::allocator< pj::VideoMedia > > *std_vector_Sl_pj_VideoMedia_Sg____getitem____SWIG_0(std::vector< pj::VideoMedia > *self,PySliceObject *slice){
      Py_ssize_t i, j, step;
      if( !PySlice_Check(slice) ) {
        SWIG_Error(SWIG_TypeError, "Slice object expected.");
        return NULL;
      }
      PySlice_GetIndices(SWIGPY_SLICE_ARG(slice), (Py_ssize_t)self->size(), &i, &j, &step);
      std::vector< pj::VideoMedia,std::allocator< pj::VideoMedia > >::difference_type id = i;
      std::vector< pj::VideoMedia,std::allocator< pj::VideoMedia > >::difference_type jd = j;
      return swig::getslice(self, id, jd, step);
    }
SWIGINTERN void std_vector_Sl_pj_VideoMedia_Sg____setitem____SWIG_0(std::vector< pj::VideoMedia > *self,PySliceObject *slice,std::vector< pj::VideoMedia,std::allocator< pj::VideoMedia > > const &v){
      Py_ssize_t i, j, step;
      if( !PySlice_Check(slice) ) {
        SWIG_Error(SWIG_TypeError, "Slice object expected.");
        return;
      }
      PySlice_GetIndices(SWIGPY_SLICE_ARG(slice), (Py_ssize_t)self->size(), &i, &j, &step);
      std::vector< pj::VideoMedia,std::allocator< pj::VideoMedia > >::difference_type id = i;
      std::vector< pj::VideoMedia,std::allocator< pj::VideoMedia > >::difference_type jd = j;
      swig::setslice(self, id, jd, step, v);
    }
SWIGINTERN void std_vector_Sl_pj_VideoMedia_Sg____setitem____SWIG_1(std::vector< pj::VideoMedia > *self,PySliceObject *slice){
      Py_ssize_t i, j, step;
      if( !PySlice_Check(slice) ) {
        SWIG_Error(SWIG_TypeError, "Slice object expected.");
        return;
      }
      PySlice_GetIndices(SWIGPY_SLICE_ARG(slice), (Py_ssize_t)self->size(), &i, &j, &step);
      std::vector< pj::VideoMedia,std::allocator< pj::VideoMedia > >::difference_type id = i;
      std::vector< pj::VideoMedia,std::allocator< pj::VideoMedia > >::difference_type jd = j;
      swig::delslice(self, id, jd, step);
    }
SWIGINTERN void std_vector_Sl_pj_VideoMedia_Sg____delitem____SWIG_1(std::vector< pj::VideoMedia > *self,PySliceObject *slice){
      Py_ssize_t i, j, step;
      if( !PySlice_Check(slice) ) {
        SWIG_Error(SWIG_TypeError, "Slice object expected.");
        return;
      }
      PySlice_GetIndices(SWIGPY_SLICE_ARG(slice), (Py_ssize_t)self->size(), &i, &j, &step);
      std::vector< pj::VideoMedia,std::allocator< pj::VideoMedia > >::difference_type id = i;
      std::vector< pj::VideoMedia,std::allocator< pj::VideoMedia > >::difference_type jd = j;
      swig::delslice(self, id, jd, step);
    }
SWIGINTERN std::vector< pj::VideoMedia >::value_type const &std_vector_Sl_pj_VideoMedia_Sg____getitem____SWIG_1(std::vector< pj::VideoMedia > const *self,std::vector< pj::VideoMedia >::difference_type i){
      return *(swig::cgetpos(self, i));
    }
SWIGINTERN void std_vector_Sl_pj_VideoMedia_Sg____setitem____SWIG_2(std::vector< pj::VideoMedia > *self,std::vector< pj::VideoMedia >::difference_type i,std::vector< pj::VideoMedia >::value_type const &x){
      *(swig::getpos(self,i)) = x;
    }
SWIGINTERN std::vector< pj::VideoMedia >::value_type std_vector_Sl_pj_VideoMedia_Sg__pop(std::vector< pj::VideoMedia > *self){
      if (self->size() == 0)
	throw std::out_of_range("pop from empty container");
      std::vector< pj::VideoMedia,std::allocator< pj::VideoMedia > >::value_type x = self->back();
      self->pop_back();
      return x;
    }
SWIGINTERN void std_vector_Sl_pj_VideoMedia_Sg__append(std::vector< pj::VideoMedia > *self,std::vector< pj::VideoMedia >::value_type const &x){
      self->push_back(x);
    }
SWIGINTERN std::vector< pj::VideoMedia >::iterator std_vector_Sl_pj_VideoMedia_Sg__erase__SWIG_0(std::vector< pj::VideoMedia > *self,std::vector< pj::VideoMedia >::iterator pos){ return self->erase(pos); }
SWIGINTERN std::vector< pj::VideoMedia >::iterator std_vector_Sl_pj_VideoMedia_Sg__erase__SWIG_1(std::vector< pj::VideoMedia > *self,std::vector< pj::VideoMedia >::iterator first,std::vector< pj::VideoMedia >::iterator last){ return self->erase(first, last); }
SWIGINTERN std::vector< pj::VideoMedia >::iterator std_vector_Sl_pj_VideoMedia_Sg__insert__SWIG_0(std::vector< pj::VideoMedia > *self,std::vector< pj::VideoMedia >::iterator pos,std::vector< pj::VideoMedia >::value_type const &x){ return self->insert(pos, x); }
SWIGINTERN void std_vector_Sl_pj_VideoMedia_Sg__insert__SWIG_1(std::vector< pj::VideoMedia > *self,std::vector< pj::VideoMedia >::iterator pos,std::vector< pj::VideoMedia >::size_type n,std::vector< pj::VideoMedia >::value_type const &x){ self->insert(pos, n, x); }

  namespace swig {
    template <>  struct traits< pj::ToneDesc > {
      typedef pointer_category category;
      static const char* type_name() { return"pj::ToneDesc"; }
    };
  }


      namespace swig {
	template <>  struct traits<std::vector< pj::ToneDesc, std::allocator< pj::ToneDesc > > > {
	  typedef pointer_category category;
	  static const char* type_name() {
	    return "std::vector<" "pj::ToneDesc" "," "std::allocator< pj::ToneDesc >" " >";
	  }
	};
      }
    
SWIGINTERN swig::SwigPyIterator *std_vector_Sl_pj_ToneDesc_Sg__iterator(std::vector< pj::ToneDesc > *self,PyObject **PYTHON_SELF){
      return swig::make_output_iterator(self->begin(), self->begin(), self->end(), *PYTHON_SELF);
    }
SWIGINTERN bool std_vector_Sl_pj_ToneDesc_Sg____nonzero__(std::vector< pj::ToneDesc > const *self){
      return !(self->empty());
    }
SWIGINTERN bool std_vector_Sl_pj_ToneDesc_Sg____bool__(std::vector< pj::ToneDesc > const *self){
      return !(self->empty());
    }
SWIGINTERN std::vector< pj::ToneDesc >::size_type std_vector_Sl_pj_ToneDesc_Sg____len__(std::vector< pj::ToneDesc > const *self){
      return self->size();
    }
SWIGINTERN std::vector< pj::ToneDesc,std::allocator< pj::ToneDesc > > *std_vector_Sl_pj_ToneDesc_Sg____getslice__(std::vector< pj::ToneDesc > *self,std::vector< pj::ToneDesc >::difference_type i,std::vector< pj::ToneDesc >::difference_type j){
      return swig::getslice(self, i, j, 1);
    }
SWIGINTERN void std_vector_Sl_pj_ToneDesc_Sg____setslice____SWIG_0(std::vector< pj::ToneDesc > *self,std::vector< pj::ToneDesc >::difference_type i,std::vector< pj::ToneDesc >::difference_type j){
      swig::setslice(self, i, j, 1, std::vector< pj::ToneDesc,std::allocator< pj::ToneDesc > >());
    }
SWIGINTERN void std_vector_Sl_pj_ToneDesc_Sg____setslice____SWIG_1(std::vector< pj::ToneDesc > *self,std::vector< pj::ToneDesc >::difference_type i,std::vector< pj::ToneDesc >::difference_type j,std::vector< pj::ToneDesc,std::allocator< pj::ToneDesc > > const &v){
      swig::setslice(self, i, j, 1, v);
    }
SWIGINTERN void std_vector_Sl_pj_ToneDesc_Sg____delslice__(std::vector< pj::ToneDesc > *self,std::vector< pj::ToneDesc >::difference_type i,std::vector< pj::ToneDesc >::difference_type j){
      swig::delslice(self, i, j, 1);
    }
SWIGINTERN void std_vector_Sl_pj_ToneDesc_Sg____delitem____SWIG_0(std::vector< pj::ToneDesc > *self,std::vector< pj::ToneDesc >::difference_type i){
      swig::erase(self, swig::getpos(self, i));
    }
SWIGINTERN std::vector< pj::ToneDesc,std::allocator< pj::ToneDesc > > *std_vector_Sl_pj_ToneDesc_Sg____getitem____SWIG_0(std::vector< pj::ToneDesc > *self,PySliceObject *slice){
      Py_ssize_t i, j, step;
      if( !PySlice_Check(slice) ) {
        SWIG_Error(SWIG_TypeError, "Slice object expected.");
        return NULL;
      }
      PySlice_GetIndices(SWIGPY_SLICE_ARG(slice), (Py_ssize_t)self->size(), &i, &j, &step);
      std::vector< pj::ToneDesc,std::allocator< pj::ToneDesc > >::difference_type id = i;
      std::vector< pj::ToneDesc,std::allocator< pj::ToneDesc > >::difference_type jd = j;
      return swig::getslice(self, id, jd, step);
    }
SWIGINTERN void std_vector_Sl_pj_ToneDesc_Sg____setitem____SWIG_0(std::vector< pj::ToneDesc > *self,PySliceObject *slice,std::vector< pj::ToneDesc,std::allocator< pj::ToneDesc > > const &v){
      Py_ssize_t i, j, step;
      if( !PySlice_Check(slice) ) {
        SWIG_Error(SWIG_TypeError, "Slice object expected.");
        return;
      }
      PySlice_GetIndices(SWIGPY_SLICE_ARG(slice), (Py_ssize_t)self->size(), &i, &j, &step);
      std::vector< pj::ToneDesc,std::allocator< pj::ToneDesc > >::difference_type id = i;
      std::vector< pj::ToneDesc,std::allocator< pj::ToneDesc > >::difference_type jd = j;
      swig::setslice(self, id, jd, step, v);
    }
SWIGINTERN void std_vector_Sl_pj_ToneDesc_Sg____setitem____SWIG_1(std::vector< pj::ToneDesc > *self,PySliceObject *slice){
      Py_ssize_t i, j, step;
      if( !PySlice_Check(slice) ) {
        SWIG_Error(SWIG_TypeError, "Slice object expected.");
        return;
      }
      PySlice_GetIndices(SWIGPY_SLICE_ARG(slice), (Py_ssize_t)self->size(), &i, &j, &step);
      std::vector< pj::ToneDesc,std::allocator< pj::ToneDesc > >::difference_type id = i;
      std::vector< pj::ToneDesc,std::allocator< pj::ToneDesc > >::difference_type jd = j;
      swig::delslice(self, id, jd, step);
    }
SWIGINTERN void std_vector_Sl_pj_ToneDesc_Sg____delitem____SWIG_1(std::vector< pj::ToneDesc > *self,PySliceObject *slice){
      Py_ssize_t i, j, step;
      if( !PySlice_Check(slice) ) {
        SWIG_Error(SWIG_TypeError, "Slice object expected.");
        return;
      }
      PySlice_GetIndices(SWIGPY_SLICE_ARG(slice), (Py_ssize_t)self->size(), &i, &j, &step);
      std::vector< pj::ToneDesc,std::allocator< pj::ToneDesc > >::difference_type id = i;
      std::vector< pj::ToneDesc,std::allocator< pj::ToneDesc > >::difference_type jd = j;
      swig::delslice(self, id, jd, step);
    }
SWIGINTERN std::vector< pj::ToneDesc >::value_type const &std_vector_Sl_pj_ToneDesc_Sg____getitem____SWIG_1(std::vector< pj::ToneDesc > const *self,std::vector< pj::ToneDesc >::difference_type i){
      return *(swig::cgetpos(self, i));
    }
SWIGINTERN void std_vector_Sl_pj_ToneDesc_Sg____setitem____SWIG_2(std::vector< pj::ToneDesc > *self,std::vector< pj::ToneDesc >::difference_type i,std::vector< pj::ToneDesc >::value_type const &x){
      *(swig::getpos(self,i)) = x;
    }
SWIGINTERN std::vector< pj::ToneDesc >::value_type std_vector_Sl_pj_ToneDesc_Sg__pop(std::vector< pj::ToneDesc > *self){
      if (self->size() == 0)
	throw std::out_of_range("pop from empty container");
      std::vector< pj::ToneDesc,std::allocator< pj::ToneDesc > >::value_type x = self->back();
      self->pop_back();
      return x;
    }
SWIGINTERN void std_vector_Sl_pj_ToneDesc_Sg__append(std::vector< pj::ToneDesc > *self,std::vector< pj::ToneDesc >::value_type const &x){
      self->push_back(x);
    }
SWIGINTERN std::vector< pj::ToneDesc >::iterator std_vector_Sl_pj_ToneDesc_Sg__erase__SWIG_0(std::vector< pj::ToneDesc > *self,std::vector< pj::ToneDesc >::iterator pos){ return self->erase(pos); }
SWIGINTERN std::vector< pj::ToneDesc >::iterator std_vector_Sl_pj_ToneDesc_Sg__erase__SWIG_1(std::vector< pj::ToneDesc > *self,std::vector< pj::ToneDesc >::iterator first,std::vector< pj::ToneDesc >::iterator last){ return self->erase(first, last); }
SWIGINTERN std::vector< pj::ToneDesc >::iterator std_vector_Sl_pj_ToneDesc_Sg__insert__SWIG_0(std::vector< pj::ToneDesc > *self,std::vector< pj::ToneDesc >::iterator pos,std::vector< pj::ToneDesc >::value_type const &x){ return self->insert(pos, x); }
SWIGINTERN void std_vector_Sl_pj_ToneDesc_Sg__insert__SWIG_1(std::vector< pj::ToneDesc > *self,std::vector< pj::ToneDesc >::iterator pos,std::vector< pj::ToneDesc >::size_type n,std::vector< pj::ToneDesc >::value_type const &x){ self->insert(pos, n, x); }

  namespace swig {
    template <>  struct traits< pj::ToneDigit > {
      typedef pointer_category category;
      static const char* type_name() { return"pj::ToneDigit"; }
    };
  }


      namespace swig {
	template <>  struct traits<std::vector< pj::ToneDigit, std::allocator< pj::ToneDigit > > > {
	  typedef pointer_category category;
	  static const char* type_name() {
	    return "std::vector<" "pj::ToneDigit" "," "std::allocator< pj::ToneDigit >" " >";
	  }
	};
      }
    
SWIGINTERN swig::SwigPyIterator *std_vector_Sl_pj_ToneDigit_Sg__iterator(std::vector< pj::ToneDigit > *self,PyObject **PYTHON_SELF){
      return swig::make_output_iterator(self->begin(), self->begin(), self->end(), *PYTHON_SELF);
    }
SWIGINTERN bool std_vector_Sl_pj_ToneDigit_Sg____nonzero__(std::vector< pj::ToneDigit > const *self){
      return !(self->empty());
    }
SWIGINTERN bool std_vector_Sl_pj_ToneDigit_Sg____bool__(std::vector< pj::ToneDigit > const *self){
      return !(self->empty());
    }
SWIGINTERN std::vector< pj::ToneDigit >::size_type std_vector_Sl_pj_ToneDigit_Sg____len__(std::vector< pj::ToneDigit > const *self){
      return self->size();
    }
SWIGINTERN std::vector< pj::ToneDigit,std::allocator< pj::ToneDigit > > *std_vector_Sl_pj_ToneDigit_Sg____getslice__(std::vector< pj::ToneDigit > *self,std::vector< pj::ToneDigit >::difference_type i,std::vector< pj::ToneDigit >::difference_type j){
      return swig::getslice(self, i, j, 1);
    }
SWIGINTERN void std_vector_Sl_pj_ToneDigit_Sg____setslice____SWIG_0(std::vector< pj::ToneDigit > *self,std::vector< pj::ToneDigit >::difference_type i,std::vector< pj::ToneDigit >::difference_type j){
      swig::setslice(self, i, j, 1, std::vector< pj::ToneDigit,std::allocator< pj::ToneDigit > >());
    }
SWIGINTERN void std_vector_Sl_pj_ToneDigit_Sg____setslice____SWIG_1(std::vector< pj::ToneDigit > *self,std::vector< pj::ToneDigit >::difference_type i,std::vector< pj::ToneDigit >::difference_type j,std::vector< pj::ToneDigit,std::allocator< pj::ToneDigit > > const &v){
      swig::setslice(self, i, j, 1, v);
    }
SWIGINTERN void std_vector_Sl_pj_ToneDigit_Sg____delslice__(std::vector< pj::ToneDigit > *self,std::vector< pj::ToneDigit >::difference_type i,std::vector< pj::ToneDigit >::difference_type j){
      swig::delslice(self, i, j, 1);
    }
SWIGINTERN void std_vector_Sl_pj_ToneDigit_Sg____delitem____SWIG_0(std::vector< pj::ToneDigit > *self,std::vector< pj::ToneDigit >::difference_type i){
      swig::erase(self, swig::getpos(self, i));
    }
SWIGINTERN std::vector< pj::ToneDigit,std::allocator< pj::ToneDigit > > *std_vector_Sl_pj_ToneDigit_Sg____getitem____SWIG_0(std::vector< pj::ToneDigit > *self,PySliceObject *slice){
      Py_ssize_t i, j, step;
      if( !PySlice_Check(slice) ) {
        SWIG_Error(SWIG_TypeError, "Slice object expected.");
        return NULL;
      }
      PySlice_GetIndices(SWIGPY_SLICE_ARG(slice), (Py_ssize_t)self->size(), &i, &j, &step);
      std::vector< pj::ToneDigit,std::allocator< pj::ToneDigit > >::difference_type id = i;
      std::vector< pj::ToneDigit,std::allocator< pj::ToneDigit > >::difference_type jd = j;
      return swig::getslice(self, id, jd, step);
    }
SWIGINTERN void std_vector_Sl_pj_ToneDigit_Sg____setitem____SWIG_0(std::vector< pj::ToneDigit > *self,PySliceObject *slice,std::vector< pj::ToneDigit,std::allocator< pj::ToneDigit > > const &v){
      Py_ssize_t i, j, step;
      if( !PySlice_Check(slice) ) {
        SWIG_Error(SWIG_TypeError, "Slice object expected.");
        return;
      }
      PySlice_GetIndices(SWIGPY_SLICE_ARG(slice), (Py_ssize_t)self->size(), &i, &j, &step);
      std::vector< pj::ToneDigit,std::allocator< pj::ToneDigit > >::difference_type id = i;
      std::vector< pj::ToneDigit,std::allocator< pj::ToneDigit > >::difference_type jd = j;
      swig::setslice(self, id, jd, step, v);
    }
SWIGINTERN void std_vector_Sl_pj_ToneDigit_Sg____setitem____SWIG_1(std::vector< pj::ToneDigit > *self,PySliceObject *slice){
      Py_ssize_t i, j, step;
      if( !PySlice_Check(slice) ) {
        SWIG_Error(SWIG_TypeError, "Slice object expected.");
        return;
      }
      PySlice_GetIndices(SWIGPY_SLICE_ARG(slice), (Py_ssize_t)self->size(), &i, &j, &step);
      std::vector< pj::ToneDigit,std::allocator< pj::ToneDigit > >::difference_type id = i;
      std::vector< pj::ToneDigit,std::allocator< pj::ToneDigit > >::difference_type jd = j;
      swig::delslice(self, id, jd, step);
    }
SWIGINTERN void std_vector_Sl_pj_ToneDigit_Sg____delitem____SWIG_1(std::vector< pj::ToneDigit > *self,PySliceObject *slice){
      Py_ssize_t i, j, step;
      if( !PySlice_Check(slice) ) {
        SWIG_Error(SWIG_TypeError, "Slice object expected.");
        return;
      }
      PySlice_GetIndices(SWIGPY_SLICE_ARG(slice), (Py_ssize_t)self->size(), &i, &j, &step);
      std::vector< pj::ToneDigit,std::allocator< pj::ToneDigit > >::difference_type id = i;
      std::vector< pj::ToneDigit,std::allocator< pj::ToneDigit > >::difference_type jd = j;
      swig::delslice(self, id, jd, step);
    }
SWIGINTERN std::vector< pj::ToneDigit >::value_type const &std_vector_Sl_pj_ToneDigit_Sg____getitem____SWIG_1(std::vector< pj::ToneDigit > const *self,std::vector< pj::ToneDigit >::difference_type i){
      return *(swig::cgetpos(self, i));
    }
SWIGINTERN void std_vector_Sl_pj_ToneDigit_Sg____setitem____SWIG_2(std::vector< pj::ToneDigit > *self,std::vector< pj::ToneDigit >::difference_type i,std::vector< pj::ToneDigit >::value_type const &x){
      *(swig::getpos(self,i)) = x;
    }
SWIGINTERN std::vector< pj::ToneDigit >::value_type std_vector_Sl_pj_ToneDigit_Sg__pop(std::vector< pj::ToneDigit > *self){
      if (self->size() == 0)
	throw std::out_of_range("pop from empty container");
      std::vector< pj::ToneDigit,std::allocator< pj::ToneDigit > >::value_type x = self->back();
      self->pop_back();
      return x;
    }
SWIGINTERN void std_vector_Sl_pj_ToneDigit_Sg__append(std::vector< pj::ToneDigit > *self,std::vector< pj::ToneDigit >::value_type const &x){
      self->push_back(x);
    }
SWIGINTERN std::vector< pj::ToneDigit >::iterator std_vector_Sl_pj_ToneDigit_Sg__erase__SWIG_0(std::vector< pj::ToneDigit > *self,std::vector< pj::ToneDigit >::iterator pos){ return self->erase(pos); }
SWIGINTERN std::vector< pj::ToneDigit >::iterator std_vector_Sl_pj_ToneDigit_Sg__erase__SWIG_1(std::vector< pj::ToneDigit > *self,std::vector< pj::ToneDigit >::iterator first,std::vector< pj::ToneDigit >::iterator last){ return self->erase(first, last); }
SWIGINTERN std::vector< pj::ToneDigit >::iterator std_vector_Sl_pj_ToneDigit_Sg__insert__SWIG_0(std::vector< pj::ToneDigit > *self,std::vector< pj::ToneDigit >::iterator pos,std::vector< pj::ToneDigit >::value_type const &x){ return self->insert(pos, x); }
SWIGINTERN void std_vector_Sl_pj_ToneDigit_Sg__insert__SWIG_1(std::vector< pj::ToneDigit > *self,std::vector< pj::ToneDigit >::iterator pos,std::vector< pj::ToneDigit >::size_type n,std::vector< pj::ToneDigit >::value_type const &x){ self->insert(pos, n, x); }

  namespace swig {
    template <>  struct traits< pj::ToneDigitMapDigit > {
      typedef pointer_category category;
      static const char* type_name() { return"pj::ToneDigitMapDigit"; }
    };
  }


      namespace swig {
	template <>  struct traits<std::vector< pj::ToneDigitMapDigit, std::allocator< pj::ToneDigitMapDigit > > > {
	  typedef pointer_category category;
	  static const char* type_name() {
	    return "std::vector<" "pj::ToneDigitMapDigit" "," "std::allocator< pj::ToneDigitMapDigit >" " >";
	  }
	};
      }
    
SWIGINTERN swig::SwigPyIterator *std_vector_Sl_pj_ToneDigitMapDigit_Sg__iterator(std::vector< pj::ToneDigitMapDigit > *self,PyObject **PYTHON_SELF){
      return swig::make_output_iterator(self->begin(), self->begin(), self->end(), *PYTHON_SELF);
    }
SWIGINTERN bool std_vector_Sl_pj_ToneDigitMapDigit_Sg____nonzero__(std::vector< pj::ToneDigitMapDigit > const *self){
      return !(self->empty());
    }
SWIGINTERN bool std_vector_Sl_pj_ToneDigitMapDigit_Sg____bool__(std::vector< pj::ToneDigitMapDigit > const *self){
      return !(self->empty());
    }
SWIGINTERN std::vector< pj::ToneDigitMapDigit >::size_type std_vector_Sl_pj_ToneDigitMapDigit_Sg____len__(std::vector< pj::ToneDigitMapDigit > const *self){
      return self->size();
    }
SWIGINTERN std::vector< pj::ToneDigitMapDigit,std::allocator< pj::ToneDigitMapDigit > > *std_vector_Sl_pj_ToneDigitMapDigit_Sg____getslice__(std::vector< pj::ToneDigitMapDigit > *self,std::vector< pj::ToneDigitMapDigit >::difference_type i,std::vector< pj::ToneDigitMapDigit >::difference_type j){
      return swig::getslice(self, i, j, 1);
    }
SWIGINTERN void std_vector_Sl_pj_ToneDigitMapDigit_Sg____setslice____SWIG_0(std::vector< pj::ToneDigitMapDigit > *self,std::vector< pj::ToneDigitMapDigit >::difference_type i,std::vector< pj::ToneDigitMapDigit >::difference_type j){
      swig::setslice(self, i, j, 1, std::vector< pj::ToneDigitMapDigit,std::allocator< pj::ToneDigitMapDigit > >());
    }
SWIGINTERN void std_vector_Sl_pj_ToneDigitMapDigit_Sg____setslice____SWIG_1(std::vector< pj::ToneDigitMapDigit > *self,std::vector< pj::ToneDigitMapDigit >::difference_type i,std::vector< pj::ToneDigitMapDigit >::difference_type j,std::vector< pj::ToneDigitMapDigit,std::allocator< pj::ToneDigitMapDigit > > const &v){
      swig::setslice(self, i, j, 1, v);
    }
SWIGINTERN void std_vector_Sl_pj_ToneDigitMapDigit_Sg____delslice__(std::vector< pj::ToneDigitMapDigit > *self,std::vector< pj::ToneDigitMapDigit >::difference_type i,std::vector< pj::ToneDigitMapDigit >::difference_type j){
      swig::delslice(self, i, j, 1);
    }
SWIGINTERN void std_vector_Sl_pj_ToneDigitMapDigit_Sg____delitem____SWIG_0(std::vector< pj::ToneDigitMapDigit > *self,std::vector< pj::ToneDigitMapDigit >::difference_type i){
      swig::erase(self, swig::getpos(self, i));
    }
SWIGINTERN std::vector< pj::ToneDigitMapDigit,std::allocator< pj::ToneDigitMapDigit > > *std_vector_Sl_pj_ToneDigitMapDigit_Sg____getitem____SWIG_0(std::vector< pj::ToneDigitMapDigit > *self,PySliceObject *slice){
      Py_ssize_t i, j, step;
      if( !PySlice_Check(slice) ) {
        SWIG_Error(SWIG_TypeError, "Slice object expected.");
        return NULL;
      }
      PySlice_GetIndices(SWIGPY_SLICE_ARG(slice), (Py_ssize_t)self->size(), &i, &j, &step);
      std::vector< pj::ToneDigitMapDigit,std::allocator< pj::ToneDigitMapDigit > >::difference_type id = i;
      std::vector< pj::ToneDigitMapDigit,std::allocator< pj::ToneDigitMapDigit > >::difference_type jd = j;
      return swig::getslice(self, id, jd, step);
    }
SWIGINTERN void std_vector_Sl_pj_ToneDigitMapDigit_Sg____setitem____SWIG_0(std::vector< pj::ToneDigitMapDigit > *self,PySliceObject *slice,std::vector< pj::ToneDigitMapDigit,std::allocator< pj::ToneDigitMapDigit > > const &v){
      Py_ssize_t i, j, step;
      if( !PySlice_Check(slice) ) {
        SWIG_Error(SWIG_TypeError, "Slice object expected.");
        return;
      }
      PySlice_GetIndices(SWIGPY_SLICE_ARG(slice), (Py_ssize_t)self->size(), &i, &j, &step);
      std::vector< pj::ToneDigitMapDigit,std::allocator< pj::ToneDigitMapDigit > >::difference_type id = i;
      std::vector< pj::ToneDigitMapDigit,std::allocator< pj::ToneDigitMapDigit > >::difference_type jd = j;
      swig::setslice(self, id, jd, step, v);
    }
SWIGINTERN void std_vector_Sl_pj_ToneDigitMapDigit_Sg____setitem____SWIG_1(std::vector< pj::ToneDigitMapDigit > *self,PySliceObject *slice){
      Py_ssize_t i, j, step;
      if( !PySlice_Check(slice) ) {
        SWIG_Error(SWIG_TypeError, "Slice object expected.");
        return;
      }
      PySlice_GetIndices(SWIGPY_SLICE_ARG(slice), (Py_ssize_t)self->size(), &i, &j, &step);
      std::vector< pj::ToneDigitMapDigit,std::allocator< pj::ToneDigitMapDigit > >::difference_type id = i;
      std::vector< pj::ToneDigitMapDigit,std::allocator< pj::ToneDigitMapDigit > >::difference_type jd = j;
      swig::delslice(self, id, jd, step);
    }
SWIGINTERN void std_vector_Sl_pj_ToneDigitMapDigit_Sg____delitem____SWIG_1(std::vector< pj::ToneDigitMapDigit > *self,PySliceObject *slice){
      Py_ssize_t i, j, step;
      if( !PySlice_Check(slice) ) {
        SWIG_Error(SWIG_TypeError, "Slice object expected.");
        return;
      }
      PySlice_GetIndices(SWIGPY_SLICE_ARG(slice), (Py_ssize_t)self->size(), &i, &j, &step);
      std::vector< pj::ToneDigitMapDigit,std::allocator< pj::ToneDigitMapDigit > >::difference_type id = i;
      std::vector< pj::ToneDigitMapDigit,std::allocator< pj::ToneDigitMapDigit > >::difference_type jd = j;
      swig::delslice(self, id, jd, step);
    }
SWIGINTERN std::vector< pj::ToneDigitMapDigit >::value_type const &std_vector_Sl_pj_ToneDigitMapDigit_Sg____getitem____SWIG_1(std::vector< pj::ToneDigitMapDigit > const *self,std::vector< pj::ToneDigitMapDigit >::difference_type i){
      return *(swig::cgetpos(self, i));
    }
SWIGINTERN void std_vector_Sl_pj_ToneDigitMapDigit_Sg____setitem____SWIG_2(std::vector< pj::ToneDigitMapDigit > *self,std::vector< pj::ToneDigitMapDigit >::difference_type i,std::vector< pj::ToneDigitMapDigit >::value_type const &x){
      *(swig::getpos(self,i)) = x;
    }
SWIGINTERN std::vector< pj::ToneDigitMapDigit >::value_type std_vector_Sl_pj_ToneDigitMapDigit_Sg__pop(std::vector< pj::ToneDigitMapDigit > *self){
      if (self->size() == 0)
	throw std::out_of_range("pop from empty container");
      std::vector< pj::ToneDigitMapDigit,std::allocator< pj::ToneDigitMapDigit > >::value_type x = self->back();
      self->pop_back();
      return x;
    }
SWIGINTERN void std_vector_Sl_pj_ToneDigitMapDigit_Sg__append(std::vector< pj::ToneDigitMapDigit > *self,std::vector< pj::ToneDigitMapDigit >::value_type const &x){
      self->push_back(x);
    }
SWIGINTERN std::vector< pj::ToneDigitMapDigit >::iterator std_vector_Sl_pj_ToneDigitMapDigit_Sg__erase__SWIG_0(std::vector< pj::ToneDigitMapDigit > *self,std::vector< pj::ToneDigitMapDigit >::iterator pos){ return self->erase(pos); }
SWIGINTERN std::vector< pj::ToneDigitMapDigit >::iterator std_vector_Sl_pj_ToneDigitMapDigit_Sg__erase__SWIG_1(std::vector< pj::ToneDigitMapDigit > *self,std::vector< pj::ToneDigitMapDigit >::iterator first,std::vector< pj::ToneDigitMapDigit >::iterator last){ return self->erase(first, last); }
SWIGINTERN std::vector< pj::ToneDigitMapDigit >::iterator std_vector_Sl_pj_ToneDigitMapDigit_Sg__insert__SWIG_0(std::vector< pj::ToneDigitMapDigit > *self,std::vector< pj::ToneDigitMapDigit >::iterator pos,std::vector< pj::ToneDigitMapDigit >::value_type const &x){ return self->insert(pos, x); }
SWIGINTERN void std_vector_Sl_pj_ToneDigitMapDigit_Sg__insert__SWIG_1(std::vector< pj::ToneDigitMapDigit > *self,std::vector< pj::ToneDigitMapDigit >::iterator pos,std::vector< pj::ToneDigitMapDigit >::size_type n,std::vector< pj::ToneDigitMapDigit >::value_type const &x){ self->insert(pos, n, x); }

  namespace swig {
    template <>  struct traits< pj::AudioDevInfo > {
      typedef pointer_category category;
      static const char* type_name() { return"pj::AudioDevInfo"; }
    };
  }


      namespace swig {
	template <>  struct traits<std::vector< pj::AudioDevInfo*, std::allocator< pj::AudioDevInfo * > > > {
	  typedef value_category category;
	  static const char* type_name() {
	    return "std::vector<" "pj::AudioDevInfo" " *," "std::allocator< pj::AudioDevInfo * >" " >";
	  }
	};
      }
    
SWIGINTERN swig::SwigPyIterator *std_vector_Sl_pj_AudioDevInfo_Sm__Sg__iterator(std::vector< pj::AudioDevInfo * > *self,PyObject **PYTHON_SELF){
      return swig::make_output_iterator(self->begin(), self->begin(), self->end(), *PYTHON_SELF);
    }
SWIGINTERN bool std_vector_Sl_pj_AudioDevInfo_Sm__Sg____nonzero__(std::vector< pj::AudioDevInfo * > const *self){
      return !(self->empty());
    }
SWIGINTERN bool std_vector_Sl_pj_AudioDevInfo_Sm__Sg____bool__(std::vector< pj::AudioDevInfo * > const *self){
      return !(self->empty());
    }
SWIGINTERN std::vector< pj::AudioDevInfo * >::size_type std_vector_Sl_pj_AudioDevInfo_Sm__Sg____len__(std::vector< pj::AudioDevInfo * > const *self){
      return self->size();
    }
SWIGINTERN std::vector< pj::AudioDevInfo *,std::allocator< pj::AudioDevInfo * > > *std_vector_Sl_pj_AudioDevInfo_Sm__Sg____getslice__(std::vector< pj::AudioDevInfo * > *self,std::vector< pj::AudioDevInfo * >::difference_type i,std::vector< pj::AudioDevInfo * >::difference_type j){
      return swig::getslice(self, i, j, 1);
    }
SWIGINTERN void std_vector_Sl_pj_AudioDevInfo_Sm__Sg____setslice____SWIG_0(std::vector< pj::AudioDevInfo * > *self,std::vector< pj::AudioDevInfo * >::difference_type i,std::vector< pj::AudioDevInfo * >::difference_type j){
      swig::setslice(self, i, j, 1, std::vector< pj::AudioDevInfo*,std::allocator< pj::AudioDevInfo * > >());
    }
SWIGINTERN void std_vector_Sl_pj_AudioDevInfo_Sm__Sg____setslice____SWIG_1(std::vector< pj::AudioDevInfo * > *self,std::vector< pj::AudioDevInfo * >::difference_type i,std::vector< pj::AudioDevInfo * >::difference_type j,std::vector< pj::AudioDevInfo *,std::allocator< pj::AudioDevInfo * > > const &v){
      swig::setslice(self, i, j, 1, v);
    }
SWIGINTERN void std_vector_Sl_pj_AudioDevInfo_Sm__Sg____delslice__(std::vector< pj::AudioDevInfo * > *self,std::vector< pj::AudioDevInfo * >::difference_type i,std::vector< pj::AudioDevInfo * >::difference_type j){
      swig::delslice(self, i, j, 1);
    }
SWIGINTERN void std_vector_Sl_pj_AudioDevInfo_Sm__Sg____delitem____SWIG_0(std::vector< pj::AudioDevInfo * > *self,std::vector< pj::AudioDevInfo * >::difference_type i){
      swig::erase(self, swig::getpos(self, i));
    }
SWIGINTERN std::vector< pj::AudioDevInfo *,std::allocator< pj::AudioDevInfo * > > *std_vector_Sl_pj_AudioDevInfo_Sm__Sg____getitem____SWIG_0(std::vector< pj::AudioDevInfo * > *self,PySliceObject *slice){
      Py_ssize_t i, j, step;
      if( !PySlice_Check(slice) ) {
        SWIG_Error(SWIG_TypeError, "Slice object expected.");
        return NULL;
      }
      PySlice_GetIndices(SWIGPY_SLICE_ARG(slice), (Py_ssize_t)self->size(), &i, &j, &step);
      std::vector< pj::AudioDevInfo*,std::allocator< pj::AudioDevInfo * > >::difference_type id = i;
      std::vector< pj::AudioDevInfo*,std::allocator< pj::AudioDevInfo * > >::difference_type jd = j;
      return swig::getslice(self, id, jd, step);
    }
SWIGINTERN void std_vector_Sl_pj_AudioDevInfo_Sm__Sg____setitem____SWIG_0(std::vector< pj::AudioDevInfo * > *self,PySliceObject *slice,std::vector< pj::AudioDevInfo *,std::allocator< pj::AudioDevInfo * > > const &v){
      Py_ssize_t i, j, step;
      if( !PySlice_Check(slice) ) {
        SWIG_Error(SWIG_TypeError, "Slice object expected.");
        return;
      }
      PySlice_GetIndices(SWIGPY_SLICE_ARG(slice), (Py_ssize_t)self->size(), &i, &j, &step);
      std::vector< pj::AudioDevInfo*,std::allocator< pj::AudioDevInfo * > >::difference_type id = i;
      std::vector< pj::AudioDevInfo*,std::allocator< pj::AudioDevInfo * > >::difference_type jd = j;
      swig::setslice(self, id, jd, step, v);
    }
SWIGINTERN void std_vector_Sl_pj_AudioDevInfo_Sm__Sg____setitem____SWIG_1(std::vector< pj::AudioDevInfo * > *self,PySliceObject *slice){
      Py_ssize_t i, j, step;
      if( !PySlice_Check(slice) ) {
        SWIG_Error(SWIG_TypeError, "Slice object expected.");
        return;
      }
      PySlice_GetIndices(SWIGPY_SLICE_ARG(slice), (Py_ssize_t)self->size(), &i, &j, &step);
      std::vector< pj::AudioDevInfo*,std::allocator< pj::AudioDevInfo * > >::difference_type id = i;
      std::vector< pj::AudioDevInfo*,std::allocator< pj::AudioDevInfo * > >::difference_type jd = j;
      swig::delslice(self, id, jd, step);
    }
SWIGINTERN void std_vector_Sl_pj_AudioDevInfo_Sm__Sg____delitem____SWIG_1(std::vector< pj::AudioDevInfo * > *self,PySliceObject *slice){
      Py_ssize_t i, j, step;
      if( !PySlice_Check(slice) ) {
        SWIG_Error(SWIG_TypeError, "Slice object expected.");
        return;
      }
      PySlice_GetIndices(SWIGPY_SLICE_ARG(slice), (Py_ssize_t)self->size(), &i, &j, &step);
      std::vector< pj::AudioDevInfo*,std::allocator< pj::AudioDevInfo * > >::difference_type id = i;
      std::vector< pj::AudioDevInfo*,std::allocator< pj::AudioDevInfo * > >::difference_type jd = j;
      swig::delslice(self, id, jd, step);
    }
SWIGINTERN std::vector< pj::AudioDevInfo * >::value_type std_vector_Sl_pj_AudioDevInfo_Sm__Sg____getitem____SWIG_1(std::vector< pj::AudioDevInfo * > *self,std::vector< pj::AudioDevInfo * >::difference_type i){
      return *(swig::cgetpos(self, i));
    }
SWIGINTERN void std_vector_Sl_pj_AudioDevInfo_Sm__Sg____setitem____SWIG_2(std::vector< pj::AudioDevInfo * > *self,std::vector< pj::AudioDevInfo * >::difference_type i,std::vector< pj::AudioDevInfo * >::value_type x){
      *(swig::getpos(self,i)) = x;
    }
SWIGINTERN std::vector< pj::AudioDevInfo * >::value_type std_vector_Sl_pj_AudioDevInfo_Sm__Sg__pop(std::vector< pj::AudioDevInfo * > *self){
      if (self->size() == 0)
	throw std::out_of_range("pop from empty container");
      std::vector< pj::AudioDevInfo*,std::allocator< pj::AudioDevInfo * > >::value_type x = self->back();
      self->pop_back();
      return x;
    }
SWIGINTERN void std_vector_Sl_pj_AudioDevInfo_Sm__Sg__append(std::vector< pj::AudioDevInfo * > *self,std::vector< pj::AudioDevInfo * >::value_type x){
      self->push_back(x);
    }
SWIGINTERN std::vector< pj::AudioDevInfo * >::iterator std_vector_Sl_pj_AudioDevInfo_Sm__Sg__erase__SWIG_0(std::vector< pj::AudioDevInfo * > *self,std::vector< pj::AudioDevInfo * >::iterator pos){ return self->erase(pos); }
SWIGINTERN std::vector< pj::AudioDevInfo * >::iterator std_vector_Sl_pj_AudioDevInfo_Sm__Sg__erase__SWIG_1(std::vector< pj::AudioDevInfo * > *self,std::vector< pj::AudioDevInfo * >::iterator first,std::vector< pj::AudioDevInfo * >::iterator last){ return self->erase(first, last); }
SWIGINTERN std::vector< pj::AudioDevInfo * >::iterator std_vector_Sl_pj_AudioDevInfo_Sm__Sg__insert__SWIG_0(std::vector< pj::AudioDevInfo * > *self,std::vector< pj::AudioDevInfo * >::iterator pos,std::vector< pj::AudioDevInfo * >::value_type x){ return self->insert(pos, x); }
SWIGINTERN void std_vector_Sl_pj_AudioDevInfo_Sm__Sg__insert__SWIG_1(std::vector< pj::AudioDevInfo * > *self,std::vector< pj::AudioDevInfo * >::iterator pos,std::vector< pj::AudioDevInfo * >::size_type n,std::vector< pj::AudioDevInfo * >::value_type x){ self->insert(pos, n, x); }

      namespace swig {
	template <>  struct traits<std::vector< pj::AudioDevInfo, std::allocator< pj::AudioDevInfo > > > {
	  typedef pointer_category category;
	  static const char* type_name() {
	    return "std::vector<" "pj::AudioDevInfo" "," "std::allocator< pj::AudioDevInfo >" " >";
	  }
	};
      }
    
SWIGINTERN swig::SwigPyIterator *std_vector_Sl_pj_AudioDevInfo_Sg__iterator(std::vector< pj::AudioDevInfo > *self,PyObject **PYTHON_SELF){
      return swig::make_output_iterator(self->begin(), self->begin(), self->end(), *PYTHON_SELF);
    }
SWIGINTERN bool std_vector_Sl_pj_AudioDevInfo_Sg____nonzero__(std::vector< pj::AudioDevInfo > const *self){
      return !(self->empty());
    }
SWIGINTERN bool std_vector_Sl_pj_AudioDevInfo_Sg____bool__(std::vector< pj::AudioDevInfo > const *self){
      return !(self->empty());
    }
SWIGINTERN std::vector< pj::AudioDevInfo >::size_type std_vector_Sl_pj_AudioDevInfo_Sg____len__(std::vector< pj::AudioDevInfo > const *self){
      return self->size();
    }
SWIGINTERN std::vector< pj::AudioDevInfo,std::allocator< pj::AudioDevInfo > > *std_vector_Sl_pj_AudioDevInfo_Sg____getslice__(std::vector< pj::AudioDevInfo > *self,std::vector< pj::AudioDevInfo >::difference_type i,std::vector< pj::AudioDevInfo >::difference_type j){
      return swig::getslice(self, i, j, 1);
    }
SWIGINTERN void std_vector_Sl_pj_AudioDevInfo_Sg____setslice____SWIG_0(std::vector< pj::AudioDevInfo > *self,std::vector< pj::AudioDevInfo >::difference_type i,std::vector< pj::AudioDevInfo >::difference_type j){
      swig::setslice(self, i, j, 1, std::vector< pj::AudioDevInfo,std::allocator< pj::AudioDevInfo > >());
    }
SWIGINTERN void std_vector_Sl_pj_AudioDevInfo_Sg____setslice____SWIG_1(std::vector< pj::AudioDevInfo > *self,std::vector< pj::AudioDevInfo >::difference_type i,std::vector< pj::AudioDevInfo >::difference_type j,std::vector< pj::AudioDevInfo,std::allocator< pj::AudioDevInfo > > const &v){
      swig::setslice(self, i, j, 1, v);
    }
SWIGINTERN void std_vector_Sl_pj_AudioDevInfo_Sg____delslice__(std::vector< pj::AudioDevInfo > *self,std::vector< pj::AudioDevInfo >::difference_type i,std::vector< pj::AudioDevInfo >::difference_type j){
      swig::delslice(self, i, j, 1);
    }
SWIGINTERN void std_vector_Sl_pj_AudioDevInfo_Sg____delitem____SWIG_0(std::vector< pj::AudioDevInfo > *self,std::vector< pj::AudioDevInfo >::difference_type i){
      swig::erase(self, swig::getpos(self, i));
    }
SWIGINTERN std::vector< pj::AudioDevInfo,std::allocator< pj::AudioDevInfo > > *std_vector_Sl_pj_AudioDevInfo_Sg____getitem____SWIG_0(std::vector< pj::AudioDevInfo > *self,PySliceObject *slice){
      Py_ssize_t i, j, step;
      if( !PySlice_Check(slice) ) {
        SWIG_Error(SWIG_TypeError, "Slice object expected.");
        return NULL;
      }
      PySlice_GetIndices(SWIGPY_SLICE_ARG(slice), (Py_ssize_t)self->size(), &i, &j, &step);
      std::vector< pj::AudioDevInfo,std::allocator< pj::AudioDevInfo > >::difference_type id = i;
      std::vector< pj::AudioDevInfo,std::allocator< pj::AudioDevInfo > >::difference_type jd = j;
      return swig::getslice(self, id, jd, step);
    }
SWIGINTERN void std_vector_Sl_pj_AudioDevInfo_Sg____setitem____SWIG_0(std::vector< pj::AudioDevInfo > *self,PySliceObject *slice,std::vector< pj::AudioDevInfo,std::allocator< pj::AudioDevInfo > > const &v){
      Py_ssize_t i, j, step;
      if( !PySlice_Check(slice) ) {
        SWIG_Error(SWIG_TypeError, "Slice object expected.");
        return;
      }
      PySlice_GetIndices(SWIGPY_SLICE_ARG(slice), (Py_ssize_t)self->size(), &i, &j, &step);
      std::vector< pj::AudioDevInfo,std::allocator< pj::AudioDevInfo > >::difference_type id = i;
      std::vector< pj::AudioDevInfo,std::allocator< pj::AudioDevInfo > >::difference_type jd = j;
      swig::setslice(self, id, jd, step, v);
    }
SWIGINTERN void std_vector_Sl_pj_AudioDevInfo_Sg____setitem____SWIG_1(std::vector< pj::AudioDevInfo > *self,PySliceObject *slice){
      Py_ssize_t i, j, step;
      if( !PySlice_Check(slice) ) {
        SWIG_Error(SWIG_TypeError, "Slice object expected.");
        return;
      }
      PySlice_GetIndices(SWIGPY_SLICE_ARG(slice), (Py_ssize_t)self->size(), &i, &j, &step);
      std::vector< pj::AudioDevInfo,std::allocator< pj::AudioDevInfo > >::difference_type id = i;
      std::vector< pj::AudioDevInfo,std::allocator< pj::AudioDevInfo > >::difference_type jd = j;
      swig::delslice(self, id, jd, step);
    }
SWIGINTERN void std_vector_Sl_pj_AudioDevInfo_Sg____delitem____SWIG_1(std::vector< pj::AudioDevInfo > *self,PySliceObject *slice){
      Py_ssize_t i, j, step;
      if( !PySlice_Check(slice) ) {
        SWIG_Error(SWIG_TypeError, "Slice object expected.");
        return;
      }
      PySlice_GetIndices(SWIGPY_SLICE_ARG(slice), (Py_ssize_t)self->size(), &i, &j, &step);
      std::vector< pj::AudioDevInfo,std::allocator< pj::AudioDevInfo > >::difference_type id = i;
      std::vector< pj::AudioDevInfo,std::allocator< pj::AudioDevInfo > >::difference_type jd = j;
      swig::delslice(self, id, jd, step);
    }
SWIGINTERN std::vector< pj::AudioDevInfo >::value_type const &std_vector_Sl_pj_AudioDevInfo_Sg____getitem____SWIG_1(std::vector< pj::AudioDevInfo > const *self,std::vector< pj::AudioDevInfo >::difference_type i){
      return *(swig::cgetpos(self, i));
    }
SWIGINTERN void std_vector_Sl_pj_AudioDevInfo_Sg____setitem____SWIG_2(std::vector< pj::AudioDevInfo > *self,std::vector< pj::AudioDevInfo >::difference_type i,std::vector< pj::AudioDevInfo >::value_type const &x){
      *(swig::getpos(self,i)) = x;
    }
SWIGINTERN std::vector< pj::AudioDevInfo >::value_type std_vector_Sl_pj_AudioDevInfo_Sg__pop(std::vector< pj::AudioDevInfo > *self){
      if (self->size() == 0)
	throw std::out_of_range("pop from empty container");
      std::vector< pj::AudioDevInfo,std::allocator< pj::AudioDevInfo > >::value_type x = self->back();
      self->pop_back();
      return x;
    }
SWIGINTERN void std_vector_Sl_pj_AudioDevInfo_Sg__append(std::vector< pj::AudioDevInfo > *self,std::vector< pj::AudioDevInfo >::value_type const &x){
      self->push_back(x);
    }
SWIGINTERN std::vector< pj::AudioDevInfo >::iterator std_vector_Sl_pj_AudioDevInfo_Sg__erase__SWIG_0(std::vector< pj::AudioDevInfo > *self,std::vector< pj::AudioDevInfo >::iterator pos){ return self->erase(pos); }
SWIGINTERN std::vector< pj::AudioDevInfo >::iterator std_vector_Sl_pj_AudioDevInfo_Sg__erase__SWIG_1(std::vector< pj::AudioDevInfo > *self,std::vector< pj::AudioDevInfo >::iterator first,std::vector< pj::AudioDevInfo >::iterator last){ return self->erase(first, last); }
SWIGINTERN std::vector< pj::AudioDevInfo >::iterator std_vector_Sl_pj_AudioDevInfo_Sg__insert__SWIG_0(std::vector< pj::AudioDevInfo > *self,std::vector< pj::AudioDevInfo >::iterator pos,std::vector< pj::AudioDevInfo >::value_type const &x){ return self->insert(pos, x); }
SWIGINTERN void std_vector_Sl_pj_AudioDevInfo_Sg__insert__SWIG_1(std::vector< pj::AudioDevInfo > *self,std::vector< pj::AudioDevInfo >::iterator pos,std::vector< pj::AudioDevInfo >::size_type n,std::vector< pj::AudioDevInfo >::value_type const &x){ self->insert(pos, n, x); }

  namespace swig {
    template <>  struct traits< pj::CodecInfo > {
      typedef pointer_category category;
      static const char* type_name() { return"pj::CodecInfo"; }
    };
  }


      namespace swig {
	template <>  struct traits<std::vector< pj::CodecInfo*, std::allocator< pj::CodecInfo * > > > {
	  typedef value_category category;
	  static const char* type_name() {
	    return "std::vector<" "pj::CodecInfo" " *," "std::allocator< pj::CodecInfo * >" " >";
	  }
	};
      }
    
SWIGINTERN swig::SwigPyIterator *std_vector_Sl_pj_CodecInfo_Sm__Sg__iterator(std::vector< pj::CodecInfo * > *self,PyObject **PYTHON_SELF){
      return swig::make_output_iterator(self->begin(), self->begin(), self->end(), *PYTHON_SELF);
    }
SWIGINTERN bool std_vector_Sl_pj_CodecInfo_Sm__Sg____nonzero__(std::vector< pj::CodecInfo * > const *self){
      return !(self->empty());
    }
SWIGINTERN bool std_vector_Sl_pj_CodecInfo_Sm__Sg____bool__(std::vector< pj::CodecInfo * > const *self){
      return !(self->empty());
    }
SWIGINTERN std::vector< pj::CodecInfo * >::size_type std_vector_Sl_pj_CodecInfo_Sm__Sg____len__(std::vector< pj::CodecInfo * > const *self){
      return self->size();
    }
SWIGINTERN std::vector< pj::CodecInfo *,std::allocator< pj::CodecInfo * > > *std_vector_Sl_pj_CodecInfo_Sm__Sg____getslice__(std::vector< pj::CodecInfo * > *self,std::vector< pj::CodecInfo * >::difference_type i,std::vector< pj::CodecInfo * >::difference_type j){
      return swig::getslice(self, i, j, 1);
    }
SWIGINTERN void std_vector_Sl_pj_CodecInfo_Sm__Sg____setslice____SWIG_0(std::vector< pj::CodecInfo * > *self,std::vector< pj::CodecInfo * >::difference_type i,std::vector< pj::CodecInfo * >::difference_type j){
      swig::setslice(self, i, j, 1, std::vector< pj::CodecInfo*,std::allocator< pj::CodecInfo * > >());
    }
SWIGINTERN void std_vector_Sl_pj_CodecInfo_Sm__Sg____setslice____SWIG_1(std::vector< pj::CodecInfo * > *self,std::vector< pj::CodecInfo * >::difference_type i,std::vector< pj::CodecInfo * >::difference_type j,std::vector< pj::CodecInfo *,std::allocator< pj::CodecInfo * > > const &v){
      swig::setslice(self, i, j, 1, v);
    }
SWIGINTERN void std_vector_Sl_pj_CodecInfo_Sm__Sg____delslice__(std::vector< pj::CodecInfo * > *self,std::vector< pj::CodecInfo * >::difference_type i,std::vector< pj::CodecInfo * >::difference_type j){
      swig::delslice(self, i, j, 1);
    }
SWIGINTERN void std_vector_Sl_pj_CodecInfo_Sm__Sg____delitem____SWIG_0(std::vector< pj::CodecInfo * > *self,std::vector< pj::CodecInfo * >::difference_type i){
      swig::erase(self, swig::getpos(self, i));
    }
SWIGINTERN std::vector< pj::CodecInfo *,std::allocator< pj::CodecInfo * > > *std_vector_Sl_pj_CodecInfo_Sm__Sg____getitem____SWIG_0(std::vector< pj::CodecInfo * > *self,PySliceObject *slice){
      Py_ssize_t i, j, step;
      if( !PySlice_Check(slice) ) {
        SWIG_Error(SWIG_TypeError, "Slice object expected.");
        return NULL;
      }
      PySlice_GetIndices(SWIGPY_SLICE_ARG(slice), (Py_ssize_t)self->size(), &i, &j, &step);
      std::vector< pj::CodecInfo*,std::allocator< pj::CodecInfo * > >::difference_type id = i;
      std::vector< pj::CodecInfo*,std::allocator< pj::CodecInfo * > >::difference_type jd = j;
      return swig::getslice(self, id, jd, step);
    }
SWIGINTERN void std_vector_Sl_pj_CodecInfo_Sm__Sg____setitem____SWIG_0(std::vector< pj::CodecInfo * > *self,PySliceObject *slice,std::vector< pj::CodecInfo *,std::allocator< pj::CodecInfo * > > const &v){
      Py_ssize_t i, j, step;
      if( !PySlice_Check(slice) ) {
        SWIG_Error(SWIG_TypeError, "Slice object expected.");
        return;
      }
      PySlice_GetIndices(SWIGPY_SLICE_ARG(slice), (Py_ssize_t)self->size(), &i, &j, &step);
      std::vector< pj::CodecInfo*,std::allocator< pj::CodecInfo * > >::difference_type id = i;
      std::vector< pj::CodecInfo*,std::allocator< pj::CodecInfo * > >::difference_type jd = j;
      swig::setslice(self, id, jd, step, v);
    }
SWIGINTERN void std_vector_Sl_pj_CodecInfo_Sm__Sg____setitem____SWIG_1(std::vector< pj::CodecInfo * > *self,PySliceObject *slice){
      Py_ssize_t i, j, step;
      if( !PySlice_Check(slice) ) {
        SWIG_Error(SWIG_TypeError, "Slice object expected.");
        return;
      }
      PySlice_GetIndices(SWIGPY_SLICE_ARG(slice), (Py_ssize_t)self->size(), &i, &j, &step);
      std::vector< pj::CodecInfo*,std::allocator< pj::CodecInfo * > >::difference_type id = i;
      std::vector< pj::CodecInfo*,std::allocator< pj::CodecInfo * > >::difference_type jd = j;
      swig::delslice(self, id, jd, step);
    }
SWIGINTERN void std_vector_Sl_pj_CodecInfo_Sm__Sg____delitem____SWIG_1(std::vector< pj::CodecInfo * > *self,PySliceObject *slice){
      Py_ssize_t i, j, step;
      if( !PySlice_Check(slice) ) {
        SWIG_Error(SWIG_TypeError, "Slice object expected.");
        return;
      }
      PySlice_GetIndices(SWIGPY_SLICE_ARG(slice), (Py_ssize_t)self->size(), &i, &j, &step);
      std::vector< pj::CodecInfo*,std::allocator< pj::CodecInfo * > >::difference_type id = i;
      std::vector< pj::CodecInfo*,std::allocator< pj::CodecInfo * > >::difference_type jd = j;
      swig::delslice(self, id, jd, step);
    }
SWIGINTERN std::vector< pj::CodecInfo * >::value_type std_vector_Sl_pj_CodecInfo_Sm__Sg____getitem____SWIG_1(std::vector< pj::CodecInfo * > *self,std::vector< pj::CodecInfo * >::difference_type i){
      return *(swig::cgetpos(self, i));
    }
SWIGINTERN void std_vector_Sl_pj_CodecInfo_Sm__Sg____setitem____SWIG_2(std::vector< pj::CodecInfo * > *self,std::vector< pj::CodecInfo * >::difference_type i,std::vector< pj::CodecInfo * >::value_type x){
      *(swig::getpos(self,i)) = x;
    }
SWIGINTERN std::vector< pj::CodecInfo * >::value_type std_vector_Sl_pj_CodecInfo_Sm__Sg__pop(std::vector< pj::CodecInfo * > *self){
      if (self->size() == 0)
	throw std::out_of_range("pop from empty container");
      std::vector< pj::CodecInfo*,std::allocator< pj::CodecInfo * > >::value_type x = self->back();
      self->pop_back();
      return x;
    }
SWIGINTERN void std_vector_Sl_pj_CodecInfo_Sm__Sg__append(std::vector< pj::CodecInfo * > *self,std::vector< pj::CodecInfo * >::value_type x){
      self->push_back(x);
    }
SWIGINTERN std::vector< pj::CodecInfo * >::iterator std_vector_Sl_pj_CodecInfo_Sm__Sg__erase__SWIG_0(std::vector< pj::CodecInfo * > *self,std::vector< pj::CodecInfo * >::iterator pos){ return self->erase(pos); }
SWIGINTERN std::vector< pj::CodecInfo * >::iterator std_vector_Sl_pj_CodecInfo_Sm__Sg__erase__SWIG_1(std::vector< pj::CodecInfo * > *self,std::vector< pj::CodecInfo * >::iterator first,std::vector< pj::CodecInfo * >::iterator last){ return self->erase(first, last); }
SWIGINTERN std::vector< pj::CodecInfo * >::iterator std_vector_Sl_pj_CodecInfo_Sm__Sg__insert__SWIG_0(std::vector< pj::CodecInfo * > *self,std::vector< pj::CodecInfo * >::iterator pos,std::vector< pj::CodecInfo * >::value_type x){ return self->insert(pos, x); }
SWIGINTERN void std_vector_Sl_pj_CodecInfo_Sm__Sg__insert__SWIG_1(std::vector< pj::CodecInfo * > *self,std::vector< pj::CodecInfo * >::iterator pos,std::vector< pj::CodecInfo * >::size_type n,std::vector< pj::CodecInfo * >::value_type x){ self->insert(pos, n, x); }

      namespace swig {
	template <>  struct traits<std::vector< pj::CodecInfo, std::allocator< pj::CodecInfo > > > {
	  typedef pointer_category category;
	  static const char* type_name() {
	    return "std::vector<" "pj::CodecInfo" "," "std::allocator< pj::CodecInfo >" " >";
	  }
	};
      }
    
SWIGINTERN swig::SwigPyIterator *std_vector_Sl_pj_CodecInfo_Sg__iterator(std::vector< pj::CodecInfo > *self,PyObject **PYTHON_SELF){
      return swig::make_output_iterator(self->begin(), self->begin(), self->end(), *PYTHON_SELF);
    }
SWIGINTERN bool std_vector_Sl_pj_CodecInfo_Sg____nonzero__(std::vector< pj::CodecInfo > const *self){
      return !(self->empty());
    }
SWIGINTERN bool std_vector_Sl_pj_CodecInfo_Sg____bool__(std::vector< pj::CodecInfo > const *self){
      return !(self->empty());
    }
SWIGINTERN std::vector< pj::CodecInfo >::size_type std_vector_Sl_pj_CodecInfo_Sg____len__(std::vector< pj::CodecInfo > const *self){
      return self->size();
    }
SWIGINTERN std::vector< pj::CodecInfo,std::allocator< pj::CodecInfo > > *std_vector_Sl_pj_CodecInfo_Sg____getslice__(std::vector< pj::CodecInfo > *self,std::vector< pj::CodecInfo >::difference_type i,std::vector< pj::CodecInfo >::difference_type j){
      return swig::getslice(self, i, j, 1);
    }
SWIGINTERN void std_vector_Sl_pj_CodecInfo_Sg____setslice____SWIG_0(std::vector< pj::CodecInfo > *self,std::vector< pj::CodecInfo >::difference_type i,std::vector< pj::CodecInfo >::difference_type j){
      swig::setslice(self, i, j, 1, std::vector< pj::CodecInfo,std::allocator< pj::CodecInfo > >());
    }
SWIGINTERN void std_vector_Sl_pj_CodecInfo_Sg____setslice____SWIG_1(std::vector< pj::CodecInfo > *self,std::vector< pj::CodecInfo >::difference_type i,std::vector< pj::CodecInfo >::difference_type j,std::vector< pj::CodecInfo,std::allocator< pj::CodecInfo > > const &v){
      swig::setslice(self, i, j, 1, v);
    }
SWIGINTERN void std_vector_Sl_pj_CodecInfo_Sg____delslice__(std::vector< pj::CodecInfo > *self,std::vector< pj::CodecInfo >::difference_type i,std::vector< pj::CodecInfo >::difference_type j){
      swig::delslice(self, i, j, 1);
    }
SWIGINTERN void std_vector_Sl_pj_CodecInfo_Sg____delitem____SWIG_0(std::vector< pj::CodecInfo > *self,std::vector< pj::CodecInfo >::difference_type i){
      swig::erase(self, swig::getpos(self, i));
    }
SWIGINTERN std::vector< pj::CodecInfo,std::allocator< pj::CodecInfo > > *std_vector_Sl_pj_CodecInfo_Sg____getitem____SWIG_0(std::vector< pj::CodecInfo > *self,PySliceObject *slice){
      Py_ssize_t i, j, step;
      if( !PySlice_Check(slice) ) {
        SWIG_Error(SWIG_TypeError, "Slice object expected.");
        return NULL;
      }
      PySlice_GetIndices(SWIGPY_SLICE_ARG(slice), (Py_ssize_t)self->size(), &i, &j, &step);
      std::vector< pj::CodecInfo,std::allocator< pj::CodecInfo > >::difference_type id = i;
      std::vector< pj::CodecInfo,std::allocator< pj::CodecInfo > >::difference_type jd = j;
      return swig::getslice(self, id, jd, step);
    }
SWIGINTERN void std_vector_Sl_pj_CodecInfo_Sg____setitem____SWIG_0(std::vector< pj::CodecInfo > *self,PySliceObject *slice,std::vector< pj::CodecInfo,std::allocator< pj::CodecInfo > > const &v){
      Py_ssize_t i, j, step;
      if( !PySlice_Check(slice) ) {
        SWIG_Error(SWIG_TypeError, "Slice object expected.");
        return;
      }
      PySlice_GetIndices(SWIGPY_SLICE_ARG(slice), (Py_ssize_t)self->size(), &i, &j, &step);
      std::vector< pj::CodecInfo,std::allocator< pj::CodecInfo > >::difference_type id = i;
      std::vector< pj::CodecInfo,std::allocator< pj::CodecInfo > >::difference_type jd = j;
      swig::setslice(self, id, jd, step, v);
    }
SWIGINTERN void std_vector_Sl_pj_CodecInfo_Sg____setitem____SWIG_1(std::vector< pj::CodecInfo > *self,PySliceObject *slice){
      Py_ssize_t i, j, step;
      if( !PySlice_Check(slice) ) {
        SWIG_Error(SWIG_TypeError, "Slice object expected.");
        return;
      }
      PySlice_GetIndices(SWIGPY_SLICE_ARG(slice), (Py_ssize_t)self->size(), &i, &j, &step);
      std::vector< pj::CodecInfo,std::allocator< pj::CodecInfo > >::difference_type id = i;
      std::vector< pj::CodecInfo,std::allocator< pj::CodecInfo > >::difference_type jd = j;
      swig::delslice(self, id, jd, step);
    }
SWIGINTERN void std_vector_Sl_pj_CodecInfo_Sg____delitem____SWIG_1(std::vector< pj::CodecInfo > *self,PySliceObject *slice){
      Py_ssize_t i, j, step;
      if( !PySlice_Check(slice) ) {
        SWIG_Error(SWIG_TypeError, "Slice object expected.");
        return;
      }
      PySlice_GetIndices(SWIGPY_SLICE_ARG(slice), (Py_ssize_t)self->size(), &i, &j, &step);
      std::vector< pj::CodecInfo,std::allocator< pj::CodecInfo > >::difference_type id = i;
      std::vector< pj::CodecInfo,std::allocator< pj::CodecInfo > >::difference_type jd = j;
      swig::delslice(self, id, jd, step);
    }
SWIGINTERN std::vector< pj::CodecInfo >::value_type const &std_vector_Sl_pj_CodecInfo_Sg____getitem____SWIG_1(std::vector< pj::CodecInfo > const *self,std::vector< pj::CodecInfo >::difference_type i){
      return *(swig::cgetpos(self, i));
    }
SWIGINTERN void std_vector_Sl_pj_CodecInfo_Sg____setitem____SWIG_2(std::vector< pj::CodecInfo > *self,std::vector< pj::CodecInfo >::difference_type i,std::vector< pj::CodecInfo >::value_type const &x){
      *(swig::getpos(self,i)) = x;
    }
SWIGINTERN std::vector< pj::CodecInfo >::value_type std_vector_Sl_pj_CodecInfo_Sg__pop(std::vector< pj::CodecInfo > *self){
      if (self->size() == 0)
	throw std::out_of_range("pop from empty container");
      std::vector< pj::CodecInfo,std::allocator< pj::CodecInfo > >::value_type x = self->back();
      self->pop_back();
      return x;
    }
SWIGINTERN void std_vector_Sl_pj_CodecInfo_Sg__append(std::vector< pj::CodecInfo > *self,std::vector< pj::CodecInfo >::value_type const &x){
      self->push_back(x);
    }
SWIGINTERN std::vector< pj::CodecInfo >::iterator std_vector_Sl_pj_CodecInfo_Sg__erase__SWIG_0(std::vector< pj::CodecInfo > *self,std::vector< pj::CodecInfo >::iterator pos){ return self->erase(pos); }
SWIGINTERN std::vector< pj::CodecInfo >::iterator std_vector_Sl_pj_CodecInfo_Sg__erase__SWIG_1(std::vector< pj::CodecInfo > *self,std::vector< pj::CodecInfo >::iterator first,std::vector< pj::CodecInfo >::iterator last){ return self->erase(first, last); }
SWIGINTERN std::vector< pj::CodecInfo >::iterator std_vector_Sl_pj_CodecInfo_Sg__insert__SWIG_0(std::vector< pj::CodecInfo > *self,std::vector< pj::CodecInfo >::iterator pos,std::vector< pj::CodecInfo >::value_type const &x){ return self->insert(pos, x); }
SWIGINTERN void std_vector_Sl_pj_CodecInfo_Sg__insert__SWIG_1(std::vector< pj::CodecInfo > *self,std::vector< pj::CodecInfo >::iterator pos,std::vector< pj::CodecInfo >::size_type n,std::vector< pj::CodecInfo >::value_type const &x){ self->insert(pos, n, x); }

  namespace swig {
    template <>  struct traits< pj::VideoDevInfo > {
      typedef pointer_category category;
      static const char* type_name() { return"pj::VideoDevInfo"; }
    };
  }


      namespace swig {
	template <>  struct traits<std::vector< pj::VideoDevInfo*, std::allocator< pj::VideoDevInfo * > > > {
	  typedef value_category category;
	  static const char* type_name() {
	    return "std::vector<" "pj::VideoDevInfo" " *," "std::allocator< pj::VideoDevInfo * >" " >";
	  }
	};
      }
    
SWIGINTERN swig::SwigPyIterator *std_vector_Sl_pj_VideoDevInfo_Sm__Sg__iterator(std::vector< pj::VideoDevInfo * > *self,PyObject **PYTHON_SELF){
      return swig::make_output_iterator(self->begin(), self->begin(), self->end(), *PYTHON_SELF);
    }
SWIGINTERN bool std_vector_Sl_pj_VideoDevInfo_Sm__Sg____nonzero__(std::vector< pj::VideoDevInfo * > const *self){
      return !(self->empty());
    }
SWIGINTERN bool std_vector_Sl_pj_VideoDevInfo_Sm__Sg____bool__(std::vector< pj::VideoDevInfo * > const *self){
      return !(self->empty());
    }
SWIGINTERN std::vector< pj::VideoDevInfo * >::size_type std_vector_Sl_pj_VideoDevInfo_Sm__Sg____len__(std::vector< pj::VideoDevInfo * > const *self){
      return self->size();
    }
SWIGINTERN std::vector< pj::VideoDevInfo *,std::allocator< pj::VideoDevInfo * > > *std_vector_Sl_pj_VideoDevInfo_Sm__Sg____getslice__(std::vector< pj::VideoDevInfo * > *self,std::vector< pj::VideoDevInfo * >::difference_type i,std::vector< pj::VideoDevInfo * >::difference_type j){
      return swig::getslice(self, i, j, 1);
    }
SWIGINTERN void std_vector_Sl_pj_VideoDevInfo_Sm__Sg____setslice____SWIG_0(std::vector< pj::VideoDevInfo * > *self,std::vector< pj::VideoDevInfo * >::difference_type i,std::vector< pj::VideoDevInfo * >::difference_type j){
      swig::setslice(self, i, j, 1, std::vector< pj::VideoDevInfo*,std::allocator< pj::VideoDevInfo * > >());
    }
SWIGINTERN void std_vector_Sl_pj_VideoDevInfo_Sm__Sg____setslice____SWIG_1(std::vector< pj::VideoDevInfo * > *self,std::vector< pj::VideoDevInfo * >::difference_type i,std::vector< pj::VideoDevInfo * >::difference_type j,std::vector< pj::VideoDevInfo *,std::allocator< pj::VideoDevInfo * > > const &v){
      swig::setslice(self, i, j, 1, v);
    }
SWIGINTERN void std_vector_Sl_pj_VideoDevInfo_Sm__Sg____delslice__(std::vector< pj::VideoDevInfo * > *self,std::vector< pj::VideoDevInfo * >::difference_type i,std::vector< pj::VideoDevInfo * >::difference_type j){
      swig::delslice(self, i, j, 1);
    }
SWIGINTERN void std_vector_Sl_pj_VideoDevInfo_Sm__Sg____delitem____SWIG_0(std::vector< pj::VideoDevInfo * > *self,std::vector< pj::VideoDevInfo * >::difference_type i){
      swig::erase(self, swig::getpos(self, i));
    }
SWIGINTERN std::vector< pj::VideoDevInfo *,std::allocator< pj::VideoDevInfo * > > *std_vector_Sl_pj_VideoDevInfo_Sm__Sg____getitem____SWIG_0(std::vector< pj::VideoDevInfo * > *self,PySliceObject *slice){
      Py_ssize_t i, j, step;
      if( !PySlice_Check(slice) ) {
        SWIG_Error(SWIG_TypeError, "Slice object expected.");
        return NULL;
      }
      PySlice_GetIndices(SWIGPY_SLICE_ARG(slice), (Py_ssize_t)self->size(), &i, &j, &step);
      std::vector< pj::VideoDevInfo*,std::allocator< pj::VideoDevInfo * > >::difference_type id = i;
      std::vector< pj::VideoDevInfo*,std::allocator< pj::VideoDevInfo * > >::difference_type jd = j;
      return swig::getslice(self, id, jd, step);
    }
SWIGINTERN void std_vector_Sl_pj_VideoDevInfo_Sm__Sg____setitem____SWIG_0(std::vector< pj::VideoDevInfo * > *self,PySliceObject *slice,std::vector< pj::VideoDevInfo *,std::allocator< pj::VideoDevInfo * > > const &v){
      Py_ssize_t i, j, step;
      if( !PySlice_Check(slice) ) {
        SWIG_Error(SWIG_TypeError, "Slice object expected.");
        return;
      }
      PySlice_GetIndices(SWIGPY_SLICE_ARG(slice), (Py_ssize_t)self->size(), &i, &j, &step);
      std::vector< pj::VideoDevInfo*,std::allocator< pj::VideoDevInfo * > >::difference_type id = i;
      std::vector< pj::VideoDevInfo*,std::allocator< pj::VideoDevInfo * > >::difference_type jd = j;
      swig::setslice(self, id, jd, step, v);
    }
SWIGINTERN void std_vector_Sl_pj_VideoDevInfo_Sm__Sg____setitem____SWIG_1(std::vector< pj::VideoDevInfo * > *self,PySliceObject *slice){
      Py_ssize_t i, j, step;
      if( !PySlice_Check(slice) ) {
        SWIG_Error(SWIG_TypeError, "Slice object expected.");
        return;
      }
      PySlice_GetIndices(SWIGPY_SLICE_ARG(slice), (Py_ssize_t)self->size(), &i, &j, &step);
      std::vector< pj::VideoDevInfo*,std::allocator< pj::VideoDevInfo * > >::difference_type id = i;
      std::vector< pj::VideoDevInfo*,std::allocator< pj::VideoDevInfo * > >::difference_type jd = j;
      swig::delslice(self, id, jd, step);
    }
SWIGINTERN void std_vector_Sl_pj_VideoDevInfo_Sm__Sg____delitem____SWIG_1(std::vector< pj::VideoDevInfo * > *self,PySliceObject *slice){
      Py_ssize_t i, j, step;
      if( !PySlice_Check(slice) ) {
        SWIG_Error(SWIG_TypeError, "Slice object expected.");
        return;
      }
      PySlice_GetIndices(SWIGPY_SLICE_ARG(slice), (Py_ssize_t)self->size(), &i, &j, &step);
      std::vector< pj::VideoDevInfo*,std::allocator< pj::VideoDevInfo * > >::difference_type id = i;
      std::vector< pj::VideoDevInfo*,std::allocator< pj::VideoDevInfo * > >::difference_type jd = j;
      swig::delslice(self, id, jd, step);
    }
SWIGINTERN std::vector< pj::VideoDevInfo * >::value_type std_vector_Sl_pj_VideoDevInfo_Sm__Sg____getitem____SWIG_1(std::vector< pj::VideoDevInfo * > *self,std::vector< pj::VideoDevInfo * >::difference_type i){
      return *(swig::cgetpos(self, i));
    }
SWIGINTERN void std_vector_Sl_pj_VideoDevInfo_Sm__Sg____setitem____SWIG_2(std::vector< pj::VideoDevInfo * > *self,std::vector< pj::VideoDevInfo * >::difference_type i,std::vector< pj::VideoDevInfo * >::value_type x){
      *(swig::getpos(self,i)) = x;
    }
SWIGINTERN std::vector< pj::VideoDevInfo * >::value_type std_vector_Sl_pj_VideoDevInfo_Sm__Sg__pop(std::vector< pj::VideoDevInfo * > *self){
      if (self->size() == 0)
	throw std::out_of_range("pop from empty container");
      std::vector< pj::VideoDevInfo*,std::allocator< pj::VideoDevInfo * > >::value_type x = self->back();
      self->pop_back();
      return x;
    }
SWIGINTERN void std_vector_Sl_pj_VideoDevInfo_Sm__Sg__append(std::vector< pj::VideoDevInfo * > *self,std::vector< pj::VideoDevInfo * >::value_type x){
      self->push_back(x);
    }
SWIGINTERN std::vector< pj::VideoDevInfo * >::iterator std_vector_Sl_pj_VideoDevInfo_Sm__Sg__erase__SWIG_0(std::vector< pj::VideoDevInfo * > *self,std::vector< pj::VideoDevInfo * >::iterator pos){ return self->erase(pos); }
SWIGINTERN std::vector< pj::VideoDevInfo * >::iterator std_vector_Sl_pj_VideoDevInfo_Sm__Sg__erase__SWIG_1(std::vector< pj::VideoDevInfo * > *self,std::vector< pj::VideoDevInfo * >::iterator first,std::vector< pj::VideoDevInfo * >::iterator last){ return self->erase(first, last); }
SWIGINTERN std::vector< pj::VideoDevInfo * >::iterator std_vector_Sl_pj_VideoDevInfo_Sm__Sg__insert__SWIG_0(std::vector< pj::VideoDevInfo * > *self,std::vector< pj::VideoDevInfo * >::iterator pos,std::vector< pj::VideoDevInfo * >::value_type x){ return self->insert(pos, x); }
SWIGINTERN void std_vector_Sl_pj_VideoDevInfo_Sm__Sg__insert__SWIG_1(std::vector< pj::VideoDevInfo * > *self,std::vector< pj::VideoDevInfo * >::iterator pos,std::vector< pj::VideoDevInfo * >::size_type n,std::vector< pj::VideoDevInfo * >::value_type x){ self->insert(pos, n, x); }

      namespace swig {
	template <>  struct traits<std::vector< pj::VideoDevInfo, std::allocator< pj::VideoDevInfo > > > {
	  typedef pointer_category category;
	  static const char* type_name() {
	    return "std::vector<" "pj::VideoDevInfo" "," "std::allocator< pj::VideoDevInfo >" " >";
	  }
	};
      }
    
SWIGINTERN swig::SwigPyIterator *std_vector_Sl_pj_VideoDevInfo_Sg__iterator(std::vector< pj::VideoDevInfo > *self,PyObject **PYTHON_SELF){
      return swig::make_output_iterator(self->begin(), self->begin(), self->end(), *PYTHON_SELF);
    }
SWIGINTERN bool std_vector_Sl_pj_VideoDevInfo_Sg____nonzero__(std::vector< pj::VideoDevInfo > const *self){
      return !(self->empty());
    }
SWIGINTERN bool std_vector_Sl_pj_VideoDevInfo_Sg____bool__(std::vector< pj::VideoDevInfo > const *self){
      return !(self->empty());
    }
SWIGINTERN std::vector< pj::VideoDevInfo >::size_type std_vector_Sl_pj_VideoDevInfo_Sg____len__(std::vector< pj::VideoDevInfo > const *self){
      return self->size();
    }
SWIGINTERN std::vector< pj::VideoDevInfo,std::allocator< pj::VideoDevInfo > > *std_vector_Sl_pj_VideoDevInfo_Sg____getslice__(std::vector< pj::VideoDevInfo > *self,std::vector< pj::VideoDevInfo >::difference_type i,std::vector< pj::VideoDevInfo >::difference_type j){
      return swig::getslice(self, i, j, 1);
    }
SWIGINTERN void std_vector_Sl_pj_VideoDevInfo_Sg____setslice____SWIG_0(std::vector< pj::VideoDevInfo > *self,std::vector< pj::VideoDevInfo >::difference_type i,std::vector< pj::VideoDevInfo >::difference_type j){
      swig::setslice(self, i, j, 1, std::vector< pj::VideoDevInfo,std::allocator< pj::VideoDevInfo > >());
    }
SWIGINTERN void std_vector_Sl_pj_VideoDevInfo_Sg____setslice____SWIG_1(std::vector< pj::VideoDevInfo > *self,std::vector< pj::VideoDevInfo >::difference_type i,std::vector< pj::VideoDevInfo >::difference_type j,std::vector< pj::VideoDevInfo,std::allocator< pj::VideoDevInfo > > const &v){
      swig::setslice(self, i, j, 1, v);
    }
SWIGINTERN void std_vector_Sl_pj_VideoDevInfo_Sg____delslice__(std::vector< pj::VideoDevInfo > *self,std::vector< pj::VideoDevInfo >::difference_type i,std::vector< pj::VideoDevInfo >::difference_type j){
      swig::delslice(self, i, j, 1);
    }
SWIGINTERN void std_vector_Sl_pj_VideoDevInfo_Sg____delitem____SWIG_0(std::vector< pj::VideoDevInfo > *self,std::vector< pj::VideoDevInfo >::difference_type i){
      swig::erase(self, swig::getpos(self, i));
    }
SWIGINTERN std::vector< pj::VideoDevInfo,std::allocator< pj::VideoDevInfo > > *std_vector_Sl_pj_VideoDevInfo_Sg____getitem____SWIG_0(std::vector< pj::VideoDevInfo > *self,PySliceObject *slice){
      Py_ssize_t i, j, step;
      if( !PySlice_Check(slice) ) {
        SWIG_Error(SWIG_TypeError, "Slice object expected.");
        return NULL;
      }
      PySlice_GetIndices(SWIGPY_SLICE_ARG(slice), (Py_ssize_t)self->size(), &i, &j, &step);
      std::vector< pj::VideoDevInfo,std::allocator< pj::VideoDevInfo > >::difference_type id = i;
      std::vector< pj::VideoDevInfo,std::allocator< pj::VideoDevInfo > >::difference_type jd = j;
      return swig::getslice(self, id, jd, step);
    }
SWIGINTERN void std_vector_Sl_pj_VideoDevInfo_Sg____setitem____SWIG_0(std::vector< pj::VideoDevInfo > *self,PySliceObject *slice,std::vector< pj::VideoDevInfo,std::allocator< pj::VideoDevInfo > > const &v){
      Py_ssize_t i, j, step;
      if( !PySlice_Check(slice) ) {
        SWIG_Error(SWIG_TypeError, "Slice object expected.");
        return;
      }
      PySlice_GetIndices(SWIGPY_SLICE_ARG(slice), (Py_ssize_t)self->size(), &i, &j, &step);
      std::vector< pj::VideoDevInfo,std::allocator< pj::VideoDevInfo > >::difference_type id = i;
      std::vector< pj::VideoDevInfo,std::allocator< pj::VideoDevInfo > >::difference_type jd = j;
      swig::setslice(self, id, jd, step, v);
    }
SWIGINTERN void std_vector_Sl_pj_VideoDevInfo_Sg____setitem____SWIG_1(std::vector< pj::VideoDevInfo > *self,PySliceObject *slice){
      Py_ssize_t i, j, step;
      if( !PySlice_Check(slice) ) {
        SWIG_Error(SWIG_TypeError, "Slice object expected.");
        return;
      }
      PySlice_GetIndices(SWIGPY_SLICE_ARG(slice), (Py_ssize_t)self->size(), &i, &j, &step);
      std::vector< pj::VideoDevInfo,std::allocator< pj::VideoDevInfo > >::difference_type id = i;
      std::vector< pj::VideoDevInfo,std::allocator< pj::VideoDevInfo > >::difference_type jd = j;
      swig::delslice(self, id, jd, step);
    }
SWIGINTERN void std_vector_Sl_pj_VideoDevInfo_Sg____delitem____SWIG_1(std::vector< pj::VideoDevInfo > *self,PySliceObject *slice){
      Py_ssize_t i, j, step;
      if( !PySlice_Check(slice) ) {
        SWIG_Error(SWIG_TypeError, "Slice object expected.");
        return;
      }
      PySlice_GetIndices(SWIGPY_SLICE_ARG(slice), (Py_ssize_t)self->size(), &i, &j, &step);
      std::vector< pj::VideoDevInfo,std::allocator< pj::VideoDevInfo > >::difference_type id = i;
      std::vector< pj::VideoDevInfo,std::allocator< pj::VideoDevInfo > >::difference_type jd = j;
      swig::delslice(self, id, jd, step);
    }
SWIGINTERN std::vector< pj::VideoDevInfo >::value_type const &std_vector_Sl_pj_VideoDevInfo_Sg____getitem____SWIG_1(std::vector< pj::VideoDevInfo > const *self,std::vector< pj::VideoDevInfo >::difference_type i){
      return *(swig::cgetpos(self, i));
    }
SWIGINTERN void std_vector_Sl_pj_VideoDevInfo_Sg____setitem____SWIG_2(std::vector< pj::VideoDevInfo > *self,std::vector< pj::VideoDevInfo >::difference_type i,std::vector< pj::VideoDevInfo >::value_type const &x){
      *(swig::getpos(self,i)) = x;
    }
SWIGINTERN std::vector< pj::VideoDevInfo >::value_type std_vector_Sl_pj_VideoDevInfo_Sg__pop(std::vector< pj::VideoDevInfo > *self){
      if (self->size() == 0)
	throw std::out_of_range("pop from empty container");
      std::vector< pj::VideoDevInfo,std::allocator< pj::VideoDevInfo > >::value_type x = self->back();
      self->pop_back();
      return x;
    }
SWIGINTERN void std_vector_Sl_pj_VideoDevInfo_Sg__append(std::vector< pj::VideoDevInfo > *self,std::vector< pj::VideoDevInfo >::value_type const &x){
      self->push_back(x);
    }
SWIGINTERN std::vector< pj::VideoDevInfo >::iterator std_vector_Sl_pj_VideoDevInfo_Sg__erase__SWIG_0(std::vector< pj::VideoDevInfo > *self,std::vector< pj::VideoDevInfo >::iterator pos){ return self->erase(pos); }
SWIGINTERN std::vector< pj::VideoDevInfo >::iterator std_vector_Sl_pj_VideoDevInfo_Sg__erase__SWIG_1(std::vector< pj::VideoDevInfo > *self,std::vector< pj::VideoDevInfo >::iterator first,std::vector< pj::VideoDevInfo >::iterator last){ return self->erase(first, last); }
SWIGINTERN std::vector< pj::VideoDevInfo >::iterator std_vector_Sl_pj_VideoDevInfo_Sg__insert__SWIG_0(std::vector< pj::VideoDevInfo > *self,std::vector< pj::VideoDevInfo >::iterator pos,std::vector< pj::VideoDevInfo >::value_type const &x){ return self->insert(pos, x); }
SWIGINTERN void std_vector_Sl_pj_VideoDevInfo_Sg__insert__SWIG_1(std::vector< pj::VideoDevInfo > *self,std::vector< pj::VideoDevInfo >::iterator pos,std::vector< pj::VideoDevInfo >::size_type n,std::vector< pj::VideoDevInfo >::value_type const &x){ self->insert(pos, n, x); }

  namespace swig {
    template <>  struct traits< pj::CodecFmtp > {
      typedef pointer_category category;
      static const char* type_name() { return"pj::CodecFmtp"; }
    };
  }


      namespace swig {
	template <>  struct traits<std::vector< pj::CodecFmtp, std::allocator< pj::CodecFmtp > > > {
	  typedef pointer_category category;
	  static const char* type_name() {
	    return "std::vector<" "pj::CodecFmtp" "," "std::allocator< pj::CodecFmtp >" " >";
	  }
	};
      }
    
SWIGINTERN swig::SwigPyIterator *std_vector_Sl_pj_CodecFmtp_Sg__iterator(std::vector< pj::CodecFmtp > *self,PyObject **PYTHON_SELF){
      return swig::make_output_iterator(self->begin(), self->begin(), self->end(), *PYTHON_SELF);
    }
SWIGINTERN bool std_vector_Sl_pj_CodecFmtp_Sg____nonzero__(std::vector< pj::CodecFmtp > const *self){
      return !(self->empty());
    }
SWIGINTERN bool std_vector_Sl_pj_CodecFmtp_Sg____bool__(std::vector< pj::CodecFmtp > const *self){
      return !(self->empty());
    }
SWIGINTERN std::vector< pj::CodecFmtp >::size_type std_vector_Sl_pj_CodecFmtp_Sg____len__(std::vector< pj::CodecFmtp > const *self){
      return self->size();
    }
SWIGINTERN std::vector< pj::CodecFmtp,std::allocator< pj::CodecFmtp > > *std_vector_Sl_pj_CodecFmtp_Sg____getslice__(std::vector< pj::CodecFmtp > *self,std::vector< pj::CodecFmtp >::difference_type i,std::vector< pj::CodecFmtp >::difference_type j){
      return swig::getslice(self, i, j, 1);
    }
SWIGINTERN void std_vector_Sl_pj_CodecFmtp_Sg____setslice____SWIG_0(std::vector< pj::CodecFmtp > *self,std::vector< pj::CodecFmtp >::difference_type i,std::vector< pj::CodecFmtp >::difference_type j){
      swig::setslice(self, i, j, 1, std::vector< pj::CodecFmtp,std::allocator< pj::CodecFmtp > >());
    }
SWIGINTERN void std_vector_Sl_pj_CodecFmtp_Sg____setslice____SWIG_1(std::vector< pj::CodecFmtp > *self,std::vector< pj::CodecFmtp >::difference_type i,std::vector< pj::CodecFmtp >::difference_type j,std::vector< pj::CodecFmtp,std::allocator< pj::CodecFmtp > > const &v){
      swig::setslice(self, i, j, 1, v);
    }
SWIGINTERN void std_vector_Sl_pj_CodecFmtp_Sg____delslice__(std::vector< pj::CodecFmtp > *self,std::vector< pj::CodecFmtp >::difference_type i,std::vector< pj::CodecFmtp >::difference_type j){
      swig::delslice(self, i, j, 1);
    }
SWIGINTERN void std_vector_Sl_pj_CodecFmtp_Sg____delitem____SWIG_0(std::vector< pj::CodecFmtp > *self,std::vector< pj::CodecFmtp >::difference_type i){
      swig::erase(self, swig::getpos(self, i));
    }
SWIGINTERN std::vector< pj::CodecFmtp,std::allocator< pj::CodecFmtp > > *std_vector_Sl_pj_CodecFmtp_Sg____getitem____SWIG_0(std::vector< pj::CodecFmtp > *self,PySliceObject *slice){
      Py_ssize_t i, j, step;
      if( !PySlice_Check(slice) ) {
        SWIG_Error(SWIG_TypeError, "Slice object expected.");
        return NULL;
      }
      PySlice_GetIndices(SWIGPY_SLICE_ARG(slice), (Py_ssize_t)self->size(), &i, &j, &step);
      std::vector< pj::CodecFmtp,std::allocator< pj::CodecFmtp > >::difference_type id = i;
      std::vector< pj::CodecFmtp,std::allocator< pj::CodecFmtp > >::difference_type jd = j;
      return swig::getslice(self, id, jd, step);
    }
SWIGINTERN void std_vector_Sl_pj_CodecFmtp_Sg____setitem____SWIG_0(std::vector< pj::CodecFmtp > *self,PySliceObject *slice,std::vector< pj::CodecFmtp,std::allocator< pj::CodecFmtp > > const &v){
      Py_ssize_t i, j, step;
      if( !PySlice_Check(slice) ) {
        SWIG_Error(SWIG_TypeError, "Slice object expected.");
        return;
      }
      PySlice_GetIndices(SWIGPY_SLICE_ARG(slice), (Py_ssize_t)self->size(), &i, &j, &step);
      std::vector< pj::CodecFmtp,std::allocator< pj::CodecFmtp > >::difference_type id = i;
      std::vector< pj::CodecFmtp,std::allocator< pj::CodecFmtp > >::difference_type jd = j;
      swig::setslice(self, id, jd, step, v);
    }
SWIGINTERN void std_vector_Sl_pj_CodecFmtp_Sg____setitem____SWIG_1(std::vector< pj::CodecFmtp > *self,PySliceObject *slice){
      Py_ssize_t i, j, step;
      if( !PySlice_Check(slice) ) {
        SWIG_Error(SWIG_TypeError, "Slice object expected.");
        return;
      }
      PySlice_GetIndices(SWIGPY_SLICE_ARG(slice), (Py_ssize_t)self->size(), &i, &j, &step);
      std::vector< pj::CodecFmtp,std::allocator< pj::CodecFmtp > >::difference_type id = i;
      std::vector< pj::CodecFmtp,std::allocator< pj::CodecFmtp > >::difference_type jd = j;
      swig::delslice(self, id, jd, step);
    }
SWIGINTERN void std_vector_Sl_pj_CodecFmtp_Sg____delitem____SWIG_1(std::vector< pj::CodecFmtp > *self,PySliceObject *slice){
      Py_ssize_t i, j, step;
      if( !PySlice_Check(slice) ) {
        SWIG_Error(SWIG_TypeError, "Slice object expected.");
        return;
      }
      PySlice_GetIndices(SWIGPY_SLICE_ARG(slice), (Py_ssize_t)self->size(), &i, &j, &step);
      std::vector< pj::CodecFmtp,std::allocator< pj::CodecFmtp > >::difference_type id = i;
      std::vector< pj::CodecFmtp,std::allocator< pj::CodecFmtp > >::difference_type jd = j;
      swig::delslice(self, id, jd, step);
    }
SWIGINTERN std::vector< pj::CodecFmtp >::value_type const &std_vector_Sl_pj_CodecFmtp_Sg____getitem____SWIG_1(std::vector< pj::CodecFmtp > const *self,std::vector< pj::CodecFmtp >::difference_type i){
      return *(swig::cgetpos(self, i));
    }
SWIGINTERN void std_vector_Sl_pj_CodecFmtp_Sg____setitem____SWIG_2(std::vector< pj::CodecFmtp > *self,std::vector< pj::CodecFmtp >::difference_type i,std::vector< pj::CodecFmtp >::value_type const &x){
      *(swig::getpos(self,i)) = x;
    }
SWIGINTERN std::vector< pj::CodecFmtp >::value_type std_vector_Sl_pj_CodecFmtp_Sg__pop(std::vector< pj::CodecFmtp > *self){
      if (self->size() == 0)
	throw std::out_of_range("pop from empty container");
      std::vector< pj::CodecFmtp,std::allocator< pj::CodecFmtp > >::value_type x = self->back();
      self->pop_back();
      return x;
    }
SWIGINTERN void std_vector_Sl_pj_CodecFmtp_Sg__append(std::vector< pj::CodecFmtp > *self,std::vector< pj::CodecFmtp >::value_type const &x){
      self->push_back(x);
    }
SWIGINTERN std::vector< pj::CodecFmtp >::iterator std_vector_Sl_pj_CodecFmtp_Sg__erase__SWIG_0(std::vector< pj::CodecFmtp > *self,std::vector< pj::CodecFmtp >::iterator pos){ return self->erase(pos); }
SWIGINTERN std::vector< pj::CodecFmtp >::iterator std_vector_Sl_pj_CodecFmtp_Sg__erase__SWIG_1(std::vector< pj::CodecFmtp > *self,std::vector< pj::CodecFmtp >::iterator first,std::vector< pj::CodecFmtp >::iterator last){ return self->erase(first, last); }
SWIGINTERN std::vector< pj::CodecFmtp >::iterator std_vector_Sl_pj_CodecFmtp_Sg__insert__SWIG_0(std::vector< pj::CodecFmtp > *self,std::vector< pj::CodecFmtp >::iterator pos,std::vector< pj::CodecFmtp >::value_type const &x){ return self->insert(pos, x); }
SWIGINTERN void std_vector_Sl_pj_CodecFmtp_Sg__insert__SWIG_1(std::vector< pj::CodecFmtp > *self,std::vector< pj::CodecFmtp >::iterator pos,std::vector< pj::CodecFmtp >::size_type n,std::vector< pj::CodecFmtp >::value_type const &x){ self->insert(pos, n, x); }

  namespace swig {
    template <>  struct traits< pj::MediaFormatAudio > {
      typedef pointer_category category;
      static const char* type_name() { return"pj::MediaFormatAudio"; }
    };
  }


      namespace swig {
	template <>  struct traits<std::vector< pj::MediaFormatAudio, std::allocator< pj::MediaFormatAudio > > > {
	  typedef pointer_category category;
	  static const char* type_name() {
	    return "std::vector<" "pj::MediaFormatAudio" "," "std::allocator< pj::MediaFormatAudio >" " >";
	  }
	};
      }
    
SWIGINTERN swig::SwigPyIterator *std_vector_Sl_pj_MediaFormatAudio_Sg__iterator(std::vector< pj::MediaFormatAudio > *self,PyObject **PYTHON_SELF){
      return swig::make_output_iterator(self->begin(), self->begin(), self->end(), *PYTHON_SELF);
    }
SWIGINTERN bool std_vector_Sl_pj_MediaFormatAudio_Sg____nonzero__(std::vector< pj::MediaFormatAudio > const *self){
      return !(self->empty());
    }
SWIGINTERN bool std_vector_Sl_pj_MediaFormatAudio_Sg____bool__(std::vector< pj::MediaFormatAudio > const *self){
      return !(self->empty());
    }
SWIGINTERN std::vector< pj::MediaFormatAudio >::size_type std_vector_Sl_pj_MediaFormatAudio_Sg____len__(std::vector< pj::MediaFormatAudio > const *self){
      return self->size();
    }
SWIGINTERN std::vector< pj::MediaFormatAudio,std::allocator< pj::MediaFormatAudio > > *std_vector_Sl_pj_MediaFormatAudio_Sg____getslice__(std::vector< pj::MediaFormatAudio > *self,std::vector< pj::MediaFormatAudio >::difference_type i,std::vector< pj::MediaFormatAudio >::difference_type j){
      return swig::getslice(self, i, j, 1);
    }
SWIGINTERN void std_vector_Sl_pj_MediaFormatAudio_Sg____setslice____SWIG_0(std::vector< pj::MediaFormatAudio > *self,std::vector< pj::MediaFormatAudio >::difference_type i,std::vector< pj::MediaFormatAudio >::difference_type j){
      swig::setslice(self, i, j, 1, std::vector< pj::MediaFormatAudio,std::allocator< pj::MediaFormatAudio > >());
    }
SWIGINTERN void std_vector_Sl_pj_MediaFormatAudio_Sg____setslice____SWIG_1(std::vector< pj::MediaFormatAudio > *self,std::vector< pj::MediaFormatAudio >::difference_type i,std::vector< pj::MediaFormatAudio >::difference_type j,std::vector< pj::MediaFormatAudio,std::allocator< pj::MediaFormatAudio > > const &v){
      swig::setslice(self, i, j, 1, v);
    }
SWIGINTERN void std_vector_Sl_pj_MediaFormatAudio_Sg____delslice__(std::vector< pj::MediaFormatAudio > *self,std::vector< pj::MediaFormatAudio >::difference_type i,std::vector< pj::MediaFormatAudio >::difference_type j){
      swig::delslice(self, i, j, 1);
    }
SWIGINTERN void std_vector_Sl_pj_MediaFormatAudio_Sg____delitem____SWIG_0(std::vector< pj::MediaFormatAudio > *self,std::vector< pj::MediaFormatAudio >::difference_type i){
      swig::erase(self, swig::getpos(self, i));
    }
SWIGINTERN std::vector< pj::MediaFormatAudio,std::allocator< pj::MediaFormatAudio > > *std_vector_Sl_pj_MediaFormatAudio_Sg____getitem____SWIG_0(std::vector< pj::MediaFormatAudio > *self,PySliceObject *slice){
      Py_ssize_t i, j, step;
      if( !PySlice_Check(slice) ) {
        SWIG_Error(SWIG_TypeError, "Slice object expected.");
        return NULL;
      }
      PySlice_GetIndices(SWIGPY_SLICE_ARG(slice), (Py_ssize_t)self->size(), &i, &j, &step);
      std::vector< pj::MediaFormatAudio,std::allocator< pj::MediaFormatAudio > >::difference_type id = i;
      std::vector< pj::MediaFormatAudio,std::allocator< pj::MediaFormatAudio > >::difference_type jd = j;
      return swig::getslice(self, id, jd, step);
    }
SWIGINTERN void std_vector_Sl_pj_MediaFormatAudio_Sg____setitem____SWIG_0(std::vector< pj::MediaFormatAudio > *self,PySliceObject *slice,std::vector< pj::MediaFormatAudio,std::allocator< pj::MediaFormatAudio > > const &v){
      Py_ssize_t i, j, step;
      if( !PySlice_Check(slice) ) {
        SWIG_Error(SWIG_TypeError, "Slice object expected.");
        return;
      }
      PySlice_GetIndices(SWIGPY_SLICE_ARG(slice), (Py_ssize_t)self->size(), &i, &j, &step);
      std::vector< pj::MediaFormatAudio,std::allocator< pj::MediaFormatAudio > >::difference_type id = i;
      std::vector< pj::MediaFormatAudio,std::allocator< pj::MediaFormatAudio > >::difference_type jd = j;
      swig::setslice(self, id, jd, step, v);
    }
SWIGINTERN void std_vector_Sl_pj_MediaFormatAudio_Sg____setitem____SWIG_1(std::vector< pj::MediaFormatAudio > *self,PySliceObject *slice){
      Py_ssize_t i, j, step;
      if( !PySlice_Check(slice) ) {
        SWIG_Error(SWIG_TypeError, "Slice object expected.");
        return;
      }
      PySlice_GetIndices(SWIGPY_SLICE_ARG(slice), (Py_ssize_t)self->size(), &i, &j, &step);
      std::vector< pj::MediaFormatAudio,std::allocator< pj::MediaFormatAudio > >::difference_type id = i;
      std::vector< pj::MediaFormatAudio,std::allocator< pj::MediaFormatAudio > >::difference_type jd = j;
      swig::delslice(self, id, jd, step);
    }
SWIGINTERN void std_vector_Sl_pj_MediaFormatAudio_Sg____delitem____SWIG_1(std::vector< pj::MediaFormatAudio > *self,PySliceObject *slice){
      Py_ssize_t i, j, step;
      if( !PySlice_Check(slice) ) {
        SWIG_Error(SWIG_TypeError, "Slice object expected.");
        return;
      }
      PySlice_GetIndices(SWIGPY_SLICE_ARG(slice), (Py_ssize_t)self->size(), &i, &j, &step);
      std::vector< pj::MediaFormatAudio,std::allocator< pj::MediaFormatAudio > >::difference_type id = i;
      std::vector< pj::MediaFormatAudio,std::allocator< pj::MediaFormatAudio > >::difference_type jd = j;
      swig::delslice(self, id, jd, step);
    }
SWIGINTERN std::vector< pj::MediaFormatAudio >::value_type const &std_vector_Sl_pj_MediaFormatAudio_Sg____getitem____SWIG_1(std::vector< pj::MediaFormatAudio > const *self,std::vector< pj::MediaFormatAudio >::difference_type i){
      return *(swig::cgetpos(self, i));
    }
SWIGINTERN void std_vector_Sl_pj_MediaFormatAudio_Sg____setitem____SWIG_2(std::vector< pj::MediaFormatAudio > *self,std::vector< pj::MediaFormatAudio >::difference_type i,std::vector< pj::MediaFormatAudio >::value_type const &x){
      *(swig::getpos(self,i)) = x;
    }
SWIGINTERN std::vector< pj::MediaFormatAudio >::value_type std_vector_Sl_pj_MediaFormatAudio_Sg__pop(std::vector< pj::MediaFormatAudio > *self){
      if (self->size() == 0)
	throw std::out_of_range("pop from empty container");
      std::vector< pj::MediaFormatAudio,std::allocator< pj::MediaFormatAudio > >::value_type x = self->back();
      self->pop_back();
      return x;
    }
SWIGINTERN void std_vector_Sl_pj_MediaFormatAudio_Sg__append(std::vector< pj::MediaFormatAudio > *self,std::vector< pj::MediaFormatAudio >::value_type const &x){
      self->push_back(x);
    }
SWIGINTERN std::vector< pj::MediaFormatAudio >::iterator std_vector_Sl_pj_MediaFormatAudio_Sg__erase__SWIG_0(std::vector< pj::MediaFormatAudio > *self,std::vector< pj::MediaFormatAudio >::iterator pos){ return self->erase(pos); }
SWIGINTERN std::vector< pj::MediaFormatAudio >::iterator std_vector_Sl_pj_MediaFormatAudio_Sg__erase__SWIG_1(std::vector< pj::MediaFormatAudio > *self,std::vector< pj::MediaFormatAudio >::iterator first,std::vector< pj::MediaFormatAudio >::iterator last){ return self->erase(first, last); }
SWIGINTERN std::vector< pj::MediaFormatAudio >::iterator std_vector_Sl_pj_MediaFormatAudio_Sg__insert__SWIG_0(std::vector< pj::MediaFormatAudio > *self,std::vector< pj::MediaFormatAudio >::iterator pos,std::vector< pj::MediaFormatAudio >::value_type const &x){ return self->insert(pos, x); }
SWIGINTERN void std_vector_Sl_pj_MediaFormatAudio_Sg__insert__SWIG_1(std::vector< pj::MediaFormatAudio > *self,std::vector< pj::MediaFormatAudio >::iterator pos,std::vector< pj::MediaFormatAudio >::size_type n,std::vector< pj::MediaFormatAudio >::value_type const &x){ self->insert(pos, n, x); }

  namespace swig {
    template <>  struct traits< pj::MediaFormatVideo > {
      typedef pointer_category category;
      static const char* type_name() { return"pj::MediaFormatVideo"; }
    };
  }


      namespace swig {
	template <>  struct traits<std::vector< pj::MediaFormatVideo, std::allocator< pj::MediaFormatVideo > > > {
	  typedef pointer_category category;
	  static const char* type_name() {
	    return "std::vector<" "pj::MediaFormatVideo" "," "std::allocator< pj::MediaFormatVideo >" " >";
	  }
	};
      }
    
SWIGINTERN swig::SwigPyIterator *std_vector_Sl_pj_MediaFormatVideo_Sg__iterator(std::vector< pj::MediaFormatVideo > *self,PyObject **PYTHON_SELF){
      return swig::make_output_iterator(self->begin(), self->begin(), self->end(), *PYTHON_SELF);
    }
SWIGINTERN bool std_vector_Sl_pj_MediaFormatVideo_Sg____nonzero__(std::vector< pj::MediaFormatVideo > const *self){
      return !(self->empty());
    }
SWIGINTERN bool std_vector_Sl_pj_MediaFormatVideo_Sg____bool__(std::vector< pj::MediaFormatVideo > const *self){
      return !(self->empty());
    }
SWIGINTERN std::vector< pj::MediaFormatVideo >::size_type std_vector_Sl_pj_MediaFormatVideo_Sg____len__(std::vector< pj::MediaFormatVideo > const *self){
      return self->size();
    }
SWIGINTERN std::vector< pj::MediaFormatVideo,std::allocator< pj::MediaFormatVideo > > *std_vector_Sl_pj_MediaFormatVideo_Sg____getslice__(std::vector< pj::MediaFormatVideo > *self,std::vector< pj::MediaFormatVideo >::difference_type i,std::vector< pj::MediaFormatVideo >::difference_type j){
      return swig::getslice(self, i, j, 1);
    }
SWIGINTERN void std_vector_Sl_pj_MediaFormatVideo_Sg____setslice____SWIG_0(std::vector< pj::MediaFormatVideo > *self,std::vector< pj::MediaFormatVideo >::difference_type i,std::vector< pj::MediaFormatVideo >::difference_type j){
      swig::setslice(self, i, j, 1, std::vector< pj::MediaFormatVideo,std::allocator< pj::MediaFormatVideo > >());
    }
SWIGINTERN void std_vector_Sl_pj_MediaFormatVideo_Sg____setslice____SWIG_1(std::vector< pj::MediaFormatVideo > *self,std::vector< pj::MediaFormatVideo >::difference_type i,std::vector< pj::MediaFormatVideo >::difference_type j,std::vector< pj::MediaFormatVideo,std::allocator< pj::MediaFormatVideo > > const &v){
      swig::setslice(self, i, j, 1, v);
    }
SWIGINTERN void std_vector_Sl_pj_MediaFormatVideo_Sg____delslice__(std::vector< pj::MediaFormatVideo > *self,std::vector< pj::MediaFormatVideo >::difference_type i,std::vector< pj::MediaFormatVideo >::difference_type j){
      swig::delslice(self, i, j, 1);
    }
SWIGINTERN void std_vector_Sl_pj_MediaFormatVideo_Sg____delitem____SWIG_0(std::vector< pj::MediaFormatVideo > *self,std::vector< pj::MediaFormatVideo >::difference_type i){
      swig::erase(self, swig::getpos(self, i));
    }
SWIGINTERN std::vector< pj::MediaFormatVideo,std::allocator< pj::MediaFormatVideo > > *std_vector_Sl_pj_MediaFormatVideo_Sg____getitem____SWIG_0(std::vector< pj::MediaFormatVideo > *self,PySliceObject *slice){
      Py_ssize_t i, j, step;
      if( !PySlice_Check(slice) ) {
        SWIG_Error(SWIG_TypeError, "Slice object expected.");
        return NULL;
      }
      PySlice_GetIndices(SWIGPY_SLICE_ARG(slice), (Py_ssize_t)self->size(), &i, &j, &step);
      std::vector< pj::MediaFormatVideo,std::allocator< pj::MediaFormatVideo > >::difference_type id = i;
      std::vector< pj::MediaFormatVideo,std::allocator< pj::MediaFormatVideo > >::difference_type jd = j;
      return swig::getslice(self, id, jd, step);
    }
SWIGINTERN void std_vector_Sl_pj_MediaFormatVideo_Sg____setitem____SWIG_0(std::vector< pj::MediaFormatVideo > *self,PySliceObject *slice,std::vector< pj::MediaFormatVideo,std::allocator< pj::MediaFormatVideo > > const &v){
      Py_ssize_t i, j, step;
      if( !PySlice_Check(slice) ) {
        SWIG_Error(SWIG_TypeError, "Slice object expected.");
        return;
      }
      PySlice_GetIndices(SWIGPY_SLICE_ARG(slice), (Py_ssize_t)self->size(), &i, &j, &step);
      std::vector< pj::MediaFormatVideo,std::allocator< pj::MediaFormatVideo > >::difference_type id = i;
      std::vector< pj::MediaFormatVideo,std::allocator< pj::MediaFormatVideo > >::difference_type jd = j;
      swig::setslice(self, id, jd, step, v);
    }
SWIGINTERN void std_vector_Sl_pj_MediaFormatVideo_Sg____setitem____SWIG_1(std::vector< pj::MediaFormatVideo > *self,PySliceObject *slice){
      Py_ssize_t i, j, step;
      if( !PySlice_Check(slice) ) {
        SWIG_Error(SWIG_TypeError, "Slice object expected.");
        return;
      }
      PySlice_GetIndices(SWIGPY_SLICE_ARG(slice), (Py_ssize_t)self->size(), &i, &j, &step);
      std::vector< pj::MediaFormatVideo,std::allocator< pj::MediaFormatVideo > >::difference_type id = i;
      std::vector< pj::MediaFormatVideo,std::allocator< pj::MediaFormatVideo > >::difference_type jd = j;
      swig::delslice(self, id, jd, step);
    }
SWIGINTERN void std_vector_Sl_pj_MediaFormatVideo_Sg____delitem____SWIG_1(std::vector< pj::MediaFormatVideo > *self,PySliceObject *slice){
      Py_ssize_t i, j, step;
      if( !PySlice_Check(slice) ) {
        SWIG_Error(SWIG_TypeError, "Slice object expected.");
        return;
      }
      PySlice_GetIndices(SWIGPY_SLICE_ARG(slice), (Py_ssize_t)self->size(), &i, &j, &step);
      std::vector< pj::MediaFormatVideo,std::allocator< pj::MediaFormatVideo > >::difference_type id = i;
      std::vector< pj::MediaFormatVideo,std::allocator< pj::MediaFormatVideo > >::difference_type jd = j;
      swig::delslice(self, id, jd, step);
    }
SWIGINTERN std::vector< pj::MediaFormatVideo >::value_type const &std_vector_Sl_pj_MediaFormatVideo_Sg____getitem____SWIG_1(std::vector< pj::MediaFormatVideo > const *self,std::vector< pj::MediaFormatVideo >::difference_type i){
      return *(swig::cgetpos(self, i));
    }
SWIGINTERN void std_vector_Sl_pj_MediaFormatVideo_Sg____setitem____SWIG_2(std::vector< pj::MediaFormatVideo > *self,std::vector< pj::MediaFormatVideo >::difference_type i,std::vector< pj::MediaFormatVideo >::value_type const &x){
      *(swig::getpos(self,i)) = x;
    }
SWIGINTERN std::vector< pj::MediaFormatVideo >::value_type std_vector_Sl_pj_MediaFormatVideo_Sg__pop(std::vector< pj::MediaFormatVideo > *self){
      if (self->size() == 0)
	throw std::out_of_range("pop from empty container");
      std::vector< pj::MediaFormatVideo,std::allocator< pj::MediaFormatVideo > >::value_type x = self->back();
      self->pop_back();
      return x;
    }
SWIGINTERN void std_vector_Sl_pj_MediaFormatVideo_Sg__append(std::vector< pj::MediaFormatVideo > *self,std::vector< pj::MediaFormatVideo >::value_type const &x){
      self->push_back(x);
    }
SWIGINTERN std::vector< pj::MediaFormatVideo >::iterator std_vector_Sl_pj_MediaFormatVideo_Sg__erase__SWIG_0(std::vector< pj::MediaFormatVideo > *self,std::vector< pj::MediaFormatVideo >::iterator pos){ return self->erase(pos); }
SWIGINTERN std::vector< pj::MediaFormatVideo >::iterator std_vector_Sl_pj_MediaFormatVideo_Sg__erase__SWIG_1(std::vector< pj::MediaFormatVideo > *self,std::vector< pj::MediaFormatVideo >::iterator first,std::vector< pj::MediaFormatVideo >::iterator last){ return self->erase(first, last); }
SWIGINTERN std::vector< pj::MediaFormatVideo >::iterator std_vector_Sl_pj_MediaFormatVideo_Sg__insert__SWIG_0(std::vector< pj::MediaFormatVideo > *self,std::vector< pj::MediaFormatVideo >::iterator pos,std::vector< pj::MediaFormatVideo >::value_type const &x){ return self->insert(pos, x); }
SWIGINTERN void std_vector_Sl_pj_MediaFormatVideo_Sg__insert__SWIG_1(std::vector< pj::MediaFormatVideo > *self,std::vector< pj::MediaFormatVideo >::iterator pos,std::vector< pj::MediaFormatVideo >::size_type n,std::vector< pj::MediaFormatVideo >::value_type const &x){ self->insert(pos, n, x); }

  namespace swig {
    template <>  struct traits< pj::CallMediaInfo > {
      typedef pointer_category category;
      static const char* type_name() { return"pj::CallMediaInfo"; }
    };
  }


      namespace swig {
	template <>  struct traits<std::vector< pj::CallMediaInfo, std::allocator< pj::CallMediaInfo > > > {
	  typedef pointer_category category;
	  static const char* type_name() {
	    return "std::vector<" "pj::CallMediaInfo" "," "std::allocator< pj::CallMediaInfo >" " >";
	  }
	};
      }
    
SWIGINTERN swig::SwigPyIterator *std_vector_Sl_pj_CallMediaInfo_Sg__iterator(std::vector< pj::CallMediaInfo > *self,PyObject **PYTHON_SELF){
      return swig::make_output_iterator(self->begin(), self->begin(), self->end(), *PYTHON_SELF);
    }
SWIGINTERN bool std_vector_Sl_pj_CallMediaInfo_Sg____nonzero__(std::vector< pj::CallMediaInfo > const *self){
      return !(self->empty());
    }
SWIGINTERN bool std_vector_Sl_pj_CallMediaInfo_Sg____bool__(std::vector< pj::CallMediaInfo > const *self){
      return !(self->empty());
    }
SWIGINTERN std::vector< pj::CallMediaInfo >::size_type std_vector_Sl_pj_CallMediaInfo_Sg____len__(std::vector< pj::CallMediaInfo > const *self){
      return self->size();
    }
SWIGINTERN std::vector< pj::CallMediaInfo,std::allocator< pj::CallMediaInfo > > *std_vector_Sl_pj_CallMediaInfo_Sg____getslice__(std::vector< pj::CallMediaInfo > *self,std::vector< pj::CallMediaInfo >::difference_type i,std::vector< pj::CallMediaInfo >::difference_type j){
      return swig::getslice(self, i, j, 1);
    }
SWIGINTERN void std_vector_Sl_pj_CallMediaInfo_Sg____setslice____SWIG_0(std::vector< pj::CallMediaInfo > *self,std::vector< pj::CallMediaInfo >::difference_type i,std::vector< pj::CallMediaInfo >::difference_type j){
      swig::setslice(self, i, j, 1, std::vector< pj::CallMediaInfo,std::allocator< pj::CallMediaInfo > >());
    }
SWIGINTERN void std_vector_Sl_pj_CallMediaInfo_Sg____setslice____SWIG_1(std::vector< pj::CallMediaInfo > *self,std::vector< pj::CallMediaInfo >::difference_type i,std::vector< pj::CallMediaInfo >::difference_type j,std::vector< pj::CallMediaInfo,std::allocator< pj::CallMediaInfo > > const &v){
      swig::setslice(self, i, j, 1, v);
    }
SWIGINTERN void std_vector_Sl_pj_CallMediaInfo_Sg____delslice__(std::vector< pj::CallMediaInfo > *self,std::vector< pj::CallMediaInfo >::difference_type i,std::vector< pj::CallMediaInfo >::difference_type j){
      swig::delslice(self, i, j, 1);
    }
SWIGINTERN void std_vector_Sl_pj_CallMediaInfo_Sg____delitem____SWIG_0(std::vector< pj::CallMediaInfo > *self,std::vector< pj::CallMediaInfo >::difference_type i){
      swig::erase(self, swig::getpos(self, i));
    }
SWIGINTERN std::vector< pj::CallMediaInfo,std::allocator< pj::CallMediaInfo > > *std_vector_Sl_pj_CallMediaInfo_Sg____getitem____SWIG_0(std::vector< pj::CallMediaInfo > *self,PySliceObject *slice){
      Py_ssize_t i, j, step;
      if( !PySlice_Check(slice) ) {
        SWIG_Error(SWIG_TypeError, "Slice object expected.");
        return NULL;
      }
      PySlice_GetIndices(SWIGPY_SLICE_ARG(slice), (Py_ssize_t)self->size(), &i, &j, &step);
      std::vector< pj::CallMediaInfo,std::allocator< pj::CallMediaInfo > >::difference_type id = i;
      std::vector< pj::CallMediaInfo,std::allocator< pj::CallMediaInfo > >::difference_type jd = j;
      return swig::getslice(self, id, jd, step);
    }
SWIGINTERN void std_vector_Sl_pj_CallMediaInfo_Sg____setitem____SWIG_0(std::vector< pj::CallMediaInfo > *self,PySliceObject *slice,std::vector< pj::CallMediaInfo,std::allocator< pj::CallMediaInfo > > const &v){
      Py_ssize_t i, j, step;
      if( !PySlice_Check(slice) ) {
        SWIG_Error(SWIG_TypeError, "Slice object expected.");
        return;
      }
      PySlice_GetIndices(SWIGPY_SLICE_ARG(slice), (Py_ssize_t)self->size(), &i, &j, &step);
      std::vector< pj::CallMediaInfo,std::allocator< pj::CallMediaInfo > >::difference_type id = i;
      std::vector< pj::CallMediaInfo,std::allocator< pj::CallMediaInfo > >::difference_type jd = j;
      swig::setslice(self, id, jd, step, v);
    }
SWIGINTERN void std_vector_Sl_pj_CallMediaInfo_Sg____setitem____SWIG_1(std::vector< pj::CallMediaInfo > *self,PySliceObject *slice){
      Py_ssize_t i, j, step;
      if( !PySlice_Check(slice) ) {
        SWIG_Error(SWIG_TypeError, "Slice object expected.");
        return;
      }
      PySlice_GetIndices(SWIGPY_SLICE_ARG(slice), (Py_ssize_t)self->size(), &i, &j, &step);
      std::vector< pj::CallMediaInfo,std::allocator< pj::CallMediaInfo > >::difference_type id = i;
      std::vector< pj::CallMediaInfo,std::allocator< pj::CallMediaInfo > >::difference_type jd = j;
      swig::delslice(self, id, jd, step);
    }
SWIGINTERN void std_vector_Sl_pj_CallMediaInfo_Sg____delitem____SWIG_1(std::vector< pj::CallMediaInfo > *self,PySliceObject *slice){
      Py_ssize_t i, j, step;
      if( !PySlice_Check(slice) ) {
        SWIG_Error(SWIG_TypeError, "Slice object expected.");
        return;
      }
      PySlice_GetIndices(SWIGPY_SLICE_ARG(slice), (Py_ssize_t)self->size(), &i, &j, &step);
      std::vector< pj::CallMediaInfo,std::allocator< pj::CallMediaInfo > >::difference_type id = i;
      std::vector< pj::CallMediaInfo,std::allocator< pj::CallMediaInfo > >::difference_type jd = j;
      swig::delslice(self, id, jd, step);
    }
SWIGINTERN std::vector< pj::CallMediaInfo >::value_type const &std_vector_Sl_pj_CallMediaInfo_Sg____getitem____SWIG_1(std::vector< pj::CallMediaInfo > const *self,std::vector< pj::CallMediaInfo >::difference_type i){
      return *(swig::cgetpos(self, i));
    }
SWIGINTERN void std_vector_Sl_pj_CallMediaInfo_Sg____setitem____SWIG_2(std::vector< pj::CallMediaInfo > *self,std::vector< pj::CallMediaInfo >::difference_type i,std::vector< pj::CallMediaInfo >::value_type const &x){
      *(swig::getpos(self,i)) = x;
    }
SWIGINTERN std::vector< pj::CallMediaInfo >::value_type std_vector_Sl_pj_CallMediaInfo_Sg__pop(std::vector< pj::CallMediaInfo > *self){
      if (self->size() == 0)
	throw std::out_of_range("pop from empty container");
      std::vector< pj::CallMediaInfo,std::allocator< pj::CallMediaInfo > >::value_type x = self->back();
      self->pop_back();
      return x;
    }
SWIGINTERN void std_vector_Sl_pj_CallMediaInfo_Sg__append(std::vector< pj::CallMediaInfo > *self,std::vector< pj::CallMediaInfo >::value_type const &x){
      self->push_back(x);
    }
SWIGINTERN std::vector< pj::CallMediaInfo >::iterator std_vector_Sl_pj_CallMediaInfo_Sg__erase__SWIG_0(std::vector< pj::CallMediaInfo > *self,std::vector< pj::CallMediaInfo >::iterator pos){ return self->erase(pos); }
SWIGINTERN std::vector< pj::CallMediaInfo >::iterator std_vector_Sl_pj_CallMediaInfo_Sg__erase__SWIG_1(std::vector< pj::CallMediaInfo > *self,std::vector< pj::CallMediaInfo >::iterator first,std::vector< pj::CallMediaInfo >::iterator last){ return self->erase(first, last); }
SWIGINTERN std::vector< pj::CallMediaInfo >::iterator std_vector_Sl_pj_CallMediaInfo_Sg__insert__SWIG_0(std::vector< pj::CallMediaInfo > *self,std::vector< pj::CallMediaInfo >::iterator pos,std::vector< pj::CallMediaInfo >::value_type const &x){ return self->insert(pos, x); }
SWIGINTERN void std_vector_Sl_pj_CallMediaInfo_Sg__insert__SWIG_1(std::vector< pj::CallMediaInfo > *self,std::vector< pj::CallMediaInfo >::iterator pos,std::vector< pj::CallMediaInfo >::size_type n,std::vector< pj::CallMediaInfo >::value_type const &x){ self->insert(pos, n, x); }

  namespace swig {
    template <>  struct traits< pj::RtcpFbCap > {
      typedef pointer_category category;
      static const char* type_name() { return"pj::RtcpFbCap"; }
    };
  }


      namespace swig {
	template <>  struct traits<std::vector< pj::RtcpFbCap, std::allocator< pj::RtcpFbCap > > > {
	  typedef pointer_category category;
	  static const char* type_name() {
	    return "std::vector<" "pj::RtcpFbCap" "," "std::allocator< pj::RtcpFbCap >" " >";
	  }
	};
      }
    
SWIGINTERN swig::SwigPyIterator *std_vector_Sl_pj_RtcpFbCap_Sg__iterator(std::vector< pj::RtcpFbCap > *self,PyObject **PYTHON_SELF){
      return swig::make_output_iterator(self->begin(), self->begin(), self->end(), *PYTHON_SELF);
    }
SWIGINTERN bool std_vector_Sl_pj_RtcpFbCap_Sg____nonzero__(std::vector< pj::RtcpFbCap > const *self){
      return !(self->empty());
    }
SWIGINTERN bool std_vector_Sl_pj_RtcpFbCap_Sg____bool__(std::vector< pj::RtcpFbCap > const *self){
      return !(self->empty());
    }
SWIGINTERN std::vector< pj::RtcpFbCap >::size_type std_vector_Sl_pj_RtcpFbCap_Sg____len__(std::vector< pj::RtcpFbCap > const *self){
      return self->size();
    }
SWIGINTERN std::vector< pj::RtcpFbCap,std::allocator< pj::RtcpFbCap > > *std_vector_Sl_pj_RtcpFbCap_Sg____getslice__(std::vector< pj::RtcpFbCap > *self,std::vector< pj::RtcpFbCap >::difference_type i,std::vector< pj::RtcpFbCap >::difference_type j){
      return swig::getslice(self, i, j, 1);
    }
SWIGINTERN void std_vector_Sl_pj_RtcpFbCap_Sg____setslice____SWIG_0(std::vector< pj::RtcpFbCap > *self,std::vector< pj::RtcpFbCap >::difference_type i,std::vector< pj::RtcpFbCap >::difference_type j){
      swig::setslice(self, i, j, 1, std::vector< pj::RtcpFbCap,std::allocator< pj::RtcpFbCap > >());
    }
SWIGINTERN void std_vector_Sl_pj_RtcpFbCap_Sg____setslice____SWIG_1(std::vector< pj::RtcpFbCap > *self,std::vector< pj::RtcpFbCap >::difference_type i,std::vector< pj::RtcpFbCap >::difference_type j,std::vector< pj::RtcpFbCap,std::allocator< pj::RtcpFbCap > > const &v){
      swig::setslice(self, i, j, 1, v);
    }
SWIGINTERN void std_vector_Sl_pj_RtcpFbCap_Sg____delslice__(std::vector< pj::RtcpFbCap > *self,std::vector< pj::RtcpFbCap >::difference_type i,std::vector< pj::RtcpFbCap >::difference_type j){
      swig::delslice(self, i, j, 1);
    }
SWIGINTERN void std_vector_Sl_pj_RtcpFbCap_Sg____delitem____SWIG_0(std::vector< pj::RtcpFbCap > *self,std::vector< pj::RtcpFbCap >::difference_type i){
      swig::erase(self, swig::getpos(self, i));
    }
SWIGINTERN std::vector< pj::RtcpFbCap,std::allocator< pj::RtcpFbCap > > *std_vector_Sl_pj_RtcpFbCap_Sg____getitem____SWIG_0(std::vector< pj::RtcpFbCap > *self,PySliceObject *slice){
      Py_ssize_t i, j, step;
      if( !PySlice_Check(slice) ) {
        SWIG_Error(SWIG_TypeError, "Slice object expected.");
        return NULL;
      }
      PySlice_GetIndices(SWIGPY_SLICE_ARG(slice), (Py_ssize_t)self->size(), &i, &j, &step);
      std::vector< pj::RtcpFbCap,std::allocator< pj::RtcpFbCap > >::difference_type id = i;
      std::vector< pj::RtcpFbCap,std::allocator< pj::RtcpFbCap > >::difference_type jd = j;
      return swig::getslice(self, id, jd, step);
    }
SWIGINTERN void std_vector_Sl_pj_RtcpFbCap_Sg____setitem____SWIG_0(std::vector< pj::RtcpFbCap > *self,PySliceObject *slice,std::vector< pj::RtcpFbCap,std::allocator< pj::RtcpFbCap > > const &v){
      Py_ssize_t i, j, step;
      if( !PySlice_Check(slice) ) {
        SWIG_Error(SWIG_TypeError, "Slice object expected.");
        return;
      }
      PySlice_GetIndices(SWIGPY_SLICE_ARG(slice), (Py_ssize_t)self->size(), &i, &j, &step);
      std::vector< pj::RtcpFbCap,std::allocator< pj::RtcpFbCap > >::difference_type id = i;
      std::vector< pj::RtcpFbCap,std::allocator< pj::RtcpFbCap > >::difference_type jd = j;
      swig::setslice(self, id, jd, step, v);
    }
SWIGINTERN void std_vector_Sl_pj_RtcpFbCap_Sg____setitem____SWIG_1(std::vector< pj::RtcpFbCap > *self,PySliceObject *slice){
      Py_ssize_t i, j, step;
      if( !PySlice_Check(slice) ) {
        SWIG_Error(SWIG_TypeError, "Slice object expected.");
        return;
      }
      PySlice_GetIndices(SWIGPY_SLICE_ARG(slice), (Py_ssize_t)self->size(), &i, &j, &step);
      std::vector< pj::RtcpFbCap,std::allocator< pj::RtcpFbCap > >::difference_type id = i;
      std::vector< pj::RtcpFbCap,std::allocator< pj::RtcpFbCap > >::difference_type jd = j;
      swig::delslice(self, id, jd, step);
    }
SWIGINTERN void std_vector_Sl_pj_RtcpFbCap_Sg____delitem____SWIG_1(std::vector< pj::RtcpFbCap > *self,PySliceObject *slice){
      Py_ssize_t i, j, step;
      if( !PySlice_Check(slice) ) {
        SWIG_Error(SWIG_TypeError, "Slice object expected.");
        return;
      }
      PySlice_GetIndices(SWIGPY_SLICE_ARG(slice), (Py_ssize_t)self->size(), &i, &j, &step);
      std::vector< pj::RtcpFbCap,std::allocator< pj::RtcpFbCap > >::difference_type id = i;
      std::vector< pj::RtcpFbCap,std::allocator< pj::RtcpFbCap > >::difference_type jd = j;
      swig::delslice(self, id, jd, step);
    }
SWIGINTERN std::vector< pj::RtcpFbCap >::value_type const &std_vector_Sl_pj_RtcpFbCap_Sg____getitem____SWIG_1(std::vector< pj::RtcpFbCap > const *self,std::vector< pj::RtcpFbCap >::difference_type i){
      return *(swig::cgetpos(self, i));
    }
SWIGINTERN void std_vector_Sl_pj_RtcpFbCap_Sg____setitem____SWIG_2(std::vector< pj::RtcpFbCap > *self,std::vector< pj::RtcpFbCap >::difference_type i,std::vector< pj::RtcpFbCap >::value_type const &x){
      *(swig::getpos(self,i)) = x;
    }
SWIGINTERN std::vector< pj::RtcpFbCap >::value_type std_vector_Sl_pj_RtcpFbCap_Sg__pop(std::vector< pj::RtcpFbCap > *self){
      if (self->size() == 0)
	throw std::out_of_range("pop from empty container");
      std::vector< pj::RtcpFbCap,std::allocator< pj::RtcpFbCap > >::value_type x = self->back();
      self->pop_back();
      return x;
    }
SWIGINTERN void std_vector_Sl_pj_RtcpFbCap_Sg__append(std::vector< pj::RtcpFbCap > *self,std::vector< pj::RtcpFbCap >::value_type const &x){
      self->push_back(x);
    }
SWIGINTERN std::vector< pj::RtcpFbCap >::iterator std_vector_Sl_pj_RtcpFbCap_Sg__erase__SWIG_0(std::vector< pj::RtcpFbCap > *self,std::vector< pj::RtcpFbCap >::iterator pos){ return self->erase(pos); }
SWIGINTERN std::vector< pj::RtcpFbCap >::iterator std_vector_Sl_pj_RtcpFbCap_Sg__erase__SWIG_1(std::vector< pj::RtcpFbCap > *self,std::vector< pj::RtcpFbCap >::iterator first,std::vector< pj::RtcpFbCap >::iterator last){ return self->erase(first, last); }
SWIGINTERN std::vector< pj::RtcpFbCap >::iterator std_vector_Sl_pj_RtcpFbCap_Sg__insert__SWIG_0(std::vector< pj::RtcpFbCap > *self,std::vector< pj::RtcpFbCap >::iterator pos,std::vector< pj::RtcpFbCap >::value_type const &x){ return self->insert(pos, x); }
SWIGINTERN void std_vector_Sl_pj_RtcpFbCap_Sg__insert__SWIG_1(std::vector< pj::RtcpFbCap > *self,std::vector< pj::RtcpFbCap >::iterator pos,std::vector< pj::RtcpFbCap >::size_type n,std::vector< pj::RtcpFbCap >::value_type const &x){ self->insert(pos, n, x); }

  namespace swig {
    template <>  struct traits< pj::SslCertName > {
      typedef pointer_category category;
      static const char* type_name() { return"pj::SslCertName"; }
    };
  }


      namespace swig {
	template <>  struct traits<std::vector< pj::SslCertName, std::allocator< pj::SslCertName > > > {
	  typedef pointer_category category;
	  static const char* type_name() {
	    return "std::vector<" "pj::SslCertName" "," "std::allocator< pj::SslCertName >" " >";
	  }
	};
      }
    
SWIGINTERN swig::SwigPyIterator *std_vector_Sl_pj_SslCertName_Sg__iterator(std::vector< pj::SslCertName > *self,PyObject **PYTHON_SELF){
      return swig::make_output_iterator(self->begin(), self->begin(), self->end(), *PYTHON_SELF);
    }
SWIGINTERN bool std_vector_Sl_pj_SslCertName_Sg____nonzero__(std::vector< pj::SslCertName > const *self){
      return !(self->empty());
    }
SWIGINTERN bool std_vector_Sl_pj_SslCertName_Sg____bool__(std::vector< pj::SslCertName > const *self){
      return !(self->empty());
    }
SWIGINTERN std::vector< pj::SslCertName >::size_type std_vector_Sl_pj_SslCertName_Sg____len__(std::vector< pj::SslCertName > const *self){
      return self->size();
    }
SWIGINTERN std::vector< pj::SslCertName,std::allocator< pj::SslCertName > > *std_vector_Sl_pj_SslCertName_Sg____getslice__(std::vector< pj::SslCertName > *self,std::vector< pj::SslCertName >::difference_type i,std::vector< pj::SslCertName >::difference_type j){
      return swig::getslice(self, i, j, 1);
    }
SWIGINTERN void std_vector_Sl_pj_SslCertName_Sg____setslice____SWIG_0(std::vector< pj::SslCertName > *self,std::vector< pj::SslCertName >::difference_type i,std::vector< pj::SslCertName >::difference_type j){
      swig::setslice(self, i, j, 1, std::vector< pj::SslCertName,std::allocator< pj::SslCertName > >());
    }
SWIGINTERN void std_vector_Sl_pj_SslCertName_Sg____setslice____SWIG_1(std::vector< pj::SslCertName > *self,std::vector< pj::SslCertName >::difference_type i,std::vector< pj::SslCertName >::difference_type j,std::vector< pj::SslCertName,std::allocator< pj::SslCertName > > const &v){
      swig::setslice(self, i, j, 1, v);
    }
SWIGINTERN void std_vector_Sl_pj_SslCertName_Sg____delslice__(std::vector< pj::SslCertName > *self,std::vector< pj::SslCertName >::difference_type i,std::vector< pj::SslCertName >::difference_type j){
      swig::delslice(self, i, j, 1);
    }
SWIGINTERN void std_vector_Sl_pj_SslCertName_Sg____delitem____SWIG_0(std::vector< pj::SslCertName > *self,std::vector< pj::SslCertName >::difference_type i){
      swig::erase(self, swig::getpos(self, i));
    }
SWIGINTERN std::vector< pj::SslCertName,std::allocator< pj::SslCertName > > *std_vector_Sl_pj_SslCertName_Sg____getitem____SWIG_0(std::vector< pj::SslCertName > *self,PySliceObject *slice){
      Py_ssize_t i, j, step;
      if( !PySlice_Check(slice) ) {
        SWIG_Error(SWIG_TypeError, "Slice object expected.");
        return NULL;
      }
      PySlice_GetIndices(SWIGPY_SLICE_ARG(slice), (Py_ssize_t)self->size(), &i, &j, &step);
      std::vector< pj::SslCertName,std::allocator< pj::SslCertName > >::difference_type id = i;
      std::vector< pj::SslCertName,std::allocator< pj::SslCertName > >::difference_type jd = j;
      return swig::getslice(self, id, jd, step);
    }
SWIGINTERN void std_vector_Sl_pj_SslCertName_Sg____setitem____SWIG_0(std::vector< pj::SslCertName > *self,PySliceObject *slice,std::vector< pj::SslCertName,std::allocator< pj::SslCertName > > const &v){
      Py_ssize_t i, j, step;
      if( !PySlice_Check(slice) ) {
        SWIG_Error(SWIG_TypeError, "Slice object expected.");
        return;
      }
      PySlice_GetIndices(SWIGPY_SLICE_ARG(slice), (Py_ssize_t)self->size(), &i, &j, &step);
      std::vector< pj::SslCertName,std::allocator< pj::SslCertName > >::difference_type id = i;
      std::vector< pj::SslCertName,std::allocator< pj::SslCertName > >::difference_type jd = j;
      swig::setslice(self, id, jd, step, v);
    }
SWIGINTERN void std_vector_Sl_pj_SslCertName_Sg____setitem____SWIG_1(std::vector< pj::SslCertName > *self,PySliceObject *slice){
      Py_ssize_t i, j, step;
      if( !PySlice_Check(slice) ) {
        SWIG_Error(SWIG_TypeError, "Slice object expected.");
        return;
      }
      PySlice_GetIndices(SWIGPY_SLICE_ARG(slice), (Py_ssize_t)self->size(), &i, &j, &step);
      std::vector< pj::SslCertName,std::allocator< pj::SslCertName > >::difference_type id = i;
      std::vector< pj::SslCertName,std::allocator< pj::SslCertName > >::difference_type jd = j;
      swig::delslice(self, id, jd, step);
    }
SWIGINTERN void std_vector_Sl_pj_SslCertName_Sg____delitem____SWIG_1(std::vector< pj::SslCertName > *self,PySliceObject *slice){
      Py_ssize_t i, j, step;
      if( !PySlice_Check(slice) ) {
        SWIG_Error(SWIG_TypeError, "Slice object expected.");
        return;
      }
      PySlice_GetIndices(SWIGPY_SLICE_ARG(slice), (Py_ssize_t)self->size(), &i, &j, &step);
      std::vector< pj::SslCertName,std::allocator< pj::SslCertName > >::difference_type id = i;
      std::vector< pj::SslCertName,std::allocator< pj::SslCertName > >::difference_type jd = j;
      swig::delslice(self, id, jd, step);
    }
SWIGINTERN std::vector< pj::SslCertName >::value_type const &std_vector_Sl_pj_SslCertName_Sg____getitem____SWIG_1(std::vector< pj::SslCertName > const *self,std::vector< pj::SslCertName >::difference_type i){
      return *(swig::cgetpos(self, i));
    }
SWIGINTERN void std_vector_Sl_pj_SslCertName_Sg____setitem____SWIG_2(std::vector< pj::SslCertName > *self,std::vector< pj::SslCertName >::difference_type i,std::vector< pj::SslCertName >::value_type const &x){
      *(swig::getpos(self,i)) = x;
    }
SWIGINTERN std::vector< pj::SslCertName >::value_type std_vector_Sl_pj_SslCertName_Sg__pop(std::vector< pj::SslCertName > *self){
      if (self->size() == 0)
	throw std::out_of_range("pop from empty container");
      std::vector< pj::SslCertName,std::allocator< pj::SslCertName > >::value_type x = self->back();
      self->pop_back();
      return x;
    }
SWIGINTERN void std_vector_Sl_pj_SslCertName_Sg__append(std::vector< pj::SslCertName > *self,std::vector< pj::SslCertName >::value_type const &x){
      self->push_back(x);
    }
SWIGINTERN std::vector< pj::SslCertName >::iterator std_vector_Sl_pj_SslCertName_Sg__erase__SWIG_0(std::vector< pj::SslCertName > *self,std::vector< pj::SslCertName >::iterator pos){ return self->erase(pos); }
SWIGINTERN std::vector< pj::SslCertName >::iterator std_vector_Sl_pj_SslCertName_Sg__erase__SWIG_1(std::vector< pj::SslCertName > *self,std::vector< pj::SslCertName >::iterator first,std::vector< pj::SslCertName >::iterator last){ return self->erase(first, last); }
SWIGINTERN std::vector< pj::SslCertName >::iterator std_vector_Sl_pj_SslCertName_Sg__insert__SWIG_0(std::vector< pj::SslCertName > *self,std::vector< pj::SslCertName >::iterator pos,std::vector< pj::SslCertName >::value_type const &x){ return self->insert(pos, x); }
SWIGINTERN void std_vector_Sl_pj_SslCertName_Sg__insert__SWIG_1(std::vector< pj::SslCertName > *self,std::vector< pj::SslCertName >::iterator pos,std::vector< pj::SslCertName >::size_type n,std::vector< pj::SslCertName >::value_type const &x){ self->insert(pos, n, x); }
SWIGINTERN void pj_WindowHandle_setWindow(pj::WindowHandle *self,long long hwnd){ self->window = (void*)hwnd; }

SWIGINTERN int
SWIG_AsVal_unsigned_SS_short (PyObject * obj, unsigned short *val)
{
  unsigned long v;
  int res = SWIG_AsVal_unsigned_SS_long (obj, &v);
  if (SWIG_IsOK(res)) {
    if ((v > USHRT_MAX)) {
      return SWIG_OverflowError;
    } else {
      if (val) *val = static_cast< unsigned short >(v);
    }
  }  
  return res;
}


SWIGINTERNINLINE PyObject *
SWIG_From_unsigned_SS_short  (unsigned short value)
{    
  return SWIG_From_unsigned_SS_long  (value);
}



/* ---------------------------------------------------
 * C++ director class methods
 * --------------------------------------------------- */

#include "pjsua2_wrap.h"

SwigDirector_AudioMediaPlayer::SwigDirector_AudioMediaPlayer(PyObject *self): pj::AudioMediaPlayer(), Swig::Director(self) {
  SWIG_DIRECTOR_RGTR((pj::AudioMediaPlayer *)this, this); 
}




SwigDirector_AudioMediaPlayer::~SwigDirector_AudioMediaPlayer() {
}

void SwigDirector_AudioMediaPlayer::onEof2() {
  if (!swig_get_self()) {
    Swig::DirectorException::raise("'self' uninitialized, maybe you forgot to call AudioMediaPlayer.__init__.");
  }
#if defined(SWIG_PYTHON_DIRECTOR_VTABLE)
  const size_t swig_method_index = 0;
  const char *const swig_method_name = "onEof2";
  PyObject *method = swig_get_method(swig_method_index, swig_method_name);
  swig::SwigVar_PyObject args = PyTuple_New(0);
  swig::SwigVar_PyObject result = PyObject_Call(method, (PyObject *) args, NULL);
#else
  swig::SwigVar_PyObject swig_method_name = SWIG_Python_str_FromChar("onEof2");
  swig::SwigVar_PyObject result = PyObject_CallMethodObjArgs(swig_get_self(), (PyObject *) swig_method_name, NULL);
#endif
  if (!result) {
    PyObject *error = PyErr_Occurred();
    {
      if( error != NULL ) {
        PyObject *ptype, *pvalue, *ptraceback;
        PyErr_Fetch( &ptype, &pvalue, &ptraceback );
        PyErr_Restore( ptype, pvalue, ptraceback );
        PyErr_Print();
        //Py_Exit(1);
      }
    }
  }
}


SwigDirector_Buddy::SwigDirector_Buddy(PyObject *self): pj::Buddy(), Swig::Director(self) {
  SWIG_DIRECTOR_RGTR((pj::Buddy *)this, this); 
}




SwigDirector_Buddy::~SwigDirector_Buddy() {
}

void SwigDirector_Buddy::onBuddyState() {
  if (!swig_get_self()) {
    Swig::DirectorException::raise("'self' uninitialized, maybe you forgot to call Buddy.__init__.");
  }
#if defined(SWIG_PYTHON_DIRECTOR_VTABLE)
  const size_t swig_method_index = 0;
  const char *const swig_method_name = "onBuddyState";
  PyObject *method = swig_get_method(swig_method_index, swig_method_name);
  swig::SwigVar_PyObject args = PyTuple_New(0);
  swig::SwigVar_PyObject result = PyObject_Call(method, (PyObject *) args, NULL);
#else
  swig::SwigVar_PyObject swig_method_name = SWIG_Python_str_FromChar("onBuddyState");
  swig::SwigVar_PyObject result = PyObject_CallMethodObjArgs(swig_get_self(), (PyObject *) swig_method_name, NULL);
#endif
  if (!result) {
    PyObject *error = PyErr_Occurred();
    {
      if( error != NULL ) {
        PyObject *ptype, *pvalue, *ptraceback;
        PyErr_Fetch( &ptype, &pvalue, &ptraceback );
        PyErr_Restore( ptype, pvalue, ptraceback );
        PyErr_Print();
        //Py_Exit(1);
      }
    }
  }
}


void SwigDirector_Buddy::onBuddyEvSubState(pj::OnBuddyEvSubStateParam &prm) {
  swig::SwigVar_PyObject obj0;
  obj0 = SWIG_NewPointerObj(SWIG_as_voidptr(&prm), SWIGTYPE_p_pj__OnBuddyEvSubStateParam,  0 );
  if (!swig_get_self()) {
    Swig::DirectorException::raise("'self' uninitialized, maybe you forgot to call Buddy.__init__.");
  }
#if defined(SWIG_PYTHON_DIRECTOR_VTABLE)
  const size_t swig_method_index = 1;
  const char *const swig_method_name = "onBuddyEvSubState";
  PyObject *method = swig_get_method(swig_method_index, swig_method_name);
  swig::SwigVar_PyObject result = PyObject_CallFunctionObjArgs(method ,(PyObject *)obj0, NULL);
#else
  swig::SwigVar_PyObject swig_method_name = SWIG_Python_str_FromChar("onBuddyEvSubState");
  swig::SwigVar_PyObject result = PyObject_CallMethodObjArgs(swig_get_self(), (PyObject *) swig_method_name ,(PyObject *)obj0, NULL);
#endif
  if (!result) {
    PyObject *error = PyErr_Occurred();
    {
      if( error != NULL ) {
        PyObject *ptype, *pvalue, *ptraceback;
        PyErr_Fetch( &ptype, &pvalue, &ptraceback );
        PyErr_Restore( ptype, pvalue, ptraceback );
        PyErr_Print();
        //Py_Exit(1);
      }
    }
  }
}


SwigDirector_FindBuddyMatch::SwigDirector_FindBuddyMatch(PyObject *self): pj::FindBuddyMatch(), Swig::Director(self) {
  SWIG_DIRECTOR_RGTR((pj::FindBuddyMatch *)this, this); 
}




bool SwigDirector_FindBuddyMatch::match(pj::string const &token, pj::Buddy const &buddy) {
  bool c_result = SwigValueInit< bool >() ;
  
  swig::SwigVar_PyObject obj0;
  obj0 = SWIG_From_std_string(static_cast< std::string >(token));
  swig::SwigVar_PyObject obj1;
  obj1 = SWIG_NewPointerObj(SWIG_as_voidptr(&buddy), SWIGTYPE_p_pj__Buddy,  0 );
  if (!swig_get_self()) {
    Swig::DirectorException::raise("'self' uninitialized, maybe you forgot to call FindBuddyMatch.__init__.");
  }
#if defined(SWIG_PYTHON_DIRECTOR_VTABLE)
  const size_t swig_method_index = 0;
  const char *const swig_method_name = "match";
  PyObject *method = swig_get_method(swig_method_index, swig_method_name);
  swig::SwigVar_PyObject result = PyObject_CallFunctionObjArgs(method ,(PyObject *)obj0,(PyObject *)obj1, NULL);
#else
  swig::SwigVar_PyObject swig_method_name = SWIG_Python_str_FromChar("match");
  swig::SwigVar_PyObject result = PyObject_CallMethodObjArgs(swig_get_self(), (PyObject *) swig_method_name ,(PyObject *)obj0,(PyObject *)obj1, NULL);
#endif
  if (!result) {
    PyObject *error = PyErr_Occurred();
    {
      if( error != NULL ) {
        PyObject *ptype, *pvalue, *ptraceback;
        PyErr_Fetch( &ptype, &pvalue, &ptraceback );
        PyErr_Restore( ptype, pvalue, ptraceback );
        PyErr_Print();
        //Py_Exit(1);
      }
    }
  }
  bool swig_val;
  int swig_res = SWIG_AsVal_bool(result, &swig_val);
  if (!SWIG_IsOK(swig_res)) {
    Swig::DirectorTypeMismatchException::raise(SWIG_ErrorType(SWIG_ArgError(swig_res)), "in output value of type '""bool""'");
  }
  c_result = static_cast< bool >(swig_val);
  return (bool) c_result;
}


SwigDirector_FindBuddyMatch::~SwigDirector_FindBuddyMatch() {
}

SwigDirector_Account::SwigDirector_Account(PyObject *self): pj::Account(), Swig::Director(self) {
  SWIG_DIRECTOR_RGTR((pj::Account *)this, this); 
}




SwigDirector_Account::~SwigDirector_Account() {
}

void SwigDirector_Account::onIncomingCall(pj::OnIncomingCallParam &prm) {
  swig::SwigVar_PyObject obj0;
  obj0 = SWIG_NewPointerObj(SWIG_as_voidptr(&prm), SWIGTYPE_p_pj__OnIncomingCallParam,  0 );
  if (!swig_get_self()) {
    Swig::DirectorException::raise("'self' uninitialized, maybe you forgot to call Account.__init__.");
  }
#if defined(SWIG_PYTHON_DIRECTOR_VTABLE)
  const size_t swig_method_index = 0;
  const char *const swig_method_name = "onIncomingCall";
  PyObject *method = swig_get_method(swig_method_index, swig_method_name);
  swig::SwigVar_PyObject result = PyObject_CallFunctionObjArgs(method ,(PyObject *)obj0, NULL);
#else
  swig::SwigVar_PyObject swig_method_name = SWIG_Python_str_FromChar("onIncomingCall");
  swig::SwigVar_PyObject result = PyObject_CallMethodObjArgs(swig_get_self(), (PyObject *) swig_method_name ,(PyObject *)obj0, NULL);
#endif
  if (!result) {
    PyObject *error = PyErr_Occurred();
    {
      if( error != NULL ) {
        PyObject *ptype, *pvalue, *ptraceback;
        PyErr_Fetch( &ptype, &pvalue, &ptraceback );
        PyErr_Restore( ptype, pvalue, ptraceback );
        PyErr_Print();
        //Py_Exit(1);
      }
    }
  }
}


void SwigDirector_Account::onRegStarted(pj::OnRegStartedParam &prm) {
  swig::SwigVar_PyObject obj0;
  obj0 = SWIG_NewPointerObj(SWIG_as_voidptr(&prm), SWIGTYPE_p_pj__OnRegStartedParam,  0 );
  if (!swig_get_self()) {
    Swig::DirectorException::raise("'self' uninitialized, maybe you forgot to call Account.__init__.");
  }
#if defined(SWIG_PYTHON_DIRECTOR_VTABLE)
  const size_t swig_method_index = 1;
  const char *const swig_method_name = "onRegStarted";
  PyObject *method = swig_get_method(swig_method_index, swig_method_name);
  swig::SwigVar_PyObject result = PyObject_CallFunctionObjArgs(method ,(PyObject *)obj0, NULL);
#else
  swig::SwigVar_PyObject swig_method_name = SWIG_Python_str_FromChar("onRegStarted");
  swig::SwigVar_PyObject result = PyObject_CallMethodObjArgs(swig_get_self(), (PyObject *) swig_method_name ,(PyObject *)obj0, NULL);
#endif
  if (!result) {
    PyObject *error = PyErr_Occurred();
    {
      if( error != NULL ) {
        PyObject *ptype, *pvalue, *ptraceback;
        PyErr_Fetch( &ptype, &pvalue, &ptraceback );
        PyErr_Restore( ptype, pvalue, ptraceback );
        PyErr_Print();
        //Py_Exit(1);
      }
    }
  }
}


void SwigDirector_Account::onRegState(pj::OnRegStateParam &prm) {
  swig::SwigVar_PyObject obj0;
  obj0 = SWIG_NewPointerObj(SWIG_as_voidptr(&prm), SWIGTYPE_p_pj__OnRegStateParam,  0 );
  if (!swig_get_self()) {
    Swig::DirectorException::raise("'self' uninitialized, maybe you forgot to call Account.__init__.");
  }
#if defined(SWIG_PYTHON_DIRECTOR_VTABLE)
  const size_t swig_method_index = 2;
  const char *const swig_method_name = "onRegState";
  PyObject *method = swig_get_method(swig_method_index, swig_method_name);
  swig::SwigVar_PyObject result = PyObject_CallFunctionObjArgs(method ,(PyObject *)obj0, NULL);
#else
  swig::SwigVar_PyObject swig_method_name = SWIG_Python_str_FromChar("onRegState");
  swig::SwigVar_PyObject result = PyObject_CallMethodObjArgs(swig_get_self(), (PyObject *) swig_method_name ,(PyObject *)obj0, NULL);
#endif
  if (!result) {
    PyObject *error = PyErr_Occurred();
    {
      if( error != NULL ) {
        PyObject *ptype, *pvalue, *ptraceback;
        PyErr_Fetch( &ptype, &pvalue, &ptraceback );
        PyErr_Restore( ptype, pvalue, ptraceback );
        PyErr_Print();
        //Py_Exit(1);
      }
    }
  }
}


void SwigDirector_Account::onIncomingSubscribe(pj::OnIncomingSubscribeParam &prm) {
  swig::SwigVar_PyObject obj0;
  obj0 = SWIG_NewPointerObj(SWIG_as_voidptr(&prm), SWIGTYPE_p_pj__OnIncomingSubscribeParam,  0 );
  if (!swig_get_self()) {
    Swig::DirectorException::raise("'self' uninitialized, maybe you forgot to call Account.__init__.");
  }
#if defined(SWIG_PYTHON_DIRECTOR_VTABLE)
  const size_t swig_method_index = 3;
  const char *const swig_method_name = "onIncomingSubscribe";
  PyObject *method = swig_get_method(swig_method_index, swig_method_name);
  swig::SwigVar_PyObject result = PyObject_CallFunctionObjArgs(method ,(PyObject *)obj0, NULL);
#else
  swig::SwigVar_PyObject swig_method_name = SWIG_Python_str_FromChar("onIncomingSubscribe");
  swig::SwigVar_PyObject result = PyObject_CallMethodObjArgs(swig_get_self(), (PyObject *) swig_method_name ,(PyObject *)obj0, NULL);
#endif
  if (!result) {
    PyObject *error = PyErr_Occurred();
    {
      if( error != NULL ) {
        PyObject *ptype, *pvalue, *ptraceback;
        PyErr_Fetch( &ptype, &pvalue, &ptraceback );
        PyErr_Restore( ptype, pvalue, ptraceback );
        PyErr_Print();
        //Py_Exit(1);
      }
    }
  }
}


void SwigDirector_Account::onInstantMessage(pj::OnInstantMessageParam &prm) {
  swig::SwigVar_PyObject obj0;
  obj0 = SWIG_NewPointerObj(SWIG_as_voidptr(&prm), SWIGTYPE_p_pj__OnInstantMessageParam,  0 );
  if (!swig_get_self()) {
    Swig::DirectorException::raise("'self' uninitialized, maybe you forgot to call Account.__init__.");
  }
#if defined(SWIG_PYTHON_DIRECTOR_VTABLE)
  const size_t swig_method_index = 4;
  const char *const swig_method_name = "onInstantMessage";
  PyObject *method = swig_get_method(swig_method_index, swig_method_name);
  swig::SwigVar_PyObject result = PyObject_CallFunctionObjArgs(method ,(PyObject *)obj0, NULL);
#else
  swig::SwigVar_PyObject swig_method_name = SWIG_Python_str_FromChar("onInstantMessage");
  swig::SwigVar_PyObject result = PyObject_CallMethodObjArgs(swig_get_self(), (PyObject *) swig_method_name ,(PyObject *)obj0, NULL);
#endif
  if (!result) {
    PyObject *error = PyErr_Occurred();
    {
      if( error != NULL ) {
        PyObject *ptype, *pvalue, *ptraceback;
        PyErr_Fetch( &ptype, &pvalue, &ptraceback );
        PyErr_Restore( ptype, pvalue, ptraceback );
        PyErr_Print();
        //Py_Exit(1);
      }
    }
  }
}


void SwigDirector_Account::onInstantMessageStatus(pj::OnInstantMessageStatusParam &prm) {
  swig::SwigVar_PyObject obj0;
  obj0 = SWIG_NewPointerObj(SWIG_as_voidptr(&prm), SWIGTYPE_p_pj__OnInstantMessageStatusParam,  0 );
  if (!swig_get_self()) {
    Swig::DirectorException::raise("'self' uninitialized, maybe you forgot to call Account.__init__.");
  }
#if defined(SWIG_PYTHON_DIRECTOR_VTABLE)
  const size_t swig_method_index = 5;
  const char *const swig_method_name = "onInstantMessageStatus";
  PyObject *method = swig_get_method(swig_method_index, swig_method_name);
  swig::SwigVar_PyObject result = PyObject_CallFunctionObjArgs(method ,(PyObject *)obj0, NULL);
#else
  swig::SwigVar_PyObject swig_method_name = SWIG_Python_str_FromChar("onInstantMessageStatus");
  swig::SwigVar_PyObject result = PyObject_CallMethodObjArgs(swig_get_self(), (PyObject *) swig_method_name ,(PyObject *)obj0, NULL);
#endif
  if (!result) {
    PyObject *error = PyErr_Occurred();
    {
      if( error != NULL ) {
        PyObject *ptype, *pvalue, *ptraceback;
        PyErr_Fetch( &ptype, &pvalue, &ptraceback );
        PyErr_Restore( ptype, pvalue, ptraceback );
        PyErr_Print();
        //Py_Exit(1);
      }
    }
  }
}


void SwigDirector_Account::onTypingIndication(pj::OnTypingIndicationParam &prm) {
  swig::SwigVar_PyObject obj0;
  obj0 = SWIG_NewPointerObj(SWIG_as_voidptr(&prm), SWIGTYPE_p_pj__OnTypingIndicationParam,  0 );
  if (!swig_get_self()) {
    Swig::DirectorException::raise("'self' uninitialized, maybe you forgot to call Account.__init__.");
  }
#if defined(SWIG_PYTHON_DIRECTOR_VTABLE)
  const size_t swig_method_index = 6;
  const char *const swig_method_name = "onTypingIndication";
  PyObject *method = swig_get_method(swig_method_index, swig_method_name);
  swig::SwigVar_PyObject result = PyObject_CallFunctionObjArgs(method ,(PyObject *)obj0, NULL);
#else
  swig::SwigVar_PyObject swig_method_name = SWIG_Python_str_FromChar("onTypingIndication");
  swig::SwigVar_PyObject result = PyObject_CallMethodObjArgs(swig_get_self(), (PyObject *) swig_method_name ,(PyObject *)obj0, NULL);
#endif
  if (!result) {
    PyObject *error = PyErr_Occurred();
    {
      if( error != NULL ) {
        PyObject *ptype, *pvalue, *ptraceback;
        PyErr_Fetch( &ptype, &pvalue, &ptraceback );
        PyErr_Restore( ptype, pvalue, ptraceback );
        PyErr_Print();
        //Py_Exit(1);
      }
    }
  }
}


void SwigDirector_Account::onMwiInfo(pj::OnMwiInfoParam &prm) {
  swig::SwigVar_PyObject obj0;
  obj0 = SWIG_NewPointerObj(SWIG_as_voidptr(&prm), SWIGTYPE_p_pj__OnMwiInfoParam,  0 );
  if (!swig_get_self()) {
    Swig::DirectorException::raise("'self' uninitialized, maybe you forgot to call Account.__init__.");
  }
#if defined(SWIG_PYTHON_DIRECTOR_VTABLE)
  const size_t swig_method_index = 7;
  const char *const swig_method_name = "onMwiInfo";
  PyObject *method = swig_get_method(swig_method_index, swig_method_name);
  swig::SwigVar_PyObject result = PyObject_CallFunctionObjArgs(method ,(PyObject *)obj0, NULL);
#else
  swig::SwigVar_PyObject swig_method_name = SWIG_Python_str_FromChar("onMwiInfo");
  swig::SwigVar_PyObject result = PyObject_CallMethodObjArgs(swig_get_self(), (PyObject *) swig_method_name ,(PyObject *)obj0, NULL);
#endif
  if (!result) {
    PyObject *error = PyErr_Occurred();
    {
      if( error != NULL ) {
        PyObject *ptype, *pvalue, *ptraceback;
        PyErr_Fetch( &ptype, &pvalue, &ptraceback );
        PyErr_Restore( ptype, pvalue, ptraceback );
        PyErr_Print();
        //Py_Exit(1);
      }
    }
  }
}


SwigDirector_Call::SwigDirector_Call(PyObject *self, pj::Account &acc, int call_id): pj::Call(acc, call_id), Swig::Director(self) {
  SWIG_DIRECTOR_RGTR((pj::Call *)this, this); 
}




SwigDirector_Call::~SwigDirector_Call() {
}

void SwigDirector_Call::onCallState(pj::OnCallStateParam &prm) {
  swig::SwigVar_PyObject obj0;
  obj0 = SWIG_NewPointerObj(SWIG_as_voidptr(&prm), SWIGTYPE_p_pj__OnCallStateParam,  0 );
  if (!swig_get_self()) {
    Swig::DirectorException::raise("'self' uninitialized, maybe you forgot to call Call.__init__.");
  }
#if defined(SWIG_PYTHON_DIRECTOR_VTABLE)
  const size_t swig_method_index = 0;
  const char *const swig_method_name = "onCallState";
  PyObject *method = swig_get_method(swig_method_index, swig_method_name);
  swig::SwigVar_PyObject result = PyObject_CallFunctionObjArgs(method ,(PyObject *)obj0, NULL);
#else
  swig::SwigVar_PyObject swig_method_name = SWIG_Python_str_FromChar("onCallState");
  swig::SwigVar_PyObject result = PyObject_CallMethodObjArgs(swig_get_self(), (PyObject *) swig_method_name ,(PyObject *)obj0, NULL);
#endif
  if (!result) {
    PyObject *error = PyErr_Occurred();
    {
      if( error != NULL ) {
        PyObject *ptype, *pvalue, *ptraceback;
        PyErr_Fetch( &ptype, &pvalue, &ptraceback );
        PyErr_Restore( ptype, pvalue, ptraceback );
        PyErr_Print();
        //Py_Exit(1);
      }
    }
  }
}


void SwigDirector_Call::onCallTsxState(pj::OnCallTsxStateParam &prm) {
  swig::SwigVar_PyObject obj0;
  obj0 = SWIG_NewPointerObj(SWIG_as_voidptr(&prm), SWIGTYPE_p_pj__OnCallTsxStateParam,  0 );
  if (!swig_get_self()) {
    Swig::DirectorException::raise("'self' uninitialized, maybe you forgot to call Call.__init__.");
  }
#if defined(SWIG_PYTHON_DIRECTOR_VTABLE)
  const size_t swig_method_index = 1;
  const char *const swig_method_name = "onCallTsxState";
  PyObject *method = swig_get_method(swig_method_index, swig_method_name);
  swig::SwigVar_PyObject result = PyObject_CallFunctionObjArgs(method ,(PyObject *)obj0, NULL);
#else
  swig::SwigVar_PyObject swig_method_name = SWIG_Python_str_FromChar("onCallTsxState");
  swig::SwigVar_PyObject result = PyObject_CallMethodObjArgs(swig_get_self(), (PyObject *) swig_method_name ,(PyObject *)obj0, NULL);
#endif
  if (!result) {
    PyObject *error = PyErr_Occurred();
    {
      if( error != NULL ) {
        PyObject *ptype, *pvalue, *ptraceback;
        PyErr_Fetch( &ptype, &pvalue, &ptraceback );
        PyErr_Restore( ptype, pvalue, ptraceback );
        PyErr_Print();
        //Py_Exit(1);
      }
    }
  }
}


void SwigDirector_Call::onCallMediaState(pj::OnCallMediaStateParam &prm) {
  swig::SwigVar_PyObject obj0;
  obj0 = SWIG_NewPointerObj(SWIG_as_voidptr(&prm), SWIGTYPE_p_pj__OnCallMediaStateParam,  0 );
  if (!swig_get_self()) {
    Swig::DirectorException::raise("'self' uninitialized, maybe you forgot to call Call.__init__.");
  }
#if defined(SWIG_PYTHON_DIRECTOR_VTABLE)
  const size_t swig_method_index = 2;
  const char *const swig_method_name = "onCallMediaState";
  PyObject *method = swig_get_method(swig_method_index, swig_method_name);
  swig::SwigVar_PyObject result = PyObject_CallFunctionObjArgs(method ,(PyObject *)obj0, NULL);
#else
  swig::SwigVar_PyObject swig_method_name = SWIG_Python_str_FromChar("onCallMediaState");
  swig::SwigVar_PyObject result = PyObject_CallMethodObjArgs(swig_get_self(), (PyObject *) swig_method_name ,(PyObject *)obj0, NULL);
#endif
  if (!result) {
    PyObject *error = PyErr_Occurred();
    {
      if( error != NULL ) {
        PyObject *ptype, *pvalue, *ptraceback;
        PyErr_Fetch( &ptype, &pvalue, &ptraceback );
        PyErr_Restore( ptype, pvalue, ptraceback );
        PyErr_Print();
        //Py_Exit(1);
      }
    }
  }
}


void SwigDirector_Call::onCallSdpCreated(pj::OnCallSdpCreatedParam &prm) {
  swig::SwigVar_PyObject obj0;
  obj0 = SWIG_NewPointerObj(SWIG_as_voidptr(&prm), SWIGTYPE_p_pj__OnCallSdpCreatedParam,  0 );
  if (!swig_get_self()) {
    Swig::DirectorException::raise("'self' uninitialized, maybe you forgot to call Call.__init__.");
  }
#if defined(SWIG_PYTHON_DIRECTOR_VTABLE)
  const size_t swig_method_index = 3;
  const char *const swig_method_name = "onCallSdpCreated";
  PyObject *method = swig_get_method(swig_method_index, swig_method_name);
  swig::SwigVar_PyObject result = PyObject_CallFunctionObjArgs(method ,(PyObject *)obj0, NULL);
#else
  swig::SwigVar_PyObject swig_method_name = SWIG_Python_str_FromChar("onCallSdpCreated");
  swig::SwigVar_PyObject result = PyObject_CallMethodObjArgs(swig_get_self(), (PyObject *) swig_method_name ,(PyObject *)obj0, NULL);
#endif
  if (!result) {
    PyObject *error = PyErr_Occurred();
    {
      if( error != NULL ) {
        PyObject *ptype, *pvalue, *ptraceback;
        PyErr_Fetch( &ptype, &pvalue, &ptraceback );
        PyErr_Restore( ptype, pvalue, ptraceback );
        PyErr_Print();
        //Py_Exit(1);
      }
    }
  }
}


void SwigDirector_Call::onStreamPreCreate(pj::OnStreamPreCreateParam &prm) {
  swig::SwigVar_PyObject obj0;
  obj0 = SWIG_NewPointerObj(SWIG_as_voidptr(&prm), SWIGTYPE_p_pj__OnStreamPreCreateParam,  0 );
  if (!swig_get_self()) {
    Swig::DirectorException::raise("'self' uninitialized, maybe you forgot to call Call.__init__.");
  }
#if defined(SWIG_PYTHON_DIRECTOR_VTABLE)
  const size_t swig_method_index = 4;
  const char *const swig_method_name = "onStreamPreCreate";
  PyObject *method = swig_get_method(swig_method_index, swig_method_name);
  swig::SwigVar_PyObject result = PyObject_CallFunctionObjArgs(method ,(PyObject *)obj0, NULL);
#else
  swig::SwigVar_PyObject swig_method_name = SWIG_Python_str_FromChar("onStreamPreCreate");
  swig::SwigVar_PyObject result = PyObject_CallMethodObjArgs(swig_get_self(), (PyObject *) swig_method_name ,(PyObject *)obj0, NULL);
#endif
  if (!result) {
    PyObject *error = PyErr_Occurred();
    {
      if( error != NULL ) {
        PyObject *ptype, *pvalue, *ptraceback;
        PyErr_Fetch( &ptype, &pvalue, &ptraceback );
        PyErr_Restore( ptype, pvalue, ptraceback );
        PyErr_Print();
        //Py_Exit(1);
      }
    }
  }
}


void SwigDirector_Call::onStreamCreated(pj::OnStreamCreatedParam &prm) {
  swig::SwigVar_PyObject obj0;
  obj0 = SWIG_NewPointerObj(SWIG_as_voidptr(&prm), SWIGTYPE_p_pj__OnStreamCreatedParam,  0 );
  if (!swig_get_self()) {
    Swig::DirectorException::raise("'self' uninitialized, maybe you forgot to call Call.__init__.");
  }
#if defined(SWIG_PYTHON_DIRECTOR_VTABLE)
  const size_t swig_method_index = 5;
  const char *const swig_method_name = "onStreamCreated";
  PyObject *method = swig_get_method(swig_method_index, swig_method_name);
  swig::SwigVar_PyObject result = PyObject_CallFunctionObjArgs(method ,(PyObject *)obj0, NULL);
#else
  swig::SwigVar_PyObject swig_method_name = SWIG_Python_str_FromChar("onStreamCreated");
  swig::SwigVar_PyObject result = PyObject_CallMethodObjArgs(swig_get_self(), (PyObject *) swig_method_name ,(PyObject *)obj0, NULL);
#endif
  if (!result) {
    PyObject *error = PyErr_Occurred();
    {
      if( error != NULL ) {
        PyObject *ptype, *pvalue, *ptraceback;
        PyErr_Fetch( &ptype, &pvalue, &ptraceback );
        PyErr_Restore( ptype, pvalue, ptraceback );
        PyErr_Print();
        //Py_Exit(1);
      }
    }
  }
}


void SwigDirector_Call::onStreamDestroyed(pj::OnStreamDestroyedParam &prm) {
  swig::SwigVar_PyObject obj0;
  obj0 = SWIG_NewPointerObj(SWIG_as_voidptr(&prm), SWIGTYPE_p_pj__OnStreamDestroyedParam,  0 );
  if (!swig_get_self()) {
    Swig::DirectorException::raise("'self' uninitialized, maybe you forgot to call Call.__init__.");
  }
#if defined(SWIG_PYTHON_DIRECTOR_VTABLE)
  const size_t swig_method_index = 6;
  const char *const swig_method_name = "onStreamDestroyed";
  PyObject *method = swig_get_method(swig_method_index, swig_method_name);
  swig::SwigVar_PyObject result = PyObject_CallFunctionObjArgs(method ,(PyObject *)obj0, NULL);
#else
  swig::SwigVar_PyObject swig_method_name = SWIG_Python_str_FromChar("onStreamDestroyed");
  swig::SwigVar_PyObject result = PyObject_CallMethodObjArgs(swig_get_self(), (PyObject *) swig_method_name ,(PyObject *)obj0, NULL);
#endif
  if (!result) {
    PyObject *error = PyErr_Occurred();
    {
      if( error != NULL ) {
        PyObject *ptype, *pvalue, *ptraceback;
        PyErr_Fetch( &ptype, &pvalue, &ptraceback );
        PyErr_Restore( ptype, pvalue, ptraceback );
        PyErr_Print();
        //Py_Exit(1);
      }
    }
  }
}


void SwigDirector_Call::onDtmfDigit(pj::OnDtmfDigitParam &prm) {
  swig::SwigVar_PyObject obj0;
  obj0 = SWIG_NewPointerObj(SWIG_as_voidptr(&prm), SWIGTYPE_p_pj__OnDtmfDigitParam,  0 );
  if (!swig_get_self()) {
    Swig::DirectorException::raise("'self' uninitialized, maybe you forgot to call Call.__init__.");
  }
#if defined(SWIG_PYTHON_DIRECTOR_VTABLE)
  const size_t swig_method_index = 7;
  const char *const swig_method_name = "onDtmfDigit";
  PyObject *method = swig_get_method(swig_method_index, swig_method_name);
  swig::SwigVar_PyObject result = PyObject_CallFunctionObjArgs(method ,(PyObject *)obj0, NULL);
#else
  swig::SwigVar_PyObject swig_method_name = SWIG_Python_str_FromChar("onDtmfDigit");
  swig::SwigVar_PyObject result = PyObject_CallMethodObjArgs(swig_get_self(), (PyObject *) swig_method_name ,(PyObject *)obj0, NULL);
#endif
  if (!result) {
    PyObject *error = PyErr_Occurred();
    {
      if( error != NULL ) {
        PyObject *ptype, *pvalue, *ptraceback;
        PyErr_Fetch( &ptype, &pvalue, &ptraceback );
        PyErr_Restore( ptype, pvalue, ptraceback );
        PyErr_Print();
        //Py_Exit(1);
      }
    }
  }
}


void SwigDirector_Call::onDtmfEvent(pj::OnDtmfEventParam &prm) {
  swig::SwigVar_PyObject obj0;
  obj0 = SWIG_NewPointerObj(SWIG_as_voidptr(&prm), SWIGTYPE_p_pj__OnDtmfEventParam,  0 );
  if (!swig_get_self()) {
    Swig::DirectorException::raise("'self' uninitialized, maybe you forgot to call Call.__init__.");
  }
#if defined(SWIG_PYTHON_DIRECTOR_VTABLE)
  const size_t swig_method_index = 8;
  const char *const swig_method_name = "onDtmfEvent";
  PyObject *method = swig_get_method(swig_method_index, swig_method_name);
  swig::SwigVar_PyObject result = PyObject_CallFunctionObjArgs(method ,(PyObject *)obj0, NULL);
#else
  swig::SwigVar_PyObject swig_method_name = SWIG_Python_str_FromChar("onDtmfEvent");
  swig::SwigVar_PyObject result = PyObject_CallMethodObjArgs(swig_get_self(), (PyObject *) swig_method_name ,(PyObject *)obj0, NULL);
#endif
  if (!result) {
    PyObject *error = PyErr_Occurred();
    {
      if( error != NULL ) {
        PyObject *ptype, *pvalue, *ptraceback;
        PyErr_Fetch( &ptype, &pvalue, &ptraceback );
        PyErr_Restore( ptype, pvalue, ptraceback );
        PyErr_Print();
        //Py_Exit(1);
      }
    }
  }
}


void SwigDirector_Call::onCallTransferRequest(pj::OnCallTransferRequestParam &prm) {
  swig::SwigVar_PyObject obj0;
  obj0 = SWIG_NewPointerObj(SWIG_as_voidptr(&prm), SWIGTYPE_p_pj__OnCallTransferRequestParam,  0 );
  if (!swig_get_self()) {
    Swig::DirectorException::raise("'self' uninitialized, maybe you forgot to call Call.__init__.");
  }
#if defined(SWIG_PYTHON_DIRECTOR_VTABLE)
  const size_t swig_method_index = 9;
  const char *const swig_method_name = "onCallTransferRequest";
  PyObject *method = swig_get_method(swig_method_index, swig_method_name);
  swig::SwigVar_PyObject result = PyObject_CallFunctionObjArgs(method ,(PyObject *)obj0, NULL);
#else
  swig::SwigVar_PyObject swig_method_name = SWIG_Python_str_FromChar("onCallTransferRequest");
  swig::SwigVar_PyObject result = PyObject_CallMethodObjArgs(swig_get_self(), (PyObject *) swig_method_name ,(PyObject *)obj0, NULL);
#endif
  if (!result) {
    PyObject *error = PyErr_Occurred();
    {
      if( error != NULL ) {
        PyObject *ptype, *pvalue, *ptraceback;
        PyErr_Fetch( &ptype, &pvalue, &ptraceback );
        PyErr_Restore( ptype, pvalue, ptraceback );
        PyErr_Print();
        //Py_Exit(1);
      }
    }
  }
}


void SwigDirector_Call::onCallTransferStatus(pj::OnCallTransferStatusParam &prm) {
  swig::SwigVar_PyObject obj0;
  obj0 = SWIG_NewPointerObj(SWIG_as_voidptr(&prm), SWIGTYPE_p_pj__OnCallTransferStatusParam,  0 );
  if (!swig_get_self()) {
    Swig::DirectorException::raise("'self' uninitialized, maybe you forgot to call Call.__init__.");
  }
#if defined(SWIG_PYTHON_DIRECTOR_VTABLE)
  const size_t swig_method_index = 10;
  const char *const swig_method_name = "onCallTransferStatus";
  PyObject *method = swig_get_method(swig_method_index, swig_method_name);
  swig::SwigVar_PyObject result = PyObject_CallFunctionObjArgs(method ,(PyObject *)obj0, NULL);
#else
  swig::SwigVar_PyObject swig_method_name = SWIG_Python_str_FromChar("onCallTransferStatus");
  swig::SwigVar_PyObject result = PyObject_CallMethodObjArgs(swig_get_self(), (PyObject *) swig_method_name ,(PyObject *)obj0, NULL);
#endif
  if (!result) {
    PyObject *error = PyErr_Occurred();
    {
      if( error != NULL ) {
        PyObject *ptype, *pvalue, *ptraceback;
        PyErr_Fetch( &ptype, &pvalue, &ptraceback );
        PyErr_Restore( ptype, pvalue, ptraceback );
        PyErr_Print();
        //Py_Exit(1);
      }
    }
  }
}


void SwigDirector_Call::onCallReplaceRequest(pj::OnCallReplaceRequestParam &prm) {
  swig::SwigVar_PyObject obj0;
  obj0 = SWIG_NewPointerObj(SWIG_as_voidptr(&prm), SWIGTYPE_p_pj__OnCallReplaceRequestParam,  0 );
  if (!swig_get_self()) {
    Swig::DirectorException::raise("'self' uninitialized, maybe you forgot to call Call.__init__.");
  }
#if defined(SWIG_PYTHON_DIRECTOR_VTABLE)
  const size_t swig_method_index = 11;
  const char *const swig_method_name = "onCallReplaceRequest";
  PyObject *method = swig_get_method(swig_method_index, swig_method_name);
  swig::SwigVar_PyObject result = PyObject_CallFunctionObjArgs(method ,(PyObject *)obj0, NULL);
#else
  swig::SwigVar_PyObject swig_method_name = SWIG_Python_str_FromChar("onCallReplaceRequest");
  swig::SwigVar_PyObject result = PyObject_CallMethodObjArgs(swig_get_self(), (PyObject *) swig_method_name ,(PyObject *)obj0, NULL);
#endif
  if (!result) {
    PyObject *error = PyErr_Occurred();
    {
      if( error != NULL ) {
        PyObject *ptype, *pvalue, *ptraceback;
        PyErr_Fetch( &ptype, &pvalue, &ptraceback );
        PyErr_Restore( ptype, pvalue, ptraceback );
        PyErr_Print();
        //Py_Exit(1);
      }
    }
  }
}


void SwigDirector_Call::onCallReplaced(pj::OnCallReplacedParam &prm) {
  swig::SwigVar_PyObject obj0;
  obj0 = SWIG_NewPointerObj(SWIG_as_voidptr(&prm), SWIGTYPE_p_pj__OnCallReplacedParam,  0 );
  if (!swig_get_self()) {
    Swig::DirectorException::raise("'self' uninitialized, maybe you forgot to call Call.__init__.");
  }
#if defined(SWIG_PYTHON_DIRECTOR_VTABLE)
  const size_t swig_method_index = 12;
  const char *const swig_method_name = "onCallReplaced";
  PyObject *method = swig_get_method(swig_method_index, swig_method_name);
  swig::SwigVar_PyObject result = PyObject_CallFunctionObjArgs(method ,(PyObject *)obj0, NULL);
#else
  swig::SwigVar_PyObject swig_method_name = SWIG_Python_str_FromChar("onCallReplaced");
  swig::SwigVar_PyObject result = PyObject_CallMethodObjArgs(swig_get_self(), (PyObject *) swig_method_name ,(PyObject *)obj0, NULL);
#endif
  if (!result) {
    PyObject *error = PyErr_Occurred();
    {
      if( error != NULL ) {
        PyObject *ptype, *pvalue, *ptraceback;
        PyErr_Fetch( &ptype, &pvalue, &ptraceback );
        PyErr_Restore( ptype, pvalue, ptraceback );
        PyErr_Print();
        //Py_Exit(1);
      }
    }
  }
}


void SwigDirector_Call::onCallRxOffer(pj::OnCallRxOfferParam &prm) {
  swig::SwigVar_PyObject obj0;
  obj0 = SWIG_NewPointerObj(SWIG_as_voidptr(&prm), SWIGTYPE_p_pj__OnCallRxOfferParam,  0 );
  if (!swig_get_self()) {
    Swig::DirectorException::raise("'self' uninitialized, maybe you forgot to call Call.__init__.");
  }
#if defined(SWIG_PYTHON_DIRECTOR_VTABLE)
  const size_t swig_method_index = 13;
  const char *const swig_method_name = "onCallRxOffer";
  PyObject *method = swig_get_method(swig_method_index, swig_method_name);
  swig::SwigVar_PyObject result = PyObject_CallFunctionObjArgs(method ,(PyObject *)obj0, NULL);
#else
  swig::SwigVar_PyObject swig_method_name = SWIG_Python_str_FromChar("onCallRxOffer");
  swig::SwigVar_PyObject result = PyObject_CallMethodObjArgs(swig_get_self(), (PyObject *) swig_method_name ,(PyObject *)obj0, NULL);
#endif
  if (!result) {
    PyObject *error = PyErr_Occurred();
    {
      if( error != NULL ) {
        PyObject *ptype, *pvalue, *ptraceback;
        PyErr_Fetch( &ptype, &pvalue, &ptraceback );
        PyErr_Restore( ptype, pvalue, ptraceback );
        PyErr_Print();
        //Py_Exit(1);
      }
    }
  }
}


void SwigDirector_Call::onCallRxReinvite(pj::OnCallRxReinviteParam &prm) {
  swig::SwigVar_PyObject obj0;
  obj0 = SWIG_NewPointerObj(SWIG_as_voidptr(&prm), SWIGTYPE_p_pj__OnCallRxReinviteParam,  0 );
  if (!swig_get_self()) {
    Swig::DirectorException::raise("'self' uninitialized, maybe you forgot to call Call.__init__.");
  }
#if defined(SWIG_PYTHON_DIRECTOR_VTABLE)
  const size_t swig_method_index = 14;
  const char *const swig_method_name = "onCallRxReinvite";
  PyObject *method = swig_get_method(swig_method_index, swig_method_name);
  swig::SwigVar_PyObject result = PyObject_CallFunctionObjArgs(method ,(PyObject *)obj0, NULL);
#else
  swig::SwigVar_PyObject swig_method_name = SWIG_Python_str_FromChar("onCallRxReinvite");
  swig::SwigVar_PyObject result = PyObject_CallMethodObjArgs(swig_get_self(), (PyObject *) swig_method_name ,(PyObject *)obj0, NULL);
#endif
  if (!result) {
    PyObject *error = PyErr_Occurred();
    {
      if( error != NULL ) {
        PyObject *ptype, *pvalue, *ptraceback;
        PyErr_Fetch( &ptype, &pvalue, &ptraceback );
        PyErr_Restore( ptype, pvalue, ptraceback );
        PyErr_Print();
        //Py_Exit(1);
      }
    }
  }
}


void SwigDirector_Call::onCallTxOffer(pj::OnCallTxOfferParam &prm) {
  swig::SwigVar_PyObject obj0;
  obj0 = SWIG_NewPointerObj(SWIG_as_voidptr(&prm), SWIGTYPE_p_pj__OnCallTxOfferParam,  0 );
  if (!swig_get_self()) {
    Swig::DirectorException::raise("'self' uninitialized, maybe you forgot to call Call.__init__.");
  }
#if defined(SWIG_PYTHON_DIRECTOR_VTABLE)
  const size_t swig_method_index = 15;
  const char *const swig_method_name = "onCallTxOffer";
  PyObject *method = swig_get_method(swig_method_index, swig_method_name);
  swig::SwigVar_PyObject result = PyObject_CallFunctionObjArgs(method ,(PyObject *)obj0, NULL);
#else
  swig::SwigVar_PyObject swig_method_name = SWIG_Python_str_FromChar("onCallTxOffer");
  swig::SwigVar_PyObject result = PyObject_CallMethodObjArgs(swig_get_self(), (PyObject *) swig_method_name ,(PyObject *)obj0, NULL);
#endif
  if (!result) {
    PyObject *error = PyErr_Occurred();
    {
      if( error != NULL ) {
        PyObject *ptype, *pvalue, *ptraceback;
        PyErr_Fetch( &ptype, &pvalue, &ptraceback );
        PyErr_Restore( ptype, pvalue, ptraceback );
        PyErr_Print();
        //Py_Exit(1);
      }
    }
  }
}


void SwigDirector_Call::onInstantMessage(pj::OnInstantMessageParam &prm) {
  swig::SwigVar_PyObject obj0;
  obj0 = SWIG_NewPointerObj(SWIG_as_voidptr(&prm), SWIGTYPE_p_pj__OnInstantMessageParam,  0 );
  if (!swig_get_self()) {
    Swig::DirectorException::raise("'self' uninitialized, maybe you forgot to call Call.__init__.");
  }
#if defined(SWIG_PYTHON_DIRECTOR_VTABLE)
  const size_t swig_method_index = 16;
  const char *const swig_method_name = "onInstantMessage";
  PyObject *method = swig_get_method(swig_method_index, swig_method_name);
  swig::SwigVar_PyObject result = PyObject_CallFunctionObjArgs(method ,(PyObject *)obj0, NULL);
#else
  swig::SwigVar_PyObject swig_method_name = SWIG_Python_str_FromChar("onInstantMessage");
  swig::SwigVar_PyObject result = PyObject_CallMethodObjArgs(swig_get_self(), (PyObject *) swig_method_name ,(PyObject *)obj0, NULL);
#endif
  if (!result) {
    PyObject *error = PyErr_Occurred();
    {
      if( error != NULL ) {
        PyObject *ptype, *pvalue, *ptraceback;
        PyErr_Fetch( &ptype, &pvalue, &ptraceback );
        PyErr_Restore( ptype, pvalue, ptraceback );
        PyErr_Print();
        //Py_Exit(1);
      }
    }
  }
}


void SwigDirector_Call::onInstantMessageStatus(pj::OnInstantMessageStatusParam &prm) {
  swig::SwigVar_PyObject obj0;
  obj0 = SWIG_NewPointerObj(SWIG_as_voidptr(&prm), SWIGTYPE_p_pj__OnInstantMessageStatusParam,  0 );
  if (!swig_get_self()) {
    Swig::DirectorException::raise("'self' uninitialized, maybe you forgot to call Call.__init__.");
  }
#if defined(SWIG_PYTHON_DIRECTOR_VTABLE)
  const size_t swig_method_index = 17;
  const char *const swig_method_name = "onInstantMessageStatus";
  PyObject *method = swig_get_method(swig_method_index, swig_method_name);
  swig::SwigVar_PyObject result = PyObject_CallFunctionObjArgs(method ,(PyObject *)obj0, NULL);
#else
  swig::SwigVar_PyObject swig_method_name = SWIG_Python_str_FromChar("onInstantMessageStatus");
  swig::SwigVar_PyObject result = PyObject_CallMethodObjArgs(swig_get_self(), (PyObject *) swig_method_name ,(PyObject *)obj0, NULL);
#endif
  if (!result) {
    PyObject *error = PyErr_Occurred();
    {
      if( error != NULL ) {
        PyObject *ptype, *pvalue, *ptraceback;
        PyErr_Fetch( &ptype, &pvalue, &ptraceback );
        PyErr_Restore( ptype, pvalue, ptraceback );
        PyErr_Print();
        //Py_Exit(1);
      }
    }
  }
}


void SwigDirector_Call::onTypingIndication(pj::OnTypingIndicationParam &prm) {
  swig::SwigVar_PyObject obj0;
  obj0 = SWIG_NewPointerObj(SWIG_as_voidptr(&prm), SWIGTYPE_p_pj__OnTypingIndicationParam,  0 );
  if (!swig_get_self()) {
    Swig::DirectorException::raise("'self' uninitialized, maybe you forgot to call Call.__init__.");
  }
#if defined(SWIG_PYTHON_DIRECTOR_VTABLE)
  const size_t swig_method_index = 18;
  const char *const swig_method_name = "onTypingIndication";
  PyObject *method = swig_get_method(swig_method_index, swig_method_name);
  swig::SwigVar_PyObject result = PyObject_CallFunctionObjArgs(method ,(PyObject *)obj0, NULL);
#else
  swig::SwigVar_PyObject swig_method_name = SWIG_Python_str_FromChar("onTypingIndication");
  swig::SwigVar_PyObject result = PyObject_CallMethodObjArgs(swig_get_self(), (PyObject *) swig_method_name ,(PyObject *)obj0, NULL);
#endif
  if (!result) {
    PyObject *error = PyErr_Occurred();
    {
      if( error != NULL ) {
        PyObject *ptype, *pvalue, *ptraceback;
        PyErr_Fetch( &ptype, &pvalue, &ptraceback );
        PyErr_Restore( ptype, pvalue, ptraceback );
        PyErr_Print();
        //Py_Exit(1);
      }
    }
  }
}


pjsip_redirect_op SwigDirector_Call::onCallRedirected(pj::OnCallRedirectedParam &prm) {
  pjsip_redirect_op c_result = SwigValueInit< pjsip_redirect_op >() ;
  
  swig::SwigVar_PyObject obj0;
  obj0 = SWIG_NewPointerObj(SWIG_as_voidptr(&prm), SWIGTYPE_p_pj__OnCallRedirectedParam,  0 );
  if (!swig_get_self()) {
    Swig::DirectorException::raise("'self' uninitialized, maybe you forgot to call Call.__init__.");
  }
#if defined(SWIG_PYTHON_DIRECTOR_VTABLE)
  const size_t swig_method_index = 19;
  const char *const swig_method_name = "onCallRedirected";
  PyObject *method = swig_get_method(swig_method_index, swig_method_name);
  swig::SwigVar_PyObject result = PyObject_CallFunctionObjArgs(method ,(PyObject *)obj0, NULL);
#else
  swig::SwigVar_PyObject swig_method_name = SWIG_Python_str_FromChar("onCallRedirected");
  swig::SwigVar_PyObject result = PyObject_CallMethodObjArgs(swig_get_self(), (PyObject *) swig_method_name ,(PyObject *)obj0, NULL);
#endif
  if (!result) {
    PyObject *error = PyErr_Occurred();
    {
      if( error != NULL ) {
        PyObject *ptype, *pvalue, *ptraceback;
        PyErr_Fetch( &ptype, &pvalue, &ptraceback );
        PyErr_Restore( ptype, pvalue, ptraceback );
        PyErr_Print();
        //Py_Exit(1);
      }
    }
  }
  int swig_val;
  int swig_res = SWIG_AsVal_int(result, &swig_val);
  if (!SWIG_IsOK(swig_res)) {
    Swig::DirectorTypeMismatchException::raise(SWIG_ErrorType(SWIG_ArgError(swig_res)), "in output value of type '""pjsip_redirect_op""'");
  }
  c_result = static_cast< pjsip_redirect_op >(swig_val);
  return (pjsip_redirect_op) c_result;
}


void SwigDirector_Call::onCallMediaTransportState(pj::OnCallMediaTransportStateParam &prm) {
  swig::SwigVar_PyObject obj0;
  obj0 = SWIG_NewPointerObj(SWIG_as_voidptr(&prm), SWIGTYPE_p_pj__OnCallMediaTransportStateParam,  0 );
  if (!swig_get_self()) {
    Swig::DirectorException::raise("'self' uninitialized, maybe you forgot to call Call.__init__.");
  }
#if defined(SWIG_PYTHON_DIRECTOR_VTABLE)
  const size_t swig_method_index = 20;
  const char *const swig_method_name = "onCallMediaTransportState";
  PyObject *method = swig_get_method(swig_method_index, swig_method_name);
  swig::SwigVar_PyObject result = PyObject_CallFunctionObjArgs(method ,(PyObject *)obj0, NULL);
#else
  swig::SwigVar_PyObject swig_method_name = SWIG_Python_str_FromChar("onCallMediaTransportState");
  swig::SwigVar_PyObject result = PyObject_CallMethodObjArgs(swig_get_self(), (PyObject *) swig_method_name ,(PyObject *)obj0, NULL);
#endif
  if (!result) {
    PyObject *error = PyErr_Occurred();
    {
      if( error != NULL ) {
        PyObject *ptype, *pvalue, *ptraceback;
        PyErr_Fetch( &ptype, &pvalue, &ptraceback );
        PyErr_Restore( ptype, pvalue, ptraceback );
        PyErr_Print();
        //Py_Exit(1);
      }
    }
  }
}


void SwigDirector_Call::onCallMediaEvent(pj::OnCallMediaEventParam &prm) {
  swig::SwigVar_PyObject obj0;
  obj0 = SWIG_NewPointerObj(SWIG_as_voidptr(&prm), SWIGTYPE_p_pj__OnCallMediaEventParam,  0 );
  if (!swig_get_self()) {
    Swig::DirectorException::raise("'self' uninitialized, maybe you forgot to call Call.__init__.");
  }
#if defined(SWIG_PYTHON_DIRECTOR_VTABLE)
  const size_t swig_method_index = 21;
  const char *const swig_method_name = "onCallMediaEvent";
  PyObject *method = swig_get_method(swig_method_index, swig_method_name);
  swig::SwigVar_PyObject result = PyObject_CallFunctionObjArgs(method ,(PyObject *)obj0, NULL);
#else
  swig::SwigVar_PyObject swig_method_name = SWIG_Python_str_FromChar("onCallMediaEvent");
  swig::SwigVar_PyObject result = PyObject_CallMethodObjArgs(swig_get_self(), (PyObject *) swig_method_name ,(PyObject *)obj0, NULL);
#endif
  if (!result) {
    PyObject *error = PyErr_Occurred();
    {
      if( error != NULL ) {
        PyObject *ptype, *pvalue, *ptraceback;
        PyErr_Fetch( &ptype, &pvalue, &ptraceback );
        PyErr_Restore( ptype, pvalue, ptraceback );
        PyErr_Print();
        //Py_Exit(1);
      }
    }
  }
}


void SwigDirector_Call::onCreateMediaTransport(pj::OnCreateMediaTransportParam &prm) {
  swig::SwigVar_PyObject obj0;
  obj0 = SWIG_NewPointerObj(SWIG_as_voidptr(&prm), SWIGTYPE_p_pj__OnCreateMediaTransportParam,  0 );
  if (!swig_get_self()) {
    Swig::DirectorException::raise("'self' uninitialized, maybe you forgot to call Call.__init__.");
  }
#if defined(SWIG_PYTHON_DIRECTOR_VTABLE)
  const size_t swig_method_index = 22;
  const char *const swig_method_name = "onCreateMediaTransport";
  PyObject *method = swig_get_method(swig_method_index, swig_method_name);
  swig::SwigVar_PyObject result = PyObject_CallFunctionObjArgs(method ,(PyObject *)obj0, NULL);
#else
  swig::SwigVar_PyObject swig_method_name = SWIG_Python_str_FromChar("onCreateMediaTransport");
  swig::SwigVar_PyObject result = PyObject_CallMethodObjArgs(swig_get_self(), (PyObject *) swig_method_name ,(PyObject *)obj0, NULL);
#endif
  if (!result) {
    PyObject *error = PyErr_Occurred();
    {
      if( error != NULL ) {
        PyObject *ptype, *pvalue, *ptraceback;
        PyErr_Fetch( &ptype, &pvalue, &ptraceback );
        PyErr_Restore( ptype, pvalue, ptraceback );
        PyErr_Print();
        //Py_Exit(1);
      }
    }
  }
}


void SwigDirector_Call::onCreateMediaTransportSrtp(pj::OnCreateMediaTransportSrtpParam &prm) {
  swig::SwigVar_PyObject obj0;
  obj0 = SWIG_NewPointerObj(SWIG_as_voidptr(&prm), SWIGTYPE_p_pj__OnCreateMediaTransportSrtpParam,  0 );
  if (!swig_get_self()) {
    Swig::DirectorException::raise("'self' uninitialized, maybe you forgot to call Call.__init__.");
  }
#if defined(SWIG_PYTHON_DIRECTOR_VTABLE)
  const size_t swig_method_index = 23;
  const char *const swig_method_name = "onCreateMediaTransportSrtp";
  PyObject *method = swig_get_method(swig_method_index, swig_method_name);
  swig::SwigVar_PyObject result = PyObject_CallFunctionObjArgs(method ,(PyObject *)obj0, NULL);
#else
  swig::SwigVar_PyObject swig_method_name = SWIG_Python_str_FromChar("onCreateMediaTransportSrtp");
  swig::SwigVar_PyObject result = PyObject_CallMethodObjArgs(swig_get_self(), (PyObject *) swig_method_name ,(PyObject *)obj0, NULL);
#endif
  if (!result) {
    PyObject *error = PyErr_Occurred();
    {
      if( error != NULL ) {
        PyObject *ptype, *pvalue, *ptraceback;
        PyErr_Fetch( &ptype, &pvalue, &ptraceback );
        PyErr_Restore( ptype, pvalue, ptraceback );
        PyErr_Print();
        //Py_Exit(1);
      }
    }
  }
}


SwigDirector_LogWriter::SwigDirector_LogWriter(PyObject *self): pj::LogWriter(), Swig::Director(self) {
  SWIG_DIRECTOR_RGTR((pj::LogWriter *)this, this); 
}




SwigDirector_LogWriter::~SwigDirector_LogWriter() {
}

void SwigDirector_LogWriter::write(pj::LogEntry const &entry) {
  swig::SwigVar_PyObject obj0;
  obj0 = SWIG_NewPointerObj(SWIG_as_voidptr(&entry), SWIGTYPE_p_pj__LogEntry,  0 );
  if (!swig_get_self()) {
    Swig::DirectorException::raise("'self' uninitialized, maybe you forgot to call LogWriter.__init__.");
  }
#if defined(SWIG_PYTHON_DIRECTOR_VTABLE)
  const size_t swig_method_index = 0;
  const char *const swig_method_name = "write";
  PyObject *method = swig_get_method(swig_method_index, swig_method_name);
  swig::SwigVar_PyObject result = PyObject_CallFunctionObjArgs(method ,(PyObject *)obj0, NULL);
#else
  swig::SwigVar_PyObject swig_method_name = SWIG_Python_str_FromChar("write");
  swig::SwigVar_PyObject result = PyObject_CallMethodObjArgs(swig_get_self(), (PyObject *) swig_method_name ,(PyObject *)obj0, NULL);
#endif
  if (!result) {
    PyObject *error = PyErr_Occurred();
    {
      if( error != NULL ) {
        PyObject *ptype, *pvalue, *ptraceback;
        PyErr_Fetch( &ptype, &pvalue, &ptraceback );
        PyErr_Restore( ptype, pvalue, ptraceback );
        PyErr_Print();
        //Py_Exit(1);
      }
    }
  }
}


SwigDirector_Endpoint::SwigDirector_Endpoint(PyObject *self): pj::Endpoint(), Swig::Director(self) {
  SWIG_DIRECTOR_RGTR((pj::Endpoint *)this, this); 
}




SwigDirector_Endpoint::~SwigDirector_Endpoint() {
}

void SwigDirector_Endpoint::onNatDetectionComplete(pj::OnNatDetectionCompleteParam const &prm) {
  swig::SwigVar_PyObject obj0;
  obj0 = SWIG_NewPointerObj(SWIG_as_voidptr(&prm), SWIGTYPE_p_pj__OnNatDetectionCompleteParam,  0 );
  if (!swig_get_self()) {
    Swig::DirectorException::raise("'self' uninitialized, maybe you forgot to call Endpoint.__init__.");
  }
#if defined(SWIG_PYTHON_DIRECTOR_VTABLE)
  const size_t swig_method_index = 0;
  const char *const swig_method_name = "onNatDetectionComplete";
  PyObject *method = swig_get_method(swig_method_index, swig_method_name);
  swig::SwigVar_PyObject result = PyObject_CallFunctionObjArgs(method ,(PyObject *)obj0, NULL);
#else
  swig::SwigVar_PyObject swig_method_name = SWIG_Python_str_FromChar("onNatDetectionComplete");
  swig::SwigVar_PyObject result = PyObject_CallMethodObjArgs(swig_get_self(), (PyObject *) swig_method_name ,(PyObject *)obj0, NULL);
#endif
  if (!result) {
    PyObject *error = PyErr_Occurred();
    {
      if( error != NULL ) {
        PyObject *ptype, *pvalue, *ptraceback;
        PyErr_Fetch( &ptype, &pvalue, &ptraceback );
        PyErr_Restore( ptype, pvalue, ptraceback );
        PyErr_Print();
        //Py_Exit(1);
      }
    }
  }
}


void SwigDirector_Endpoint::onNatCheckStunServersComplete(pj::OnNatCheckStunServersCompleteParam const &prm) {
  swig::SwigVar_PyObject obj0;
  obj0 = SWIG_NewPointerObj(SWIG_as_voidptr(&prm), SWIGTYPE_p_pj__OnNatCheckStunServersCompleteParam,  0 );
  if (!swig_get_self()) {
    Swig::DirectorException::raise("'self' uninitialized, maybe you forgot to call Endpoint.__init__.");
  }
#if defined(SWIG_PYTHON_DIRECTOR_VTABLE)
  const size_t swig_method_index = 1;
  const char *const swig_method_name = "onNatCheckStunServersComplete";
  PyObject *method = swig_get_method(swig_method_index, swig_method_name);
  swig::SwigVar_PyObject result = PyObject_CallFunctionObjArgs(method ,(PyObject *)obj0, NULL);
#else
  swig::SwigVar_PyObject swig_method_name = SWIG_Python_str_FromChar("onNatCheckStunServersComplete");
  swig::SwigVar_PyObject result = PyObject_CallMethodObjArgs(swig_get_self(), (PyObject *) swig_method_name ,(PyObject *)obj0, NULL);
#endif
  if (!result) {
    PyObject *error = PyErr_Occurred();
    {
      if( error != NULL ) {
        PyObject *ptype, *pvalue, *ptraceback;
        PyErr_Fetch( &ptype, &pvalue, &ptraceback );
        PyErr_Restore( ptype, pvalue, ptraceback );
        PyErr_Print();
        //Py_Exit(1);
      }
    }
  }
}


void SwigDirector_Endpoint::onTransportState(pj::OnTransportStateParam const &prm) {
  swig::SwigVar_PyObject obj0;
  obj0 = SWIG_NewPointerObj(SWIG_as_voidptr(&prm), SWIGTYPE_p_pj__OnTransportStateParam,  0 );
  if (!swig_get_self()) {
    Swig::DirectorException::raise("'self' uninitialized, maybe you forgot to call Endpoint.__init__.");
  }
#if defined(SWIG_PYTHON_DIRECTOR_VTABLE)
  const size_t swig_method_index = 2;
  const char *const swig_method_name = "onTransportState";
  PyObject *method = swig_get_method(swig_method_index, swig_method_name);
  swig::SwigVar_PyObject result = PyObject_CallFunctionObjArgs(method ,(PyObject *)obj0, NULL);
#else
  swig::SwigVar_PyObject swig_method_name = SWIG_Python_str_FromChar("onTransportState");
  swig::SwigVar_PyObject result = PyObject_CallMethodObjArgs(swig_get_self(), (PyObject *) swig_method_name ,(PyObject *)obj0, NULL);
#endif
  if (!result) {
    PyObject *error = PyErr_Occurred();
    {
      if( error != NULL ) {
        PyObject *ptype, *pvalue, *ptraceback;
        PyErr_Fetch( &ptype, &pvalue, &ptraceback );
        PyErr_Restore( ptype, pvalue, ptraceback );
        PyErr_Print();
        //Py_Exit(1);
      }
    }
  }
}


void SwigDirector_Endpoint::onTimer(pj::OnTimerParam const &prm) {
  swig::SwigVar_PyObject obj0;
  obj0 = SWIG_NewPointerObj(SWIG_as_voidptr(&prm), SWIGTYPE_p_pj__OnTimerParam,  0 );
  if (!swig_get_self()) {
    Swig::DirectorException::raise("'self' uninitialized, maybe you forgot to call Endpoint.__init__.");
  }
#if defined(SWIG_PYTHON_DIRECTOR_VTABLE)
  const size_t swig_method_index = 3;
  const char *const swig_method_name = "onTimer";
  PyObject *method = swig_get_method(swig_method_index, swig_method_name);
  swig::SwigVar_PyObject result = PyObject_CallFunctionObjArgs(method ,(PyObject *)obj0, NULL);
#else
  swig::SwigVar_PyObject swig_method_name = SWIG_Python_str_FromChar("onTimer");
  swig::SwigVar_PyObject result = PyObject_CallMethodObjArgs(swig_get_self(), (PyObject *) swig_method_name ,(PyObject *)obj0, NULL);
#endif
  if (!result) {
    PyObject *error = PyErr_Occurred();
    {
      if( error != NULL ) {
        PyObject *ptype, *pvalue, *ptraceback;
        PyErr_Fetch( &ptype, &pvalue, &ptraceback );
        PyErr_Restore( ptype, pvalue, ptraceback );
        PyErr_Print();
        //Py_Exit(1);
      }
    }
  }
}


void SwigDirector_Endpoint::onSelectAccount(pj::OnSelectAccountParam &prm) {
  swig::SwigVar_PyObject obj0;
  obj0 = SWIG_NewPointerObj(SWIG_as_voidptr(&prm), SWIGTYPE_p_pj__OnSelectAccountParam,  0 );
  if (!swig_get_self()) {
    Swig::DirectorException::raise("'self' uninitialized, maybe you forgot to call Endpoint.__init__.");
  }
#if defined(SWIG_PYTHON_DIRECTOR_VTABLE)
  const size_t swig_method_index = 4;
  const char *const swig_method_name = "onSelectAccount";
  PyObject *method = swig_get_method(swig_method_index, swig_method_name);
  swig::SwigVar_PyObject result = PyObject_CallFunctionObjArgs(method ,(PyObject *)obj0, NULL);
#else
  swig::SwigVar_PyObject swig_method_name = SWIG_Python_str_FromChar("onSelectAccount");
  swig::SwigVar_PyObject result = PyObject_CallMethodObjArgs(swig_get_self(), (PyObject *) swig_method_name ,(PyObject *)obj0, NULL);
#endif
  if (!result) {
    PyObject *error = PyErr_Occurred();
    {
      if( error != NULL ) {
        PyObject *ptype, *pvalue, *ptraceback;
        PyErr_Fetch( &ptype, &pvalue, &ptraceback );
        PyErr_Restore( ptype, pvalue, ptraceback );
        PyErr_Print();
        //Py_Exit(1);
      }
    }
  }
}


void SwigDirector_Endpoint::onIpChangeProgress(pj::OnIpChangeProgressParam &prm) {
  swig::SwigVar_PyObject obj0;
  obj0 = SWIG_NewPointerObj(SWIG_as_voidptr(&prm), SWIGTYPE_p_pj__OnIpChangeProgressParam,  0 );
  if (!swig_get_self()) {
    Swig::DirectorException::raise("'self' uninitialized, maybe you forgot to call Endpoint.__init__.");
  }
#if defined(SWIG_PYTHON_DIRECTOR_VTABLE)
  const size_t swig_method_index = 5;
  const char *const swig_method_name = "onIpChangeProgress";
  PyObject *method = swig_get_method(swig_method_index, swig_method_name);
  swig::SwigVar_PyObject result = PyObject_CallFunctionObjArgs(method ,(PyObject *)obj0, NULL);
#else
  swig::SwigVar_PyObject swig_method_name = SWIG_Python_str_FromChar("onIpChangeProgress");
  swig::SwigVar_PyObject result = PyObject_CallMethodObjArgs(swig_get_self(), (PyObject *) swig_method_name ,(PyObject *)obj0, NULL);
#endif
  if (!result) {
    PyObject *error = PyErr_Occurred();
    {
      if( error != NULL ) {
        PyObject *ptype, *pvalue, *ptraceback;
        PyErr_Fetch( &ptype, &pvalue, &ptraceback );
        PyErr_Restore( ptype, pvalue, ptraceback );
        PyErr_Print();
        //Py_Exit(1);
      }
    }
  }
}


void SwigDirector_Endpoint::onMediaEvent(pj::OnMediaEventParam &prm) {
  swig::SwigVar_PyObject obj0;
  obj0 = SWIG_NewPointerObj(SWIG_as_voidptr(&prm), SWIGTYPE_p_pj__OnMediaEventParam,  0 );
  if (!swig_get_self()) {
    Swig::DirectorException::raise("'self' uninitialized, maybe you forgot to call Endpoint.__init__.");
  }
#if defined(SWIG_PYTHON_DIRECTOR_VTABLE)
  const size_t swig_method_index = 6;
  const char *const swig_method_name = "onMediaEvent";
  PyObject *method = swig_get_method(swig_method_index, swig_method_name);
  swig::SwigVar_PyObject result = PyObject_CallFunctionObjArgs(method ,(PyObject *)obj0, NULL);
#else
  swig::SwigVar_PyObject swig_method_name = SWIG_Python_str_FromChar("onMediaEvent");
  swig::SwigVar_PyObject result = PyObject_CallMethodObjArgs(swig_get_self(), (PyObject *) swig_method_name ,(PyObject *)obj0, NULL);
#endif
  if (!result) {
    PyObject *error = PyErr_Occurred();
    {
      if( error != NULL ) {
        PyObject *ptype, *pvalue, *ptraceback;
        PyErr_Fetch( &ptype, &pvalue, &ptraceback );
        PyErr_Restore( ptype, pvalue, ptraceback );
        PyErr_Print();
        //Py_Exit(1);
      }
    }
  }
}


pj_status_t SwigDirector_Endpoint::onCredAuth(pj::OnCredAuthParam &prm) {
  pj_status_t c_result = SwigValueInit< pj_status_t >() ;
  
  swig::SwigVar_PyObject obj0;
  obj0 = SWIG_NewPointerObj(SWIG_as_voidptr(&prm), SWIGTYPE_p_pj__OnCredAuthParam,  0 );
  if (!swig_get_self()) {
    Swig::DirectorException::raise("'self' uninitialized, maybe you forgot to call Endpoint.__init__.");
  }
#if defined(SWIG_PYTHON_DIRECTOR_VTABLE)
  const size_t swig_method_index = 7;
  const char *const swig_method_name = "onCredAuth";
  PyObject *method = swig_get_method(swig_method_index, swig_method_name);
  swig::SwigVar_PyObject result = PyObject_CallFunctionObjArgs(method ,(PyObject *)obj0, NULL);
#else
  swig::SwigVar_PyObject swig_method_name = SWIG_Python_str_FromChar("onCredAuth");
  swig::SwigVar_PyObject result = PyObject_CallMethodObjArgs(swig_get_self(), (PyObject *) swig_method_name ,(PyObject *)obj0, NULL);
#endif
  if (!result) {
    PyObject *error = PyErr_Occurred();
    {
      if( error != NULL ) {
        PyObject *ptype, *pvalue, *ptraceback;
        PyErr_Fetch( &ptype, &pvalue, &ptraceback );
        PyErr_Restore( ptype, pvalue, ptraceback );
        PyErr_Print();
        //Py_Exit(1);
      }
    }
  }
  int swig_val;
  int swig_res = SWIG_AsVal_int(result, &swig_val);
  if (!SWIG_IsOK(swig_res)) {
    Swig::DirectorTypeMismatchException::raise(SWIG_ErrorType(SWIG_ArgError(swig_res)), "in output value of type '""pj_status_t""'");
  }
  c_result = static_cast< pj_status_t >(swig_val);
  return (pj_status_t) c_result;
}


#ifdef __cplusplus
extern "C" {
#endif
SWIGINTERN PyObject *_wrap_pj_qos_params_flags_set(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj_qos_params *arg1 = (pj_qos_params *) 0 ;
  pj_uint8_t arg2 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  unsigned char val2 ;
  int ecode2 = 0 ;
  PyObject *swig_obj[2] ;
  
  if (!SWIG_Python_UnpackTuple(args, "pj_qos_params_flags_set", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj_qos_params, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "pj_qos_params_flags_set" "', argument " "1"" of type '" "pj_qos_params *""'"); 
  }
  arg1 = reinterpret_cast< pj_qos_params * >(argp1);
  ecode2 = SWIG_AsVal_unsigned_SS_char(swig_obj[1], &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "pj_qos_params_flags_set" "', argument " "2"" of type '" "pj_uint8_t""'");
  } 
  arg2 = static_cast< pj_uint8_t >(val2);
  if (arg1) (arg1)->flags = arg2;
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_pj_qos_params_flags_get(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj_qos_params *arg1 = (pj_qos_params *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  pj_uint8_t result;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj_qos_params, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "pj_qos_params_flags_get" "', argument " "1"" of type '" "pj_qos_params *""'"); 
  }
  arg1 = reinterpret_cast< pj_qos_params * >(argp1);
  result = (pj_uint8_t) ((arg1)->flags);
  resultobj = SWIG_From_unsigned_SS_char(static_cast< unsigned char >(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_pj_qos_params_dscp_val_set(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj_qos_params *arg1 = (pj_qos_params *) 0 ;
  pj_uint8_t arg2 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  unsigned char val2 ;
  int ecode2 = 0 ;
  PyObject *swig_obj[2] ;
  
  if (!SWIG_Python_UnpackTuple(args, "pj_qos_params_dscp_val_set", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj_qos_params, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "pj_qos_params_dscp_val_set" "', argument " "1"" of type '" "pj_qos_params *""'"); 
  }
  arg1 = reinterpret_cast< pj_qos_params * >(argp1);
  ecode2 = SWIG_AsVal_unsigned_SS_char(swig_obj[1], &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "pj_qos_params_dscp_val_set" "', argument " "2"" of type '" "pj_uint8_t""'");
  } 
  arg2 = static_cast< pj_uint8_t >(val2);
  if (arg1) (arg1)->dscp_val = arg2;
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_pj_qos_params_dscp_val_get(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj_qos_params *arg1 = (pj_qos_params *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  pj_uint8_t result;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj_qos_params, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "pj_qos_params_dscp_val_get" "', argument " "1"" of type '" "pj_qos_params *""'"); 
  }
  arg1 = reinterpret_cast< pj_qos_params * >(argp1);
  result = (pj_uint8_t) ((arg1)->dscp_val);
  resultobj = SWIG_From_unsigned_SS_char(static_cast< unsigned char >(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_pj_qos_params_so_prio_set(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj_qos_params *arg1 = (pj_qos_params *) 0 ;
  pj_uint8_t arg2 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  unsigned char val2 ;
  int ecode2 = 0 ;
  PyObject *swig_obj[2] ;
  
  if (!SWIG_Python_UnpackTuple(args, "pj_qos_params_so_prio_set", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj_qos_params, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "pj_qos_params_so_prio_set" "', argument " "1"" of type '" "pj_qos_params *""'"); 
  }
  arg1 = reinterpret_cast< pj_qos_params * >(argp1);
  ecode2 = SWIG_AsVal_unsigned_SS_char(swig_obj[1], &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "pj_qos_params_so_prio_set" "', argument " "2"" of type '" "pj_uint8_t""'");
  } 
  arg2 = static_cast< pj_uint8_t >(val2);
  if (arg1) (arg1)->so_prio = arg2;
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_pj_qos_params_so_prio_get(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj_qos_params *arg1 = (pj_qos_params *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  pj_uint8_t result;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj_qos_params, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "pj_qos_params_so_prio_get" "', argument " "1"" of type '" "pj_qos_params *""'"); 
  }
  arg1 = reinterpret_cast< pj_qos_params * >(argp1);
  result = (pj_uint8_t) ((arg1)->so_prio);
  resultobj = SWIG_From_unsigned_SS_char(static_cast< unsigned char >(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_pj_qos_params_wmm_prio_set(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj_qos_params *arg1 = (pj_qos_params *) 0 ;
  pj_qos_wmm_prio arg2 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  int val2 ;
  int ecode2 = 0 ;
  PyObject *swig_obj[2] ;
  
  if (!SWIG_Python_UnpackTuple(args, "pj_qos_params_wmm_prio_set", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj_qos_params, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "pj_qos_params_wmm_prio_set" "', argument " "1"" of type '" "pj_qos_params *""'"); 
  }
  arg1 = reinterpret_cast< pj_qos_params * >(argp1);
  ecode2 = SWIG_AsVal_int(swig_obj[1], &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "pj_qos_params_wmm_prio_set" "', argument " "2"" of type '" "pj_qos_wmm_prio""'");
  } 
  arg2 = static_cast< pj_qos_wmm_prio >(val2);
  if (arg1) (arg1)->wmm_prio = arg2;
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_pj_qos_params_wmm_prio_get(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj_qos_params *arg1 = (pj_qos_params *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  pj_qos_wmm_prio result;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj_qos_params, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "pj_qos_params_wmm_prio_get" "', argument " "1"" of type '" "pj_qos_params *""'"); 
  }
  arg1 = reinterpret_cast< pj_qos_params * >(argp1);
  result = (pj_qos_wmm_prio) ((arg1)->wmm_prio);
  resultobj = SWIG_From_int(static_cast< int >(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_new_pj_qos_params(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj_qos_params *result = 0 ;
  
  if (!SWIG_Python_UnpackTuple(args, "new_pj_qos_params", 0, 0, 0)) SWIG_fail;
  result = (pj_qos_params *)new pj_qos_params();
  resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(result), SWIGTYPE_p_pj_qos_params, SWIG_POINTER_NEW |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_delete_pj_qos_params(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj_qos_params *arg1 = (pj_qos_params *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj_qos_params, SWIG_POINTER_DISOWN |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "delete_pj_qos_params" "', argument " "1"" of type '" "pj_qos_params *""'"); 
  }
  arg1 = reinterpret_cast< pj_qos_params * >(argp1);
  delete arg1;
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *pj_qos_params_swigregister(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *obj;
  if (!SWIG_Python_UnpackTuple(args, "swigregister", 1, 1, &obj)) return NULL;
  SWIG_TypeNewClientData(SWIGTYPE_p_pj_qos_params, SWIG_NewClientData(obj));
  return SWIG_Py_Void();
}

SWIGINTERN PyObject *pj_qos_params_swiginit(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  return SWIG_Python_InitShadowInstance(args);
}

SWIGINTERN PyObject *_wrap_pjmedia_tone_digit_digit_set(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pjmedia_tone_digit *arg1 = (pjmedia_tone_digit *) 0 ;
  char arg2 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  char val2 ;
  int ecode2 = 0 ;
  PyObject *swig_obj[2] ;
  
  if (!SWIG_Python_UnpackTuple(args, "pjmedia_tone_digit_digit_set", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pjmedia_tone_digit, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "pjmedia_tone_digit_digit_set" "', argument " "1"" of type '" "pjmedia_tone_digit *""'"); 
  }
  arg1 = reinterpret_cast< pjmedia_tone_digit * >(argp1);
  ecode2 = SWIG_AsVal_char(swig_obj[1], &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "pjmedia_tone_digit_digit_set" "', argument " "2"" of type '" "char""'");
  } 
  arg2 = static_cast< char >(val2);
  if (arg1) (arg1)->digit = arg2;
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_pjmedia_tone_digit_digit_get(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pjmedia_tone_digit *arg1 = (pjmedia_tone_digit *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  char result;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pjmedia_tone_digit, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "pjmedia_tone_digit_digit_get" "', argument " "1"" of type '" "pjmedia_tone_digit *""'"); 
  }
  arg1 = reinterpret_cast< pjmedia_tone_digit * >(argp1);
  result = (char) ((arg1)->digit);
  resultobj = SWIG_From_char(static_cast< char >(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_pjmedia_tone_digit_on_msec_set(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pjmedia_tone_digit *arg1 = (pjmedia_tone_digit *) 0 ;
  short arg2 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  short val2 ;
  int ecode2 = 0 ;
  PyObject *swig_obj[2] ;
  
  if (!SWIG_Python_UnpackTuple(args, "pjmedia_tone_digit_on_msec_set", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pjmedia_tone_digit, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "pjmedia_tone_digit_on_msec_set" "', argument " "1"" of type '" "pjmedia_tone_digit *""'"); 
  }
  arg1 = reinterpret_cast< pjmedia_tone_digit * >(argp1);
  ecode2 = SWIG_AsVal_short(swig_obj[1], &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "pjmedia_tone_digit_on_msec_set" "', argument " "2"" of type '" "short""'");
  } 
  arg2 = static_cast< short >(val2);
  if (arg1) (arg1)->on_msec = arg2;
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_pjmedia_tone_digit_on_msec_get(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pjmedia_tone_digit *arg1 = (pjmedia_tone_digit *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  short result;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pjmedia_tone_digit, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "pjmedia_tone_digit_on_msec_get" "', argument " "1"" of type '" "pjmedia_tone_digit *""'"); 
  }
  arg1 = reinterpret_cast< pjmedia_tone_digit * >(argp1);
  result = (short) ((arg1)->on_msec);
  resultobj = SWIG_From_short(static_cast< short >(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_pjmedia_tone_digit_off_msec_set(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pjmedia_tone_digit *arg1 = (pjmedia_tone_digit *) 0 ;
  short arg2 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  short val2 ;
  int ecode2 = 0 ;
  PyObject *swig_obj[2] ;
  
  if (!SWIG_Python_UnpackTuple(args, "pjmedia_tone_digit_off_msec_set", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pjmedia_tone_digit, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "pjmedia_tone_digit_off_msec_set" "', argument " "1"" of type '" "pjmedia_tone_digit *""'"); 
  }
  arg1 = reinterpret_cast< pjmedia_tone_digit * >(argp1);
  ecode2 = SWIG_AsVal_short(swig_obj[1], &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "pjmedia_tone_digit_off_msec_set" "', argument " "2"" of type '" "short""'");
  } 
  arg2 = static_cast< short >(val2);
  if (arg1) (arg1)->off_msec = arg2;
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_pjmedia_tone_digit_off_msec_get(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pjmedia_tone_digit *arg1 = (pjmedia_tone_digit *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  short result;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pjmedia_tone_digit, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "pjmedia_tone_digit_off_msec_get" "', argument " "1"" of type '" "pjmedia_tone_digit *""'"); 
  }
  arg1 = reinterpret_cast< pjmedia_tone_digit * >(argp1);
  result = (short) ((arg1)->off_msec);
  resultobj = SWIG_From_short(static_cast< short >(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_pjmedia_tone_digit_volume_set(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pjmedia_tone_digit *arg1 = (pjmedia_tone_digit *) 0 ;
  short arg2 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  short val2 ;
  int ecode2 = 0 ;
  PyObject *swig_obj[2] ;
  
  if (!SWIG_Python_UnpackTuple(args, "pjmedia_tone_digit_volume_set", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pjmedia_tone_digit, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "pjmedia_tone_digit_volume_set" "', argument " "1"" of type '" "pjmedia_tone_digit *""'"); 
  }
  arg1 = reinterpret_cast< pjmedia_tone_digit * >(argp1);
  ecode2 = SWIG_AsVal_short(swig_obj[1], &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "pjmedia_tone_digit_volume_set" "', argument " "2"" of type '" "short""'");
  } 
  arg2 = static_cast< short >(val2);
  if (arg1) (arg1)->volume = arg2;
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_pjmedia_tone_digit_volume_get(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pjmedia_tone_digit *arg1 = (pjmedia_tone_digit *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  short result;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pjmedia_tone_digit, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "pjmedia_tone_digit_volume_get" "', argument " "1"" of type '" "pjmedia_tone_digit *""'"); 
  }
  arg1 = reinterpret_cast< pjmedia_tone_digit * >(argp1);
  result = (short) ((arg1)->volume);
  resultobj = SWIG_From_short(static_cast< short >(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_new_pjmedia_tone_digit(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pjmedia_tone_digit *result = 0 ;
  
  if (!SWIG_Python_UnpackTuple(args, "new_pjmedia_tone_digit", 0, 0, 0)) SWIG_fail;
  result = (pjmedia_tone_digit *)new pjmedia_tone_digit();
  resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(result), SWIGTYPE_p_pjmedia_tone_digit, SWIG_POINTER_NEW |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_delete_pjmedia_tone_digit(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pjmedia_tone_digit *arg1 = (pjmedia_tone_digit *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pjmedia_tone_digit, SWIG_POINTER_DISOWN |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "delete_pjmedia_tone_digit" "', argument " "1"" of type '" "pjmedia_tone_digit *""'"); 
  }
  arg1 = reinterpret_cast< pjmedia_tone_digit * >(argp1);
  delete arg1;
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *pjmedia_tone_digit_swigregister(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *obj;
  if (!SWIG_Python_UnpackTuple(args, "swigregister", 1, 1, &obj)) return NULL;
  SWIG_TypeNewClientData(SWIGTYPE_p_pjmedia_tone_digit, SWIG_NewClientData(obj));
  return SWIG_Py_Void();
}

SWIGINTERN PyObject *pjmedia_tone_digit_swiginit(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  return SWIG_Python_InitShadowInstance(args);
}

SWIGINTERN PyObject *_wrap_pjmedia_tone_digit_map_count_set(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pjmedia_tone_digit_map *arg1 = (pjmedia_tone_digit_map *) 0 ;
  unsigned int arg2 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  unsigned int val2 ;
  int ecode2 = 0 ;
  PyObject *swig_obj[2] ;
  
  if (!SWIG_Python_UnpackTuple(args, "pjmedia_tone_digit_map_count_set", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pjmedia_tone_digit_map, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "pjmedia_tone_digit_map_count_set" "', argument " "1"" of type '" "pjmedia_tone_digit_map *""'"); 
  }
  arg1 = reinterpret_cast< pjmedia_tone_digit_map * >(argp1);
  ecode2 = SWIG_AsVal_unsigned_SS_int(swig_obj[1], &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "pjmedia_tone_digit_map_count_set" "', argument " "2"" of type '" "unsigned int""'");
  } 
  arg2 = static_cast< unsigned int >(val2);
  if (arg1) (arg1)->count = arg2;
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_pjmedia_tone_digit_map_count_get(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pjmedia_tone_digit_map *arg1 = (pjmedia_tone_digit_map *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  unsigned int result;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pjmedia_tone_digit_map, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "pjmedia_tone_digit_map_count_get" "', argument " "1"" of type '" "pjmedia_tone_digit_map *""'"); 
  }
  arg1 = reinterpret_cast< pjmedia_tone_digit_map * >(argp1);
  result = (unsigned int) ((arg1)->count);
  resultobj = SWIG_From_unsigned_SS_int(static_cast< unsigned int >(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_new_pjmedia_tone_digit_map(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pjmedia_tone_digit_map *result = 0 ;
  
  if (!SWIG_Python_UnpackTuple(args, "new_pjmedia_tone_digit_map", 0, 0, 0)) SWIG_fail;
  result = (pjmedia_tone_digit_map *)new pjmedia_tone_digit_map();
  resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(result), SWIGTYPE_p_pjmedia_tone_digit_map, SWIG_POINTER_NEW |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_delete_pjmedia_tone_digit_map(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pjmedia_tone_digit_map *arg1 = (pjmedia_tone_digit_map *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pjmedia_tone_digit_map, SWIG_POINTER_DISOWN |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "delete_pjmedia_tone_digit_map" "', argument " "1"" of type '" "pjmedia_tone_digit_map *""'"); 
  }
  arg1 = reinterpret_cast< pjmedia_tone_digit_map * >(argp1);
  delete arg1;
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *pjmedia_tone_digit_map_swigregister(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *obj;
  if (!SWIG_Python_UnpackTuple(args, "swigregister", 1, 1, &obj)) return NULL;
  SWIG_TypeNewClientData(SWIGTYPE_p_pjmedia_tone_digit_map, SWIG_NewClientData(obj));
  return SWIG_Py_Void();
}

SWIGINTERN PyObject *pjmedia_tone_digit_map_swiginit(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  return SWIG_Python_InitShadowInstance(args);
}

SWIGINTERN PyObject *_wrap_pjmedia_tone_desc_freq1_set(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pjmedia_tone_desc *arg1 = (pjmedia_tone_desc *) 0 ;
  short arg2 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  short val2 ;
  int ecode2 = 0 ;
  PyObject *swig_obj[2] ;
  
  if (!SWIG_Python_UnpackTuple(args, "pjmedia_tone_desc_freq1_set", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pjmedia_tone_desc, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "pjmedia_tone_desc_freq1_set" "', argument " "1"" of type '" "pjmedia_tone_desc *""'"); 
  }
  arg1 = reinterpret_cast< pjmedia_tone_desc * >(argp1);
  ecode2 = SWIG_AsVal_short(swig_obj[1], &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "pjmedia_tone_desc_freq1_set" "', argument " "2"" of type '" "short""'");
  } 
  arg2 = static_cast< short >(val2);
  if (arg1) (arg1)->freq1 = arg2;
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_pjmedia_tone_desc_freq1_get(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pjmedia_tone_desc *arg1 = (pjmedia_tone_desc *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  short result;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pjmedia_tone_desc, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "pjmedia_tone_desc_freq1_get" "', argument " "1"" of type '" "pjmedia_tone_desc *""'"); 
  }
  arg1 = reinterpret_cast< pjmedia_tone_desc * >(argp1);
  result = (short) ((arg1)->freq1);
  resultobj = SWIG_From_short(static_cast< short >(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_pjmedia_tone_desc_freq2_set(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pjmedia_tone_desc *arg1 = (pjmedia_tone_desc *) 0 ;
  short arg2 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  short val2 ;
  int ecode2 = 0 ;
  PyObject *swig_obj[2] ;
  
  if (!SWIG_Python_UnpackTuple(args, "pjmedia_tone_desc_freq2_set", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pjmedia_tone_desc, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "pjmedia_tone_desc_freq2_set" "', argument " "1"" of type '" "pjmedia_tone_desc *""'"); 
  }
  arg1 = reinterpret_cast< pjmedia_tone_desc * >(argp1);
  ecode2 = SWIG_AsVal_short(swig_obj[1], &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "pjmedia_tone_desc_freq2_set" "', argument " "2"" of type '" "short""'");
  } 
  arg2 = static_cast< short >(val2);
  if (arg1) (arg1)->freq2 = arg2;
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_pjmedia_tone_desc_freq2_get(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pjmedia_tone_desc *arg1 = (pjmedia_tone_desc *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  short result;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pjmedia_tone_desc, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "pjmedia_tone_desc_freq2_get" "', argument " "1"" of type '" "pjmedia_tone_desc *""'"); 
  }
  arg1 = reinterpret_cast< pjmedia_tone_desc * >(argp1);
  result = (short) ((arg1)->freq2);
  resultobj = SWIG_From_short(static_cast< short >(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_pjmedia_tone_desc_on_msec_set(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pjmedia_tone_desc *arg1 = (pjmedia_tone_desc *) 0 ;
  short arg2 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  short val2 ;
  int ecode2 = 0 ;
  PyObject *swig_obj[2] ;
  
  if (!SWIG_Python_UnpackTuple(args, "pjmedia_tone_desc_on_msec_set", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pjmedia_tone_desc, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "pjmedia_tone_desc_on_msec_set" "', argument " "1"" of type '" "pjmedia_tone_desc *""'"); 
  }
  arg1 = reinterpret_cast< pjmedia_tone_desc * >(argp1);
  ecode2 = SWIG_AsVal_short(swig_obj[1], &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "pjmedia_tone_desc_on_msec_set" "', argument " "2"" of type '" "short""'");
  } 
  arg2 = static_cast< short >(val2);
  if (arg1) (arg1)->on_msec = arg2;
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_pjmedia_tone_desc_on_msec_get(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pjmedia_tone_desc *arg1 = (pjmedia_tone_desc *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  short result;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pjmedia_tone_desc, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "pjmedia_tone_desc_on_msec_get" "', argument " "1"" of type '" "pjmedia_tone_desc *""'"); 
  }
  arg1 = reinterpret_cast< pjmedia_tone_desc * >(argp1);
  result = (short) ((arg1)->on_msec);
  resultobj = SWIG_From_short(static_cast< short >(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_pjmedia_tone_desc_off_msec_set(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pjmedia_tone_desc *arg1 = (pjmedia_tone_desc *) 0 ;
  short arg2 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  short val2 ;
  int ecode2 = 0 ;
  PyObject *swig_obj[2] ;
  
  if (!SWIG_Python_UnpackTuple(args, "pjmedia_tone_desc_off_msec_set", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pjmedia_tone_desc, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "pjmedia_tone_desc_off_msec_set" "', argument " "1"" of type '" "pjmedia_tone_desc *""'"); 
  }
  arg1 = reinterpret_cast< pjmedia_tone_desc * >(argp1);
  ecode2 = SWIG_AsVal_short(swig_obj[1], &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "pjmedia_tone_desc_off_msec_set" "', argument " "2"" of type '" "short""'");
  } 
  arg2 = static_cast< short >(val2);
  if (arg1) (arg1)->off_msec = arg2;
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_pjmedia_tone_desc_off_msec_get(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pjmedia_tone_desc *arg1 = (pjmedia_tone_desc *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  short result;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pjmedia_tone_desc, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "pjmedia_tone_desc_off_msec_get" "', argument " "1"" of type '" "pjmedia_tone_desc *""'"); 
  }
  arg1 = reinterpret_cast< pjmedia_tone_desc * >(argp1);
  result = (short) ((arg1)->off_msec);
  resultobj = SWIG_From_short(static_cast< short >(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_pjmedia_tone_desc_volume_set(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pjmedia_tone_desc *arg1 = (pjmedia_tone_desc *) 0 ;
  short arg2 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  short val2 ;
  int ecode2 = 0 ;
  PyObject *swig_obj[2] ;
  
  if (!SWIG_Python_UnpackTuple(args, "pjmedia_tone_desc_volume_set", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pjmedia_tone_desc, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "pjmedia_tone_desc_volume_set" "', argument " "1"" of type '" "pjmedia_tone_desc *""'"); 
  }
  arg1 = reinterpret_cast< pjmedia_tone_desc * >(argp1);
  ecode2 = SWIG_AsVal_short(swig_obj[1], &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "pjmedia_tone_desc_volume_set" "', argument " "2"" of type '" "short""'");
  } 
  arg2 = static_cast< short >(val2);
  if (arg1) (arg1)->volume = arg2;
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_pjmedia_tone_desc_volume_get(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pjmedia_tone_desc *arg1 = (pjmedia_tone_desc *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  short result;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pjmedia_tone_desc, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "pjmedia_tone_desc_volume_get" "', argument " "1"" of type '" "pjmedia_tone_desc *""'"); 
  }
  arg1 = reinterpret_cast< pjmedia_tone_desc * >(argp1);
  result = (short) ((arg1)->volume);
  resultobj = SWIG_From_short(static_cast< short >(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_pjmedia_tone_desc_flags_set(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pjmedia_tone_desc *arg1 = (pjmedia_tone_desc *) 0 ;
  short arg2 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  short val2 ;
  int ecode2 = 0 ;
  PyObject *swig_obj[2] ;
  
  if (!SWIG_Python_UnpackTuple(args, "pjmedia_tone_desc_flags_set", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pjmedia_tone_desc, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "pjmedia_tone_desc_flags_set" "', argument " "1"" of type '" "pjmedia_tone_desc *""'"); 
  }
  arg1 = reinterpret_cast< pjmedia_tone_desc * >(argp1);
  ecode2 = SWIG_AsVal_short(swig_obj[1], &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "pjmedia_tone_desc_flags_set" "', argument " "2"" of type '" "short""'");
  } 
  arg2 = static_cast< short >(val2);
  if (arg1) (arg1)->flags = arg2;
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_pjmedia_tone_desc_flags_get(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pjmedia_tone_desc *arg1 = (pjmedia_tone_desc *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  short result;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pjmedia_tone_desc, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "pjmedia_tone_desc_flags_get" "', argument " "1"" of type '" "pjmedia_tone_desc *""'"); 
  }
  arg1 = reinterpret_cast< pjmedia_tone_desc * >(argp1);
  result = (short) ((arg1)->flags);
  resultobj = SWIG_From_short(static_cast< short >(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_new_pjmedia_tone_desc(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pjmedia_tone_desc *result = 0 ;
  
  if (!SWIG_Python_UnpackTuple(args, "new_pjmedia_tone_desc", 0, 0, 0)) SWIG_fail;
  result = (pjmedia_tone_desc *)new pjmedia_tone_desc();
  resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(result), SWIGTYPE_p_pjmedia_tone_desc, SWIG_POINTER_NEW |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_delete_pjmedia_tone_desc(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pjmedia_tone_desc *arg1 = (pjmedia_tone_desc *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pjmedia_tone_desc, SWIG_POINTER_DISOWN |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "delete_pjmedia_tone_desc" "', argument " "1"" of type '" "pjmedia_tone_desc *""'"); 
  }
  arg1 = reinterpret_cast< pjmedia_tone_desc * >(argp1);
  delete arg1;
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *pjmedia_tone_desc_swigregister(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *obj;
  if (!SWIG_Python_UnpackTuple(args, "swigregister", 1, 1, &obj)) return NULL;
  SWIG_TypeNewClientData(SWIGTYPE_p_pjmedia_tone_desc, SWIG_NewClientData(obj));
  return SWIG_Py_Void();
}

SWIGINTERN PyObject *pjmedia_tone_desc_swiginit(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  return SWIG_Python_InitShadowInstance(args);
}

SWIGINTERN PyObject *_wrap_delete_SwigPyIterator(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  swig::SwigPyIterator *arg1 = (swig::SwigPyIterator *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_swig__SwigPyIterator, SWIG_POINTER_DISOWN |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "delete_SwigPyIterator" "', argument " "1"" of type '" "swig::SwigPyIterator *""'"); 
  }
  arg1 = reinterpret_cast< swig::SwigPyIterator * >(argp1);
  delete arg1;
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_SwigPyIterator_value(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  swig::SwigPyIterator *arg1 = (swig::SwigPyIterator *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  PyObject *result = 0 ;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_swig__SwigPyIterator, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "SwigPyIterator_value" "', argument " "1"" of type '" "swig::SwigPyIterator const *""'"); 
  }
  arg1 = reinterpret_cast< swig::SwigPyIterator * >(argp1);
  try {
    result = (PyObject *)((swig::SwigPyIterator const *)arg1)->value();
  } catch(swig::stop_iteration &_e) {
    {
      (void)_e;
      SWIG_SetErrorObj(PyExc_StopIteration, SWIG_Py_Void());
      SWIG_fail;
    }
  }
  resultobj = result;
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_SwigPyIterator_incr__SWIG_0(PyObject *SWIGUNUSEDPARM(self), Py_ssize_t nobjs, PyObject **swig_obj) {
  PyObject *resultobj = 0;
  swig::SwigPyIterator *arg1 = (swig::SwigPyIterator *) 0 ;
  size_t arg2 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  size_t val2 ;
  int ecode2 = 0 ;
  swig::SwigPyIterator *result = 0 ;
  
  if ((nobjs < 2) || (nobjs > 2)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_swig__SwigPyIterator, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "SwigPyIterator_incr" "', argument " "1"" of type '" "swig::SwigPyIterator *""'"); 
  }
  arg1 = reinterpret_cast< swig::SwigPyIterator * >(argp1);
  ecode2 = SWIG_AsVal_size_t(swig_obj[1], &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "SwigPyIterator_incr" "', argument " "2"" of type '" "size_t""'");
  } 
  arg2 = static_cast< size_t >(val2);
  try {
    result = (swig::SwigPyIterator *)(arg1)->incr(arg2);
  } catch(swig::stop_iteration &_e) {
    {
      (void)_e;
      SWIG_SetErrorObj(PyExc_StopIteration, SWIG_Py_Void());
      SWIG_fail;
    }
  }
  resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(result), SWIGTYPE_p_swig__SwigPyIterator, 0 |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_SwigPyIterator_incr__SWIG_1(PyObject *SWIGUNUSEDPARM(self), Py_ssize_t nobjs, PyObject **swig_obj) {
  PyObject *resultobj = 0;
  swig::SwigPyIterator *arg1 = (swig::SwigPyIterator *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  swig::SwigPyIterator *result = 0 ;
  
  if ((nobjs < 1) || (nobjs > 1)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_swig__SwigPyIterator, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "SwigPyIterator_incr" "', argument " "1"" of type '" "swig::SwigPyIterator *""'"); 
  }
  arg1 = reinterpret_cast< swig::SwigPyIterator * >(argp1);
  try {
    result = (swig::SwigPyIterator *)(arg1)->incr();
  } catch(swig::stop_iteration &_e) {
    {
      (void)_e;
      SWIG_SetErrorObj(PyExc_StopIteration, SWIG_Py_Void());
      SWIG_fail;
    }
  }
  resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(result), SWIGTYPE_p_swig__SwigPyIterator, 0 |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_SwigPyIterator_incr(PyObject *self, PyObject *args) {
  Py_ssize_t argc;
  PyObject *argv[3] = {
    0
  };
  
  if (!(argc = SWIG_Python_UnpackTuple(args, "SwigPyIterator_incr", 0, 2, argv))) SWIG_fail;
  --argc;
  if (argc == 1) {
    int _v;
    void *vptr = 0;
    int res = SWIG_ConvertPtr(argv[0], &vptr, SWIGTYPE_p_swig__SwigPyIterator, 0);
    _v = SWIG_CheckState(res);
    if (_v) {
      return _wrap_SwigPyIterator_incr__SWIG_1(self, argc, argv);
    }
  }
  if (argc == 2) {
    int _v;
    void *vptr = 0;
    int res = SWIG_ConvertPtr(argv[0], &vptr, SWIGTYPE_p_swig__SwigPyIterator, 0);
    _v = SWIG_CheckState(res);
    if (_v) {
      {
        int res = SWIG_AsVal_size_t(argv[1], NULL);
        _v = SWIG_CheckState(res);
      }
      if (_v) {
        return _wrap_SwigPyIterator_incr__SWIG_0(self, argc, argv);
      }
    }
  }
  
fail:
  SWIG_Python_RaiseOrModifyTypeError("Wrong number or type of arguments for overloaded function 'SwigPyIterator_incr'.\n"
    "  Possible C/C++ prototypes are:\n"
    "    swig::SwigPyIterator::incr(size_t)\n"
    "    swig::SwigPyIterator::incr()\n");
  return 0;
}


SWIGINTERN PyObject *_wrap_SwigPyIterator_decr__SWIG_0(PyObject *SWIGUNUSEDPARM(self), Py_ssize_t nobjs, PyObject **swig_obj) {
  PyObject *resultobj = 0;
  swig::SwigPyIterator *arg1 = (swig::SwigPyIterator *) 0 ;
  size_t arg2 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  size_t val2 ;
  int ecode2 = 0 ;
  swig::SwigPyIterator *result = 0 ;
  
  if ((nobjs < 2) || (nobjs > 2)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_swig__SwigPyIterator, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "SwigPyIterator_decr" "', argument " "1"" of type '" "swig::SwigPyIterator *""'"); 
  }
  arg1 = reinterpret_cast< swig::SwigPyIterator * >(argp1);
  ecode2 = SWIG_AsVal_size_t(swig_obj[1], &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "SwigPyIterator_decr" "', argument " "2"" of type '" "size_t""'");
  } 
  arg2 = static_cast< size_t >(val2);
  try {
    result = (swig::SwigPyIterator *)(arg1)->decr(arg2);
  } catch(swig::stop_iteration &_e) {
    {
      (void)_e;
      SWIG_SetErrorObj(PyExc_StopIteration, SWIG_Py_Void());
      SWIG_fail;
    }
  }
  resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(result), SWIGTYPE_p_swig__SwigPyIterator, 0 |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_SwigPyIterator_decr__SWIG_1(PyObject *SWIGUNUSEDPARM(self), Py_ssize_t nobjs, PyObject **swig_obj) {
  PyObject *resultobj = 0;
  swig::SwigPyIterator *arg1 = (swig::SwigPyIterator *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  swig::SwigPyIterator *result = 0 ;
  
  if ((nobjs < 1) || (nobjs > 1)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_swig__SwigPyIterator, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "SwigPyIterator_decr" "', argument " "1"" of type '" "swig::SwigPyIterator *""'"); 
  }
  arg1 = reinterpret_cast< swig::SwigPyIterator * >(argp1);
  try {
    result = (swig::SwigPyIterator *)(arg1)->decr();
  } catch(swig::stop_iteration &_e) {
    {
      (void)_e;
      SWIG_SetErrorObj(PyExc_StopIteration, SWIG_Py_Void());
      SWIG_fail;
    }
  }
  resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(result), SWIGTYPE_p_swig__SwigPyIterator, 0 |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_SwigPyIterator_decr(PyObject *self, PyObject *args) {
  Py_ssize_t argc;
  PyObject *argv[3] = {
    0
  };
  
  if (!(argc = SWIG_Python_UnpackTuple(args, "SwigPyIterator_decr", 0, 2, argv))) SWIG_fail;
  --argc;
  if (argc == 1) {
    int _v;
    void *vptr = 0;
    int res = SWIG_ConvertPtr(argv[0], &vptr, SWIGTYPE_p_swig__SwigPyIterator, 0);
    _v = SWIG_CheckState(res);
    if (_v) {
      return _wrap_SwigPyIterator_decr__SWIG_1(self, argc, argv);
    }
  }
  if (argc == 2) {
    int _v;
    void *vptr = 0;
    int res = SWIG_ConvertPtr(argv[0], &vptr, SWIGTYPE_p_swig__SwigPyIterator, 0);
    _v = SWIG_CheckState(res);
    if (_v) {
      {
        int res = SWIG_AsVal_size_t(argv[1], NULL);
        _v = SWIG_CheckState(res);
      }
      if (_v) {
        return _wrap_SwigPyIterator_decr__SWIG_0(self, argc, argv);
      }
    }
  }
  
fail:
  SWIG_Python_RaiseOrModifyTypeError("Wrong number or type of arguments for overloaded function 'SwigPyIterator_decr'.\n"
    "  Possible C/C++ prototypes are:\n"
    "    swig::SwigPyIterator::decr(size_t)\n"
    "    swig::SwigPyIterator::decr()\n");
  return 0;
}


SWIGINTERN PyObject *_wrap_SwigPyIterator_distance(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  swig::SwigPyIterator *arg1 = (swig::SwigPyIterator *) 0 ;
  swig::SwigPyIterator *arg2 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  void *argp2 = 0 ;
  int res2 = 0 ;
  PyObject *swig_obj[2] ;
  ptrdiff_t result;
  
  if (!SWIG_Python_UnpackTuple(args, "SwigPyIterator_distance", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_swig__SwigPyIterator, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "SwigPyIterator_distance" "', argument " "1"" of type '" "swig::SwigPyIterator const *""'"); 
  }
  arg1 = reinterpret_cast< swig::SwigPyIterator * >(argp1);
  res2 = SWIG_ConvertPtr(swig_obj[1], &argp2, SWIGTYPE_p_swig__SwigPyIterator,  0  | 0);
  if (!SWIG_IsOK(res2)) {
    SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "SwigPyIterator_distance" "', argument " "2"" of type '" "swig::SwigPyIterator const &""'"); 
  }
  if (!argp2) {
    SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "SwigPyIterator_distance" "', argument " "2"" of type '" "swig::SwigPyIterator const &""'"); 
  }
  arg2 = reinterpret_cast< swig::SwigPyIterator * >(argp2);
  try {
    result = ((swig::SwigPyIterator const *)arg1)->distance((swig::SwigPyIterator const &)*arg2);
  } catch(std::invalid_argument &_e) {
    SWIG_Python_Raise(SWIG_NewPointerObj((new std::invalid_argument(static_cast< const std::invalid_argument& >(_e))),SWIGTYPE_p_std__invalid_argument,SWIG_POINTER_OWN), "std::invalid_argument", SWIGTYPE_p_std__invalid_argument); SWIG_fail;
  }
  resultobj = SWIG_From_ptrdiff_t(static_cast< ptrdiff_t >(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_SwigPyIterator_equal(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  swig::SwigPyIterator *arg1 = (swig::SwigPyIterator *) 0 ;
  swig::SwigPyIterator *arg2 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  void *argp2 = 0 ;
  int res2 = 0 ;
  PyObject *swig_obj[2] ;
  bool result;
  
  if (!SWIG_Python_UnpackTuple(args, "SwigPyIterator_equal", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_swig__SwigPyIterator, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "SwigPyIterator_equal" "', argument " "1"" of type '" "swig::SwigPyIterator const *""'"); 
  }
  arg1 = reinterpret_cast< swig::SwigPyIterator * >(argp1);
  res2 = SWIG_ConvertPtr(swig_obj[1], &argp2, SWIGTYPE_p_swig__SwigPyIterator,  0  | 0);
  if (!SWIG_IsOK(res2)) {
    SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "SwigPyIterator_equal" "', argument " "2"" of type '" "swig::SwigPyIterator const &""'"); 
  }
  if (!argp2) {
    SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "SwigPyIterator_equal" "', argument " "2"" of type '" "swig::SwigPyIterator const &""'"); 
  }
  arg2 = reinterpret_cast< swig::SwigPyIterator * >(argp2);
  try {
    result = (bool)((swig::SwigPyIterator const *)arg1)->equal((swig::SwigPyIterator const &)*arg2);
  } catch(std::invalid_argument &_e) {
    SWIG_Python_Raise(SWIG_NewPointerObj((new std::invalid_argument(static_cast< const std::invalid_argument& >(_e))),SWIGTYPE_p_std__invalid_argument,SWIG_POINTER_OWN), "std::invalid_argument", SWIGTYPE_p_std__invalid_argument); SWIG_fail;
  }
  resultobj = SWIG_From_bool(static_cast< bool >(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_SwigPyIterator_copy(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  swig::SwigPyIterator *arg1 = (swig::SwigPyIterator *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  swig::SwigPyIterator *result = 0 ;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_swig__SwigPyIterator, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "SwigPyIterator_copy" "', argument " "1"" of type '" "swig::SwigPyIterator const *""'"); 
  }
  arg1 = reinterpret_cast< swig::SwigPyIterator * >(argp1);
  result = (swig::SwigPyIterator *)((swig::SwigPyIterator const *)arg1)->copy();
  resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(result), SWIGTYPE_p_swig__SwigPyIterator, SWIG_POINTER_OWN |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_SwigPyIterator_next(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  swig::SwigPyIterator *arg1 = (swig::SwigPyIterator *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  PyObject *result = 0 ;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_swig__SwigPyIterator, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "SwigPyIterator_next" "', argument " "1"" of type '" "swig::SwigPyIterator *""'"); 
  }
  arg1 = reinterpret_cast< swig::SwigPyIterator * >(argp1);
  try {
    result = (PyObject *)(arg1)->next();
  } catch(swig::stop_iteration &_e) {
    {
      (void)_e;
      SWIG_SetErrorObj(PyExc_StopIteration, SWIG_Py_Void());
      SWIG_fail;
    }
  }
  resultobj = result;
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_SwigPyIterator___next__(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  swig::SwigPyIterator *arg1 = (swig::SwigPyIterator *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  PyObject *result = 0 ;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_swig__SwigPyIterator, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "SwigPyIterator___next__" "', argument " "1"" of type '" "swig::SwigPyIterator *""'"); 
  }
  arg1 = reinterpret_cast< swig::SwigPyIterator * >(argp1);
  try {
    result = (PyObject *)(arg1)->__next__();
  } catch(swig::stop_iteration &_e) {
    {
      (void)_e;
      SWIG_SetErrorObj(PyExc_StopIteration, SWIG_Py_Void());
      SWIG_fail;
    }
  }
  resultobj = result;
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_SwigPyIterator_previous(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  swig::SwigPyIterator *arg1 = (swig::SwigPyIterator *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  PyObject *result = 0 ;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_swig__SwigPyIterator, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "SwigPyIterator_previous" "', argument " "1"" of type '" "swig::SwigPyIterator *""'"); 
  }
  arg1 = reinterpret_cast< swig::SwigPyIterator * >(argp1);
  try {
    result = (PyObject *)(arg1)->previous();
  } catch(swig::stop_iteration &_e) {
    {
      (void)_e;
      SWIG_SetErrorObj(PyExc_StopIteration, SWIG_Py_Void());
      SWIG_fail;
    }
  }
  resultobj = result;
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_SwigPyIterator_advance(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  swig::SwigPyIterator *arg1 = (swig::SwigPyIterator *) 0 ;
  ptrdiff_t arg2 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  ptrdiff_t val2 ;
  int ecode2 = 0 ;
  PyObject *swig_obj[2] ;
  swig::SwigPyIterator *result = 0 ;
  
  if (!SWIG_Python_UnpackTuple(args, "SwigPyIterator_advance", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_swig__SwigPyIterator, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "SwigPyIterator_advance" "', argument " "1"" of type '" "swig::SwigPyIterator *""'"); 
  }
  arg1 = reinterpret_cast< swig::SwigPyIterator * >(argp1);
  ecode2 = SWIG_AsVal_ptrdiff_t(swig_obj[1], &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "SwigPyIterator_advance" "', argument " "2"" of type '" "ptrdiff_t""'");
  } 
  arg2 = static_cast< ptrdiff_t >(val2);
  try {
    result = (swig::SwigPyIterator *)(arg1)->advance(arg2);
  } catch(swig::stop_iteration &_e) {
    {
      (void)_e;
      SWIG_SetErrorObj(PyExc_StopIteration, SWIG_Py_Void());
      SWIG_fail;
    }
  }
  resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(result), SWIGTYPE_p_swig__SwigPyIterator, 0 |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_SwigPyIterator___eq__(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  swig::SwigPyIterator *arg1 = (swig::SwigPyIterator *) 0 ;
  swig::SwigPyIterator *arg2 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  void *argp2 = 0 ;
  int res2 = 0 ;
  PyObject *swig_obj[2] ;
  bool result;
  
  if (!SWIG_Python_UnpackTuple(args, "SwigPyIterator___eq__", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_swig__SwigPyIterator, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "SwigPyIterator___eq__" "', argument " "1"" of type '" "swig::SwigPyIterator const *""'"); 
  }
  arg1 = reinterpret_cast< swig::SwigPyIterator * >(argp1);
  res2 = SWIG_ConvertPtr(swig_obj[1], &argp2, SWIGTYPE_p_swig__SwigPyIterator,  0  | 0);
  if (!SWIG_IsOK(res2)) {
    SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "SwigPyIterator___eq__" "', argument " "2"" of type '" "swig::SwigPyIterator const &""'"); 
  }
  if (!argp2) {
    SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "SwigPyIterator___eq__" "', argument " "2"" of type '" "swig::SwigPyIterator const &""'"); 
  }
  arg2 = reinterpret_cast< swig::SwigPyIterator * >(argp2);
  result = (bool)((swig::SwigPyIterator const *)arg1)->operator ==((swig::SwigPyIterator const &)*arg2);
  resultobj = SWIG_From_bool(static_cast< bool >(result));
  return resultobj;
fail:
  PyErr_Clear();
  Py_INCREF(Py_NotImplemented);
  return Py_NotImplemented;
}


SWIGINTERN PyObject *_wrap_SwigPyIterator___ne__(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  swig::SwigPyIterator *arg1 = (swig::SwigPyIterator *) 0 ;
  swig::SwigPyIterator *arg2 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  void *argp2 = 0 ;
  int res2 = 0 ;
  PyObject *swig_obj[2] ;
  bool result;
  
  if (!SWIG_Python_UnpackTuple(args, "SwigPyIterator___ne__", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_swig__SwigPyIterator, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "SwigPyIterator___ne__" "', argument " "1"" of type '" "swig::SwigPyIterator const *""'"); 
  }
  arg1 = reinterpret_cast< swig::SwigPyIterator * >(argp1);
  res2 = SWIG_ConvertPtr(swig_obj[1], &argp2, SWIGTYPE_p_swig__SwigPyIterator,  0  | 0);
  if (!SWIG_IsOK(res2)) {
    SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "SwigPyIterator___ne__" "', argument " "2"" of type '" "swig::SwigPyIterator const &""'"); 
  }
  if (!argp2) {
    SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "SwigPyIterator___ne__" "', argument " "2"" of type '" "swig::SwigPyIterator const &""'"); 
  }
  arg2 = reinterpret_cast< swig::SwigPyIterator * >(argp2);
  result = (bool)((swig::SwigPyIterator const *)arg1)->operator !=((swig::SwigPyIterator const &)*arg2);
  resultobj = SWIG_From_bool(static_cast< bool >(result));
  return resultobj;
fail:
  PyErr_Clear();
  Py_INCREF(Py_NotImplemented);
  return Py_NotImplemented;
}


SWIGINTERN PyObject *_wrap_SwigPyIterator___iadd__(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  swig::SwigPyIterator *arg1 = (swig::SwigPyIterator *) 0 ;
  ptrdiff_t arg2 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  ptrdiff_t val2 ;
  int ecode2 = 0 ;
  PyObject *swig_obj[2] ;
  swig::SwigPyIterator *result = 0 ;
  
  if (!SWIG_Python_UnpackTuple(args, "SwigPyIterator___iadd__", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_swig__SwigPyIterator, SWIG_POINTER_DISOWN |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "SwigPyIterator___iadd__" "', argument " "1"" of type '" "swig::SwigPyIterator *""'"); 
  }
  arg1 = reinterpret_cast< swig::SwigPyIterator * >(argp1);
  ecode2 = SWIG_AsVal_ptrdiff_t(swig_obj[1], &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "SwigPyIterator___iadd__" "', argument " "2"" of type '" "ptrdiff_t""'");
  } 
  arg2 = static_cast< ptrdiff_t >(val2);
  try {
    result = (swig::SwigPyIterator *) &(arg1)->operator +=(arg2);
  } catch(swig::stop_iteration &_e) {
    {
      (void)_e;
      SWIG_SetErrorObj(PyExc_StopIteration, SWIG_Py_Void());
      SWIG_fail;
    }
  }
  resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(result), SWIGTYPE_p_swig__SwigPyIterator, SWIG_POINTER_OWN |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_SwigPyIterator___isub__(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  swig::SwigPyIterator *arg1 = (swig::SwigPyIterator *) 0 ;
  ptrdiff_t arg2 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  ptrdiff_t val2 ;
  int ecode2 = 0 ;
  PyObject *swig_obj[2] ;
  swig::SwigPyIterator *result = 0 ;
  
  if (!SWIG_Python_UnpackTuple(args, "SwigPyIterator___isub__", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_swig__SwigPyIterator, SWIG_POINTER_DISOWN |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "SwigPyIterator___isub__" "', argument " "1"" of type '" "swig::SwigPyIterator *""'"); 
  }
  arg1 = reinterpret_cast< swig::SwigPyIterator * >(argp1);
  ecode2 = SWIG_AsVal_ptrdiff_t(swig_obj[1], &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "SwigPyIterator___isub__" "', argument " "2"" of type '" "ptrdiff_t""'");
  } 
  arg2 = static_cast< ptrdiff_t >(val2);
  try {
    result = (swig::SwigPyIterator *) &(arg1)->operator -=(arg2);
  } catch(swig::stop_iteration &_e) {
    {
      (void)_e;
      SWIG_SetErrorObj(PyExc_StopIteration, SWIG_Py_Void());
      SWIG_fail;
    }
  }
  resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(result), SWIGTYPE_p_swig__SwigPyIterator, SWIG_POINTER_OWN |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_SwigPyIterator___add__(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  swig::SwigPyIterator *arg1 = (swig::SwigPyIterator *) 0 ;
  ptrdiff_t arg2 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  ptrdiff_t val2 ;
  int ecode2 = 0 ;
  PyObject *swig_obj[2] ;
  swig::SwigPyIterator *result = 0 ;
  
  if (!SWIG_Python_UnpackTuple(args, "SwigPyIterator___add__", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_swig__SwigPyIterator, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "SwigPyIterator___add__" "', argument " "1"" of type '" "swig::SwigPyIterator const *""'"); 
  }
  arg1 = reinterpret_cast< swig::SwigPyIterator * >(argp1);
  ecode2 = SWIG_AsVal_ptrdiff_t(swig_obj[1], &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "SwigPyIterator___add__" "', argument " "2"" of type '" "ptrdiff_t""'");
  } 
  arg2 = static_cast< ptrdiff_t >(val2);
  try {
    result = (swig::SwigPyIterator *)((swig::SwigPyIterator const *)arg1)->operator +(arg2);
  } catch(swig::stop_iteration &_e) {
    {
      (void)_e;
      SWIG_SetErrorObj(PyExc_StopIteration, SWIG_Py_Void());
      SWIG_fail;
    }
  }
  resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(result), SWIGTYPE_p_swig__SwigPyIterator, SWIG_POINTER_OWN |  0 );
  return resultobj;
fail:
  PyErr_Clear();
  Py_INCREF(Py_NotImplemented);
  return Py_NotImplemented;
}


SWIGINTERN PyObject *_wrap_SwigPyIterator___sub____SWIG_0(PyObject *SWIGUNUSEDPARM(self), Py_ssize_t nobjs, PyObject **swig_obj) {
  PyObject *resultobj = 0;
  swig::SwigPyIterator *arg1 = (swig::SwigPyIterator *) 0 ;
  ptrdiff_t arg2 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  ptrdiff_t val2 ;
  int ecode2 = 0 ;
  swig::SwigPyIterator *result = 0 ;
  
  if ((nobjs < 2) || (nobjs > 2)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_swig__SwigPyIterator, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "SwigPyIterator___sub__" "', argument " "1"" of type '" "swig::SwigPyIterator const *""'"); 
  }
  arg1 = reinterpret_cast< swig::SwigPyIterator * >(argp1);
  ecode2 = SWIG_AsVal_ptrdiff_t(swig_obj[1], &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "SwigPyIterator___sub__" "', argument " "2"" of type '" "ptrdiff_t""'");
  } 
  arg2 = static_cast< ptrdiff_t >(val2);
  try {
    result = (swig::SwigPyIterator *)((swig::SwigPyIterator const *)arg1)->operator -(arg2);
  } catch(swig::stop_iteration &_e) {
    {
      (void)_e;
      SWIG_SetErrorObj(PyExc_StopIteration, SWIG_Py_Void());
      SWIG_fail;
    }
  }
  resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(result), SWIGTYPE_p_swig__SwigPyIterator, SWIG_POINTER_OWN |  0 );
  return resultobj;
fail:
  PyErr_Clear();
  Py_INCREF(Py_NotImplemented);
  return Py_NotImplemented;
}


SWIGINTERN PyObject *_wrap_SwigPyIterator___sub____SWIG_1(PyObject *SWIGUNUSEDPARM(self), Py_ssize_t nobjs, PyObject **swig_obj) {
  PyObject *resultobj = 0;
  swig::SwigPyIterator *arg1 = (swig::SwigPyIterator *) 0 ;
  swig::SwigPyIterator *arg2 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  void *argp2 = 0 ;
  int res2 = 0 ;
  ptrdiff_t result;
  
  if ((nobjs < 2) || (nobjs > 2)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_swig__SwigPyIterator, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "SwigPyIterator___sub__" "', argument " "1"" of type '" "swig::SwigPyIterator const *""'"); 
  }
  arg1 = reinterpret_cast< swig::SwigPyIterator * >(argp1);
  res2 = SWIG_ConvertPtr(swig_obj[1], &argp2, SWIGTYPE_p_swig__SwigPyIterator,  0  | 0);
  if (!SWIG_IsOK(res2)) {
    SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "SwigPyIterator___sub__" "', argument " "2"" of type '" "swig::SwigPyIterator const &""'"); 
  }
  if (!argp2) {
    SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "SwigPyIterator___sub__" "', argument " "2"" of type '" "swig::SwigPyIterator const &""'"); 
  }
  arg2 = reinterpret_cast< swig::SwigPyIterator * >(argp2);
  result = ((swig::SwigPyIterator const *)arg1)->operator -((swig::SwigPyIterator const &)*arg2);
  resultobj = SWIG_From_ptrdiff_t(static_cast< ptrdiff_t >(result));
  return resultobj;
fail:
  PyErr_Clear();
  Py_INCREF(Py_NotImplemented);
  return Py_NotImplemented;
}


SWIGINTERN PyObject *_wrap_SwigPyIterator___sub__(PyObject *self, PyObject *args) {
  Py_ssize_t argc;
  PyObject *argv[3] = {
    0
  };
  
  if (!(argc = SWIG_Python_UnpackTuple(args, "SwigPyIterator___sub__", 0, 2, argv))) SWIG_fail;
  --argc;
  if (argc == 2) {
    int _v;
    void *vptr = 0;
    int res = SWIG_ConvertPtr(argv[0], &vptr, SWIGTYPE_p_swig__SwigPyIterator, 0);
    _v = SWIG_CheckState(res);
    if (_v) {
      int res = SWIG_ConvertPtr(argv[1], 0, SWIGTYPE_p_swig__SwigPyIterator, SWIG_POINTER_NO_NULL | 0);
      _v = SWIG_CheckState(res);
      if (_v) {
        return _wrap_SwigPyIterator___sub____SWIG_1(self, argc, argv);
      }
    }
  }
  if (argc == 2) {
    int _v;
    void *vptr = 0;
    int res = SWIG_ConvertPtr(argv[0], &vptr, SWIGTYPE_p_swig__SwigPyIterator, 0);
    _v = SWIG_CheckState(res);
    if (_v) {
      {
        int res = SWIG_AsVal_ptrdiff_t(argv[1], NULL);
        _v = SWIG_CheckState(res);
      }
      if (_v) {
        return _wrap_SwigPyIterator___sub____SWIG_0(self, argc, argv);
      }
    }
  }
  
fail:
  Py_INCREF(Py_NotImplemented);
  return Py_NotImplemented;
}


SWIGINTERN PyObject *SwigPyIterator_swigregister(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *obj;
  if (!SWIG_Python_UnpackTuple(args, "swigregister", 1, 1, &obj)) return NULL;
  SWIG_TypeNewClientData(SWIGTYPE_p_swig__SwigPyIterator, SWIG_NewClientData(obj));
  return SWIG_Py_Void();
}

SWIGINTERN PyObject *_wrap_StringVector_iterator(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  std::vector< std::string > *arg1 = (std::vector< std::string > *) 0 ;
  PyObject **arg2 = (PyObject **) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  swig::SwigPyIterator *result = 0 ;
  
  arg2 = &swig_obj[0];
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__vectorT_std__string_std__allocatorT_std__string_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "StringVector_iterator" "', argument " "1"" of type '" "std::vector< std::string > *""'"); 
  }
  arg1 = reinterpret_cast< std::vector< std::string > * >(argp1);
  result = (swig::SwigPyIterator *)std_vector_Sl_std_string_Sg__iterator(arg1,arg2);
  resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(result), SWIGTYPE_p_swig__SwigPyIterator, SWIG_POINTER_OWN |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_StringVector___nonzero__(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  std::vector< std::string > *arg1 = (std::vector< std::string > *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  bool result;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__vectorT_std__string_std__allocatorT_std__string_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "StringVector___nonzero__" "', argument " "1"" of type '" "std::vector< std::string > const *""'"); 
  }
  arg1 = reinterpret_cast< std::vector< std::string > * >(argp1);
  result = (bool)std_vector_Sl_std_string_Sg____nonzero__((std::vector< std::string > const *)arg1);
  resultobj = SWIG_From_bool(static_cast< bool >(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_StringVector___bool__(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  std::vector< std::string > *arg1 = (std::vector< std::string > *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  bool result;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__vectorT_std__string_std__allocatorT_std__string_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "StringVector___bool__" "', argument " "1"" of type '" "std::vector< std::string > const *""'"); 
  }
  arg1 = reinterpret_cast< std::vector< std::string > * >(argp1);
  result = (bool)std_vector_Sl_std_string_Sg____bool__((std::vector< std::string > const *)arg1);
  resultobj = SWIG_From_bool(static_cast< bool >(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_StringVector___len__(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  std::vector< std::string > *arg1 = (std::vector< std::string > *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  std::vector< std::string >::size_type result;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__vectorT_std__string_std__allocatorT_std__string_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "StringVector___len__" "', argument " "1"" of type '" "std::vector< std::string > const *""'"); 
  }
  arg1 = reinterpret_cast< std::vector< std::string > * >(argp1);
  result = std_vector_Sl_std_string_Sg____len__((std::vector< std::string > const *)arg1);
  resultobj = SWIG_From_size_t(static_cast< size_t >(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_StringVector___getslice__(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  std::vector< std::string > *arg1 = (std::vector< std::string > *) 0 ;
  std::vector< std::string >::difference_type arg2 ;
  std::vector< std::string >::difference_type arg3 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  ptrdiff_t val2 ;
  int ecode2 = 0 ;
  ptrdiff_t val3 ;
  int ecode3 = 0 ;
  PyObject *swig_obj[3] ;
  std::vector< std::string,std::allocator< std::string > > *result = 0 ;
  
  if (!SWIG_Python_UnpackTuple(args, "StringVector___getslice__", 3, 3, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__vectorT_std__string_std__allocatorT_std__string_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "StringVector___getslice__" "', argument " "1"" of type '" "std::vector< std::string > *""'"); 
  }
  arg1 = reinterpret_cast< std::vector< std::string > * >(argp1);
  ecode2 = SWIG_AsVal_ptrdiff_t(swig_obj[1], &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "StringVector___getslice__" "', argument " "2"" of type '" "std::vector< std::string >::difference_type""'");
  } 
  arg2 = static_cast< std::vector< std::string >::difference_type >(val2);
  ecode3 = SWIG_AsVal_ptrdiff_t(swig_obj[2], &val3);
  if (!SWIG_IsOK(ecode3)) {
    SWIG_exception_fail(SWIG_ArgError(ecode3), "in method '" "StringVector___getslice__" "', argument " "3"" of type '" "std::vector< std::string >::difference_type""'");
  } 
  arg3 = static_cast< std::vector< std::string >::difference_type >(val3);
  try {
    result = (std::vector< std::string,std::allocator< std::string > > *)std_vector_Sl_std_string_Sg____getslice__(arg1,arg2,arg3);
  } catch(std::out_of_range &_e) {
    SWIG_exception_fail(SWIG_IndexError, (&_e)->what());
  } catch(std::invalid_argument &_e) {
    SWIG_exception_fail(SWIG_ValueError, (&_e)->what());
  }
  resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(result), SWIGTYPE_p_std__vectorT_std__string_std__allocatorT_std__string_t_t, SWIG_POINTER_OWN |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_StringVector___setslice____SWIG_0(PyObject *SWIGUNUSEDPARM(self), Py_ssize_t nobjs, PyObject **swig_obj) {
  PyObject *resultobj = 0;
  std::vector< std::string > *arg1 = (std::vector< std::string > *) 0 ;
  std::vector< std::string >::difference_type arg2 ;
  std::vector< std::string >::difference_type arg3 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  ptrdiff_t val2 ;
  int ecode2 = 0 ;
  ptrdiff_t val3 ;
  int ecode3 = 0 ;
  
  if ((nobjs < 3) || (nobjs > 3)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__vectorT_std__string_std__allocatorT_std__string_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "StringVector___setslice__" "', argument " "1"" of type '" "std::vector< std::string > *""'"); 
  }
  arg1 = reinterpret_cast< std::vector< std::string > * >(argp1);
  ecode2 = SWIG_AsVal_ptrdiff_t(swig_obj[1], &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "StringVector___setslice__" "', argument " "2"" of type '" "std::vector< std::string >::difference_type""'");
  } 
  arg2 = static_cast< std::vector< std::string >::difference_type >(val2);
  ecode3 = SWIG_AsVal_ptrdiff_t(swig_obj[2], &val3);
  if (!SWIG_IsOK(ecode3)) {
    SWIG_exception_fail(SWIG_ArgError(ecode3), "in method '" "StringVector___setslice__" "', argument " "3"" of type '" "std::vector< std::string >::difference_type""'");
  } 
  arg3 = static_cast< std::vector< std::string >::difference_type >(val3);
  try {
    std_vector_Sl_std_string_Sg____setslice____SWIG_0(arg1,arg2,arg3);
  } catch(std::out_of_range &_e) {
    SWIG_exception_fail(SWIG_IndexError, (&_e)->what());
  } catch(std::invalid_argument &_e) {
    SWIG_exception_fail(SWIG_ValueError, (&_e)->what());
  }
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_StringVector___setslice____SWIG_1(PyObject *SWIGUNUSEDPARM(self), Py_ssize_t nobjs, PyObject **swig_obj) {
  PyObject *resultobj = 0;
  std::vector< std::string > *arg1 = (std::vector< std::string > *) 0 ;
  std::vector< std::string >::difference_type arg2 ;
  std::vector< std::string >::difference_type arg3 ;
  std::vector< std::string,std::allocator< std::string > > *arg4 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  ptrdiff_t val2 ;
  int ecode2 = 0 ;
  ptrdiff_t val3 ;
  int ecode3 = 0 ;
  int res4 = SWIG_OLDOBJ ;
  
  if ((nobjs < 4) || (nobjs > 4)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__vectorT_std__string_std__allocatorT_std__string_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "StringVector___setslice__" "', argument " "1"" of type '" "std::vector< std::string > *""'"); 
  }
  arg1 = reinterpret_cast< std::vector< std::string > * >(argp1);
  ecode2 = SWIG_AsVal_ptrdiff_t(swig_obj[1], &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "StringVector___setslice__" "', argument " "2"" of type '" "std::vector< std::string >::difference_type""'");
  } 
  arg2 = static_cast< std::vector< std::string >::difference_type >(val2);
  ecode3 = SWIG_AsVal_ptrdiff_t(swig_obj[2], &val3);
  if (!SWIG_IsOK(ecode3)) {
    SWIG_exception_fail(SWIG_ArgError(ecode3), "in method '" "StringVector___setslice__" "', argument " "3"" of type '" "std::vector< std::string >::difference_type""'");
  } 
  arg3 = static_cast< std::vector< std::string >::difference_type >(val3);
  {
    std::vector< std::string,std::allocator< std::string > > *ptr = (std::vector< std::string,std::allocator< std::string > > *)0;
    res4 = swig::asptr(swig_obj[3], &ptr);
    if (!SWIG_IsOK(res4)) {
      SWIG_exception_fail(SWIG_ArgError(res4), "in method '" "StringVector___setslice__" "', argument " "4"" of type '" "std::vector< std::string,std::allocator< std::string > > const &""'"); 
    }
    if (!ptr) {
      SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "StringVector___setslice__" "', argument " "4"" of type '" "std::vector< std::string,std::allocator< std::string > > const &""'"); 
    }
    arg4 = ptr;
  }
  try {
    std_vector_Sl_std_string_Sg____setslice____SWIG_1(arg1,arg2,arg3,(std::vector< std::string,std::allocator< std::string > > const &)*arg4);
  } catch(std::out_of_range &_e) {
    SWIG_exception_fail(SWIG_IndexError, (&_e)->what());
  } catch(std::invalid_argument &_e) {
    SWIG_exception_fail(SWIG_ValueError, (&_e)->what());
  }
  resultobj = SWIG_Py_Void();
  if (SWIG_IsNewObj(res4)) delete arg4;
  return resultobj;
fail:
  if (SWIG_IsNewObj(res4)) delete arg4;
  return NULL;
}


SWIGINTERN PyObject *_wrap_StringVector___setslice__(PyObject *self, PyObject *args) {
  Py_ssize_t argc;
  PyObject *argv[5] = {
    0
  };
  
  if (!(argc = SWIG_Python_UnpackTuple(args, "StringVector___setslice__", 0, 4, argv))) SWIG_fail;
  --argc;
  if (argc == 3) {
    int _v;
    int res = swig::asptr(argv[0], (std::vector< std::string,std::allocator< std::string > >**)(0));
    _v = SWIG_CheckState(res);
    if (_v) {
      {
        int res = SWIG_AsVal_ptrdiff_t(argv[1], NULL);
        _v = SWIG_CheckState(res);
      }
      if (_v) {
        {
          int res = SWIG_AsVal_ptrdiff_t(argv[2], NULL);
          _v = SWIG_CheckState(res);
        }
        if (_v) {
          return _wrap_StringVector___setslice____SWIG_0(self, argc, argv);
        }
      }
    }
  }
  if (argc == 4) {
    int _v;
    int res = swig::asptr(argv[0], (std::vector< std::string,std::allocator< std::string > >**)(0));
    _v = SWIG_CheckState(res);
    if (_v) {
      {
        int res = SWIG_AsVal_ptrdiff_t(argv[1], NULL);
        _v = SWIG_CheckState(res);
      }
      if (_v) {
        {
          int res = SWIG_AsVal_ptrdiff_t(argv[2], NULL);
          _v = SWIG_CheckState(res);
        }
        if (_v) {
          int res = swig::asptr(argv[3], (std::vector< std::string,std::allocator< std::string > >**)(0));
          _v = SWIG_CheckState(res);
          if (_v) {
            return _wrap_StringVector___setslice____SWIG_1(self, argc, argv);
          }
        }
      }
    }
  }
  
fail:
  SWIG_Python_RaiseOrModifyTypeError("Wrong number or type of arguments for overloaded function 'StringVector___setslice__'.\n"
    "  Possible C/C++ prototypes are:\n"
    "    std::vector< std::string >::__setslice__(std::vector< std::string >::difference_type,std::vector< std::string >::difference_type)\n"
    "    std::vector< std::string >::__setslice__(std::vector< std::string >::difference_type,std::vector< std::string >::difference_type,std::vector< std::string,std::allocator< std::string > > const &)\n");
  return 0;
}


SWIGINTERN PyObject *_wrap_StringVector___delslice__(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  std::vector< std::string > *arg1 = (std::vector< std::string > *) 0 ;
  std::vector< std::string >::difference_type arg2 ;
  std::vector< std::string >::difference_type arg3 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  ptrdiff_t val2 ;
  int ecode2 = 0 ;
  ptrdiff_t val3 ;
  int ecode3 = 0 ;
  PyObject *swig_obj[3] ;
  
  if (!SWIG_Python_UnpackTuple(args, "StringVector___delslice__", 3, 3, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__vectorT_std__string_std__allocatorT_std__string_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "StringVector___delslice__" "', argument " "1"" of type '" "std::vector< std::string > *""'"); 
  }
  arg1 = reinterpret_cast< std::vector< std::string > * >(argp1);
  ecode2 = SWIG_AsVal_ptrdiff_t(swig_obj[1], &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "StringVector___delslice__" "', argument " "2"" of type '" "std::vector< std::string >::difference_type""'");
  } 
  arg2 = static_cast< std::vector< std::string >::difference_type >(val2);
  ecode3 = SWIG_AsVal_ptrdiff_t(swig_obj[2], &val3);
  if (!SWIG_IsOK(ecode3)) {
    SWIG_exception_fail(SWIG_ArgError(ecode3), "in method '" "StringVector___delslice__" "', argument " "3"" of type '" "std::vector< std::string >::difference_type""'");
  } 
  arg3 = static_cast< std::vector< std::string >::difference_type >(val3);
  try {
    std_vector_Sl_std_string_Sg____delslice__(arg1,arg2,arg3);
  } catch(std::out_of_range &_e) {
    SWIG_exception_fail(SWIG_IndexError, (&_e)->what());
  } catch(std::invalid_argument &_e) {
    SWIG_exception_fail(SWIG_ValueError, (&_e)->what());
  }
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_StringVector___delitem____SWIG_0(PyObject *SWIGUNUSEDPARM(self), Py_ssize_t nobjs, PyObject **swig_obj) {
  PyObject *resultobj = 0;
  std::vector< std::string > *arg1 = (std::vector< std::string > *) 0 ;
  std::vector< std::string >::difference_type arg2 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  ptrdiff_t val2 ;
  int ecode2 = 0 ;
  
  if ((nobjs < 2) || (nobjs > 2)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__vectorT_std__string_std__allocatorT_std__string_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "StringVector___delitem__" "', argument " "1"" of type '" "std::vector< std::string > *""'"); 
  }
  arg1 = reinterpret_cast< std::vector< std::string > * >(argp1);
  ecode2 = SWIG_AsVal_ptrdiff_t(swig_obj[1], &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "StringVector___delitem__" "', argument " "2"" of type '" "std::vector< std::string >::difference_type""'");
  } 
  arg2 = static_cast< std::vector< std::string >::difference_type >(val2);
  try {
    std_vector_Sl_std_string_Sg____delitem____SWIG_0(arg1,arg2);
  } catch(std::out_of_range &_e) {
    SWIG_exception_fail(SWIG_IndexError, (&_e)->what());
  } catch(std::invalid_argument &_e) {
    SWIG_exception_fail(SWIG_ValueError, (&_e)->what());
  }
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_StringVector___getitem____SWIG_0(PyObject *SWIGUNUSEDPARM(self), Py_ssize_t nobjs, PyObject **swig_obj) {
  PyObject *resultobj = 0;
  std::vector< std::string > *arg1 = (std::vector< std::string > *) 0 ;
  PySliceObject *arg2 = (PySliceObject *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  std::vector< std::string,std::allocator< std::string > > *result = 0 ;
  
  if ((nobjs < 2) || (nobjs > 2)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__vectorT_std__string_std__allocatorT_std__string_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "StringVector___getitem__" "', argument " "1"" of type '" "std::vector< std::string > *""'"); 
  }
  arg1 = reinterpret_cast< std::vector< std::string > * >(argp1);
  {
    if (!PySlice_Check(swig_obj[1])) {
      SWIG_exception_fail(SWIG_ArgError(SWIG_TypeError), "in method '" "StringVector___getitem__" "', argument " "2"" of type '" "PySliceObject *""'");
    }
    arg2 = (PySliceObject *) swig_obj[1];
  }
  try {
    result = (std::vector< std::string,std::allocator< std::string > > *)std_vector_Sl_std_string_Sg____getitem____SWIG_0(arg1,arg2);
  } catch(std::out_of_range &_e) {
    SWIG_exception_fail(SWIG_IndexError, (&_e)->what());
  } catch(std::invalid_argument &_e) {
    SWIG_exception_fail(SWIG_ValueError, (&_e)->what());
  }
  resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(result), SWIGTYPE_p_std__vectorT_std__string_std__allocatorT_std__string_t_t, SWIG_POINTER_OWN |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_StringVector___setitem____SWIG_0(PyObject *SWIGUNUSEDPARM(self), Py_ssize_t nobjs, PyObject **swig_obj) {
  PyObject *resultobj = 0;
  std::vector< std::string > *arg1 = (std::vector< std::string > *) 0 ;
  PySliceObject *arg2 = (PySliceObject *) 0 ;
  std::vector< std::string,std::allocator< std::string > > *arg3 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  int res3 = SWIG_OLDOBJ ;
  
  if ((nobjs < 3) || (nobjs > 3)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__vectorT_std__string_std__allocatorT_std__string_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "StringVector___setitem__" "', argument " "1"" of type '" "std::vector< std::string > *""'"); 
  }
  arg1 = reinterpret_cast< std::vector< std::string > * >(argp1);
  {
    if (!PySlice_Check(swig_obj[1])) {
      SWIG_exception_fail(SWIG_ArgError(SWIG_TypeError), "in method '" "StringVector___setitem__" "', argument " "2"" of type '" "PySliceObject *""'");
    }
    arg2 = (PySliceObject *) swig_obj[1];
  }
  {
    std::vector< std::string,std::allocator< std::string > > *ptr = (std::vector< std::string,std::allocator< std::string > > *)0;
    res3 = swig::asptr(swig_obj[2], &ptr);
    if (!SWIG_IsOK(res3)) {
      SWIG_exception_fail(SWIG_ArgError(res3), "in method '" "StringVector___setitem__" "', argument " "3"" of type '" "std::vector< std::string,std::allocator< std::string > > const &""'"); 
    }
    if (!ptr) {
      SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "StringVector___setitem__" "', argument " "3"" of type '" "std::vector< std::string,std::allocator< std::string > > const &""'"); 
    }
    arg3 = ptr;
  }
  try {
    std_vector_Sl_std_string_Sg____setitem____SWIG_0(arg1,arg2,(std::vector< std::string,std::allocator< std::string > > const &)*arg3);
  } catch(std::out_of_range &_e) {
    SWIG_exception_fail(SWIG_IndexError, (&_e)->what());
  } catch(std::invalid_argument &_e) {
    SWIG_exception_fail(SWIG_ValueError, (&_e)->what());
  }
  resultobj = SWIG_Py_Void();
  if (SWIG_IsNewObj(res3)) delete arg3;
  return resultobj;
fail:
  if (SWIG_IsNewObj(res3)) delete arg3;
  return NULL;
}


SWIGINTERN PyObject *_wrap_StringVector___setitem____SWIG_1(PyObject *SWIGUNUSEDPARM(self), Py_ssize_t nobjs, PyObject **swig_obj) {
  PyObject *resultobj = 0;
  std::vector< std::string > *arg1 = (std::vector< std::string > *) 0 ;
  PySliceObject *arg2 = (PySliceObject *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  
  if ((nobjs < 2) || (nobjs > 2)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__vectorT_std__string_std__allocatorT_std__string_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "StringVector___setitem__" "', argument " "1"" of type '" "std::vector< std::string > *""'"); 
  }
  arg1 = reinterpret_cast< std::vector< std::string > * >(argp1);
  {
    if (!PySlice_Check(swig_obj[1])) {
      SWIG_exception_fail(SWIG_ArgError(SWIG_TypeError), "in method '" "StringVector___setitem__" "', argument " "2"" of type '" "PySliceObject *""'");
    }
    arg2 = (PySliceObject *) swig_obj[1];
  }
  try {
    std_vector_Sl_std_string_Sg____setitem____SWIG_1(arg1,arg2);
  } catch(std::out_of_range &_e) {
    SWIG_exception_fail(SWIG_IndexError, (&_e)->what());
  } catch(std::invalid_argument &_e) {
    SWIG_exception_fail(SWIG_ValueError, (&_e)->what());
  }
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_StringVector___delitem____SWIG_1(PyObject *SWIGUNUSEDPARM(self), Py_ssize_t nobjs, PyObject **swig_obj) {
  PyObject *resultobj = 0;
  std::vector< std::string > *arg1 = (std::vector< std::string > *) 0 ;
  PySliceObject *arg2 = (PySliceObject *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  
  if ((nobjs < 2) || (nobjs > 2)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__vectorT_std__string_std__allocatorT_std__string_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "StringVector___delitem__" "', argument " "1"" of type '" "std::vector< std::string > *""'"); 
  }
  arg1 = reinterpret_cast< std::vector< std::string > * >(argp1);
  {
    if (!PySlice_Check(swig_obj[1])) {
      SWIG_exception_fail(SWIG_ArgError(SWIG_TypeError), "in method '" "StringVector___delitem__" "', argument " "2"" of type '" "PySliceObject *""'");
    }
    arg2 = (PySliceObject *) swig_obj[1];
  }
  try {
    std_vector_Sl_std_string_Sg____delitem____SWIG_1(arg1,arg2);
  } catch(std::out_of_range &_e) {
    SWIG_exception_fail(SWIG_IndexError, (&_e)->what());
  } catch(std::invalid_argument &_e) {
    SWIG_exception_fail(SWIG_ValueError, (&_e)->what());
  }
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_StringVector___delitem__(PyObject *self, PyObject *args) {
  Py_ssize_t argc;
  PyObject *argv[3] = {
    0
  };
  
  if (!(argc = SWIG_Python_UnpackTuple(args, "StringVector___delitem__", 0, 2, argv))) SWIG_fail;
  --argc;
  if (argc == 2) {
    int _v;
    int res = swig::asptr(argv[0], (std::vector< std::string,std::allocator< std::string > >**)(0));
    _v = SWIG_CheckState(res);
    if (_v) {
      {
        _v = PySlice_Check(argv[1]);
      }
      if (_v) {
        return _wrap_StringVector___delitem____SWIG_1(self, argc, argv);
      }
    }
  }
  if (argc == 2) {
    int _v;
    int res = swig::asptr(argv[0], (std::vector< std::string,std::allocator< std::string > >**)(0));
    _v = SWIG_CheckState(res);
    if (_v) {
      {
        int res = SWIG_AsVal_ptrdiff_t(argv[1], NULL);
        _v = SWIG_CheckState(res);
      }
      if (_v) {
        return _wrap_StringVector___delitem____SWIG_0(self, argc, argv);
      }
    }
  }
  
fail:
  SWIG_Python_RaiseOrModifyTypeError("Wrong number or type of arguments for overloaded function 'StringVector___delitem__'.\n"
    "  Possible C/C++ prototypes are:\n"
    "    std::vector< std::string >::__delitem__(std::vector< std::string >::difference_type)\n"
    "    std::vector< std::string >::__delitem__(PySliceObject *)\n");
  return 0;
}


SWIGINTERN PyObject *_wrap_StringVector___getitem____SWIG_1(PyObject *SWIGUNUSEDPARM(self), Py_ssize_t nobjs, PyObject **swig_obj) {
  PyObject *resultobj = 0;
  std::vector< std::string > *arg1 = (std::vector< std::string > *) 0 ;
  std::vector< std::string >::difference_type arg2 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  ptrdiff_t val2 ;
  int ecode2 = 0 ;
  std::vector< std::string >::value_type *result = 0 ;
  
  if ((nobjs < 2) || (nobjs > 2)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__vectorT_std__string_std__allocatorT_std__string_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "StringVector___getitem__" "', argument " "1"" of type '" "std::vector< std::string > const *""'"); 
  }
  arg1 = reinterpret_cast< std::vector< std::string > * >(argp1);
  ecode2 = SWIG_AsVal_ptrdiff_t(swig_obj[1], &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "StringVector___getitem__" "', argument " "2"" of type '" "std::vector< std::string >::difference_type""'");
  } 
  arg2 = static_cast< std::vector< std::string >::difference_type >(val2);
  try {
    result = (std::vector< std::string >::value_type *) &std_vector_Sl_std_string_Sg____getitem____SWIG_1((std::vector< std::string > const *)arg1,arg2);
  } catch(std::out_of_range &_e) {
    SWIG_exception_fail(SWIG_IndexError, (&_e)->what());
  }
  resultobj = SWIG_From_std_string(static_cast< std::string >(*result));
  (void)swig::container_owner<swig::traits<std::vector< std::string >::value_type>::category>::back_reference(resultobj, swig_obj[0]);
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_StringVector___getitem__(PyObject *self, PyObject *args) {
  Py_ssize_t argc;
  PyObject *argv[3] = {
    0
  };
  
  if (!(argc = SWIG_Python_UnpackTuple(args, "StringVector___getitem__", 0, 2, argv))) SWIG_fail;
  --argc;
  if (argc == 2) {
    int _v;
    int res = swig::asptr(argv[0], (std::vector< std::string,std::allocator< std::string > >**)(0));
    _v = SWIG_CheckState(res);
    if (_v) {
      {
        _v = PySlice_Check(argv[1]);
      }
      if (_v) {
        return _wrap_StringVector___getitem____SWIG_0(self, argc, argv);
      }
    }
  }
  if (argc == 2) {
    int _v;
    int res = swig::asptr(argv[0], (std::vector< std::string,std::allocator< std::string > >**)(0));
    _v = SWIG_CheckState(res);
    if (_v) {
      {
        int res = SWIG_AsVal_ptrdiff_t(argv[1], NULL);
        _v = SWIG_CheckState(res);
      }
      if (_v) {
        return _wrap_StringVector___getitem____SWIG_1(self, argc, argv);
      }
    }
  }
  
fail:
  SWIG_Python_RaiseOrModifyTypeError("Wrong number or type of arguments for overloaded function 'StringVector___getitem__'.\n"
    "  Possible C/C++ prototypes are:\n"
    "    std::vector< std::string >::__getitem__(PySliceObject *)\n"
    "    std::vector< std::string >::__getitem__(std::vector< std::string >::difference_type) const\n");
  return 0;
}


SWIGINTERN PyObject *_wrap_StringVector___setitem____SWIG_2(PyObject *SWIGUNUSEDPARM(self), Py_ssize_t nobjs, PyObject **swig_obj) {
  PyObject *resultobj = 0;
  std::vector< std::string > *arg1 = (std::vector< std::string > *) 0 ;
  std::vector< std::string >::difference_type arg2 ;
  std::vector< std::string >::value_type *arg3 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  ptrdiff_t val2 ;
  int ecode2 = 0 ;
  int res3 = SWIG_OLDOBJ ;
  
  if ((nobjs < 3) || (nobjs > 3)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__vectorT_std__string_std__allocatorT_std__string_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "StringVector___setitem__" "', argument " "1"" of type '" "std::vector< std::string > *""'"); 
  }
  arg1 = reinterpret_cast< std::vector< std::string > * >(argp1);
  ecode2 = SWIG_AsVal_ptrdiff_t(swig_obj[1], &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "StringVector___setitem__" "', argument " "2"" of type '" "std::vector< std::string >::difference_type""'");
  } 
  arg2 = static_cast< std::vector< std::string >::difference_type >(val2);
  {
    std::string *ptr = (std::string *)0;
    res3 = SWIG_AsPtr_std_string(swig_obj[2], &ptr);
    if (!SWIG_IsOK(res3)) {
      SWIG_exception_fail(SWIG_ArgError(res3), "in method '" "StringVector___setitem__" "', argument " "3"" of type '" "std::vector< std::string >::value_type const &""'"); 
    }
    if (!ptr) {
      SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "StringVector___setitem__" "', argument " "3"" of type '" "std::vector< std::string >::value_type const &""'"); 
    }
    arg3 = ptr;
  }
  try {
    std_vector_Sl_std_string_Sg____setitem____SWIG_2(arg1,arg2,(std::string const &)*arg3);
  } catch(std::out_of_range &_e) {
    SWIG_exception_fail(SWIG_IndexError, (&_e)->what());
  }
  resultobj = SWIG_Py_Void();
  if (SWIG_IsNewObj(res3)) delete arg3;
  return resultobj;
fail:
  if (SWIG_IsNewObj(res3)) delete arg3;
  return NULL;
}


SWIGINTERN PyObject *_wrap_StringVector___setitem__(PyObject *self, PyObject *args) {
  Py_ssize_t argc;
  PyObject *argv[4] = {
    0
  };
  
  if (!(argc = SWIG_Python_UnpackTuple(args, "StringVector___setitem__", 0, 3, argv))) SWIG_fail;
  --argc;
  if (argc == 2) {
    int _v;
    int res = swig::asptr(argv[0], (std::vector< std::string,std::allocator< std::string > >**)(0));
    _v = SWIG_CheckState(res);
    if (_v) {
      {
        _v = PySlice_Check(argv[1]);
      }
      if (_v) {
        return _wrap_StringVector___setitem____SWIG_1(self, argc, argv);
      }
    }
  }
  if (argc == 3) {
    int _v;
    int res = swig::asptr(argv[0], (std::vector< std::string,std::allocator< std::string > >**)(0));
    _v = SWIG_CheckState(res);
    if (_v) {
      {
        _v = PySlice_Check(argv[1]);
      }
      if (_v) {
        int res = swig::asptr(argv[2], (std::vector< std::string,std::allocator< std::string > >**)(0));
        _v = SWIG_CheckState(res);
        if (_v) {
          return _wrap_StringVector___setitem____SWIG_0(self, argc, argv);
        }
      }
    }
  }
  if (argc == 3) {
    int _v;
    int res = swig::asptr(argv[0], (std::vector< std::string,std::allocator< std::string > >**)(0));
    _v = SWIG_CheckState(res);
    if (_v) {
      {
        int res = SWIG_AsVal_ptrdiff_t(argv[1], NULL);
        _v = SWIG_CheckState(res);
      }
      if (_v) {
        int res = SWIG_AsPtr_std_string(argv[2], (std::string**)(0));
        _v = SWIG_CheckState(res);
        if (_v) {
          return _wrap_StringVector___setitem____SWIG_2(self, argc, argv);
        }
      }
    }
  }
  
fail:
  SWIG_Python_RaiseOrModifyTypeError("Wrong number or type of arguments for overloaded function 'StringVector___setitem__'.\n"
    "  Possible C/C++ prototypes are:\n"
    "    std::vector< std::string >::__setitem__(PySliceObject *,std::vector< std::string,std::allocator< std::string > > const &)\n"
    "    std::vector< std::string >::__setitem__(PySliceObject *)\n"
    "    std::vector< std::string >::__setitem__(std::vector< std::string >::difference_type,std::vector< std::string >::value_type const &)\n");
  return 0;
}


SWIGINTERN PyObject *_wrap_StringVector_pop(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  std::vector< std::string > *arg1 = (std::vector< std::string > *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  std::vector< std::string >::value_type result;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__vectorT_std__string_std__allocatorT_std__string_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "StringVector_pop" "', argument " "1"" of type '" "std::vector< std::string > *""'"); 
  }
  arg1 = reinterpret_cast< std::vector< std::string > * >(argp1);
  try {
    result = std_vector_Sl_std_string_Sg__pop(arg1);
  } catch(std::out_of_range &_e) {
    SWIG_exception_fail(SWIG_IndexError, (&_e)->what());
  }
  resultobj = SWIG_From_std_string(static_cast< std::string >(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_StringVector_append(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  std::vector< std::string > *arg1 = (std::vector< std::string > *) 0 ;
  std::vector< std::string >::value_type *arg2 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  int res2 = SWIG_OLDOBJ ;
  PyObject *swig_obj[2] ;
  
  if (!SWIG_Python_UnpackTuple(args, "StringVector_append", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__vectorT_std__string_std__allocatorT_std__string_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "StringVector_append" "', argument " "1"" of type '" "std::vector< std::string > *""'"); 
  }
  arg1 = reinterpret_cast< std::vector< std::string > * >(argp1);
  {
    std::string *ptr = (std::string *)0;
    res2 = SWIG_AsPtr_std_string(swig_obj[1], &ptr);
    if (!SWIG_IsOK(res2)) {
      SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "StringVector_append" "', argument " "2"" of type '" "std::vector< std::string >::value_type const &""'"); 
    }
    if (!ptr) {
      SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "StringVector_append" "', argument " "2"" of type '" "std::vector< std::string >::value_type const &""'"); 
    }
    arg2 = ptr;
  }
  std_vector_Sl_std_string_Sg__append(arg1,(std::string const &)*arg2);
  resultobj = SWIG_Py_Void();
  if (SWIG_IsNewObj(res2)) delete arg2;
  return resultobj;
fail:
  if (SWIG_IsNewObj(res2)) delete arg2;
  return NULL;
}


SWIGINTERN PyObject *_wrap_new_StringVector__SWIG_0(PyObject *SWIGUNUSEDPARM(self), Py_ssize_t nobjs, PyObject **SWIGUNUSEDPARM(swig_obj)) {
  PyObject *resultobj = 0;
  std::vector< std::string > *result = 0 ;
  
  if ((nobjs < 0) || (nobjs > 0)) SWIG_fail;
  result = (std::vector< std::string > *)new std::vector< std::string >();
  resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(result), SWIGTYPE_p_std__vectorT_std__string_std__allocatorT_std__string_t_t, SWIG_POINTER_NEW |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_new_StringVector__SWIG_1(PyObject *SWIGUNUSEDPARM(self), Py_ssize_t nobjs, PyObject **swig_obj) {
  PyObject *resultobj = 0;
  std::vector< std::string > *arg1 = 0 ;
  int res1 = SWIG_OLDOBJ ;
  std::vector< std::string > *result = 0 ;
  
  if ((nobjs < 1) || (nobjs > 1)) SWIG_fail;
  {
    std::vector< std::string,std::allocator< std::string > > *ptr = (std::vector< std::string,std::allocator< std::string > > *)0;
    res1 = swig::asptr(swig_obj[0], &ptr);
    if (!SWIG_IsOK(res1)) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "new_StringVector" "', argument " "1"" of type '" "std::vector< std::string > const &""'"); 
    }
    if (!ptr) {
      SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "new_StringVector" "', argument " "1"" of type '" "std::vector< std::string > const &""'"); 
    }
    arg1 = ptr;
  }
  result = (std::vector< std::string > *)new std::vector< std::string >((std::vector< std::string > const &)*arg1);
  resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(result), SWIGTYPE_p_std__vectorT_std__string_std__allocatorT_std__string_t_t, SWIG_POINTER_NEW |  0 );
  if (SWIG_IsNewObj(res1)) delete arg1;
  return resultobj;
fail:
  if (SWIG_IsNewObj(res1)) delete arg1;
  return NULL;
}


SWIGINTERN PyObject *_wrap_StringVector_empty(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  std::vector< std::string > *arg1 = (std::vector< std::string > *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  bool result;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__vectorT_std__string_std__allocatorT_std__string_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "StringVector_empty" "', argument " "1"" of type '" "std::vector< std::string > const *""'"); 
  }
  arg1 = reinterpret_cast< std::vector< std::string > * >(argp1);
  result = (bool)((std::vector< std::string > const *)arg1)->empty();
  resultobj = SWIG_From_bool(static_cast< bool >(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_StringVector_size(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  std::vector< std::string > *arg1 = (std::vector< std::string > *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  std::vector< std::string >::size_type result;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__vectorT_std__string_std__allocatorT_std__string_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "StringVector_size" "', argument " "1"" of type '" "std::vector< std::string > const *""'"); 
  }
  arg1 = reinterpret_cast< std::vector< std::string > * >(argp1);
  result = ((std::vector< std::string > const *)arg1)->size();
  resultobj = SWIG_From_size_t(static_cast< size_t >(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_StringVector_swap(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  std::vector< std::string > *arg1 = (std::vector< std::string > *) 0 ;
  std::vector< std::string > *arg2 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  void *argp2 = 0 ;
  int res2 = 0 ;
  PyObject *swig_obj[2] ;
  
  if (!SWIG_Python_UnpackTuple(args, "StringVector_swap", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__vectorT_std__string_std__allocatorT_std__string_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "StringVector_swap" "', argument " "1"" of type '" "std::vector< std::string > *""'"); 
  }
  arg1 = reinterpret_cast< std::vector< std::string > * >(argp1);
  res2 = SWIG_ConvertPtr(swig_obj[1], &argp2, SWIGTYPE_p_std__vectorT_std__string_std__allocatorT_std__string_t_t,  0 );
  if (!SWIG_IsOK(res2)) {
    SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "StringVector_swap" "', argument " "2"" of type '" "std::vector< std::string > &""'"); 
  }
  if (!argp2) {
    SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "StringVector_swap" "', argument " "2"" of type '" "std::vector< std::string > &""'"); 
  }
  arg2 = reinterpret_cast< std::vector< std::string > * >(argp2);
  (arg1)->swap(*arg2);
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_StringVector_begin(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  std::vector< std::string > *arg1 = (std::vector< std::string > *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  std::vector< std::string >::iterator result;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__vectorT_std__string_std__allocatorT_std__string_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "StringVector_begin" "', argument " "1"" of type '" "std::vector< std::string > *""'"); 
  }
  arg1 = reinterpret_cast< std::vector< std::string > * >(argp1);
  result = (arg1)->begin();
  resultobj = SWIG_NewPointerObj(swig::make_output_iterator(static_cast< const std::vector< std::string >::iterator & >(result)),
    swig::SwigPyIterator::descriptor(),SWIG_POINTER_OWN);
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_StringVector_end(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  std::vector< std::string > *arg1 = (std::vector< std::string > *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  std::vector< std::string >::iterator result;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__vectorT_std__string_std__allocatorT_std__string_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "StringVector_end" "', argument " "1"" of type '" "std::vector< std::string > *""'"); 
  }
  arg1 = reinterpret_cast< std::vector< std::string > * >(argp1);
  result = (arg1)->end();
  resultobj = SWIG_NewPointerObj(swig::make_output_iterator(static_cast< const std::vector< std::string >::iterator & >(result)),
    swig::SwigPyIterator::descriptor(),SWIG_POINTER_OWN);
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_StringVector_rbegin(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  std::vector< std::string > *arg1 = (std::vector< std::string > *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  std::vector< std::string >::reverse_iterator result;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__vectorT_std__string_std__allocatorT_std__string_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "StringVector_rbegin" "', argument " "1"" of type '" "std::vector< std::string > *""'"); 
  }
  arg1 = reinterpret_cast< std::vector< std::string > * >(argp1);
  result = (arg1)->rbegin();
  resultobj = SWIG_NewPointerObj(swig::make_output_iterator(static_cast< const std::vector< std::string >::reverse_iterator & >(result)),
    swig::SwigPyIterator::descriptor(),SWIG_POINTER_OWN);
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_StringVector_rend(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  std::vector< std::string > *arg1 = (std::vector< std::string > *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  std::vector< std::string >::reverse_iterator result;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__vectorT_std__string_std__allocatorT_std__string_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "StringVector_rend" "', argument " "1"" of type '" "std::vector< std::string > *""'"); 
  }
  arg1 = reinterpret_cast< std::vector< std::string > * >(argp1);
  result = (arg1)->rend();
  resultobj = SWIG_NewPointerObj(swig::make_output_iterator(static_cast< const std::vector< std::string >::reverse_iterator & >(result)),
    swig::SwigPyIterator::descriptor(),SWIG_POINTER_OWN);
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_StringVector_clear(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  std::vector< std::string > *arg1 = (std::vector< std::string > *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__vectorT_std__string_std__allocatorT_std__string_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "StringVector_clear" "', argument " "1"" of type '" "std::vector< std::string > *""'"); 
  }
  arg1 = reinterpret_cast< std::vector< std::string > * >(argp1);
  (arg1)->clear();
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_StringVector_get_allocator(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  std::vector< std::string > *arg1 = (std::vector< std::string > *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  SwigValueWrapper< std::allocator< std::string > > result;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__vectorT_std__string_std__allocatorT_std__string_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "StringVector_get_allocator" "', argument " "1"" of type '" "std::vector< std::string > const *""'"); 
  }
  arg1 = reinterpret_cast< std::vector< std::string > * >(argp1);
  result = ((std::vector< std::string > const *)arg1)->get_allocator();
  resultobj = SWIG_NewPointerObj((new std::vector< std::string >::allocator_type(static_cast< const std::vector< std::string >::allocator_type& >(result))), SWIGTYPE_p_std__allocatorT_std__string_t, SWIG_POINTER_OWN |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_new_StringVector__SWIG_2(PyObject *SWIGUNUSEDPARM(self), Py_ssize_t nobjs, PyObject **swig_obj) {
  PyObject *resultobj = 0;
  std::vector< std::string >::size_type arg1 ;
  size_t val1 ;
  int ecode1 = 0 ;
  std::vector< std::string > *result = 0 ;
  
  if ((nobjs < 1) || (nobjs > 1)) SWIG_fail;
  ecode1 = SWIG_AsVal_size_t(swig_obj[0], &val1);
  if (!SWIG_IsOK(ecode1)) {
    SWIG_exception_fail(SWIG_ArgError(ecode1), "in method '" "new_StringVector" "', argument " "1"" of type '" "std::vector< std::string >::size_type""'");
  } 
  arg1 = static_cast< std::vector< std::string >::size_type >(val1);
  result = (std::vector< std::string > *)new std::vector< std::string >(arg1);
  resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(result), SWIGTYPE_p_std__vectorT_std__string_std__allocatorT_std__string_t_t, SWIG_POINTER_NEW |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_StringVector_pop_back(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  std::vector< std::string > *arg1 = (std::vector< std::string > *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__vectorT_std__string_std__allocatorT_std__string_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "StringVector_pop_back" "', argument " "1"" of type '" "std::vector< std::string > *""'"); 
  }
  arg1 = reinterpret_cast< std::vector< std::string > * >(argp1);
  (arg1)->pop_back();
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_StringVector_resize__SWIG_0(PyObject *SWIGUNUSEDPARM(self), Py_ssize_t nobjs, PyObject **swig_obj) {
  PyObject *resultobj = 0;
  std::vector< std::string > *arg1 = (std::vector< std::string > *) 0 ;
  std::vector< std::string >::size_type arg2 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  size_t val2 ;
  int ecode2 = 0 ;
  
  if ((nobjs < 2) || (nobjs > 2)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__vectorT_std__string_std__allocatorT_std__string_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "StringVector_resize" "', argument " "1"" of type '" "std::vector< std::string > *""'"); 
  }
  arg1 = reinterpret_cast< std::vector< std::string > * >(argp1);
  ecode2 = SWIG_AsVal_size_t(swig_obj[1], &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "StringVector_resize" "', argument " "2"" of type '" "std::vector< std::string >::size_type""'");
  } 
  arg2 = static_cast< std::vector< std::string >::size_type >(val2);
  (arg1)->resize(arg2);
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_StringVector_erase__SWIG_0(PyObject *SWIGUNUSEDPARM(self), Py_ssize_t nobjs, PyObject **swig_obj) {
  PyObject *resultobj = 0;
  std::vector< std::string > *arg1 = (std::vector< std::string > *) 0 ;
  std::vector< std::string >::iterator arg2 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  swig::SwigPyIterator *iter2 = 0 ;
  int res2 ;
  std::vector< std::string >::iterator result;
  
  if ((nobjs < 2) || (nobjs > 2)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__vectorT_std__string_std__allocatorT_std__string_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "StringVector_erase" "', argument " "1"" of type '" "std::vector< std::string > *""'"); 
  }
  arg1 = reinterpret_cast< std::vector< std::string > * >(argp1);
  res2 = SWIG_ConvertPtr(swig_obj[1], SWIG_as_voidptrptr(&iter2), swig::SwigPyIterator::descriptor(), 0);
  if (!SWIG_IsOK(res2) || !iter2) {
    SWIG_exception_fail(SWIG_ArgError(SWIG_TypeError), "in method '" "StringVector_erase" "', argument " "2"" of type '" "std::vector< std::string >::iterator""'");
  } else {
    swig::SwigPyIterator_T<std::vector< std::string >::iterator > *iter_t = dynamic_cast<swig::SwigPyIterator_T<std::vector< std::string >::iterator > *>(iter2);
    if (iter_t) {
      arg2 = iter_t->get_current();
    } else {
      SWIG_exception_fail(SWIG_ArgError(SWIG_TypeError), "in method '" "StringVector_erase" "', argument " "2"" of type '" "std::vector< std::string >::iterator""'");
    }
  }
  result = std_vector_Sl_std_string_Sg__erase__SWIG_0(arg1,arg2);
  resultobj = SWIG_NewPointerObj(swig::make_output_iterator(static_cast< const std::vector< std::string >::iterator & >(result)),
    swig::SwigPyIterator::descriptor(),SWIG_POINTER_OWN);
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_StringVector_erase__SWIG_1(PyObject *SWIGUNUSEDPARM(self), Py_ssize_t nobjs, PyObject **swig_obj) {
  PyObject *resultobj = 0;
  std::vector< std::string > *arg1 = (std::vector< std::string > *) 0 ;
  std::vector< std::string >::iterator arg2 ;
  std::vector< std::string >::iterator arg3 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  swig::SwigPyIterator *iter2 = 0 ;
  int res2 ;
  swig::SwigPyIterator *iter3 = 0 ;
  int res3 ;
  std::vector< std::string >::iterator result;
  
  if ((nobjs < 3) || (nobjs > 3)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__vectorT_std__string_std__allocatorT_std__string_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "StringVector_erase" "', argument " "1"" of type '" "std::vector< std::string > *""'"); 
  }
  arg1 = reinterpret_cast< std::vector< std::string > * >(argp1);
  res2 = SWIG_ConvertPtr(swig_obj[1], SWIG_as_voidptrptr(&iter2), swig::SwigPyIterator::descriptor(), 0);
  if (!SWIG_IsOK(res2) || !iter2) {
    SWIG_exception_fail(SWIG_ArgError(SWIG_TypeError), "in method '" "StringVector_erase" "', argument " "2"" of type '" "std::vector< std::string >::iterator""'");
  } else {
    swig::SwigPyIterator_T<std::vector< std::string >::iterator > *iter_t = dynamic_cast<swig::SwigPyIterator_T<std::vector< std::string >::iterator > *>(iter2);
    if (iter_t) {
      arg2 = iter_t->get_current();
    } else {
      SWIG_exception_fail(SWIG_ArgError(SWIG_TypeError), "in method '" "StringVector_erase" "', argument " "2"" of type '" "std::vector< std::string >::iterator""'");
    }
  }
  res3 = SWIG_ConvertPtr(swig_obj[2], SWIG_as_voidptrptr(&iter3), swig::SwigPyIterator::descriptor(), 0);
  if (!SWIG_IsOK(res3) || !iter3) {
    SWIG_exception_fail(SWIG_ArgError(SWIG_TypeError), "in method '" "StringVector_erase" "', argument " "3"" of type '" "std::vector< std::string >::iterator""'");
  } else {
    swig::SwigPyIterator_T<std::vector< std::string >::iterator > *iter_t = dynamic_cast<swig::SwigPyIterator_T<std::vector< std::string >::iterator > *>(iter3);
    if (iter_t) {
      arg3 = iter_t->get_current();
    } else {
      SWIG_exception_fail(SWIG_ArgError(SWIG_TypeError), "in method '" "StringVector_erase" "', argument " "3"" of type '" "std::vector< std::string >::iterator""'");
    }
  }
  result = std_vector_Sl_std_string_Sg__erase__SWIG_1(arg1,arg2,arg3);
  resultobj = SWIG_NewPointerObj(swig::make_output_iterator(static_cast< const std::vector< std::string >::iterator & >(result)),
    swig::SwigPyIterator::descriptor(),SWIG_POINTER_OWN);
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_StringVector_erase(PyObject *self, PyObject *args) {
  Py_ssize_t argc;
  PyObject *argv[4] = {
    0
  };
  
  if (!(argc = SWIG_Python_UnpackTuple(args, "StringVector_erase", 0, 3, argv))) SWIG_fail;
  --argc;
  if (argc == 2) {
    int _v;
    int res = swig::asptr(argv[0], (std::vector< std::string,std::allocator< std::string > >**)(0));
    _v = SWIG_CheckState(res);
    if (_v) {
      swig::SwigPyIterator *iter = 0;
      int res = SWIG_ConvertPtr(argv[1], SWIG_as_voidptrptr(&iter), swig::SwigPyIterator::descriptor(), 0);
      _v = (SWIG_IsOK(res) && iter && (dynamic_cast<swig::SwigPyIterator_T<std::vector< std::string >::iterator > *>(iter) != 0));
      if (_v) {
        return _wrap_StringVector_erase__SWIG_0(self, argc, argv);
      }
    }
  }
  if (argc == 3) {
    int _v;
    int res = swig::asptr(argv[0], (std::vector< std::string,std::allocator< std::string > >**)(0));
    _v = SWIG_CheckState(res);
    if (_v) {
      swig::SwigPyIterator *iter = 0;
      int res = SWIG_ConvertPtr(argv[1], SWIG_as_voidptrptr(&iter), swig::SwigPyIterator::descriptor(), 0);
      _v = (SWIG_IsOK(res) && iter && (dynamic_cast<swig::SwigPyIterator_T<std::vector< std::string >::iterator > *>(iter) != 0));
      if (_v) {
        swig::SwigPyIterator *iter = 0;
        int res = SWIG_ConvertPtr(argv[2], SWIG_as_voidptrptr(&iter), swig::SwigPyIterator::descriptor(), 0);
        _v = (SWIG_IsOK(res) && iter && (dynamic_cast<swig::SwigPyIterator_T<std::vector< std::string >::iterator > *>(iter) != 0));
        if (_v) {
          return _wrap_StringVector_erase__SWIG_1(self, argc, argv);
        }
      }
    }
  }
  
fail:
  SWIG_Python_RaiseOrModifyTypeError("Wrong number or type of arguments for overloaded function 'StringVector_erase'.\n"
    "  Possible C/C++ prototypes are:\n"
    "    std::vector< std::string >::erase(std::vector< std::string >::iterator)\n"
    "    std::vector< std::string >::erase(std::vector< std::string >::iterator,std::vector< std::string >::iterator)\n");
  return 0;
}


SWIGINTERN PyObject *_wrap_new_StringVector__SWIG_3(PyObject *SWIGUNUSEDPARM(self), Py_ssize_t nobjs, PyObject **swig_obj) {
  PyObject *resultobj = 0;
  std::vector< std::string >::size_type arg1 ;
  std::vector< std::string >::value_type *arg2 = 0 ;
  size_t val1 ;
  int ecode1 = 0 ;
  int res2 = SWIG_OLDOBJ ;
  std::vector< std::string > *result = 0 ;
  
  if ((nobjs < 2) || (nobjs > 2)) SWIG_fail;
  ecode1 = SWIG_AsVal_size_t(swig_obj[0], &val1);
  if (!SWIG_IsOK(ecode1)) {
    SWIG_exception_fail(SWIG_ArgError(ecode1), "in method '" "new_StringVector" "', argument " "1"" of type '" "std::vector< std::string >::size_type""'");
  } 
  arg1 = static_cast< std::vector< std::string >::size_type >(val1);
  {
    std::string *ptr = (std::string *)0;
    res2 = SWIG_AsPtr_std_string(swig_obj[1], &ptr);
    if (!SWIG_IsOK(res2)) {
      SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "new_StringVector" "', argument " "2"" of type '" "std::vector< std::string >::value_type const &""'"); 
    }
    if (!ptr) {
      SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "new_StringVector" "', argument " "2"" of type '" "std::vector< std::string >::value_type const &""'"); 
    }
    arg2 = ptr;
  }
  result = (std::vector< std::string > *)new std::vector< std::string >(arg1,(std::vector< std::string >::value_type const &)*arg2);
  resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(result), SWIGTYPE_p_std__vectorT_std__string_std__allocatorT_std__string_t_t, SWIG_POINTER_NEW |  0 );
  if (SWIG_IsNewObj(res2)) delete arg2;
  return resultobj;
fail:
  if (SWIG_IsNewObj(res2)) delete arg2;
  return NULL;
}


SWIGINTERN PyObject *_wrap_new_StringVector(PyObject *self, PyObject *args) {
  Py_ssize_t argc;
  PyObject *argv[3] = {
    0
  };
  
  if (!(argc = SWIG_Python_UnpackTuple(args, "new_StringVector", 0, 2, argv))) SWIG_fail;
  --argc;
  if (argc == 0) {
    return _wrap_new_StringVector__SWIG_0(self, argc, argv);
  }
  if (argc == 1) {
    int _v;
    {
      int res = SWIG_AsVal_size_t(argv[0], NULL);
      _v = SWIG_CheckState(res);
    }
    if (_v) {
      return _wrap_new_StringVector__SWIG_2(self, argc, argv);
    }
  }
  if (argc == 1) {
    int _v;
    int res = swig::asptr(argv[0], (std::vector< std::string,std::allocator< std::string > >**)(0));
    _v = SWIG_CheckState(res);
    if (_v) {
      return _wrap_new_StringVector__SWIG_1(self, argc, argv);
    }
  }
  if (argc == 2) {
    int _v;
    {
      int res = SWIG_AsVal_size_t(argv[0], NULL);
      _v = SWIG_CheckState(res);
    }
    if (_v) {
      int res = SWIG_AsPtr_std_string(argv[1], (std::string**)(0));
      _v = SWIG_CheckState(res);
      if (_v) {
        return _wrap_new_StringVector__SWIG_3(self, argc, argv);
      }
    }
  }
  
fail:
  SWIG_Python_RaiseOrModifyTypeError("Wrong number or type of arguments for overloaded function 'new_StringVector'.\n"
    "  Possible C/C++ prototypes are:\n"
    "    std::vector< std::string >::vector()\n"
    "    std::vector< std::string >::vector(std::vector< std::string > const &)\n"
    "    std::vector< std::string >::vector(std::vector< std::string >::size_type)\n"
    "    std::vector< std::string >::vector(std::vector< std::string >::size_type,std::vector< std::string >::value_type const &)\n");
  return 0;
}


SWIGINTERN PyObject *_wrap_StringVector_push_back(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  std::vector< std::string > *arg1 = (std::vector< std::string > *) 0 ;
  std::vector< std::string >::value_type *arg2 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  int res2 = SWIG_OLDOBJ ;
  PyObject *swig_obj[2] ;
  
  if (!SWIG_Python_UnpackTuple(args, "StringVector_push_back", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__vectorT_std__string_std__allocatorT_std__string_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "StringVector_push_back" "', argument " "1"" of type '" "std::vector< std::string > *""'"); 
  }
  arg1 = reinterpret_cast< std::vector< std::string > * >(argp1);
  {
    std::string *ptr = (std::string *)0;
    res2 = SWIG_AsPtr_std_string(swig_obj[1], &ptr);
    if (!SWIG_IsOK(res2)) {
      SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "StringVector_push_back" "', argument " "2"" of type '" "std::vector< std::string >::value_type const &""'"); 
    }
    if (!ptr) {
      SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "StringVector_push_back" "', argument " "2"" of type '" "std::vector< std::string >::value_type const &""'"); 
    }
    arg2 = ptr;
  }
  (arg1)->push_back((std::vector< std::string >::value_type const &)*arg2);
  resultobj = SWIG_Py_Void();
  if (SWIG_IsNewObj(res2)) delete arg2;
  return resultobj;
fail:
  if (SWIG_IsNewObj(res2)) delete arg2;
  return NULL;
}


SWIGINTERN PyObject *_wrap_StringVector_front(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  std::vector< std::string > *arg1 = (std::vector< std::string > *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  std::vector< std::string >::value_type *result = 0 ;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__vectorT_std__string_std__allocatorT_std__string_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "StringVector_front" "', argument " "1"" of type '" "std::vector< std::string > const *""'"); 
  }
  arg1 = reinterpret_cast< std::vector< std::string > * >(argp1);
  result = (std::vector< std::string >::value_type *) &((std::vector< std::string > const *)arg1)->front();
  resultobj = SWIG_From_std_string(static_cast< std::string >(*result));
  (void)swig::container_owner<swig::traits<std::vector< std::string >::value_type>::category>::back_reference(resultobj, swig_obj[0]);
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_StringVector_back(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  std::vector< std::string > *arg1 = (std::vector< std::string > *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  std::vector< std::string >::value_type *result = 0 ;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__vectorT_std__string_std__allocatorT_std__string_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "StringVector_back" "', argument " "1"" of type '" "std::vector< std::string > const *""'"); 
  }
  arg1 = reinterpret_cast< std::vector< std::string > * >(argp1);
  result = (std::vector< std::string >::value_type *) &((std::vector< std::string > const *)arg1)->back();
  resultobj = SWIG_From_std_string(static_cast< std::string >(*result));
  (void)swig::container_owner<swig::traits<std::vector< std::string >::value_type>::category>::back_reference(resultobj, swig_obj[0]);
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_StringVector_assign(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  std::vector< std::string > *arg1 = (std::vector< std::string > *) 0 ;
  std::vector< std::string >::size_type arg2 ;
  std::vector< std::string >::value_type *arg3 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  size_t val2 ;
  int ecode2 = 0 ;
  int res3 = SWIG_OLDOBJ ;
  PyObject *swig_obj[3] ;
  
  if (!SWIG_Python_UnpackTuple(args, "StringVector_assign", 3, 3, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__vectorT_std__string_std__allocatorT_std__string_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "StringVector_assign" "', argument " "1"" of type '" "std::vector< std::string > *""'"); 
  }
  arg1 = reinterpret_cast< std::vector< std::string > * >(argp1);
  ecode2 = SWIG_AsVal_size_t(swig_obj[1], &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "StringVector_assign" "', argument " "2"" of type '" "std::vector< std::string >::size_type""'");
  } 
  arg2 = static_cast< std::vector< std::string >::size_type >(val2);
  {
    std::string *ptr = (std::string *)0;
    res3 = SWIG_AsPtr_std_string(swig_obj[2], &ptr);
    if (!SWIG_IsOK(res3)) {
      SWIG_exception_fail(SWIG_ArgError(res3), "in method '" "StringVector_assign" "', argument " "3"" of type '" "std::vector< std::string >::value_type const &""'"); 
    }
    if (!ptr) {
      SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "StringVector_assign" "', argument " "3"" of type '" "std::vector< std::string >::value_type const &""'"); 
    }
    arg3 = ptr;
  }
  (arg1)->assign(arg2,(std::vector< std::string >::value_type const &)*arg3);
  resultobj = SWIG_Py_Void();
  if (SWIG_IsNewObj(res3)) delete arg3;
  return resultobj;
fail:
  if (SWIG_IsNewObj(res3)) delete arg3;
  return NULL;
}


SWIGINTERN PyObject *_wrap_StringVector_resize__SWIG_1(PyObject *SWIGUNUSEDPARM(self), Py_ssize_t nobjs, PyObject **swig_obj) {
  PyObject *resultobj = 0;
  std::vector< std::string > *arg1 = (std::vector< std::string > *) 0 ;
  std::vector< std::string >::size_type arg2 ;
  std::vector< std::string >::value_type *arg3 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  size_t val2 ;
  int ecode2 = 0 ;
  int res3 = SWIG_OLDOBJ ;
  
  if ((nobjs < 3) || (nobjs > 3)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__vectorT_std__string_std__allocatorT_std__string_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "StringVector_resize" "', argument " "1"" of type '" "std::vector< std::string > *""'"); 
  }
  arg1 = reinterpret_cast< std::vector< std::string > * >(argp1);
  ecode2 = SWIG_AsVal_size_t(swig_obj[1], &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "StringVector_resize" "', argument " "2"" of type '" "std::vector< std::string >::size_type""'");
  } 
  arg2 = static_cast< std::vector< std::string >::size_type >(val2);
  {
    std::string *ptr = (std::string *)0;
    res3 = SWIG_AsPtr_std_string(swig_obj[2], &ptr);
    if (!SWIG_IsOK(res3)) {
      SWIG_exception_fail(SWIG_ArgError(res3), "in method '" "StringVector_resize" "', argument " "3"" of type '" "std::vector< std::string >::value_type const &""'"); 
    }
    if (!ptr) {
      SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "StringVector_resize" "', argument " "3"" of type '" "std::vector< std::string >::value_type const &""'"); 
    }
    arg3 = ptr;
  }
  (arg1)->resize(arg2,(std::vector< std::string >::value_type const &)*arg3);
  resultobj = SWIG_Py_Void();
  if (SWIG_IsNewObj(res3)) delete arg3;
  return resultobj;
fail:
  if (SWIG_IsNewObj(res3)) delete arg3;
  return NULL;
}


SWIGINTERN PyObject *_wrap_StringVector_resize(PyObject *self, PyObject *args) {
  Py_ssize_t argc;
  PyObject *argv[4] = {
    0
  };
  
  if (!(argc = SWIG_Python_UnpackTuple(args, "StringVector_resize", 0, 3, argv))) SWIG_fail;
  --argc;
  if (argc == 2) {
    int _v;
    int res = swig::asptr(argv[0], (std::vector< std::string,std::allocator< std::string > >**)(0));
    _v = SWIG_CheckState(res);
    if (_v) {
      {
        int res = SWIG_AsVal_size_t(argv[1], NULL);
        _v = SWIG_CheckState(res);
      }
      if (_v) {
        return _wrap_StringVector_resize__SWIG_0(self, argc, argv);
      }
    }
  }
  if (argc == 3) {
    int _v;
    int res = swig::asptr(argv[0], (std::vector< std::string,std::allocator< std::string > >**)(0));
    _v = SWIG_CheckState(res);
    if (_v) {
      {
        int res = SWIG_AsVal_size_t(argv[1], NULL);
        _v = SWIG_CheckState(res);
      }
      if (_v) {
        int res = SWIG_AsPtr_std_string(argv[2], (std::string**)(0));
        _v = SWIG_CheckState(res);
        if (_v) {
          return _wrap_StringVector_resize__SWIG_1(self, argc, argv);
        }
      }
    }
  }
  
fail:
  SWIG_Python_RaiseOrModifyTypeError("Wrong number or type of arguments for overloaded function 'StringVector_resize'.\n"
    "  Possible C/C++ prototypes are:\n"
    "    std::vector< std::string >::resize(std::vector< std::string >::size_type)\n"
    "    std::vector< std::string >::resize(std::vector< std::string >::size_type,std::vector< std::string >::value_type const &)\n");
  return 0;
}


SWIGINTERN PyObject *_wrap_StringVector_insert__SWIG_0(PyObject *SWIGUNUSEDPARM(self), Py_ssize_t nobjs, PyObject **swig_obj) {
  PyObject *resultobj = 0;
  std::vector< std::string > *arg1 = (std::vector< std::string > *) 0 ;
  std::vector< std::string >::iterator arg2 ;
  std::vector< std::string >::value_type *arg3 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  swig::SwigPyIterator *iter2 = 0 ;
  int res2 ;
  int res3 = SWIG_OLDOBJ ;
  std::vector< std::string >::iterator result;
  
  if ((nobjs < 3) || (nobjs > 3)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__vectorT_std__string_std__allocatorT_std__string_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "StringVector_insert" "', argument " "1"" of type '" "std::vector< std::string > *""'"); 
  }
  arg1 = reinterpret_cast< std::vector< std::string > * >(argp1);
  res2 = SWIG_ConvertPtr(swig_obj[1], SWIG_as_voidptrptr(&iter2), swig::SwigPyIterator::descriptor(), 0);
  if (!SWIG_IsOK(res2) || !iter2) {
    SWIG_exception_fail(SWIG_ArgError(SWIG_TypeError), "in method '" "StringVector_insert" "', argument " "2"" of type '" "std::vector< std::string >::iterator""'");
  } else {
    swig::SwigPyIterator_T<std::vector< std::string >::iterator > *iter_t = dynamic_cast<swig::SwigPyIterator_T<std::vector< std::string >::iterator > *>(iter2);
    if (iter_t) {
      arg2 = iter_t->get_current();
    } else {
      SWIG_exception_fail(SWIG_ArgError(SWIG_TypeError), "in method '" "StringVector_insert" "', argument " "2"" of type '" "std::vector< std::string >::iterator""'");
    }
  }
  {
    std::string *ptr = (std::string *)0;
    res3 = SWIG_AsPtr_std_string(swig_obj[2], &ptr);
    if (!SWIG_IsOK(res3)) {
      SWIG_exception_fail(SWIG_ArgError(res3), "in method '" "StringVector_insert" "', argument " "3"" of type '" "std::vector< std::string >::value_type const &""'"); 
    }
    if (!ptr) {
      SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "StringVector_insert" "', argument " "3"" of type '" "std::vector< std::string >::value_type const &""'"); 
    }
    arg3 = ptr;
  }
  result = std_vector_Sl_std_string_Sg__insert__SWIG_0(arg1,arg2,(std::string const &)*arg3);
  resultobj = SWIG_NewPointerObj(swig::make_output_iterator(static_cast< const std::vector< std::string >::iterator & >(result)),
    swig::SwigPyIterator::descriptor(),SWIG_POINTER_OWN);
  if (SWIG_IsNewObj(res3)) delete arg3;
  return resultobj;
fail:
  if (SWIG_IsNewObj(res3)) delete arg3;
  return NULL;
}


SWIGINTERN PyObject *_wrap_StringVector_insert__SWIG_1(PyObject *SWIGUNUSEDPARM(self), Py_ssize_t nobjs, PyObject **swig_obj) {
  PyObject *resultobj = 0;
  std::vector< std::string > *arg1 = (std::vector< std::string > *) 0 ;
  std::vector< std::string >::iterator arg2 ;
  std::vector< std::string >::size_type arg3 ;
  std::vector< std::string >::value_type *arg4 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  swig::SwigPyIterator *iter2 = 0 ;
  int res2 ;
  size_t val3 ;
  int ecode3 = 0 ;
  int res4 = SWIG_OLDOBJ ;
  
  if ((nobjs < 4) || (nobjs > 4)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__vectorT_std__string_std__allocatorT_std__string_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "StringVector_insert" "', argument " "1"" of type '" "std::vector< std::string > *""'"); 
  }
  arg1 = reinterpret_cast< std::vector< std::string > * >(argp1);
  res2 = SWIG_ConvertPtr(swig_obj[1], SWIG_as_voidptrptr(&iter2), swig::SwigPyIterator::descriptor(), 0);
  if (!SWIG_IsOK(res2) || !iter2) {
    SWIG_exception_fail(SWIG_ArgError(SWIG_TypeError), "in method '" "StringVector_insert" "', argument " "2"" of type '" "std::vector< std::string >::iterator""'");
  } else {
    swig::SwigPyIterator_T<std::vector< std::string >::iterator > *iter_t = dynamic_cast<swig::SwigPyIterator_T<std::vector< std::string >::iterator > *>(iter2);
    if (iter_t) {
      arg2 = iter_t->get_current();
    } else {
      SWIG_exception_fail(SWIG_ArgError(SWIG_TypeError), "in method '" "StringVector_insert" "', argument " "2"" of type '" "std::vector< std::string >::iterator""'");
    }
  }
  ecode3 = SWIG_AsVal_size_t(swig_obj[2], &val3);
  if (!SWIG_IsOK(ecode3)) {
    SWIG_exception_fail(SWIG_ArgError(ecode3), "in method '" "StringVector_insert" "', argument " "3"" of type '" "std::vector< std::string >::size_type""'");
  } 
  arg3 = static_cast< std::vector< std::string >::size_type >(val3);
  {
    std::string *ptr = (std::string *)0;
    res4 = SWIG_AsPtr_std_string(swig_obj[3], &ptr);
    if (!SWIG_IsOK(res4)) {
      SWIG_exception_fail(SWIG_ArgError(res4), "in method '" "StringVector_insert" "', argument " "4"" of type '" "std::vector< std::string >::value_type const &""'"); 
    }
    if (!ptr) {
      SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "StringVector_insert" "', argument " "4"" of type '" "std::vector< std::string >::value_type const &""'"); 
    }
    arg4 = ptr;
  }
  std_vector_Sl_std_string_Sg__insert__SWIG_1(arg1,arg2,arg3,(std::string const &)*arg4);
  resultobj = SWIG_Py_Void();
  if (SWIG_IsNewObj(res4)) delete arg4;
  return resultobj;
fail:
  if (SWIG_IsNewObj(res4)) delete arg4;
  return NULL;
}


SWIGINTERN PyObject *_wrap_StringVector_insert(PyObject *self, PyObject *args) {
  Py_ssize_t argc;
  PyObject *argv[5] = {
    0
  };
  
  if (!(argc = SWIG_Python_UnpackTuple(args, "StringVector_insert", 0, 4, argv))) SWIG_fail;
  --argc;
  if (argc == 3) {
    int _v;
    int res = swig::asptr(argv[0], (std::vector< std::string,std::allocator< std::string > >**)(0));
    _v = SWIG_CheckState(res);
    if (_v) {
      swig::SwigPyIterator *iter = 0;
      int res = SWIG_ConvertPtr(argv[1], SWIG_as_voidptrptr(&iter), swig::SwigPyIterator::descriptor(), 0);
      _v = (SWIG_IsOK(res) && iter && (dynamic_cast<swig::SwigPyIterator_T<std::vector< std::string >::iterator > *>(iter) != 0));
      if (_v) {
        int res = SWIG_AsPtr_std_string(argv[2], (std::string**)(0));
        _v = SWIG_CheckState(res);
        if (_v) {
          return _wrap_StringVector_insert__SWIG_0(self, argc, argv);
        }
      }
    }
  }
  if (argc == 4) {
    int _v;
    int res = swig::asptr(argv[0], (std::vector< std::string,std::allocator< std::string > >**)(0));
    _v = SWIG_CheckState(res);
    if (_v) {
      swig::SwigPyIterator *iter = 0;
      int res = SWIG_ConvertPtr(argv[1], SWIG_as_voidptrptr(&iter), swig::SwigPyIterator::descriptor(), 0);
      _v = (SWIG_IsOK(res) && iter && (dynamic_cast<swig::SwigPyIterator_T<std::vector< std::string >::iterator > *>(iter) != 0));
      if (_v) {
        {
          int res = SWIG_AsVal_size_t(argv[2], NULL);
          _v = SWIG_CheckState(res);
        }
        if (_v) {
          int res = SWIG_AsPtr_std_string(argv[3], (std::string**)(0));
          _v = SWIG_CheckState(res);
          if (_v) {
            return _wrap_StringVector_insert__SWIG_1(self, argc, argv);
          }
        }
      }
    }
  }
  
fail:
  SWIG_Python_RaiseOrModifyTypeError("Wrong number or type of arguments for overloaded function 'StringVector_insert'.\n"
    "  Possible C/C++ prototypes are:\n"
    "    std::vector< std::string >::insert(std::vector< std::string >::iterator,std::vector< std::string >::value_type const &)\n"
    "    std::vector< std::string >::insert(std::vector< std::string >::iterator,std::vector< std::string >::size_type,std::vector< std::string >::value_type const &)\n");
  return 0;
}


SWIGINTERN PyObject *_wrap_StringVector_reserve(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  std::vector< std::string > *arg1 = (std::vector< std::string > *) 0 ;
  std::vector< std::string >::size_type arg2 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  size_t val2 ;
  int ecode2 = 0 ;
  PyObject *swig_obj[2] ;
  
  if (!SWIG_Python_UnpackTuple(args, "StringVector_reserve", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__vectorT_std__string_std__allocatorT_std__string_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "StringVector_reserve" "', argument " "1"" of type '" "std::vector< std::string > *""'"); 
  }
  arg1 = reinterpret_cast< std::vector< std::string > * >(argp1);
  ecode2 = SWIG_AsVal_size_t(swig_obj[1], &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "StringVector_reserve" "', argument " "2"" of type '" "std::vector< std::string >::size_type""'");
  } 
  arg2 = static_cast< std::vector< std::string >::size_type >(val2);
  (arg1)->reserve(arg2);
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_StringVector_capacity(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  std::vector< std::string > *arg1 = (std::vector< std::string > *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  std::vector< std::string >::size_type result;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__vectorT_std__string_std__allocatorT_std__string_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "StringVector_capacity" "', argument " "1"" of type '" "std::vector< std::string > const *""'"); 
  }
  arg1 = reinterpret_cast< std::vector< std::string > * >(argp1);
  result = ((std::vector< std::string > const *)arg1)->capacity();
  resultobj = SWIG_From_size_t(static_cast< size_t >(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_delete_StringVector(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  std::vector< std::string > *arg1 = (std::vector< std::string > *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__vectorT_std__string_std__allocatorT_std__string_t_t, SWIG_POINTER_DISOWN |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "delete_StringVector" "', argument " "1"" of type '" "std::vector< std::string > *""'"); 
  }
  arg1 = reinterpret_cast< std::vector< std::string > * >(argp1);
  delete arg1;
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *StringVector_swigregister(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *obj;
  if (!SWIG_Python_UnpackTuple(args, "swigregister", 1, 1, &obj)) return NULL;
  SWIG_TypeNewClientData(SWIGTYPE_p_std__vectorT_std__string_std__allocatorT_std__string_t_t, SWIG_NewClientData(obj));
  return SWIG_Py_Void();
}

SWIGINTERN PyObject *StringVector_swiginit(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  return SWIG_Python_InitShadowInstance(args);
}

SWIGINTERN PyObject *_wrap_IntVector_iterator(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  std::vector< int > *arg1 = (std::vector< int > *) 0 ;
  PyObject **arg2 = (PyObject **) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  swig::SwigPyIterator *result = 0 ;
  
  arg2 = &swig_obj[0];
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__vectorT_int_std__allocatorT_int_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "IntVector_iterator" "', argument " "1"" of type '" "std::vector< int > *""'"); 
  }
  arg1 = reinterpret_cast< std::vector< int > * >(argp1);
  result = (swig::SwigPyIterator *)std_vector_Sl_int_Sg__iterator(arg1,arg2);
  resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(result), SWIGTYPE_p_swig__SwigPyIterator, SWIG_POINTER_OWN |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_IntVector___nonzero__(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  std::vector< int > *arg1 = (std::vector< int > *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  bool result;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__vectorT_int_std__allocatorT_int_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "IntVector___nonzero__" "', argument " "1"" of type '" "std::vector< int > const *""'"); 
  }
  arg1 = reinterpret_cast< std::vector< int > * >(argp1);
  result = (bool)std_vector_Sl_int_Sg____nonzero__((std::vector< int > const *)arg1);
  resultobj = SWIG_From_bool(static_cast< bool >(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_IntVector___bool__(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  std::vector< int > *arg1 = (std::vector< int > *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  bool result;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__vectorT_int_std__allocatorT_int_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "IntVector___bool__" "', argument " "1"" of type '" "std::vector< int > const *""'"); 
  }
  arg1 = reinterpret_cast< std::vector< int > * >(argp1);
  result = (bool)std_vector_Sl_int_Sg____bool__((std::vector< int > const *)arg1);
  resultobj = SWIG_From_bool(static_cast< bool >(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_IntVector___len__(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  std::vector< int > *arg1 = (std::vector< int > *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  std::vector< int >::size_type result;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__vectorT_int_std__allocatorT_int_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "IntVector___len__" "', argument " "1"" of type '" "std::vector< int > const *""'"); 
  }
  arg1 = reinterpret_cast< std::vector< int > * >(argp1);
  result = std_vector_Sl_int_Sg____len__((std::vector< int > const *)arg1);
  resultobj = SWIG_From_size_t(static_cast< size_t >(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_IntVector___getslice__(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  std::vector< int > *arg1 = (std::vector< int > *) 0 ;
  std::vector< int >::difference_type arg2 ;
  std::vector< int >::difference_type arg3 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  ptrdiff_t val2 ;
  int ecode2 = 0 ;
  ptrdiff_t val3 ;
  int ecode3 = 0 ;
  PyObject *swig_obj[3] ;
  std::vector< int,std::allocator< int > > *result = 0 ;
  
  if (!SWIG_Python_UnpackTuple(args, "IntVector___getslice__", 3, 3, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__vectorT_int_std__allocatorT_int_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "IntVector___getslice__" "', argument " "1"" of type '" "std::vector< int > *""'"); 
  }
  arg1 = reinterpret_cast< std::vector< int > * >(argp1);
  ecode2 = SWIG_AsVal_ptrdiff_t(swig_obj[1], &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "IntVector___getslice__" "', argument " "2"" of type '" "std::vector< int >::difference_type""'");
  } 
  arg2 = static_cast< std::vector< int >::difference_type >(val2);
  ecode3 = SWIG_AsVal_ptrdiff_t(swig_obj[2], &val3);
  if (!SWIG_IsOK(ecode3)) {
    SWIG_exception_fail(SWIG_ArgError(ecode3), "in method '" "IntVector___getslice__" "', argument " "3"" of type '" "std::vector< int >::difference_type""'");
  } 
  arg3 = static_cast< std::vector< int >::difference_type >(val3);
  try {
    result = (std::vector< int,std::allocator< int > > *)std_vector_Sl_int_Sg____getslice__(arg1,arg2,arg3);
  } catch(std::out_of_range &_e) {
    SWIG_exception_fail(SWIG_IndexError, (&_e)->what());
  } catch(std::invalid_argument &_e) {
    SWIG_exception_fail(SWIG_ValueError, (&_e)->what());
  }
  resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(result), SWIGTYPE_p_std__vectorT_int_std__allocatorT_int_t_t, SWIG_POINTER_OWN |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_IntVector___setslice____SWIG_0(PyObject *SWIGUNUSEDPARM(self), Py_ssize_t nobjs, PyObject **swig_obj) {
  PyObject *resultobj = 0;
  std::vector< int > *arg1 = (std::vector< int > *) 0 ;
  std::vector< int >::difference_type arg2 ;
  std::vector< int >::difference_type arg3 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  ptrdiff_t val2 ;
  int ecode2 = 0 ;
  ptrdiff_t val3 ;
  int ecode3 = 0 ;
  
  if ((nobjs < 3) || (nobjs > 3)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__vectorT_int_std__allocatorT_int_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "IntVector___setslice__" "', argument " "1"" of type '" "std::vector< int > *""'"); 
  }
  arg1 = reinterpret_cast< std::vector< int > * >(argp1);
  ecode2 = SWIG_AsVal_ptrdiff_t(swig_obj[1], &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "IntVector___setslice__" "', argument " "2"" of type '" "std::vector< int >::difference_type""'");
  } 
  arg2 = static_cast< std::vector< int >::difference_type >(val2);
  ecode3 = SWIG_AsVal_ptrdiff_t(swig_obj[2], &val3);
  if (!SWIG_IsOK(ecode3)) {
    SWIG_exception_fail(SWIG_ArgError(ecode3), "in method '" "IntVector___setslice__" "', argument " "3"" of type '" "std::vector< int >::difference_type""'");
  } 
  arg3 = static_cast< std::vector< int >::difference_type >(val3);
  try {
    std_vector_Sl_int_Sg____setslice____SWIG_0(arg1,arg2,arg3);
  } catch(std::out_of_range &_e) {
    SWIG_exception_fail(SWIG_IndexError, (&_e)->what());
  } catch(std::invalid_argument &_e) {
    SWIG_exception_fail(SWIG_ValueError, (&_e)->what());
  }
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_IntVector___setslice____SWIG_1(PyObject *SWIGUNUSEDPARM(self), Py_ssize_t nobjs, PyObject **swig_obj) {
  PyObject *resultobj = 0;
  std::vector< int > *arg1 = (std::vector< int > *) 0 ;
  std::vector< int >::difference_type arg2 ;
  std::vector< int >::difference_type arg3 ;
  std::vector< int,std::allocator< int > > *arg4 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  ptrdiff_t val2 ;
  int ecode2 = 0 ;
  ptrdiff_t val3 ;
  int ecode3 = 0 ;
  int res4 = SWIG_OLDOBJ ;
  
  if ((nobjs < 4) || (nobjs > 4)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__vectorT_int_std__allocatorT_int_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "IntVector___setslice__" "', argument " "1"" of type '" "std::vector< int > *""'"); 
  }
  arg1 = reinterpret_cast< std::vector< int > * >(argp1);
  ecode2 = SWIG_AsVal_ptrdiff_t(swig_obj[1], &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "IntVector___setslice__" "', argument " "2"" of type '" "std::vector< int >::difference_type""'");
  } 
  arg2 = static_cast< std::vector< int >::difference_type >(val2);
  ecode3 = SWIG_AsVal_ptrdiff_t(swig_obj[2], &val3);
  if (!SWIG_IsOK(ecode3)) {
    SWIG_exception_fail(SWIG_ArgError(ecode3), "in method '" "IntVector___setslice__" "', argument " "3"" of type '" "std::vector< int >::difference_type""'");
  } 
  arg3 = static_cast< std::vector< int >::difference_type >(val3);
  {
    std::vector< int,std::allocator< int > > *ptr = (std::vector< int,std::allocator< int > > *)0;
    res4 = swig::asptr(swig_obj[3], &ptr);
    if (!SWIG_IsOK(res4)) {
      SWIG_exception_fail(SWIG_ArgError(res4), "in method '" "IntVector___setslice__" "', argument " "4"" of type '" "std::vector< int,std::allocator< int > > const &""'"); 
    }
    if (!ptr) {
      SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "IntVector___setslice__" "', argument " "4"" of type '" "std::vector< int,std::allocator< int > > const &""'"); 
    }
    arg4 = ptr;
  }
  try {
    std_vector_Sl_int_Sg____setslice____SWIG_1(arg1,arg2,arg3,(std::vector< int,std::allocator< int > > const &)*arg4);
  } catch(std::out_of_range &_e) {
    SWIG_exception_fail(SWIG_IndexError, (&_e)->what());
  } catch(std::invalid_argument &_e) {
    SWIG_exception_fail(SWIG_ValueError, (&_e)->what());
  }
  resultobj = SWIG_Py_Void();
  if (SWIG_IsNewObj(res4)) delete arg4;
  return resultobj;
fail:
  if (SWIG_IsNewObj(res4)) delete arg4;
  return NULL;
}


SWIGINTERN PyObject *_wrap_IntVector___setslice__(PyObject *self, PyObject *args) {
  Py_ssize_t argc;
  PyObject *argv[5] = {
    0
  };
  
  if (!(argc = SWIG_Python_UnpackTuple(args, "IntVector___setslice__", 0, 4, argv))) SWIG_fail;
  --argc;
  if (argc == 3) {
    int _v;
    int res = swig::asptr(argv[0], (std::vector< int,std::allocator< int > >**)(0));
    _v = SWIG_CheckState(res);
    if (_v) {
      {
        int res = SWIG_AsVal_ptrdiff_t(argv[1], NULL);
        _v = SWIG_CheckState(res);
      }
      if (_v) {
        {
          int res = SWIG_AsVal_ptrdiff_t(argv[2], NULL);
          _v = SWIG_CheckState(res);
        }
        if (_v) {
          return _wrap_IntVector___setslice____SWIG_0(self, argc, argv);
        }
      }
    }
  }
  if (argc == 4) {
    int _v;
    int res = swig::asptr(argv[0], (std::vector< int,std::allocator< int > >**)(0));
    _v = SWIG_CheckState(res);
    if (_v) {
      {
        int res = SWIG_AsVal_ptrdiff_t(argv[1], NULL);
        _v = SWIG_CheckState(res);
      }
      if (_v) {
        {
          int res = SWIG_AsVal_ptrdiff_t(argv[2], NULL);
          _v = SWIG_CheckState(res);
        }
        if (_v) {
          int res = swig::asptr(argv[3], (std::vector< int,std::allocator< int > >**)(0));
          _v = SWIG_CheckState(res);
          if (_v) {
            return _wrap_IntVector___setslice____SWIG_1(self, argc, argv);
          }
        }
      }
    }
  }
  
fail:
  SWIG_Python_RaiseOrModifyTypeError("Wrong number or type of arguments for overloaded function 'IntVector___setslice__'.\n"
    "  Possible C/C++ prototypes are:\n"
    "    std::vector< int >::__setslice__(std::vector< int >::difference_type,std::vector< int >::difference_type)\n"
    "    std::vector< int >::__setslice__(std::vector< int >::difference_type,std::vector< int >::difference_type,std::vector< int,std::allocator< int > > const &)\n");
  return 0;
}


SWIGINTERN PyObject *_wrap_IntVector___delslice__(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  std::vector< int > *arg1 = (std::vector< int > *) 0 ;
  std::vector< int >::difference_type arg2 ;
  std::vector< int >::difference_type arg3 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  ptrdiff_t val2 ;
  int ecode2 = 0 ;
  ptrdiff_t val3 ;
  int ecode3 = 0 ;
  PyObject *swig_obj[3] ;
  
  if (!SWIG_Python_UnpackTuple(args, "IntVector___delslice__", 3, 3, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__vectorT_int_std__allocatorT_int_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "IntVector___delslice__" "', argument " "1"" of type '" "std::vector< int > *""'"); 
  }
  arg1 = reinterpret_cast< std::vector< int > * >(argp1);
  ecode2 = SWIG_AsVal_ptrdiff_t(swig_obj[1], &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "IntVector___delslice__" "', argument " "2"" of type '" "std::vector< int >::difference_type""'");
  } 
  arg2 = static_cast< std::vector< int >::difference_type >(val2);
  ecode3 = SWIG_AsVal_ptrdiff_t(swig_obj[2], &val3);
  if (!SWIG_IsOK(ecode3)) {
    SWIG_exception_fail(SWIG_ArgError(ecode3), "in method '" "IntVector___delslice__" "', argument " "3"" of type '" "std::vector< int >::difference_type""'");
  } 
  arg3 = static_cast< std::vector< int >::difference_type >(val3);
  try {
    std_vector_Sl_int_Sg____delslice__(arg1,arg2,arg3);
  } catch(std::out_of_range &_e) {
    SWIG_exception_fail(SWIG_IndexError, (&_e)->what());
  } catch(std::invalid_argument &_e) {
    SWIG_exception_fail(SWIG_ValueError, (&_e)->what());
  }
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_IntVector___delitem____SWIG_0(PyObject *SWIGUNUSEDPARM(self), Py_ssize_t nobjs, PyObject **swig_obj) {
  PyObject *resultobj = 0;
  std::vector< int > *arg1 = (std::vector< int > *) 0 ;
  std::vector< int >::difference_type arg2 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  ptrdiff_t val2 ;
  int ecode2 = 0 ;
  
  if ((nobjs < 2) || (nobjs > 2)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__vectorT_int_std__allocatorT_int_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "IntVector___delitem__" "', argument " "1"" of type '" "std::vector< int > *""'"); 
  }
  arg1 = reinterpret_cast< std::vector< int > * >(argp1);
  ecode2 = SWIG_AsVal_ptrdiff_t(swig_obj[1], &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "IntVector___delitem__" "', argument " "2"" of type '" "std::vector< int >::difference_type""'");
  } 
  arg2 = static_cast< std::vector< int >::difference_type >(val2);
  try {
    std_vector_Sl_int_Sg____delitem____SWIG_0(arg1,arg2);
  } catch(std::out_of_range &_e) {
    SWIG_exception_fail(SWIG_IndexError, (&_e)->what());
  } catch(std::invalid_argument &_e) {
    SWIG_exception_fail(SWIG_ValueError, (&_e)->what());
  }
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_IntVector___getitem____SWIG_0(PyObject *SWIGUNUSEDPARM(self), Py_ssize_t nobjs, PyObject **swig_obj) {
  PyObject *resultobj = 0;
  std::vector< int > *arg1 = (std::vector< int > *) 0 ;
  PySliceObject *arg2 = (PySliceObject *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  std::vector< int,std::allocator< int > > *result = 0 ;
  
  if ((nobjs < 2) || (nobjs > 2)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__vectorT_int_std__allocatorT_int_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "IntVector___getitem__" "', argument " "1"" of type '" "std::vector< int > *""'"); 
  }
  arg1 = reinterpret_cast< std::vector< int > * >(argp1);
  {
    if (!PySlice_Check(swig_obj[1])) {
      SWIG_exception_fail(SWIG_ArgError(SWIG_TypeError), "in method '" "IntVector___getitem__" "', argument " "2"" of type '" "PySliceObject *""'");
    }
    arg2 = (PySliceObject *) swig_obj[1];
  }
  try {
    result = (std::vector< int,std::allocator< int > > *)std_vector_Sl_int_Sg____getitem____SWIG_0(arg1,arg2);
  } catch(std::out_of_range &_e) {
    SWIG_exception_fail(SWIG_IndexError, (&_e)->what());
  } catch(std::invalid_argument &_e) {
    SWIG_exception_fail(SWIG_ValueError, (&_e)->what());
  }
  resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(result), SWIGTYPE_p_std__vectorT_int_std__allocatorT_int_t_t, SWIG_POINTER_OWN |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_IntVector___setitem____SWIG_0(PyObject *SWIGUNUSEDPARM(self), Py_ssize_t nobjs, PyObject **swig_obj) {
  PyObject *resultobj = 0;
  std::vector< int > *arg1 = (std::vector< int > *) 0 ;
  PySliceObject *arg2 = (PySliceObject *) 0 ;
  std::vector< int,std::allocator< int > > *arg3 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  int res3 = SWIG_OLDOBJ ;
  
  if ((nobjs < 3) || (nobjs > 3)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__vectorT_int_std__allocatorT_int_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "IntVector___setitem__" "', argument " "1"" of type '" "std::vector< int > *""'"); 
  }
  arg1 = reinterpret_cast< std::vector< int > * >(argp1);
  {
    if (!PySlice_Check(swig_obj[1])) {
      SWIG_exception_fail(SWIG_ArgError(SWIG_TypeError), "in method '" "IntVector___setitem__" "', argument " "2"" of type '" "PySliceObject *""'");
    }
    arg2 = (PySliceObject *) swig_obj[1];
  }
  {
    std::vector< int,std::allocator< int > > *ptr = (std::vector< int,std::allocator< int > > *)0;
    res3 = swig::asptr(swig_obj[2], &ptr);
    if (!SWIG_IsOK(res3)) {
      SWIG_exception_fail(SWIG_ArgError(res3), "in method '" "IntVector___setitem__" "', argument " "3"" of type '" "std::vector< int,std::allocator< int > > const &""'"); 
    }
    if (!ptr) {
      SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "IntVector___setitem__" "', argument " "3"" of type '" "std::vector< int,std::allocator< int > > const &""'"); 
    }
    arg3 = ptr;
  }
  try {
    std_vector_Sl_int_Sg____setitem____SWIG_0(arg1,arg2,(std::vector< int,std::allocator< int > > const &)*arg3);
  } catch(std::out_of_range &_e) {
    SWIG_exception_fail(SWIG_IndexError, (&_e)->what());
  } catch(std::invalid_argument &_e) {
    SWIG_exception_fail(SWIG_ValueError, (&_e)->what());
  }
  resultobj = SWIG_Py_Void();
  if (SWIG_IsNewObj(res3)) delete arg3;
  return resultobj;
fail:
  if (SWIG_IsNewObj(res3)) delete arg3;
  return NULL;
}


SWIGINTERN PyObject *_wrap_IntVector___setitem____SWIG_1(PyObject *SWIGUNUSEDPARM(self), Py_ssize_t nobjs, PyObject **swig_obj) {
  PyObject *resultobj = 0;
  std::vector< int > *arg1 = (std::vector< int > *) 0 ;
  PySliceObject *arg2 = (PySliceObject *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  
  if ((nobjs < 2) || (nobjs > 2)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__vectorT_int_std__allocatorT_int_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "IntVector___setitem__" "', argument " "1"" of type '" "std::vector< int > *""'"); 
  }
  arg1 = reinterpret_cast< std::vector< int > * >(argp1);
  {
    if (!PySlice_Check(swig_obj[1])) {
      SWIG_exception_fail(SWIG_ArgError(SWIG_TypeError), "in method '" "IntVector___setitem__" "', argument " "2"" of type '" "PySliceObject *""'");
    }
    arg2 = (PySliceObject *) swig_obj[1];
  }
  try {
    std_vector_Sl_int_Sg____setitem____SWIG_1(arg1,arg2);
  } catch(std::out_of_range &_e) {
    SWIG_exception_fail(SWIG_IndexError, (&_e)->what());
  } catch(std::invalid_argument &_e) {
    SWIG_exception_fail(SWIG_ValueError, (&_e)->what());
  }
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_IntVector___delitem____SWIG_1(PyObject *SWIGUNUSEDPARM(self), Py_ssize_t nobjs, PyObject **swig_obj) {
  PyObject *resultobj = 0;
  std::vector< int > *arg1 = (std::vector< int > *) 0 ;
  PySliceObject *arg2 = (PySliceObject *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  
  if ((nobjs < 2) || (nobjs > 2)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__vectorT_int_std__allocatorT_int_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "IntVector___delitem__" "', argument " "1"" of type '" "std::vector< int > *""'"); 
  }
  arg1 = reinterpret_cast< std::vector< int > * >(argp1);
  {
    if (!PySlice_Check(swig_obj[1])) {
      SWIG_exception_fail(SWIG_ArgError(SWIG_TypeError), "in method '" "IntVector___delitem__" "', argument " "2"" of type '" "PySliceObject *""'");
    }
    arg2 = (PySliceObject *) swig_obj[1];
  }
  try {
    std_vector_Sl_int_Sg____delitem____SWIG_1(arg1,arg2);
  } catch(std::out_of_range &_e) {
    SWIG_exception_fail(SWIG_IndexError, (&_e)->what());
  } catch(std::invalid_argument &_e) {
    SWIG_exception_fail(SWIG_ValueError, (&_e)->what());
  }
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_IntVector___delitem__(PyObject *self, PyObject *args) {
  Py_ssize_t argc;
  PyObject *argv[3] = {
    0
  };
  
  if (!(argc = SWIG_Python_UnpackTuple(args, "IntVector___delitem__", 0, 2, argv))) SWIG_fail;
  --argc;
  if (argc == 2) {
    int _v;
    int res = swig::asptr(argv[0], (std::vector< int,std::allocator< int > >**)(0));
    _v = SWIG_CheckState(res);
    if (_v) {
      {
        _v = PySlice_Check(argv[1]);
      }
      if (_v) {
        return _wrap_IntVector___delitem____SWIG_1(self, argc, argv);
      }
    }
  }
  if (argc == 2) {
    int _v;
    int res = swig::asptr(argv[0], (std::vector< int,std::allocator< int > >**)(0));
    _v = SWIG_CheckState(res);
    if (_v) {
      {
        int res = SWIG_AsVal_ptrdiff_t(argv[1], NULL);
        _v = SWIG_CheckState(res);
      }
      if (_v) {
        return _wrap_IntVector___delitem____SWIG_0(self, argc, argv);
      }
    }
  }
  
fail:
  SWIG_Python_RaiseOrModifyTypeError("Wrong number or type of arguments for overloaded function 'IntVector___delitem__'.\n"
    "  Possible C/C++ prototypes are:\n"
    "    std::vector< int >::__delitem__(std::vector< int >::difference_type)\n"
    "    std::vector< int >::__delitem__(PySliceObject *)\n");
  return 0;
}


SWIGINTERN PyObject *_wrap_IntVector___getitem____SWIG_1(PyObject *SWIGUNUSEDPARM(self), Py_ssize_t nobjs, PyObject **swig_obj) {
  PyObject *resultobj = 0;
  std::vector< int > *arg1 = (std::vector< int > *) 0 ;
  std::vector< int >::difference_type arg2 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  ptrdiff_t val2 ;
  int ecode2 = 0 ;
  std::vector< int >::value_type *result = 0 ;
  
  if ((nobjs < 2) || (nobjs > 2)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__vectorT_int_std__allocatorT_int_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "IntVector___getitem__" "', argument " "1"" of type '" "std::vector< int > const *""'"); 
  }
  arg1 = reinterpret_cast< std::vector< int > * >(argp1);
  ecode2 = SWIG_AsVal_ptrdiff_t(swig_obj[1], &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "IntVector___getitem__" "', argument " "2"" of type '" "std::vector< int >::difference_type""'");
  } 
  arg2 = static_cast< std::vector< int >::difference_type >(val2);
  try {
    result = (std::vector< int >::value_type *) &std_vector_Sl_int_Sg____getitem____SWIG_1((std::vector< int > const *)arg1,arg2);
  } catch(std::out_of_range &_e) {
    SWIG_exception_fail(SWIG_IndexError, (&_e)->what());
  }
  resultobj = SWIG_From_int(static_cast< int >(*result));
  (void)swig::container_owner<swig::traits<std::vector< int >::value_type>::category>::back_reference(resultobj, swig_obj[0]);
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_IntVector___getitem__(PyObject *self, PyObject *args) {
  Py_ssize_t argc;
  PyObject *argv[3] = {
    0
  };
  
  if (!(argc = SWIG_Python_UnpackTuple(args, "IntVector___getitem__", 0, 2, argv))) SWIG_fail;
  --argc;
  if (argc == 2) {
    int _v;
    int res = swig::asptr(argv[0], (std::vector< int,std::allocator< int > >**)(0));
    _v = SWIG_CheckState(res);
    if (_v) {
      {
        _v = PySlice_Check(argv[1]);
      }
      if (_v) {
        return _wrap_IntVector___getitem____SWIG_0(self, argc, argv);
      }
    }
  }
  if (argc == 2) {
    int _v;
    int res = swig::asptr(argv[0], (std::vector< int,std::allocator< int > >**)(0));
    _v = SWIG_CheckState(res);
    if (_v) {
      {
        int res = SWIG_AsVal_ptrdiff_t(argv[1], NULL);
        _v = SWIG_CheckState(res);
      }
      if (_v) {
        return _wrap_IntVector___getitem____SWIG_1(self, argc, argv);
      }
    }
  }
  
fail:
  SWIG_Python_RaiseOrModifyTypeError("Wrong number or type of arguments for overloaded function 'IntVector___getitem__'.\n"
    "  Possible C/C++ prototypes are:\n"
    "    std::vector< int >::__getitem__(PySliceObject *)\n"
    "    std::vector< int >::__getitem__(std::vector< int >::difference_type) const\n");
  return 0;
}


SWIGINTERN PyObject *_wrap_IntVector___setitem____SWIG_2(PyObject *SWIGUNUSEDPARM(self), Py_ssize_t nobjs, PyObject **swig_obj) {
  PyObject *resultobj = 0;
  std::vector< int > *arg1 = (std::vector< int > *) 0 ;
  std::vector< int >::difference_type arg2 ;
  std::vector< int >::value_type *arg3 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  ptrdiff_t val2 ;
  int ecode2 = 0 ;
  std::vector< int >::value_type temp3 ;
  int val3 ;
  int ecode3 = 0 ;
  
  if ((nobjs < 3) || (nobjs > 3)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__vectorT_int_std__allocatorT_int_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "IntVector___setitem__" "', argument " "1"" of type '" "std::vector< int > *""'"); 
  }
  arg1 = reinterpret_cast< std::vector< int > * >(argp1);
  ecode2 = SWIG_AsVal_ptrdiff_t(swig_obj[1], &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "IntVector___setitem__" "', argument " "2"" of type '" "std::vector< int >::difference_type""'");
  } 
  arg2 = static_cast< std::vector< int >::difference_type >(val2);
  ecode3 = SWIG_AsVal_int(swig_obj[2], &val3);
  if (!SWIG_IsOK(ecode3)) {
    SWIG_exception_fail(SWIG_ArgError(ecode3), "in method '" "IntVector___setitem__" "', argument " "3"" of type '" "std::vector< int >::value_type""'");
  } 
  temp3 = static_cast< std::vector< int >::value_type >(val3);
  arg3 = &temp3;
  try {
    std_vector_Sl_int_Sg____setitem____SWIG_2(arg1,arg2,(int const &)*arg3);
  } catch(std::out_of_range &_e) {
    SWIG_exception_fail(SWIG_IndexError, (&_e)->what());
  }
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_IntVector___setitem__(PyObject *self, PyObject *args) {
  Py_ssize_t argc;
  PyObject *argv[4] = {
    0
  };
  
  if (!(argc = SWIG_Python_UnpackTuple(args, "IntVector___setitem__", 0, 3, argv))) SWIG_fail;
  --argc;
  if (argc == 2) {
    int _v;
    int res = swig::asptr(argv[0], (std::vector< int,std::allocator< int > >**)(0));
    _v = SWIG_CheckState(res);
    if (_v) {
      {
        _v = PySlice_Check(argv[1]);
      }
      if (_v) {
        return _wrap_IntVector___setitem____SWIG_1(self, argc, argv);
      }
    }
  }
  if (argc == 3) {
    int _v;
    int res = swig::asptr(argv[0], (std::vector< int,std::allocator< int > >**)(0));
    _v = SWIG_CheckState(res);
    if (_v) {
      {
        _v = PySlice_Check(argv[1]);
      }
      if (_v) {
        int res = swig::asptr(argv[2], (std::vector< int,std::allocator< int > >**)(0));
        _v = SWIG_CheckState(res);
        if (_v) {
          return _wrap_IntVector___setitem____SWIG_0(self, argc, argv);
        }
      }
    }
  }
  if (argc == 3) {
    int _v;
    int res = swig::asptr(argv[0], (std::vector< int,std::allocator< int > >**)(0));
    _v = SWIG_CheckState(res);
    if (_v) {
      {
        int res = SWIG_AsVal_ptrdiff_t(argv[1], NULL);
        _v = SWIG_CheckState(res);
      }
      if (_v) {
        {
          int res = SWIG_AsVal_int(argv[2], NULL);
          _v = SWIG_CheckState(res);
        }
        if (_v) {
          return _wrap_IntVector___setitem____SWIG_2(self, argc, argv);
        }
      }
    }
  }
  
fail:
  SWIG_Python_RaiseOrModifyTypeError("Wrong number or type of arguments for overloaded function 'IntVector___setitem__'.\n"
    "  Possible C/C++ prototypes are:\n"
    "    std::vector< int >::__setitem__(PySliceObject *,std::vector< int,std::allocator< int > > const &)\n"
    "    std::vector< int >::__setitem__(PySliceObject *)\n"
    "    std::vector< int >::__setitem__(std::vector< int >::difference_type,std::vector< int >::value_type const &)\n");
  return 0;
}


SWIGINTERN PyObject *_wrap_IntVector_pop(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  std::vector< int > *arg1 = (std::vector< int > *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  std::vector< int >::value_type result;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__vectorT_int_std__allocatorT_int_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "IntVector_pop" "', argument " "1"" of type '" "std::vector< int > *""'"); 
  }
  arg1 = reinterpret_cast< std::vector< int > * >(argp1);
  try {
    result = (std::vector< int >::value_type)std_vector_Sl_int_Sg__pop(arg1);
  } catch(std::out_of_range &_e) {
    SWIG_exception_fail(SWIG_IndexError, (&_e)->what());
  }
  resultobj = SWIG_From_int(static_cast< int >(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_IntVector_append(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  std::vector< int > *arg1 = (std::vector< int > *) 0 ;
  std::vector< int >::value_type *arg2 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  std::vector< int >::value_type temp2 ;
  int val2 ;
  int ecode2 = 0 ;
  PyObject *swig_obj[2] ;
  
  if (!SWIG_Python_UnpackTuple(args, "IntVector_append", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__vectorT_int_std__allocatorT_int_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "IntVector_append" "', argument " "1"" of type '" "std::vector< int > *""'"); 
  }
  arg1 = reinterpret_cast< std::vector< int > * >(argp1);
  ecode2 = SWIG_AsVal_int(swig_obj[1], &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "IntVector_append" "', argument " "2"" of type '" "std::vector< int >::value_type""'");
  } 
  temp2 = static_cast< std::vector< int >::value_type >(val2);
  arg2 = &temp2;
  std_vector_Sl_int_Sg__append(arg1,(int const &)*arg2);
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_new_IntVector__SWIG_0(PyObject *SWIGUNUSEDPARM(self), Py_ssize_t nobjs, PyObject **SWIGUNUSEDPARM(swig_obj)) {
  PyObject *resultobj = 0;
  std::vector< int > *result = 0 ;
  
  if ((nobjs < 0) || (nobjs > 0)) SWIG_fail;
  result = (std::vector< int > *)new std::vector< int >();
  resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(result), SWIGTYPE_p_std__vectorT_int_std__allocatorT_int_t_t, SWIG_POINTER_NEW |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_new_IntVector__SWIG_1(PyObject *SWIGUNUSEDPARM(self), Py_ssize_t nobjs, PyObject **swig_obj) {
  PyObject *resultobj = 0;
  std::vector< int > *arg1 = 0 ;
  int res1 = SWIG_OLDOBJ ;
  std::vector< int > *result = 0 ;
  
  if ((nobjs < 1) || (nobjs > 1)) SWIG_fail;
  {
    std::vector< int,std::allocator< int > > *ptr = (std::vector< int,std::allocator< int > > *)0;
    res1 = swig::asptr(swig_obj[0], &ptr);
    if (!SWIG_IsOK(res1)) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "new_IntVector" "', argument " "1"" of type '" "std::vector< int > const &""'"); 
    }
    if (!ptr) {
      SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "new_IntVector" "', argument " "1"" of type '" "std::vector< int > const &""'"); 
    }
    arg1 = ptr;
  }
  result = (std::vector< int > *)new std::vector< int >((std::vector< int > const &)*arg1);
  resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(result), SWIGTYPE_p_std__vectorT_int_std__allocatorT_int_t_t, SWIG_POINTER_NEW |  0 );
  if (SWIG_IsNewObj(res1)) delete arg1;
  return resultobj;
fail:
  if (SWIG_IsNewObj(res1)) delete arg1;
  return NULL;
}


SWIGINTERN PyObject *_wrap_IntVector_empty(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  std::vector< int > *arg1 = (std::vector< int > *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  bool result;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__vectorT_int_std__allocatorT_int_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "IntVector_empty" "', argument " "1"" of type '" "std::vector< int > const *""'"); 
  }
  arg1 = reinterpret_cast< std::vector< int > * >(argp1);
  result = (bool)((std::vector< int > const *)arg1)->empty();
  resultobj = SWIG_From_bool(static_cast< bool >(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_IntVector_size(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  std::vector< int > *arg1 = (std::vector< int > *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  std::vector< int >::size_type result;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__vectorT_int_std__allocatorT_int_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "IntVector_size" "', argument " "1"" of type '" "std::vector< int > const *""'"); 
  }
  arg1 = reinterpret_cast< std::vector< int > * >(argp1);
  result = ((std::vector< int > const *)arg1)->size();
  resultobj = SWIG_From_size_t(static_cast< size_t >(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_IntVector_swap(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  std::vector< int > *arg1 = (std::vector< int > *) 0 ;
  std::vector< int > *arg2 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  void *argp2 = 0 ;
  int res2 = 0 ;
  PyObject *swig_obj[2] ;
  
  if (!SWIG_Python_UnpackTuple(args, "IntVector_swap", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__vectorT_int_std__allocatorT_int_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "IntVector_swap" "', argument " "1"" of type '" "std::vector< int > *""'"); 
  }
  arg1 = reinterpret_cast< std::vector< int > * >(argp1);
  res2 = SWIG_ConvertPtr(swig_obj[1], &argp2, SWIGTYPE_p_std__vectorT_int_std__allocatorT_int_t_t,  0 );
  if (!SWIG_IsOK(res2)) {
    SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "IntVector_swap" "', argument " "2"" of type '" "std::vector< int > &""'"); 
  }
  if (!argp2) {
    SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "IntVector_swap" "', argument " "2"" of type '" "std::vector< int > &""'"); 
  }
  arg2 = reinterpret_cast< std::vector< int > * >(argp2);
  (arg1)->swap(*arg2);
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_IntVector_begin(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  std::vector< int > *arg1 = (std::vector< int > *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  std::vector< int >::iterator result;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__vectorT_int_std__allocatorT_int_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "IntVector_begin" "', argument " "1"" of type '" "std::vector< int > *""'"); 
  }
  arg1 = reinterpret_cast< std::vector< int > * >(argp1);
  result = (arg1)->begin();
  resultobj = SWIG_NewPointerObj(swig::make_output_iterator(static_cast< const std::vector< int >::iterator & >(result)),
    swig::SwigPyIterator::descriptor(),SWIG_POINTER_OWN);
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_IntVector_end(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  std::vector< int > *arg1 = (std::vector< int > *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  std::vector< int >::iterator result;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__vectorT_int_std__allocatorT_int_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "IntVector_end" "', argument " "1"" of type '" "std::vector< int > *""'"); 
  }
  arg1 = reinterpret_cast< std::vector< int > * >(argp1);
  result = (arg1)->end();
  resultobj = SWIG_NewPointerObj(swig::make_output_iterator(static_cast< const std::vector< int >::iterator & >(result)),
    swig::SwigPyIterator::descriptor(),SWIG_POINTER_OWN);
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_IntVector_rbegin(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  std::vector< int > *arg1 = (std::vector< int > *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  std::vector< int >::reverse_iterator result;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__vectorT_int_std__allocatorT_int_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "IntVector_rbegin" "', argument " "1"" of type '" "std::vector< int > *""'"); 
  }
  arg1 = reinterpret_cast< std::vector< int > * >(argp1);
  result = (arg1)->rbegin();
  resultobj = SWIG_NewPointerObj(swig::make_output_iterator(static_cast< const std::vector< int >::reverse_iterator & >(result)),
    swig::SwigPyIterator::descriptor(),SWIG_POINTER_OWN);
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_IntVector_rend(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  std::vector< int > *arg1 = (std::vector< int > *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  std::vector< int >::reverse_iterator result;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__vectorT_int_std__allocatorT_int_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "IntVector_rend" "', argument " "1"" of type '" "std::vector< int > *""'"); 
  }
  arg1 = reinterpret_cast< std::vector< int > * >(argp1);
  result = (arg1)->rend();
  resultobj = SWIG_NewPointerObj(swig::make_output_iterator(static_cast< const std::vector< int >::reverse_iterator & >(result)),
    swig::SwigPyIterator::descriptor(),SWIG_POINTER_OWN);
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_IntVector_clear(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  std::vector< int > *arg1 = (std::vector< int > *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__vectorT_int_std__allocatorT_int_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "IntVector_clear" "', argument " "1"" of type '" "std::vector< int > *""'"); 
  }
  arg1 = reinterpret_cast< std::vector< int > * >(argp1);
  (arg1)->clear();
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_IntVector_get_allocator(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  std::vector< int > *arg1 = (std::vector< int > *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  SwigValueWrapper< std::allocator< int > > result;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__vectorT_int_std__allocatorT_int_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "IntVector_get_allocator" "', argument " "1"" of type '" "std::vector< int > const *""'"); 
  }
  arg1 = reinterpret_cast< std::vector< int > * >(argp1);
  result = ((std::vector< int > const *)arg1)->get_allocator();
  resultobj = SWIG_NewPointerObj((new std::vector< int >::allocator_type(static_cast< const std::vector< int >::allocator_type& >(result))), SWIGTYPE_p_std__allocatorT_int_t, SWIG_POINTER_OWN |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_new_IntVector__SWIG_2(PyObject *SWIGUNUSEDPARM(self), Py_ssize_t nobjs, PyObject **swig_obj) {
  PyObject *resultobj = 0;
  std::vector< int >::size_type arg1 ;
  size_t val1 ;
  int ecode1 = 0 ;
  std::vector< int > *result = 0 ;
  
  if ((nobjs < 1) || (nobjs > 1)) SWIG_fail;
  ecode1 = SWIG_AsVal_size_t(swig_obj[0], &val1);
  if (!SWIG_IsOK(ecode1)) {
    SWIG_exception_fail(SWIG_ArgError(ecode1), "in method '" "new_IntVector" "', argument " "1"" of type '" "std::vector< int >::size_type""'");
  } 
  arg1 = static_cast< std::vector< int >::size_type >(val1);
  result = (std::vector< int > *)new std::vector< int >(arg1);
  resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(result), SWIGTYPE_p_std__vectorT_int_std__allocatorT_int_t_t, SWIG_POINTER_NEW |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_IntVector_pop_back(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  std::vector< int > *arg1 = (std::vector< int > *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__vectorT_int_std__allocatorT_int_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "IntVector_pop_back" "', argument " "1"" of type '" "std::vector< int > *""'"); 
  }
  arg1 = reinterpret_cast< std::vector< int > * >(argp1);
  (arg1)->pop_back();
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_IntVector_resize__SWIG_0(PyObject *SWIGUNUSEDPARM(self), Py_ssize_t nobjs, PyObject **swig_obj) {
  PyObject *resultobj = 0;
  std::vector< int > *arg1 = (std::vector< int > *) 0 ;
  std::vector< int >::size_type arg2 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  size_t val2 ;
  int ecode2 = 0 ;
  
  if ((nobjs < 2) || (nobjs > 2)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__vectorT_int_std__allocatorT_int_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "IntVector_resize" "', argument " "1"" of type '" "std::vector< int > *""'"); 
  }
  arg1 = reinterpret_cast< std::vector< int > * >(argp1);
  ecode2 = SWIG_AsVal_size_t(swig_obj[1], &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "IntVector_resize" "', argument " "2"" of type '" "std::vector< int >::size_type""'");
  } 
  arg2 = static_cast< std::vector< int >::size_type >(val2);
  (arg1)->resize(arg2);
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_IntVector_erase__SWIG_0(PyObject *SWIGUNUSEDPARM(self), Py_ssize_t nobjs, PyObject **swig_obj) {
  PyObject *resultobj = 0;
  std::vector< int > *arg1 = (std::vector< int > *) 0 ;
  std::vector< int >::iterator arg2 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  swig::SwigPyIterator *iter2 = 0 ;
  int res2 ;
  std::vector< int >::iterator result;
  
  if ((nobjs < 2) || (nobjs > 2)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__vectorT_int_std__allocatorT_int_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "IntVector_erase" "', argument " "1"" of type '" "std::vector< int > *""'"); 
  }
  arg1 = reinterpret_cast< std::vector< int > * >(argp1);
  res2 = SWIG_ConvertPtr(swig_obj[1], SWIG_as_voidptrptr(&iter2), swig::SwigPyIterator::descriptor(), 0);
  if (!SWIG_IsOK(res2) || !iter2) {
    SWIG_exception_fail(SWIG_ArgError(SWIG_TypeError), "in method '" "IntVector_erase" "', argument " "2"" of type '" "std::vector< int >::iterator""'");
  } else {
    swig::SwigPyIterator_T<std::vector< int >::iterator > *iter_t = dynamic_cast<swig::SwigPyIterator_T<std::vector< int >::iterator > *>(iter2);
    if (iter_t) {
      arg2 = iter_t->get_current();
    } else {
      SWIG_exception_fail(SWIG_ArgError(SWIG_TypeError), "in method '" "IntVector_erase" "', argument " "2"" of type '" "std::vector< int >::iterator""'");
    }
  }
  result = std_vector_Sl_int_Sg__erase__SWIG_0(arg1,arg2);
  resultobj = SWIG_NewPointerObj(swig::make_output_iterator(static_cast< const std::vector< int >::iterator & >(result)),
    swig::SwigPyIterator::descriptor(),SWIG_POINTER_OWN);
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_IntVector_erase__SWIG_1(PyObject *SWIGUNUSEDPARM(self), Py_ssize_t nobjs, PyObject **swig_obj) {
  PyObject *resultobj = 0;
  std::vector< int > *arg1 = (std::vector< int > *) 0 ;
  std::vector< int >::iterator arg2 ;
  std::vector< int >::iterator arg3 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  swig::SwigPyIterator *iter2 = 0 ;
  int res2 ;
  swig::SwigPyIterator *iter3 = 0 ;
  int res3 ;
  std::vector< int >::iterator result;
  
  if ((nobjs < 3) || (nobjs > 3)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__vectorT_int_std__allocatorT_int_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "IntVector_erase" "', argument " "1"" of type '" "std::vector< int > *""'"); 
  }
  arg1 = reinterpret_cast< std::vector< int > * >(argp1);
  res2 = SWIG_ConvertPtr(swig_obj[1], SWIG_as_voidptrptr(&iter2), swig::SwigPyIterator::descriptor(), 0);
  if (!SWIG_IsOK(res2) || !iter2) {
    SWIG_exception_fail(SWIG_ArgError(SWIG_TypeError), "in method '" "IntVector_erase" "', argument " "2"" of type '" "std::vector< int >::iterator""'");
  } else {
    swig::SwigPyIterator_T<std::vector< int >::iterator > *iter_t = dynamic_cast<swig::SwigPyIterator_T<std::vector< int >::iterator > *>(iter2);
    if (iter_t) {
      arg2 = iter_t->get_current();
    } else {
      SWIG_exception_fail(SWIG_ArgError(SWIG_TypeError), "in method '" "IntVector_erase" "', argument " "2"" of type '" "std::vector< int >::iterator""'");
    }
  }
  res3 = SWIG_ConvertPtr(swig_obj[2], SWIG_as_voidptrptr(&iter3), swig::SwigPyIterator::descriptor(), 0);
  if (!SWIG_IsOK(res3) || !iter3) {
    SWIG_exception_fail(SWIG_ArgError(SWIG_TypeError), "in method '" "IntVector_erase" "', argument " "3"" of type '" "std::vector< int >::iterator""'");
  } else {
    swig::SwigPyIterator_T<std::vector< int >::iterator > *iter_t = dynamic_cast<swig::SwigPyIterator_T<std::vector< int >::iterator > *>(iter3);
    if (iter_t) {
      arg3 = iter_t->get_current();
    } else {
      SWIG_exception_fail(SWIG_ArgError(SWIG_TypeError), "in method '" "IntVector_erase" "', argument " "3"" of type '" "std::vector< int >::iterator""'");
    }
  }
  result = std_vector_Sl_int_Sg__erase__SWIG_1(arg1,arg2,arg3);
  resultobj = SWIG_NewPointerObj(swig::make_output_iterator(static_cast< const std::vector< int >::iterator & >(result)),
    swig::SwigPyIterator::descriptor(),SWIG_POINTER_OWN);
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_IntVector_erase(PyObject *self, PyObject *args) {
  Py_ssize_t argc;
  PyObject *argv[4] = {
    0
  };
  
  if (!(argc = SWIG_Python_UnpackTuple(args, "IntVector_erase", 0, 3, argv))) SWIG_fail;
  --argc;
  if (argc == 2) {
    int _v;
    int res = swig::asptr(argv[0], (std::vector< int,std::allocator< int > >**)(0));
    _v = SWIG_CheckState(res);
    if (_v) {
      swig::SwigPyIterator *iter = 0;
      int res = SWIG_ConvertPtr(argv[1], SWIG_as_voidptrptr(&iter), swig::SwigPyIterator::descriptor(), 0);
      _v = (SWIG_IsOK(res) && iter && (dynamic_cast<swig::SwigPyIterator_T<std::vector< int >::iterator > *>(iter) != 0));
      if (_v) {
        return _wrap_IntVector_erase__SWIG_0(self, argc, argv);
      }
    }
  }
  if (argc == 3) {
    int _v;
    int res = swig::asptr(argv[0], (std::vector< int,std::allocator< int > >**)(0));
    _v = SWIG_CheckState(res);
    if (_v) {
      swig::SwigPyIterator *iter = 0;
      int res = SWIG_ConvertPtr(argv[1], SWIG_as_voidptrptr(&iter), swig::SwigPyIterator::descriptor(), 0);
      _v = (SWIG_IsOK(res) && iter && (dynamic_cast<swig::SwigPyIterator_T<std::vector< int >::iterator > *>(iter) != 0));
      if (_v) {
        swig::SwigPyIterator *iter = 0;
        int res = SWIG_ConvertPtr(argv[2], SWIG_as_voidptrptr(&iter), swig::SwigPyIterator::descriptor(), 0);
        _v = (SWIG_IsOK(res) && iter && (dynamic_cast<swig::SwigPyIterator_T<std::vector< int >::iterator > *>(iter) != 0));
        if (_v) {
          return _wrap_IntVector_erase__SWIG_1(self, argc, argv);
        }
      }
    }
  }
  
fail:
  SWIG_Python_RaiseOrModifyTypeError("Wrong number or type of arguments for overloaded function 'IntVector_erase'.\n"
    "  Possible C/C++ prototypes are:\n"
    "    std::vector< int >::erase(std::vector< int >::iterator)\n"
    "    std::vector< int >::erase(std::vector< int >::iterator,std::vector< int >::iterator)\n");
  return 0;
}


SWIGINTERN PyObject *_wrap_new_IntVector__SWIG_3(PyObject *SWIGUNUSEDPARM(self), Py_ssize_t nobjs, PyObject **swig_obj) {
  PyObject *resultobj = 0;
  std::vector< int >::size_type arg1 ;
  std::vector< int >::value_type *arg2 = 0 ;
  size_t val1 ;
  int ecode1 = 0 ;
  std::vector< int >::value_type temp2 ;
  int val2 ;
  int ecode2 = 0 ;
  std::vector< int > *result = 0 ;
  
  if ((nobjs < 2) || (nobjs > 2)) SWIG_fail;
  ecode1 = SWIG_AsVal_size_t(swig_obj[0], &val1);
  if (!SWIG_IsOK(ecode1)) {
    SWIG_exception_fail(SWIG_ArgError(ecode1), "in method '" "new_IntVector" "', argument " "1"" of type '" "std::vector< int >::size_type""'");
  } 
  arg1 = static_cast< std::vector< int >::size_type >(val1);
  ecode2 = SWIG_AsVal_int(swig_obj[1], &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "new_IntVector" "', argument " "2"" of type '" "std::vector< int >::value_type""'");
  } 
  temp2 = static_cast< std::vector< int >::value_type >(val2);
  arg2 = &temp2;
  result = (std::vector< int > *)new std::vector< int >(arg1,(std::vector< int >::value_type const &)*arg2);
  resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(result), SWIGTYPE_p_std__vectorT_int_std__allocatorT_int_t_t, SWIG_POINTER_NEW |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_new_IntVector(PyObject *self, PyObject *args) {
  Py_ssize_t argc;
  PyObject *argv[3] = {
    0
  };
  
  if (!(argc = SWIG_Python_UnpackTuple(args, "new_IntVector", 0, 2, argv))) SWIG_fail;
  --argc;
  if (argc == 0) {
    return _wrap_new_IntVector__SWIG_0(self, argc, argv);
  }
  if (argc == 1) {
    int _v;
    {
      int res = SWIG_AsVal_size_t(argv[0], NULL);
      _v = SWIG_CheckState(res);
    }
    if (_v) {
      return _wrap_new_IntVector__SWIG_2(self, argc, argv);
    }
  }
  if (argc == 1) {
    int _v;
    int res = swig::asptr(argv[0], (std::vector< int,std::allocator< int > >**)(0));
    _v = SWIG_CheckState(res);
    if (_v) {
      return _wrap_new_IntVector__SWIG_1(self, argc, argv);
    }
  }
  if (argc == 2) {
    int _v;
    {
      int res = SWIG_AsVal_size_t(argv[0], NULL);
      _v = SWIG_CheckState(res);
    }
    if (_v) {
      {
        int res = SWIG_AsVal_int(argv[1], NULL);
        _v = SWIG_CheckState(res);
      }
      if (_v) {
        return _wrap_new_IntVector__SWIG_3(self, argc, argv);
      }
    }
  }
  
fail:
  SWIG_Python_RaiseOrModifyTypeError("Wrong number or type of arguments for overloaded function 'new_IntVector'.\n"
    "  Possible C/C++ prototypes are:\n"
    "    std::vector< int >::vector()\n"
    "    std::vector< int >::vector(std::vector< int > const &)\n"
    "    std::vector< int >::vector(std::vector< int >::size_type)\n"
    "    std::vector< int >::vector(std::vector< int >::size_type,std::vector< int >::value_type const &)\n");
  return 0;
}


SWIGINTERN PyObject *_wrap_IntVector_push_back(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  std::vector< int > *arg1 = (std::vector< int > *) 0 ;
  std::vector< int >::value_type *arg2 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  std::vector< int >::value_type temp2 ;
  int val2 ;
  int ecode2 = 0 ;
  PyObject *swig_obj[2] ;
  
  if (!SWIG_Python_UnpackTuple(args, "IntVector_push_back", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__vectorT_int_std__allocatorT_int_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "IntVector_push_back" "', argument " "1"" of type '" "std::vector< int > *""'"); 
  }
  arg1 = reinterpret_cast< std::vector< int > * >(argp1);
  ecode2 = SWIG_AsVal_int(swig_obj[1], &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "IntVector_push_back" "', argument " "2"" of type '" "std::vector< int >::value_type""'");
  } 
  temp2 = static_cast< std::vector< int >::value_type >(val2);
  arg2 = &temp2;
  (arg1)->push_back((std::vector< int >::value_type const &)*arg2);
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_IntVector_front(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  std::vector< int > *arg1 = (std::vector< int > *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  std::vector< int >::value_type *result = 0 ;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__vectorT_int_std__allocatorT_int_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "IntVector_front" "', argument " "1"" of type '" "std::vector< int > const *""'"); 
  }
  arg1 = reinterpret_cast< std::vector< int > * >(argp1);
  result = (std::vector< int >::value_type *) &((std::vector< int > const *)arg1)->front();
  resultobj = SWIG_From_int(static_cast< int >(*result));
  (void)swig::container_owner<swig::traits<std::vector< int >::value_type>::category>::back_reference(resultobj, swig_obj[0]);
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_IntVector_back(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  std::vector< int > *arg1 = (std::vector< int > *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  std::vector< int >::value_type *result = 0 ;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__vectorT_int_std__allocatorT_int_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "IntVector_back" "', argument " "1"" of type '" "std::vector< int > const *""'"); 
  }
  arg1 = reinterpret_cast< std::vector< int > * >(argp1);
  result = (std::vector< int >::value_type *) &((std::vector< int > const *)arg1)->back();
  resultobj = SWIG_From_int(static_cast< int >(*result));
  (void)swig::container_owner<swig::traits<std::vector< int >::value_type>::category>::back_reference(resultobj, swig_obj[0]);
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_IntVector_assign(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  std::vector< int > *arg1 = (std::vector< int > *) 0 ;
  std::vector< int >::size_type arg2 ;
  std::vector< int >::value_type *arg3 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  size_t val2 ;
  int ecode2 = 0 ;
  std::vector< int >::value_type temp3 ;
  int val3 ;
  int ecode3 = 0 ;
  PyObject *swig_obj[3] ;
  
  if (!SWIG_Python_UnpackTuple(args, "IntVector_assign", 3, 3, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__vectorT_int_std__allocatorT_int_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "IntVector_assign" "', argument " "1"" of type '" "std::vector< int > *""'"); 
  }
  arg1 = reinterpret_cast< std::vector< int > * >(argp1);
  ecode2 = SWIG_AsVal_size_t(swig_obj[1], &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "IntVector_assign" "', argument " "2"" of type '" "std::vector< int >::size_type""'");
  } 
  arg2 = static_cast< std::vector< int >::size_type >(val2);
  ecode3 = SWIG_AsVal_int(swig_obj[2], &val3);
  if (!SWIG_IsOK(ecode3)) {
    SWIG_exception_fail(SWIG_ArgError(ecode3), "in method '" "IntVector_assign" "', argument " "3"" of type '" "std::vector< int >::value_type""'");
  } 
  temp3 = static_cast< std::vector< int >::value_type >(val3);
  arg3 = &temp3;
  (arg1)->assign(arg2,(std::vector< int >::value_type const &)*arg3);
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_IntVector_resize__SWIG_1(PyObject *SWIGUNUSEDPARM(self), Py_ssize_t nobjs, PyObject **swig_obj) {
  PyObject *resultobj = 0;
  std::vector< int > *arg1 = (std::vector< int > *) 0 ;
  std::vector< int >::size_type arg2 ;
  std::vector< int >::value_type *arg3 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  size_t val2 ;
  int ecode2 = 0 ;
  std::vector< int >::value_type temp3 ;
  int val3 ;
  int ecode3 = 0 ;
  
  if ((nobjs < 3) || (nobjs > 3)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__vectorT_int_std__allocatorT_int_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "IntVector_resize" "', argument " "1"" of type '" "std::vector< int > *""'"); 
  }
  arg1 = reinterpret_cast< std::vector< int > * >(argp1);
  ecode2 = SWIG_AsVal_size_t(swig_obj[1], &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "IntVector_resize" "', argument " "2"" of type '" "std::vector< int >::size_type""'");
  } 
  arg2 = static_cast< std::vector< int >::size_type >(val2);
  ecode3 = SWIG_AsVal_int(swig_obj[2], &val3);
  if (!SWIG_IsOK(ecode3)) {
    SWIG_exception_fail(SWIG_ArgError(ecode3), "in method '" "IntVector_resize" "', argument " "3"" of type '" "std::vector< int >::value_type""'");
  } 
  temp3 = static_cast< std::vector< int >::value_type >(val3);
  arg3 = &temp3;
  (arg1)->resize(arg2,(std::vector< int >::value_type const &)*arg3);
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_IntVector_resize(PyObject *self, PyObject *args) {
  Py_ssize_t argc;
  PyObject *argv[4] = {
    0
  };
  
  if (!(argc = SWIG_Python_UnpackTuple(args, "IntVector_resize", 0, 3, argv))) SWIG_fail;
  --argc;
  if (argc == 2) {
    int _v;
    int res = swig::asptr(argv[0], (std::vector< int,std::allocator< int > >**)(0));
    _v = SWIG_CheckState(res);
    if (_v) {
      {
        int res = SWIG_AsVal_size_t(argv[1], NULL);
        _v = SWIG_CheckState(res);
      }
      if (_v) {
        return _wrap_IntVector_resize__SWIG_0(self, argc, argv);
      }
    }
  }
  if (argc == 3) {
    int _v;
    int res = swig::asptr(argv[0], (std::vector< int,std::allocator< int > >**)(0));
    _v = SWIG_CheckState(res);
    if (_v) {
      {
        int res = SWIG_AsVal_size_t(argv[1], NULL);
        _v = SWIG_CheckState(res);
      }
      if (_v) {
        {
          int res = SWIG_AsVal_int(argv[2], NULL);
          _v = SWIG_CheckState(res);
        }
        if (_v) {
          return _wrap_IntVector_resize__SWIG_1(self, argc, argv);
        }
      }
    }
  }
  
fail:
  SWIG_Python_RaiseOrModifyTypeError("Wrong number or type of arguments for overloaded function 'IntVector_resize'.\n"
    "  Possible C/C++ prototypes are:\n"
    "    std::vector< int >::resize(std::vector< int >::size_type)\n"
    "    std::vector< int >::resize(std::vector< int >::size_type,std::vector< int >::value_type const &)\n");
  return 0;
}


SWIGINTERN PyObject *_wrap_IntVector_insert__SWIG_0(PyObject *SWIGUNUSEDPARM(self), Py_ssize_t nobjs, PyObject **swig_obj) {
  PyObject *resultobj = 0;
  std::vector< int > *arg1 = (std::vector< int > *) 0 ;
  std::vector< int >::iterator arg2 ;
  std::vector< int >::value_type *arg3 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  swig::SwigPyIterator *iter2 = 0 ;
  int res2 ;
  std::vector< int >::value_type temp3 ;
  int val3 ;
  int ecode3 = 0 ;
  std::vector< int >::iterator result;
  
  if ((nobjs < 3) || (nobjs > 3)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__vectorT_int_std__allocatorT_int_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "IntVector_insert" "', argument " "1"" of type '" "std::vector< int > *""'"); 
  }
  arg1 = reinterpret_cast< std::vector< int > * >(argp1);
  res2 = SWIG_ConvertPtr(swig_obj[1], SWIG_as_voidptrptr(&iter2), swig::SwigPyIterator::descriptor(), 0);
  if (!SWIG_IsOK(res2) || !iter2) {
    SWIG_exception_fail(SWIG_ArgError(SWIG_TypeError), "in method '" "IntVector_insert" "', argument " "2"" of type '" "std::vector< int >::iterator""'");
  } else {
    swig::SwigPyIterator_T<std::vector< int >::iterator > *iter_t = dynamic_cast<swig::SwigPyIterator_T<std::vector< int >::iterator > *>(iter2);
    if (iter_t) {
      arg2 = iter_t->get_current();
    } else {
      SWIG_exception_fail(SWIG_ArgError(SWIG_TypeError), "in method '" "IntVector_insert" "', argument " "2"" of type '" "std::vector< int >::iterator""'");
    }
  }
  ecode3 = SWIG_AsVal_int(swig_obj[2], &val3);
  if (!SWIG_IsOK(ecode3)) {
    SWIG_exception_fail(SWIG_ArgError(ecode3), "in method '" "IntVector_insert" "', argument " "3"" of type '" "std::vector< int >::value_type""'");
  } 
  temp3 = static_cast< std::vector< int >::value_type >(val3);
  arg3 = &temp3;
  result = std_vector_Sl_int_Sg__insert__SWIG_0(arg1,arg2,(int const &)*arg3);
  resultobj = SWIG_NewPointerObj(swig::make_output_iterator(static_cast< const std::vector< int >::iterator & >(result)),
    swig::SwigPyIterator::descriptor(),SWIG_POINTER_OWN);
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_IntVector_insert__SWIG_1(PyObject *SWIGUNUSEDPARM(self), Py_ssize_t nobjs, PyObject **swig_obj) {
  PyObject *resultobj = 0;
  std::vector< int > *arg1 = (std::vector< int > *) 0 ;
  std::vector< int >::iterator arg2 ;
  std::vector< int >::size_type arg3 ;
  std::vector< int >::value_type *arg4 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  swig::SwigPyIterator *iter2 = 0 ;
  int res2 ;
  size_t val3 ;
  int ecode3 = 0 ;
  std::vector< int >::value_type temp4 ;
  int val4 ;
  int ecode4 = 0 ;
  
  if ((nobjs < 4) || (nobjs > 4)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__vectorT_int_std__allocatorT_int_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "IntVector_insert" "', argument " "1"" of type '" "std::vector< int > *""'"); 
  }
  arg1 = reinterpret_cast< std::vector< int > * >(argp1);
  res2 = SWIG_ConvertPtr(swig_obj[1], SWIG_as_voidptrptr(&iter2), swig::SwigPyIterator::descriptor(), 0);
  if (!SWIG_IsOK(res2) || !iter2) {
    SWIG_exception_fail(SWIG_ArgError(SWIG_TypeError), "in method '" "IntVector_insert" "', argument " "2"" of type '" "std::vector< int >::iterator""'");
  } else {
    swig::SwigPyIterator_T<std::vector< int >::iterator > *iter_t = dynamic_cast<swig::SwigPyIterator_T<std::vector< int >::iterator > *>(iter2);
    if (iter_t) {
      arg2 = iter_t->get_current();
    } else {
      SWIG_exception_fail(SWIG_ArgError(SWIG_TypeError), "in method '" "IntVector_insert" "', argument " "2"" of type '" "std::vector< int >::iterator""'");
    }
  }
  ecode3 = SWIG_AsVal_size_t(swig_obj[2], &val3);
  if (!SWIG_IsOK(ecode3)) {
    SWIG_exception_fail(SWIG_ArgError(ecode3), "in method '" "IntVector_insert" "', argument " "3"" of type '" "std::vector< int >::size_type""'");
  } 
  arg3 = static_cast< std::vector< int >::size_type >(val3);
  ecode4 = SWIG_AsVal_int(swig_obj[3], &val4);
  if (!SWIG_IsOK(ecode4)) {
    SWIG_exception_fail(SWIG_ArgError(ecode4), "in method '" "IntVector_insert" "', argument " "4"" of type '" "std::vector< int >::value_type""'");
  } 
  temp4 = static_cast< std::vector< int >::value_type >(val4);
  arg4 = &temp4;
  std_vector_Sl_int_Sg__insert__SWIG_1(arg1,arg2,arg3,(int const &)*arg4);
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_IntVector_insert(PyObject *self, PyObject *args) {
  Py_ssize_t argc;
  PyObject *argv[5] = {
    0
  };
  
  if (!(argc = SWIG_Python_UnpackTuple(args, "IntVector_insert", 0, 4, argv))) SWIG_fail;
  --argc;
  if (argc == 3) {
    int _v;
    int res = swig::asptr(argv[0], (std::vector< int,std::allocator< int > >**)(0));
    _v = SWIG_CheckState(res);
    if (_v) {
      swig::SwigPyIterator *iter = 0;
      int res = SWIG_ConvertPtr(argv[1], SWIG_as_voidptrptr(&iter), swig::SwigPyIterator::descriptor(), 0);
      _v = (SWIG_IsOK(res) && iter && (dynamic_cast<swig::SwigPyIterator_T<std::vector< int >::iterator > *>(iter) != 0));
      if (_v) {
        {
          int res = SWIG_AsVal_int(argv[2], NULL);
          _v = SWIG_CheckState(res);
        }
        if (_v) {
          return _wrap_IntVector_insert__SWIG_0(self, argc, argv);
        }
      }
    }
  }
  if (argc == 4) {
    int _v;
    int res = swig::asptr(argv[0], (std::vector< int,std::allocator< int > >**)(0));
    _v = SWIG_CheckState(res);
    if (_v) {
      swig::SwigPyIterator *iter = 0;
      int res = SWIG_ConvertPtr(argv[1], SWIG_as_voidptrptr(&iter), swig::SwigPyIterator::descriptor(), 0);
      _v = (SWIG_IsOK(res) && iter && (dynamic_cast<swig::SwigPyIterator_T<std::vector< int >::iterator > *>(iter) != 0));
      if (_v) {
        {
          int res = SWIG_AsVal_size_t(argv[2], NULL);
          _v = SWIG_CheckState(res);
        }
        if (_v) {
          {
            int res = SWIG_AsVal_int(argv[3], NULL);
            _v = SWIG_CheckState(res);
          }
          if (_v) {
            return _wrap_IntVector_insert__SWIG_1(self, argc, argv);
          }
        }
      }
    }
  }
  
fail:
  SWIG_Python_RaiseOrModifyTypeError("Wrong number or type of arguments for overloaded function 'IntVector_insert'.\n"
    "  Possible C/C++ prototypes are:\n"
    "    std::vector< int >::insert(std::vector< int >::iterator,std::vector< int >::value_type const &)\n"
    "    std::vector< int >::insert(std::vector< int >::iterator,std::vector< int >::size_type,std::vector< int >::value_type const &)\n");
  return 0;
}


SWIGINTERN PyObject *_wrap_IntVector_reserve(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  std::vector< int > *arg1 = (std::vector< int > *) 0 ;
  std::vector< int >::size_type arg2 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  size_t val2 ;
  int ecode2 = 0 ;
  PyObject *swig_obj[2] ;
  
  if (!SWIG_Python_UnpackTuple(args, "IntVector_reserve", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__vectorT_int_std__allocatorT_int_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "IntVector_reserve" "', argument " "1"" of type '" "std::vector< int > *""'"); 
  }
  arg1 = reinterpret_cast< std::vector< int > * >(argp1);
  ecode2 = SWIG_AsVal_size_t(swig_obj[1], &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "IntVector_reserve" "', argument " "2"" of type '" "std::vector< int >::size_type""'");
  } 
  arg2 = static_cast< std::vector< int >::size_type >(val2);
  (arg1)->reserve(arg2);
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_IntVector_capacity(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  std::vector< int > *arg1 = (std::vector< int > *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  std::vector< int >::size_type result;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__vectorT_int_std__allocatorT_int_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "IntVector_capacity" "', argument " "1"" of type '" "std::vector< int > const *""'"); 
  }
  arg1 = reinterpret_cast< std::vector< int > * >(argp1);
  result = ((std::vector< int > const *)arg1)->capacity();
  resultobj = SWIG_From_size_t(static_cast< size_t >(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_delete_IntVector(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  std::vector< int > *arg1 = (std::vector< int > *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__vectorT_int_std__allocatorT_int_t_t, SWIG_POINTER_DISOWN |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "delete_IntVector" "', argument " "1"" of type '" "std::vector< int > *""'"); 
  }
  arg1 = reinterpret_cast< std::vector< int > * >(argp1);
  delete arg1;
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *IntVector_swigregister(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *obj;
  if (!SWIG_Python_UnpackTuple(args, "swigregister", 1, 1, &obj)) return NULL;
  SWIG_TypeNewClientData(SWIGTYPE_p_std__vectorT_int_std__allocatorT_int_t_t, SWIG_NewClientData(obj));
  return SWIG_Py_Void();
}

SWIGINTERN PyObject *IntVector_swiginit(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  return SWIG_Python_InitShadowInstance(args);
}

SWIGINTERN PyObject *_wrap_new_StringToStringMap__SWIG_0(PyObject *SWIGUNUSEDPARM(self), Py_ssize_t nobjs, PyObject **swig_obj) {
  PyObject *resultobj = 0;
  std::less< std::string > *arg1 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  std::map< string,string > *result = 0 ;
  
  if ((nobjs < 1) || (nobjs > 1)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1, SWIGTYPE_p_std__lessT_std__string_t,  0  | 0);
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "new_StringToStringMap" "', argument " "1"" of type '" "std::less< std::string > const &""'"); 
  }
  if (!argp1) {
    SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "new_StringToStringMap" "', argument " "1"" of type '" "std::less< std::string > const &""'"); 
  }
  arg1 = reinterpret_cast< std::less< std::string > * >(argp1);
  result = (std::map< string,string > *)new std::map< string,string >((std::less< std::string > const &)*arg1);
  resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(result), SWIGTYPE_p_std__mapT_std__string_std__string_std__lessT_std__string_t_std__allocatorT_std__pairT_std__string_const_std__string_t_t_t, SWIG_POINTER_NEW |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_StringToStringMap_iterator(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  std::map< string,string > *arg1 = (std::map< string,string > *) 0 ;
  PyObject **arg2 = (PyObject **) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  swig::SwigPyIterator *result = 0 ;
  
  arg2 = &swig_obj[0];
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__mapT_std__string_std__string_std__lessT_std__string_t_std__allocatorT_std__pairT_std__string_const_std__string_t_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "StringToStringMap_iterator" "', argument " "1"" of type '" "std::map< string,string > *""'"); 
  }
  arg1 = reinterpret_cast< std::map< string,string > * >(argp1);
  result = (swig::SwigPyIterator *)std_map_Sl_string_Sc_string_Sg__iterator(arg1,arg2);
  resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(result), SWIGTYPE_p_swig__SwigPyIterator, SWIG_POINTER_OWN |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_StringToStringMap___nonzero__(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  std::map< string,string > *arg1 = (std::map< string,string > *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  bool result;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__mapT_std__string_std__string_std__lessT_std__string_t_std__allocatorT_std__pairT_std__string_const_std__string_t_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "StringToStringMap___nonzero__" "', argument " "1"" of type '" "std::map< string,string > const *""'"); 
  }
  arg1 = reinterpret_cast< std::map< string,string > * >(argp1);
  result = (bool)std_map_Sl_string_Sc_string_Sg____nonzero__((std::map< string,string > const *)arg1);
  resultobj = SWIG_From_bool(static_cast< bool >(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_StringToStringMap___bool__(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  std::map< string,string > *arg1 = (std::map< string,string > *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  bool result;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__mapT_std__string_std__string_std__lessT_std__string_t_std__allocatorT_std__pairT_std__string_const_std__string_t_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "StringToStringMap___bool__" "', argument " "1"" of type '" "std::map< string,string > const *""'"); 
  }
  arg1 = reinterpret_cast< std::map< string,string > * >(argp1);
  result = (bool)std_map_Sl_string_Sc_string_Sg____bool__((std::map< string,string > const *)arg1);
  resultobj = SWIG_From_bool(static_cast< bool >(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_StringToStringMap___len__(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  std::map< string,string > *arg1 = (std::map< string,string > *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  std::map< string,string >::size_type result;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__mapT_std__string_std__string_std__lessT_std__string_t_std__allocatorT_std__pairT_std__string_const_std__string_t_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "StringToStringMap___len__" "', argument " "1"" of type '" "std::map< string,string > const *""'"); 
  }
  arg1 = reinterpret_cast< std::map< string,string > * >(argp1);
  result = std_map_Sl_string_Sc_string_Sg____len__((std::map< string,string > const *)arg1);
  resultobj = SWIG_From_size_t(static_cast< size_t >(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_StringToStringMap___getitem__(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  std::map< string,string > *arg1 = (std::map< string,string > *) 0 ;
  std::map< string,string >::key_type *arg2 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  int res2 = SWIG_OLDOBJ ;
  PyObject *swig_obj[2] ;
  std::map< string,string >::mapped_type *result = 0 ;
  
  if (!SWIG_Python_UnpackTuple(args, "StringToStringMap___getitem__", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__mapT_std__string_std__string_std__lessT_std__string_t_std__allocatorT_std__pairT_std__string_const_std__string_t_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "StringToStringMap___getitem__" "', argument " "1"" of type '" "std::map< string,string > *""'"); 
  }
  arg1 = reinterpret_cast< std::map< string,string > * >(argp1);
  {
    std::string *ptr = (std::string *)0;
    res2 = SWIG_AsPtr_std_string(swig_obj[1], &ptr);
    if (!SWIG_IsOK(res2)) {
      SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "StringToStringMap___getitem__" "', argument " "2"" of type '" "std::map< string,string >::key_type const &""'"); 
    }
    if (!ptr) {
      SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "StringToStringMap___getitem__" "', argument " "2"" of type '" "std::map< string,string >::key_type const &""'"); 
    }
    arg2 = ptr;
  }
  try {
    result = (std::map< string,string >::mapped_type *) &std_map_Sl_string_Sc_string_Sg____getitem__(arg1,(std::string const &)*arg2);
  } catch(std::out_of_range &_e) {
    SWIG_exception_fail(SWIG_IndexError, (&_e)->what());
  }
  resultobj = SWIG_From_std_string(static_cast< std::string >(*result));
  if (SWIG_IsNewObj(res2)) delete arg2;
  return resultobj;
fail:
  if (SWIG_IsNewObj(res2)) delete arg2;
  return NULL;
}


SWIGINTERN PyObject *_wrap_StringToStringMap___delitem__(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  std::map< string,string > *arg1 = (std::map< string,string > *) 0 ;
  std::map< string,string >::key_type *arg2 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  int res2 = SWIG_OLDOBJ ;
  PyObject *swig_obj[2] ;
  
  if (!SWIG_Python_UnpackTuple(args, "StringToStringMap___delitem__", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__mapT_std__string_std__string_std__lessT_std__string_t_std__allocatorT_std__pairT_std__string_const_std__string_t_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "StringToStringMap___delitem__" "', argument " "1"" of type '" "std::map< string,string > *""'"); 
  }
  arg1 = reinterpret_cast< std::map< string,string > * >(argp1);
  {
    std::string *ptr = (std::string *)0;
    res2 = SWIG_AsPtr_std_string(swig_obj[1], &ptr);
    if (!SWIG_IsOK(res2)) {
      SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "StringToStringMap___delitem__" "', argument " "2"" of type '" "std::map< string,string >::key_type const &""'"); 
    }
    if (!ptr) {
      SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "StringToStringMap___delitem__" "', argument " "2"" of type '" "std::map< string,string >::key_type const &""'"); 
    }
    arg2 = ptr;
  }
  try {
    std_map_Sl_string_Sc_string_Sg____delitem__(arg1,(std::string const &)*arg2);
  } catch(std::out_of_range &_e) {
    SWIG_exception_fail(SWIG_IndexError, (&_e)->what());
  }
  resultobj = SWIG_Py_Void();
  if (SWIG_IsNewObj(res2)) delete arg2;
  return resultobj;
fail:
  if (SWIG_IsNewObj(res2)) delete arg2;
  return NULL;
}


SWIGINTERN PyObject *_wrap_StringToStringMap_has_key(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  std::map< string,string > *arg1 = (std::map< string,string > *) 0 ;
  std::map< string,string >::key_type *arg2 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  int res2 = SWIG_OLDOBJ ;
  PyObject *swig_obj[2] ;
  bool result;
  
  if (!SWIG_Python_UnpackTuple(args, "StringToStringMap_has_key", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__mapT_std__string_std__string_std__lessT_std__string_t_std__allocatorT_std__pairT_std__string_const_std__string_t_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "StringToStringMap_has_key" "', argument " "1"" of type '" "std::map< string,string > const *""'"); 
  }
  arg1 = reinterpret_cast< std::map< string,string > * >(argp1);
  {
    std::string *ptr = (std::string *)0;
    res2 = SWIG_AsPtr_std_string(swig_obj[1], &ptr);
    if (!SWIG_IsOK(res2)) {
      SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "StringToStringMap_has_key" "', argument " "2"" of type '" "std::map< string,string >::key_type const &""'"); 
    }
    if (!ptr) {
      SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "StringToStringMap_has_key" "', argument " "2"" of type '" "std::map< string,string >::key_type const &""'"); 
    }
    arg2 = ptr;
  }
  result = (bool)std_map_Sl_string_Sc_string_Sg__has_key((std::map< string,string > const *)arg1,(std::string const &)*arg2);
  resultobj = SWIG_From_bool(static_cast< bool >(result));
  if (SWIG_IsNewObj(res2)) delete arg2;
  return resultobj;
fail:
  if (SWIG_IsNewObj(res2)) delete arg2;
  return NULL;
}


SWIGINTERN PyObject *_wrap_StringToStringMap_keys(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  std::map< string,string > *arg1 = (std::map< string,string > *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  PyObject *result = 0 ;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__mapT_std__string_std__string_std__lessT_std__string_t_std__allocatorT_std__pairT_std__string_const_std__string_t_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "StringToStringMap_keys" "', argument " "1"" of type '" "std::map< string,string > *""'"); 
  }
  arg1 = reinterpret_cast< std::map< string,string > * >(argp1);
  result = (PyObject *)std_map_Sl_string_Sc_string_Sg__keys(arg1);
  resultobj = result;
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_StringToStringMap_values(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  std::map< string,string > *arg1 = (std::map< string,string > *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  PyObject *result = 0 ;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__mapT_std__string_std__string_std__lessT_std__string_t_std__allocatorT_std__pairT_std__string_const_std__string_t_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "StringToStringMap_values" "', argument " "1"" of type '" "std::map< string,string > *""'"); 
  }
  arg1 = reinterpret_cast< std::map< string,string > * >(argp1);
  result = (PyObject *)std_map_Sl_string_Sc_string_Sg__values(arg1);
  resultobj = result;
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_StringToStringMap_items(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  std::map< string,string > *arg1 = (std::map< string,string > *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  PyObject *result = 0 ;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__mapT_std__string_std__string_std__lessT_std__string_t_std__allocatorT_std__pairT_std__string_const_std__string_t_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "StringToStringMap_items" "', argument " "1"" of type '" "std::map< string,string > *""'"); 
  }
  arg1 = reinterpret_cast< std::map< string,string > * >(argp1);
  result = (PyObject *)std_map_Sl_string_Sc_string_Sg__items(arg1);
  resultobj = result;
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_StringToStringMap___contains__(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  std::map< string,string > *arg1 = (std::map< string,string > *) 0 ;
  std::map< string,string >::key_type *arg2 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  int res2 = SWIG_OLDOBJ ;
  PyObject *swig_obj[2] ;
  bool result;
  
  if (!SWIG_Python_UnpackTuple(args, "StringToStringMap___contains__", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__mapT_std__string_std__string_std__lessT_std__string_t_std__allocatorT_std__pairT_std__string_const_std__string_t_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "StringToStringMap___contains__" "', argument " "1"" of type '" "std::map< string,string > *""'"); 
  }
  arg1 = reinterpret_cast< std::map< string,string > * >(argp1);
  {
    std::string *ptr = (std::string *)0;
    res2 = SWIG_AsPtr_std_string(swig_obj[1], &ptr);
    if (!SWIG_IsOK(res2)) {
      SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "StringToStringMap___contains__" "', argument " "2"" of type '" "std::map< string,string >::key_type const &""'"); 
    }
    if (!ptr) {
      SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "StringToStringMap___contains__" "', argument " "2"" of type '" "std::map< string,string >::key_type const &""'"); 
    }
    arg2 = ptr;
  }
  result = (bool)std_map_Sl_string_Sc_string_Sg____contains__(arg1,(std::string const &)*arg2);
  resultobj = SWIG_From_bool(static_cast< bool >(result));
  if (SWIG_IsNewObj(res2)) delete arg2;
  return resultobj;
fail:
  if (SWIG_IsNewObj(res2)) delete arg2;
  return NULL;
}


SWIGINTERN PyObject *_wrap_StringToStringMap_key_iterator(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  std::map< string,string > *arg1 = (std::map< string,string > *) 0 ;
  PyObject **arg2 = (PyObject **) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  swig::SwigPyIterator *result = 0 ;
  
  arg2 = &swig_obj[0];
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__mapT_std__string_std__string_std__lessT_std__string_t_std__allocatorT_std__pairT_std__string_const_std__string_t_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "StringToStringMap_key_iterator" "', argument " "1"" of type '" "std::map< string,string > *""'"); 
  }
  arg1 = reinterpret_cast< std::map< string,string > * >(argp1);
  result = (swig::SwigPyIterator *)std_map_Sl_string_Sc_string_Sg__key_iterator(arg1,arg2);
  resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(result), SWIGTYPE_p_swig__SwigPyIterator, SWIG_POINTER_OWN |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_StringToStringMap_value_iterator(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  std::map< string,string > *arg1 = (std::map< string,string > *) 0 ;
  PyObject **arg2 = (PyObject **) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  swig::SwigPyIterator *result = 0 ;
  
  arg2 = &swig_obj[0];
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__mapT_std__string_std__string_std__lessT_std__string_t_std__allocatorT_std__pairT_std__string_const_std__string_t_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "StringToStringMap_value_iterator" "', argument " "1"" of type '" "std::map< string,string > *""'"); 
  }
  arg1 = reinterpret_cast< std::map< string,string > * >(argp1);
  result = (swig::SwigPyIterator *)std_map_Sl_string_Sc_string_Sg__value_iterator(arg1,arg2);
  resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(result), SWIGTYPE_p_swig__SwigPyIterator, SWIG_POINTER_OWN |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_StringToStringMap___setitem____SWIG_0(PyObject *SWIGUNUSEDPARM(self), Py_ssize_t nobjs, PyObject **swig_obj) {
  PyObject *resultobj = 0;
  std::map< string,string > *arg1 = (std::map< string,string > *) 0 ;
  std::map< string,string >::key_type *arg2 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  int res2 = SWIG_OLDOBJ ;
  
  if ((nobjs < 2) || (nobjs > 2)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__mapT_std__string_std__string_std__lessT_std__string_t_std__allocatorT_std__pairT_std__string_const_std__string_t_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "StringToStringMap___setitem__" "', argument " "1"" of type '" "std::map< string,string > *""'"); 
  }
  arg1 = reinterpret_cast< std::map< string,string > * >(argp1);
  {
    std::string *ptr = (std::string *)0;
    res2 = SWIG_AsPtr_std_string(swig_obj[1], &ptr);
    if (!SWIG_IsOK(res2)) {
      SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "StringToStringMap___setitem__" "', argument " "2"" of type '" "std::map< string,string >::key_type const &""'"); 
    }
    if (!ptr) {
      SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "StringToStringMap___setitem__" "', argument " "2"" of type '" "std::map< string,string >::key_type const &""'"); 
    }
    arg2 = ptr;
  }
  std_map_Sl_string_Sc_string_Sg____setitem____SWIG_0(arg1,(std::string const &)*arg2);
  resultobj = SWIG_Py_Void();
  if (SWIG_IsNewObj(res2)) delete arg2;
  return resultobj;
fail:
  if (SWIG_IsNewObj(res2)) delete arg2;
  return NULL;
}


SWIGINTERN PyObject *_wrap_StringToStringMap___setitem____SWIG_1(PyObject *SWIGUNUSEDPARM(self), Py_ssize_t nobjs, PyObject **swig_obj) {
  PyObject *resultobj = 0;
  std::map< string,string > *arg1 = (std::map< string,string > *) 0 ;
  std::map< string,string >::key_type *arg2 = 0 ;
  std::map< string,string >::mapped_type *arg3 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  int res2 = SWIG_OLDOBJ ;
  int res3 = SWIG_OLDOBJ ;
  
  if ((nobjs < 3) || (nobjs > 3)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__mapT_std__string_std__string_std__lessT_std__string_t_std__allocatorT_std__pairT_std__string_const_std__string_t_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "StringToStringMap___setitem__" "', argument " "1"" of type '" "std::map< string,string > *""'"); 
  }
  arg1 = reinterpret_cast< std::map< string,string > * >(argp1);
  {
    std::string *ptr = (std::string *)0;
    res2 = SWIG_AsPtr_std_string(swig_obj[1], &ptr);
    if (!SWIG_IsOK(res2)) {
      SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "StringToStringMap___setitem__" "', argument " "2"" of type '" "std::map< string,string >::key_type const &""'"); 
    }
    if (!ptr) {
      SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "StringToStringMap___setitem__" "', argument " "2"" of type '" "std::map< string,string >::key_type const &""'"); 
    }
    arg2 = ptr;
  }
  {
    std::string *ptr = (std::string *)0;
    res3 = SWIG_AsPtr_std_string(swig_obj[2], &ptr);
    if (!SWIG_IsOK(res3)) {
      SWIG_exception_fail(SWIG_ArgError(res3), "in method '" "StringToStringMap___setitem__" "', argument " "3"" of type '" "std::map< string,string >::mapped_type const &""'"); 
    }
    if (!ptr) {
      SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "StringToStringMap___setitem__" "', argument " "3"" of type '" "std::map< string,string >::mapped_type const &""'"); 
    }
    arg3 = ptr;
  }
  try {
    std_map_Sl_string_Sc_string_Sg____setitem____SWIG_1(arg1,(std::string const &)*arg2,(std::string const &)*arg3);
  } catch(std::out_of_range &_e) {
    SWIG_exception_fail(SWIG_IndexError, (&_e)->what());
  }
  resultobj = SWIG_Py_Void();
  if (SWIG_IsNewObj(res2)) delete arg2;
  if (SWIG_IsNewObj(res3)) delete arg3;
  return resultobj;
fail:
  if (SWIG_IsNewObj(res2)) delete arg2;
  if (SWIG_IsNewObj(res3)) delete arg3;
  return NULL;
}


SWIGINTERN PyObject *_wrap_StringToStringMap___setitem__(PyObject *self, PyObject *args) {
  Py_ssize_t argc;
  PyObject *argv[4] = {
    0
  };
  
  if (!(argc = SWIG_Python_UnpackTuple(args, "StringToStringMap___setitem__", 0, 3, argv))) SWIG_fail;
  --argc;
  if (argc == 2) {
    int _v;
    int res = swig::asptr(argv[0], (std::map< std::string,std::string,std::less< std::string >,std::allocator< std::pair< std::string const,std::string > > >**)(0));
    _v = SWIG_CheckState(res);
    if (_v) {
      int res = SWIG_AsPtr_std_string(argv[1], (std::string**)(0));
      _v = SWIG_CheckState(res);
      if (_v) {
        return _wrap_StringToStringMap___setitem____SWIG_0(self, argc, argv);
      }
    }
  }
  if (argc == 3) {
    int _v;
    int res = swig::asptr(argv[0], (std::map< std::string,std::string,std::less< std::string >,std::allocator< std::pair< std::string const,std::string > > >**)(0));
    _v = SWIG_CheckState(res);
    if (_v) {
      int res = SWIG_AsPtr_std_string(argv[1], (std::string**)(0));
      _v = SWIG_CheckState(res);
      if (_v) {
        int res = SWIG_AsPtr_std_string(argv[2], (std::string**)(0));
        _v = SWIG_CheckState(res);
        if (_v) {
          return _wrap_StringToStringMap___setitem____SWIG_1(self, argc, argv);
        }
      }
    }
  }
  
fail:
  SWIG_Python_RaiseOrModifyTypeError("Wrong number or type of arguments for overloaded function 'StringToStringMap___setitem__'.\n"
    "  Possible C/C++ prototypes are:\n"
    "    std::map< string,string >::__setitem__(std::map< string,string >::key_type const &)\n"
    "    std::map< string,string >::__setitem__(std::map< string,string >::key_type const &,std::map< string,string >::mapped_type const &)\n");
  return 0;
}


SWIGINTERN PyObject *_wrap_StringToStringMap_asdict(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  std::map< string,string > *arg1 = (std::map< string,string > *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  PyObject *result = 0 ;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__mapT_std__string_std__string_std__lessT_std__string_t_std__allocatorT_std__pairT_std__string_const_std__string_t_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "StringToStringMap_asdict" "', argument " "1"" of type '" "std::map< string,string > *""'"); 
  }
  arg1 = reinterpret_cast< std::map< string,string > * >(argp1);
  result = (PyObject *)std_map_Sl_string_Sc_string_Sg__asdict(arg1);
  resultobj = result;
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_new_StringToStringMap__SWIG_1(PyObject *SWIGUNUSEDPARM(self), Py_ssize_t nobjs, PyObject **SWIGUNUSEDPARM(swig_obj)) {
  PyObject *resultobj = 0;
  std::map< string,string > *result = 0 ;
  
  if ((nobjs < 0) || (nobjs > 0)) SWIG_fail;
  result = (std::map< string,string > *)new std::map< string,string >();
  resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(result), SWIGTYPE_p_std__mapT_std__string_std__string_std__lessT_std__string_t_std__allocatorT_std__pairT_std__string_const_std__string_t_t_t, SWIG_POINTER_NEW |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_new_StringToStringMap__SWIG_2(PyObject *SWIGUNUSEDPARM(self), Py_ssize_t nobjs, PyObject **swig_obj) {
  PyObject *resultobj = 0;
  std::map< std::string,std::string > *arg1 = 0 ;
  int res1 = SWIG_OLDOBJ ;
  std::map< string,string > *result = 0 ;
  
  if ((nobjs < 1) || (nobjs > 1)) SWIG_fail;
  {
    std::map< std::string,std::string,std::less< std::string >,std::allocator< std::pair< std::string const,std::string > > > *ptr = (std::map< std::string,std::string,std::less< std::string >,std::allocator< std::pair< std::string const,std::string > > > *)0;
    res1 = swig::asptr(swig_obj[0], &ptr);
    if (!SWIG_IsOK(res1)) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "new_StringToStringMap" "', argument " "1"" of type '" "std::map< std::string,std::string > const &""'"); 
    }
    if (!ptr) {
      SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "new_StringToStringMap" "', argument " "1"" of type '" "std::map< std::string,std::string > const &""'"); 
    }
    arg1 = ptr;
  }
  result = (std::map< string,string > *)new std::map< string,string >((std::map< std::string,std::string > const &)*arg1);
  resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(result), SWIGTYPE_p_std__mapT_std__string_std__string_std__lessT_std__string_t_std__allocatorT_std__pairT_std__string_const_std__string_t_t_t, SWIG_POINTER_NEW |  0 );
  if (SWIG_IsNewObj(res1)) delete arg1;
  return resultobj;
fail:
  if (SWIG_IsNewObj(res1)) delete arg1;
  return NULL;
}


SWIGINTERN PyObject *_wrap_new_StringToStringMap(PyObject *self, PyObject *args) {
  Py_ssize_t argc;
  PyObject *argv[2] = {
    0
  };
  
  if (!(argc = SWIG_Python_UnpackTuple(args, "new_StringToStringMap", 0, 1, argv))) SWIG_fail;
  --argc;
  if (argc == 0) {
    return _wrap_new_StringToStringMap__SWIG_1(self, argc, argv);
  }
  if (argc == 1) {
    int _v;
    int res = SWIG_ConvertPtr(argv[0], 0, SWIGTYPE_p_std__lessT_std__string_t, SWIG_POINTER_NO_NULL | 0);
    _v = SWIG_CheckState(res);
    if (_v) {
      return _wrap_new_StringToStringMap__SWIG_0(self, argc, argv);
    }
  }
  if (argc == 1) {
    int _v;
    int res = swig::asptr(argv[0], (std::map< std::string,std::string,std::less< std::string >,std::allocator< std::pair< std::string const,std::string > > >**)(0));
    _v = SWIG_CheckState(res);
    if (_v) {
      return _wrap_new_StringToStringMap__SWIG_2(self, argc, argv);
    }
  }
  
fail:
  SWIG_Python_RaiseOrModifyTypeError("Wrong number or type of arguments for overloaded function 'new_StringToStringMap'.\n"
    "  Possible C/C++ prototypes are:\n"
    "    std::map< string,string >::map(std::less< std::string > const &)\n"
    "    std::map< string,string >::map()\n"
    "    std::map< string,string >::map(std::map< std::string,std::string > const &)\n");
  return 0;
}


SWIGINTERN PyObject *_wrap_StringToStringMap_empty(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  std::map< string,string > *arg1 = (std::map< string,string > *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  bool result;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__mapT_std__string_std__string_std__lessT_std__string_t_std__allocatorT_std__pairT_std__string_const_std__string_t_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "StringToStringMap_empty" "', argument " "1"" of type '" "std::map< string,string > const *""'"); 
  }
  arg1 = reinterpret_cast< std::map< string,string > * >(argp1);
  result = (bool)((std::map< string,string > const *)arg1)->empty();
  resultobj = SWIG_From_bool(static_cast< bool >(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_StringToStringMap_size(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  std::map< string,string > *arg1 = (std::map< string,string > *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  std::map< string,string >::size_type result;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__mapT_std__string_std__string_std__lessT_std__string_t_std__allocatorT_std__pairT_std__string_const_std__string_t_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "StringToStringMap_size" "', argument " "1"" of type '" "std::map< string,string > const *""'"); 
  }
  arg1 = reinterpret_cast< std::map< string,string > * >(argp1);
  result = ((std::map< string,string > const *)arg1)->size();
  resultobj = SWIG_From_size_t(static_cast< size_t >(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_StringToStringMap_swap(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  std::map< string,string > *arg1 = (std::map< string,string > *) 0 ;
  std::map< std::string,std::string > *arg2 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  void *argp2 = 0 ;
  int res2 = 0 ;
  PyObject *swig_obj[2] ;
  
  if (!SWIG_Python_UnpackTuple(args, "StringToStringMap_swap", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__mapT_std__string_std__string_std__lessT_std__string_t_std__allocatorT_std__pairT_std__string_const_std__string_t_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "StringToStringMap_swap" "', argument " "1"" of type '" "std::map< string,string > *""'"); 
  }
  arg1 = reinterpret_cast< std::map< string,string > * >(argp1);
  res2 = SWIG_ConvertPtr(swig_obj[1], &argp2, SWIGTYPE_p_std__mapT_std__string_std__string_std__lessT_std__string_t_std__allocatorT_std__pairT_std__string_const_std__string_t_t_t,  0 );
  if (!SWIG_IsOK(res2)) {
    SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "StringToStringMap_swap" "', argument " "2"" of type '" "std::map< std::string,std::string > &""'"); 
  }
  if (!argp2) {
    SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "StringToStringMap_swap" "', argument " "2"" of type '" "std::map< std::string,std::string > &""'"); 
  }
  arg2 = reinterpret_cast< std::map< std::string,std::string > * >(argp2);
  (arg1)->swap(*arg2);
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_StringToStringMap_begin(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  std::map< string,string > *arg1 = (std::map< string,string > *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  std::map< string,string >::iterator result;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__mapT_std__string_std__string_std__lessT_std__string_t_std__allocatorT_std__pairT_std__string_const_std__string_t_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "StringToStringMap_begin" "', argument " "1"" of type '" "std::map< string,string > *""'"); 
  }
  arg1 = reinterpret_cast< std::map< string,string > * >(argp1);
  result = (arg1)->begin();
  resultobj = SWIG_NewPointerObj(swig::make_output_iterator(static_cast< const std::map< string,string >::iterator & >(result)),
    swig::SwigPyIterator::descriptor(),SWIG_POINTER_OWN);
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_StringToStringMap_end(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  std::map< string,string > *arg1 = (std::map< string,string > *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  std::map< string,string >::iterator result;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__mapT_std__string_std__string_std__lessT_std__string_t_std__allocatorT_std__pairT_std__string_const_std__string_t_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "StringToStringMap_end" "', argument " "1"" of type '" "std::map< string,string > *""'"); 
  }
  arg1 = reinterpret_cast< std::map< string,string > * >(argp1);
  result = (arg1)->end();
  resultobj = SWIG_NewPointerObj(swig::make_output_iterator(static_cast< const std::map< string,string >::iterator & >(result)),
    swig::SwigPyIterator::descriptor(),SWIG_POINTER_OWN);
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_StringToStringMap_rbegin(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  std::map< string,string > *arg1 = (std::map< string,string > *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  std::map< string,string >::reverse_iterator result;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__mapT_std__string_std__string_std__lessT_std__string_t_std__allocatorT_std__pairT_std__string_const_std__string_t_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "StringToStringMap_rbegin" "', argument " "1"" of type '" "std::map< string,string > *""'"); 
  }
  arg1 = reinterpret_cast< std::map< string,string > * >(argp1);
  result = (arg1)->rbegin();
  resultobj = SWIG_NewPointerObj(swig::make_output_iterator(static_cast< const std::map< string,string >::reverse_iterator & >(result)),
    swig::SwigPyIterator::descriptor(),SWIG_POINTER_OWN);
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_StringToStringMap_rend(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  std::map< string,string > *arg1 = (std::map< string,string > *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  std::map< string,string >::reverse_iterator result;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__mapT_std__string_std__string_std__lessT_std__string_t_std__allocatorT_std__pairT_std__string_const_std__string_t_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "StringToStringMap_rend" "', argument " "1"" of type '" "std::map< string,string > *""'"); 
  }
  arg1 = reinterpret_cast< std::map< string,string > * >(argp1);
  result = (arg1)->rend();
  resultobj = SWIG_NewPointerObj(swig::make_output_iterator(static_cast< const std::map< string,string >::reverse_iterator & >(result)),
    swig::SwigPyIterator::descriptor(),SWIG_POINTER_OWN);
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_StringToStringMap_clear(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  std::map< string,string > *arg1 = (std::map< string,string > *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__mapT_std__string_std__string_std__lessT_std__string_t_std__allocatorT_std__pairT_std__string_const_std__string_t_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "StringToStringMap_clear" "', argument " "1"" of type '" "std::map< string,string > *""'"); 
  }
  arg1 = reinterpret_cast< std::map< string,string > * >(argp1);
  (arg1)->clear();
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_StringToStringMap_get_allocator(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  std::map< string,string > *arg1 = (std::map< string,string > *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  SwigValueWrapper< std::allocator< std::pair< std::string const,std::string > > > result;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__mapT_std__string_std__string_std__lessT_std__string_t_std__allocatorT_std__pairT_std__string_const_std__string_t_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "StringToStringMap_get_allocator" "', argument " "1"" of type '" "std::map< string,string > const *""'"); 
  }
  arg1 = reinterpret_cast< std::map< string,string > * >(argp1);
  result = ((std::map< string,string > const *)arg1)->get_allocator();
  resultobj = SWIG_NewPointerObj((new std::map< string,string >::allocator_type(static_cast< const std::map< string,string >::allocator_type& >(result))), SWIGTYPE_p_std__allocatorT_std__pairT_std__string_const_std__string_t_t, SWIG_POINTER_OWN |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_StringToStringMap_erase__SWIG_0(PyObject *SWIGUNUSEDPARM(self), Py_ssize_t nobjs, PyObject **swig_obj) {
  PyObject *resultobj = 0;
  std::map< string,string > *arg1 = (std::map< string,string > *) 0 ;
  std::map< string,string >::key_type *arg2 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  int res2 = SWIG_OLDOBJ ;
  std::map< string,string >::size_type result;
  
  if ((nobjs < 2) || (nobjs > 2)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__mapT_std__string_std__string_std__lessT_std__string_t_std__allocatorT_std__pairT_std__string_const_std__string_t_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "StringToStringMap_erase" "', argument " "1"" of type '" "std::map< string,string > *""'"); 
  }
  arg1 = reinterpret_cast< std::map< string,string > * >(argp1);
  {
    std::string *ptr = (std::string *)0;
    res2 = SWIG_AsPtr_std_string(swig_obj[1], &ptr);
    if (!SWIG_IsOK(res2)) {
      SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "StringToStringMap_erase" "', argument " "2"" of type '" "std::map< string,string >::key_type const &""'"); 
    }
    if (!ptr) {
      SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "StringToStringMap_erase" "', argument " "2"" of type '" "std::map< string,string >::key_type const &""'"); 
    }
    arg2 = ptr;
  }
  result = (arg1)->erase((std::map< string,string >::key_type const &)*arg2);
  resultobj = SWIG_From_size_t(static_cast< size_t >(result));
  if (SWIG_IsNewObj(res2)) delete arg2;
  return resultobj;
fail:
  if (SWIG_IsNewObj(res2)) delete arg2;
  return NULL;
}


SWIGINTERN PyObject *_wrap_StringToStringMap_count(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  std::map< string,string > *arg1 = (std::map< string,string > *) 0 ;
  std::map< string,string >::key_type *arg2 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  int res2 = SWIG_OLDOBJ ;
  PyObject *swig_obj[2] ;
  std::map< string,string >::size_type result;
  
  if (!SWIG_Python_UnpackTuple(args, "StringToStringMap_count", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__mapT_std__string_std__string_std__lessT_std__string_t_std__allocatorT_std__pairT_std__string_const_std__string_t_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "StringToStringMap_count" "', argument " "1"" of type '" "std::map< string,string > const *""'"); 
  }
  arg1 = reinterpret_cast< std::map< string,string > * >(argp1);
  {
    std::string *ptr = (std::string *)0;
    res2 = SWIG_AsPtr_std_string(swig_obj[1], &ptr);
    if (!SWIG_IsOK(res2)) {
      SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "StringToStringMap_count" "', argument " "2"" of type '" "std::map< string,string >::key_type const &""'"); 
    }
    if (!ptr) {
      SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "StringToStringMap_count" "', argument " "2"" of type '" "std::map< string,string >::key_type const &""'"); 
    }
    arg2 = ptr;
  }
  result = ((std::map< string,string > const *)arg1)->count((std::map< string,string >::key_type const &)*arg2);
  resultobj = SWIG_From_size_t(static_cast< size_t >(result));
  if (SWIG_IsNewObj(res2)) delete arg2;
  return resultobj;
fail:
  if (SWIG_IsNewObj(res2)) delete arg2;
  return NULL;
}


SWIGINTERN PyObject *_wrap_StringToStringMap_erase__SWIG_1(PyObject *SWIGUNUSEDPARM(self), Py_ssize_t nobjs, PyObject **swig_obj) {
  PyObject *resultobj = 0;
  std::map< string,string > *arg1 = (std::map< string,string > *) 0 ;
  std::map< string,string >::iterator arg2 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  swig::SwigPyIterator *iter2 = 0 ;
  int res2 ;
  
  if ((nobjs < 2) || (nobjs > 2)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__mapT_std__string_std__string_std__lessT_std__string_t_std__allocatorT_std__pairT_std__string_const_std__string_t_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "StringToStringMap_erase" "', argument " "1"" of type '" "std::map< string,string > *""'"); 
  }
  arg1 = reinterpret_cast< std::map< string,string > * >(argp1);
  res2 = SWIG_ConvertPtr(swig_obj[1], SWIG_as_voidptrptr(&iter2), swig::SwigPyIterator::descriptor(), 0);
  if (!SWIG_IsOK(res2) || !iter2) {
    SWIG_exception_fail(SWIG_ArgError(SWIG_TypeError), "in method '" "StringToStringMap_erase" "', argument " "2"" of type '" "std::map< string,string >::iterator""'");
  } else {
    swig::SwigPyIterator_T<std::map< string,string >::iterator > *iter_t = dynamic_cast<swig::SwigPyIterator_T<std::map< string,string >::iterator > *>(iter2);
    if (iter_t) {
      arg2 = iter_t->get_current();
    } else {
      SWIG_exception_fail(SWIG_ArgError(SWIG_TypeError), "in method '" "StringToStringMap_erase" "', argument " "2"" of type '" "std::map< string,string >::iterator""'");
    }
  }
  std_map_Sl_string_Sc_string_Sg__erase__SWIG_1(arg1,arg2);
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_StringToStringMap_erase__SWIG_2(PyObject *SWIGUNUSEDPARM(self), Py_ssize_t nobjs, PyObject **swig_obj) {
  PyObject *resultobj = 0;
  std::map< string,string > *arg1 = (std::map< string,string > *) 0 ;
  std::map< string,string >::iterator arg2 ;
  std::map< string,string >::iterator arg3 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  swig::SwigPyIterator *iter2 = 0 ;
  int res2 ;
  swig::SwigPyIterator *iter3 = 0 ;
  int res3 ;
  
  if ((nobjs < 3) || (nobjs > 3)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__mapT_std__string_std__string_std__lessT_std__string_t_std__allocatorT_std__pairT_std__string_const_std__string_t_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "StringToStringMap_erase" "', argument " "1"" of type '" "std::map< string,string > *""'"); 
  }
  arg1 = reinterpret_cast< std::map< string,string > * >(argp1);
  res2 = SWIG_ConvertPtr(swig_obj[1], SWIG_as_voidptrptr(&iter2), swig::SwigPyIterator::descriptor(), 0);
  if (!SWIG_IsOK(res2) || !iter2) {
    SWIG_exception_fail(SWIG_ArgError(SWIG_TypeError), "in method '" "StringToStringMap_erase" "', argument " "2"" of type '" "std::map< string,string >::iterator""'");
  } else {
    swig::SwigPyIterator_T<std::map< string,string >::iterator > *iter_t = dynamic_cast<swig::SwigPyIterator_T<std::map< string,string >::iterator > *>(iter2);
    if (iter_t) {
      arg2 = iter_t->get_current();
    } else {
      SWIG_exception_fail(SWIG_ArgError(SWIG_TypeError), "in method '" "StringToStringMap_erase" "', argument " "2"" of type '" "std::map< string,string >::iterator""'");
    }
  }
  res3 = SWIG_ConvertPtr(swig_obj[2], SWIG_as_voidptrptr(&iter3), swig::SwigPyIterator::descriptor(), 0);
  if (!SWIG_IsOK(res3) || !iter3) {
    SWIG_exception_fail(SWIG_ArgError(SWIG_TypeError), "in method '" "StringToStringMap_erase" "', argument " "3"" of type '" "std::map< string,string >::iterator""'");
  } else {
    swig::SwigPyIterator_T<std::map< string,string >::iterator > *iter_t = dynamic_cast<swig::SwigPyIterator_T<std::map< string,string >::iterator > *>(iter3);
    if (iter_t) {
      arg3 = iter_t->get_current();
    } else {
      SWIG_exception_fail(SWIG_ArgError(SWIG_TypeError), "in method '" "StringToStringMap_erase" "', argument " "3"" of type '" "std::map< string,string >::iterator""'");
    }
  }
  std_map_Sl_string_Sc_string_Sg__erase__SWIG_2(arg1,arg2,arg3);
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_StringToStringMap_erase(PyObject *self, PyObject *args) {
  Py_ssize_t argc;
  PyObject *argv[4] = {
    0
  };
  
  if (!(argc = SWIG_Python_UnpackTuple(args, "StringToStringMap_erase", 0, 3, argv))) SWIG_fail;
  --argc;
  if (argc == 2) {
    int _v;
    int res = swig::asptr(argv[0], (std::map< std::string,std::string,std::less< std::string >,std::allocator< std::pair< std::string const,std::string > > >**)(0));
    _v = SWIG_CheckState(res);
    if (_v) {
      swig::SwigPyIterator *iter = 0;
      int res = SWIG_ConvertPtr(argv[1], SWIG_as_voidptrptr(&iter), swig::SwigPyIterator::descriptor(), 0);
      _v = (SWIG_IsOK(res) && iter && (dynamic_cast<swig::SwigPyIterator_T<std::map< string,string >::iterator > *>(iter) != 0));
      if (_v) {
        return _wrap_StringToStringMap_erase__SWIG_1(self, argc, argv);
      }
    }
  }
  if (argc == 2) {
    int _v;
    int res = swig::asptr(argv[0], (std::map< std::string,std::string,std::less< std::string >,std::allocator< std::pair< std::string const,std::string > > >**)(0));
    _v = SWIG_CheckState(res);
    if (_v) {
      int res = SWIG_AsPtr_std_string(argv[1], (std::string**)(0));
      _v = SWIG_CheckState(res);
      if (_v) {
        return _wrap_StringToStringMap_erase__SWIG_0(self, argc, argv);
      }
    }
  }
  if (argc == 3) {
    int _v;
    int res = swig::asptr(argv[0], (std::map< std::string,std::string,std::less< std::string >,std::allocator< std::pair< std::string const,std::string > > >**)(0));
    _v = SWIG_CheckState(res);
    if (_v) {
      swig::SwigPyIterator *iter = 0;
      int res = SWIG_ConvertPtr(argv[1], SWIG_as_voidptrptr(&iter), swig::SwigPyIterator::descriptor(), 0);
      _v = (SWIG_IsOK(res) && iter && (dynamic_cast<swig::SwigPyIterator_T<std::map< string,string >::iterator > *>(iter) != 0));
      if (_v) {
        swig::SwigPyIterator *iter = 0;
        int res = SWIG_ConvertPtr(argv[2], SWIG_as_voidptrptr(&iter), swig::SwigPyIterator::descriptor(), 0);
        _v = (SWIG_IsOK(res) && iter && (dynamic_cast<swig::SwigPyIterator_T<std::map< string,string >::iterator > *>(iter) != 0));
        if (_v) {
          return _wrap_StringToStringMap_erase__SWIG_2(self, argc, argv);
        }
      }
    }
  }
  
fail:
  SWIG_Python_RaiseOrModifyTypeError("Wrong number or type of arguments for overloaded function 'StringToStringMap_erase'.\n"
    "  Possible C/C++ prototypes are:\n"
    "    std::map< string,string >::erase(std::map< string,string >::key_type const &)\n"
    "    std::map< string,string >::erase(std::map< string,string >::iterator)\n"
    "    std::map< string,string >::erase(std::map< string,string >::iterator,std::map< string,string >::iterator)\n");
  return 0;
}


SWIGINTERN PyObject *_wrap_StringToStringMap_find(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  std::map< string,string > *arg1 = (std::map< string,string > *) 0 ;
  std::map< string,string >::key_type *arg2 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  int res2 = SWIG_OLDOBJ ;
  PyObject *swig_obj[2] ;
  std::map< string,string >::iterator result;
  
  if (!SWIG_Python_UnpackTuple(args, "StringToStringMap_find", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__mapT_std__string_std__string_std__lessT_std__string_t_std__allocatorT_std__pairT_std__string_const_std__string_t_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "StringToStringMap_find" "', argument " "1"" of type '" "std::map< string,string > *""'"); 
  }
  arg1 = reinterpret_cast< std::map< string,string > * >(argp1);
  {
    std::string *ptr = (std::string *)0;
    res2 = SWIG_AsPtr_std_string(swig_obj[1], &ptr);
    if (!SWIG_IsOK(res2)) {
      SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "StringToStringMap_find" "', argument " "2"" of type '" "std::map< string,string >::key_type const &""'"); 
    }
    if (!ptr) {
      SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "StringToStringMap_find" "', argument " "2"" of type '" "std::map< string,string >::key_type const &""'"); 
    }
    arg2 = ptr;
  }
  result = (arg1)->find((std::map< string,string >::key_type const &)*arg2);
  resultobj = SWIG_NewPointerObj(swig::make_output_iterator(static_cast< const std::map< string,string >::iterator & >(result)),
    swig::SwigPyIterator::descriptor(),SWIG_POINTER_OWN);
  if (SWIG_IsNewObj(res2)) delete arg2;
  return resultobj;
fail:
  if (SWIG_IsNewObj(res2)) delete arg2;
  return NULL;
}


SWIGINTERN PyObject *_wrap_StringToStringMap_lower_bound(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  std::map< string,string > *arg1 = (std::map< string,string > *) 0 ;
  std::map< string,string >::key_type *arg2 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  int res2 = SWIG_OLDOBJ ;
  PyObject *swig_obj[2] ;
  std::map< string,string >::iterator result;
  
  if (!SWIG_Python_UnpackTuple(args, "StringToStringMap_lower_bound", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__mapT_std__string_std__string_std__lessT_std__string_t_std__allocatorT_std__pairT_std__string_const_std__string_t_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "StringToStringMap_lower_bound" "', argument " "1"" of type '" "std::map< string,string > *""'"); 
  }
  arg1 = reinterpret_cast< std::map< string,string > * >(argp1);
  {
    std::string *ptr = (std::string *)0;
    res2 = SWIG_AsPtr_std_string(swig_obj[1], &ptr);
    if (!SWIG_IsOK(res2)) {
      SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "StringToStringMap_lower_bound" "', argument " "2"" of type '" "std::map< string,string >::key_type const &""'"); 
    }
    if (!ptr) {
      SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "StringToStringMap_lower_bound" "', argument " "2"" of type '" "std::map< string,string >::key_type const &""'"); 
    }
    arg2 = ptr;
  }
  result = (arg1)->lower_bound((std::map< string,string >::key_type const &)*arg2);
  resultobj = SWIG_NewPointerObj(swig::make_output_iterator(static_cast< const std::map< string,string >::iterator & >(result)),
    swig::SwigPyIterator::descriptor(),SWIG_POINTER_OWN);
  if (SWIG_IsNewObj(res2)) delete arg2;
  return resultobj;
fail:
  if (SWIG_IsNewObj(res2)) delete arg2;
  return NULL;
}


SWIGINTERN PyObject *_wrap_StringToStringMap_upper_bound(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  std::map< string,string > *arg1 = (std::map< string,string > *) 0 ;
  std::map< string,string >::key_type *arg2 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  int res2 = SWIG_OLDOBJ ;
  PyObject *swig_obj[2] ;
  std::map< string,string >::iterator result;
  
  if (!SWIG_Python_UnpackTuple(args, "StringToStringMap_upper_bound", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__mapT_std__string_std__string_std__lessT_std__string_t_std__allocatorT_std__pairT_std__string_const_std__string_t_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "StringToStringMap_upper_bound" "', argument " "1"" of type '" "std::map< string,string > *""'"); 
  }
  arg1 = reinterpret_cast< std::map< string,string > * >(argp1);
  {
    std::string *ptr = (std::string *)0;
    res2 = SWIG_AsPtr_std_string(swig_obj[1], &ptr);
    if (!SWIG_IsOK(res2)) {
      SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "StringToStringMap_upper_bound" "', argument " "2"" of type '" "std::map< string,string >::key_type const &""'"); 
    }
    if (!ptr) {
      SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "StringToStringMap_upper_bound" "', argument " "2"" of type '" "std::map< string,string >::key_type const &""'"); 
    }
    arg2 = ptr;
  }
  result = (arg1)->upper_bound((std::map< string,string >::key_type const &)*arg2);
  resultobj = SWIG_NewPointerObj(swig::make_output_iterator(static_cast< const std::map< string,string >::iterator & >(result)),
    swig::SwigPyIterator::descriptor(),SWIG_POINTER_OWN);
  if (SWIG_IsNewObj(res2)) delete arg2;
  return resultobj;
fail:
  if (SWIG_IsNewObj(res2)) delete arg2;
  return NULL;
}


SWIGINTERN PyObject *_wrap_delete_StringToStringMap(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  std::map< string,string > *arg1 = (std::map< string,string > *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__mapT_std__string_std__string_std__lessT_std__string_t_std__allocatorT_std__pairT_std__string_const_std__string_t_t_t, SWIG_POINTER_DISOWN |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "delete_StringToStringMap" "', argument " "1"" of type '" "std::map< string,string > *""'"); 
  }
  arg1 = reinterpret_cast< std::map< string,string > * >(argp1);
  delete arg1;
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *StringToStringMap_swigregister(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *obj;
  if (!SWIG_Python_UnpackTuple(args, "swigregister", 1, 1, &obj)) return NULL;
  SWIG_TypeNewClientData(SWIGTYPE_p_std__mapT_std__string_std__string_std__lessT_std__string_t_std__allocatorT_std__pairT_std__string_const_std__string_t_t_t, SWIG_NewClientData(obj));
  return SWIG_Py_Void();
}

SWIGINTERN PyObject *StringToStringMap_swiginit(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  return SWIG_Python_InitShadowInstance(args);
}

SWIGINTERN PyObject *_wrap_Error_status_set(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::Error *arg1 = (pj::Error *) 0 ;
  pj_status_t arg2 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  int val2 ;
  int ecode2 = 0 ;
  PyObject *swig_obj[2] ;
  
  if (!SWIG_Python_UnpackTuple(args, "Error_status_set", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__Error, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "Error_status_set" "', argument " "1"" of type '" "pj::Error *""'"); 
  }
  arg1 = reinterpret_cast< pj::Error * >(argp1);
  ecode2 = SWIG_AsVal_int(swig_obj[1], &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "Error_status_set" "', argument " "2"" of type '" "pj_status_t""'");
  } 
  arg2 = static_cast< pj_status_t >(val2);
  if (arg1) (arg1)->status = arg2;
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_Error_status_get(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::Error *arg1 = (pj::Error *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  pj_status_t result;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__Error, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "Error_status_get" "', argument " "1"" of type '" "pj::Error *""'"); 
  }
  arg1 = reinterpret_cast< pj::Error * >(argp1);
  result = (pj_status_t) ((arg1)->status);
  resultobj = SWIG_From_int(static_cast< int >(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_Error_title_set(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::Error *arg1 = (pj::Error *) 0 ;
  pj::string *arg2 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  int res2 = SWIG_OLDOBJ ;
  PyObject *swig_obj[2] ;
  
  if (!SWIG_Python_UnpackTuple(args, "Error_title_set", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__Error, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "Error_title_set" "', argument " "1"" of type '" "pj::Error *""'"); 
  }
  arg1 = reinterpret_cast< pj::Error * >(argp1);
  {
    std::string *ptr = (std::string *)0;
    res2 = SWIG_AsPtr_std_string(swig_obj[1], &ptr);
    if (!SWIG_IsOK(res2)) {
      SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "Error_title_set" "', argument " "2"" of type '" "pj::string const &""'"); 
    }
    if (!ptr) {
      SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "Error_title_set" "', argument " "2"" of type '" "pj::string const &""'"); 
    }
    arg2 = ptr;
  }
  if (arg1) (arg1)->title = *arg2;
  resultobj = SWIG_Py_Void();
  if (SWIG_IsNewObj(res2)) delete arg2;
  return resultobj;
fail:
  if (SWIG_IsNewObj(res2)) delete arg2;
  return NULL;
}


SWIGINTERN PyObject *_wrap_Error_title_get(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::Error *arg1 = (pj::Error *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  pj::string *result = 0 ;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__Error, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "Error_title_get" "', argument " "1"" of type '" "pj::Error *""'"); 
  }
  arg1 = reinterpret_cast< pj::Error * >(argp1);
  result = (pj::string *) & ((arg1)->title);
  resultobj = SWIG_From_std_string(static_cast< std::string >(*result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_Error_reason_set(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::Error *arg1 = (pj::Error *) 0 ;
  pj::string *arg2 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  int res2 = SWIG_OLDOBJ ;
  PyObject *swig_obj[2] ;
  
  if (!SWIG_Python_UnpackTuple(args, "Error_reason_set", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__Error, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "Error_reason_set" "', argument " "1"" of type '" "pj::Error *""'"); 
  }
  arg1 = reinterpret_cast< pj::Error * >(argp1);
  {
    std::string *ptr = (std::string *)0;
    res2 = SWIG_AsPtr_std_string(swig_obj[1], &ptr);
    if (!SWIG_IsOK(res2)) {
      SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "Error_reason_set" "', argument " "2"" of type '" "pj::string const &""'"); 
    }
    if (!ptr) {
      SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "Error_reason_set" "', argument " "2"" of type '" "pj::string const &""'"); 
    }
    arg2 = ptr;
  }
  if (arg1) (arg1)->reason = *arg2;
  resultobj = SWIG_Py_Void();
  if (SWIG_IsNewObj(res2)) delete arg2;
  return resultobj;
fail:
  if (SWIG_IsNewObj(res2)) delete arg2;
  return NULL;
}


SWIGINTERN PyObject *_wrap_Error_reason_get(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::Error *arg1 = (pj::Error *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  pj::string *result = 0 ;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__Error, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "Error_reason_get" "', argument " "1"" of type '" "pj::Error *""'"); 
  }
  arg1 = reinterpret_cast< pj::Error * >(argp1);
  result = (pj::string *) & ((arg1)->reason);
  resultobj = SWIG_From_std_string(static_cast< std::string >(*result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_Error_srcFile_set(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::Error *arg1 = (pj::Error *) 0 ;
  pj::string *arg2 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  int res2 = SWIG_OLDOBJ ;
  PyObject *swig_obj[2] ;
  
  if (!SWIG_Python_UnpackTuple(args, "Error_srcFile_set", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__Error, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "Error_srcFile_set" "', argument " "1"" of type '" "pj::Error *""'"); 
  }
  arg1 = reinterpret_cast< pj::Error * >(argp1);
  {
    std::string *ptr = (std::string *)0;
    res2 = SWIG_AsPtr_std_string(swig_obj[1], &ptr);
    if (!SWIG_IsOK(res2)) {
      SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "Error_srcFile_set" "', argument " "2"" of type '" "pj::string const &""'"); 
    }
    if (!ptr) {
      SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "Error_srcFile_set" "', argument " "2"" of type '" "pj::string const &""'"); 
    }
    arg2 = ptr;
  }
  if (arg1) (arg1)->srcFile = *arg2;
  resultobj = SWIG_Py_Void();
  if (SWIG_IsNewObj(res2)) delete arg2;
  return resultobj;
fail:
  if (SWIG_IsNewObj(res2)) delete arg2;
  return NULL;
}


SWIGINTERN PyObject *_wrap_Error_srcFile_get(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::Error *arg1 = (pj::Error *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  pj::string *result = 0 ;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__Error, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "Error_srcFile_get" "', argument " "1"" of type '" "pj::Error *""'"); 
  }
  arg1 = reinterpret_cast< pj::Error * >(argp1);
  result = (pj::string *) & ((arg1)->srcFile);
  resultobj = SWIG_From_std_string(static_cast< std::string >(*result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_Error_srcLine_set(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::Error *arg1 = (pj::Error *) 0 ;
  int arg2 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  int val2 ;
  int ecode2 = 0 ;
  PyObject *swig_obj[2] ;
  
  if (!SWIG_Python_UnpackTuple(args, "Error_srcLine_set", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__Error, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "Error_srcLine_set" "', argument " "1"" of type '" "pj::Error *""'"); 
  }
  arg1 = reinterpret_cast< pj::Error * >(argp1);
  ecode2 = SWIG_AsVal_int(swig_obj[1], &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "Error_srcLine_set" "', argument " "2"" of type '" "int""'");
  } 
  arg2 = static_cast< int >(val2);
  if (arg1) (arg1)->srcLine = arg2;
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_Error_srcLine_get(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::Error *arg1 = (pj::Error *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  int result;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__Error, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "Error_srcLine_get" "', argument " "1"" of type '" "pj::Error *""'"); 
  }
  arg1 = reinterpret_cast< pj::Error * >(argp1);
  result = (int) ((arg1)->srcLine);
  resultobj = SWIG_From_int(static_cast< int >(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_Error_info__SWIG_0(PyObject *SWIGUNUSEDPARM(self), Py_ssize_t nobjs, PyObject **swig_obj) {
  PyObject *resultobj = 0;
  pj::Error *arg1 = (pj::Error *) 0 ;
  bool arg2 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  bool val2 ;
  int ecode2 = 0 ;
  pj::string result;
  
  if ((nobjs < 2) || (nobjs > 2)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__Error, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "Error_info" "', argument " "1"" of type '" "pj::Error const *""'"); 
  }
  arg1 = reinterpret_cast< pj::Error * >(argp1);
  ecode2 = SWIG_AsVal_bool(swig_obj[1], &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "Error_info" "', argument " "2"" of type '" "bool""'");
  } 
  arg2 = static_cast< bool >(val2);
  result = ((pj::Error const *)arg1)->info(arg2);
  resultobj = SWIG_From_std_string(static_cast< std::string >(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_Error_info__SWIG_1(PyObject *SWIGUNUSEDPARM(self), Py_ssize_t nobjs, PyObject **swig_obj) {
  PyObject *resultobj = 0;
  pj::Error *arg1 = (pj::Error *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  pj::string result;
  
  if ((nobjs < 1) || (nobjs > 1)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__Error, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "Error_info" "', argument " "1"" of type '" "pj::Error const *""'"); 
  }
  arg1 = reinterpret_cast< pj::Error * >(argp1);
  result = ((pj::Error const *)arg1)->info();
  resultobj = SWIG_From_std_string(static_cast< std::string >(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_Error_info(PyObject *self, PyObject *args) {
  Py_ssize_t argc;
  PyObject *argv[3] = {
    0
  };
  
  if (!(argc = SWIG_Python_UnpackTuple(args, "Error_info", 0, 2, argv))) SWIG_fail;
  --argc;
  if (argc == 1) {
    int _v;
    void *vptr = 0;
    int res = SWIG_ConvertPtr(argv[0], &vptr, SWIGTYPE_p_pj__Error, 0);
    _v = SWIG_CheckState(res);
    if (_v) {
      return _wrap_Error_info__SWIG_1(self, argc, argv);
    }
  }
  if (argc == 2) {
    int _v;
    void *vptr = 0;
    int res = SWIG_ConvertPtr(argv[0], &vptr, SWIGTYPE_p_pj__Error, 0);
    _v = SWIG_CheckState(res);
    if (_v) {
      {
        int res = SWIG_AsVal_bool(argv[1], NULL);
        _v = SWIG_CheckState(res);
      }
      if (_v) {
        return _wrap_Error_info__SWIG_0(self, argc, argv);
      }
    }
  }
  
fail:
  SWIG_Python_RaiseOrModifyTypeError("Wrong number or type of arguments for overloaded function 'Error_info'.\n"
    "  Possible C/C++ prototypes are:\n"
    "    pj::Error::info(bool) const\n"
    "    pj::Error::info() const\n");
  return 0;
}


SWIGINTERN PyObject *_wrap_new_Error__SWIG_0(PyObject *SWIGUNUSEDPARM(self), Py_ssize_t nobjs, PyObject **SWIGUNUSEDPARM(swig_obj)) {
  PyObject *resultobj = 0;
  pj::Error *result = 0 ;
  
  if ((nobjs < 0) || (nobjs > 0)) SWIG_fail;
  result = (pj::Error *)new pj::Error();
  resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(result), SWIGTYPE_p_pj__Error, SWIG_POINTER_NEW |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_new_Error__SWIG_1(PyObject *SWIGUNUSEDPARM(self), Py_ssize_t nobjs, PyObject **swig_obj) {
  PyObject *resultobj = 0;
  pj_status_t arg1 ;
  pj::string *arg2 = 0 ;
  pj::string *arg3 = 0 ;
  pj::string *arg4 = 0 ;
  int arg5 ;
  int val1 ;
  int ecode1 = 0 ;
  int res2 = SWIG_OLDOBJ ;
  int res3 = SWIG_OLDOBJ ;
  int res4 = SWIG_OLDOBJ ;
  int val5 ;
  int ecode5 = 0 ;
  pj::Error *result = 0 ;
  
  if ((nobjs < 5) || (nobjs > 5)) SWIG_fail;
  ecode1 = SWIG_AsVal_int(swig_obj[0], &val1);
  if (!SWIG_IsOK(ecode1)) {
    SWIG_exception_fail(SWIG_ArgError(ecode1), "in method '" "new_Error" "', argument " "1"" of type '" "pj_status_t""'");
  } 
  arg1 = static_cast< pj_status_t >(val1);
  {
    std::string *ptr = (std::string *)0;
    res2 = SWIG_AsPtr_std_string(swig_obj[1], &ptr);
    if (!SWIG_IsOK(res2)) {
      SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "new_Error" "', argument " "2"" of type '" "pj::string const &""'"); 
    }
    if (!ptr) {
      SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "new_Error" "', argument " "2"" of type '" "pj::string const &""'"); 
    }
    arg2 = ptr;
  }
  {
    std::string *ptr = (std::string *)0;
    res3 = SWIG_AsPtr_std_string(swig_obj[2], &ptr);
    if (!SWIG_IsOK(res3)) {
      SWIG_exception_fail(SWIG_ArgError(res3), "in method '" "new_Error" "', argument " "3"" of type '" "pj::string const &""'"); 
    }
    if (!ptr) {
      SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "new_Error" "', argument " "3"" of type '" "pj::string const &""'"); 
    }
    arg3 = ptr;
  }
  {
    std::string *ptr = (std::string *)0;
    res4 = SWIG_AsPtr_std_string(swig_obj[3], &ptr);
    if (!SWIG_IsOK(res4)) {
      SWIG_exception_fail(SWIG_ArgError(res4), "in method '" "new_Error" "', argument " "4"" of type '" "pj::string const &""'"); 
    }
    if (!ptr) {
      SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "new_Error" "', argument " "4"" of type '" "pj::string const &""'"); 
    }
    arg4 = ptr;
  }
  ecode5 = SWIG_AsVal_int(swig_obj[4], &val5);
  if (!SWIG_IsOK(ecode5)) {
    SWIG_exception_fail(SWIG_ArgError(ecode5), "in method '" "new_Error" "', argument " "5"" of type '" "int""'");
  } 
  arg5 = static_cast< int >(val5);
  result = (pj::Error *)new pj::Error(arg1,(pj::string const &)*arg2,(pj::string const &)*arg3,(pj::string const &)*arg4,arg5);
  resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(result), SWIGTYPE_p_pj__Error, SWIG_POINTER_NEW |  0 );
  if (SWIG_IsNewObj(res2)) delete arg2;
  if (SWIG_IsNewObj(res3)) delete arg3;
  if (SWIG_IsNewObj(res4)) delete arg4;
  return resultobj;
fail:
  if (SWIG_IsNewObj(res2)) delete arg2;
  if (SWIG_IsNewObj(res3)) delete arg3;
  if (SWIG_IsNewObj(res4)) delete arg4;
  return NULL;
}


SWIGINTERN PyObject *_wrap_new_Error(PyObject *self, PyObject *args) {
  Py_ssize_t argc;
  PyObject *argv[6] = {
    0
  };
  
  if (!(argc = SWIG_Python_UnpackTuple(args, "new_Error", 0, 5, argv))) SWIG_fail;
  --argc;
  if (argc == 0) {
    return _wrap_new_Error__SWIG_0(self, argc, argv);
  }
  if (argc == 5) {
    int _v;
    {
      int res = SWIG_AsVal_int(argv[0], NULL);
      _v = SWIG_CheckState(res);
    }
    if (_v) {
      int res = SWIG_AsPtr_std_string(argv[1], (std::string**)(0));
      _v = SWIG_CheckState(res);
      if (_v) {
        int res = SWIG_AsPtr_std_string(argv[2], (std::string**)(0));
        _v = SWIG_CheckState(res);
        if (_v) {
          int res = SWIG_AsPtr_std_string(argv[3], (std::string**)(0));
          _v = SWIG_CheckState(res);
          if (_v) {
            {
              int res = SWIG_AsVal_int(argv[4], NULL);
              _v = SWIG_CheckState(res);
            }
            if (_v) {
              return _wrap_new_Error__SWIG_1(self, argc, argv);
            }
          }
        }
      }
    }
  }
  
fail:
  SWIG_Python_RaiseOrModifyTypeError("Wrong number or type of arguments for overloaded function 'new_Error'.\n"
    "  Possible C/C++ prototypes are:\n"
    "    pj::Error::Error()\n"
    "    pj::Error::Error(pj_status_t,pj::string const &,pj::string const &,pj::string const &,int)\n");
  return 0;
}


SWIGINTERN PyObject *_wrap_delete_Error(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::Error *arg1 = (pj::Error *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__Error, SWIG_POINTER_DISOWN |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "delete_Error" "', argument " "1"" of type '" "pj::Error *""'"); 
  }
  arg1 = reinterpret_cast< pj::Error * >(argp1);
  delete arg1;
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *Error_swigregister(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *obj;
  if (!SWIG_Python_UnpackTuple(args, "swigregister", 1, 1, &obj)) return NULL;
  SWIG_TypeNewClientData(SWIGTYPE_p_pj__Error, SWIG_NewClientData(obj));
  return SWIG_Py_Void();
}

SWIGINTERN PyObject *Error_swiginit(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  return SWIG_Python_InitShadowInstance(args);
}

SWIGINTERN PyObject *_wrap_Version_major_set(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::Version *arg1 = (pj::Version *) 0 ;
  int arg2 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  int val2 ;
  int ecode2 = 0 ;
  PyObject *swig_obj[2] ;
  
  if (!SWIG_Python_UnpackTuple(args, "Version_major_set", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__Version, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "Version_major_set" "', argument " "1"" of type '" "pj::Version *""'"); 
  }
  arg1 = reinterpret_cast< pj::Version * >(argp1);
  ecode2 = SWIG_AsVal_int(swig_obj[1], &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "Version_major_set" "', argument " "2"" of type '" "int""'");
  } 
  arg2 = static_cast< int >(val2);
  if (arg1) (arg1)->major = arg2;
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_Version_major_get(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::Version *arg1 = (pj::Version *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  int result;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__Version, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "Version_major_get" "', argument " "1"" of type '" "pj::Version *""'"); 
  }
  arg1 = reinterpret_cast< pj::Version * >(argp1);
  result = (int) ((arg1)->major);
  resultobj = SWIG_From_int(static_cast< int >(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_Version_minor_set(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::Version *arg1 = (pj::Version *) 0 ;
  int arg2 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  int val2 ;
  int ecode2 = 0 ;
  PyObject *swig_obj[2] ;
  
  if (!SWIG_Python_UnpackTuple(args, "Version_minor_set", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__Version, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "Version_minor_set" "', argument " "1"" of type '" "pj::Version *""'"); 
  }
  arg1 = reinterpret_cast< pj::Version * >(argp1);
  ecode2 = SWIG_AsVal_int(swig_obj[1], &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "Version_minor_set" "', argument " "2"" of type '" "int""'");
  } 
  arg2 = static_cast< int >(val2);
  if (arg1) (arg1)->minor = arg2;
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_Version_minor_get(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::Version *arg1 = (pj::Version *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  int result;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__Version, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "Version_minor_get" "', argument " "1"" of type '" "pj::Version *""'"); 
  }
  arg1 = reinterpret_cast< pj::Version * >(argp1);
  result = (int) ((arg1)->minor);
  resultobj = SWIG_From_int(static_cast< int >(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_Version_rev_set(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::Version *arg1 = (pj::Version *) 0 ;
  int arg2 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  int val2 ;
  int ecode2 = 0 ;
  PyObject *swig_obj[2] ;
  
  if (!SWIG_Python_UnpackTuple(args, "Version_rev_set", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__Version, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "Version_rev_set" "', argument " "1"" of type '" "pj::Version *""'"); 
  }
  arg1 = reinterpret_cast< pj::Version * >(argp1);
  ecode2 = SWIG_AsVal_int(swig_obj[1], &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "Version_rev_set" "', argument " "2"" of type '" "int""'");
  } 
  arg2 = static_cast< int >(val2);
  if (arg1) (arg1)->rev = arg2;
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_Version_rev_get(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::Version *arg1 = (pj::Version *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  int result;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__Version, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "Version_rev_get" "', argument " "1"" of type '" "pj::Version *""'"); 
  }
  arg1 = reinterpret_cast< pj::Version * >(argp1);
  result = (int) ((arg1)->rev);
  resultobj = SWIG_From_int(static_cast< int >(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_Version_suffix_set(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::Version *arg1 = (pj::Version *) 0 ;
  pj::string *arg2 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  int res2 = SWIG_OLDOBJ ;
  PyObject *swig_obj[2] ;
  
  if (!SWIG_Python_UnpackTuple(args, "Version_suffix_set", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__Version, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "Version_suffix_set" "', argument " "1"" of type '" "pj::Version *""'"); 
  }
  arg1 = reinterpret_cast< pj::Version * >(argp1);
  {
    std::string *ptr = (std::string *)0;
    res2 = SWIG_AsPtr_std_string(swig_obj[1], &ptr);
    if (!SWIG_IsOK(res2)) {
      SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "Version_suffix_set" "', argument " "2"" of type '" "pj::string const &""'"); 
    }
    if (!ptr) {
      SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "Version_suffix_set" "', argument " "2"" of type '" "pj::string const &""'"); 
    }
    arg2 = ptr;
  }
  if (arg1) (arg1)->suffix = *arg2;
  resultobj = SWIG_Py_Void();
  if (SWIG_IsNewObj(res2)) delete arg2;
  return resultobj;
fail:
  if (SWIG_IsNewObj(res2)) delete arg2;
  return NULL;
}


SWIGINTERN PyObject *_wrap_Version_suffix_get(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::Version *arg1 = (pj::Version *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  pj::string *result = 0 ;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__Version, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "Version_suffix_get" "', argument " "1"" of type '" "pj::Version *""'"); 
  }
  arg1 = reinterpret_cast< pj::Version * >(argp1);
  result = (pj::string *) & ((arg1)->suffix);
  resultobj = SWIG_From_std_string(static_cast< std::string >(*result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_Version_full_set(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::Version *arg1 = (pj::Version *) 0 ;
  pj::string *arg2 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  int res2 = SWIG_OLDOBJ ;
  PyObject *swig_obj[2] ;
  
  if (!SWIG_Python_UnpackTuple(args, "Version_full_set", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__Version, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "Version_full_set" "', argument " "1"" of type '" "pj::Version *""'"); 
  }
  arg1 = reinterpret_cast< pj::Version * >(argp1);
  {
    std::string *ptr = (std::string *)0;
    res2 = SWIG_AsPtr_std_string(swig_obj[1], &ptr);
    if (!SWIG_IsOK(res2)) {
      SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "Version_full_set" "', argument " "2"" of type '" "pj::string const &""'"); 
    }
    if (!ptr) {
      SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "Version_full_set" "', argument " "2"" of type '" "pj::string const &""'"); 
    }
    arg2 = ptr;
  }
  if (arg1) (arg1)->full = *arg2;
  resultobj = SWIG_Py_Void();
  if (SWIG_IsNewObj(res2)) delete arg2;
  return resultobj;
fail:
  if (SWIG_IsNewObj(res2)) delete arg2;
  return NULL;
}


SWIGINTERN PyObject *_wrap_Version_full_get(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::Version *arg1 = (pj::Version *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  pj::string *result = 0 ;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__Version, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "Version_full_get" "', argument " "1"" of type '" "pj::Version *""'"); 
  }
  arg1 = reinterpret_cast< pj::Version * >(argp1);
  result = (pj::string *) & ((arg1)->full);
  resultobj = SWIG_From_std_string(static_cast< std::string >(*result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_Version_numeric_set(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::Version *arg1 = (pj::Version *) 0 ;
  unsigned int arg2 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  unsigned int val2 ;
  int ecode2 = 0 ;
  PyObject *swig_obj[2] ;
  
  if (!SWIG_Python_UnpackTuple(args, "Version_numeric_set", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__Version, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "Version_numeric_set" "', argument " "1"" of type '" "pj::Version *""'"); 
  }
  arg1 = reinterpret_cast< pj::Version * >(argp1);
  ecode2 = SWIG_AsVal_unsigned_SS_int(swig_obj[1], &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "Version_numeric_set" "', argument " "2"" of type '" "unsigned int""'");
  } 
  arg2 = static_cast< unsigned int >(val2);
  if (arg1) (arg1)->numeric = arg2;
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_Version_numeric_get(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::Version *arg1 = (pj::Version *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  unsigned int result;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__Version, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "Version_numeric_get" "', argument " "1"" of type '" "pj::Version *""'"); 
  }
  arg1 = reinterpret_cast< pj::Version * >(argp1);
  result = (unsigned int) ((arg1)->numeric);
  resultobj = SWIG_From_unsigned_SS_int(static_cast< unsigned int >(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_new_Version(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::Version *result = 0 ;
  
  if (!SWIG_Python_UnpackTuple(args, "new_Version", 0, 0, 0)) SWIG_fail;
  result = (pj::Version *)new pj::Version();
  resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(result), SWIGTYPE_p_pj__Version, SWIG_POINTER_NEW |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_delete_Version(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::Version *arg1 = (pj::Version *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__Version, SWIG_POINTER_DISOWN |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "delete_Version" "', argument " "1"" of type '" "pj::Version *""'"); 
  }
  arg1 = reinterpret_cast< pj::Version * >(argp1);
  delete arg1;
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *Version_swigregister(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *obj;
  if (!SWIG_Python_UnpackTuple(args, "swigregister", 1, 1, &obj)) return NULL;
  SWIG_TypeNewClientData(SWIGTYPE_p_pj__Version, SWIG_NewClientData(obj));
  return SWIG_Py_Void();
}

SWIGINTERN PyObject *Version_swiginit(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  return SWIG_Python_InitShadowInstance(args);
}

SWIGINTERN PyObject *_wrap_TimeVal_sec_set(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::TimeVal *arg1 = (pj::TimeVal *) 0 ;
  long arg2 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  long val2 ;
  int ecode2 = 0 ;
  PyObject *swig_obj[2] ;
  
  if (!SWIG_Python_UnpackTuple(args, "TimeVal_sec_set", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__TimeVal, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "TimeVal_sec_set" "', argument " "1"" of type '" "pj::TimeVal *""'"); 
  }
  arg1 = reinterpret_cast< pj::TimeVal * >(argp1);
  ecode2 = SWIG_AsVal_long(swig_obj[1], &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "TimeVal_sec_set" "', argument " "2"" of type '" "long""'");
  } 
  arg2 = static_cast< long >(val2);
  if (arg1) (arg1)->sec = arg2;
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_TimeVal_sec_get(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::TimeVal *arg1 = (pj::TimeVal *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  long result;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__TimeVal, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "TimeVal_sec_get" "', argument " "1"" of type '" "pj::TimeVal *""'"); 
  }
  arg1 = reinterpret_cast< pj::TimeVal * >(argp1);
  result = (long) ((arg1)->sec);
  resultobj = SWIG_From_long(static_cast< long >(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_TimeVal_msec_set(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::TimeVal *arg1 = (pj::TimeVal *) 0 ;
  long arg2 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  long val2 ;
  int ecode2 = 0 ;
  PyObject *swig_obj[2] ;
  
  if (!SWIG_Python_UnpackTuple(args, "TimeVal_msec_set", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__TimeVal, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "TimeVal_msec_set" "', argument " "1"" of type '" "pj::TimeVal *""'"); 
  }
  arg1 = reinterpret_cast< pj::TimeVal * >(argp1);
  ecode2 = SWIG_AsVal_long(swig_obj[1], &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "TimeVal_msec_set" "', argument " "2"" of type '" "long""'");
  } 
  arg2 = static_cast< long >(val2);
  if (arg1) (arg1)->msec = arg2;
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_TimeVal_msec_get(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::TimeVal *arg1 = (pj::TimeVal *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  long result;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__TimeVal, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "TimeVal_msec_get" "', argument " "1"" of type '" "pj::TimeVal *""'"); 
  }
  arg1 = reinterpret_cast< pj::TimeVal * >(argp1);
  result = (long) ((arg1)->msec);
  resultobj = SWIG_From_long(static_cast< long >(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_new_TimeVal(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::TimeVal *result = 0 ;
  
  if (!SWIG_Python_UnpackTuple(args, "new_TimeVal", 0, 0, 0)) SWIG_fail;
  result = (pj::TimeVal *)new pj::TimeVal();
  resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(result), SWIGTYPE_p_pj__TimeVal, SWIG_POINTER_NEW |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_delete_TimeVal(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::TimeVal *arg1 = (pj::TimeVal *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__TimeVal, SWIG_POINTER_DISOWN |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "delete_TimeVal" "', argument " "1"" of type '" "pj::TimeVal *""'"); 
  }
  arg1 = reinterpret_cast< pj::TimeVal * >(argp1);
  delete arg1;
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *TimeVal_swigregister(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *obj;
  if (!SWIG_Python_UnpackTuple(args, "swigregister", 1, 1, &obj)) return NULL;
  SWIG_TypeNewClientData(SWIGTYPE_p_pj__TimeVal, SWIG_NewClientData(obj));
  return SWIG_Py_Void();
}

SWIGINTERN PyObject *TimeVal_swiginit(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  return SWIG_Python_InitShadowInstance(args);
}

SWIGINTERN PyObject *_wrap_delete_PersistentObject(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::PersistentObject *arg1 = (pj::PersistentObject *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__PersistentObject, SWIG_POINTER_DISOWN |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "delete_PersistentObject" "', argument " "1"" of type '" "pj::PersistentObject *""'"); 
  }
  arg1 = reinterpret_cast< pj::PersistentObject * >(argp1);
  delete arg1;
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_PersistentObject_readObject(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::PersistentObject *arg1 = (pj::PersistentObject *) 0 ;
  pj::ContainerNode *arg2 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  void *argp2 = 0 ;
  int res2 = 0 ;
  PyObject *swig_obj[2] ;
  
  if (!SWIG_Python_UnpackTuple(args, "PersistentObject_readObject", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__PersistentObject, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "PersistentObject_readObject" "', argument " "1"" of type '" "pj::PersistentObject *""'"); 
  }
  arg1 = reinterpret_cast< pj::PersistentObject * >(argp1);
  res2 = SWIG_ConvertPtr(swig_obj[1], &argp2, SWIGTYPE_p_pj__ContainerNode,  0  | 0);
  if (!SWIG_IsOK(res2)) {
    SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "PersistentObject_readObject" "', argument " "2"" of type '" "pj::ContainerNode const &""'"); 
  }
  if (!argp2) {
    SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "PersistentObject_readObject" "', argument " "2"" of type '" "pj::ContainerNode const &""'"); 
  }
  arg2 = reinterpret_cast< pj::ContainerNode * >(argp2);
  try {
    (arg1)->readObject((pj::ContainerNode const &)*arg2);
  } catch(pj::Error &_e) {
    SWIG_Python_Raise(SWIG_NewPointerObj((new pj::Error(static_cast< const pj::Error& >(_e))),SWIGTYPE_p_pj__Error,SWIG_POINTER_OWN), "pj::Error", SWIGTYPE_p_pj__Error); SWIG_fail;
  }
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_PersistentObject_writeObject(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::PersistentObject *arg1 = (pj::PersistentObject *) 0 ;
  pj::ContainerNode *arg2 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  void *argp2 = 0 ;
  int res2 = 0 ;
  PyObject *swig_obj[2] ;
  
  if (!SWIG_Python_UnpackTuple(args, "PersistentObject_writeObject", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__PersistentObject, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "PersistentObject_writeObject" "', argument " "1"" of type '" "pj::PersistentObject const *""'"); 
  }
  arg1 = reinterpret_cast< pj::PersistentObject * >(argp1);
  res2 = SWIG_ConvertPtr(swig_obj[1], &argp2, SWIGTYPE_p_pj__ContainerNode,  0 );
  if (!SWIG_IsOK(res2)) {
    SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "PersistentObject_writeObject" "', argument " "2"" of type '" "pj::ContainerNode &""'"); 
  }
  if (!argp2) {
    SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "PersistentObject_writeObject" "', argument " "2"" of type '" "pj::ContainerNode &""'"); 
  }
  arg2 = reinterpret_cast< pj::ContainerNode * >(argp2);
  try {
    ((pj::PersistentObject const *)arg1)->writeObject(*arg2);
  } catch(pj::Error &_e) {
    SWIG_Python_Raise(SWIG_NewPointerObj((new pj::Error(static_cast< const pj::Error& >(_e))),SWIGTYPE_p_pj__Error,SWIG_POINTER_OWN), "pj::Error", SWIGTYPE_p_pj__Error); SWIG_fail;
  }
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *PersistentObject_swigregister(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *obj;
  if (!SWIG_Python_UnpackTuple(args, "swigregister", 1, 1, &obj)) return NULL;
  SWIG_TypeNewClientData(SWIGTYPE_p_pj__PersistentObject, SWIG_NewClientData(obj));
  return SWIG_Py_Void();
}

SWIGINTERN PyObject *_wrap_delete_PersistentDocument(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::PersistentDocument *arg1 = (pj::PersistentDocument *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__PersistentDocument, SWIG_POINTER_DISOWN |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "delete_PersistentDocument" "', argument " "1"" of type '" "pj::PersistentDocument *""'"); 
  }
  arg1 = reinterpret_cast< pj::PersistentDocument * >(argp1);
  delete arg1;
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_PersistentDocument_loadFile(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::PersistentDocument *arg1 = (pj::PersistentDocument *) 0 ;
  pj::string *arg2 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  int res2 = SWIG_OLDOBJ ;
  PyObject *swig_obj[2] ;
  
  if (!SWIG_Python_UnpackTuple(args, "PersistentDocument_loadFile", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__PersistentDocument, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "PersistentDocument_loadFile" "', argument " "1"" of type '" "pj::PersistentDocument *""'"); 
  }
  arg1 = reinterpret_cast< pj::PersistentDocument * >(argp1);
  {
    std::string *ptr = (std::string *)0;
    res2 = SWIG_AsPtr_std_string(swig_obj[1], &ptr);
    if (!SWIG_IsOK(res2)) {
      SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "PersistentDocument_loadFile" "', argument " "2"" of type '" "pj::string const &""'"); 
    }
    if (!ptr) {
      SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "PersistentDocument_loadFile" "', argument " "2"" of type '" "pj::string const &""'"); 
    }
    arg2 = ptr;
  }
  try {
    (arg1)->loadFile((pj::string const &)*arg2);
  } catch(pj::Error &_e) {
    SWIG_Python_Raise(SWIG_NewPointerObj((new pj::Error(static_cast< const pj::Error& >(_e))),SWIGTYPE_p_pj__Error,SWIG_POINTER_OWN), "pj::Error", SWIGTYPE_p_pj__Error); SWIG_fail;
  }
  resultobj = SWIG_Py_Void();
  if (SWIG_IsNewObj(res2)) delete arg2;
  return resultobj;
fail:
  if (SWIG_IsNewObj(res2)) delete arg2;
  return NULL;
}


SWIGINTERN PyObject *_wrap_PersistentDocument_loadString(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::PersistentDocument *arg1 = (pj::PersistentDocument *) 0 ;
  pj::string *arg2 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  int res2 = SWIG_OLDOBJ ;
  PyObject *swig_obj[2] ;
  
  if (!SWIG_Python_UnpackTuple(args, "PersistentDocument_loadString", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__PersistentDocument, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "PersistentDocument_loadString" "', argument " "1"" of type '" "pj::PersistentDocument *""'"); 
  }
  arg1 = reinterpret_cast< pj::PersistentDocument * >(argp1);
  {
    std::string *ptr = (std::string *)0;
    res2 = SWIG_AsPtr_std_string(swig_obj[1], &ptr);
    if (!SWIG_IsOK(res2)) {
      SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "PersistentDocument_loadString" "', argument " "2"" of type '" "pj::string const &""'"); 
    }
    if (!ptr) {
      SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "PersistentDocument_loadString" "', argument " "2"" of type '" "pj::string const &""'"); 
    }
    arg2 = ptr;
  }
  try {
    (arg1)->loadString((pj::string const &)*arg2);
  } catch(pj::Error &_e) {
    SWIG_Python_Raise(SWIG_NewPointerObj((new pj::Error(static_cast< const pj::Error& >(_e))),SWIGTYPE_p_pj__Error,SWIG_POINTER_OWN), "pj::Error", SWIGTYPE_p_pj__Error); SWIG_fail;
  }
  resultobj = SWIG_Py_Void();
  if (SWIG_IsNewObj(res2)) delete arg2;
  return resultobj;
fail:
  if (SWIG_IsNewObj(res2)) delete arg2;
  return NULL;
}


SWIGINTERN PyObject *_wrap_PersistentDocument_saveFile(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::PersistentDocument *arg1 = (pj::PersistentDocument *) 0 ;
  pj::string *arg2 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  int res2 = SWIG_OLDOBJ ;
  PyObject *swig_obj[2] ;
  
  if (!SWIG_Python_UnpackTuple(args, "PersistentDocument_saveFile", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__PersistentDocument, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "PersistentDocument_saveFile" "', argument " "1"" of type '" "pj::PersistentDocument *""'"); 
  }
  arg1 = reinterpret_cast< pj::PersistentDocument * >(argp1);
  {
    std::string *ptr = (std::string *)0;
    res2 = SWIG_AsPtr_std_string(swig_obj[1], &ptr);
    if (!SWIG_IsOK(res2)) {
      SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "PersistentDocument_saveFile" "', argument " "2"" of type '" "pj::string const &""'"); 
    }
    if (!ptr) {
      SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "PersistentDocument_saveFile" "', argument " "2"" of type '" "pj::string const &""'"); 
    }
    arg2 = ptr;
  }
  try {
    (arg1)->saveFile((pj::string const &)*arg2);
  } catch(pj::Error &_e) {
    SWIG_Python_Raise(SWIG_NewPointerObj((new pj::Error(static_cast< const pj::Error& >(_e))),SWIGTYPE_p_pj__Error,SWIG_POINTER_OWN), "pj::Error", SWIGTYPE_p_pj__Error); SWIG_fail;
  }
  resultobj = SWIG_Py_Void();
  if (SWIG_IsNewObj(res2)) delete arg2;
  return resultobj;
fail:
  if (SWIG_IsNewObj(res2)) delete arg2;
  return NULL;
}


SWIGINTERN PyObject *_wrap_PersistentDocument_saveString(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::PersistentDocument *arg1 = (pj::PersistentDocument *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  pj::string result;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__PersistentDocument, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "PersistentDocument_saveString" "', argument " "1"" of type '" "pj::PersistentDocument *""'"); 
  }
  arg1 = reinterpret_cast< pj::PersistentDocument * >(argp1);
  try {
    result = (arg1)->saveString();
  } catch(pj::Error &_e) {
    SWIG_Python_Raise(SWIG_NewPointerObj((new pj::Error(static_cast< const pj::Error& >(_e))),SWIGTYPE_p_pj__Error,SWIG_POINTER_OWN), "pj::Error", SWIGTYPE_p_pj__Error); SWIG_fail;
  }
  resultobj = SWIG_From_std_string(static_cast< std::string >(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_PersistentDocument_getRootContainer(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::PersistentDocument *arg1 = (pj::PersistentDocument *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  pj::ContainerNode *result = 0 ;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__PersistentDocument, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "PersistentDocument_getRootContainer" "', argument " "1"" of type '" "pj::PersistentDocument const *""'"); 
  }
  arg1 = reinterpret_cast< pj::PersistentDocument * >(argp1);
  result = (pj::ContainerNode *) &((pj::PersistentDocument const *)arg1)->getRootContainer();
  resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(result), SWIGTYPE_p_pj__ContainerNode, 0 |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_PersistentDocument_hasUnread(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::PersistentDocument *arg1 = (pj::PersistentDocument *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  bool result;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__PersistentDocument, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "PersistentDocument_hasUnread" "', argument " "1"" of type '" "pj::PersistentDocument const *""'"); 
  }
  arg1 = reinterpret_cast< pj::PersistentDocument * >(argp1);
  result = (bool)((pj::PersistentDocument const *)arg1)->hasUnread();
  resultobj = SWIG_From_bool(static_cast< bool >(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_PersistentDocument_unreadName(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::PersistentDocument *arg1 = (pj::PersistentDocument *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  pj::string result;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__PersistentDocument, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "PersistentDocument_unreadName" "', argument " "1"" of type '" "pj::PersistentDocument const *""'"); 
  }
  arg1 = reinterpret_cast< pj::PersistentDocument * >(argp1);
  try {
    result = ((pj::PersistentDocument const *)arg1)->unreadName();
  } catch(pj::Error &_e) {
    SWIG_Python_Raise(SWIG_NewPointerObj((new pj::Error(static_cast< const pj::Error& >(_e))),SWIGTYPE_p_pj__Error,SWIG_POINTER_OWN), "pj::Error", SWIGTYPE_p_pj__Error); SWIG_fail;
  }
  resultobj = SWIG_From_std_string(static_cast< std::string >(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_PersistentDocument_readInt__SWIG_0(PyObject *SWIGUNUSEDPARM(self), Py_ssize_t nobjs, PyObject **swig_obj) {
  PyObject *resultobj = 0;
  pj::PersistentDocument *arg1 = (pj::PersistentDocument *) 0 ;
  pj::string *arg2 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  int res2 = SWIG_OLDOBJ ;
  int result;
  
  if ((nobjs < 2) || (nobjs > 2)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__PersistentDocument, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "PersistentDocument_readInt" "', argument " "1"" of type '" "pj::PersistentDocument const *""'"); 
  }
  arg1 = reinterpret_cast< pj::PersistentDocument * >(argp1);
  {
    std::string *ptr = (std::string *)0;
    res2 = SWIG_AsPtr_std_string(swig_obj[1], &ptr);
    if (!SWIG_IsOK(res2)) {
      SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "PersistentDocument_readInt" "', argument " "2"" of type '" "pj::string const &""'"); 
    }
    if (!ptr) {
      SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "PersistentDocument_readInt" "', argument " "2"" of type '" "pj::string const &""'"); 
    }
    arg2 = ptr;
  }
  try {
    result = (int)((pj::PersistentDocument const *)arg1)->readInt((pj::string const &)*arg2);
  } catch(pj::Error &_e) {
    SWIG_Python_Raise(SWIG_NewPointerObj((new pj::Error(static_cast< const pj::Error& >(_e))),SWIGTYPE_p_pj__Error,SWIG_POINTER_OWN), "pj::Error", SWIGTYPE_p_pj__Error); SWIG_fail;
  }
  resultobj = SWIG_From_int(static_cast< int >(result));
  if (SWIG_IsNewObj(res2)) delete arg2;
  return resultobj;
fail:
  if (SWIG_IsNewObj(res2)) delete arg2;
  return NULL;
}


SWIGINTERN PyObject *_wrap_PersistentDocument_readInt__SWIG_1(PyObject *SWIGUNUSEDPARM(self), Py_ssize_t nobjs, PyObject **swig_obj) {
  PyObject *resultobj = 0;
  pj::PersistentDocument *arg1 = (pj::PersistentDocument *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  int result;
  
  if ((nobjs < 1) || (nobjs > 1)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__PersistentDocument, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "PersistentDocument_readInt" "', argument " "1"" of type '" "pj::PersistentDocument const *""'"); 
  }
  arg1 = reinterpret_cast< pj::PersistentDocument * >(argp1);
  try {
    result = (int)((pj::PersistentDocument const *)arg1)->readInt();
  } catch(pj::Error &_e) {
    SWIG_Python_Raise(SWIG_NewPointerObj((new pj::Error(static_cast< const pj::Error& >(_e))),SWIGTYPE_p_pj__Error,SWIG_POINTER_OWN), "pj::Error", SWIGTYPE_p_pj__Error); SWIG_fail;
  }
  resultobj = SWIG_From_int(static_cast< int >(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_PersistentDocument_readInt(PyObject *self, PyObject *args) {
  Py_ssize_t argc;
  PyObject *argv[3] = {
    0
  };
  
  if (!(argc = SWIG_Python_UnpackTuple(args, "PersistentDocument_readInt", 0, 2, argv))) SWIG_fail;
  --argc;
  if (argc == 1) {
    int _v;
    void *vptr = 0;
    int res = SWIG_ConvertPtr(argv[0], &vptr, SWIGTYPE_p_pj__PersistentDocument, 0);
    _v = SWIG_CheckState(res);
    if (_v) {
      return _wrap_PersistentDocument_readInt__SWIG_1(self, argc, argv);
    }
  }
  if (argc == 2) {
    int _v;
    void *vptr = 0;
    int res = SWIG_ConvertPtr(argv[0], &vptr, SWIGTYPE_p_pj__PersistentDocument, 0);
    _v = SWIG_CheckState(res);
    if (_v) {
      int res = SWIG_AsPtr_std_string(argv[1], (std::string**)(0));
      _v = SWIG_CheckState(res);
      if (_v) {
        return _wrap_PersistentDocument_readInt__SWIG_0(self, argc, argv);
      }
    }
  }
  
fail:
  SWIG_Python_RaiseOrModifyTypeError("Wrong number or type of arguments for overloaded function 'PersistentDocument_readInt'.\n"
    "  Possible C/C++ prototypes are:\n"
    "    pj::PersistentDocument::readInt(pj::string const &) const\n"
    "    pj::PersistentDocument::readInt() const\n");
  return 0;
}


SWIGINTERN PyObject *_wrap_PersistentDocument_readNumber__SWIG_0(PyObject *SWIGUNUSEDPARM(self), Py_ssize_t nobjs, PyObject **swig_obj) {
  PyObject *resultobj = 0;
  pj::PersistentDocument *arg1 = (pj::PersistentDocument *) 0 ;
  pj::string *arg2 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  int res2 = SWIG_OLDOBJ ;
  float result;
  
  if ((nobjs < 2) || (nobjs > 2)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__PersistentDocument, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "PersistentDocument_readNumber" "', argument " "1"" of type '" "pj::PersistentDocument const *""'"); 
  }
  arg1 = reinterpret_cast< pj::PersistentDocument * >(argp1);
  {
    std::string *ptr = (std::string *)0;
    res2 = SWIG_AsPtr_std_string(swig_obj[1], &ptr);
    if (!SWIG_IsOK(res2)) {
      SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "PersistentDocument_readNumber" "', argument " "2"" of type '" "pj::string const &""'"); 
    }
    if (!ptr) {
      SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "PersistentDocument_readNumber" "', argument " "2"" of type '" "pj::string const &""'"); 
    }
    arg2 = ptr;
  }
  try {
    result = (float)((pj::PersistentDocument const *)arg1)->readNumber((pj::string const &)*arg2);
  } catch(pj::Error &_e) {
    SWIG_Python_Raise(SWIG_NewPointerObj((new pj::Error(static_cast< const pj::Error& >(_e))),SWIGTYPE_p_pj__Error,SWIG_POINTER_OWN), "pj::Error", SWIGTYPE_p_pj__Error); SWIG_fail;
  }
  resultobj = SWIG_From_float(static_cast< float >(result));
  if (SWIG_IsNewObj(res2)) delete arg2;
  return resultobj;
fail:
  if (SWIG_IsNewObj(res2)) delete arg2;
  return NULL;
}


SWIGINTERN PyObject *_wrap_PersistentDocument_readNumber__SWIG_1(PyObject *SWIGUNUSEDPARM(self), Py_ssize_t nobjs, PyObject **swig_obj) {
  PyObject *resultobj = 0;
  pj::PersistentDocument *arg1 = (pj::PersistentDocument *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  float result;
  
  if ((nobjs < 1) || (nobjs > 1)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__PersistentDocument, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "PersistentDocument_readNumber" "', argument " "1"" of type '" "pj::PersistentDocument const *""'"); 
  }
  arg1 = reinterpret_cast< pj::PersistentDocument * >(argp1);
  try {
    result = (float)((pj::PersistentDocument const *)arg1)->readNumber();
  } catch(pj::Error &_e) {
    SWIG_Python_Raise(SWIG_NewPointerObj((new pj::Error(static_cast< const pj::Error& >(_e))),SWIGTYPE_p_pj__Error,SWIG_POINTER_OWN), "pj::Error", SWIGTYPE_p_pj__Error); SWIG_fail;
  }
  resultobj = SWIG_From_float(static_cast< float >(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_PersistentDocument_readNumber(PyObject *self, PyObject *args) {
  Py_ssize_t argc;
  PyObject *argv[3] = {
    0
  };
  
  if (!(argc = SWIG_Python_UnpackTuple(args, "PersistentDocument_readNumber", 0, 2, argv))) SWIG_fail;
  --argc;
  if (argc == 1) {
    int _v;
    void *vptr = 0;
    int res = SWIG_ConvertPtr(argv[0], &vptr, SWIGTYPE_p_pj__PersistentDocument, 0);
    _v = SWIG_CheckState(res);
    if (_v) {
      return _wrap_PersistentDocument_readNumber__SWIG_1(self, argc, argv);
    }
  }
  if (argc == 2) {
    int _v;
    void *vptr = 0;
    int res = SWIG_ConvertPtr(argv[0], &vptr, SWIGTYPE_p_pj__PersistentDocument, 0);
    _v = SWIG_CheckState(res);
    if (_v) {
      int res = SWIG_AsPtr_std_string(argv[1], (std::string**)(0));
      _v = SWIG_CheckState(res);
      if (_v) {
        return _wrap_PersistentDocument_readNumber__SWIG_0(self, argc, argv);
      }
    }
  }
  
fail:
  SWIG_Python_RaiseOrModifyTypeError("Wrong number or type of arguments for overloaded function 'PersistentDocument_readNumber'.\n"
    "  Possible C/C++ prototypes are:\n"
    "    pj::PersistentDocument::readNumber(pj::string const &) const\n"
    "    pj::PersistentDocument::readNumber() const\n");
  return 0;
}


SWIGINTERN PyObject *_wrap_PersistentDocument_readBool__SWIG_0(PyObject *SWIGUNUSEDPARM(self), Py_ssize_t nobjs, PyObject **swig_obj) {
  PyObject *resultobj = 0;
  pj::PersistentDocument *arg1 = (pj::PersistentDocument *) 0 ;
  pj::string *arg2 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  int res2 = SWIG_OLDOBJ ;
  bool result;
  
  if ((nobjs < 2) || (nobjs > 2)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__PersistentDocument, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "PersistentDocument_readBool" "', argument " "1"" of type '" "pj::PersistentDocument const *""'"); 
  }
  arg1 = reinterpret_cast< pj::PersistentDocument * >(argp1);
  {
    std::string *ptr = (std::string *)0;
    res2 = SWIG_AsPtr_std_string(swig_obj[1], &ptr);
    if (!SWIG_IsOK(res2)) {
      SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "PersistentDocument_readBool" "', argument " "2"" of type '" "pj::string const &""'"); 
    }
    if (!ptr) {
      SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "PersistentDocument_readBool" "', argument " "2"" of type '" "pj::string const &""'"); 
    }
    arg2 = ptr;
  }
  try {
    result = (bool)((pj::PersistentDocument const *)arg1)->readBool((pj::string const &)*arg2);
  } catch(pj::Error &_e) {
    SWIG_Python_Raise(SWIG_NewPointerObj((new pj::Error(static_cast< const pj::Error& >(_e))),SWIGTYPE_p_pj__Error,SWIG_POINTER_OWN), "pj::Error", SWIGTYPE_p_pj__Error); SWIG_fail;
  }
  resultobj = SWIG_From_bool(static_cast< bool >(result));
  if (SWIG_IsNewObj(res2)) delete arg2;
  return resultobj;
fail:
  if (SWIG_IsNewObj(res2)) delete arg2;
  return NULL;
}


SWIGINTERN PyObject *_wrap_PersistentDocument_readBool__SWIG_1(PyObject *SWIGUNUSEDPARM(self), Py_ssize_t nobjs, PyObject **swig_obj) {
  PyObject *resultobj = 0;
  pj::PersistentDocument *arg1 = (pj::PersistentDocument *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  bool result;
  
  if ((nobjs < 1) || (nobjs > 1)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__PersistentDocument, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "PersistentDocument_readBool" "', argument " "1"" of type '" "pj::PersistentDocument const *""'"); 
  }
  arg1 = reinterpret_cast< pj::PersistentDocument * >(argp1);
  try {
    result = (bool)((pj::PersistentDocument const *)arg1)->readBool();
  } catch(pj::Error &_e) {
    SWIG_Python_Raise(SWIG_NewPointerObj((new pj::Error(static_cast< const pj::Error& >(_e))),SWIGTYPE_p_pj__Error,SWIG_POINTER_OWN), "pj::Error", SWIGTYPE_p_pj__Error); SWIG_fail;
  }
  resultobj = SWIG_From_bool(static_cast< bool >(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_PersistentDocument_readBool(PyObject *self, PyObject *args) {
  Py_ssize_t argc;
  PyObject *argv[3] = {
    0
  };
  
  if (!(argc = SWIG_Python_UnpackTuple(args, "PersistentDocument_readBool", 0, 2, argv))) SWIG_fail;
  --argc;
  if (argc == 1) {
    int _v;
    void *vptr = 0;
    int res = SWIG_ConvertPtr(argv[0], &vptr, SWIGTYPE_p_pj__PersistentDocument, 0);
    _v = SWIG_CheckState(res);
    if (_v) {
      return _wrap_PersistentDocument_readBool__SWIG_1(self, argc, argv);
    }
  }
  if (argc == 2) {
    int _v;
    void *vptr = 0;
    int res = SWIG_ConvertPtr(argv[0], &vptr, SWIGTYPE_p_pj__PersistentDocument, 0);
    _v = SWIG_CheckState(res);
    if (_v) {
      int res = SWIG_AsPtr_std_string(argv[1], (std::string**)(0));
      _v = SWIG_CheckState(res);
      if (_v) {
        return _wrap_PersistentDocument_readBool__SWIG_0(self, argc, argv);
      }
    }
  }
  
fail:
  SWIG_Python_RaiseOrModifyTypeError("Wrong number or type of arguments for overloaded function 'PersistentDocument_readBool'.\n"
    "  Possible C/C++ prototypes are:\n"
    "    pj::PersistentDocument::readBool(pj::string const &) const\n"
    "    pj::PersistentDocument::readBool() const\n");
  return 0;
}


SWIGINTERN PyObject *_wrap_PersistentDocument_readString__SWIG_0(PyObject *SWIGUNUSEDPARM(self), Py_ssize_t nobjs, PyObject **swig_obj) {
  PyObject *resultobj = 0;
  pj::PersistentDocument *arg1 = (pj::PersistentDocument *) 0 ;
  pj::string *arg2 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  int res2 = SWIG_OLDOBJ ;
  pj::string result;
  
  if ((nobjs < 2) || (nobjs > 2)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__PersistentDocument, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "PersistentDocument_readString" "', argument " "1"" of type '" "pj::PersistentDocument const *""'"); 
  }
  arg1 = reinterpret_cast< pj::PersistentDocument * >(argp1);
  {
    std::string *ptr = (std::string *)0;
    res2 = SWIG_AsPtr_std_string(swig_obj[1], &ptr);
    if (!SWIG_IsOK(res2)) {
      SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "PersistentDocument_readString" "', argument " "2"" of type '" "pj::string const &""'"); 
    }
    if (!ptr) {
      SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "PersistentDocument_readString" "', argument " "2"" of type '" "pj::string const &""'"); 
    }
    arg2 = ptr;
  }
  try {
    result = ((pj::PersistentDocument const *)arg1)->readString((pj::string const &)*arg2);
  } catch(pj::Error &_e) {
    SWIG_Python_Raise(SWIG_NewPointerObj((new pj::Error(static_cast< const pj::Error& >(_e))),SWIGTYPE_p_pj__Error,SWIG_POINTER_OWN), "pj::Error", SWIGTYPE_p_pj__Error); SWIG_fail;
  }
  resultobj = SWIG_From_std_string(static_cast< std::string >(result));
  if (SWIG_IsNewObj(res2)) delete arg2;
  return resultobj;
fail:
  if (SWIG_IsNewObj(res2)) delete arg2;
  return NULL;
}


SWIGINTERN PyObject *_wrap_PersistentDocument_readString__SWIG_1(PyObject *SWIGUNUSEDPARM(self), Py_ssize_t nobjs, PyObject **swig_obj) {
  PyObject *resultobj = 0;
  pj::PersistentDocument *arg1 = (pj::PersistentDocument *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  pj::string result;
  
  if ((nobjs < 1) || (nobjs > 1)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__PersistentDocument, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "PersistentDocument_readString" "', argument " "1"" of type '" "pj::PersistentDocument const *""'"); 
  }
  arg1 = reinterpret_cast< pj::PersistentDocument * >(argp1);
  try {
    result = ((pj::PersistentDocument const *)arg1)->readString();
  } catch(pj::Error &_e) {
    SWIG_Python_Raise(SWIG_NewPointerObj((new pj::Error(static_cast< const pj::Error& >(_e))),SWIGTYPE_p_pj__Error,SWIG_POINTER_OWN), "pj::Error", SWIGTYPE_p_pj__Error); SWIG_fail;
  }
  resultobj = SWIG_From_std_string(static_cast< std::string >(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_PersistentDocument_readString(PyObject *self, PyObject *args) {
  Py_ssize_t argc;
  PyObject *argv[3] = {
    0
  };
  
  if (!(argc = SWIG_Python_UnpackTuple(args, "PersistentDocument_readString", 0, 2, argv))) SWIG_fail;
  --argc;
  if (argc == 1) {
    int _v;
    void *vptr = 0;
    int res = SWIG_ConvertPtr(argv[0], &vptr, SWIGTYPE_p_pj__PersistentDocument, 0);
    _v = SWIG_CheckState(res);
    if (_v) {
      return _wrap_PersistentDocument_readString__SWIG_1(self, argc, argv);
    }
  }
  if (argc == 2) {
    int _v;
    void *vptr = 0;
    int res = SWIG_ConvertPtr(argv[0], &vptr, SWIGTYPE_p_pj__PersistentDocument, 0);
    _v = SWIG_CheckState(res);
    if (_v) {
      int res = SWIG_AsPtr_std_string(argv[1], (std::string**)(0));
      _v = SWIG_CheckState(res);
      if (_v) {
        return _wrap_PersistentDocument_readString__SWIG_0(self, argc, argv);
      }
    }
  }
  
fail:
  SWIG_Python_RaiseOrModifyTypeError("Wrong number or type of arguments for overloaded function 'PersistentDocument_readString'.\n"
    "  Possible C/C++ prototypes are:\n"
    "    pj::PersistentDocument::readString(pj::string const &) const\n"
    "    pj::PersistentDocument::readString() const\n");
  return 0;
}


SWIGINTERN PyObject *_wrap_PersistentDocument_readStringVector__SWIG_0(PyObject *SWIGUNUSEDPARM(self), Py_ssize_t nobjs, PyObject **swig_obj) {
  PyObject *resultobj = 0;
  pj::PersistentDocument *arg1 = (pj::PersistentDocument *) 0 ;
  pj::string *arg2 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  int res2 = SWIG_OLDOBJ ;
  pj::StringVector result;
  
  if ((nobjs < 2) || (nobjs > 2)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__PersistentDocument, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "PersistentDocument_readStringVector" "', argument " "1"" of type '" "pj::PersistentDocument const *""'"); 
  }
  arg1 = reinterpret_cast< pj::PersistentDocument * >(argp1);
  {
    std::string *ptr = (std::string *)0;
    res2 = SWIG_AsPtr_std_string(swig_obj[1], &ptr);
    if (!SWIG_IsOK(res2)) {
      SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "PersistentDocument_readStringVector" "', argument " "2"" of type '" "pj::string const &""'"); 
    }
    if (!ptr) {
      SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "PersistentDocument_readStringVector" "', argument " "2"" of type '" "pj::string const &""'"); 
    }
    arg2 = ptr;
  }
  try {
    result = ((pj::PersistentDocument const *)arg1)->readStringVector((pj::string const &)*arg2);
  } catch(pj::Error &_e) {
    SWIG_Python_Raise(SWIG_NewPointerObj((new pj::Error(static_cast< const pj::Error& >(_e))),SWIGTYPE_p_pj__Error,SWIG_POINTER_OWN), "pj::Error", SWIGTYPE_p_pj__Error); SWIG_fail;
  }
  resultobj = swig::from(static_cast< std::vector< std::string,std::allocator< std::string > > >(result));
  if (SWIG_IsNewObj(res2)) delete arg2;
  return resultobj;
fail:
  if (SWIG_IsNewObj(res2)) delete arg2;
  return NULL;
}


SWIGINTERN PyObject *_wrap_PersistentDocument_readStringVector__SWIG_1(PyObject *SWIGUNUSEDPARM(self), Py_ssize_t nobjs, PyObject **swig_obj) {
  PyObject *resultobj = 0;
  pj::PersistentDocument *arg1 = (pj::PersistentDocument *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  pj::StringVector result;
  
  if ((nobjs < 1) || (nobjs > 1)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__PersistentDocument, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "PersistentDocument_readStringVector" "', argument " "1"" of type '" "pj::PersistentDocument const *""'"); 
  }
  arg1 = reinterpret_cast< pj::PersistentDocument * >(argp1);
  try {
    result = ((pj::PersistentDocument const *)arg1)->readStringVector();
  } catch(pj::Error &_e) {
    SWIG_Python_Raise(SWIG_NewPointerObj((new pj::Error(static_cast< const pj::Error& >(_e))),SWIGTYPE_p_pj__Error,SWIG_POINTER_OWN), "pj::Error", SWIGTYPE_p_pj__Error); SWIG_fail;
  }
  resultobj = swig::from(static_cast< std::vector< std::string,std::allocator< std::string > > >(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_PersistentDocument_readStringVector(PyObject *self, PyObject *args) {
  Py_ssize_t argc;
  PyObject *argv[3] = {
    0
  };
  
  if (!(argc = SWIG_Python_UnpackTuple(args, "PersistentDocument_readStringVector", 0, 2, argv))) SWIG_fail;
  --argc;
  if (argc == 1) {
    int _v;
    void *vptr = 0;
    int res = SWIG_ConvertPtr(argv[0], &vptr, SWIGTYPE_p_pj__PersistentDocument, 0);
    _v = SWIG_CheckState(res);
    if (_v) {
      return _wrap_PersistentDocument_readStringVector__SWIG_1(self, argc, argv);
    }
  }
  if (argc == 2) {
    int _v;
    void *vptr = 0;
    int res = SWIG_ConvertPtr(argv[0], &vptr, SWIGTYPE_p_pj__PersistentDocument, 0);
    _v = SWIG_CheckState(res);
    if (_v) {
      int res = SWIG_AsPtr_std_string(argv[1], (std::string**)(0));
      _v = SWIG_CheckState(res);
      if (_v) {
        return _wrap_PersistentDocument_readStringVector__SWIG_0(self, argc, argv);
      }
    }
  }
  
fail:
  SWIG_Python_RaiseOrModifyTypeError("Wrong number or type of arguments for overloaded function 'PersistentDocument_readStringVector'.\n"
    "  Possible C/C++ prototypes are:\n"
    "    pj::PersistentDocument::readStringVector(pj::string const &) const\n"
    "    pj::PersistentDocument::readStringVector() const\n");
  return 0;
}


SWIGINTERN PyObject *_wrap_PersistentDocument_readObject(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::PersistentDocument *arg1 = (pj::PersistentDocument *) 0 ;
  pj::PersistentObject *arg2 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  void *argp2 = 0 ;
  int res2 = 0 ;
  PyObject *swig_obj[2] ;
  
  if (!SWIG_Python_UnpackTuple(args, "PersistentDocument_readObject", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__PersistentDocument, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "PersistentDocument_readObject" "', argument " "1"" of type '" "pj::PersistentDocument const *""'"); 
  }
  arg1 = reinterpret_cast< pj::PersistentDocument * >(argp1);
  res2 = SWIG_ConvertPtr(swig_obj[1], &argp2, SWIGTYPE_p_pj__PersistentObject,  0 );
  if (!SWIG_IsOK(res2)) {
    SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "PersistentDocument_readObject" "', argument " "2"" of type '" "pj::PersistentObject &""'"); 
  }
  if (!argp2) {
    SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "PersistentDocument_readObject" "', argument " "2"" of type '" "pj::PersistentObject &""'"); 
  }
  arg2 = reinterpret_cast< pj::PersistentObject * >(argp2);
  try {
    ((pj::PersistentDocument const *)arg1)->readObject(*arg2);
  } catch(pj::Error &_e) {
    SWIG_Python_Raise(SWIG_NewPointerObj((new pj::Error(static_cast< const pj::Error& >(_e))),SWIGTYPE_p_pj__Error,SWIG_POINTER_OWN), "pj::Error", SWIGTYPE_p_pj__Error); SWIG_fail;
  }
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_PersistentDocument_readContainer__SWIG_0(PyObject *SWIGUNUSEDPARM(self), Py_ssize_t nobjs, PyObject **swig_obj) {
  PyObject *resultobj = 0;
  pj::PersistentDocument *arg1 = (pj::PersistentDocument *) 0 ;
  pj::string *arg2 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  int res2 = SWIG_OLDOBJ ;
  pj::ContainerNode result;
  
  if ((nobjs < 2) || (nobjs > 2)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__PersistentDocument, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "PersistentDocument_readContainer" "', argument " "1"" of type '" "pj::PersistentDocument const *""'"); 
  }
  arg1 = reinterpret_cast< pj::PersistentDocument * >(argp1);
  {
    std::string *ptr = (std::string *)0;
    res2 = SWIG_AsPtr_std_string(swig_obj[1], &ptr);
    if (!SWIG_IsOK(res2)) {
      SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "PersistentDocument_readContainer" "', argument " "2"" of type '" "pj::string const &""'"); 
    }
    if (!ptr) {
      SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "PersistentDocument_readContainer" "', argument " "2"" of type '" "pj::string const &""'"); 
    }
    arg2 = ptr;
  }
  try {
    result = ((pj::PersistentDocument const *)arg1)->readContainer((pj::string const &)*arg2);
  } catch(pj::Error &_e) {
    SWIG_Python_Raise(SWIG_NewPointerObj((new pj::Error(static_cast< const pj::Error& >(_e))),SWIGTYPE_p_pj__Error,SWIG_POINTER_OWN), "pj::Error", SWIGTYPE_p_pj__Error); SWIG_fail;
  }
  resultobj = SWIG_NewPointerObj((new pj::ContainerNode(static_cast< const pj::ContainerNode& >(result))), SWIGTYPE_p_pj__ContainerNode, SWIG_POINTER_OWN |  0 );
  if (SWIG_IsNewObj(res2)) delete arg2;
  return resultobj;
fail:
  if (SWIG_IsNewObj(res2)) delete arg2;
  return NULL;
}


SWIGINTERN PyObject *_wrap_PersistentDocument_readContainer__SWIG_1(PyObject *SWIGUNUSEDPARM(self), Py_ssize_t nobjs, PyObject **swig_obj) {
  PyObject *resultobj = 0;
  pj::PersistentDocument *arg1 = (pj::PersistentDocument *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  pj::ContainerNode result;
  
  if ((nobjs < 1) || (nobjs > 1)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__PersistentDocument, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "PersistentDocument_readContainer" "', argument " "1"" of type '" "pj::PersistentDocument const *""'"); 
  }
  arg1 = reinterpret_cast< pj::PersistentDocument * >(argp1);
  try {
    result = ((pj::PersistentDocument const *)arg1)->readContainer();
  } catch(pj::Error &_e) {
    SWIG_Python_Raise(SWIG_NewPointerObj((new pj::Error(static_cast< const pj::Error& >(_e))),SWIGTYPE_p_pj__Error,SWIG_POINTER_OWN), "pj::Error", SWIGTYPE_p_pj__Error); SWIG_fail;
  }
  resultobj = SWIG_NewPointerObj((new pj::ContainerNode(static_cast< const pj::ContainerNode& >(result))), SWIGTYPE_p_pj__ContainerNode, SWIG_POINTER_OWN |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_PersistentDocument_readContainer(PyObject *self, PyObject *args) {
  Py_ssize_t argc;
  PyObject *argv[3] = {
    0
  };
  
  if (!(argc = SWIG_Python_UnpackTuple(args, "PersistentDocument_readContainer", 0, 2, argv))) SWIG_fail;
  --argc;
  if (argc == 1) {
    int _v;
    void *vptr = 0;
    int res = SWIG_ConvertPtr(argv[0], &vptr, SWIGTYPE_p_pj__PersistentDocument, 0);
    _v = SWIG_CheckState(res);
    if (_v) {
      return _wrap_PersistentDocument_readContainer__SWIG_1(self, argc, argv);
    }
  }
  if (argc == 2) {
    int _v;
    void *vptr = 0;
    int res = SWIG_ConvertPtr(argv[0], &vptr, SWIGTYPE_p_pj__PersistentDocument, 0);
    _v = SWIG_CheckState(res);
    if (_v) {
      int res = SWIG_AsPtr_std_string(argv[1], (std::string**)(0));
      _v = SWIG_CheckState(res);
      if (_v) {
        return _wrap_PersistentDocument_readContainer__SWIG_0(self, argc, argv);
      }
    }
  }
  
fail:
  SWIG_Python_RaiseOrModifyTypeError("Wrong number or type of arguments for overloaded function 'PersistentDocument_readContainer'.\n"
    "  Possible C/C++ prototypes are:\n"
    "    pj::PersistentDocument::readContainer(pj::string const &) const\n"
    "    pj::PersistentDocument::readContainer() const\n");
  return 0;
}


SWIGINTERN PyObject *_wrap_PersistentDocument_readArray__SWIG_0(PyObject *SWIGUNUSEDPARM(self), Py_ssize_t nobjs, PyObject **swig_obj) {
  PyObject *resultobj = 0;
  pj::PersistentDocument *arg1 = (pj::PersistentDocument *) 0 ;
  pj::string *arg2 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  int res2 = SWIG_OLDOBJ ;
  pj::ContainerNode result;
  
  if ((nobjs < 2) || (nobjs > 2)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__PersistentDocument, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "PersistentDocument_readArray" "', argument " "1"" of type '" "pj::PersistentDocument const *""'"); 
  }
  arg1 = reinterpret_cast< pj::PersistentDocument * >(argp1);
  {
    std::string *ptr = (std::string *)0;
    res2 = SWIG_AsPtr_std_string(swig_obj[1], &ptr);
    if (!SWIG_IsOK(res2)) {
      SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "PersistentDocument_readArray" "', argument " "2"" of type '" "pj::string const &""'"); 
    }
    if (!ptr) {
      SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "PersistentDocument_readArray" "', argument " "2"" of type '" "pj::string const &""'"); 
    }
    arg2 = ptr;
  }
  try {
    result = ((pj::PersistentDocument const *)arg1)->readArray((pj::string const &)*arg2);
  } catch(pj::Error &_e) {
    SWIG_Python_Raise(SWIG_NewPointerObj((new pj::Error(static_cast< const pj::Error& >(_e))),SWIGTYPE_p_pj__Error,SWIG_POINTER_OWN), "pj::Error", SWIGTYPE_p_pj__Error); SWIG_fail;
  }
  resultobj = SWIG_NewPointerObj((new pj::ContainerNode(static_cast< const pj::ContainerNode& >(result))), SWIGTYPE_p_pj__ContainerNode, SWIG_POINTER_OWN |  0 );
  if (SWIG_IsNewObj(res2)) delete arg2;
  return resultobj;
fail:
  if (SWIG_IsNewObj(res2)) delete arg2;
  return NULL;
}


SWIGINTERN PyObject *_wrap_PersistentDocument_readArray__SWIG_1(PyObject *SWIGUNUSEDPARM(self), Py_ssize_t nobjs, PyObject **swig_obj) {
  PyObject *resultobj = 0;
  pj::PersistentDocument *arg1 = (pj::PersistentDocument *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  pj::ContainerNode result;
  
  if ((nobjs < 1) || (nobjs > 1)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__PersistentDocument, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "PersistentDocument_readArray" "', argument " "1"" of type '" "pj::PersistentDocument const *""'"); 
  }
  arg1 = reinterpret_cast< pj::PersistentDocument * >(argp1);
  try {
    result = ((pj::PersistentDocument const *)arg1)->readArray();
  } catch(pj::Error &_e) {
    SWIG_Python_Raise(SWIG_NewPointerObj((new pj::Error(static_cast< const pj::Error& >(_e))),SWIGTYPE_p_pj__Error,SWIG_POINTER_OWN), "pj::Error", SWIGTYPE_p_pj__Error); SWIG_fail;
  }
  resultobj = SWIG_NewPointerObj((new pj::ContainerNode(static_cast< const pj::ContainerNode& >(result))), SWIGTYPE_p_pj__ContainerNode, SWIG_POINTER_OWN |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_PersistentDocument_readArray(PyObject *self, PyObject *args) {
  Py_ssize_t argc;
  PyObject *argv[3] = {
    0
  };
  
  if (!(argc = SWIG_Python_UnpackTuple(args, "PersistentDocument_readArray", 0, 2, argv))) SWIG_fail;
  --argc;
  if (argc == 1) {
    int _v;
    void *vptr = 0;
    int res = SWIG_ConvertPtr(argv[0], &vptr, SWIGTYPE_p_pj__PersistentDocument, 0);
    _v = SWIG_CheckState(res);
    if (_v) {
      return _wrap_PersistentDocument_readArray__SWIG_1(self, argc, argv);
    }
  }
  if (argc == 2) {
    int _v;
    void *vptr = 0;
    int res = SWIG_ConvertPtr(argv[0], &vptr, SWIGTYPE_p_pj__PersistentDocument, 0);
    _v = SWIG_CheckState(res);
    if (_v) {
      int res = SWIG_AsPtr_std_string(argv[1], (std::string**)(0));
      _v = SWIG_CheckState(res);
      if (_v) {
        return _wrap_PersistentDocument_readArray__SWIG_0(self, argc, argv);
      }
    }
  }
  
fail:
  SWIG_Python_RaiseOrModifyTypeError("Wrong number or type of arguments for overloaded function 'PersistentDocument_readArray'.\n"
    "  Possible C/C++ prototypes are:\n"
    "    pj::PersistentDocument::readArray(pj::string const &) const\n"
    "    pj::PersistentDocument::readArray() const\n");
  return 0;
}


SWIGINTERN PyObject *_wrap_PersistentDocument_writeNumber(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::PersistentDocument *arg1 = (pj::PersistentDocument *) 0 ;
  pj::string *arg2 = 0 ;
  float arg3 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  int res2 = SWIG_OLDOBJ ;
  float val3 ;
  int ecode3 = 0 ;
  PyObject *swig_obj[3] ;
  
  if (!SWIG_Python_UnpackTuple(args, "PersistentDocument_writeNumber", 3, 3, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__PersistentDocument, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "PersistentDocument_writeNumber" "', argument " "1"" of type '" "pj::PersistentDocument *""'"); 
  }
  arg1 = reinterpret_cast< pj::PersistentDocument * >(argp1);
  {
    std::string *ptr = (std::string *)0;
    res2 = SWIG_AsPtr_std_string(swig_obj[1], &ptr);
    if (!SWIG_IsOK(res2)) {
      SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "PersistentDocument_writeNumber" "', argument " "2"" of type '" "pj::string const &""'"); 
    }
    if (!ptr) {
      SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "PersistentDocument_writeNumber" "', argument " "2"" of type '" "pj::string const &""'"); 
    }
    arg2 = ptr;
  }
  ecode3 = SWIG_AsVal_float(swig_obj[2], &val3);
  if (!SWIG_IsOK(ecode3)) {
    SWIG_exception_fail(SWIG_ArgError(ecode3), "in method '" "PersistentDocument_writeNumber" "', argument " "3"" of type '" "float""'");
  } 
  arg3 = static_cast< float >(val3);
  try {
    (arg1)->writeNumber((pj::string const &)*arg2,arg3);
  } catch(pj::Error &_e) {
    SWIG_Python_Raise(SWIG_NewPointerObj((new pj::Error(static_cast< const pj::Error& >(_e))),SWIGTYPE_p_pj__Error,SWIG_POINTER_OWN), "pj::Error", SWIGTYPE_p_pj__Error); SWIG_fail;
  }
  resultobj = SWIG_Py_Void();
  if (SWIG_IsNewObj(res2)) delete arg2;
  return resultobj;
fail:
  if (SWIG_IsNewObj(res2)) delete arg2;
  return NULL;
}


SWIGINTERN PyObject *_wrap_PersistentDocument_writeInt(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::PersistentDocument *arg1 = (pj::PersistentDocument *) 0 ;
  pj::string *arg2 = 0 ;
  int arg3 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  int res2 = SWIG_OLDOBJ ;
  int val3 ;
  int ecode3 = 0 ;
  PyObject *swig_obj[3] ;
  
  if (!SWIG_Python_UnpackTuple(args, "PersistentDocument_writeInt", 3, 3, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__PersistentDocument, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "PersistentDocument_writeInt" "', argument " "1"" of type '" "pj::PersistentDocument *""'"); 
  }
  arg1 = reinterpret_cast< pj::PersistentDocument * >(argp1);
  {
    std::string *ptr = (std::string *)0;
    res2 = SWIG_AsPtr_std_string(swig_obj[1], &ptr);
    if (!SWIG_IsOK(res2)) {
      SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "PersistentDocument_writeInt" "', argument " "2"" of type '" "pj::string const &""'"); 
    }
    if (!ptr) {
      SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "PersistentDocument_writeInt" "', argument " "2"" of type '" "pj::string const &""'"); 
    }
    arg2 = ptr;
  }
  ecode3 = SWIG_AsVal_int(swig_obj[2], &val3);
  if (!SWIG_IsOK(ecode3)) {
    SWIG_exception_fail(SWIG_ArgError(ecode3), "in method '" "PersistentDocument_writeInt" "', argument " "3"" of type '" "int""'");
  } 
  arg3 = static_cast< int >(val3);
  try {
    (arg1)->writeInt((pj::string const &)*arg2,arg3);
  } catch(pj::Error &_e) {
    SWIG_Python_Raise(SWIG_NewPointerObj((new pj::Error(static_cast< const pj::Error& >(_e))),SWIGTYPE_p_pj__Error,SWIG_POINTER_OWN), "pj::Error", SWIGTYPE_p_pj__Error); SWIG_fail;
  }
  resultobj = SWIG_Py_Void();
  if (SWIG_IsNewObj(res2)) delete arg2;
  return resultobj;
fail:
  if (SWIG_IsNewObj(res2)) delete arg2;
  return NULL;
}


SWIGINTERN PyObject *_wrap_PersistentDocument_writeBool(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::PersistentDocument *arg1 = (pj::PersistentDocument *) 0 ;
  pj::string *arg2 = 0 ;
  bool arg3 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  int res2 = SWIG_OLDOBJ ;
  bool val3 ;
  int ecode3 = 0 ;
  PyObject *swig_obj[3] ;
  
  if (!SWIG_Python_UnpackTuple(args, "PersistentDocument_writeBool", 3, 3, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__PersistentDocument, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "PersistentDocument_writeBool" "', argument " "1"" of type '" "pj::PersistentDocument *""'"); 
  }
  arg1 = reinterpret_cast< pj::PersistentDocument * >(argp1);
  {
    std::string *ptr = (std::string *)0;
    res2 = SWIG_AsPtr_std_string(swig_obj[1], &ptr);
    if (!SWIG_IsOK(res2)) {
      SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "PersistentDocument_writeBool" "', argument " "2"" of type '" "pj::string const &""'"); 
    }
    if (!ptr) {
      SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "PersistentDocument_writeBool" "', argument " "2"" of type '" "pj::string const &""'"); 
    }
    arg2 = ptr;
  }
  ecode3 = SWIG_AsVal_bool(swig_obj[2], &val3);
  if (!SWIG_IsOK(ecode3)) {
    SWIG_exception_fail(SWIG_ArgError(ecode3), "in method '" "PersistentDocument_writeBool" "', argument " "3"" of type '" "bool""'");
  } 
  arg3 = static_cast< bool >(val3);
  try {
    (arg1)->writeBool((pj::string const &)*arg2,arg3);
  } catch(pj::Error &_e) {
    SWIG_Python_Raise(SWIG_NewPointerObj((new pj::Error(static_cast< const pj::Error& >(_e))),SWIGTYPE_p_pj__Error,SWIG_POINTER_OWN), "pj::Error", SWIGTYPE_p_pj__Error); SWIG_fail;
  }
  resultobj = SWIG_Py_Void();
  if (SWIG_IsNewObj(res2)) delete arg2;
  return resultobj;
fail:
  if (SWIG_IsNewObj(res2)) delete arg2;
  return NULL;
}


SWIGINTERN PyObject *_wrap_PersistentDocument_writeString(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::PersistentDocument *arg1 = (pj::PersistentDocument *) 0 ;
  pj::string *arg2 = 0 ;
  pj::string *arg3 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  int res2 = SWIG_OLDOBJ ;
  int res3 = SWIG_OLDOBJ ;
  PyObject *swig_obj[3] ;
  
  if (!SWIG_Python_UnpackTuple(args, "PersistentDocument_writeString", 3, 3, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__PersistentDocument, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "PersistentDocument_writeString" "', argument " "1"" of type '" "pj::PersistentDocument *""'"); 
  }
  arg1 = reinterpret_cast< pj::PersistentDocument * >(argp1);
  {
    std::string *ptr = (std::string *)0;
    res2 = SWIG_AsPtr_std_string(swig_obj[1], &ptr);
    if (!SWIG_IsOK(res2)) {
      SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "PersistentDocument_writeString" "', argument " "2"" of type '" "pj::string const &""'"); 
    }
    if (!ptr) {
      SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "PersistentDocument_writeString" "', argument " "2"" of type '" "pj::string const &""'"); 
    }
    arg2 = ptr;
  }
  {
    std::string *ptr = (std::string *)0;
    res3 = SWIG_AsPtr_std_string(swig_obj[2], &ptr);
    if (!SWIG_IsOK(res3)) {
      SWIG_exception_fail(SWIG_ArgError(res3), "in method '" "PersistentDocument_writeString" "', argument " "3"" of type '" "pj::string const &""'"); 
    }
    if (!ptr) {
      SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "PersistentDocument_writeString" "', argument " "3"" of type '" "pj::string const &""'"); 
    }
    arg3 = ptr;
  }
  try {
    (arg1)->writeString((pj::string const &)*arg2,(pj::string const &)*arg3);
  } catch(pj::Error &_e) {
    SWIG_Python_Raise(SWIG_NewPointerObj((new pj::Error(static_cast< const pj::Error& >(_e))),SWIGTYPE_p_pj__Error,SWIG_POINTER_OWN), "pj::Error", SWIGTYPE_p_pj__Error); SWIG_fail;
  }
  resultobj = SWIG_Py_Void();
  if (SWIG_IsNewObj(res2)) delete arg2;
  if (SWIG_IsNewObj(res3)) delete arg3;
  return resultobj;
fail:
  if (SWIG_IsNewObj(res2)) delete arg2;
  if (SWIG_IsNewObj(res3)) delete arg3;
  return NULL;
}


SWIGINTERN PyObject *_wrap_PersistentDocument_writeStringVector(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::PersistentDocument *arg1 = (pj::PersistentDocument *) 0 ;
  pj::string *arg2 = 0 ;
  pj::StringVector *arg3 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  int res2 = SWIG_OLDOBJ ;
  int res3 = SWIG_OLDOBJ ;
  PyObject *swig_obj[3] ;
  
  if (!SWIG_Python_UnpackTuple(args, "PersistentDocument_writeStringVector", 3, 3, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__PersistentDocument, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "PersistentDocument_writeStringVector" "', argument " "1"" of type '" "pj::PersistentDocument *""'"); 
  }
  arg1 = reinterpret_cast< pj::PersistentDocument * >(argp1);
  {
    std::string *ptr = (std::string *)0;
    res2 = SWIG_AsPtr_std_string(swig_obj[1], &ptr);
    if (!SWIG_IsOK(res2)) {
      SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "PersistentDocument_writeStringVector" "', argument " "2"" of type '" "pj::string const &""'"); 
    }
    if (!ptr) {
      SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "PersistentDocument_writeStringVector" "', argument " "2"" of type '" "pj::string const &""'"); 
    }
    arg2 = ptr;
  }
  {
    std::vector< std::string,std::allocator< std::string > > *ptr = (std::vector< std::string,std::allocator< std::string > > *)0;
    res3 = swig::asptr(swig_obj[2], &ptr);
    if (!SWIG_IsOK(res3)) {
      SWIG_exception_fail(SWIG_ArgError(res3), "in method '" "PersistentDocument_writeStringVector" "', argument " "3"" of type '" "pj::StringVector const &""'"); 
    }
    if (!ptr) {
      SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "PersistentDocument_writeStringVector" "', argument " "3"" of type '" "pj::StringVector const &""'"); 
    }
    arg3 = ptr;
  }
  try {
    (arg1)->writeStringVector((pj::string const &)*arg2,(pj::StringVector const &)*arg3);
  } catch(pj::Error &_e) {
    SWIG_Python_Raise(SWIG_NewPointerObj((new pj::Error(static_cast< const pj::Error& >(_e))),SWIGTYPE_p_pj__Error,SWIG_POINTER_OWN), "pj::Error", SWIGTYPE_p_pj__Error); SWIG_fail;
  }
  resultobj = SWIG_Py_Void();
  if (SWIG_IsNewObj(res2)) delete arg2;
  if (SWIG_IsNewObj(res3)) delete arg3;
  return resultobj;
fail:
  if (SWIG_IsNewObj(res2)) delete arg2;
  if (SWIG_IsNewObj(res3)) delete arg3;
  return NULL;
}


SWIGINTERN PyObject *_wrap_PersistentDocument_writeObject(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::PersistentDocument *arg1 = (pj::PersistentDocument *) 0 ;
  pj::PersistentObject *arg2 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  void *argp2 = 0 ;
  int res2 = 0 ;
  PyObject *swig_obj[2] ;
  
  if (!SWIG_Python_UnpackTuple(args, "PersistentDocument_writeObject", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__PersistentDocument, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "PersistentDocument_writeObject" "', argument " "1"" of type '" "pj::PersistentDocument *""'"); 
  }
  arg1 = reinterpret_cast< pj::PersistentDocument * >(argp1);
  res2 = SWIG_ConvertPtr(swig_obj[1], &argp2, SWIGTYPE_p_pj__PersistentObject,  0  | 0);
  if (!SWIG_IsOK(res2)) {
    SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "PersistentDocument_writeObject" "', argument " "2"" of type '" "pj::PersistentObject const &""'"); 
  }
  if (!argp2) {
    SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "PersistentDocument_writeObject" "', argument " "2"" of type '" "pj::PersistentObject const &""'"); 
  }
  arg2 = reinterpret_cast< pj::PersistentObject * >(argp2);
  try {
    (arg1)->writeObject((pj::PersistentObject const &)*arg2);
  } catch(pj::Error &_e) {
    SWIG_Python_Raise(SWIG_NewPointerObj((new pj::Error(static_cast< const pj::Error& >(_e))),SWIGTYPE_p_pj__Error,SWIG_POINTER_OWN), "pj::Error", SWIGTYPE_p_pj__Error); SWIG_fail;
  }
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_PersistentDocument_writeNewContainer(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::PersistentDocument *arg1 = (pj::PersistentDocument *) 0 ;
  pj::string *arg2 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  int res2 = SWIG_OLDOBJ ;
  PyObject *swig_obj[2] ;
  pj::ContainerNode result;
  
  if (!SWIG_Python_UnpackTuple(args, "PersistentDocument_writeNewContainer", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__PersistentDocument, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "PersistentDocument_writeNewContainer" "', argument " "1"" of type '" "pj::PersistentDocument *""'"); 
  }
  arg1 = reinterpret_cast< pj::PersistentDocument * >(argp1);
  {
    std::string *ptr = (std::string *)0;
    res2 = SWIG_AsPtr_std_string(swig_obj[1], &ptr);
    if (!SWIG_IsOK(res2)) {
      SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "PersistentDocument_writeNewContainer" "', argument " "2"" of type '" "pj::string const &""'"); 
    }
    if (!ptr) {
      SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "PersistentDocument_writeNewContainer" "', argument " "2"" of type '" "pj::string const &""'"); 
    }
    arg2 = ptr;
  }
  try {
    result = (arg1)->writeNewContainer((pj::string const &)*arg2);
  } catch(pj::Error &_e) {
    SWIG_Python_Raise(SWIG_NewPointerObj((new pj::Error(static_cast< const pj::Error& >(_e))),SWIGTYPE_p_pj__Error,SWIG_POINTER_OWN), "pj::Error", SWIGTYPE_p_pj__Error); SWIG_fail;
  }
  resultobj = SWIG_NewPointerObj((new pj::ContainerNode(static_cast< const pj::ContainerNode& >(result))), SWIGTYPE_p_pj__ContainerNode, SWIG_POINTER_OWN |  0 );
  if (SWIG_IsNewObj(res2)) delete arg2;
  return resultobj;
fail:
  if (SWIG_IsNewObj(res2)) delete arg2;
  return NULL;
}


SWIGINTERN PyObject *_wrap_PersistentDocument_writeNewArray(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::PersistentDocument *arg1 = (pj::PersistentDocument *) 0 ;
  pj::string *arg2 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  int res2 = SWIG_OLDOBJ ;
  PyObject *swig_obj[2] ;
  pj::ContainerNode result;
  
  if (!SWIG_Python_UnpackTuple(args, "PersistentDocument_writeNewArray", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__PersistentDocument, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "PersistentDocument_writeNewArray" "', argument " "1"" of type '" "pj::PersistentDocument *""'"); 
  }
  arg1 = reinterpret_cast< pj::PersistentDocument * >(argp1);
  {
    std::string *ptr = (std::string *)0;
    res2 = SWIG_AsPtr_std_string(swig_obj[1], &ptr);
    if (!SWIG_IsOK(res2)) {
      SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "PersistentDocument_writeNewArray" "', argument " "2"" of type '" "pj::string const &""'"); 
    }
    if (!ptr) {
      SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "PersistentDocument_writeNewArray" "', argument " "2"" of type '" "pj::string const &""'"); 
    }
    arg2 = ptr;
  }
  try {
    result = (arg1)->writeNewArray((pj::string const &)*arg2);
  } catch(pj::Error &_e) {
    SWIG_Python_Raise(SWIG_NewPointerObj((new pj::Error(static_cast< const pj::Error& >(_e))),SWIGTYPE_p_pj__Error,SWIG_POINTER_OWN), "pj::Error", SWIGTYPE_p_pj__Error); SWIG_fail;
  }
  resultobj = SWIG_NewPointerObj((new pj::ContainerNode(static_cast< const pj::ContainerNode& >(result))), SWIGTYPE_p_pj__ContainerNode, SWIG_POINTER_OWN |  0 );
  if (SWIG_IsNewObj(res2)) delete arg2;
  return resultobj;
fail:
  if (SWIG_IsNewObj(res2)) delete arg2;
  return NULL;
}


SWIGINTERN PyObject *PersistentDocument_swigregister(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *obj;
  if (!SWIG_Python_UnpackTuple(args, "swigregister", 1, 1, &obj)) return NULL;
  SWIG_TypeNewClientData(SWIGTYPE_p_pj__PersistentDocument, SWIG_NewClientData(obj));
  return SWIG_Py_Void();
}

SWIGINTERN PyObject *_wrap_ContainerNode_hasUnread(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::ContainerNode *arg1 = (pj::ContainerNode *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  bool result;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__ContainerNode, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "ContainerNode_hasUnread" "', argument " "1"" of type '" "pj::ContainerNode const *""'"); 
  }
  arg1 = reinterpret_cast< pj::ContainerNode * >(argp1);
  result = (bool)((pj::ContainerNode const *)arg1)->hasUnread();
  resultobj = SWIG_From_bool(static_cast< bool >(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_ContainerNode_unreadName(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::ContainerNode *arg1 = (pj::ContainerNode *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  pj::string result;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__ContainerNode, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "ContainerNode_unreadName" "', argument " "1"" of type '" "pj::ContainerNode const *""'"); 
  }
  arg1 = reinterpret_cast< pj::ContainerNode * >(argp1);
  try {
    result = ((pj::ContainerNode const *)arg1)->unreadName();
  } catch(pj::Error &_e) {
    SWIG_Python_Raise(SWIG_NewPointerObj((new pj::Error(static_cast< const pj::Error& >(_e))),SWIGTYPE_p_pj__Error,SWIG_POINTER_OWN), "pj::Error", SWIGTYPE_p_pj__Error); SWIG_fail;
  }
  resultobj = SWIG_From_std_string(static_cast< std::string >(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_ContainerNode_readInt__SWIG_0(PyObject *SWIGUNUSEDPARM(self), Py_ssize_t nobjs, PyObject **swig_obj) {
  PyObject *resultobj = 0;
  pj::ContainerNode *arg1 = (pj::ContainerNode *) 0 ;
  pj::string *arg2 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  int res2 = SWIG_OLDOBJ ;
  int result;
  
  if ((nobjs < 2) || (nobjs > 2)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__ContainerNode, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "ContainerNode_readInt" "', argument " "1"" of type '" "pj::ContainerNode const *""'"); 
  }
  arg1 = reinterpret_cast< pj::ContainerNode * >(argp1);
  {
    std::string *ptr = (std::string *)0;
    res2 = SWIG_AsPtr_std_string(swig_obj[1], &ptr);
    if (!SWIG_IsOK(res2)) {
      SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "ContainerNode_readInt" "', argument " "2"" of type '" "pj::string const &""'"); 
    }
    if (!ptr) {
      SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "ContainerNode_readInt" "', argument " "2"" of type '" "pj::string const &""'"); 
    }
    arg2 = ptr;
  }
  try {
    result = (int)((pj::ContainerNode const *)arg1)->readInt((pj::string const &)*arg2);
  } catch(pj::Error &_e) {
    SWIG_Python_Raise(SWIG_NewPointerObj((new pj::Error(static_cast< const pj::Error& >(_e))),SWIGTYPE_p_pj__Error,SWIG_POINTER_OWN), "pj::Error", SWIGTYPE_p_pj__Error); SWIG_fail;
  }
  resultobj = SWIG_From_int(static_cast< int >(result));
  if (SWIG_IsNewObj(res2)) delete arg2;
  return resultobj;
fail:
  if (SWIG_IsNewObj(res2)) delete arg2;
  return NULL;
}


SWIGINTERN PyObject *_wrap_ContainerNode_readInt__SWIG_1(PyObject *SWIGUNUSEDPARM(self), Py_ssize_t nobjs, PyObject **swig_obj) {
  PyObject *resultobj = 0;
  pj::ContainerNode *arg1 = (pj::ContainerNode *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  int result;
  
  if ((nobjs < 1) || (nobjs > 1)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__ContainerNode, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "ContainerNode_readInt" "', argument " "1"" of type '" "pj::ContainerNode const *""'"); 
  }
  arg1 = reinterpret_cast< pj::ContainerNode * >(argp1);
  try {
    result = (int)((pj::ContainerNode const *)arg1)->readInt();
  } catch(pj::Error &_e) {
    SWIG_Python_Raise(SWIG_NewPointerObj((new pj::Error(static_cast< const pj::Error& >(_e))),SWIGTYPE_p_pj__Error,SWIG_POINTER_OWN), "pj::Error", SWIGTYPE_p_pj__Error); SWIG_fail;
  }
  resultobj = SWIG_From_int(static_cast< int >(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_ContainerNode_readInt(PyObject *self, PyObject *args) {
  Py_ssize_t argc;
  PyObject *argv[3] = {
    0
  };
  
  if (!(argc = SWIG_Python_UnpackTuple(args, "ContainerNode_readInt", 0, 2, argv))) SWIG_fail;
  --argc;
  if (argc == 1) {
    int _v;
    void *vptr = 0;
    int res = SWIG_ConvertPtr(argv[0], &vptr, SWIGTYPE_p_pj__ContainerNode, 0);
    _v = SWIG_CheckState(res);
    if (_v) {
      return _wrap_ContainerNode_readInt__SWIG_1(self, argc, argv);
    }
  }
  if (argc == 2) {
    int _v;
    void *vptr = 0;
    int res = SWIG_ConvertPtr(argv[0], &vptr, SWIGTYPE_p_pj__ContainerNode, 0);
    _v = SWIG_CheckState(res);
    if (_v) {
      int res = SWIG_AsPtr_std_string(argv[1], (std::string**)(0));
      _v = SWIG_CheckState(res);
      if (_v) {
        return _wrap_ContainerNode_readInt__SWIG_0(self, argc, argv);
      }
    }
  }
  
fail:
  SWIG_Python_RaiseOrModifyTypeError("Wrong number or type of arguments for overloaded function 'ContainerNode_readInt'.\n"
    "  Possible C/C++ prototypes are:\n"
    "    pj::ContainerNode::readInt(pj::string const &) const\n"
    "    pj::ContainerNode::readInt() const\n");
  return 0;
}


SWIGINTERN PyObject *_wrap_ContainerNode_readNumber__SWIG_0(PyObject *SWIGUNUSEDPARM(self), Py_ssize_t nobjs, PyObject **swig_obj) {
  PyObject *resultobj = 0;
  pj::ContainerNode *arg1 = (pj::ContainerNode *) 0 ;
  pj::string *arg2 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  int res2 = SWIG_OLDOBJ ;
  float result;
  
  if ((nobjs < 2) || (nobjs > 2)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__ContainerNode, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "ContainerNode_readNumber" "', argument " "1"" of type '" "pj::ContainerNode const *""'"); 
  }
  arg1 = reinterpret_cast< pj::ContainerNode * >(argp1);
  {
    std::string *ptr = (std::string *)0;
    res2 = SWIG_AsPtr_std_string(swig_obj[1], &ptr);
    if (!SWIG_IsOK(res2)) {
      SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "ContainerNode_readNumber" "', argument " "2"" of type '" "pj::string const &""'"); 
    }
    if (!ptr) {
      SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "ContainerNode_readNumber" "', argument " "2"" of type '" "pj::string const &""'"); 
    }
    arg2 = ptr;
  }
  try {
    result = (float)((pj::ContainerNode const *)arg1)->readNumber((pj::string const &)*arg2);
  } catch(pj::Error &_e) {
    SWIG_Python_Raise(SWIG_NewPointerObj((new pj::Error(static_cast< const pj::Error& >(_e))),SWIGTYPE_p_pj__Error,SWIG_POINTER_OWN), "pj::Error", SWIGTYPE_p_pj__Error); SWIG_fail;
  }
  resultobj = SWIG_From_float(static_cast< float >(result));
  if (SWIG_IsNewObj(res2)) delete arg2;
  return resultobj;
fail:
  if (SWIG_IsNewObj(res2)) delete arg2;
  return NULL;
}


SWIGINTERN PyObject *_wrap_ContainerNode_readNumber__SWIG_1(PyObject *SWIGUNUSEDPARM(self), Py_ssize_t nobjs, PyObject **swig_obj) {
  PyObject *resultobj = 0;
  pj::ContainerNode *arg1 = (pj::ContainerNode *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  float result;
  
  if ((nobjs < 1) || (nobjs > 1)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__ContainerNode, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "ContainerNode_readNumber" "', argument " "1"" of type '" "pj::ContainerNode const *""'"); 
  }
  arg1 = reinterpret_cast< pj::ContainerNode * >(argp1);
  try {
    result = (float)((pj::ContainerNode const *)arg1)->readNumber();
  } catch(pj::Error &_e) {
    SWIG_Python_Raise(SWIG_NewPointerObj((new pj::Error(static_cast< const pj::Error& >(_e))),SWIGTYPE_p_pj__Error,SWIG_POINTER_OWN), "pj::Error", SWIGTYPE_p_pj__Error); SWIG_fail;
  }
  resultobj = SWIG_From_float(static_cast< float >(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_ContainerNode_readNumber(PyObject *self, PyObject *args) {
  Py_ssize_t argc;
  PyObject *argv[3] = {
    0
  };
  
  if (!(argc = SWIG_Python_UnpackTuple(args, "ContainerNode_readNumber", 0, 2, argv))) SWIG_fail;
  --argc;
  if (argc == 1) {
    int _v;
    void *vptr = 0;
    int res = SWIG_ConvertPtr(argv[0], &vptr, SWIGTYPE_p_pj__ContainerNode, 0);
    _v = SWIG_CheckState(res);
    if (_v) {
      return _wrap_ContainerNode_readNumber__SWIG_1(self, argc, argv);
    }
  }
  if (argc == 2) {
    int _v;
    void *vptr = 0;
    int res = SWIG_ConvertPtr(argv[0], &vptr, SWIGTYPE_p_pj__ContainerNode, 0);
    _v = SWIG_CheckState(res);
    if (_v) {
      int res = SWIG_AsPtr_std_string(argv[1], (std::string**)(0));
      _v = SWIG_CheckState(res);
      if (_v) {
        return _wrap_ContainerNode_readNumber__SWIG_0(self, argc, argv);
      }
    }
  }
  
fail:
  SWIG_Python_RaiseOrModifyTypeError("Wrong number or type of arguments for overloaded function 'ContainerNode_readNumber'.\n"
    "  Possible C/C++ prototypes are:\n"
    "    pj::ContainerNode::readNumber(pj::string const &) const\n"
    "    pj::ContainerNode::readNumber() const\n");
  return 0;
}


SWIGINTERN PyObject *_wrap_ContainerNode_readBool__SWIG_0(PyObject *SWIGUNUSEDPARM(self), Py_ssize_t nobjs, PyObject **swig_obj) {
  PyObject *resultobj = 0;
  pj::ContainerNode *arg1 = (pj::ContainerNode *) 0 ;
  pj::string *arg2 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  int res2 = SWIG_OLDOBJ ;
  bool result;
  
  if ((nobjs < 2) || (nobjs > 2)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__ContainerNode, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "ContainerNode_readBool" "', argument " "1"" of type '" "pj::ContainerNode const *""'"); 
  }
  arg1 = reinterpret_cast< pj::ContainerNode * >(argp1);
  {
    std::string *ptr = (std::string *)0;
    res2 = SWIG_AsPtr_std_string(swig_obj[1], &ptr);
    if (!SWIG_IsOK(res2)) {
      SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "ContainerNode_readBool" "', argument " "2"" of type '" "pj::string const &""'"); 
    }
    if (!ptr) {
      SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "ContainerNode_readBool" "', argument " "2"" of type '" "pj::string const &""'"); 
    }
    arg2 = ptr;
  }
  try {
    result = (bool)((pj::ContainerNode const *)arg1)->readBool((pj::string const &)*arg2);
  } catch(pj::Error &_e) {
    SWIG_Python_Raise(SWIG_NewPointerObj((new pj::Error(static_cast< const pj::Error& >(_e))),SWIGTYPE_p_pj__Error,SWIG_POINTER_OWN), "pj::Error", SWIGTYPE_p_pj__Error); SWIG_fail;
  }
  resultobj = SWIG_From_bool(static_cast< bool >(result));
  if (SWIG_IsNewObj(res2)) delete arg2;
  return resultobj;
fail:
  if (SWIG_IsNewObj(res2)) delete arg2;
  return NULL;
}


SWIGINTERN PyObject *_wrap_ContainerNode_readBool__SWIG_1(PyObject *SWIGUNUSEDPARM(self), Py_ssize_t nobjs, PyObject **swig_obj) {
  PyObject *resultobj = 0;
  pj::ContainerNode *arg1 = (pj::ContainerNode *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  bool result;
  
  if ((nobjs < 1) || (nobjs > 1)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__ContainerNode, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "ContainerNode_readBool" "', argument " "1"" of type '" "pj::ContainerNode const *""'"); 
  }
  arg1 = reinterpret_cast< pj::ContainerNode * >(argp1);
  try {
    result = (bool)((pj::ContainerNode const *)arg1)->readBool();
  } catch(pj::Error &_e) {
    SWIG_Python_Raise(SWIG_NewPointerObj((new pj::Error(static_cast< const pj::Error& >(_e))),SWIGTYPE_p_pj__Error,SWIG_POINTER_OWN), "pj::Error", SWIGTYPE_p_pj__Error); SWIG_fail;
  }
  resultobj = SWIG_From_bool(static_cast< bool >(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_ContainerNode_readBool(PyObject *self, PyObject *args) {
  Py_ssize_t argc;
  PyObject *argv[3] = {
    0
  };
  
  if (!(argc = SWIG_Python_UnpackTuple(args, "ContainerNode_readBool", 0, 2, argv))) SWIG_fail;
  --argc;
  if (argc == 1) {
    int _v;
    void *vptr = 0;
    int res = SWIG_ConvertPtr(argv[0], &vptr, SWIGTYPE_p_pj__ContainerNode, 0);
    _v = SWIG_CheckState(res);
    if (_v) {
      return _wrap_ContainerNode_readBool__SWIG_1(self, argc, argv);
    }
  }
  if (argc == 2) {
    int _v;
    void *vptr = 0;
    int res = SWIG_ConvertPtr(argv[0], &vptr, SWIGTYPE_p_pj__ContainerNode, 0);
    _v = SWIG_CheckState(res);
    if (_v) {
      int res = SWIG_AsPtr_std_string(argv[1], (std::string**)(0));
      _v = SWIG_CheckState(res);
      if (_v) {
        return _wrap_ContainerNode_readBool__SWIG_0(self, argc, argv);
      }
    }
  }
  
fail:
  SWIG_Python_RaiseOrModifyTypeError("Wrong number or type of arguments for overloaded function 'ContainerNode_readBool'.\n"
    "  Possible C/C++ prototypes are:\n"
    "    pj::ContainerNode::readBool(pj::string const &) const\n"
    "    pj::ContainerNode::readBool() const\n");
  return 0;
}


SWIGINTERN PyObject *_wrap_ContainerNode_readString__SWIG_0(PyObject *SWIGUNUSEDPARM(self), Py_ssize_t nobjs, PyObject **swig_obj) {
  PyObject *resultobj = 0;
  pj::ContainerNode *arg1 = (pj::ContainerNode *) 0 ;
  pj::string *arg2 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  int res2 = SWIG_OLDOBJ ;
  pj::string result;
  
  if ((nobjs < 2) || (nobjs > 2)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__ContainerNode, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "ContainerNode_readString" "', argument " "1"" of type '" "pj::ContainerNode const *""'"); 
  }
  arg1 = reinterpret_cast< pj::ContainerNode * >(argp1);
  {
    std::string *ptr = (std::string *)0;
    res2 = SWIG_AsPtr_std_string(swig_obj[1], &ptr);
    if (!SWIG_IsOK(res2)) {
      SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "ContainerNode_readString" "', argument " "2"" of type '" "pj::string const &""'"); 
    }
    if (!ptr) {
      SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "ContainerNode_readString" "', argument " "2"" of type '" "pj::string const &""'"); 
    }
    arg2 = ptr;
  }
  try {
    result = ((pj::ContainerNode const *)arg1)->readString((pj::string const &)*arg2);
  } catch(pj::Error &_e) {
    SWIG_Python_Raise(SWIG_NewPointerObj((new pj::Error(static_cast< const pj::Error& >(_e))),SWIGTYPE_p_pj__Error,SWIG_POINTER_OWN), "pj::Error", SWIGTYPE_p_pj__Error); SWIG_fail;
  }
  resultobj = SWIG_From_std_string(static_cast< std::string >(result));
  if (SWIG_IsNewObj(res2)) delete arg2;
  return resultobj;
fail:
  if (SWIG_IsNewObj(res2)) delete arg2;
  return NULL;
}


SWIGINTERN PyObject *_wrap_ContainerNode_readString__SWIG_1(PyObject *SWIGUNUSEDPARM(self), Py_ssize_t nobjs, PyObject **swig_obj) {
  PyObject *resultobj = 0;
  pj::ContainerNode *arg1 = (pj::ContainerNode *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  pj::string result;
  
  if ((nobjs < 1) || (nobjs > 1)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__ContainerNode, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "ContainerNode_readString" "', argument " "1"" of type '" "pj::ContainerNode const *""'"); 
  }
  arg1 = reinterpret_cast< pj::ContainerNode * >(argp1);
  try {
    result = ((pj::ContainerNode const *)arg1)->readString();
  } catch(pj::Error &_e) {
    SWIG_Python_Raise(SWIG_NewPointerObj((new pj::Error(static_cast< const pj::Error& >(_e))),SWIGTYPE_p_pj__Error,SWIG_POINTER_OWN), "pj::Error", SWIGTYPE_p_pj__Error); SWIG_fail;
  }
  resultobj = SWIG_From_std_string(static_cast< std::string >(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_ContainerNode_readString(PyObject *self, PyObject *args) {
  Py_ssize_t argc;
  PyObject *argv[3] = {
    0
  };
  
  if (!(argc = SWIG_Python_UnpackTuple(args, "ContainerNode_readString", 0, 2, argv))) SWIG_fail;
  --argc;
  if (argc == 1) {
    int _v;
    void *vptr = 0;
    int res = SWIG_ConvertPtr(argv[0], &vptr, SWIGTYPE_p_pj__ContainerNode, 0);
    _v = SWIG_CheckState(res);
    if (_v) {
      return _wrap_ContainerNode_readString__SWIG_1(self, argc, argv);
    }
  }
  if (argc == 2) {
    int _v;
    void *vptr = 0;
    int res = SWIG_ConvertPtr(argv[0], &vptr, SWIGTYPE_p_pj__ContainerNode, 0);
    _v = SWIG_CheckState(res);
    if (_v) {
      int res = SWIG_AsPtr_std_string(argv[1], (std::string**)(0));
      _v = SWIG_CheckState(res);
      if (_v) {
        return _wrap_ContainerNode_readString__SWIG_0(self, argc, argv);
      }
    }
  }
  
fail:
  SWIG_Python_RaiseOrModifyTypeError("Wrong number or type of arguments for overloaded function 'ContainerNode_readString'.\n"
    "  Possible C/C++ prototypes are:\n"
    "    pj::ContainerNode::readString(pj::string const &) const\n"
    "    pj::ContainerNode::readString() const\n");
  return 0;
}


SWIGINTERN PyObject *_wrap_ContainerNode_readStringVector__SWIG_0(PyObject *SWIGUNUSEDPARM(self), Py_ssize_t nobjs, PyObject **swig_obj) {
  PyObject *resultobj = 0;
  pj::ContainerNode *arg1 = (pj::ContainerNode *) 0 ;
  pj::string *arg2 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  int res2 = SWIG_OLDOBJ ;
  pj::StringVector result;
  
  if ((nobjs < 2) || (nobjs > 2)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__ContainerNode, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "ContainerNode_readStringVector" "', argument " "1"" of type '" "pj::ContainerNode const *""'"); 
  }
  arg1 = reinterpret_cast< pj::ContainerNode * >(argp1);
  {
    std::string *ptr = (std::string *)0;
    res2 = SWIG_AsPtr_std_string(swig_obj[1], &ptr);
    if (!SWIG_IsOK(res2)) {
      SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "ContainerNode_readStringVector" "', argument " "2"" of type '" "pj::string const &""'"); 
    }
    if (!ptr) {
      SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "ContainerNode_readStringVector" "', argument " "2"" of type '" "pj::string const &""'"); 
    }
    arg2 = ptr;
  }
  try {
    result = ((pj::ContainerNode const *)arg1)->readStringVector((pj::string const &)*arg2);
  } catch(pj::Error &_e) {
    SWIG_Python_Raise(SWIG_NewPointerObj((new pj::Error(static_cast< const pj::Error& >(_e))),SWIGTYPE_p_pj__Error,SWIG_POINTER_OWN), "pj::Error", SWIGTYPE_p_pj__Error); SWIG_fail;
  }
  resultobj = swig::from(static_cast< std::vector< std::string,std::allocator< std::string > > >(result));
  if (SWIG_IsNewObj(res2)) delete arg2;
  return resultobj;
fail:
  if (SWIG_IsNewObj(res2)) delete arg2;
  return NULL;
}


SWIGINTERN PyObject *_wrap_ContainerNode_readStringVector__SWIG_1(PyObject *SWIGUNUSEDPARM(self), Py_ssize_t nobjs, PyObject **swig_obj) {
  PyObject *resultobj = 0;
  pj::ContainerNode *arg1 = (pj::ContainerNode *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  pj::StringVector result;
  
  if ((nobjs < 1) || (nobjs > 1)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__ContainerNode, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "ContainerNode_readStringVector" "', argument " "1"" of type '" "pj::ContainerNode const *""'"); 
  }
  arg1 = reinterpret_cast< pj::ContainerNode * >(argp1);
  try {
    result = ((pj::ContainerNode const *)arg1)->readStringVector();
  } catch(pj::Error &_e) {
    SWIG_Python_Raise(SWIG_NewPointerObj((new pj::Error(static_cast< const pj::Error& >(_e))),SWIGTYPE_p_pj__Error,SWIG_POINTER_OWN), "pj::Error", SWIGTYPE_p_pj__Error); SWIG_fail;
  }
  resultobj = swig::from(static_cast< std::vector< std::string,std::allocator< std::string > > >(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_ContainerNode_readStringVector(PyObject *self, PyObject *args) {
  Py_ssize_t argc;
  PyObject *argv[3] = {
    0
  };
  
  if (!(argc = SWIG_Python_UnpackTuple(args, "ContainerNode_readStringVector", 0, 2, argv))) SWIG_fail;
  --argc;
  if (argc == 1) {
    int _v;
    void *vptr = 0;
    int res = SWIG_ConvertPtr(argv[0], &vptr, SWIGTYPE_p_pj__ContainerNode, 0);
    _v = SWIG_CheckState(res);
    if (_v) {
      return _wrap_ContainerNode_readStringVector__SWIG_1(self, argc, argv);
    }
  }
  if (argc == 2) {
    int _v;
    void *vptr = 0;
    int res = SWIG_ConvertPtr(argv[0], &vptr, SWIGTYPE_p_pj__ContainerNode, 0);
    _v = SWIG_CheckState(res);
    if (_v) {
      int res = SWIG_AsPtr_std_string(argv[1], (std::string**)(0));
      _v = SWIG_CheckState(res);
      if (_v) {
        return _wrap_ContainerNode_readStringVector__SWIG_0(self, argc, argv);
      }
    }
  }
  
fail:
  SWIG_Python_RaiseOrModifyTypeError("Wrong number or type of arguments for overloaded function 'ContainerNode_readStringVector'.\n"
    "  Possible C/C++ prototypes are:\n"
    "    pj::ContainerNode::readStringVector(pj::string const &) const\n"
    "    pj::ContainerNode::readStringVector() const\n");
  return 0;
}


SWIGINTERN PyObject *_wrap_ContainerNode_readObject(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::ContainerNode *arg1 = (pj::ContainerNode *) 0 ;
  pj::PersistentObject *arg2 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  void *argp2 = 0 ;
  int res2 = 0 ;
  PyObject *swig_obj[2] ;
  
  if (!SWIG_Python_UnpackTuple(args, "ContainerNode_readObject", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__ContainerNode, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "ContainerNode_readObject" "', argument " "1"" of type '" "pj::ContainerNode const *""'"); 
  }
  arg1 = reinterpret_cast< pj::ContainerNode * >(argp1);
  res2 = SWIG_ConvertPtr(swig_obj[1], &argp2, SWIGTYPE_p_pj__PersistentObject,  0 );
  if (!SWIG_IsOK(res2)) {
    SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "ContainerNode_readObject" "', argument " "2"" of type '" "pj::PersistentObject &""'"); 
  }
  if (!argp2) {
    SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "ContainerNode_readObject" "', argument " "2"" of type '" "pj::PersistentObject &""'"); 
  }
  arg2 = reinterpret_cast< pj::PersistentObject * >(argp2);
  try {
    ((pj::ContainerNode const *)arg1)->readObject(*arg2);
  } catch(pj::Error &_e) {
    SWIG_Python_Raise(SWIG_NewPointerObj((new pj::Error(static_cast< const pj::Error& >(_e))),SWIGTYPE_p_pj__Error,SWIG_POINTER_OWN), "pj::Error", SWIGTYPE_p_pj__Error); SWIG_fail;
  }
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_ContainerNode_readContainer__SWIG_0(PyObject *SWIGUNUSEDPARM(self), Py_ssize_t nobjs, PyObject **swig_obj) {
  PyObject *resultobj = 0;
  pj::ContainerNode *arg1 = (pj::ContainerNode *) 0 ;
  pj::string *arg2 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  int res2 = SWIG_OLDOBJ ;
  pj::ContainerNode result;
  
  if ((nobjs < 2) || (nobjs > 2)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__ContainerNode, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "ContainerNode_readContainer" "', argument " "1"" of type '" "pj::ContainerNode const *""'"); 
  }
  arg1 = reinterpret_cast< pj::ContainerNode * >(argp1);
  {
    std::string *ptr = (std::string *)0;
    res2 = SWIG_AsPtr_std_string(swig_obj[1], &ptr);
    if (!SWIG_IsOK(res2)) {
      SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "ContainerNode_readContainer" "', argument " "2"" of type '" "pj::string const &""'"); 
    }
    if (!ptr) {
      SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "ContainerNode_readContainer" "', argument " "2"" of type '" "pj::string const &""'"); 
    }
    arg2 = ptr;
  }
  try {
    result = ((pj::ContainerNode const *)arg1)->readContainer((pj::string const &)*arg2);
  } catch(pj::Error &_e) {
    SWIG_Python_Raise(SWIG_NewPointerObj((new pj::Error(static_cast< const pj::Error& >(_e))),SWIGTYPE_p_pj__Error,SWIG_POINTER_OWN), "pj::Error", SWIGTYPE_p_pj__Error); SWIG_fail;
  }
  resultobj = SWIG_NewPointerObj((new pj::ContainerNode(static_cast< const pj::ContainerNode& >(result))), SWIGTYPE_p_pj__ContainerNode, SWIG_POINTER_OWN |  0 );
  if (SWIG_IsNewObj(res2)) delete arg2;
  return resultobj;
fail:
  if (SWIG_IsNewObj(res2)) delete arg2;
  return NULL;
}


SWIGINTERN PyObject *_wrap_ContainerNode_readContainer__SWIG_1(PyObject *SWIGUNUSEDPARM(self), Py_ssize_t nobjs, PyObject **swig_obj) {
  PyObject *resultobj = 0;
  pj::ContainerNode *arg1 = (pj::ContainerNode *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  pj::ContainerNode result;
  
  if ((nobjs < 1) || (nobjs > 1)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__ContainerNode, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "ContainerNode_readContainer" "', argument " "1"" of type '" "pj::ContainerNode const *""'"); 
  }
  arg1 = reinterpret_cast< pj::ContainerNode * >(argp1);
  try {
    result = ((pj::ContainerNode const *)arg1)->readContainer();
  } catch(pj::Error &_e) {
    SWIG_Python_Raise(SWIG_NewPointerObj((new pj::Error(static_cast< const pj::Error& >(_e))),SWIGTYPE_p_pj__Error,SWIG_POINTER_OWN), "pj::Error", SWIGTYPE_p_pj__Error); SWIG_fail;
  }
  resultobj = SWIG_NewPointerObj((new pj::ContainerNode(static_cast< const pj::ContainerNode& >(result))), SWIGTYPE_p_pj__ContainerNode, SWIG_POINTER_OWN |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_ContainerNode_readContainer(PyObject *self, PyObject *args) {
  Py_ssize_t argc;
  PyObject *argv[3] = {
    0
  };
  
  if (!(argc = SWIG_Python_UnpackTuple(args, "ContainerNode_readContainer", 0, 2, argv))) SWIG_fail;
  --argc;
  if (argc == 1) {
    int _v;
    void *vptr = 0;
    int res = SWIG_ConvertPtr(argv[0], &vptr, SWIGTYPE_p_pj__ContainerNode, 0);
    _v = SWIG_CheckState(res);
    if (_v) {
      return _wrap_ContainerNode_readContainer__SWIG_1(self, argc, argv);
    }
  }
  if (argc == 2) {
    int _v;
    void *vptr = 0;
    int res = SWIG_ConvertPtr(argv[0], &vptr, SWIGTYPE_p_pj__ContainerNode, 0);
    _v = SWIG_CheckState(res);
    if (_v) {
      int res = SWIG_AsPtr_std_string(argv[1], (std::string**)(0));
      _v = SWIG_CheckState(res);
      if (_v) {
        return _wrap_ContainerNode_readContainer__SWIG_0(self, argc, argv);
      }
    }
  }
  
fail:
  SWIG_Python_RaiseOrModifyTypeError("Wrong number or type of arguments for overloaded function 'ContainerNode_readContainer'.\n"
    "  Possible C/C++ prototypes are:\n"
    "    pj::ContainerNode::readContainer(pj::string const &) const\n"
    "    pj::ContainerNode::readContainer() const\n");
  return 0;
}


SWIGINTERN PyObject *_wrap_ContainerNode_readArray__SWIG_0(PyObject *SWIGUNUSEDPARM(self), Py_ssize_t nobjs, PyObject **swig_obj) {
  PyObject *resultobj = 0;
  pj::ContainerNode *arg1 = (pj::ContainerNode *) 0 ;
  pj::string *arg2 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  int res2 = SWIG_OLDOBJ ;
  pj::ContainerNode result;
  
  if ((nobjs < 2) || (nobjs > 2)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__ContainerNode, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "ContainerNode_readArray" "', argument " "1"" of type '" "pj::ContainerNode const *""'"); 
  }
  arg1 = reinterpret_cast< pj::ContainerNode * >(argp1);
  {
    std::string *ptr = (std::string *)0;
    res2 = SWIG_AsPtr_std_string(swig_obj[1], &ptr);
    if (!SWIG_IsOK(res2)) {
      SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "ContainerNode_readArray" "', argument " "2"" of type '" "pj::string const &""'"); 
    }
    if (!ptr) {
      SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "ContainerNode_readArray" "', argument " "2"" of type '" "pj::string const &""'"); 
    }
    arg2 = ptr;
  }
  try {
    result = ((pj::ContainerNode const *)arg1)->readArray((pj::string const &)*arg2);
  } catch(pj::Error &_e) {
    SWIG_Python_Raise(SWIG_NewPointerObj((new pj::Error(static_cast< const pj::Error& >(_e))),SWIGTYPE_p_pj__Error,SWIG_POINTER_OWN), "pj::Error", SWIGTYPE_p_pj__Error); SWIG_fail;
  }
  resultobj = SWIG_NewPointerObj((new pj::ContainerNode(static_cast< const pj::ContainerNode& >(result))), SWIGTYPE_p_pj__ContainerNode, SWIG_POINTER_OWN |  0 );
  if (SWIG_IsNewObj(res2)) delete arg2;
  return resultobj;
fail:
  if (SWIG_IsNewObj(res2)) delete arg2;
  return NULL;
}


SWIGINTERN PyObject *_wrap_ContainerNode_readArray__SWIG_1(PyObject *SWIGUNUSEDPARM(self), Py_ssize_t nobjs, PyObject **swig_obj) {
  PyObject *resultobj = 0;
  pj::ContainerNode *arg1 = (pj::ContainerNode *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  pj::ContainerNode result;
  
  if ((nobjs < 1) || (nobjs > 1)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__ContainerNode, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "ContainerNode_readArray" "', argument " "1"" of type '" "pj::ContainerNode const *""'"); 
  }
  arg1 = reinterpret_cast< pj::ContainerNode * >(argp1);
  try {
    result = ((pj::ContainerNode const *)arg1)->readArray();
  } catch(pj::Error &_e) {
    SWIG_Python_Raise(SWIG_NewPointerObj((new pj::Error(static_cast< const pj::Error& >(_e))),SWIGTYPE_p_pj__Error,SWIG_POINTER_OWN), "pj::Error", SWIGTYPE_p_pj__Error); SWIG_fail;
  }
  resultobj = SWIG_NewPointerObj((new pj::ContainerNode(static_cast< const pj::ContainerNode& >(result))), SWIGTYPE_p_pj__ContainerNode, SWIG_POINTER_OWN |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_ContainerNode_readArray(PyObject *self, PyObject *args) {
  Py_ssize_t argc;
  PyObject *argv[3] = {
    0
  };
  
  if (!(argc = SWIG_Python_UnpackTuple(args, "ContainerNode_readArray", 0, 2, argv))) SWIG_fail;
  --argc;
  if (argc == 1) {
    int _v;
    void *vptr = 0;
    int res = SWIG_ConvertPtr(argv[0], &vptr, SWIGTYPE_p_pj__ContainerNode, 0);
    _v = SWIG_CheckState(res);
    if (_v) {
      return _wrap_ContainerNode_readArray__SWIG_1(self, argc, argv);
    }
  }
  if (argc == 2) {
    int _v;
    void *vptr = 0;
    int res = SWIG_ConvertPtr(argv[0], &vptr, SWIGTYPE_p_pj__ContainerNode, 0);
    _v = SWIG_CheckState(res);
    if (_v) {
      int res = SWIG_AsPtr_std_string(argv[1], (std::string**)(0));
      _v = SWIG_CheckState(res);
      if (_v) {
        return _wrap_ContainerNode_readArray__SWIG_0(self, argc, argv);
      }
    }
  }
  
fail:
  SWIG_Python_RaiseOrModifyTypeError("Wrong number or type of arguments for overloaded function 'ContainerNode_readArray'.\n"
    "  Possible C/C++ prototypes are:\n"
    "    pj::ContainerNode::readArray(pj::string const &) const\n"
    "    pj::ContainerNode::readArray() const\n");
  return 0;
}


SWIGINTERN PyObject *_wrap_ContainerNode_writeNumber(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::ContainerNode *arg1 = (pj::ContainerNode *) 0 ;
  pj::string *arg2 = 0 ;
  float arg3 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  int res2 = SWIG_OLDOBJ ;
  float val3 ;
  int ecode3 = 0 ;
  PyObject *swig_obj[3] ;
  
  if (!SWIG_Python_UnpackTuple(args, "ContainerNode_writeNumber", 3, 3, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__ContainerNode, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "ContainerNode_writeNumber" "', argument " "1"" of type '" "pj::ContainerNode *""'"); 
  }
  arg1 = reinterpret_cast< pj::ContainerNode * >(argp1);
  {
    std::string *ptr = (std::string *)0;
    res2 = SWIG_AsPtr_std_string(swig_obj[1], &ptr);
    if (!SWIG_IsOK(res2)) {
      SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "ContainerNode_writeNumber" "', argument " "2"" of type '" "pj::string const &""'"); 
    }
    if (!ptr) {
      SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "ContainerNode_writeNumber" "', argument " "2"" of type '" "pj::string const &""'"); 
    }
    arg2 = ptr;
  }
  ecode3 = SWIG_AsVal_float(swig_obj[2], &val3);
  if (!SWIG_IsOK(ecode3)) {
    SWIG_exception_fail(SWIG_ArgError(ecode3), "in method '" "ContainerNode_writeNumber" "', argument " "3"" of type '" "float""'");
  } 
  arg3 = static_cast< float >(val3);
  try {
    (arg1)->writeNumber((pj::string const &)*arg2,arg3);
  } catch(pj::Error &_e) {
    SWIG_Python_Raise(SWIG_NewPointerObj((new pj::Error(static_cast< const pj::Error& >(_e))),SWIGTYPE_p_pj__Error,SWIG_POINTER_OWN), "pj::Error", SWIGTYPE_p_pj__Error); SWIG_fail;
  }
  resultobj = SWIG_Py_Void();
  if (SWIG_IsNewObj(res2)) delete arg2;
  return resultobj;
fail:
  if (SWIG_IsNewObj(res2)) delete arg2;
  return NULL;
}


SWIGINTERN PyObject *_wrap_ContainerNode_writeInt(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::ContainerNode *arg1 = (pj::ContainerNode *) 0 ;
  pj::string *arg2 = 0 ;
  int arg3 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  int res2 = SWIG_OLDOBJ ;
  int val3 ;
  int ecode3 = 0 ;
  PyObject *swig_obj[3] ;
  
  if (!SWIG_Python_UnpackTuple(args, "ContainerNode_writeInt", 3, 3, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__ContainerNode, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "ContainerNode_writeInt" "', argument " "1"" of type '" "pj::ContainerNode *""'"); 
  }
  arg1 = reinterpret_cast< pj::ContainerNode * >(argp1);
  {
    std::string *ptr = (std::string *)0;
    res2 = SWIG_AsPtr_std_string(swig_obj[1], &ptr);
    if (!SWIG_IsOK(res2)) {
      SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "ContainerNode_writeInt" "', argument " "2"" of type '" "pj::string const &""'"); 
    }
    if (!ptr) {
      SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "ContainerNode_writeInt" "', argument " "2"" of type '" "pj::string const &""'"); 
    }
    arg2 = ptr;
  }
  ecode3 = SWIG_AsVal_int(swig_obj[2], &val3);
  if (!SWIG_IsOK(ecode3)) {
    SWIG_exception_fail(SWIG_ArgError(ecode3), "in method '" "ContainerNode_writeInt" "', argument " "3"" of type '" "int""'");
  } 
  arg3 = static_cast< int >(val3);
  try {
    (arg1)->writeInt((pj::string const &)*arg2,arg3);
  } catch(pj::Error &_e) {
    SWIG_Python_Raise(SWIG_NewPointerObj((new pj::Error(static_cast< const pj::Error& >(_e))),SWIGTYPE_p_pj__Error,SWIG_POINTER_OWN), "pj::Error", SWIGTYPE_p_pj__Error); SWIG_fail;
  }
  resultobj = SWIG_Py_Void();
  if (SWIG_IsNewObj(res2)) delete arg2;
  return resultobj;
fail:
  if (SWIG_IsNewObj(res2)) delete arg2;
  return NULL;
}


SWIGINTERN PyObject *_wrap_ContainerNode_writeBool(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::ContainerNode *arg1 = (pj::ContainerNode *) 0 ;
  pj::string *arg2 = 0 ;
  bool arg3 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  int res2 = SWIG_OLDOBJ ;
  bool val3 ;
  int ecode3 = 0 ;
  PyObject *swig_obj[3] ;
  
  if (!SWIG_Python_UnpackTuple(args, "ContainerNode_writeBool", 3, 3, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__ContainerNode, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "ContainerNode_writeBool" "', argument " "1"" of type '" "pj::ContainerNode *""'"); 
  }
  arg1 = reinterpret_cast< pj::ContainerNode * >(argp1);
  {
    std::string *ptr = (std::string *)0;
    res2 = SWIG_AsPtr_std_string(swig_obj[1], &ptr);
    if (!SWIG_IsOK(res2)) {
      SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "ContainerNode_writeBool" "', argument " "2"" of type '" "pj::string const &""'"); 
    }
    if (!ptr) {
      SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "ContainerNode_writeBool" "', argument " "2"" of type '" "pj::string const &""'"); 
    }
    arg2 = ptr;
  }
  ecode3 = SWIG_AsVal_bool(swig_obj[2], &val3);
  if (!SWIG_IsOK(ecode3)) {
    SWIG_exception_fail(SWIG_ArgError(ecode3), "in method '" "ContainerNode_writeBool" "', argument " "3"" of type '" "bool""'");
  } 
  arg3 = static_cast< bool >(val3);
  try {
    (arg1)->writeBool((pj::string const &)*arg2,arg3);
  } catch(pj::Error &_e) {
    SWIG_Python_Raise(SWIG_NewPointerObj((new pj::Error(static_cast< const pj::Error& >(_e))),SWIGTYPE_p_pj__Error,SWIG_POINTER_OWN), "pj::Error", SWIGTYPE_p_pj__Error); SWIG_fail;
  }
  resultobj = SWIG_Py_Void();
  if (SWIG_IsNewObj(res2)) delete arg2;
  return resultobj;
fail:
  if (SWIG_IsNewObj(res2)) delete arg2;
  return NULL;
}


SWIGINTERN PyObject *_wrap_ContainerNode_writeString(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::ContainerNode *arg1 = (pj::ContainerNode *) 0 ;
  pj::string *arg2 = 0 ;
  pj::string *arg3 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  int res2 = SWIG_OLDOBJ ;
  int res3 = SWIG_OLDOBJ ;
  PyObject *swig_obj[3] ;
  
  if (!SWIG_Python_UnpackTuple(args, "ContainerNode_writeString", 3, 3, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__ContainerNode, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "ContainerNode_writeString" "', argument " "1"" of type '" "pj::ContainerNode *""'"); 
  }
  arg1 = reinterpret_cast< pj::ContainerNode * >(argp1);
  {
    std::string *ptr = (std::string *)0;
    res2 = SWIG_AsPtr_std_string(swig_obj[1], &ptr);
    if (!SWIG_IsOK(res2)) {
      SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "ContainerNode_writeString" "', argument " "2"" of type '" "pj::string const &""'"); 
    }
    if (!ptr) {
      SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "ContainerNode_writeString" "', argument " "2"" of type '" "pj::string const &""'"); 
    }
    arg2 = ptr;
  }
  {
    std::string *ptr = (std::string *)0;
    res3 = SWIG_AsPtr_std_string(swig_obj[2], &ptr);
    if (!SWIG_IsOK(res3)) {
      SWIG_exception_fail(SWIG_ArgError(res3), "in method '" "ContainerNode_writeString" "', argument " "3"" of type '" "pj::string const &""'"); 
    }
    if (!ptr) {
      SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "ContainerNode_writeString" "', argument " "3"" of type '" "pj::string const &""'"); 
    }
    arg3 = ptr;
  }
  try {
    (arg1)->writeString((pj::string const &)*arg2,(pj::string const &)*arg3);
  } catch(pj::Error &_e) {
    SWIG_Python_Raise(SWIG_NewPointerObj((new pj::Error(static_cast< const pj::Error& >(_e))),SWIGTYPE_p_pj__Error,SWIG_POINTER_OWN), "pj::Error", SWIGTYPE_p_pj__Error); SWIG_fail;
  }
  resultobj = SWIG_Py_Void();
  if (SWIG_IsNewObj(res2)) delete arg2;
  if (SWIG_IsNewObj(res3)) delete arg3;
  return resultobj;
fail:
  if (SWIG_IsNewObj(res2)) delete arg2;
  if (SWIG_IsNewObj(res3)) delete arg3;
  return NULL;
}


SWIGINTERN PyObject *_wrap_ContainerNode_writeStringVector(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::ContainerNode *arg1 = (pj::ContainerNode *) 0 ;
  pj::string *arg2 = 0 ;
  pj::StringVector *arg3 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  int res2 = SWIG_OLDOBJ ;
  int res3 = SWIG_OLDOBJ ;
  PyObject *swig_obj[3] ;
  
  if (!SWIG_Python_UnpackTuple(args, "ContainerNode_writeStringVector", 3, 3, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__ContainerNode, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "ContainerNode_writeStringVector" "', argument " "1"" of type '" "pj::ContainerNode *""'"); 
  }
  arg1 = reinterpret_cast< pj::ContainerNode * >(argp1);
  {
    std::string *ptr = (std::string *)0;
    res2 = SWIG_AsPtr_std_string(swig_obj[1], &ptr);
    if (!SWIG_IsOK(res2)) {
      SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "ContainerNode_writeStringVector" "', argument " "2"" of type '" "pj::string const &""'"); 
    }
    if (!ptr) {
      SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "ContainerNode_writeStringVector" "', argument " "2"" of type '" "pj::string const &""'"); 
    }
    arg2 = ptr;
  }
  {
    std::vector< std::string,std::allocator< std::string > > *ptr = (std::vector< std::string,std::allocator< std::string > > *)0;
    res3 = swig::asptr(swig_obj[2], &ptr);
    if (!SWIG_IsOK(res3)) {
      SWIG_exception_fail(SWIG_ArgError(res3), "in method '" "ContainerNode_writeStringVector" "', argument " "3"" of type '" "pj::StringVector const &""'"); 
    }
    if (!ptr) {
      SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "ContainerNode_writeStringVector" "', argument " "3"" of type '" "pj::StringVector const &""'"); 
    }
    arg3 = ptr;
  }
  try {
    (arg1)->writeStringVector((pj::string const &)*arg2,(pj::StringVector const &)*arg3);
  } catch(pj::Error &_e) {
    SWIG_Python_Raise(SWIG_NewPointerObj((new pj::Error(static_cast< const pj::Error& >(_e))),SWIGTYPE_p_pj__Error,SWIG_POINTER_OWN), "pj::Error", SWIGTYPE_p_pj__Error); SWIG_fail;
  }
  resultobj = SWIG_Py_Void();
  if (SWIG_IsNewObj(res2)) delete arg2;
  if (SWIG_IsNewObj(res3)) delete arg3;
  return resultobj;
fail:
  if (SWIG_IsNewObj(res2)) delete arg2;
  if (SWIG_IsNewObj(res3)) delete arg3;
  return NULL;
}


SWIGINTERN PyObject *_wrap_ContainerNode_writeObject(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::ContainerNode *arg1 = (pj::ContainerNode *) 0 ;
  pj::PersistentObject *arg2 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  void *argp2 = 0 ;
  int res2 = 0 ;
  PyObject *swig_obj[2] ;
  
  if (!SWIG_Python_UnpackTuple(args, "ContainerNode_writeObject", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__ContainerNode, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "ContainerNode_writeObject" "', argument " "1"" of type '" "pj::ContainerNode *""'"); 
  }
  arg1 = reinterpret_cast< pj::ContainerNode * >(argp1);
  res2 = SWIG_ConvertPtr(swig_obj[1], &argp2, SWIGTYPE_p_pj__PersistentObject,  0  | 0);
  if (!SWIG_IsOK(res2)) {
    SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "ContainerNode_writeObject" "', argument " "2"" of type '" "pj::PersistentObject const &""'"); 
  }
  if (!argp2) {
    SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "ContainerNode_writeObject" "', argument " "2"" of type '" "pj::PersistentObject const &""'"); 
  }
  arg2 = reinterpret_cast< pj::PersistentObject * >(argp2);
  try {
    (arg1)->writeObject((pj::PersistentObject const &)*arg2);
  } catch(pj::Error &_e) {
    SWIG_Python_Raise(SWIG_NewPointerObj((new pj::Error(static_cast< const pj::Error& >(_e))),SWIGTYPE_p_pj__Error,SWIG_POINTER_OWN), "pj::Error", SWIGTYPE_p_pj__Error); SWIG_fail;
  }
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_ContainerNode_writeNewContainer(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::ContainerNode *arg1 = (pj::ContainerNode *) 0 ;
  pj::string *arg2 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  int res2 = SWIG_OLDOBJ ;
  PyObject *swig_obj[2] ;
  pj::ContainerNode result;
  
  if (!SWIG_Python_UnpackTuple(args, "ContainerNode_writeNewContainer", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__ContainerNode, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "ContainerNode_writeNewContainer" "', argument " "1"" of type '" "pj::ContainerNode *""'"); 
  }
  arg1 = reinterpret_cast< pj::ContainerNode * >(argp1);
  {
    std::string *ptr = (std::string *)0;
    res2 = SWIG_AsPtr_std_string(swig_obj[1], &ptr);
    if (!SWIG_IsOK(res2)) {
      SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "ContainerNode_writeNewContainer" "', argument " "2"" of type '" "pj::string const &""'"); 
    }
    if (!ptr) {
      SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "ContainerNode_writeNewContainer" "', argument " "2"" of type '" "pj::string const &""'"); 
    }
    arg2 = ptr;
  }
  try {
    result = (arg1)->writeNewContainer((pj::string const &)*arg2);
  } catch(pj::Error &_e) {
    SWIG_Python_Raise(SWIG_NewPointerObj((new pj::Error(static_cast< const pj::Error& >(_e))),SWIGTYPE_p_pj__Error,SWIG_POINTER_OWN), "pj::Error", SWIGTYPE_p_pj__Error); SWIG_fail;
  }
  resultobj = SWIG_NewPointerObj((new pj::ContainerNode(static_cast< const pj::ContainerNode& >(result))), SWIGTYPE_p_pj__ContainerNode, SWIG_POINTER_OWN |  0 );
  if (SWIG_IsNewObj(res2)) delete arg2;
  return resultobj;
fail:
  if (SWIG_IsNewObj(res2)) delete arg2;
  return NULL;
}


SWIGINTERN PyObject *_wrap_ContainerNode_writeNewArray(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::ContainerNode *arg1 = (pj::ContainerNode *) 0 ;
  pj::string *arg2 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  int res2 = SWIG_OLDOBJ ;
  PyObject *swig_obj[2] ;
  pj::ContainerNode result;
  
  if (!SWIG_Python_UnpackTuple(args, "ContainerNode_writeNewArray", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__ContainerNode, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "ContainerNode_writeNewArray" "', argument " "1"" of type '" "pj::ContainerNode *""'"); 
  }
  arg1 = reinterpret_cast< pj::ContainerNode * >(argp1);
  {
    std::string *ptr = (std::string *)0;
    res2 = SWIG_AsPtr_std_string(swig_obj[1], &ptr);
    if (!SWIG_IsOK(res2)) {
      SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "ContainerNode_writeNewArray" "', argument " "2"" of type '" "pj::string const &""'"); 
    }
    if (!ptr) {
      SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "ContainerNode_writeNewArray" "', argument " "2"" of type '" "pj::string const &""'"); 
    }
    arg2 = ptr;
  }
  try {
    result = (arg1)->writeNewArray((pj::string const &)*arg2);
  } catch(pj::Error &_e) {
    SWIG_Python_Raise(SWIG_NewPointerObj((new pj::Error(static_cast< const pj::Error& >(_e))),SWIGTYPE_p_pj__Error,SWIG_POINTER_OWN), "pj::Error", SWIGTYPE_p_pj__Error); SWIG_fail;
  }
  resultobj = SWIG_NewPointerObj((new pj::ContainerNode(static_cast< const pj::ContainerNode& >(result))), SWIGTYPE_p_pj__ContainerNode, SWIG_POINTER_OWN |  0 );
  if (SWIG_IsNewObj(res2)) delete arg2;
  return resultobj;
fail:
  if (SWIG_IsNewObj(res2)) delete arg2;
  return NULL;
}


SWIGINTERN PyObject *_wrap_new_ContainerNode(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::ContainerNode *result = 0 ;
  
  if (!SWIG_Python_UnpackTuple(args, "new_ContainerNode", 0, 0, 0)) SWIG_fail;
  result = (pj::ContainerNode *)new pj::ContainerNode();
  resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(result), SWIGTYPE_p_pj__ContainerNode, SWIG_POINTER_NEW |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_delete_ContainerNode(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::ContainerNode *arg1 = (pj::ContainerNode *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__ContainerNode, SWIG_POINTER_DISOWN |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "delete_ContainerNode" "', argument " "1"" of type '" "pj::ContainerNode *""'"); 
  }
  arg1 = reinterpret_cast< pj::ContainerNode * >(argp1);
  delete arg1;
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *ContainerNode_swigregister(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *obj;
  if (!SWIG_Python_UnpackTuple(args, "swigregister", 1, 1, &obj)) return NULL;
  SWIG_TypeNewClientData(SWIGTYPE_p_pj__ContainerNode, SWIG_NewClientData(obj));
  return SWIG_Py_Void();
}

SWIGINTERN PyObject *ContainerNode_swiginit(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  return SWIG_Python_InitShadowInstance(args);
}

SWIGINTERN PyObject *_wrap_AuthCredInfo_scheme_set(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::AuthCredInfo *arg1 = (pj::AuthCredInfo *) 0 ;
  pj::string *arg2 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  int res2 = SWIG_OLDOBJ ;
  PyObject *swig_obj[2] ;
  
  if (!SWIG_Python_UnpackTuple(args, "AuthCredInfo_scheme_set", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__AuthCredInfo, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "AuthCredInfo_scheme_set" "', argument " "1"" of type '" "pj::AuthCredInfo *""'"); 
  }
  arg1 = reinterpret_cast< pj::AuthCredInfo * >(argp1);
  {
    std::string *ptr = (std::string *)0;
    res2 = SWIG_AsPtr_std_string(swig_obj[1], &ptr);
    if (!SWIG_IsOK(res2)) {
      SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "AuthCredInfo_scheme_set" "', argument " "2"" of type '" "pj::string const &""'"); 
    }
    if (!ptr) {
      SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "AuthCredInfo_scheme_set" "', argument " "2"" of type '" "pj::string const &""'"); 
    }
    arg2 = ptr;
  }
  if (arg1) (arg1)->scheme = *arg2;
  resultobj = SWIG_Py_Void();
  if (SWIG_IsNewObj(res2)) delete arg2;
  return resultobj;
fail:
  if (SWIG_IsNewObj(res2)) delete arg2;
  return NULL;
}


SWIGINTERN PyObject *_wrap_AuthCredInfo_scheme_get(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::AuthCredInfo *arg1 = (pj::AuthCredInfo *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  pj::string *result = 0 ;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__AuthCredInfo, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "AuthCredInfo_scheme_get" "', argument " "1"" of type '" "pj::AuthCredInfo *""'"); 
  }
  arg1 = reinterpret_cast< pj::AuthCredInfo * >(argp1);
  result = (pj::string *) & ((arg1)->scheme);
  resultobj = SWIG_From_std_string(static_cast< std::string >(*result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_AuthCredInfo_realm_set(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::AuthCredInfo *arg1 = (pj::AuthCredInfo *) 0 ;
  pj::string *arg2 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  int res2 = SWIG_OLDOBJ ;
  PyObject *swig_obj[2] ;
  
  if (!SWIG_Python_UnpackTuple(args, "AuthCredInfo_realm_set", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__AuthCredInfo, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "AuthCredInfo_realm_set" "', argument " "1"" of type '" "pj::AuthCredInfo *""'"); 
  }
  arg1 = reinterpret_cast< pj::AuthCredInfo * >(argp1);
  {
    std::string *ptr = (std::string *)0;
    res2 = SWIG_AsPtr_std_string(swig_obj[1], &ptr);
    if (!SWIG_IsOK(res2)) {
      SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "AuthCredInfo_realm_set" "', argument " "2"" of type '" "pj::string const &""'"); 
    }
    if (!ptr) {
      SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "AuthCredInfo_realm_set" "', argument " "2"" of type '" "pj::string const &""'"); 
    }
    arg2 = ptr;
  }
  if (arg1) (arg1)->realm = *arg2;
  resultobj = SWIG_Py_Void();
  if (SWIG_IsNewObj(res2)) delete arg2;
  return resultobj;
fail:
  if (SWIG_IsNewObj(res2)) delete arg2;
  return NULL;
}


SWIGINTERN PyObject *_wrap_AuthCredInfo_realm_get(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::AuthCredInfo *arg1 = (pj::AuthCredInfo *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  pj::string *result = 0 ;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__AuthCredInfo, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "AuthCredInfo_realm_get" "', argument " "1"" of type '" "pj::AuthCredInfo *""'"); 
  }
  arg1 = reinterpret_cast< pj::AuthCredInfo * >(argp1);
  result = (pj::string *) & ((arg1)->realm);
  resultobj = SWIG_From_std_string(static_cast< std::string >(*result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_AuthCredInfo_username_set(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::AuthCredInfo *arg1 = (pj::AuthCredInfo *) 0 ;
  pj::string *arg2 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  int res2 = SWIG_OLDOBJ ;
  PyObject *swig_obj[2] ;
  
  if (!SWIG_Python_UnpackTuple(args, "AuthCredInfo_username_set", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__AuthCredInfo, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "AuthCredInfo_username_set" "', argument " "1"" of type '" "pj::AuthCredInfo *""'"); 
  }
  arg1 = reinterpret_cast< pj::AuthCredInfo * >(argp1);
  {
    std::string *ptr = (std::string *)0;
    res2 = SWIG_AsPtr_std_string(swig_obj[1], &ptr);
    if (!SWIG_IsOK(res2)) {
      SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "AuthCredInfo_username_set" "', argument " "2"" of type '" "pj::string const &""'"); 
    }
    if (!ptr) {
      SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "AuthCredInfo_username_set" "', argument " "2"" of type '" "pj::string const &""'"); 
    }
    arg2 = ptr;
  }
  if (arg1) (arg1)->username = *arg2;
  resultobj = SWIG_Py_Void();
  if (SWIG_IsNewObj(res2)) delete arg2;
  return resultobj;
fail:
  if (SWIG_IsNewObj(res2)) delete arg2;
  return NULL;
}


SWIGINTERN PyObject *_wrap_AuthCredInfo_username_get(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::AuthCredInfo *arg1 = (pj::AuthCredInfo *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  pj::string *result = 0 ;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__AuthCredInfo, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "AuthCredInfo_username_get" "', argument " "1"" of type '" "pj::AuthCredInfo *""'"); 
  }
  arg1 = reinterpret_cast< pj::AuthCredInfo * >(argp1);
  result = (pj::string *) & ((arg1)->username);
  resultobj = SWIG_From_std_string(static_cast< std::string >(*result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_AuthCredInfo_dataType_set(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::AuthCredInfo *arg1 = (pj::AuthCredInfo *) 0 ;
  int arg2 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  int val2 ;
  int ecode2 = 0 ;
  PyObject *swig_obj[2] ;
  
  if (!SWIG_Python_UnpackTuple(args, "AuthCredInfo_dataType_set", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__AuthCredInfo, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "AuthCredInfo_dataType_set" "', argument " "1"" of type '" "pj::AuthCredInfo *""'"); 
  }
  arg1 = reinterpret_cast< pj::AuthCredInfo * >(argp1);
  ecode2 = SWIG_AsVal_int(swig_obj[1], &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "AuthCredInfo_dataType_set" "', argument " "2"" of type '" "int""'");
  } 
  arg2 = static_cast< int >(val2);
  if (arg1) (arg1)->dataType = arg2;
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_AuthCredInfo_dataType_get(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::AuthCredInfo *arg1 = (pj::AuthCredInfo *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  int result;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__AuthCredInfo, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "AuthCredInfo_dataType_get" "', argument " "1"" of type '" "pj::AuthCredInfo *""'"); 
  }
  arg1 = reinterpret_cast< pj::AuthCredInfo * >(argp1);
  result = (int) ((arg1)->dataType);
  resultobj = SWIG_From_int(static_cast< int >(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_AuthCredInfo_data_set(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::AuthCredInfo *arg1 = (pj::AuthCredInfo *) 0 ;
  pj::string *arg2 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  int res2 = SWIG_OLDOBJ ;
  PyObject *swig_obj[2] ;
  
  if (!SWIG_Python_UnpackTuple(args, "AuthCredInfo_data_set", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__AuthCredInfo, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "AuthCredInfo_data_set" "', argument " "1"" of type '" "pj::AuthCredInfo *""'"); 
  }
  arg1 = reinterpret_cast< pj::AuthCredInfo * >(argp1);
  {
    std::string *ptr = (std::string *)0;
    res2 = SWIG_AsPtr_std_string(swig_obj[1], &ptr);
    if (!SWIG_IsOK(res2)) {
      SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "AuthCredInfo_data_set" "', argument " "2"" of type '" "pj::string const &""'"); 
    }
    if (!ptr) {
      SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "AuthCredInfo_data_set" "', argument " "2"" of type '" "pj::string const &""'"); 
    }
    arg2 = ptr;
  }
  if (arg1) (arg1)->data = *arg2;
  resultobj = SWIG_Py_Void();
  if (SWIG_IsNewObj(res2)) delete arg2;
  return resultobj;
fail:
  if (SWIG_IsNewObj(res2)) delete arg2;
  return NULL;
}


SWIGINTERN PyObject *_wrap_AuthCredInfo_data_get(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::AuthCredInfo *arg1 = (pj::AuthCredInfo *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  pj::string *result = 0 ;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__AuthCredInfo, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "AuthCredInfo_data_get" "', argument " "1"" of type '" "pj::AuthCredInfo *""'"); 
  }
  arg1 = reinterpret_cast< pj::AuthCredInfo * >(argp1);
  result = (pj::string *) & ((arg1)->data);
  resultobj = SWIG_From_std_string(static_cast< std::string >(*result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_AuthCredInfo_akaK_set(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::AuthCredInfo *arg1 = (pj::AuthCredInfo *) 0 ;
  pj::string *arg2 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  int res2 = SWIG_OLDOBJ ;
  PyObject *swig_obj[2] ;
  
  if (!SWIG_Python_UnpackTuple(args, "AuthCredInfo_akaK_set", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__AuthCredInfo, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "AuthCredInfo_akaK_set" "', argument " "1"" of type '" "pj::AuthCredInfo *""'"); 
  }
  arg1 = reinterpret_cast< pj::AuthCredInfo * >(argp1);
  {
    std::string *ptr = (std::string *)0;
    res2 = SWIG_AsPtr_std_string(swig_obj[1], &ptr);
    if (!SWIG_IsOK(res2)) {
      SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "AuthCredInfo_akaK_set" "', argument " "2"" of type '" "pj::string const &""'"); 
    }
    if (!ptr) {
      SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "AuthCredInfo_akaK_set" "', argument " "2"" of type '" "pj::string const &""'"); 
    }
    arg2 = ptr;
  }
  if (arg1) (arg1)->akaK = *arg2;
  resultobj = SWIG_Py_Void();
  if (SWIG_IsNewObj(res2)) delete arg2;
  return resultobj;
fail:
  if (SWIG_IsNewObj(res2)) delete arg2;
  return NULL;
}


SWIGINTERN PyObject *_wrap_AuthCredInfo_akaK_get(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::AuthCredInfo *arg1 = (pj::AuthCredInfo *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  pj::string *result = 0 ;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__AuthCredInfo, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "AuthCredInfo_akaK_get" "', argument " "1"" of type '" "pj::AuthCredInfo *""'"); 
  }
  arg1 = reinterpret_cast< pj::AuthCredInfo * >(argp1);
  result = (pj::string *) & ((arg1)->akaK);
  resultobj = SWIG_From_std_string(static_cast< std::string >(*result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_AuthCredInfo_akaOp_set(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::AuthCredInfo *arg1 = (pj::AuthCredInfo *) 0 ;
  pj::string *arg2 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  int res2 = SWIG_OLDOBJ ;
  PyObject *swig_obj[2] ;
  
  if (!SWIG_Python_UnpackTuple(args, "AuthCredInfo_akaOp_set", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__AuthCredInfo, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "AuthCredInfo_akaOp_set" "', argument " "1"" of type '" "pj::AuthCredInfo *""'"); 
  }
  arg1 = reinterpret_cast< pj::AuthCredInfo * >(argp1);
  {
    std::string *ptr = (std::string *)0;
    res2 = SWIG_AsPtr_std_string(swig_obj[1], &ptr);
    if (!SWIG_IsOK(res2)) {
      SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "AuthCredInfo_akaOp_set" "', argument " "2"" of type '" "pj::string const &""'"); 
    }
    if (!ptr) {
      SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "AuthCredInfo_akaOp_set" "', argument " "2"" of type '" "pj::string const &""'"); 
    }
    arg2 = ptr;
  }
  if (arg1) (arg1)->akaOp = *arg2;
  resultobj = SWIG_Py_Void();
  if (SWIG_IsNewObj(res2)) delete arg2;
  return resultobj;
fail:
  if (SWIG_IsNewObj(res2)) delete arg2;
  return NULL;
}


SWIGINTERN PyObject *_wrap_AuthCredInfo_akaOp_get(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::AuthCredInfo *arg1 = (pj::AuthCredInfo *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  pj::string *result = 0 ;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__AuthCredInfo, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "AuthCredInfo_akaOp_get" "', argument " "1"" of type '" "pj::AuthCredInfo *""'"); 
  }
  arg1 = reinterpret_cast< pj::AuthCredInfo * >(argp1);
  result = (pj::string *) & ((arg1)->akaOp);
  resultobj = SWIG_From_std_string(static_cast< std::string >(*result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_AuthCredInfo_akaAmf_set(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::AuthCredInfo *arg1 = (pj::AuthCredInfo *) 0 ;
  pj::string *arg2 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  int res2 = SWIG_OLDOBJ ;
  PyObject *swig_obj[2] ;
  
  if (!SWIG_Python_UnpackTuple(args, "AuthCredInfo_akaAmf_set", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__AuthCredInfo, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "AuthCredInfo_akaAmf_set" "', argument " "1"" of type '" "pj::AuthCredInfo *""'"); 
  }
  arg1 = reinterpret_cast< pj::AuthCredInfo * >(argp1);
  {
    std::string *ptr = (std::string *)0;
    res2 = SWIG_AsPtr_std_string(swig_obj[1], &ptr);
    if (!SWIG_IsOK(res2)) {
      SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "AuthCredInfo_akaAmf_set" "', argument " "2"" of type '" "pj::string const &""'"); 
    }
    if (!ptr) {
      SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "AuthCredInfo_akaAmf_set" "', argument " "2"" of type '" "pj::string const &""'"); 
    }
    arg2 = ptr;
  }
  if (arg1) (arg1)->akaAmf = *arg2;
  resultobj = SWIG_Py_Void();
  if (SWIG_IsNewObj(res2)) delete arg2;
  return resultobj;
fail:
  if (SWIG_IsNewObj(res2)) delete arg2;
  return NULL;
}


SWIGINTERN PyObject *_wrap_AuthCredInfo_akaAmf_get(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::AuthCredInfo *arg1 = (pj::AuthCredInfo *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  pj::string *result = 0 ;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__AuthCredInfo, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "AuthCredInfo_akaAmf_get" "', argument " "1"" of type '" "pj::AuthCredInfo *""'"); 
  }
  arg1 = reinterpret_cast< pj::AuthCredInfo * >(argp1);
  result = (pj::string *) & ((arg1)->akaAmf);
  resultobj = SWIG_From_std_string(static_cast< std::string >(*result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_new_AuthCredInfo__SWIG_0(PyObject *SWIGUNUSEDPARM(self), Py_ssize_t nobjs, PyObject **SWIGUNUSEDPARM(swig_obj)) {
  PyObject *resultobj = 0;
  pj::AuthCredInfo *result = 0 ;
  
  if ((nobjs < 0) || (nobjs > 0)) SWIG_fail;
  result = (pj::AuthCredInfo *)new pj::AuthCredInfo();
  resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(result), SWIGTYPE_p_pj__AuthCredInfo, SWIG_POINTER_NEW |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_new_AuthCredInfo__SWIG_1(PyObject *SWIGUNUSEDPARM(self), Py_ssize_t nobjs, PyObject **swig_obj) {
  PyObject *resultobj = 0;
  pj::string *arg1 = 0 ;
  pj::string *arg2 = 0 ;
  pj::string *arg3 = 0 ;
  int arg4 ;
  pj::string arg5 ;
  int res1 = SWIG_OLDOBJ ;
  int res2 = SWIG_OLDOBJ ;
  int res3 = SWIG_OLDOBJ ;
  int val4 ;
  int ecode4 = 0 ;
  pj::AuthCredInfo *result = 0 ;
  
  if ((nobjs < 5) || (nobjs > 5)) SWIG_fail;
  {
    std::string *ptr = (std::string *)0;
    res1 = SWIG_AsPtr_std_string(swig_obj[0], &ptr);
    if (!SWIG_IsOK(res1)) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "new_AuthCredInfo" "', argument " "1"" of type '" "pj::string const &""'"); 
    }
    if (!ptr) {
      SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "new_AuthCredInfo" "', argument " "1"" of type '" "pj::string const &""'"); 
    }
    arg1 = ptr;
  }
  {
    std::string *ptr = (std::string *)0;
    res2 = SWIG_AsPtr_std_string(swig_obj[1], &ptr);
    if (!SWIG_IsOK(res2)) {
      SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "new_AuthCredInfo" "', argument " "2"" of type '" "pj::string const &""'"); 
    }
    if (!ptr) {
      SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "new_AuthCredInfo" "', argument " "2"" of type '" "pj::string const &""'"); 
    }
    arg2 = ptr;
  }
  {
    std::string *ptr = (std::string *)0;
    res3 = SWIG_AsPtr_std_string(swig_obj[2], &ptr);
    if (!SWIG_IsOK(res3)) {
      SWIG_exception_fail(SWIG_ArgError(res3), "in method '" "new_AuthCredInfo" "', argument " "3"" of type '" "pj::string const &""'"); 
    }
    if (!ptr) {
      SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "new_AuthCredInfo" "', argument " "3"" of type '" "pj::string const &""'"); 
    }
    arg3 = ptr;
  }
  ecode4 = SWIG_AsVal_int(swig_obj[3], &val4);
  if (!SWIG_IsOK(ecode4)) {
    SWIG_exception_fail(SWIG_ArgError(ecode4), "in method '" "new_AuthCredInfo" "', argument " "4"" of type '" "int""'");
  } 
  arg4 = static_cast< int >(val4);
  {
    std::string *ptr = (std::string *)0;
    int res = SWIG_AsPtr_std_string(swig_obj[4], &ptr);
    if (!SWIG_IsOK(res) || !ptr) {
      SWIG_exception_fail(SWIG_ArgError((ptr ? res : SWIG_TypeError)), "in method '" "new_AuthCredInfo" "', argument " "5"" of type '" "pj::string const""'"); 
    }
    arg5 = *ptr;
    if (SWIG_IsNewObj(res)) delete ptr;
  }
  result = (pj::AuthCredInfo *)new pj::AuthCredInfo((pj::string const &)*arg1,(pj::string const &)*arg2,(pj::string const &)*arg3,arg4,arg5);
  resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(result), SWIGTYPE_p_pj__AuthCredInfo, SWIG_POINTER_NEW |  0 );
  if (SWIG_IsNewObj(res1)) delete arg1;
  if (SWIG_IsNewObj(res2)) delete arg2;
  if (SWIG_IsNewObj(res3)) delete arg3;
  return resultobj;
fail:
  if (SWIG_IsNewObj(res1)) delete arg1;
  if (SWIG_IsNewObj(res2)) delete arg2;
  if (SWIG_IsNewObj(res3)) delete arg3;
  return NULL;
}


SWIGINTERN PyObject *_wrap_new_AuthCredInfo(PyObject *self, PyObject *args) {
  Py_ssize_t argc;
  PyObject *argv[6] = {
    0
  };
  
  if (!(argc = SWIG_Python_UnpackTuple(args, "new_AuthCredInfo", 0, 5, argv))) SWIG_fail;
  --argc;
  if (argc == 0) {
    return _wrap_new_AuthCredInfo__SWIG_0(self, argc, argv);
  }
  if (argc == 5) {
    int _v;
    int res = SWIG_AsPtr_std_string(argv[0], (std::string**)(0));
    _v = SWIG_CheckState(res);
    if (_v) {
      int res = SWIG_AsPtr_std_string(argv[1], (std::string**)(0));
      _v = SWIG_CheckState(res);
      if (_v) {
        int res = SWIG_AsPtr_std_string(argv[2], (std::string**)(0));
        _v = SWIG_CheckState(res);
        if (_v) {
          {
            int res = SWIG_AsVal_int(argv[3], NULL);
            _v = SWIG_CheckState(res);
          }
          if (_v) {
            int res = SWIG_AsPtr_std_string(argv[4], (std::string**)(0));
            _v = SWIG_CheckState(res);
            if (_v) {
              return _wrap_new_AuthCredInfo__SWIG_1(self, argc, argv);
            }
          }
        }
      }
    }
  }
  
fail:
  SWIG_Python_RaiseOrModifyTypeError("Wrong number or type of arguments for overloaded function 'new_AuthCredInfo'.\n"
    "  Possible C/C++ prototypes are:\n"
    "    pj::AuthCredInfo::AuthCredInfo()\n"
    "    pj::AuthCredInfo::AuthCredInfo(pj::string const &,pj::string const &,pj::string const &,int const,pj::string const)\n");
  return 0;
}


SWIGINTERN PyObject *_wrap_AuthCredInfo_readObject(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::AuthCredInfo *arg1 = (pj::AuthCredInfo *) 0 ;
  pj::ContainerNode *arg2 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  void *argp2 = 0 ;
  int res2 = 0 ;
  PyObject *swig_obj[2] ;
  
  if (!SWIG_Python_UnpackTuple(args, "AuthCredInfo_readObject", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__AuthCredInfo, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "AuthCredInfo_readObject" "', argument " "1"" of type '" "pj::AuthCredInfo *""'"); 
  }
  arg1 = reinterpret_cast< pj::AuthCredInfo * >(argp1);
  res2 = SWIG_ConvertPtr(swig_obj[1], &argp2, SWIGTYPE_p_pj__ContainerNode,  0  | 0);
  if (!SWIG_IsOK(res2)) {
    SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "AuthCredInfo_readObject" "', argument " "2"" of type '" "pj::ContainerNode const &""'"); 
  }
  if (!argp2) {
    SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "AuthCredInfo_readObject" "', argument " "2"" of type '" "pj::ContainerNode const &""'"); 
  }
  arg2 = reinterpret_cast< pj::ContainerNode * >(argp2);
  try {
    (arg1)->readObject((pj::ContainerNode const &)*arg2);
  } catch(pj::Error &_e) {
    SWIG_Python_Raise(SWIG_NewPointerObj((new pj::Error(static_cast< const pj::Error& >(_e))),SWIGTYPE_p_pj__Error,SWIG_POINTER_OWN), "pj::Error", SWIGTYPE_p_pj__Error); SWIG_fail;
  }
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_AuthCredInfo_writeObject(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::AuthCredInfo *arg1 = (pj::AuthCredInfo *) 0 ;
  pj::ContainerNode *arg2 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  void *argp2 = 0 ;
  int res2 = 0 ;
  PyObject *swig_obj[2] ;
  
  if (!SWIG_Python_UnpackTuple(args, "AuthCredInfo_writeObject", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__AuthCredInfo, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "AuthCredInfo_writeObject" "', argument " "1"" of type '" "pj::AuthCredInfo const *""'"); 
  }
  arg1 = reinterpret_cast< pj::AuthCredInfo * >(argp1);
  res2 = SWIG_ConvertPtr(swig_obj[1], &argp2, SWIGTYPE_p_pj__ContainerNode,  0 );
  if (!SWIG_IsOK(res2)) {
    SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "AuthCredInfo_writeObject" "', argument " "2"" of type '" "pj::ContainerNode &""'"); 
  }
  if (!argp2) {
    SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "AuthCredInfo_writeObject" "', argument " "2"" of type '" "pj::ContainerNode &""'"); 
  }
  arg2 = reinterpret_cast< pj::ContainerNode * >(argp2);
  try {
    ((pj::AuthCredInfo const *)arg1)->writeObject(*arg2);
  } catch(pj::Error &_e) {
    SWIG_Python_Raise(SWIG_NewPointerObj((new pj::Error(static_cast< const pj::Error& >(_e))),SWIGTYPE_p_pj__Error,SWIG_POINTER_OWN), "pj::Error", SWIGTYPE_p_pj__Error); SWIG_fail;
  }
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_delete_AuthCredInfo(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::AuthCredInfo *arg1 = (pj::AuthCredInfo *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__AuthCredInfo, SWIG_POINTER_DISOWN |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "delete_AuthCredInfo" "', argument " "1"" of type '" "pj::AuthCredInfo *""'"); 
  }
  arg1 = reinterpret_cast< pj::AuthCredInfo * >(argp1);
  delete arg1;
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *AuthCredInfo_swigregister(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *obj;
  if (!SWIG_Python_UnpackTuple(args, "swigregister", 1, 1, &obj)) return NULL;
  SWIG_TypeNewClientData(SWIGTYPE_p_pj__AuthCredInfo, SWIG_NewClientData(obj));
  return SWIG_Py_Void();
}

SWIGINTERN PyObject *AuthCredInfo_swiginit(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  return SWIG_Python_InitShadowInstance(args);
}

SWIGINTERN PyObject *_wrap_TlsConfig_CaListFile_set(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::TlsConfig *arg1 = (pj::TlsConfig *) 0 ;
  pj::string *arg2 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  int res2 = SWIG_OLDOBJ ;
  PyObject *swig_obj[2] ;
  
  if (!SWIG_Python_UnpackTuple(args, "TlsConfig_CaListFile_set", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__TlsConfig, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "TlsConfig_CaListFile_set" "', argument " "1"" of type '" "pj::TlsConfig *""'"); 
  }
  arg1 = reinterpret_cast< pj::TlsConfig * >(argp1);
  {
    std::string *ptr = (std::string *)0;
    res2 = SWIG_AsPtr_std_string(swig_obj[1], &ptr);
    if (!SWIG_IsOK(res2)) {
      SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "TlsConfig_CaListFile_set" "', argument " "2"" of type '" "pj::string const &""'"); 
    }
    if (!ptr) {
      SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "TlsConfig_CaListFile_set" "', argument " "2"" of type '" "pj::string const &""'"); 
    }
    arg2 = ptr;
  }
  if (arg1) (arg1)->CaListFile = *arg2;
  resultobj = SWIG_Py_Void();
  if (SWIG_IsNewObj(res2)) delete arg2;
  return resultobj;
fail:
  if (SWIG_IsNewObj(res2)) delete arg2;
  return NULL;
}


SWIGINTERN PyObject *_wrap_TlsConfig_CaListFile_get(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::TlsConfig *arg1 = (pj::TlsConfig *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  pj::string *result = 0 ;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__TlsConfig, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "TlsConfig_CaListFile_get" "', argument " "1"" of type '" "pj::TlsConfig *""'"); 
  }
  arg1 = reinterpret_cast< pj::TlsConfig * >(argp1);
  result = (pj::string *) & ((arg1)->CaListFile);
  resultobj = SWIG_From_std_string(static_cast< std::string >(*result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_TlsConfig_certFile_set(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::TlsConfig *arg1 = (pj::TlsConfig *) 0 ;
  pj::string *arg2 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  int res2 = SWIG_OLDOBJ ;
  PyObject *swig_obj[2] ;
  
  if (!SWIG_Python_UnpackTuple(args, "TlsConfig_certFile_set", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__TlsConfig, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "TlsConfig_certFile_set" "', argument " "1"" of type '" "pj::TlsConfig *""'"); 
  }
  arg1 = reinterpret_cast< pj::TlsConfig * >(argp1);
  {
    std::string *ptr = (std::string *)0;
    res2 = SWIG_AsPtr_std_string(swig_obj[1], &ptr);
    if (!SWIG_IsOK(res2)) {
      SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "TlsConfig_certFile_set" "', argument " "2"" of type '" "pj::string const &""'"); 
    }
    if (!ptr) {
      SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "TlsConfig_certFile_set" "', argument " "2"" of type '" "pj::string const &""'"); 
    }
    arg2 = ptr;
  }
  if (arg1) (arg1)->certFile = *arg2;
  resultobj = SWIG_Py_Void();
  if (SWIG_IsNewObj(res2)) delete arg2;
  return resultobj;
fail:
  if (SWIG_IsNewObj(res2)) delete arg2;
  return NULL;
}


SWIGINTERN PyObject *_wrap_TlsConfig_certFile_get(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::TlsConfig *arg1 = (pj::TlsConfig *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  pj::string *result = 0 ;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__TlsConfig, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "TlsConfig_certFile_get" "', argument " "1"" of type '" "pj::TlsConfig *""'"); 
  }
  arg1 = reinterpret_cast< pj::TlsConfig * >(argp1);
  result = (pj::string *) & ((arg1)->certFile);
  resultobj = SWIG_From_std_string(static_cast< std::string >(*result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_TlsConfig_privKeyFile_set(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::TlsConfig *arg1 = (pj::TlsConfig *) 0 ;
  pj::string *arg2 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  int res2 = SWIG_OLDOBJ ;
  PyObject *swig_obj[2] ;
  
  if (!SWIG_Python_UnpackTuple(args, "TlsConfig_privKeyFile_set", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__TlsConfig, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "TlsConfig_privKeyFile_set" "', argument " "1"" of type '" "pj::TlsConfig *""'"); 
  }
  arg1 = reinterpret_cast< pj::TlsConfig * >(argp1);
  {
    std::string *ptr = (std::string *)0;
    res2 = SWIG_AsPtr_std_string(swig_obj[1], &ptr);
    if (!SWIG_IsOK(res2)) {
      SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "TlsConfig_privKeyFile_set" "', argument " "2"" of type '" "pj::string const &""'"); 
    }
    if (!ptr) {
      SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "TlsConfig_privKeyFile_set" "', argument " "2"" of type '" "pj::string const &""'"); 
    }
    arg2 = ptr;
  }
  if (arg1) (arg1)->privKeyFile = *arg2;
  resultobj = SWIG_Py_Void();
  if (SWIG_IsNewObj(res2)) delete arg2;
  return resultobj;
fail:
  if (SWIG_IsNewObj(res2)) delete arg2;
  return NULL;
}


SWIGINTERN PyObject *_wrap_TlsConfig_privKeyFile_get(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::TlsConfig *arg1 = (pj::TlsConfig *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  pj::string *result = 0 ;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__TlsConfig, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "TlsConfig_privKeyFile_get" "', argument " "1"" of type '" "pj::TlsConfig *""'"); 
  }
  arg1 = reinterpret_cast< pj::TlsConfig * >(argp1);
  result = (pj::string *) & ((arg1)->privKeyFile);
  resultobj = SWIG_From_std_string(static_cast< std::string >(*result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_TlsConfig_password_set(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::TlsConfig *arg1 = (pj::TlsConfig *) 0 ;
  pj::string *arg2 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  int res2 = SWIG_OLDOBJ ;
  PyObject *swig_obj[2] ;
  
  if (!SWIG_Python_UnpackTuple(args, "TlsConfig_password_set", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__TlsConfig, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "TlsConfig_password_set" "', argument " "1"" of type '" "pj::TlsConfig *""'"); 
  }
  arg1 = reinterpret_cast< pj::TlsConfig * >(argp1);
  {
    std::string *ptr = (std::string *)0;
    res2 = SWIG_AsPtr_std_string(swig_obj[1], &ptr);
    if (!SWIG_IsOK(res2)) {
      SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "TlsConfig_password_set" "', argument " "2"" of type '" "pj::string const &""'"); 
    }
    if (!ptr) {
      SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "TlsConfig_password_set" "', argument " "2"" of type '" "pj::string const &""'"); 
    }
    arg2 = ptr;
  }
  if (arg1) (arg1)->password = *arg2;
  resultobj = SWIG_Py_Void();
  if (SWIG_IsNewObj(res2)) delete arg2;
  return resultobj;
fail:
  if (SWIG_IsNewObj(res2)) delete arg2;
  return NULL;
}


SWIGINTERN PyObject *_wrap_TlsConfig_password_get(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::TlsConfig *arg1 = (pj::TlsConfig *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  pj::string *result = 0 ;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__TlsConfig, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "TlsConfig_password_get" "', argument " "1"" of type '" "pj::TlsConfig *""'"); 
  }
  arg1 = reinterpret_cast< pj::TlsConfig * >(argp1);
  result = (pj::string *) & ((arg1)->password);
  resultobj = SWIG_From_std_string(static_cast< std::string >(*result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_TlsConfig_CaBuf_set(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::TlsConfig *arg1 = (pj::TlsConfig *) 0 ;
  pj::string *arg2 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  int res2 = SWIG_OLDOBJ ;
  PyObject *swig_obj[2] ;
  
  if (!SWIG_Python_UnpackTuple(args, "TlsConfig_CaBuf_set", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__TlsConfig, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "TlsConfig_CaBuf_set" "', argument " "1"" of type '" "pj::TlsConfig *""'"); 
  }
  arg1 = reinterpret_cast< pj::TlsConfig * >(argp1);
  {
    std::string *ptr = (std::string *)0;
    res2 = SWIG_AsPtr_std_string(swig_obj[1], &ptr);
    if (!SWIG_IsOK(res2)) {
      SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "TlsConfig_CaBuf_set" "', argument " "2"" of type '" "pj::string const &""'"); 
    }
    if (!ptr) {
      SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "TlsConfig_CaBuf_set" "', argument " "2"" of type '" "pj::string const &""'"); 
    }
    arg2 = ptr;
  }
  if (arg1) (arg1)->CaBuf = *arg2;
  resultobj = SWIG_Py_Void();
  if (SWIG_IsNewObj(res2)) delete arg2;
  return resultobj;
fail:
  if (SWIG_IsNewObj(res2)) delete arg2;
  return NULL;
}


SWIGINTERN PyObject *_wrap_TlsConfig_CaBuf_get(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::TlsConfig *arg1 = (pj::TlsConfig *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  pj::string *result = 0 ;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__TlsConfig, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "TlsConfig_CaBuf_get" "', argument " "1"" of type '" "pj::TlsConfig *""'"); 
  }
  arg1 = reinterpret_cast< pj::TlsConfig * >(argp1);
  result = (pj::string *) & ((arg1)->CaBuf);
  resultobj = SWIG_From_std_string(static_cast< std::string >(*result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_TlsConfig_certBuf_set(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::TlsConfig *arg1 = (pj::TlsConfig *) 0 ;
  pj::string *arg2 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  int res2 = SWIG_OLDOBJ ;
  PyObject *swig_obj[2] ;
  
  if (!SWIG_Python_UnpackTuple(args, "TlsConfig_certBuf_set", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__TlsConfig, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "TlsConfig_certBuf_set" "', argument " "1"" of type '" "pj::TlsConfig *""'"); 
  }
  arg1 = reinterpret_cast< pj::TlsConfig * >(argp1);
  {
    std::string *ptr = (std::string *)0;
    res2 = SWIG_AsPtr_std_string(swig_obj[1], &ptr);
    if (!SWIG_IsOK(res2)) {
      SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "TlsConfig_certBuf_set" "', argument " "2"" of type '" "pj::string const &""'"); 
    }
    if (!ptr) {
      SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "TlsConfig_certBuf_set" "', argument " "2"" of type '" "pj::string const &""'"); 
    }
    arg2 = ptr;
  }
  if (arg1) (arg1)->certBuf = *arg2;
  resultobj = SWIG_Py_Void();
  if (SWIG_IsNewObj(res2)) delete arg2;
  return resultobj;
fail:
  if (SWIG_IsNewObj(res2)) delete arg2;
  return NULL;
}


SWIGINTERN PyObject *_wrap_TlsConfig_certBuf_get(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::TlsConfig *arg1 = (pj::TlsConfig *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  pj::string *result = 0 ;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__TlsConfig, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "TlsConfig_certBuf_get" "', argument " "1"" of type '" "pj::TlsConfig *""'"); 
  }
  arg1 = reinterpret_cast< pj::TlsConfig * >(argp1);
  result = (pj::string *) & ((arg1)->certBuf);
  resultobj = SWIG_From_std_string(static_cast< std::string >(*result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_TlsConfig_privKeyBuf_set(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::TlsConfig *arg1 = (pj::TlsConfig *) 0 ;
  pj::string *arg2 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  int res2 = SWIG_OLDOBJ ;
  PyObject *swig_obj[2] ;
  
  if (!SWIG_Python_UnpackTuple(args, "TlsConfig_privKeyBuf_set", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__TlsConfig, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "TlsConfig_privKeyBuf_set" "', argument " "1"" of type '" "pj::TlsConfig *""'"); 
  }
  arg1 = reinterpret_cast< pj::TlsConfig * >(argp1);
  {
    std::string *ptr = (std::string *)0;
    res2 = SWIG_AsPtr_std_string(swig_obj[1], &ptr);
    if (!SWIG_IsOK(res2)) {
      SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "TlsConfig_privKeyBuf_set" "', argument " "2"" of type '" "pj::string const &""'"); 
    }
    if (!ptr) {
      SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "TlsConfig_privKeyBuf_set" "', argument " "2"" of type '" "pj::string const &""'"); 
    }
    arg2 = ptr;
  }
  if (arg1) (arg1)->privKeyBuf = *arg2;
  resultobj = SWIG_Py_Void();
  if (SWIG_IsNewObj(res2)) delete arg2;
  return resultobj;
fail:
  if (SWIG_IsNewObj(res2)) delete arg2;
  return NULL;
}


SWIGINTERN PyObject *_wrap_TlsConfig_privKeyBuf_get(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::TlsConfig *arg1 = (pj::TlsConfig *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  pj::string *result = 0 ;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__TlsConfig, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "TlsConfig_privKeyBuf_get" "', argument " "1"" of type '" "pj::TlsConfig *""'"); 
  }
  arg1 = reinterpret_cast< pj::TlsConfig * >(argp1);
  result = (pj::string *) & ((arg1)->privKeyBuf);
  resultobj = SWIG_From_std_string(static_cast< std::string >(*result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_TlsConfig_method_set(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::TlsConfig *arg1 = (pj::TlsConfig *) 0 ;
  pjsip_ssl_method arg2 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  int val2 ;
  int ecode2 = 0 ;
  PyObject *swig_obj[2] ;
  
  if (!SWIG_Python_UnpackTuple(args, "TlsConfig_method_set", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__TlsConfig, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "TlsConfig_method_set" "', argument " "1"" of type '" "pj::TlsConfig *""'"); 
  }
  arg1 = reinterpret_cast< pj::TlsConfig * >(argp1);
  ecode2 = SWIG_AsVal_int(swig_obj[1], &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "TlsConfig_method_set" "', argument " "2"" of type '" "pjsip_ssl_method""'");
  } 
  arg2 = static_cast< pjsip_ssl_method >(val2);
  if (arg1) (arg1)->method = arg2;
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_TlsConfig_method_get(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::TlsConfig *arg1 = (pj::TlsConfig *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  pjsip_ssl_method result;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__TlsConfig, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "TlsConfig_method_get" "', argument " "1"" of type '" "pj::TlsConfig *""'"); 
  }
  arg1 = reinterpret_cast< pj::TlsConfig * >(argp1);
  result = (pjsip_ssl_method) ((arg1)->method);
  resultobj = SWIG_From_int(static_cast< int >(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_TlsConfig_proto_set(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::TlsConfig *arg1 = (pj::TlsConfig *) 0 ;
  unsigned int arg2 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  unsigned int val2 ;
  int ecode2 = 0 ;
  PyObject *swig_obj[2] ;
  
  if (!SWIG_Python_UnpackTuple(args, "TlsConfig_proto_set", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__TlsConfig, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "TlsConfig_proto_set" "', argument " "1"" of type '" "pj::TlsConfig *""'"); 
  }
  arg1 = reinterpret_cast< pj::TlsConfig * >(argp1);
  ecode2 = SWIG_AsVal_unsigned_SS_int(swig_obj[1], &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "TlsConfig_proto_set" "', argument " "2"" of type '" "unsigned int""'");
  } 
  arg2 = static_cast< unsigned int >(val2);
  if (arg1) (arg1)->proto = arg2;
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_TlsConfig_proto_get(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::TlsConfig *arg1 = (pj::TlsConfig *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  unsigned int result;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__TlsConfig, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "TlsConfig_proto_get" "', argument " "1"" of type '" "pj::TlsConfig *""'"); 
  }
  arg1 = reinterpret_cast< pj::TlsConfig * >(argp1);
  result = (unsigned int) ((arg1)->proto);
  resultobj = SWIG_From_unsigned_SS_int(static_cast< unsigned int >(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_TlsConfig_ciphers_set(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::TlsConfig *arg1 = (pj::TlsConfig *) 0 ;
  pj::IntVector *arg2 = (pj::IntVector *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  void *argp2 = 0 ;
  int res2 = 0 ;
  PyObject *swig_obj[2] ;
  
  if (!SWIG_Python_UnpackTuple(args, "TlsConfig_ciphers_set", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__TlsConfig, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "TlsConfig_ciphers_set" "', argument " "1"" of type '" "pj::TlsConfig *""'"); 
  }
  arg1 = reinterpret_cast< pj::TlsConfig * >(argp1);
  res2 = SWIG_ConvertPtr(swig_obj[1], &argp2,SWIGTYPE_p_std__vectorT_int_std__allocatorT_int_t_t, 0 |  0 );
  if (!SWIG_IsOK(res2)) {
    SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "TlsConfig_ciphers_set" "', argument " "2"" of type '" "pj::IntVector *""'"); 
  }
  arg2 = reinterpret_cast< pj::IntVector * >(argp2);
  if (arg1) (arg1)->ciphers = *arg2;
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_TlsConfig_ciphers_get(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::TlsConfig *arg1 = (pj::TlsConfig *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  pj::IntVector *result = 0 ;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__TlsConfig, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "TlsConfig_ciphers_get" "', argument " "1"" of type '" "pj::TlsConfig *""'"); 
  }
  arg1 = reinterpret_cast< pj::TlsConfig * >(argp1);
  result = (pj::IntVector *)& ((arg1)->ciphers);
  resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(result), SWIGTYPE_p_std__vectorT_int_std__allocatorT_int_t_t, 0 |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_TlsConfig_verifyServer_set(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::TlsConfig *arg1 = (pj::TlsConfig *) 0 ;
  bool arg2 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  bool val2 ;
  int ecode2 = 0 ;
  PyObject *swig_obj[2] ;
  
  if (!SWIG_Python_UnpackTuple(args, "TlsConfig_verifyServer_set", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__TlsConfig, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "TlsConfig_verifyServer_set" "', argument " "1"" of type '" "pj::TlsConfig *""'"); 
  }
  arg1 = reinterpret_cast< pj::TlsConfig * >(argp1);
  ecode2 = SWIG_AsVal_bool(swig_obj[1], &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "TlsConfig_verifyServer_set" "', argument " "2"" of type '" "bool""'");
  } 
  arg2 = static_cast< bool >(val2);
  if (arg1) (arg1)->verifyServer = arg2;
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_TlsConfig_verifyServer_get(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::TlsConfig *arg1 = (pj::TlsConfig *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  bool result;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__TlsConfig, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "TlsConfig_verifyServer_get" "', argument " "1"" of type '" "pj::TlsConfig *""'"); 
  }
  arg1 = reinterpret_cast< pj::TlsConfig * >(argp1);
  result = (bool) ((arg1)->verifyServer);
  resultobj = SWIG_From_bool(static_cast< bool >(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_TlsConfig_verifyClient_set(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::TlsConfig *arg1 = (pj::TlsConfig *) 0 ;
  bool arg2 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  bool val2 ;
  int ecode2 = 0 ;
  PyObject *swig_obj[2] ;
  
  if (!SWIG_Python_UnpackTuple(args, "TlsConfig_verifyClient_set", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__TlsConfig, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "TlsConfig_verifyClient_set" "', argument " "1"" of type '" "pj::TlsConfig *""'"); 
  }
  arg1 = reinterpret_cast< pj::TlsConfig * >(argp1);
  ecode2 = SWIG_AsVal_bool(swig_obj[1], &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "TlsConfig_verifyClient_set" "', argument " "2"" of type '" "bool""'");
  } 
  arg2 = static_cast< bool >(val2);
  if (arg1) (arg1)->verifyClient = arg2;
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_TlsConfig_verifyClient_get(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::TlsConfig *arg1 = (pj::TlsConfig *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  bool result;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__TlsConfig, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "TlsConfig_verifyClient_get" "', argument " "1"" of type '" "pj::TlsConfig *""'"); 
  }
  arg1 = reinterpret_cast< pj::TlsConfig * >(argp1);
  result = (bool) ((arg1)->verifyClient);
  resultobj = SWIG_From_bool(static_cast< bool >(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_TlsConfig_requireClientCert_set(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::TlsConfig *arg1 = (pj::TlsConfig *) 0 ;
  bool arg2 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  bool val2 ;
  int ecode2 = 0 ;
  PyObject *swig_obj[2] ;
  
  if (!SWIG_Python_UnpackTuple(args, "TlsConfig_requireClientCert_set", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__TlsConfig, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "TlsConfig_requireClientCert_set" "', argument " "1"" of type '" "pj::TlsConfig *""'"); 
  }
  arg1 = reinterpret_cast< pj::TlsConfig * >(argp1);
  ecode2 = SWIG_AsVal_bool(swig_obj[1], &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "TlsConfig_requireClientCert_set" "', argument " "2"" of type '" "bool""'");
  } 
  arg2 = static_cast< bool >(val2);
  if (arg1) (arg1)->requireClientCert = arg2;
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_TlsConfig_requireClientCert_get(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::TlsConfig *arg1 = (pj::TlsConfig *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  bool result;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__TlsConfig, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "TlsConfig_requireClientCert_get" "', argument " "1"" of type '" "pj::TlsConfig *""'"); 
  }
  arg1 = reinterpret_cast< pj::TlsConfig * >(argp1);
  result = (bool) ((arg1)->requireClientCert);
  resultobj = SWIG_From_bool(static_cast< bool >(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_TlsConfig_msecTimeout_set(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::TlsConfig *arg1 = (pj::TlsConfig *) 0 ;
  unsigned int arg2 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  unsigned int val2 ;
  int ecode2 = 0 ;
  PyObject *swig_obj[2] ;
  
  if (!SWIG_Python_UnpackTuple(args, "TlsConfig_msecTimeout_set", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__TlsConfig, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "TlsConfig_msecTimeout_set" "', argument " "1"" of type '" "pj::TlsConfig *""'"); 
  }
  arg1 = reinterpret_cast< pj::TlsConfig * >(argp1);
  ecode2 = SWIG_AsVal_unsigned_SS_int(swig_obj[1], &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "TlsConfig_msecTimeout_set" "', argument " "2"" of type '" "unsigned int""'");
  } 
  arg2 = static_cast< unsigned int >(val2);
  if (arg1) (arg1)->msecTimeout = arg2;
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_TlsConfig_msecTimeout_get(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::TlsConfig *arg1 = (pj::TlsConfig *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  unsigned int result;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__TlsConfig, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "TlsConfig_msecTimeout_get" "', argument " "1"" of type '" "pj::TlsConfig *""'"); 
  }
  arg1 = reinterpret_cast< pj::TlsConfig * >(argp1);
  result = (unsigned int) ((arg1)->msecTimeout);
  resultobj = SWIG_From_unsigned_SS_int(static_cast< unsigned int >(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_TlsConfig_qosType_set(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::TlsConfig *arg1 = (pj::TlsConfig *) 0 ;
  pj_qos_type arg2 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  int val2 ;
  int ecode2 = 0 ;
  PyObject *swig_obj[2] ;
  
  if (!SWIG_Python_UnpackTuple(args, "TlsConfig_qosType_set", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__TlsConfig, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "TlsConfig_qosType_set" "', argument " "1"" of type '" "pj::TlsConfig *""'"); 
  }
  arg1 = reinterpret_cast< pj::TlsConfig * >(argp1);
  ecode2 = SWIG_AsVal_int(swig_obj[1], &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "TlsConfig_qosType_set" "', argument " "2"" of type '" "pj_qos_type""'");
  } 
  arg2 = static_cast< pj_qos_type >(val2);
  if (arg1) (arg1)->qosType = arg2;
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_TlsConfig_qosType_get(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::TlsConfig *arg1 = (pj::TlsConfig *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  pj_qos_type result;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__TlsConfig, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "TlsConfig_qosType_get" "', argument " "1"" of type '" "pj::TlsConfig *""'"); 
  }
  arg1 = reinterpret_cast< pj::TlsConfig * >(argp1);
  result = (pj_qos_type) ((arg1)->qosType);
  resultobj = SWIG_From_int(static_cast< int >(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_TlsConfig_qosParams_set(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::TlsConfig *arg1 = (pj::TlsConfig *) 0 ;
  pj_qos_params *arg2 = (pj_qos_params *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  void *argp2 = 0 ;
  int res2 = 0 ;
  PyObject *swig_obj[2] ;
  
  if (!SWIG_Python_UnpackTuple(args, "TlsConfig_qosParams_set", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__TlsConfig, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "TlsConfig_qosParams_set" "', argument " "1"" of type '" "pj::TlsConfig *""'"); 
  }
  arg1 = reinterpret_cast< pj::TlsConfig * >(argp1);
  res2 = SWIG_ConvertPtr(swig_obj[1], &argp2,SWIGTYPE_p_pj_qos_params, 0 |  0 );
  if (!SWIG_IsOK(res2)) {
    SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "TlsConfig_qosParams_set" "', argument " "2"" of type '" "pj_qos_params *""'"); 
  }
  arg2 = reinterpret_cast< pj_qos_params * >(argp2);
  if (arg1) (arg1)->qosParams = *arg2;
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_TlsConfig_qosParams_get(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::TlsConfig *arg1 = (pj::TlsConfig *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  pj_qos_params *result = 0 ;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__TlsConfig, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "TlsConfig_qosParams_get" "', argument " "1"" of type '" "pj::TlsConfig *""'"); 
  }
  arg1 = reinterpret_cast< pj::TlsConfig * >(argp1);
  result = (pj_qos_params *)& ((arg1)->qosParams);
  resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(result), SWIGTYPE_p_pj_qos_params, 0 |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_TlsConfig_qosIgnoreError_set(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::TlsConfig *arg1 = (pj::TlsConfig *) 0 ;
  bool arg2 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  bool val2 ;
  int ecode2 = 0 ;
  PyObject *swig_obj[2] ;
  
  if (!SWIG_Python_UnpackTuple(args, "TlsConfig_qosIgnoreError_set", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__TlsConfig, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "TlsConfig_qosIgnoreError_set" "', argument " "1"" of type '" "pj::TlsConfig *""'"); 
  }
  arg1 = reinterpret_cast< pj::TlsConfig * >(argp1);
  ecode2 = SWIG_AsVal_bool(swig_obj[1], &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "TlsConfig_qosIgnoreError_set" "', argument " "2"" of type '" "bool""'");
  } 
  arg2 = static_cast< bool >(val2);
  if (arg1) (arg1)->qosIgnoreError = arg2;
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_TlsConfig_qosIgnoreError_get(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::TlsConfig *arg1 = (pj::TlsConfig *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  bool result;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__TlsConfig, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "TlsConfig_qosIgnoreError_get" "', argument " "1"" of type '" "pj::TlsConfig *""'"); 
  }
  arg1 = reinterpret_cast< pj::TlsConfig * >(argp1);
  result = (bool) ((arg1)->qosIgnoreError);
  resultobj = SWIG_From_bool(static_cast< bool >(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_new_TlsConfig(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::TlsConfig *result = 0 ;
  
  if (!SWIG_Python_UnpackTuple(args, "new_TlsConfig", 0, 0, 0)) SWIG_fail;
  result = (pj::TlsConfig *)new pj::TlsConfig();
  resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(result), SWIGTYPE_p_pj__TlsConfig, SWIG_POINTER_NEW |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_TlsConfig_readObject(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::TlsConfig *arg1 = (pj::TlsConfig *) 0 ;
  pj::ContainerNode *arg2 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  void *argp2 = 0 ;
  int res2 = 0 ;
  PyObject *swig_obj[2] ;
  
  if (!SWIG_Python_UnpackTuple(args, "TlsConfig_readObject", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__TlsConfig, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "TlsConfig_readObject" "', argument " "1"" of type '" "pj::TlsConfig *""'"); 
  }
  arg1 = reinterpret_cast< pj::TlsConfig * >(argp1);
  res2 = SWIG_ConvertPtr(swig_obj[1], &argp2, SWIGTYPE_p_pj__ContainerNode,  0  | 0);
  if (!SWIG_IsOK(res2)) {
    SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "TlsConfig_readObject" "', argument " "2"" of type '" "pj::ContainerNode const &""'"); 
  }
  if (!argp2) {
    SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "TlsConfig_readObject" "', argument " "2"" of type '" "pj::ContainerNode const &""'"); 
  }
  arg2 = reinterpret_cast< pj::ContainerNode * >(argp2);
  try {
    (arg1)->readObject((pj::ContainerNode const &)*arg2);
  } catch(pj::Error &_e) {
    SWIG_Python_Raise(SWIG_NewPointerObj((new pj::Error(static_cast< const pj::Error& >(_e))),SWIGTYPE_p_pj__Error,SWIG_POINTER_OWN), "pj::Error", SWIGTYPE_p_pj__Error); SWIG_fail;
  }
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_TlsConfig_writeObject(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::TlsConfig *arg1 = (pj::TlsConfig *) 0 ;
  pj::ContainerNode *arg2 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  void *argp2 = 0 ;
  int res2 = 0 ;
  PyObject *swig_obj[2] ;
  
  if (!SWIG_Python_UnpackTuple(args, "TlsConfig_writeObject", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__TlsConfig, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "TlsConfig_writeObject" "', argument " "1"" of type '" "pj::TlsConfig const *""'"); 
  }
  arg1 = reinterpret_cast< pj::TlsConfig * >(argp1);
  res2 = SWIG_ConvertPtr(swig_obj[1], &argp2, SWIGTYPE_p_pj__ContainerNode,  0 );
  if (!SWIG_IsOK(res2)) {
    SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "TlsConfig_writeObject" "', argument " "2"" of type '" "pj::ContainerNode &""'"); 
  }
  if (!argp2) {
    SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "TlsConfig_writeObject" "', argument " "2"" of type '" "pj::ContainerNode &""'"); 
  }
  arg2 = reinterpret_cast< pj::ContainerNode * >(argp2);
  try {
    ((pj::TlsConfig const *)arg1)->writeObject(*arg2);
  } catch(pj::Error &_e) {
    SWIG_Python_Raise(SWIG_NewPointerObj((new pj::Error(static_cast< const pj::Error& >(_e))),SWIGTYPE_p_pj__Error,SWIG_POINTER_OWN), "pj::Error", SWIGTYPE_p_pj__Error); SWIG_fail;
  }
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_delete_TlsConfig(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::TlsConfig *arg1 = (pj::TlsConfig *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__TlsConfig, SWIG_POINTER_DISOWN |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "delete_TlsConfig" "', argument " "1"" of type '" "pj::TlsConfig *""'"); 
  }
  arg1 = reinterpret_cast< pj::TlsConfig * >(argp1);
  delete arg1;
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *TlsConfig_swigregister(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *obj;
  if (!SWIG_Python_UnpackTuple(args, "swigregister", 1, 1, &obj)) return NULL;
  SWIG_TypeNewClientData(SWIGTYPE_p_pj__TlsConfig, SWIG_NewClientData(obj));
  return SWIG_Py_Void();
}

SWIGINTERN PyObject *TlsConfig_swiginit(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  return SWIG_Python_InitShadowInstance(args);
}

SWIGINTERN PyObject *_wrap_TransportConfig_port_set(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::TransportConfig *arg1 = (pj::TransportConfig *) 0 ;
  unsigned int arg2 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  unsigned int val2 ;
  int ecode2 = 0 ;
  PyObject *swig_obj[2] ;
  
  if (!SWIG_Python_UnpackTuple(args, "TransportConfig_port_set", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__TransportConfig, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "TransportConfig_port_set" "', argument " "1"" of type '" "pj::TransportConfig *""'"); 
  }
  arg1 = reinterpret_cast< pj::TransportConfig * >(argp1);
  ecode2 = SWIG_AsVal_unsigned_SS_int(swig_obj[1], &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "TransportConfig_port_set" "', argument " "2"" of type '" "unsigned int""'");
  } 
  arg2 = static_cast< unsigned int >(val2);
  if (arg1) (arg1)->port = arg2;
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_TransportConfig_port_get(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::TransportConfig *arg1 = (pj::TransportConfig *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  unsigned int result;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__TransportConfig, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "TransportConfig_port_get" "', argument " "1"" of type '" "pj::TransportConfig *""'"); 
  }
  arg1 = reinterpret_cast< pj::TransportConfig * >(argp1);
  result = (unsigned int) ((arg1)->port);
  resultobj = SWIG_From_unsigned_SS_int(static_cast< unsigned int >(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_TransportConfig_portRange_set(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::TransportConfig *arg1 = (pj::TransportConfig *) 0 ;
  unsigned int arg2 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  unsigned int val2 ;
  int ecode2 = 0 ;
  PyObject *swig_obj[2] ;
  
  if (!SWIG_Python_UnpackTuple(args, "TransportConfig_portRange_set", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__TransportConfig, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "TransportConfig_portRange_set" "', argument " "1"" of type '" "pj::TransportConfig *""'"); 
  }
  arg1 = reinterpret_cast< pj::TransportConfig * >(argp1);
  ecode2 = SWIG_AsVal_unsigned_SS_int(swig_obj[1], &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "TransportConfig_portRange_set" "', argument " "2"" of type '" "unsigned int""'");
  } 
  arg2 = static_cast< unsigned int >(val2);
  if (arg1) (arg1)->portRange = arg2;
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_TransportConfig_portRange_get(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::TransportConfig *arg1 = (pj::TransportConfig *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  unsigned int result;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__TransportConfig, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "TransportConfig_portRange_get" "', argument " "1"" of type '" "pj::TransportConfig *""'"); 
  }
  arg1 = reinterpret_cast< pj::TransportConfig * >(argp1);
  result = (unsigned int) ((arg1)->portRange);
  resultobj = SWIG_From_unsigned_SS_int(static_cast< unsigned int >(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_TransportConfig_publicAddress_set(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::TransportConfig *arg1 = (pj::TransportConfig *) 0 ;
  pj::string *arg2 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  int res2 = SWIG_OLDOBJ ;
  PyObject *swig_obj[2] ;
  
  if (!SWIG_Python_UnpackTuple(args, "TransportConfig_publicAddress_set", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__TransportConfig, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "TransportConfig_publicAddress_set" "', argument " "1"" of type '" "pj::TransportConfig *""'"); 
  }
  arg1 = reinterpret_cast< pj::TransportConfig * >(argp1);
  {
    std::string *ptr = (std::string *)0;
    res2 = SWIG_AsPtr_std_string(swig_obj[1], &ptr);
    if (!SWIG_IsOK(res2)) {
      SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "TransportConfig_publicAddress_set" "', argument " "2"" of type '" "pj::string const &""'"); 
    }
    if (!ptr) {
      SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "TransportConfig_publicAddress_set" "', argument " "2"" of type '" "pj::string const &""'"); 
    }
    arg2 = ptr;
  }
  if (arg1) (arg1)->publicAddress = *arg2;
  resultobj = SWIG_Py_Void();
  if (SWIG_IsNewObj(res2)) delete arg2;
  return resultobj;
fail:
  if (SWIG_IsNewObj(res2)) delete arg2;
  return NULL;
}


SWIGINTERN PyObject *_wrap_TransportConfig_publicAddress_get(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::TransportConfig *arg1 = (pj::TransportConfig *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  pj::string *result = 0 ;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__TransportConfig, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "TransportConfig_publicAddress_get" "', argument " "1"" of type '" "pj::TransportConfig *""'"); 
  }
  arg1 = reinterpret_cast< pj::TransportConfig * >(argp1);
  result = (pj::string *) & ((arg1)->publicAddress);
  resultobj = SWIG_From_std_string(static_cast< std::string >(*result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_TransportConfig_boundAddress_set(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::TransportConfig *arg1 = (pj::TransportConfig *) 0 ;
  pj::string *arg2 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  int res2 = SWIG_OLDOBJ ;
  PyObject *swig_obj[2] ;
  
  if (!SWIG_Python_UnpackTuple(args, "TransportConfig_boundAddress_set", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__TransportConfig, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "TransportConfig_boundAddress_set" "', argument " "1"" of type '" "pj::TransportConfig *""'"); 
  }
  arg1 = reinterpret_cast< pj::TransportConfig * >(argp1);
  {
    std::string *ptr = (std::string *)0;
    res2 = SWIG_AsPtr_std_string(swig_obj[1], &ptr);
    if (!SWIG_IsOK(res2)) {
      SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "TransportConfig_boundAddress_set" "', argument " "2"" of type '" "pj::string const &""'"); 
    }
    if (!ptr) {
      SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "TransportConfig_boundAddress_set" "', argument " "2"" of type '" "pj::string const &""'"); 
    }
    arg2 = ptr;
  }
  if (arg1) (arg1)->boundAddress = *arg2;
  resultobj = SWIG_Py_Void();
  if (SWIG_IsNewObj(res2)) delete arg2;
  return resultobj;
fail:
  if (SWIG_IsNewObj(res2)) delete arg2;
  return NULL;
}


SWIGINTERN PyObject *_wrap_TransportConfig_boundAddress_get(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::TransportConfig *arg1 = (pj::TransportConfig *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  pj::string *result = 0 ;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__TransportConfig, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "TransportConfig_boundAddress_get" "', argument " "1"" of type '" "pj::TransportConfig *""'"); 
  }
  arg1 = reinterpret_cast< pj::TransportConfig * >(argp1);
  result = (pj::string *) & ((arg1)->boundAddress);
  resultobj = SWIG_From_std_string(static_cast< std::string >(*result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_TransportConfig_tlsConfig_set(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::TransportConfig *arg1 = (pj::TransportConfig *) 0 ;
  pj::TlsConfig *arg2 = (pj::TlsConfig *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  void *argp2 = 0 ;
  int res2 = 0 ;
  PyObject *swig_obj[2] ;
  
  if (!SWIG_Python_UnpackTuple(args, "TransportConfig_tlsConfig_set", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__TransportConfig, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "TransportConfig_tlsConfig_set" "', argument " "1"" of type '" "pj::TransportConfig *""'"); 
  }
  arg1 = reinterpret_cast< pj::TransportConfig * >(argp1);
  res2 = SWIG_ConvertPtr(swig_obj[1], &argp2,SWIGTYPE_p_pj__TlsConfig, 0 |  0 );
  if (!SWIG_IsOK(res2)) {
    SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "TransportConfig_tlsConfig_set" "', argument " "2"" of type '" "pj::TlsConfig *""'"); 
  }
  arg2 = reinterpret_cast< pj::TlsConfig * >(argp2);
  if (arg1) (arg1)->tlsConfig = *arg2;
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_TransportConfig_tlsConfig_get(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::TransportConfig *arg1 = (pj::TransportConfig *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  pj::TlsConfig *result = 0 ;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__TransportConfig, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "TransportConfig_tlsConfig_get" "', argument " "1"" of type '" "pj::TransportConfig *""'"); 
  }
  arg1 = reinterpret_cast< pj::TransportConfig * >(argp1);
  result = (pj::TlsConfig *)& ((arg1)->tlsConfig);
  resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(result), SWIGTYPE_p_pj__TlsConfig, 0 |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_TransportConfig_qosType_set(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::TransportConfig *arg1 = (pj::TransportConfig *) 0 ;
  pj_qos_type arg2 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  int val2 ;
  int ecode2 = 0 ;
  PyObject *swig_obj[2] ;
  
  if (!SWIG_Python_UnpackTuple(args, "TransportConfig_qosType_set", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__TransportConfig, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "TransportConfig_qosType_set" "', argument " "1"" of type '" "pj::TransportConfig *""'"); 
  }
  arg1 = reinterpret_cast< pj::TransportConfig * >(argp1);
  ecode2 = SWIG_AsVal_int(swig_obj[1], &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "TransportConfig_qosType_set" "', argument " "2"" of type '" "pj_qos_type""'");
  } 
  arg2 = static_cast< pj_qos_type >(val2);
  if (arg1) (arg1)->qosType = arg2;
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_TransportConfig_qosType_get(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::TransportConfig *arg1 = (pj::TransportConfig *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  pj_qos_type result;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__TransportConfig, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "TransportConfig_qosType_get" "', argument " "1"" of type '" "pj::TransportConfig *""'"); 
  }
  arg1 = reinterpret_cast< pj::TransportConfig * >(argp1);
  result = (pj_qos_type) ((arg1)->qosType);
  resultobj = SWIG_From_int(static_cast< int >(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_TransportConfig_qosParams_set(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::TransportConfig *arg1 = (pj::TransportConfig *) 0 ;
  pj_qos_params *arg2 = (pj_qos_params *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  void *argp2 = 0 ;
  int res2 = 0 ;
  PyObject *swig_obj[2] ;
  
  if (!SWIG_Python_UnpackTuple(args, "TransportConfig_qosParams_set", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__TransportConfig, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "TransportConfig_qosParams_set" "', argument " "1"" of type '" "pj::TransportConfig *""'"); 
  }
  arg1 = reinterpret_cast< pj::TransportConfig * >(argp1);
  res2 = SWIG_ConvertPtr(swig_obj[1], &argp2,SWIGTYPE_p_pj_qos_params, 0 |  0 );
  if (!SWIG_IsOK(res2)) {
    SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "TransportConfig_qosParams_set" "', argument " "2"" of type '" "pj_qos_params *""'"); 
  }
  arg2 = reinterpret_cast< pj_qos_params * >(argp2);
  if (arg1) (arg1)->qosParams = *arg2;
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_TransportConfig_qosParams_get(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::TransportConfig *arg1 = (pj::TransportConfig *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  pj_qos_params *result = 0 ;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__TransportConfig, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "TransportConfig_qosParams_get" "', argument " "1"" of type '" "pj::TransportConfig *""'"); 
  }
  arg1 = reinterpret_cast< pj::TransportConfig * >(argp1);
  result = (pj_qos_params *)& ((arg1)->qosParams);
  resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(result), SWIGTYPE_p_pj_qos_params, 0 |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_new_TransportConfig(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::TransportConfig *result = 0 ;
  
  if (!SWIG_Python_UnpackTuple(args, "new_TransportConfig", 0, 0, 0)) SWIG_fail;
  result = (pj::TransportConfig *)new pj::TransportConfig();
  resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(result), SWIGTYPE_p_pj__TransportConfig, SWIG_POINTER_NEW |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_TransportConfig_readObject(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::TransportConfig *arg1 = (pj::TransportConfig *) 0 ;
  pj::ContainerNode *arg2 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  void *argp2 = 0 ;
  int res2 = 0 ;
  PyObject *swig_obj[2] ;
  
  if (!SWIG_Python_UnpackTuple(args, "TransportConfig_readObject", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__TransportConfig, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "TransportConfig_readObject" "', argument " "1"" of type '" "pj::TransportConfig *""'"); 
  }
  arg1 = reinterpret_cast< pj::TransportConfig * >(argp1);
  res2 = SWIG_ConvertPtr(swig_obj[1], &argp2, SWIGTYPE_p_pj__ContainerNode,  0  | 0);
  if (!SWIG_IsOK(res2)) {
    SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "TransportConfig_readObject" "', argument " "2"" of type '" "pj::ContainerNode const &""'"); 
  }
  if (!argp2) {
    SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "TransportConfig_readObject" "', argument " "2"" of type '" "pj::ContainerNode const &""'"); 
  }
  arg2 = reinterpret_cast< pj::ContainerNode * >(argp2);
  try {
    (arg1)->readObject((pj::ContainerNode const &)*arg2);
  } catch(pj::Error &_e) {
    SWIG_Python_Raise(SWIG_NewPointerObj((new pj::Error(static_cast< const pj::Error& >(_e))),SWIGTYPE_p_pj__Error,SWIG_POINTER_OWN), "pj::Error", SWIGTYPE_p_pj__Error); SWIG_fail;
  }
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_TransportConfig_writeObject(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::TransportConfig *arg1 = (pj::TransportConfig *) 0 ;
  pj::ContainerNode *arg2 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  void *argp2 = 0 ;
  int res2 = 0 ;
  PyObject *swig_obj[2] ;
  
  if (!SWIG_Python_UnpackTuple(args, "TransportConfig_writeObject", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__TransportConfig, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "TransportConfig_writeObject" "', argument " "1"" of type '" "pj::TransportConfig const *""'"); 
  }
  arg1 = reinterpret_cast< pj::TransportConfig * >(argp1);
  res2 = SWIG_ConvertPtr(swig_obj[1], &argp2, SWIGTYPE_p_pj__ContainerNode,  0 );
  if (!SWIG_IsOK(res2)) {
    SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "TransportConfig_writeObject" "', argument " "2"" of type '" "pj::ContainerNode &""'"); 
  }
  if (!argp2) {
    SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "TransportConfig_writeObject" "', argument " "2"" of type '" "pj::ContainerNode &""'"); 
  }
  arg2 = reinterpret_cast< pj::ContainerNode * >(argp2);
  try {
    ((pj::TransportConfig const *)arg1)->writeObject(*arg2);
  } catch(pj::Error &_e) {
    SWIG_Python_Raise(SWIG_NewPointerObj((new pj::Error(static_cast< const pj::Error& >(_e))),SWIGTYPE_p_pj__Error,SWIG_POINTER_OWN), "pj::Error", SWIGTYPE_p_pj__Error); SWIG_fail;
  }
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_delete_TransportConfig(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::TransportConfig *arg1 = (pj::TransportConfig *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__TransportConfig, SWIG_POINTER_DISOWN |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "delete_TransportConfig" "', argument " "1"" of type '" "pj::TransportConfig *""'"); 
  }
  arg1 = reinterpret_cast< pj::TransportConfig * >(argp1);
  delete arg1;
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *TransportConfig_swigregister(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *obj;
  if (!SWIG_Python_UnpackTuple(args, "swigregister", 1, 1, &obj)) return NULL;
  SWIG_TypeNewClientData(SWIGTYPE_p_pj__TransportConfig, SWIG_NewClientData(obj));
  return SWIG_Py_Void();
}

SWIGINTERN PyObject *TransportConfig_swiginit(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  return SWIG_Python_InitShadowInstance(args);
}

SWIGINTERN PyObject *_wrap_TransportInfo_id_set(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::TransportInfo *arg1 = (pj::TransportInfo *) 0 ;
  pj::TransportId arg2 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  int val2 ;
  int ecode2 = 0 ;
  PyObject *swig_obj[2] ;
  
  if (!SWIG_Python_UnpackTuple(args, "TransportInfo_id_set", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__TransportInfo, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "TransportInfo_id_set" "', argument " "1"" of type '" "pj::TransportInfo *""'"); 
  }
  arg1 = reinterpret_cast< pj::TransportInfo * >(argp1);
  ecode2 = SWIG_AsVal_int(swig_obj[1], &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "TransportInfo_id_set" "', argument " "2"" of type '" "pj::TransportId""'");
  } 
  arg2 = static_cast< pj::TransportId >(val2);
  if (arg1) (arg1)->id = arg2;
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_TransportInfo_id_get(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::TransportInfo *arg1 = (pj::TransportInfo *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  pj::TransportId result;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__TransportInfo, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "TransportInfo_id_get" "', argument " "1"" of type '" "pj::TransportInfo *""'"); 
  }
  arg1 = reinterpret_cast< pj::TransportInfo * >(argp1);
  result = (pj::TransportId) ((arg1)->id);
  resultobj = SWIG_From_int(static_cast< int >(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_TransportInfo_type_set(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::TransportInfo *arg1 = (pj::TransportInfo *) 0 ;
  pjsip_transport_type_e arg2 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  int val2 ;
  int ecode2 = 0 ;
  PyObject *swig_obj[2] ;
  
  if (!SWIG_Python_UnpackTuple(args, "TransportInfo_type_set", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__TransportInfo, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "TransportInfo_type_set" "', argument " "1"" of type '" "pj::TransportInfo *""'"); 
  }
  arg1 = reinterpret_cast< pj::TransportInfo * >(argp1);
  ecode2 = SWIG_AsVal_int(swig_obj[1], &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "TransportInfo_type_set" "', argument " "2"" of type '" "pjsip_transport_type_e""'");
  } 
  arg2 = static_cast< pjsip_transport_type_e >(val2);
  if (arg1) (arg1)->type = arg2;
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_TransportInfo_type_get(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::TransportInfo *arg1 = (pj::TransportInfo *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  pjsip_transport_type_e result;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__TransportInfo, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "TransportInfo_type_get" "', argument " "1"" of type '" "pj::TransportInfo *""'"); 
  }
  arg1 = reinterpret_cast< pj::TransportInfo * >(argp1);
  result = (pjsip_transport_type_e) ((arg1)->type);
  resultobj = SWIG_From_int(static_cast< int >(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_TransportInfo_typeName_set(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::TransportInfo *arg1 = (pj::TransportInfo *) 0 ;
  pj::string *arg2 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  int res2 = SWIG_OLDOBJ ;
  PyObject *swig_obj[2] ;
  
  if (!SWIG_Python_UnpackTuple(args, "TransportInfo_typeName_set", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__TransportInfo, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "TransportInfo_typeName_set" "', argument " "1"" of type '" "pj::TransportInfo *""'"); 
  }
  arg1 = reinterpret_cast< pj::TransportInfo * >(argp1);
  {
    std::string *ptr = (std::string *)0;
    res2 = SWIG_AsPtr_std_string(swig_obj[1], &ptr);
    if (!SWIG_IsOK(res2)) {
      SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "TransportInfo_typeName_set" "', argument " "2"" of type '" "pj::string const &""'"); 
    }
    if (!ptr) {
      SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "TransportInfo_typeName_set" "', argument " "2"" of type '" "pj::string const &""'"); 
    }
    arg2 = ptr;
  }
  if (arg1) (arg1)->typeName = *arg2;
  resultobj = SWIG_Py_Void();
  if (SWIG_IsNewObj(res2)) delete arg2;
  return resultobj;
fail:
  if (SWIG_IsNewObj(res2)) delete arg2;
  return NULL;
}


SWIGINTERN PyObject *_wrap_TransportInfo_typeName_get(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::TransportInfo *arg1 = (pj::TransportInfo *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  pj::string *result = 0 ;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__TransportInfo, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "TransportInfo_typeName_get" "', argument " "1"" of type '" "pj::TransportInfo *""'"); 
  }
  arg1 = reinterpret_cast< pj::TransportInfo * >(argp1);
  result = (pj::string *) & ((arg1)->typeName);
  resultobj = SWIG_From_std_string(static_cast< std::string >(*result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_TransportInfo_info_set(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::TransportInfo *arg1 = (pj::TransportInfo *) 0 ;
  pj::string *arg2 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  int res2 = SWIG_OLDOBJ ;
  PyObject *swig_obj[2] ;
  
  if (!SWIG_Python_UnpackTuple(args, "TransportInfo_info_set", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__TransportInfo, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "TransportInfo_info_set" "', argument " "1"" of type '" "pj::TransportInfo *""'"); 
  }
  arg1 = reinterpret_cast< pj::TransportInfo * >(argp1);
  {
    std::string *ptr = (std::string *)0;
    res2 = SWIG_AsPtr_std_string(swig_obj[1], &ptr);
    if (!SWIG_IsOK(res2)) {
      SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "TransportInfo_info_set" "', argument " "2"" of type '" "pj::string const &""'"); 
    }
    if (!ptr) {
      SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "TransportInfo_info_set" "', argument " "2"" of type '" "pj::string const &""'"); 
    }
    arg2 = ptr;
  }
  if (arg1) (arg1)->info = *arg2;
  resultobj = SWIG_Py_Void();
  if (SWIG_IsNewObj(res2)) delete arg2;
  return resultobj;
fail:
  if (SWIG_IsNewObj(res2)) delete arg2;
  return NULL;
}


SWIGINTERN PyObject *_wrap_TransportInfo_info_get(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::TransportInfo *arg1 = (pj::TransportInfo *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  pj::string *result = 0 ;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__TransportInfo, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "TransportInfo_info_get" "', argument " "1"" of type '" "pj::TransportInfo *""'"); 
  }
  arg1 = reinterpret_cast< pj::TransportInfo * >(argp1);
  result = (pj::string *) & ((arg1)->info);
  resultobj = SWIG_From_std_string(static_cast< std::string >(*result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_TransportInfo_flags_set(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::TransportInfo *arg1 = (pj::TransportInfo *) 0 ;
  unsigned int arg2 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  unsigned int val2 ;
  int ecode2 = 0 ;
  PyObject *swig_obj[2] ;
  
  if (!SWIG_Python_UnpackTuple(args, "TransportInfo_flags_set", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__TransportInfo, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "TransportInfo_flags_set" "', argument " "1"" of type '" "pj::TransportInfo *""'"); 
  }
  arg1 = reinterpret_cast< pj::TransportInfo * >(argp1);
  ecode2 = SWIG_AsVal_unsigned_SS_int(swig_obj[1], &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "TransportInfo_flags_set" "', argument " "2"" of type '" "unsigned int""'");
  } 
  arg2 = static_cast< unsigned int >(val2);
  if (arg1) (arg1)->flags = arg2;
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_TransportInfo_flags_get(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::TransportInfo *arg1 = (pj::TransportInfo *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  unsigned int result;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__TransportInfo, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "TransportInfo_flags_get" "', argument " "1"" of type '" "pj::TransportInfo *""'"); 
  }
  arg1 = reinterpret_cast< pj::TransportInfo * >(argp1);
  result = (unsigned int) ((arg1)->flags);
  resultobj = SWIG_From_unsigned_SS_int(static_cast< unsigned int >(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_TransportInfo_localAddress_set(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::TransportInfo *arg1 = (pj::TransportInfo *) 0 ;
  pj::SocketAddress *arg2 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  int res2 = SWIG_OLDOBJ ;
  PyObject *swig_obj[2] ;
  
  if (!SWIG_Python_UnpackTuple(args, "TransportInfo_localAddress_set", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__TransportInfo, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "TransportInfo_localAddress_set" "', argument " "1"" of type '" "pj::TransportInfo *""'"); 
  }
  arg1 = reinterpret_cast< pj::TransportInfo * >(argp1);
  {
    std::string *ptr = (std::string *)0;
    res2 = SWIG_AsPtr_std_string(swig_obj[1], &ptr);
    if (!SWIG_IsOK(res2)) {
      SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "TransportInfo_localAddress_set" "', argument " "2"" of type '" "pj::SocketAddress const &""'"); 
    }
    if (!ptr) {
      SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "TransportInfo_localAddress_set" "', argument " "2"" of type '" "pj::SocketAddress const &""'"); 
    }
    arg2 = ptr;
  }
  if (arg1) (arg1)->localAddress = *arg2;
  resultobj = SWIG_Py_Void();
  if (SWIG_IsNewObj(res2)) delete arg2;
  return resultobj;
fail:
  if (SWIG_IsNewObj(res2)) delete arg2;
  return NULL;
}


SWIGINTERN PyObject *_wrap_TransportInfo_localAddress_get(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::TransportInfo *arg1 = (pj::TransportInfo *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  pj::SocketAddress *result = 0 ;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__TransportInfo, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "TransportInfo_localAddress_get" "', argument " "1"" of type '" "pj::TransportInfo *""'"); 
  }
  arg1 = reinterpret_cast< pj::TransportInfo * >(argp1);
  result = (pj::SocketAddress *) & ((arg1)->localAddress);
  resultobj = SWIG_From_std_string(static_cast< std::string >(*result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_TransportInfo_localName_set(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::TransportInfo *arg1 = (pj::TransportInfo *) 0 ;
  pj::SocketAddress *arg2 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  int res2 = SWIG_OLDOBJ ;
  PyObject *swig_obj[2] ;
  
  if (!SWIG_Python_UnpackTuple(args, "TransportInfo_localName_set", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__TransportInfo, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "TransportInfo_localName_set" "', argument " "1"" of type '" "pj::TransportInfo *""'"); 
  }
  arg1 = reinterpret_cast< pj::TransportInfo * >(argp1);
  {
    std::string *ptr = (std::string *)0;
    res2 = SWIG_AsPtr_std_string(swig_obj[1], &ptr);
    if (!SWIG_IsOK(res2)) {
      SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "TransportInfo_localName_set" "', argument " "2"" of type '" "pj::SocketAddress const &""'"); 
    }
    if (!ptr) {
      SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "TransportInfo_localName_set" "', argument " "2"" of type '" "pj::SocketAddress const &""'"); 
    }
    arg2 = ptr;
  }
  if (arg1) (arg1)->localName = *arg2;
  resultobj = SWIG_Py_Void();
  if (SWIG_IsNewObj(res2)) delete arg2;
  return resultobj;
fail:
  if (SWIG_IsNewObj(res2)) delete arg2;
  return NULL;
}


SWIGINTERN PyObject *_wrap_TransportInfo_localName_get(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::TransportInfo *arg1 = (pj::TransportInfo *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  pj::SocketAddress *result = 0 ;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__TransportInfo, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "TransportInfo_localName_get" "', argument " "1"" of type '" "pj::TransportInfo *""'"); 
  }
  arg1 = reinterpret_cast< pj::TransportInfo * >(argp1);
  result = (pj::SocketAddress *) & ((arg1)->localName);
  resultobj = SWIG_From_std_string(static_cast< std::string >(*result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_TransportInfo_usageCount_set(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::TransportInfo *arg1 = (pj::TransportInfo *) 0 ;
  unsigned int arg2 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  unsigned int val2 ;
  int ecode2 = 0 ;
  PyObject *swig_obj[2] ;
  
  if (!SWIG_Python_UnpackTuple(args, "TransportInfo_usageCount_set", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__TransportInfo, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "TransportInfo_usageCount_set" "', argument " "1"" of type '" "pj::TransportInfo *""'"); 
  }
  arg1 = reinterpret_cast< pj::TransportInfo * >(argp1);
  ecode2 = SWIG_AsVal_unsigned_SS_int(swig_obj[1], &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "TransportInfo_usageCount_set" "', argument " "2"" of type '" "unsigned int""'");
  } 
  arg2 = static_cast< unsigned int >(val2);
  if (arg1) (arg1)->usageCount = arg2;
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_TransportInfo_usageCount_get(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::TransportInfo *arg1 = (pj::TransportInfo *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  unsigned int result;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__TransportInfo, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "TransportInfo_usageCount_get" "', argument " "1"" of type '" "pj::TransportInfo *""'"); 
  }
  arg1 = reinterpret_cast< pj::TransportInfo * >(argp1);
  result = (unsigned int) ((arg1)->usageCount);
  resultobj = SWIG_From_unsigned_SS_int(static_cast< unsigned int >(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_new_TransportInfo(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::TransportInfo *result = 0 ;
  
  if (!SWIG_Python_UnpackTuple(args, "new_TransportInfo", 0, 0, 0)) SWIG_fail;
  result = (pj::TransportInfo *)new pj::TransportInfo();
  resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(result), SWIGTYPE_p_pj__TransportInfo, SWIG_POINTER_NEW |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_delete_TransportInfo(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::TransportInfo *arg1 = (pj::TransportInfo *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__TransportInfo, SWIG_POINTER_DISOWN |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "delete_TransportInfo" "', argument " "1"" of type '" "pj::TransportInfo *""'"); 
  }
  arg1 = reinterpret_cast< pj::TransportInfo * >(argp1);
  delete arg1;
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *TransportInfo_swigregister(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *obj;
  if (!SWIG_Python_UnpackTuple(args, "swigregister", 1, 1, &obj)) return NULL;
  SWIG_TypeNewClientData(SWIGTYPE_p_pj__TransportInfo, SWIG_NewClientData(obj));
  return SWIG_Py_Void();
}

SWIGINTERN PyObject *TransportInfo_swiginit(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  return SWIG_Python_InitShadowInstance(args);
}

SWIGINTERN PyObject *_wrap_SipRxData_info_set(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::SipRxData *arg1 = (pj::SipRxData *) 0 ;
  pj::string *arg2 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  int res2 = SWIG_OLDOBJ ;
  PyObject *swig_obj[2] ;
  
  if (!SWIG_Python_UnpackTuple(args, "SipRxData_info_set", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__SipRxData, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "SipRxData_info_set" "', argument " "1"" of type '" "pj::SipRxData *""'"); 
  }
  arg1 = reinterpret_cast< pj::SipRxData * >(argp1);
  {
    std::string *ptr = (std::string *)0;
    res2 = SWIG_AsPtr_std_string(swig_obj[1], &ptr);
    if (!SWIG_IsOK(res2)) {
      SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "SipRxData_info_set" "', argument " "2"" of type '" "pj::string const &""'"); 
    }
    if (!ptr) {
      SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "SipRxData_info_set" "', argument " "2"" of type '" "pj::string const &""'"); 
    }
    arg2 = ptr;
  }
  if (arg1) (arg1)->info = *arg2;
  resultobj = SWIG_Py_Void();
  if (SWIG_IsNewObj(res2)) delete arg2;
  return resultobj;
fail:
  if (SWIG_IsNewObj(res2)) delete arg2;
  return NULL;
}


SWIGINTERN PyObject *_wrap_SipRxData_info_get(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::SipRxData *arg1 = (pj::SipRxData *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  pj::string *result = 0 ;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__SipRxData, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "SipRxData_info_get" "', argument " "1"" of type '" "pj::SipRxData *""'"); 
  }
  arg1 = reinterpret_cast< pj::SipRxData * >(argp1);
  result = (pj::string *) & ((arg1)->info);
  resultobj = SWIG_From_std_string(static_cast< std::string >(*result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_SipRxData_wholeMsg_set(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::SipRxData *arg1 = (pj::SipRxData *) 0 ;
  pj::string *arg2 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  int res2 = SWIG_OLDOBJ ;
  PyObject *swig_obj[2] ;
  
  if (!SWIG_Python_UnpackTuple(args, "SipRxData_wholeMsg_set", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__SipRxData, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "SipRxData_wholeMsg_set" "', argument " "1"" of type '" "pj::SipRxData *""'"); 
  }
  arg1 = reinterpret_cast< pj::SipRxData * >(argp1);
  {
    std::string *ptr = (std::string *)0;
    res2 = SWIG_AsPtr_std_string(swig_obj[1], &ptr);
    if (!SWIG_IsOK(res2)) {
      SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "SipRxData_wholeMsg_set" "', argument " "2"" of type '" "pj::string const &""'"); 
    }
    if (!ptr) {
      SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "SipRxData_wholeMsg_set" "', argument " "2"" of type '" "pj::string const &""'"); 
    }
    arg2 = ptr;
  }
  if (arg1) (arg1)->wholeMsg = *arg2;
  resultobj = SWIG_Py_Void();
  if (SWIG_IsNewObj(res2)) delete arg2;
  return resultobj;
fail:
  if (SWIG_IsNewObj(res2)) delete arg2;
  return NULL;
}


SWIGINTERN PyObject *_wrap_SipRxData_wholeMsg_get(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::SipRxData *arg1 = (pj::SipRxData *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  pj::string *result = 0 ;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__SipRxData, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "SipRxData_wholeMsg_get" "', argument " "1"" of type '" "pj::SipRxData *""'"); 
  }
  arg1 = reinterpret_cast< pj::SipRxData * >(argp1);
  result = (pj::string *) & ((arg1)->wholeMsg);
  resultobj = SWIG_From_std_string(static_cast< std::string >(*result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_SipRxData_srcAddress_set(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::SipRxData *arg1 = (pj::SipRxData *) 0 ;
  pj::SocketAddress *arg2 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  int res2 = SWIG_OLDOBJ ;
  PyObject *swig_obj[2] ;
  
  if (!SWIG_Python_UnpackTuple(args, "SipRxData_srcAddress_set", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__SipRxData, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "SipRxData_srcAddress_set" "', argument " "1"" of type '" "pj::SipRxData *""'"); 
  }
  arg1 = reinterpret_cast< pj::SipRxData * >(argp1);
  {
    std::string *ptr = (std::string *)0;
    res2 = SWIG_AsPtr_std_string(swig_obj[1], &ptr);
    if (!SWIG_IsOK(res2)) {
      SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "SipRxData_srcAddress_set" "', argument " "2"" of type '" "pj::SocketAddress const &""'"); 
    }
    if (!ptr) {
      SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "SipRxData_srcAddress_set" "', argument " "2"" of type '" "pj::SocketAddress const &""'"); 
    }
    arg2 = ptr;
  }
  if (arg1) (arg1)->srcAddress = *arg2;
  resultobj = SWIG_Py_Void();
  if (SWIG_IsNewObj(res2)) delete arg2;
  return resultobj;
fail:
  if (SWIG_IsNewObj(res2)) delete arg2;
  return NULL;
}


SWIGINTERN PyObject *_wrap_SipRxData_srcAddress_get(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::SipRxData *arg1 = (pj::SipRxData *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  pj::SocketAddress *result = 0 ;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__SipRxData, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "SipRxData_srcAddress_get" "', argument " "1"" of type '" "pj::SipRxData *""'"); 
  }
  arg1 = reinterpret_cast< pj::SipRxData * >(argp1);
  result = (pj::SocketAddress *) & ((arg1)->srcAddress);
  resultobj = SWIG_From_std_string(static_cast< std::string >(*result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_SipRxData_pjRxData_set(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::SipRxData *arg1 = (pj::SipRxData *) 0 ;
  void *arg2 = (void *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  int res2 ;
  PyObject *swig_obj[2] ;
  
  if (!SWIG_Python_UnpackTuple(args, "SipRxData_pjRxData_set", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__SipRxData, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "SipRxData_pjRxData_set" "', argument " "1"" of type '" "pj::SipRxData *""'"); 
  }
  arg1 = reinterpret_cast< pj::SipRxData * >(argp1);
  res2 = SWIG_ConvertPtr(swig_obj[1],SWIG_as_voidptrptr(&arg2), 0, SWIG_POINTER_DISOWN);
  if (!SWIG_IsOK(res2)) {
    SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "SipRxData_pjRxData_set" "', argument " "2"" of type '" "void *""'"); 
  }
  if (arg1) (arg1)->pjRxData = arg2;
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_SipRxData_pjRxData_get(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::SipRxData *arg1 = (pj::SipRxData *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  void *result = 0 ;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__SipRxData, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "SipRxData_pjRxData_get" "', argument " "1"" of type '" "pj::SipRxData *""'"); 
  }
  arg1 = reinterpret_cast< pj::SipRxData * >(argp1);
  result = (void *) ((arg1)->pjRxData);
  resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(result), SWIGTYPE_p_void, 0 |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_new_SipRxData(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::SipRxData *result = 0 ;
  
  if (!SWIG_Python_UnpackTuple(args, "new_SipRxData", 0, 0, 0)) SWIG_fail;
  result = (pj::SipRxData *)new pj::SipRxData();
  resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(result), SWIGTYPE_p_pj__SipRxData, SWIG_POINTER_NEW |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_delete_SipRxData(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::SipRxData *arg1 = (pj::SipRxData *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__SipRxData, SWIG_POINTER_DISOWN |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "delete_SipRxData" "', argument " "1"" of type '" "pj::SipRxData *""'"); 
  }
  arg1 = reinterpret_cast< pj::SipRxData * >(argp1);
  delete arg1;
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *SipRxData_swigregister(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *obj;
  if (!SWIG_Python_UnpackTuple(args, "swigregister", 1, 1, &obj)) return NULL;
  SWIG_TypeNewClientData(SWIGTYPE_p_pj__SipRxData, SWIG_NewClientData(obj));
  return SWIG_Py_Void();
}

SWIGINTERN PyObject *SipRxData_swiginit(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  return SWIG_Python_InitShadowInstance(args);
}

SWIGINTERN PyObject *_wrap_SipTxData_info_set(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::SipTxData *arg1 = (pj::SipTxData *) 0 ;
  pj::string *arg2 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  int res2 = SWIG_OLDOBJ ;
  PyObject *swig_obj[2] ;
  
  if (!SWIG_Python_UnpackTuple(args, "SipTxData_info_set", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__SipTxData, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "SipTxData_info_set" "', argument " "1"" of type '" "pj::SipTxData *""'"); 
  }
  arg1 = reinterpret_cast< pj::SipTxData * >(argp1);
  {
    std::string *ptr = (std::string *)0;
    res2 = SWIG_AsPtr_std_string(swig_obj[1], &ptr);
    if (!SWIG_IsOK(res2)) {
      SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "SipTxData_info_set" "', argument " "2"" of type '" "pj::string const &""'"); 
    }
    if (!ptr) {
      SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "SipTxData_info_set" "', argument " "2"" of type '" "pj::string const &""'"); 
    }
    arg2 = ptr;
  }
  if (arg1) (arg1)->info = *arg2;
  resultobj = SWIG_Py_Void();
  if (SWIG_IsNewObj(res2)) delete arg2;
  return resultobj;
fail:
  if (SWIG_IsNewObj(res2)) delete arg2;
  return NULL;
}


SWIGINTERN PyObject *_wrap_SipTxData_info_get(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::SipTxData *arg1 = (pj::SipTxData *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  pj::string *result = 0 ;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__SipTxData, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "SipTxData_info_get" "', argument " "1"" of type '" "pj::SipTxData *""'"); 
  }
  arg1 = reinterpret_cast< pj::SipTxData * >(argp1);
  result = (pj::string *) & ((arg1)->info);
  resultobj = SWIG_From_std_string(static_cast< std::string >(*result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_SipTxData_wholeMsg_set(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::SipTxData *arg1 = (pj::SipTxData *) 0 ;
  pj::string *arg2 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  int res2 = SWIG_OLDOBJ ;
  PyObject *swig_obj[2] ;
  
  if (!SWIG_Python_UnpackTuple(args, "SipTxData_wholeMsg_set", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__SipTxData, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "SipTxData_wholeMsg_set" "', argument " "1"" of type '" "pj::SipTxData *""'"); 
  }
  arg1 = reinterpret_cast< pj::SipTxData * >(argp1);
  {
    std::string *ptr = (std::string *)0;
    res2 = SWIG_AsPtr_std_string(swig_obj[1], &ptr);
    if (!SWIG_IsOK(res2)) {
      SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "SipTxData_wholeMsg_set" "', argument " "2"" of type '" "pj::string const &""'"); 
    }
    if (!ptr) {
      SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "SipTxData_wholeMsg_set" "', argument " "2"" of type '" "pj::string const &""'"); 
    }
    arg2 = ptr;
  }
  if (arg1) (arg1)->wholeMsg = *arg2;
  resultobj = SWIG_Py_Void();
  if (SWIG_IsNewObj(res2)) delete arg2;
  return resultobj;
fail:
  if (SWIG_IsNewObj(res2)) delete arg2;
  return NULL;
}


SWIGINTERN PyObject *_wrap_SipTxData_wholeMsg_get(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::SipTxData *arg1 = (pj::SipTxData *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  pj::string *result = 0 ;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__SipTxData, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "SipTxData_wholeMsg_get" "', argument " "1"" of type '" "pj::SipTxData *""'"); 
  }
  arg1 = reinterpret_cast< pj::SipTxData * >(argp1);
  result = (pj::string *) & ((arg1)->wholeMsg);
  resultobj = SWIG_From_std_string(static_cast< std::string >(*result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_SipTxData_dstAddress_set(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::SipTxData *arg1 = (pj::SipTxData *) 0 ;
  pj::SocketAddress *arg2 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  int res2 = SWIG_OLDOBJ ;
  PyObject *swig_obj[2] ;
  
  if (!SWIG_Python_UnpackTuple(args, "SipTxData_dstAddress_set", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__SipTxData, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "SipTxData_dstAddress_set" "', argument " "1"" of type '" "pj::SipTxData *""'"); 
  }
  arg1 = reinterpret_cast< pj::SipTxData * >(argp1);
  {
    std::string *ptr = (std::string *)0;
    res2 = SWIG_AsPtr_std_string(swig_obj[1], &ptr);
    if (!SWIG_IsOK(res2)) {
      SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "SipTxData_dstAddress_set" "', argument " "2"" of type '" "pj::SocketAddress const &""'"); 
    }
    if (!ptr) {
      SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "SipTxData_dstAddress_set" "', argument " "2"" of type '" "pj::SocketAddress const &""'"); 
    }
    arg2 = ptr;
  }
  if (arg1) (arg1)->dstAddress = *arg2;
  resultobj = SWIG_Py_Void();
  if (SWIG_IsNewObj(res2)) delete arg2;
  return resultobj;
fail:
  if (SWIG_IsNewObj(res2)) delete arg2;
  return NULL;
}


SWIGINTERN PyObject *_wrap_SipTxData_dstAddress_get(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::SipTxData *arg1 = (pj::SipTxData *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  pj::SocketAddress *result = 0 ;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__SipTxData, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "SipTxData_dstAddress_get" "', argument " "1"" of type '" "pj::SipTxData *""'"); 
  }
  arg1 = reinterpret_cast< pj::SipTxData * >(argp1);
  result = (pj::SocketAddress *) & ((arg1)->dstAddress);
  resultobj = SWIG_From_std_string(static_cast< std::string >(*result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_SipTxData_pjTxData_set(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::SipTxData *arg1 = (pj::SipTxData *) 0 ;
  void *arg2 = (void *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  int res2 ;
  PyObject *swig_obj[2] ;
  
  if (!SWIG_Python_UnpackTuple(args, "SipTxData_pjTxData_set", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__SipTxData, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "SipTxData_pjTxData_set" "', argument " "1"" of type '" "pj::SipTxData *""'"); 
  }
  arg1 = reinterpret_cast< pj::SipTxData * >(argp1);
  res2 = SWIG_ConvertPtr(swig_obj[1],SWIG_as_voidptrptr(&arg2), 0, SWIG_POINTER_DISOWN);
  if (!SWIG_IsOK(res2)) {
    SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "SipTxData_pjTxData_set" "', argument " "2"" of type '" "void *""'"); 
  }
  if (arg1) (arg1)->pjTxData = arg2;
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_SipTxData_pjTxData_get(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::SipTxData *arg1 = (pj::SipTxData *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  void *result = 0 ;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__SipTxData, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "SipTxData_pjTxData_get" "', argument " "1"" of type '" "pj::SipTxData *""'"); 
  }
  arg1 = reinterpret_cast< pj::SipTxData * >(argp1);
  result = (void *) ((arg1)->pjTxData);
  resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(result), SWIGTYPE_p_void, 0 |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_new_SipTxData(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::SipTxData *result = 0 ;
  
  if (!SWIG_Python_UnpackTuple(args, "new_SipTxData", 0, 0, 0)) SWIG_fail;
  result = (pj::SipTxData *)new pj::SipTxData();
  resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(result), SWIGTYPE_p_pj__SipTxData, SWIG_POINTER_NEW |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_delete_SipTxData(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::SipTxData *arg1 = (pj::SipTxData *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__SipTxData, SWIG_POINTER_DISOWN |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "delete_SipTxData" "', argument " "1"" of type '" "pj::SipTxData *""'"); 
  }
  arg1 = reinterpret_cast< pj::SipTxData * >(argp1);
  delete arg1;
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *SipTxData_swigregister(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *obj;
  if (!SWIG_Python_UnpackTuple(args, "swigregister", 1, 1, &obj)) return NULL;
  SWIG_TypeNewClientData(SWIGTYPE_p_pj__SipTxData, SWIG_NewClientData(obj));
  return SWIG_Py_Void();
}

SWIGINTERN PyObject *SipTxData_swiginit(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  return SWIG_Python_InitShadowInstance(args);
}

SWIGINTERN PyObject *_wrap_SipTransaction_role_set(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::SipTransaction *arg1 = (pj::SipTransaction *) 0 ;
  pjsip_role_e arg2 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  int val2 ;
  int ecode2 = 0 ;
  PyObject *swig_obj[2] ;
  
  if (!SWIG_Python_UnpackTuple(args, "SipTransaction_role_set", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__SipTransaction, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "SipTransaction_role_set" "', argument " "1"" of type '" "pj::SipTransaction *""'"); 
  }
  arg1 = reinterpret_cast< pj::SipTransaction * >(argp1);
  ecode2 = SWIG_AsVal_int(swig_obj[1], &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "SipTransaction_role_set" "', argument " "2"" of type '" "pjsip_role_e""'");
  } 
  arg2 = static_cast< pjsip_role_e >(val2);
  if (arg1) (arg1)->role = arg2;
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_SipTransaction_role_get(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::SipTransaction *arg1 = (pj::SipTransaction *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  pjsip_role_e result;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__SipTransaction, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "SipTransaction_role_get" "', argument " "1"" of type '" "pj::SipTransaction *""'"); 
  }
  arg1 = reinterpret_cast< pj::SipTransaction * >(argp1);
  result = (pjsip_role_e) ((arg1)->role);
  resultobj = SWIG_From_int(static_cast< int >(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_SipTransaction_method_set(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::SipTransaction *arg1 = (pj::SipTransaction *) 0 ;
  pj::string *arg2 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  int res2 = SWIG_OLDOBJ ;
  PyObject *swig_obj[2] ;
  
  if (!SWIG_Python_UnpackTuple(args, "SipTransaction_method_set", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__SipTransaction, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "SipTransaction_method_set" "', argument " "1"" of type '" "pj::SipTransaction *""'"); 
  }
  arg1 = reinterpret_cast< pj::SipTransaction * >(argp1);
  {
    std::string *ptr = (std::string *)0;
    res2 = SWIG_AsPtr_std_string(swig_obj[1], &ptr);
    if (!SWIG_IsOK(res2)) {
      SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "SipTransaction_method_set" "', argument " "2"" of type '" "pj::string const &""'"); 
    }
    if (!ptr) {
      SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "SipTransaction_method_set" "', argument " "2"" of type '" "pj::string const &""'"); 
    }
    arg2 = ptr;
  }
  if (arg1) (arg1)->method = *arg2;
  resultobj = SWIG_Py_Void();
  if (SWIG_IsNewObj(res2)) delete arg2;
  return resultobj;
fail:
  if (SWIG_IsNewObj(res2)) delete arg2;
  return NULL;
}


SWIGINTERN PyObject *_wrap_SipTransaction_method_get(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::SipTransaction *arg1 = (pj::SipTransaction *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  pj::string *result = 0 ;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__SipTransaction, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "SipTransaction_method_get" "', argument " "1"" of type '" "pj::SipTransaction *""'"); 
  }
  arg1 = reinterpret_cast< pj::SipTransaction * >(argp1);
  result = (pj::string *) & ((arg1)->method);
  resultobj = SWIG_From_std_string(static_cast< std::string >(*result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_SipTransaction_statusCode_set(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::SipTransaction *arg1 = (pj::SipTransaction *) 0 ;
  int arg2 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  int val2 ;
  int ecode2 = 0 ;
  PyObject *swig_obj[2] ;
  
  if (!SWIG_Python_UnpackTuple(args, "SipTransaction_statusCode_set", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__SipTransaction, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "SipTransaction_statusCode_set" "', argument " "1"" of type '" "pj::SipTransaction *""'"); 
  }
  arg1 = reinterpret_cast< pj::SipTransaction * >(argp1);
  ecode2 = SWIG_AsVal_int(swig_obj[1], &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "SipTransaction_statusCode_set" "', argument " "2"" of type '" "int""'");
  } 
  arg2 = static_cast< int >(val2);
  if (arg1) (arg1)->statusCode = arg2;
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_SipTransaction_statusCode_get(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::SipTransaction *arg1 = (pj::SipTransaction *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  int result;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__SipTransaction, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "SipTransaction_statusCode_get" "', argument " "1"" of type '" "pj::SipTransaction *""'"); 
  }
  arg1 = reinterpret_cast< pj::SipTransaction * >(argp1);
  result = (int) ((arg1)->statusCode);
  resultobj = SWIG_From_int(static_cast< int >(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_SipTransaction_statusText_set(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::SipTransaction *arg1 = (pj::SipTransaction *) 0 ;
  pj::string *arg2 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  int res2 = SWIG_OLDOBJ ;
  PyObject *swig_obj[2] ;
  
  if (!SWIG_Python_UnpackTuple(args, "SipTransaction_statusText_set", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__SipTransaction, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "SipTransaction_statusText_set" "', argument " "1"" of type '" "pj::SipTransaction *""'"); 
  }
  arg1 = reinterpret_cast< pj::SipTransaction * >(argp1);
  {
    std::string *ptr = (std::string *)0;
    res2 = SWIG_AsPtr_std_string(swig_obj[1], &ptr);
    if (!SWIG_IsOK(res2)) {
      SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "SipTransaction_statusText_set" "', argument " "2"" of type '" "pj::string const &""'"); 
    }
    if (!ptr) {
      SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "SipTransaction_statusText_set" "', argument " "2"" of type '" "pj::string const &""'"); 
    }
    arg2 = ptr;
  }
  if (arg1) (arg1)->statusText = *arg2;
  resultobj = SWIG_Py_Void();
  if (SWIG_IsNewObj(res2)) delete arg2;
  return resultobj;
fail:
  if (SWIG_IsNewObj(res2)) delete arg2;
  return NULL;
}


SWIGINTERN PyObject *_wrap_SipTransaction_statusText_get(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::SipTransaction *arg1 = (pj::SipTransaction *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  pj::string *result = 0 ;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__SipTransaction, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "SipTransaction_statusText_get" "', argument " "1"" of type '" "pj::SipTransaction *""'"); 
  }
  arg1 = reinterpret_cast< pj::SipTransaction * >(argp1);
  result = (pj::string *) & ((arg1)->statusText);
  resultobj = SWIG_From_std_string(static_cast< std::string >(*result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_SipTransaction_state_set(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::SipTransaction *arg1 = (pj::SipTransaction *) 0 ;
  pjsip_tsx_state_e arg2 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  int val2 ;
  int ecode2 = 0 ;
  PyObject *swig_obj[2] ;
  
  if (!SWIG_Python_UnpackTuple(args, "SipTransaction_state_set", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__SipTransaction, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "SipTransaction_state_set" "', argument " "1"" of type '" "pj::SipTransaction *""'"); 
  }
  arg1 = reinterpret_cast< pj::SipTransaction * >(argp1);
  ecode2 = SWIG_AsVal_int(swig_obj[1], &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "SipTransaction_state_set" "', argument " "2"" of type '" "pjsip_tsx_state_e""'");
  } 
  arg2 = static_cast< pjsip_tsx_state_e >(val2);
  if (arg1) (arg1)->state = arg2;
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_SipTransaction_state_get(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::SipTransaction *arg1 = (pj::SipTransaction *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  pjsip_tsx_state_e result;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__SipTransaction, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "SipTransaction_state_get" "', argument " "1"" of type '" "pj::SipTransaction *""'"); 
  }
  arg1 = reinterpret_cast< pj::SipTransaction * >(argp1);
  result = (pjsip_tsx_state_e) ((arg1)->state);
  resultobj = SWIG_From_int(static_cast< int >(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_SipTransaction_lastTx_set(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::SipTransaction *arg1 = (pj::SipTransaction *) 0 ;
  pj::SipTxData *arg2 = (pj::SipTxData *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  void *argp2 = 0 ;
  int res2 = 0 ;
  PyObject *swig_obj[2] ;
  
  if (!SWIG_Python_UnpackTuple(args, "SipTransaction_lastTx_set", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__SipTransaction, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "SipTransaction_lastTx_set" "', argument " "1"" of type '" "pj::SipTransaction *""'"); 
  }
  arg1 = reinterpret_cast< pj::SipTransaction * >(argp1);
  res2 = SWIG_ConvertPtr(swig_obj[1], &argp2,SWIGTYPE_p_pj__SipTxData, 0 |  0 );
  if (!SWIG_IsOK(res2)) {
    SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "SipTransaction_lastTx_set" "', argument " "2"" of type '" "pj::SipTxData *""'"); 
  }
  arg2 = reinterpret_cast< pj::SipTxData * >(argp2);
  if (arg1) (arg1)->lastTx = *arg2;
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_SipTransaction_lastTx_get(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::SipTransaction *arg1 = (pj::SipTransaction *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  pj::SipTxData *result = 0 ;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__SipTransaction, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "SipTransaction_lastTx_get" "', argument " "1"" of type '" "pj::SipTransaction *""'"); 
  }
  arg1 = reinterpret_cast< pj::SipTransaction * >(argp1);
  result = (pj::SipTxData *)& ((arg1)->lastTx);
  resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(result), SWIGTYPE_p_pj__SipTxData, 0 |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_SipTransaction_pjTransaction_set(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::SipTransaction *arg1 = (pj::SipTransaction *) 0 ;
  void *arg2 = (void *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  int res2 ;
  PyObject *swig_obj[2] ;
  
  if (!SWIG_Python_UnpackTuple(args, "SipTransaction_pjTransaction_set", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__SipTransaction, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "SipTransaction_pjTransaction_set" "', argument " "1"" of type '" "pj::SipTransaction *""'"); 
  }
  arg1 = reinterpret_cast< pj::SipTransaction * >(argp1);
  res2 = SWIG_ConvertPtr(swig_obj[1],SWIG_as_voidptrptr(&arg2), 0, SWIG_POINTER_DISOWN);
  if (!SWIG_IsOK(res2)) {
    SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "SipTransaction_pjTransaction_set" "', argument " "2"" of type '" "void *""'"); 
  }
  if (arg1) (arg1)->pjTransaction = arg2;
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_SipTransaction_pjTransaction_get(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::SipTransaction *arg1 = (pj::SipTransaction *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  void *result = 0 ;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__SipTransaction, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "SipTransaction_pjTransaction_get" "', argument " "1"" of type '" "pj::SipTransaction *""'"); 
  }
  arg1 = reinterpret_cast< pj::SipTransaction * >(argp1);
  result = (void *) ((arg1)->pjTransaction);
  resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(result), SWIGTYPE_p_void, 0 |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_new_SipTransaction(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::SipTransaction *result = 0 ;
  
  if (!SWIG_Python_UnpackTuple(args, "new_SipTransaction", 0, 0, 0)) SWIG_fail;
  result = (pj::SipTransaction *)new pj::SipTransaction();
  resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(result), SWIGTYPE_p_pj__SipTransaction, SWIG_POINTER_NEW |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_delete_SipTransaction(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::SipTransaction *arg1 = (pj::SipTransaction *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__SipTransaction, SWIG_POINTER_DISOWN |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "delete_SipTransaction" "', argument " "1"" of type '" "pj::SipTransaction *""'"); 
  }
  arg1 = reinterpret_cast< pj::SipTransaction * >(argp1);
  delete arg1;
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *SipTransaction_swigregister(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *obj;
  if (!SWIG_Python_UnpackTuple(args, "swigregister", 1, 1, &obj)) return NULL;
  SWIG_TypeNewClientData(SWIGTYPE_p_pj__SipTransaction, SWIG_NewClientData(obj));
  return SWIG_Py_Void();
}

SWIGINTERN PyObject *SipTransaction_swiginit(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  return SWIG_Python_InitShadowInstance(args);
}

SWIGINTERN PyObject *_wrap_TimerEvent_entry_set(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::TimerEvent *arg1 = (pj::TimerEvent *) 0 ;
  pj::TimerEntry arg2 = (pj::TimerEntry) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  int res2 ;
  PyObject *swig_obj[2] ;
  
  if (!SWIG_Python_UnpackTuple(args, "TimerEvent_entry_set", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__TimerEvent, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "TimerEvent_entry_set" "', argument " "1"" of type '" "pj::TimerEvent *""'"); 
  }
  arg1 = reinterpret_cast< pj::TimerEvent * >(argp1);
  res2 = SWIG_ConvertPtr(swig_obj[1],SWIG_as_voidptrptr(&arg2), 0, SWIG_POINTER_DISOWN);
  if (!SWIG_IsOK(res2)) {
    SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "TimerEvent_entry_set" "', argument " "2"" of type '" "pj::TimerEntry""'"); 
  }
  if (arg1) (arg1)->entry = arg2;
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_TimerEvent_entry_get(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::TimerEvent *arg1 = (pj::TimerEvent *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  pj::TimerEntry result;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__TimerEvent, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "TimerEvent_entry_get" "', argument " "1"" of type '" "pj::TimerEvent *""'"); 
  }
  arg1 = reinterpret_cast< pj::TimerEvent * >(argp1);
  result = (pj::TimerEntry) ((arg1)->entry);
  resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(result), SWIGTYPE_p_void, 0 |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_new_TimerEvent(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::TimerEvent *result = 0 ;
  
  if (!SWIG_Python_UnpackTuple(args, "new_TimerEvent", 0, 0, 0)) SWIG_fail;
  result = (pj::TimerEvent *)new pj::TimerEvent();
  resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(result), SWIGTYPE_p_pj__TimerEvent, SWIG_POINTER_NEW |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_delete_TimerEvent(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::TimerEvent *arg1 = (pj::TimerEvent *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__TimerEvent, SWIG_POINTER_DISOWN |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "delete_TimerEvent" "', argument " "1"" of type '" "pj::TimerEvent *""'"); 
  }
  arg1 = reinterpret_cast< pj::TimerEvent * >(argp1);
  delete arg1;
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *TimerEvent_swigregister(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *obj;
  if (!SWIG_Python_UnpackTuple(args, "swigregister", 1, 1, &obj)) return NULL;
  SWIG_TypeNewClientData(SWIGTYPE_p_pj__TimerEvent, SWIG_NewClientData(obj));
  return SWIG_Py_Void();
}

SWIGINTERN PyObject *TimerEvent_swiginit(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  return SWIG_Python_InitShadowInstance(args);
}

SWIGINTERN PyObject *_wrap_TsxStateEventSrc_rdata_set(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::TsxStateEventSrc *arg1 = (pj::TsxStateEventSrc *) 0 ;
  pj::SipRxData *arg2 = (pj::SipRxData *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  void *argp2 = 0 ;
  int res2 = 0 ;
  PyObject *swig_obj[2] ;
  
  if (!SWIG_Python_UnpackTuple(args, "TsxStateEventSrc_rdata_set", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__TsxStateEventSrc, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "TsxStateEventSrc_rdata_set" "', argument " "1"" of type '" "pj::TsxStateEventSrc *""'"); 
  }
  arg1 = reinterpret_cast< pj::TsxStateEventSrc * >(argp1);
  res2 = SWIG_ConvertPtr(swig_obj[1], &argp2,SWIGTYPE_p_pj__SipRxData, 0 |  0 );
  if (!SWIG_IsOK(res2)) {
    SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "TsxStateEventSrc_rdata_set" "', argument " "2"" of type '" "pj::SipRxData *""'"); 
  }
  arg2 = reinterpret_cast< pj::SipRxData * >(argp2);
  if (arg1) (arg1)->rdata = *arg2;
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_TsxStateEventSrc_rdata_get(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::TsxStateEventSrc *arg1 = (pj::TsxStateEventSrc *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  pj::SipRxData *result = 0 ;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__TsxStateEventSrc, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "TsxStateEventSrc_rdata_get" "', argument " "1"" of type '" "pj::TsxStateEventSrc *""'"); 
  }
  arg1 = reinterpret_cast< pj::TsxStateEventSrc * >(argp1);
  result = (pj::SipRxData *)& ((arg1)->rdata);
  resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(result), SWIGTYPE_p_pj__SipRxData, 0 |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_TsxStateEventSrc_tdata_set(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::TsxStateEventSrc *arg1 = (pj::TsxStateEventSrc *) 0 ;
  pj::SipTxData *arg2 = (pj::SipTxData *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  void *argp2 = 0 ;
  int res2 = 0 ;
  PyObject *swig_obj[2] ;
  
  if (!SWIG_Python_UnpackTuple(args, "TsxStateEventSrc_tdata_set", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__TsxStateEventSrc, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "TsxStateEventSrc_tdata_set" "', argument " "1"" of type '" "pj::TsxStateEventSrc *""'"); 
  }
  arg1 = reinterpret_cast< pj::TsxStateEventSrc * >(argp1);
  res2 = SWIG_ConvertPtr(swig_obj[1], &argp2,SWIGTYPE_p_pj__SipTxData, 0 |  0 );
  if (!SWIG_IsOK(res2)) {
    SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "TsxStateEventSrc_tdata_set" "', argument " "2"" of type '" "pj::SipTxData *""'"); 
  }
  arg2 = reinterpret_cast< pj::SipTxData * >(argp2);
  if (arg1) (arg1)->tdata = *arg2;
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_TsxStateEventSrc_tdata_get(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::TsxStateEventSrc *arg1 = (pj::TsxStateEventSrc *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  pj::SipTxData *result = 0 ;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__TsxStateEventSrc, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "TsxStateEventSrc_tdata_get" "', argument " "1"" of type '" "pj::TsxStateEventSrc *""'"); 
  }
  arg1 = reinterpret_cast< pj::TsxStateEventSrc * >(argp1);
  result = (pj::SipTxData *)& ((arg1)->tdata);
  resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(result), SWIGTYPE_p_pj__SipTxData, 0 |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_TsxStateEventSrc_timer_set(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::TsxStateEventSrc *arg1 = (pj::TsxStateEventSrc *) 0 ;
  pj::TimerEntry arg2 = (pj::TimerEntry) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  int res2 ;
  PyObject *swig_obj[2] ;
  
  if (!SWIG_Python_UnpackTuple(args, "TsxStateEventSrc_timer_set", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__TsxStateEventSrc, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "TsxStateEventSrc_timer_set" "', argument " "1"" of type '" "pj::TsxStateEventSrc *""'"); 
  }
  arg1 = reinterpret_cast< pj::TsxStateEventSrc * >(argp1);
  res2 = SWIG_ConvertPtr(swig_obj[1],SWIG_as_voidptrptr(&arg2), 0, SWIG_POINTER_DISOWN);
  if (!SWIG_IsOK(res2)) {
    SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "TsxStateEventSrc_timer_set" "', argument " "2"" of type '" "pj::TimerEntry""'"); 
  }
  if (arg1) (arg1)->timer = arg2;
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_TsxStateEventSrc_timer_get(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::TsxStateEventSrc *arg1 = (pj::TsxStateEventSrc *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  pj::TimerEntry result;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__TsxStateEventSrc, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "TsxStateEventSrc_timer_get" "', argument " "1"" of type '" "pj::TsxStateEventSrc *""'"); 
  }
  arg1 = reinterpret_cast< pj::TsxStateEventSrc * >(argp1);
  result = (pj::TimerEntry) ((arg1)->timer);
  resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(result), SWIGTYPE_p_void, 0 |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_TsxStateEventSrc_status_set(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::TsxStateEventSrc *arg1 = (pj::TsxStateEventSrc *) 0 ;
  pj_status_t arg2 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  int val2 ;
  int ecode2 = 0 ;
  PyObject *swig_obj[2] ;
  
  if (!SWIG_Python_UnpackTuple(args, "TsxStateEventSrc_status_set", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__TsxStateEventSrc, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "TsxStateEventSrc_status_set" "', argument " "1"" of type '" "pj::TsxStateEventSrc *""'"); 
  }
  arg1 = reinterpret_cast< pj::TsxStateEventSrc * >(argp1);
  ecode2 = SWIG_AsVal_int(swig_obj[1], &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "TsxStateEventSrc_status_set" "', argument " "2"" of type '" "pj_status_t""'");
  } 
  arg2 = static_cast< pj_status_t >(val2);
  if (arg1) (arg1)->status = arg2;
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_TsxStateEventSrc_status_get(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::TsxStateEventSrc *arg1 = (pj::TsxStateEventSrc *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  pj_status_t result;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__TsxStateEventSrc, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "TsxStateEventSrc_status_get" "', argument " "1"" of type '" "pj::TsxStateEventSrc *""'"); 
  }
  arg1 = reinterpret_cast< pj::TsxStateEventSrc * >(argp1);
  result = (pj_status_t) ((arg1)->status);
  resultobj = SWIG_From_int(static_cast< int >(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_TsxStateEventSrc_data_set(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::TsxStateEventSrc *arg1 = (pj::TsxStateEventSrc *) 0 ;
  pj::GenericData arg2 = (pj::GenericData) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  int res2 ;
  PyObject *swig_obj[2] ;
  
  if (!SWIG_Python_UnpackTuple(args, "TsxStateEventSrc_data_set", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__TsxStateEventSrc, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "TsxStateEventSrc_data_set" "', argument " "1"" of type '" "pj::TsxStateEventSrc *""'"); 
  }
  arg1 = reinterpret_cast< pj::TsxStateEventSrc * >(argp1);
  res2 = SWIG_ConvertPtr(swig_obj[1],SWIG_as_voidptrptr(&arg2), 0, SWIG_POINTER_DISOWN);
  if (!SWIG_IsOK(res2)) {
    SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "TsxStateEventSrc_data_set" "', argument " "2"" of type '" "pj::GenericData""'"); 
  }
  if (arg1) (arg1)->data = arg2;
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_TsxStateEventSrc_data_get(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::TsxStateEventSrc *arg1 = (pj::TsxStateEventSrc *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  pj::GenericData result;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__TsxStateEventSrc, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "TsxStateEventSrc_data_get" "', argument " "1"" of type '" "pj::TsxStateEventSrc *""'"); 
  }
  arg1 = reinterpret_cast< pj::TsxStateEventSrc * >(argp1);
  result = (pj::GenericData) ((arg1)->data);
  resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(result), SWIGTYPE_p_void, 0 |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_new_TsxStateEventSrc(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::TsxStateEventSrc *result = 0 ;
  
  if (!SWIG_Python_UnpackTuple(args, "new_TsxStateEventSrc", 0, 0, 0)) SWIG_fail;
  result = (pj::TsxStateEventSrc *)new pj::TsxStateEventSrc();
  resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(result), SWIGTYPE_p_pj__TsxStateEventSrc, SWIG_POINTER_NEW |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_delete_TsxStateEventSrc(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::TsxStateEventSrc *arg1 = (pj::TsxStateEventSrc *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__TsxStateEventSrc, SWIG_POINTER_DISOWN |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "delete_TsxStateEventSrc" "', argument " "1"" of type '" "pj::TsxStateEventSrc *""'"); 
  }
  arg1 = reinterpret_cast< pj::TsxStateEventSrc * >(argp1);
  delete arg1;
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *TsxStateEventSrc_swigregister(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *obj;
  if (!SWIG_Python_UnpackTuple(args, "swigregister", 1, 1, &obj)) return NULL;
  SWIG_TypeNewClientData(SWIGTYPE_p_pj__TsxStateEventSrc, SWIG_NewClientData(obj));
  return SWIG_Py_Void();
}

SWIGINTERN PyObject *TsxStateEventSrc_swiginit(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  return SWIG_Python_InitShadowInstance(args);
}

SWIGINTERN PyObject *_wrap_TsxStateEvent_src_set(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::TsxStateEvent *arg1 = (pj::TsxStateEvent *) 0 ;
  pj::TsxStateEventSrc *arg2 = (pj::TsxStateEventSrc *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  void *argp2 = 0 ;
  int res2 = 0 ;
  PyObject *swig_obj[2] ;
  
  if (!SWIG_Python_UnpackTuple(args, "TsxStateEvent_src_set", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__TsxStateEvent, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "TsxStateEvent_src_set" "', argument " "1"" of type '" "pj::TsxStateEvent *""'"); 
  }
  arg1 = reinterpret_cast< pj::TsxStateEvent * >(argp1);
  res2 = SWIG_ConvertPtr(swig_obj[1], &argp2,SWIGTYPE_p_pj__TsxStateEventSrc, 0 |  0 );
  if (!SWIG_IsOK(res2)) {
    SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "TsxStateEvent_src_set" "', argument " "2"" of type '" "pj::TsxStateEventSrc *""'"); 
  }
  arg2 = reinterpret_cast< pj::TsxStateEventSrc * >(argp2);
  if (arg1) (arg1)->src = *arg2;
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_TsxStateEvent_src_get(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::TsxStateEvent *arg1 = (pj::TsxStateEvent *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  pj::TsxStateEventSrc *result = 0 ;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__TsxStateEvent, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "TsxStateEvent_src_get" "', argument " "1"" of type '" "pj::TsxStateEvent *""'"); 
  }
  arg1 = reinterpret_cast< pj::TsxStateEvent * >(argp1);
  result = (pj::TsxStateEventSrc *)& ((arg1)->src);
  resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(result), SWIGTYPE_p_pj__TsxStateEventSrc, 0 |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_TsxStateEvent_tsx_set(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::TsxStateEvent *arg1 = (pj::TsxStateEvent *) 0 ;
  pj::SipTransaction *arg2 = (pj::SipTransaction *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  void *argp2 = 0 ;
  int res2 = 0 ;
  PyObject *swig_obj[2] ;
  
  if (!SWIG_Python_UnpackTuple(args, "TsxStateEvent_tsx_set", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__TsxStateEvent, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "TsxStateEvent_tsx_set" "', argument " "1"" of type '" "pj::TsxStateEvent *""'"); 
  }
  arg1 = reinterpret_cast< pj::TsxStateEvent * >(argp1);
  res2 = SWIG_ConvertPtr(swig_obj[1], &argp2,SWIGTYPE_p_pj__SipTransaction, 0 |  0 );
  if (!SWIG_IsOK(res2)) {
    SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "TsxStateEvent_tsx_set" "', argument " "2"" of type '" "pj::SipTransaction *""'"); 
  }
  arg2 = reinterpret_cast< pj::SipTransaction * >(argp2);
  if (arg1) (arg1)->tsx = *arg2;
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_TsxStateEvent_tsx_get(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::TsxStateEvent *arg1 = (pj::TsxStateEvent *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  pj::SipTransaction *result = 0 ;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__TsxStateEvent, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "TsxStateEvent_tsx_get" "', argument " "1"" of type '" "pj::TsxStateEvent *""'"); 
  }
  arg1 = reinterpret_cast< pj::TsxStateEvent * >(argp1);
  result = (pj::SipTransaction *)& ((arg1)->tsx);
  resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(result), SWIGTYPE_p_pj__SipTransaction, 0 |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_TsxStateEvent_prevState_set(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::TsxStateEvent *arg1 = (pj::TsxStateEvent *) 0 ;
  pjsip_tsx_state_e arg2 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  int val2 ;
  int ecode2 = 0 ;
  PyObject *swig_obj[2] ;
  
  if (!SWIG_Python_UnpackTuple(args, "TsxStateEvent_prevState_set", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__TsxStateEvent, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "TsxStateEvent_prevState_set" "', argument " "1"" of type '" "pj::TsxStateEvent *""'"); 
  }
  arg1 = reinterpret_cast< pj::TsxStateEvent * >(argp1);
  ecode2 = SWIG_AsVal_int(swig_obj[1], &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "TsxStateEvent_prevState_set" "', argument " "2"" of type '" "pjsip_tsx_state_e""'");
  } 
  arg2 = static_cast< pjsip_tsx_state_e >(val2);
  if (arg1) (arg1)->prevState = arg2;
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_TsxStateEvent_prevState_get(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::TsxStateEvent *arg1 = (pj::TsxStateEvent *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  pjsip_tsx_state_e result;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__TsxStateEvent, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "TsxStateEvent_prevState_get" "', argument " "1"" of type '" "pj::TsxStateEvent *""'"); 
  }
  arg1 = reinterpret_cast< pj::TsxStateEvent * >(argp1);
  result = (pjsip_tsx_state_e) ((arg1)->prevState);
  resultobj = SWIG_From_int(static_cast< int >(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_TsxStateEvent_type_set(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::TsxStateEvent *arg1 = (pj::TsxStateEvent *) 0 ;
  pjsip_event_id_e arg2 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  int val2 ;
  int ecode2 = 0 ;
  PyObject *swig_obj[2] ;
  
  if (!SWIG_Python_UnpackTuple(args, "TsxStateEvent_type_set", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__TsxStateEvent, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "TsxStateEvent_type_set" "', argument " "1"" of type '" "pj::TsxStateEvent *""'"); 
  }
  arg1 = reinterpret_cast< pj::TsxStateEvent * >(argp1);
  ecode2 = SWIG_AsVal_int(swig_obj[1], &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "TsxStateEvent_type_set" "', argument " "2"" of type '" "pjsip_event_id_e""'");
  } 
  arg2 = static_cast< pjsip_event_id_e >(val2);
  if (arg1) (arg1)->type = arg2;
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_TsxStateEvent_type_get(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::TsxStateEvent *arg1 = (pj::TsxStateEvent *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  pjsip_event_id_e result;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__TsxStateEvent, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "TsxStateEvent_type_get" "', argument " "1"" of type '" "pj::TsxStateEvent *""'"); 
  }
  arg1 = reinterpret_cast< pj::TsxStateEvent * >(argp1);
  result = (pjsip_event_id_e) ((arg1)->type);
  resultobj = SWIG_From_int(static_cast< int >(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_new_TsxStateEvent(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::TsxStateEvent *result = 0 ;
  
  if (!SWIG_Python_UnpackTuple(args, "new_TsxStateEvent", 0, 0, 0)) SWIG_fail;
  result = (pj::TsxStateEvent *)new pj::TsxStateEvent();
  resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(result), SWIGTYPE_p_pj__TsxStateEvent, SWIG_POINTER_NEW |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_delete_TsxStateEvent(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::TsxStateEvent *arg1 = (pj::TsxStateEvent *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__TsxStateEvent, SWIG_POINTER_DISOWN |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "delete_TsxStateEvent" "', argument " "1"" of type '" "pj::TsxStateEvent *""'"); 
  }
  arg1 = reinterpret_cast< pj::TsxStateEvent * >(argp1);
  delete arg1;
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *TsxStateEvent_swigregister(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *obj;
  if (!SWIG_Python_UnpackTuple(args, "swigregister", 1, 1, &obj)) return NULL;
  SWIG_TypeNewClientData(SWIGTYPE_p_pj__TsxStateEvent, SWIG_NewClientData(obj));
  return SWIG_Py_Void();
}

SWIGINTERN PyObject *TsxStateEvent_swiginit(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  return SWIG_Python_InitShadowInstance(args);
}

SWIGINTERN PyObject *_wrap_TxMsgEvent_tdata_set(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::TxMsgEvent *arg1 = (pj::TxMsgEvent *) 0 ;
  pj::SipTxData *arg2 = (pj::SipTxData *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  void *argp2 = 0 ;
  int res2 = 0 ;
  PyObject *swig_obj[2] ;
  
  if (!SWIG_Python_UnpackTuple(args, "TxMsgEvent_tdata_set", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__TxMsgEvent, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "TxMsgEvent_tdata_set" "', argument " "1"" of type '" "pj::TxMsgEvent *""'"); 
  }
  arg1 = reinterpret_cast< pj::TxMsgEvent * >(argp1);
  res2 = SWIG_ConvertPtr(swig_obj[1], &argp2,SWIGTYPE_p_pj__SipTxData, 0 |  0 );
  if (!SWIG_IsOK(res2)) {
    SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "TxMsgEvent_tdata_set" "', argument " "2"" of type '" "pj::SipTxData *""'"); 
  }
  arg2 = reinterpret_cast< pj::SipTxData * >(argp2);
  if (arg1) (arg1)->tdata = *arg2;
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_TxMsgEvent_tdata_get(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::TxMsgEvent *arg1 = (pj::TxMsgEvent *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  pj::SipTxData *result = 0 ;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__TxMsgEvent, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "TxMsgEvent_tdata_get" "', argument " "1"" of type '" "pj::TxMsgEvent *""'"); 
  }
  arg1 = reinterpret_cast< pj::TxMsgEvent * >(argp1);
  result = (pj::SipTxData *)& ((arg1)->tdata);
  resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(result), SWIGTYPE_p_pj__SipTxData, 0 |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_new_TxMsgEvent(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::TxMsgEvent *result = 0 ;
  
  if (!SWIG_Python_UnpackTuple(args, "new_TxMsgEvent", 0, 0, 0)) SWIG_fail;
  result = (pj::TxMsgEvent *)new pj::TxMsgEvent();
  resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(result), SWIGTYPE_p_pj__TxMsgEvent, SWIG_POINTER_NEW |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_delete_TxMsgEvent(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::TxMsgEvent *arg1 = (pj::TxMsgEvent *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__TxMsgEvent, SWIG_POINTER_DISOWN |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "delete_TxMsgEvent" "', argument " "1"" of type '" "pj::TxMsgEvent *""'"); 
  }
  arg1 = reinterpret_cast< pj::TxMsgEvent * >(argp1);
  delete arg1;
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *TxMsgEvent_swigregister(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *obj;
  if (!SWIG_Python_UnpackTuple(args, "swigregister", 1, 1, &obj)) return NULL;
  SWIG_TypeNewClientData(SWIGTYPE_p_pj__TxMsgEvent, SWIG_NewClientData(obj));
  return SWIG_Py_Void();
}

SWIGINTERN PyObject *TxMsgEvent_swiginit(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  return SWIG_Python_InitShadowInstance(args);
}

SWIGINTERN PyObject *_wrap_TxErrorEvent_tdata_set(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::TxErrorEvent *arg1 = (pj::TxErrorEvent *) 0 ;
  pj::SipTxData *arg2 = (pj::SipTxData *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  void *argp2 = 0 ;
  int res2 = 0 ;
  PyObject *swig_obj[2] ;
  
  if (!SWIG_Python_UnpackTuple(args, "TxErrorEvent_tdata_set", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__TxErrorEvent, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "TxErrorEvent_tdata_set" "', argument " "1"" of type '" "pj::TxErrorEvent *""'"); 
  }
  arg1 = reinterpret_cast< pj::TxErrorEvent * >(argp1);
  res2 = SWIG_ConvertPtr(swig_obj[1], &argp2,SWIGTYPE_p_pj__SipTxData, 0 |  0 );
  if (!SWIG_IsOK(res2)) {
    SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "TxErrorEvent_tdata_set" "', argument " "2"" of type '" "pj::SipTxData *""'"); 
  }
  arg2 = reinterpret_cast< pj::SipTxData * >(argp2);
  if (arg1) (arg1)->tdata = *arg2;
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_TxErrorEvent_tdata_get(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::TxErrorEvent *arg1 = (pj::TxErrorEvent *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  pj::SipTxData *result = 0 ;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__TxErrorEvent, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "TxErrorEvent_tdata_get" "', argument " "1"" of type '" "pj::TxErrorEvent *""'"); 
  }
  arg1 = reinterpret_cast< pj::TxErrorEvent * >(argp1);
  result = (pj::SipTxData *)& ((arg1)->tdata);
  resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(result), SWIGTYPE_p_pj__SipTxData, 0 |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_TxErrorEvent_tsx_set(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::TxErrorEvent *arg1 = (pj::TxErrorEvent *) 0 ;
  pj::SipTransaction *arg2 = (pj::SipTransaction *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  void *argp2 = 0 ;
  int res2 = 0 ;
  PyObject *swig_obj[2] ;
  
  if (!SWIG_Python_UnpackTuple(args, "TxErrorEvent_tsx_set", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__TxErrorEvent, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "TxErrorEvent_tsx_set" "', argument " "1"" of type '" "pj::TxErrorEvent *""'"); 
  }
  arg1 = reinterpret_cast< pj::TxErrorEvent * >(argp1);
  res2 = SWIG_ConvertPtr(swig_obj[1], &argp2,SWIGTYPE_p_pj__SipTransaction, 0 |  0 );
  if (!SWIG_IsOK(res2)) {
    SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "TxErrorEvent_tsx_set" "', argument " "2"" of type '" "pj::SipTransaction *""'"); 
  }
  arg2 = reinterpret_cast< pj::SipTransaction * >(argp2);
  if (arg1) (arg1)->tsx = *arg2;
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_TxErrorEvent_tsx_get(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::TxErrorEvent *arg1 = (pj::TxErrorEvent *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  pj::SipTransaction *result = 0 ;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__TxErrorEvent, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "TxErrorEvent_tsx_get" "', argument " "1"" of type '" "pj::TxErrorEvent *""'"); 
  }
  arg1 = reinterpret_cast< pj::TxErrorEvent * >(argp1);
  result = (pj::SipTransaction *)& ((arg1)->tsx);
  resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(result), SWIGTYPE_p_pj__SipTransaction, 0 |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_new_TxErrorEvent(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::TxErrorEvent *result = 0 ;
  
  if (!SWIG_Python_UnpackTuple(args, "new_TxErrorEvent", 0, 0, 0)) SWIG_fail;
  result = (pj::TxErrorEvent *)new pj::TxErrorEvent();
  resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(result), SWIGTYPE_p_pj__TxErrorEvent, SWIG_POINTER_NEW |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_delete_TxErrorEvent(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::TxErrorEvent *arg1 = (pj::TxErrorEvent *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__TxErrorEvent, SWIG_POINTER_DISOWN |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "delete_TxErrorEvent" "', argument " "1"" of type '" "pj::TxErrorEvent *""'"); 
  }
  arg1 = reinterpret_cast< pj::TxErrorEvent * >(argp1);
  delete arg1;
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *TxErrorEvent_swigregister(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *obj;
  if (!SWIG_Python_UnpackTuple(args, "swigregister", 1, 1, &obj)) return NULL;
  SWIG_TypeNewClientData(SWIGTYPE_p_pj__TxErrorEvent, SWIG_NewClientData(obj));
  return SWIG_Py_Void();
}

SWIGINTERN PyObject *TxErrorEvent_swiginit(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  return SWIG_Python_InitShadowInstance(args);
}

SWIGINTERN PyObject *_wrap_RxMsgEvent_rdata_set(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::RxMsgEvent *arg1 = (pj::RxMsgEvent *) 0 ;
  pj::SipRxData *arg2 = (pj::SipRxData *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  void *argp2 = 0 ;
  int res2 = 0 ;
  PyObject *swig_obj[2] ;
  
  if (!SWIG_Python_UnpackTuple(args, "RxMsgEvent_rdata_set", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__RxMsgEvent, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "RxMsgEvent_rdata_set" "', argument " "1"" of type '" "pj::RxMsgEvent *""'"); 
  }
  arg1 = reinterpret_cast< pj::RxMsgEvent * >(argp1);
  res2 = SWIG_ConvertPtr(swig_obj[1], &argp2,SWIGTYPE_p_pj__SipRxData, 0 |  0 );
  if (!SWIG_IsOK(res2)) {
    SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "RxMsgEvent_rdata_set" "', argument " "2"" of type '" "pj::SipRxData *""'"); 
  }
  arg2 = reinterpret_cast< pj::SipRxData * >(argp2);
  if (arg1) (arg1)->rdata = *arg2;
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_RxMsgEvent_rdata_get(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::RxMsgEvent *arg1 = (pj::RxMsgEvent *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  pj::SipRxData *result = 0 ;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__RxMsgEvent, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "RxMsgEvent_rdata_get" "', argument " "1"" of type '" "pj::RxMsgEvent *""'"); 
  }
  arg1 = reinterpret_cast< pj::RxMsgEvent * >(argp1);
  result = (pj::SipRxData *)& ((arg1)->rdata);
  resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(result), SWIGTYPE_p_pj__SipRxData, 0 |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_new_RxMsgEvent(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::RxMsgEvent *result = 0 ;
  
  if (!SWIG_Python_UnpackTuple(args, "new_RxMsgEvent", 0, 0, 0)) SWIG_fail;
  result = (pj::RxMsgEvent *)new pj::RxMsgEvent();
  resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(result), SWIGTYPE_p_pj__RxMsgEvent, SWIG_POINTER_NEW |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_delete_RxMsgEvent(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::RxMsgEvent *arg1 = (pj::RxMsgEvent *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__RxMsgEvent, SWIG_POINTER_DISOWN |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "delete_RxMsgEvent" "', argument " "1"" of type '" "pj::RxMsgEvent *""'"); 
  }
  arg1 = reinterpret_cast< pj::RxMsgEvent * >(argp1);
  delete arg1;
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *RxMsgEvent_swigregister(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *obj;
  if (!SWIG_Python_UnpackTuple(args, "swigregister", 1, 1, &obj)) return NULL;
  SWIG_TypeNewClientData(SWIGTYPE_p_pj__RxMsgEvent, SWIG_NewClientData(obj));
  return SWIG_Py_Void();
}

SWIGINTERN PyObject *RxMsgEvent_swiginit(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  return SWIG_Python_InitShadowInstance(args);
}

SWIGINTERN PyObject *_wrap_UserEvent_user1_set(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::UserEvent *arg1 = (pj::UserEvent *) 0 ;
  pj::GenericData arg2 = (pj::GenericData) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  int res2 ;
  PyObject *swig_obj[2] ;
  
  if (!SWIG_Python_UnpackTuple(args, "UserEvent_user1_set", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__UserEvent, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "UserEvent_user1_set" "', argument " "1"" of type '" "pj::UserEvent *""'"); 
  }
  arg1 = reinterpret_cast< pj::UserEvent * >(argp1);
  res2 = SWIG_ConvertPtr(swig_obj[1],SWIG_as_voidptrptr(&arg2), 0, SWIG_POINTER_DISOWN);
  if (!SWIG_IsOK(res2)) {
    SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "UserEvent_user1_set" "', argument " "2"" of type '" "pj::GenericData""'"); 
  }
  if (arg1) (arg1)->user1 = arg2;
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_UserEvent_user1_get(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::UserEvent *arg1 = (pj::UserEvent *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  pj::GenericData result;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__UserEvent, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "UserEvent_user1_get" "', argument " "1"" of type '" "pj::UserEvent *""'"); 
  }
  arg1 = reinterpret_cast< pj::UserEvent * >(argp1);
  result = (pj::GenericData) ((arg1)->user1);
  resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(result), SWIGTYPE_p_void, 0 |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_UserEvent_user2_set(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::UserEvent *arg1 = (pj::UserEvent *) 0 ;
  pj::GenericData arg2 = (pj::GenericData) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  int res2 ;
  PyObject *swig_obj[2] ;
  
  if (!SWIG_Python_UnpackTuple(args, "UserEvent_user2_set", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__UserEvent, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "UserEvent_user2_set" "', argument " "1"" of type '" "pj::UserEvent *""'"); 
  }
  arg1 = reinterpret_cast< pj::UserEvent * >(argp1);
  res2 = SWIG_ConvertPtr(swig_obj[1],SWIG_as_voidptrptr(&arg2), 0, SWIG_POINTER_DISOWN);
  if (!SWIG_IsOK(res2)) {
    SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "UserEvent_user2_set" "', argument " "2"" of type '" "pj::GenericData""'"); 
  }
  if (arg1) (arg1)->user2 = arg2;
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_UserEvent_user2_get(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::UserEvent *arg1 = (pj::UserEvent *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  pj::GenericData result;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__UserEvent, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "UserEvent_user2_get" "', argument " "1"" of type '" "pj::UserEvent *""'"); 
  }
  arg1 = reinterpret_cast< pj::UserEvent * >(argp1);
  result = (pj::GenericData) ((arg1)->user2);
  resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(result), SWIGTYPE_p_void, 0 |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_UserEvent_user3_set(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::UserEvent *arg1 = (pj::UserEvent *) 0 ;
  pj::GenericData arg2 = (pj::GenericData) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  int res2 ;
  PyObject *swig_obj[2] ;
  
  if (!SWIG_Python_UnpackTuple(args, "UserEvent_user3_set", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__UserEvent, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "UserEvent_user3_set" "', argument " "1"" of type '" "pj::UserEvent *""'"); 
  }
  arg1 = reinterpret_cast< pj::UserEvent * >(argp1);
  res2 = SWIG_ConvertPtr(swig_obj[1],SWIG_as_voidptrptr(&arg2), 0, SWIG_POINTER_DISOWN);
  if (!SWIG_IsOK(res2)) {
    SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "UserEvent_user3_set" "', argument " "2"" of type '" "pj::GenericData""'"); 
  }
  if (arg1) (arg1)->user3 = arg2;
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_UserEvent_user3_get(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::UserEvent *arg1 = (pj::UserEvent *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  pj::GenericData result;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__UserEvent, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "UserEvent_user3_get" "', argument " "1"" of type '" "pj::UserEvent *""'"); 
  }
  arg1 = reinterpret_cast< pj::UserEvent * >(argp1);
  result = (pj::GenericData) ((arg1)->user3);
  resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(result), SWIGTYPE_p_void, 0 |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_UserEvent_user4_set(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::UserEvent *arg1 = (pj::UserEvent *) 0 ;
  pj::GenericData arg2 = (pj::GenericData) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  int res2 ;
  PyObject *swig_obj[2] ;
  
  if (!SWIG_Python_UnpackTuple(args, "UserEvent_user4_set", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__UserEvent, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "UserEvent_user4_set" "', argument " "1"" of type '" "pj::UserEvent *""'"); 
  }
  arg1 = reinterpret_cast< pj::UserEvent * >(argp1);
  res2 = SWIG_ConvertPtr(swig_obj[1],SWIG_as_voidptrptr(&arg2), 0, SWIG_POINTER_DISOWN);
  if (!SWIG_IsOK(res2)) {
    SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "UserEvent_user4_set" "', argument " "2"" of type '" "pj::GenericData""'"); 
  }
  if (arg1) (arg1)->user4 = arg2;
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_UserEvent_user4_get(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::UserEvent *arg1 = (pj::UserEvent *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  pj::GenericData result;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__UserEvent, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "UserEvent_user4_get" "', argument " "1"" of type '" "pj::UserEvent *""'"); 
  }
  arg1 = reinterpret_cast< pj::UserEvent * >(argp1);
  result = (pj::GenericData) ((arg1)->user4);
  resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(result), SWIGTYPE_p_void, 0 |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_new_UserEvent(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::UserEvent *result = 0 ;
  
  if (!SWIG_Python_UnpackTuple(args, "new_UserEvent", 0, 0, 0)) SWIG_fail;
  result = (pj::UserEvent *)new pj::UserEvent();
  resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(result), SWIGTYPE_p_pj__UserEvent, SWIG_POINTER_NEW |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_delete_UserEvent(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::UserEvent *arg1 = (pj::UserEvent *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__UserEvent, SWIG_POINTER_DISOWN |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "delete_UserEvent" "', argument " "1"" of type '" "pj::UserEvent *""'"); 
  }
  arg1 = reinterpret_cast< pj::UserEvent * >(argp1);
  delete arg1;
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *UserEvent_swigregister(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *obj;
  if (!SWIG_Python_UnpackTuple(args, "swigregister", 1, 1, &obj)) return NULL;
  SWIG_TypeNewClientData(SWIGTYPE_p_pj__UserEvent, SWIG_NewClientData(obj));
  return SWIG_Py_Void();
}

SWIGINTERN PyObject *UserEvent_swiginit(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  return SWIG_Python_InitShadowInstance(args);
}

SWIGINTERN PyObject *_wrap_SipEventBody_timer_set(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::SipEventBody *arg1 = (pj::SipEventBody *) 0 ;
  pj::TimerEvent *arg2 = (pj::TimerEvent *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  void *argp2 = 0 ;
  int res2 = 0 ;
  PyObject *swig_obj[2] ;
  
  if (!SWIG_Python_UnpackTuple(args, "SipEventBody_timer_set", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__SipEventBody, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "SipEventBody_timer_set" "', argument " "1"" of type '" "pj::SipEventBody *""'"); 
  }
  arg1 = reinterpret_cast< pj::SipEventBody * >(argp1);
  res2 = SWIG_ConvertPtr(swig_obj[1], &argp2,SWIGTYPE_p_pj__TimerEvent, 0 |  0 );
  if (!SWIG_IsOK(res2)) {
    SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "SipEventBody_timer_set" "', argument " "2"" of type '" "pj::TimerEvent *""'"); 
  }
  arg2 = reinterpret_cast< pj::TimerEvent * >(argp2);
  if (arg1) (arg1)->timer = *arg2;
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_SipEventBody_timer_get(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::SipEventBody *arg1 = (pj::SipEventBody *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  pj::TimerEvent *result = 0 ;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__SipEventBody, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "SipEventBody_timer_get" "', argument " "1"" of type '" "pj::SipEventBody *""'"); 
  }
  arg1 = reinterpret_cast< pj::SipEventBody * >(argp1);
  result = (pj::TimerEvent *)& ((arg1)->timer);
  resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(result), SWIGTYPE_p_pj__TimerEvent, 0 |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_SipEventBody_tsxState_set(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::SipEventBody *arg1 = (pj::SipEventBody *) 0 ;
  pj::TsxStateEvent *arg2 = (pj::TsxStateEvent *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  void *argp2 = 0 ;
  int res2 = 0 ;
  PyObject *swig_obj[2] ;
  
  if (!SWIG_Python_UnpackTuple(args, "SipEventBody_tsxState_set", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__SipEventBody, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "SipEventBody_tsxState_set" "', argument " "1"" of type '" "pj::SipEventBody *""'"); 
  }
  arg1 = reinterpret_cast< pj::SipEventBody * >(argp1);
  res2 = SWIG_ConvertPtr(swig_obj[1], &argp2,SWIGTYPE_p_pj__TsxStateEvent, 0 |  0 );
  if (!SWIG_IsOK(res2)) {
    SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "SipEventBody_tsxState_set" "', argument " "2"" of type '" "pj::TsxStateEvent *""'"); 
  }
  arg2 = reinterpret_cast< pj::TsxStateEvent * >(argp2);
  if (arg1) (arg1)->tsxState = *arg2;
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_SipEventBody_tsxState_get(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::SipEventBody *arg1 = (pj::SipEventBody *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  pj::TsxStateEvent *result = 0 ;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__SipEventBody, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "SipEventBody_tsxState_get" "', argument " "1"" of type '" "pj::SipEventBody *""'"); 
  }
  arg1 = reinterpret_cast< pj::SipEventBody * >(argp1);
  result = (pj::TsxStateEvent *)& ((arg1)->tsxState);
  resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(result), SWIGTYPE_p_pj__TsxStateEvent, 0 |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_SipEventBody_txMsg_set(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::SipEventBody *arg1 = (pj::SipEventBody *) 0 ;
  pj::TxMsgEvent *arg2 = (pj::TxMsgEvent *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  void *argp2 = 0 ;
  int res2 = 0 ;
  PyObject *swig_obj[2] ;
  
  if (!SWIG_Python_UnpackTuple(args, "SipEventBody_txMsg_set", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__SipEventBody, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "SipEventBody_txMsg_set" "', argument " "1"" of type '" "pj::SipEventBody *""'"); 
  }
  arg1 = reinterpret_cast< pj::SipEventBody * >(argp1);
  res2 = SWIG_ConvertPtr(swig_obj[1], &argp2,SWIGTYPE_p_pj__TxMsgEvent, 0 |  0 );
  if (!SWIG_IsOK(res2)) {
    SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "SipEventBody_txMsg_set" "', argument " "2"" of type '" "pj::TxMsgEvent *""'"); 
  }
  arg2 = reinterpret_cast< pj::TxMsgEvent * >(argp2);
  if (arg1) (arg1)->txMsg = *arg2;
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_SipEventBody_txMsg_get(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::SipEventBody *arg1 = (pj::SipEventBody *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  pj::TxMsgEvent *result = 0 ;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__SipEventBody, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "SipEventBody_txMsg_get" "', argument " "1"" of type '" "pj::SipEventBody *""'"); 
  }
  arg1 = reinterpret_cast< pj::SipEventBody * >(argp1);
  result = (pj::TxMsgEvent *)& ((arg1)->txMsg);
  resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(result), SWIGTYPE_p_pj__TxMsgEvent, 0 |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_SipEventBody_txError_set(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::SipEventBody *arg1 = (pj::SipEventBody *) 0 ;
  pj::TxErrorEvent *arg2 = (pj::TxErrorEvent *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  void *argp2 = 0 ;
  int res2 = 0 ;
  PyObject *swig_obj[2] ;
  
  if (!SWIG_Python_UnpackTuple(args, "SipEventBody_txError_set", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__SipEventBody, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "SipEventBody_txError_set" "', argument " "1"" of type '" "pj::SipEventBody *""'"); 
  }
  arg1 = reinterpret_cast< pj::SipEventBody * >(argp1);
  res2 = SWIG_ConvertPtr(swig_obj[1], &argp2,SWIGTYPE_p_pj__TxErrorEvent, 0 |  0 );
  if (!SWIG_IsOK(res2)) {
    SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "SipEventBody_txError_set" "', argument " "2"" of type '" "pj::TxErrorEvent *""'"); 
  }
  arg2 = reinterpret_cast< pj::TxErrorEvent * >(argp2);
  if (arg1) (arg1)->txError = *arg2;
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_SipEventBody_txError_get(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::SipEventBody *arg1 = (pj::SipEventBody *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  pj::TxErrorEvent *result = 0 ;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__SipEventBody, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "SipEventBody_txError_get" "', argument " "1"" of type '" "pj::SipEventBody *""'"); 
  }
  arg1 = reinterpret_cast< pj::SipEventBody * >(argp1);
  result = (pj::TxErrorEvent *)& ((arg1)->txError);
  resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(result), SWIGTYPE_p_pj__TxErrorEvent, 0 |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_SipEventBody_rxMsg_set(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::SipEventBody *arg1 = (pj::SipEventBody *) 0 ;
  pj::RxMsgEvent *arg2 = (pj::RxMsgEvent *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  void *argp2 = 0 ;
  int res2 = 0 ;
  PyObject *swig_obj[2] ;
  
  if (!SWIG_Python_UnpackTuple(args, "SipEventBody_rxMsg_set", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__SipEventBody, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "SipEventBody_rxMsg_set" "', argument " "1"" of type '" "pj::SipEventBody *""'"); 
  }
  arg1 = reinterpret_cast< pj::SipEventBody * >(argp1);
  res2 = SWIG_ConvertPtr(swig_obj[1], &argp2,SWIGTYPE_p_pj__RxMsgEvent, 0 |  0 );
  if (!SWIG_IsOK(res2)) {
    SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "SipEventBody_rxMsg_set" "', argument " "2"" of type '" "pj::RxMsgEvent *""'"); 
  }
  arg2 = reinterpret_cast< pj::RxMsgEvent * >(argp2);
  if (arg1) (arg1)->rxMsg = *arg2;
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_SipEventBody_rxMsg_get(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::SipEventBody *arg1 = (pj::SipEventBody *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  pj::RxMsgEvent *result = 0 ;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__SipEventBody, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "SipEventBody_rxMsg_get" "', argument " "1"" of type '" "pj::SipEventBody *""'"); 
  }
  arg1 = reinterpret_cast< pj::SipEventBody * >(argp1);
  result = (pj::RxMsgEvent *)& ((arg1)->rxMsg);
  resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(result), SWIGTYPE_p_pj__RxMsgEvent, 0 |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_SipEventBody_user_set(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::SipEventBody *arg1 = (pj::SipEventBody *) 0 ;
  pj::UserEvent *arg2 = (pj::UserEvent *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  void *argp2 = 0 ;
  int res2 = 0 ;
  PyObject *swig_obj[2] ;
  
  if (!SWIG_Python_UnpackTuple(args, "SipEventBody_user_set", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__SipEventBody, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "SipEventBody_user_set" "', argument " "1"" of type '" "pj::SipEventBody *""'"); 
  }
  arg1 = reinterpret_cast< pj::SipEventBody * >(argp1);
  res2 = SWIG_ConvertPtr(swig_obj[1], &argp2,SWIGTYPE_p_pj__UserEvent, 0 |  0 );
  if (!SWIG_IsOK(res2)) {
    SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "SipEventBody_user_set" "', argument " "2"" of type '" "pj::UserEvent *""'"); 
  }
  arg2 = reinterpret_cast< pj::UserEvent * >(argp2);
  if (arg1) (arg1)->user = *arg2;
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_SipEventBody_user_get(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::SipEventBody *arg1 = (pj::SipEventBody *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  pj::UserEvent *result = 0 ;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__SipEventBody, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "SipEventBody_user_get" "', argument " "1"" of type '" "pj::SipEventBody *""'"); 
  }
  arg1 = reinterpret_cast< pj::SipEventBody * >(argp1);
  result = (pj::UserEvent *)& ((arg1)->user);
  resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(result), SWIGTYPE_p_pj__UserEvent, 0 |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_new_SipEventBody(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::SipEventBody *result = 0 ;
  
  if (!SWIG_Python_UnpackTuple(args, "new_SipEventBody", 0, 0, 0)) SWIG_fail;
  result = (pj::SipEventBody *)new pj::SipEventBody();
  resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(result), SWIGTYPE_p_pj__SipEventBody, SWIG_POINTER_NEW |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_delete_SipEventBody(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::SipEventBody *arg1 = (pj::SipEventBody *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__SipEventBody, SWIG_POINTER_DISOWN |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "delete_SipEventBody" "', argument " "1"" of type '" "pj::SipEventBody *""'"); 
  }
  arg1 = reinterpret_cast< pj::SipEventBody * >(argp1);
  delete arg1;
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *SipEventBody_swigregister(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *obj;
  if (!SWIG_Python_UnpackTuple(args, "swigregister", 1, 1, &obj)) return NULL;
  SWIG_TypeNewClientData(SWIGTYPE_p_pj__SipEventBody, SWIG_NewClientData(obj));
  return SWIG_Py_Void();
}

SWIGINTERN PyObject *SipEventBody_swiginit(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  return SWIG_Python_InitShadowInstance(args);
}

SWIGINTERN PyObject *_wrap_SipEvent_type_set(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::SipEvent *arg1 = (pj::SipEvent *) 0 ;
  pjsip_event_id_e arg2 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  int val2 ;
  int ecode2 = 0 ;
  PyObject *swig_obj[2] ;
  
  if (!SWIG_Python_UnpackTuple(args, "SipEvent_type_set", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__SipEvent, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "SipEvent_type_set" "', argument " "1"" of type '" "pj::SipEvent *""'"); 
  }
  arg1 = reinterpret_cast< pj::SipEvent * >(argp1);
  ecode2 = SWIG_AsVal_int(swig_obj[1], &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "SipEvent_type_set" "', argument " "2"" of type '" "pjsip_event_id_e""'");
  } 
  arg2 = static_cast< pjsip_event_id_e >(val2);
  if (arg1) (arg1)->type = arg2;
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_SipEvent_type_get(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::SipEvent *arg1 = (pj::SipEvent *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  pjsip_event_id_e result;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__SipEvent, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "SipEvent_type_get" "', argument " "1"" of type '" "pj::SipEvent *""'"); 
  }
  arg1 = reinterpret_cast< pj::SipEvent * >(argp1);
  result = (pjsip_event_id_e) ((arg1)->type);
  resultobj = SWIG_From_int(static_cast< int >(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_SipEvent_body_set(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::SipEvent *arg1 = (pj::SipEvent *) 0 ;
  pj::SipEventBody *arg2 = (pj::SipEventBody *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  void *argp2 = 0 ;
  int res2 = 0 ;
  PyObject *swig_obj[2] ;
  
  if (!SWIG_Python_UnpackTuple(args, "SipEvent_body_set", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__SipEvent, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "SipEvent_body_set" "', argument " "1"" of type '" "pj::SipEvent *""'"); 
  }
  arg1 = reinterpret_cast< pj::SipEvent * >(argp1);
  res2 = SWIG_ConvertPtr(swig_obj[1], &argp2,SWIGTYPE_p_pj__SipEventBody, 0 |  0 );
  if (!SWIG_IsOK(res2)) {
    SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "SipEvent_body_set" "', argument " "2"" of type '" "pj::SipEventBody *""'"); 
  }
  arg2 = reinterpret_cast< pj::SipEventBody * >(argp2);
  if (arg1) (arg1)->body = *arg2;
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_SipEvent_body_get(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::SipEvent *arg1 = (pj::SipEvent *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  pj::SipEventBody *result = 0 ;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__SipEvent, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "SipEvent_body_get" "', argument " "1"" of type '" "pj::SipEvent *""'"); 
  }
  arg1 = reinterpret_cast< pj::SipEvent * >(argp1);
  result = (pj::SipEventBody *)& ((arg1)->body);
  resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(result), SWIGTYPE_p_pj__SipEventBody, 0 |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_SipEvent_pjEvent_set(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::SipEvent *arg1 = (pj::SipEvent *) 0 ;
  void *arg2 = (void *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  int res2 ;
  PyObject *swig_obj[2] ;
  
  if (!SWIG_Python_UnpackTuple(args, "SipEvent_pjEvent_set", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__SipEvent, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "SipEvent_pjEvent_set" "', argument " "1"" of type '" "pj::SipEvent *""'"); 
  }
  arg1 = reinterpret_cast< pj::SipEvent * >(argp1);
  res2 = SWIG_ConvertPtr(swig_obj[1],SWIG_as_voidptrptr(&arg2), 0, SWIG_POINTER_DISOWN);
  if (!SWIG_IsOK(res2)) {
    SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "SipEvent_pjEvent_set" "', argument " "2"" of type '" "void *""'"); 
  }
  if (arg1) (arg1)->pjEvent = arg2;
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_SipEvent_pjEvent_get(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::SipEvent *arg1 = (pj::SipEvent *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  void *result = 0 ;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__SipEvent, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "SipEvent_pjEvent_get" "', argument " "1"" of type '" "pj::SipEvent *""'"); 
  }
  arg1 = reinterpret_cast< pj::SipEvent * >(argp1);
  result = (void *) ((arg1)->pjEvent);
  resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(result), SWIGTYPE_p_void, 0 |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_new_SipEvent(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::SipEvent *result = 0 ;
  
  if (!SWIG_Python_UnpackTuple(args, "new_SipEvent", 0, 0, 0)) SWIG_fail;
  result = (pj::SipEvent *)new pj::SipEvent();
  resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(result), SWIGTYPE_p_pj__SipEvent, SWIG_POINTER_NEW |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_delete_SipEvent(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::SipEvent *arg1 = (pj::SipEvent *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__SipEvent, SWIG_POINTER_DISOWN |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "delete_SipEvent" "', argument " "1"" of type '" "pj::SipEvent *""'"); 
  }
  arg1 = reinterpret_cast< pj::SipEvent * >(argp1);
  delete arg1;
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *SipEvent_swigregister(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *obj;
  if (!SWIG_Python_UnpackTuple(args, "swigregister", 1, 1, &obj)) return NULL;
  SWIG_TypeNewClientData(SWIGTYPE_p_pj__SipEvent, SWIG_NewClientData(obj));
  return SWIG_Py_Void();
}

SWIGINTERN PyObject *SipEvent_swiginit(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  return SWIG_Python_InitShadowInstance(args);
}

SWIGINTERN PyObject *_wrap_SipMediaType_type_set(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::SipMediaType *arg1 = (pj::SipMediaType *) 0 ;
  pj::string *arg2 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  int res2 = SWIG_OLDOBJ ;
  PyObject *swig_obj[2] ;
  
  if (!SWIG_Python_UnpackTuple(args, "SipMediaType_type_set", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__SipMediaType, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "SipMediaType_type_set" "', argument " "1"" of type '" "pj::SipMediaType *""'"); 
  }
  arg1 = reinterpret_cast< pj::SipMediaType * >(argp1);
  {
    std::string *ptr = (std::string *)0;
    res2 = SWIG_AsPtr_std_string(swig_obj[1], &ptr);
    if (!SWIG_IsOK(res2)) {
      SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "SipMediaType_type_set" "', argument " "2"" of type '" "pj::string const &""'"); 
    }
    if (!ptr) {
      SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "SipMediaType_type_set" "', argument " "2"" of type '" "pj::string const &""'"); 
    }
    arg2 = ptr;
  }
  if (arg1) (arg1)->type = *arg2;
  resultobj = SWIG_Py_Void();
  if (SWIG_IsNewObj(res2)) delete arg2;
  return resultobj;
fail:
  if (SWIG_IsNewObj(res2)) delete arg2;
  return NULL;
}


SWIGINTERN PyObject *_wrap_SipMediaType_type_get(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::SipMediaType *arg1 = (pj::SipMediaType *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  pj::string *result = 0 ;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__SipMediaType, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "SipMediaType_type_get" "', argument " "1"" of type '" "pj::SipMediaType *""'"); 
  }
  arg1 = reinterpret_cast< pj::SipMediaType * >(argp1);
  result = (pj::string *) & ((arg1)->type);
  resultobj = SWIG_From_std_string(static_cast< std::string >(*result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_SipMediaType_subType_set(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::SipMediaType *arg1 = (pj::SipMediaType *) 0 ;
  pj::string *arg2 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  int res2 = SWIG_OLDOBJ ;
  PyObject *swig_obj[2] ;
  
  if (!SWIG_Python_UnpackTuple(args, "SipMediaType_subType_set", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__SipMediaType, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "SipMediaType_subType_set" "', argument " "1"" of type '" "pj::SipMediaType *""'"); 
  }
  arg1 = reinterpret_cast< pj::SipMediaType * >(argp1);
  {
    std::string *ptr = (std::string *)0;
    res2 = SWIG_AsPtr_std_string(swig_obj[1], &ptr);
    if (!SWIG_IsOK(res2)) {
      SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "SipMediaType_subType_set" "', argument " "2"" of type '" "pj::string const &""'"); 
    }
    if (!ptr) {
      SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "SipMediaType_subType_set" "', argument " "2"" of type '" "pj::string const &""'"); 
    }
    arg2 = ptr;
  }
  if (arg1) (arg1)->subType = *arg2;
  resultobj = SWIG_Py_Void();
  if (SWIG_IsNewObj(res2)) delete arg2;
  return resultobj;
fail:
  if (SWIG_IsNewObj(res2)) delete arg2;
  return NULL;
}


SWIGINTERN PyObject *_wrap_SipMediaType_subType_get(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::SipMediaType *arg1 = (pj::SipMediaType *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  pj::string *result = 0 ;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__SipMediaType, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "SipMediaType_subType_get" "', argument " "1"" of type '" "pj::SipMediaType *""'"); 
  }
  arg1 = reinterpret_cast< pj::SipMediaType * >(argp1);
  result = (pj::string *) & ((arg1)->subType);
  resultobj = SWIG_From_std_string(static_cast< std::string >(*result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_new_SipMediaType(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::SipMediaType *result = 0 ;
  
  if (!SWIG_Python_UnpackTuple(args, "new_SipMediaType", 0, 0, 0)) SWIG_fail;
  result = (pj::SipMediaType *)new pj::SipMediaType();
  resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(result), SWIGTYPE_p_pj__SipMediaType, SWIG_POINTER_NEW |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_delete_SipMediaType(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::SipMediaType *arg1 = (pj::SipMediaType *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__SipMediaType, SWIG_POINTER_DISOWN |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "delete_SipMediaType" "', argument " "1"" of type '" "pj::SipMediaType *""'"); 
  }
  arg1 = reinterpret_cast< pj::SipMediaType * >(argp1);
  delete arg1;
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *SipMediaType_swigregister(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *obj;
  if (!SWIG_Python_UnpackTuple(args, "swigregister", 1, 1, &obj)) return NULL;
  SWIG_TypeNewClientData(SWIGTYPE_p_pj__SipMediaType, SWIG_NewClientData(obj));
  return SWIG_Py_Void();
}

SWIGINTERN PyObject *SipMediaType_swiginit(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  return SWIG_Python_InitShadowInstance(args);
}

SWIGINTERN PyObject *_wrap_SipHeader_hName_set(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::SipHeader *arg1 = (pj::SipHeader *) 0 ;
  pj::string *arg2 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  int res2 = SWIG_OLDOBJ ;
  PyObject *swig_obj[2] ;
  
  if (!SWIG_Python_UnpackTuple(args, "SipHeader_hName_set", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__SipHeader, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "SipHeader_hName_set" "', argument " "1"" of type '" "pj::SipHeader *""'"); 
  }
  arg1 = reinterpret_cast< pj::SipHeader * >(argp1);
  {
    std::string *ptr = (std::string *)0;
    res2 = SWIG_AsPtr_std_string(swig_obj[1], &ptr);
    if (!SWIG_IsOK(res2)) {
      SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "SipHeader_hName_set" "', argument " "2"" of type '" "pj::string const &""'"); 
    }
    if (!ptr) {
      SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "SipHeader_hName_set" "', argument " "2"" of type '" "pj::string const &""'"); 
    }
    arg2 = ptr;
  }
  if (arg1) (arg1)->hName = *arg2;
  resultobj = SWIG_Py_Void();
  if (SWIG_IsNewObj(res2)) delete arg2;
  return resultobj;
fail:
  if (SWIG_IsNewObj(res2)) delete arg2;
  return NULL;
}


SWIGINTERN PyObject *_wrap_SipHeader_hName_get(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::SipHeader *arg1 = (pj::SipHeader *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  pj::string *result = 0 ;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__SipHeader, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "SipHeader_hName_get" "', argument " "1"" of type '" "pj::SipHeader *""'"); 
  }
  arg1 = reinterpret_cast< pj::SipHeader * >(argp1);
  result = (pj::string *) & ((arg1)->hName);
  resultobj = SWIG_From_std_string(static_cast< std::string >(*result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_SipHeader_hValue_set(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::SipHeader *arg1 = (pj::SipHeader *) 0 ;
  pj::string *arg2 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  int res2 = SWIG_OLDOBJ ;
  PyObject *swig_obj[2] ;
  
  if (!SWIG_Python_UnpackTuple(args, "SipHeader_hValue_set", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__SipHeader, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "SipHeader_hValue_set" "', argument " "1"" of type '" "pj::SipHeader *""'"); 
  }
  arg1 = reinterpret_cast< pj::SipHeader * >(argp1);
  {
    std::string *ptr = (std::string *)0;
    res2 = SWIG_AsPtr_std_string(swig_obj[1], &ptr);
    if (!SWIG_IsOK(res2)) {
      SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "SipHeader_hValue_set" "', argument " "2"" of type '" "pj::string const &""'"); 
    }
    if (!ptr) {
      SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "SipHeader_hValue_set" "', argument " "2"" of type '" "pj::string const &""'"); 
    }
    arg2 = ptr;
  }
  if (arg1) (arg1)->hValue = *arg2;
  resultobj = SWIG_Py_Void();
  if (SWIG_IsNewObj(res2)) delete arg2;
  return resultobj;
fail:
  if (SWIG_IsNewObj(res2)) delete arg2;
  return NULL;
}


SWIGINTERN PyObject *_wrap_SipHeader_hValue_get(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::SipHeader *arg1 = (pj::SipHeader *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  pj::string *result = 0 ;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__SipHeader, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "SipHeader_hValue_get" "', argument " "1"" of type '" "pj::SipHeader *""'"); 
  }
  arg1 = reinterpret_cast< pj::SipHeader * >(argp1);
  result = (pj::string *) & ((arg1)->hValue);
  resultobj = SWIG_From_std_string(static_cast< std::string >(*result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_new_SipHeader(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::SipHeader *result = 0 ;
  
  if (!SWIG_Python_UnpackTuple(args, "new_SipHeader", 0, 0, 0)) SWIG_fail;
  result = (pj::SipHeader *)new pj::SipHeader();
  resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(result), SWIGTYPE_p_pj__SipHeader, SWIG_POINTER_NEW |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_delete_SipHeader(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::SipHeader *arg1 = (pj::SipHeader *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__SipHeader, SWIG_POINTER_DISOWN |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "delete_SipHeader" "', argument " "1"" of type '" "pj::SipHeader *""'"); 
  }
  arg1 = reinterpret_cast< pj::SipHeader * >(argp1);
  delete arg1;
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *SipHeader_swigregister(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *obj;
  if (!SWIG_Python_UnpackTuple(args, "swigregister", 1, 1, &obj)) return NULL;
  SWIG_TypeNewClientData(SWIGTYPE_p_pj__SipHeader, SWIG_NewClientData(obj));
  return SWIG_Py_Void();
}

SWIGINTERN PyObject *SipHeader_swiginit(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  return SWIG_Python_InitShadowInstance(args);
}

SWIGINTERN PyObject *_wrap_SipMultipartPart_headers_set(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::SipMultipartPart *arg1 = (pj::SipMultipartPart *) 0 ;
  pj::SipHeaderVector *arg2 = (pj::SipHeaderVector *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  void *argp2 = 0 ;
  int res2 = 0 ;
  PyObject *swig_obj[2] ;
  
  if (!SWIG_Python_UnpackTuple(args, "SipMultipartPart_headers_set", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__SipMultipartPart, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "SipMultipartPart_headers_set" "', argument " "1"" of type '" "pj::SipMultipartPart *""'"); 
  }
  arg1 = reinterpret_cast< pj::SipMultipartPart * >(argp1);
  res2 = SWIG_ConvertPtr(swig_obj[1], &argp2,SWIGTYPE_p_std__vectorT_pj__SipHeader_std__allocatorT_pj__SipHeader_t_t, 0 |  0 );
  if (!SWIG_IsOK(res2)) {
    SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "SipMultipartPart_headers_set" "', argument " "2"" of type '" "pj::SipHeaderVector *""'"); 
  }
  arg2 = reinterpret_cast< pj::SipHeaderVector * >(argp2);
  if (arg1) (arg1)->headers = *arg2;
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_SipMultipartPart_headers_get(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::SipMultipartPart *arg1 = (pj::SipMultipartPart *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  pj::SipHeaderVector *result = 0 ;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__SipMultipartPart, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "SipMultipartPart_headers_get" "', argument " "1"" of type '" "pj::SipMultipartPart *""'"); 
  }
  arg1 = reinterpret_cast< pj::SipMultipartPart * >(argp1);
  result = (pj::SipHeaderVector *)& ((arg1)->headers);
  resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(result), SWIGTYPE_p_std__vectorT_pj__SipHeader_std__allocatorT_pj__SipHeader_t_t, 0 |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_SipMultipartPart_contentType_set(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::SipMultipartPart *arg1 = (pj::SipMultipartPart *) 0 ;
  pj::SipMediaType *arg2 = (pj::SipMediaType *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  void *argp2 = 0 ;
  int res2 = 0 ;
  PyObject *swig_obj[2] ;
  
  if (!SWIG_Python_UnpackTuple(args, "SipMultipartPart_contentType_set", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__SipMultipartPart, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "SipMultipartPart_contentType_set" "', argument " "1"" of type '" "pj::SipMultipartPart *""'"); 
  }
  arg1 = reinterpret_cast< pj::SipMultipartPart * >(argp1);
  res2 = SWIG_ConvertPtr(swig_obj[1], &argp2,SWIGTYPE_p_pj__SipMediaType, 0 |  0 );
  if (!SWIG_IsOK(res2)) {
    SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "SipMultipartPart_contentType_set" "', argument " "2"" of type '" "pj::SipMediaType *""'"); 
  }
  arg2 = reinterpret_cast< pj::SipMediaType * >(argp2);
  if (arg1) (arg1)->contentType = *arg2;
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_SipMultipartPart_contentType_get(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::SipMultipartPart *arg1 = (pj::SipMultipartPart *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  pj::SipMediaType *result = 0 ;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__SipMultipartPart, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "SipMultipartPart_contentType_get" "', argument " "1"" of type '" "pj::SipMultipartPart *""'"); 
  }
  arg1 = reinterpret_cast< pj::SipMultipartPart * >(argp1);
  result = (pj::SipMediaType *)& ((arg1)->contentType);
  resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(result), SWIGTYPE_p_pj__SipMediaType, 0 |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_SipMultipartPart_body_set(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::SipMultipartPart *arg1 = (pj::SipMultipartPart *) 0 ;
  pj::string *arg2 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  int res2 = SWIG_OLDOBJ ;
  PyObject *swig_obj[2] ;
  
  if (!SWIG_Python_UnpackTuple(args, "SipMultipartPart_body_set", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__SipMultipartPart, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "SipMultipartPart_body_set" "', argument " "1"" of type '" "pj::SipMultipartPart *""'"); 
  }
  arg1 = reinterpret_cast< pj::SipMultipartPart * >(argp1);
  {
    std::string *ptr = (std::string *)0;
    res2 = SWIG_AsPtr_std_string(swig_obj[1], &ptr);
    if (!SWIG_IsOK(res2)) {
      SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "SipMultipartPart_body_set" "', argument " "2"" of type '" "pj::string const &""'"); 
    }
    if (!ptr) {
      SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "SipMultipartPart_body_set" "', argument " "2"" of type '" "pj::string const &""'"); 
    }
    arg2 = ptr;
  }
  if (arg1) (arg1)->body = *arg2;
  resultobj = SWIG_Py_Void();
  if (SWIG_IsNewObj(res2)) delete arg2;
  return resultobj;
fail:
  if (SWIG_IsNewObj(res2)) delete arg2;
  return NULL;
}


SWIGINTERN PyObject *_wrap_SipMultipartPart_body_get(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::SipMultipartPart *arg1 = (pj::SipMultipartPart *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  pj::string *result = 0 ;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__SipMultipartPart, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "SipMultipartPart_body_get" "', argument " "1"" of type '" "pj::SipMultipartPart *""'"); 
  }
  arg1 = reinterpret_cast< pj::SipMultipartPart * >(argp1);
  result = (pj::string *) & ((arg1)->body);
  resultobj = SWIG_From_std_string(static_cast< std::string >(*result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_new_SipMultipartPart(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::SipMultipartPart *result = 0 ;
  
  if (!SWIG_Python_UnpackTuple(args, "new_SipMultipartPart", 0, 0, 0)) SWIG_fail;
  result = (pj::SipMultipartPart *)new pj::SipMultipartPart();
  resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(result), SWIGTYPE_p_pj__SipMultipartPart, SWIG_POINTER_NEW |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_delete_SipMultipartPart(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::SipMultipartPart *arg1 = (pj::SipMultipartPart *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__SipMultipartPart, SWIG_POINTER_DISOWN |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "delete_SipMultipartPart" "', argument " "1"" of type '" "pj::SipMultipartPart *""'"); 
  }
  arg1 = reinterpret_cast< pj::SipMultipartPart * >(argp1);
  delete arg1;
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *SipMultipartPart_swigregister(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *obj;
  if (!SWIG_Python_UnpackTuple(args, "swigregister", 1, 1, &obj)) return NULL;
  SWIG_TypeNewClientData(SWIGTYPE_p_pj__SipMultipartPart, SWIG_NewClientData(obj));
  return SWIG_Py_Void();
}

SWIGINTERN PyObject *SipMultipartPart_swiginit(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  return SWIG_Python_InitShadowInstance(args);
}

SWIGINTERN PyObject *_wrap_SipTxOption_targetUri_set(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::SipTxOption *arg1 = (pj::SipTxOption *) 0 ;
  pj::string *arg2 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  int res2 = SWIG_OLDOBJ ;
  PyObject *swig_obj[2] ;
  
  if (!SWIG_Python_UnpackTuple(args, "SipTxOption_targetUri_set", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__SipTxOption, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "SipTxOption_targetUri_set" "', argument " "1"" of type '" "pj::SipTxOption *""'"); 
  }
  arg1 = reinterpret_cast< pj::SipTxOption * >(argp1);
  {
    std::string *ptr = (std::string *)0;
    res2 = SWIG_AsPtr_std_string(swig_obj[1], &ptr);
    if (!SWIG_IsOK(res2)) {
      SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "SipTxOption_targetUri_set" "', argument " "2"" of type '" "pj::string const &""'"); 
    }
    if (!ptr) {
      SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "SipTxOption_targetUri_set" "', argument " "2"" of type '" "pj::string const &""'"); 
    }
    arg2 = ptr;
  }
  if (arg1) (arg1)->targetUri = *arg2;
  resultobj = SWIG_Py_Void();
  if (SWIG_IsNewObj(res2)) delete arg2;
  return resultobj;
fail:
  if (SWIG_IsNewObj(res2)) delete arg2;
  return NULL;
}


SWIGINTERN PyObject *_wrap_SipTxOption_targetUri_get(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::SipTxOption *arg1 = (pj::SipTxOption *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  pj::string *result = 0 ;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__SipTxOption, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "SipTxOption_targetUri_get" "', argument " "1"" of type '" "pj::SipTxOption *""'"); 
  }
  arg1 = reinterpret_cast< pj::SipTxOption * >(argp1);
  result = (pj::string *) & ((arg1)->targetUri);
  resultobj = SWIG_From_std_string(static_cast< std::string >(*result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_SipTxOption_headers_set(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::SipTxOption *arg1 = (pj::SipTxOption *) 0 ;
  pj::SipHeaderVector *arg2 = (pj::SipHeaderVector *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  void *argp2 = 0 ;
  int res2 = 0 ;
  PyObject *swig_obj[2] ;
  
  if (!SWIG_Python_UnpackTuple(args, "SipTxOption_headers_set", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__SipTxOption, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "SipTxOption_headers_set" "', argument " "1"" of type '" "pj::SipTxOption *""'"); 
  }
  arg1 = reinterpret_cast< pj::SipTxOption * >(argp1);
  res2 = SWIG_ConvertPtr(swig_obj[1], &argp2,SWIGTYPE_p_std__vectorT_pj__SipHeader_std__allocatorT_pj__SipHeader_t_t, 0 |  0 );
  if (!SWIG_IsOK(res2)) {
    SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "SipTxOption_headers_set" "', argument " "2"" of type '" "pj::SipHeaderVector *""'"); 
  }
  arg2 = reinterpret_cast< pj::SipHeaderVector * >(argp2);
  if (arg1) (arg1)->headers = *arg2;
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_SipTxOption_headers_get(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::SipTxOption *arg1 = (pj::SipTxOption *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  pj::SipHeaderVector *result = 0 ;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__SipTxOption, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "SipTxOption_headers_get" "', argument " "1"" of type '" "pj::SipTxOption *""'"); 
  }
  arg1 = reinterpret_cast< pj::SipTxOption * >(argp1);
  result = (pj::SipHeaderVector *)& ((arg1)->headers);
  resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(result), SWIGTYPE_p_std__vectorT_pj__SipHeader_std__allocatorT_pj__SipHeader_t_t, 0 |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_SipTxOption_contentType_set(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::SipTxOption *arg1 = (pj::SipTxOption *) 0 ;
  pj::string *arg2 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  int res2 = SWIG_OLDOBJ ;
  PyObject *swig_obj[2] ;
  
  if (!SWIG_Python_UnpackTuple(args, "SipTxOption_contentType_set", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__SipTxOption, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "SipTxOption_contentType_set" "', argument " "1"" of type '" "pj::SipTxOption *""'"); 
  }
  arg1 = reinterpret_cast< pj::SipTxOption * >(argp1);
  {
    std::string *ptr = (std::string *)0;
    res2 = SWIG_AsPtr_std_string(swig_obj[1], &ptr);
    if (!SWIG_IsOK(res2)) {
      SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "SipTxOption_contentType_set" "', argument " "2"" of type '" "pj::string const &""'"); 
    }
    if (!ptr) {
      SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "SipTxOption_contentType_set" "', argument " "2"" of type '" "pj::string const &""'"); 
    }
    arg2 = ptr;
  }
  if (arg1) (arg1)->contentType = *arg2;
  resultobj = SWIG_Py_Void();
  if (SWIG_IsNewObj(res2)) delete arg2;
  return resultobj;
fail:
  if (SWIG_IsNewObj(res2)) delete arg2;
  return NULL;
}


SWIGINTERN PyObject *_wrap_SipTxOption_contentType_get(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::SipTxOption *arg1 = (pj::SipTxOption *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  pj::string *result = 0 ;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__SipTxOption, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "SipTxOption_contentType_get" "', argument " "1"" of type '" "pj::SipTxOption *""'"); 
  }
  arg1 = reinterpret_cast< pj::SipTxOption * >(argp1);
  result = (pj::string *) & ((arg1)->contentType);
  resultobj = SWIG_From_std_string(static_cast< std::string >(*result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_SipTxOption_msgBody_set(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::SipTxOption *arg1 = (pj::SipTxOption *) 0 ;
  pj::string *arg2 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  int res2 = SWIG_OLDOBJ ;
  PyObject *swig_obj[2] ;
  
  if (!SWIG_Python_UnpackTuple(args, "SipTxOption_msgBody_set", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__SipTxOption, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "SipTxOption_msgBody_set" "', argument " "1"" of type '" "pj::SipTxOption *""'"); 
  }
  arg1 = reinterpret_cast< pj::SipTxOption * >(argp1);
  {
    std::string *ptr = (std::string *)0;
    res2 = SWIG_AsPtr_std_string(swig_obj[1], &ptr);
    if (!SWIG_IsOK(res2)) {
      SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "SipTxOption_msgBody_set" "', argument " "2"" of type '" "pj::string const &""'"); 
    }
    if (!ptr) {
      SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "SipTxOption_msgBody_set" "', argument " "2"" of type '" "pj::string const &""'"); 
    }
    arg2 = ptr;
  }
  if (arg1) (arg1)->msgBody = *arg2;
  resultobj = SWIG_Py_Void();
  if (SWIG_IsNewObj(res2)) delete arg2;
  return resultobj;
fail:
  if (SWIG_IsNewObj(res2)) delete arg2;
  return NULL;
}


SWIGINTERN PyObject *_wrap_SipTxOption_msgBody_get(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::SipTxOption *arg1 = (pj::SipTxOption *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  pj::string *result = 0 ;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__SipTxOption, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "SipTxOption_msgBody_get" "', argument " "1"" of type '" "pj::SipTxOption *""'"); 
  }
  arg1 = reinterpret_cast< pj::SipTxOption * >(argp1);
  result = (pj::string *) & ((arg1)->msgBody);
  resultobj = SWIG_From_std_string(static_cast< std::string >(*result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_SipTxOption_multipartContentType_set(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::SipTxOption *arg1 = (pj::SipTxOption *) 0 ;
  pj::SipMediaType *arg2 = (pj::SipMediaType *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  void *argp2 = 0 ;
  int res2 = 0 ;
  PyObject *swig_obj[2] ;
  
  if (!SWIG_Python_UnpackTuple(args, "SipTxOption_multipartContentType_set", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__SipTxOption, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "SipTxOption_multipartContentType_set" "', argument " "1"" of type '" "pj::SipTxOption *""'"); 
  }
  arg1 = reinterpret_cast< pj::SipTxOption * >(argp1);
  res2 = SWIG_ConvertPtr(swig_obj[1], &argp2,SWIGTYPE_p_pj__SipMediaType, 0 |  0 );
  if (!SWIG_IsOK(res2)) {
    SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "SipTxOption_multipartContentType_set" "', argument " "2"" of type '" "pj::SipMediaType *""'"); 
  }
  arg2 = reinterpret_cast< pj::SipMediaType * >(argp2);
  if (arg1) (arg1)->multipartContentType = *arg2;
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_SipTxOption_multipartContentType_get(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::SipTxOption *arg1 = (pj::SipTxOption *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  pj::SipMediaType *result = 0 ;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__SipTxOption, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "SipTxOption_multipartContentType_get" "', argument " "1"" of type '" "pj::SipTxOption *""'"); 
  }
  arg1 = reinterpret_cast< pj::SipTxOption * >(argp1);
  result = (pj::SipMediaType *)& ((arg1)->multipartContentType);
  resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(result), SWIGTYPE_p_pj__SipMediaType, 0 |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_SipTxOption_multipartParts_set(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::SipTxOption *arg1 = (pj::SipTxOption *) 0 ;
  pj::SipMultipartPartVector *arg2 = (pj::SipMultipartPartVector *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  void *argp2 = 0 ;
  int res2 = 0 ;
  PyObject *swig_obj[2] ;
  
  if (!SWIG_Python_UnpackTuple(args, "SipTxOption_multipartParts_set", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__SipTxOption, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "SipTxOption_multipartParts_set" "', argument " "1"" of type '" "pj::SipTxOption *""'"); 
  }
  arg1 = reinterpret_cast< pj::SipTxOption * >(argp1);
  res2 = SWIG_ConvertPtr(swig_obj[1], &argp2,SWIGTYPE_p_std__vectorT_pj__SipMultipartPart_std__allocatorT_pj__SipMultipartPart_t_t, 0 |  0 );
  if (!SWIG_IsOK(res2)) {
    SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "SipTxOption_multipartParts_set" "', argument " "2"" of type '" "pj::SipMultipartPartVector *""'"); 
  }
  arg2 = reinterpret_cast< pj::SipMultipartPartVector * >(argp2);
  if (arg1) (arg1)->multipartParts = *arg2;
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_SipTxOption_multipartParts_get(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::SipTxOption *arg1 = (pj::SipTxOption *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  pj::SipMultipartPartVector *result = 0 ;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__SipTxOption, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "SipTxOption_multipartParts_get" "', argument " "1"" of type '" "pj::SipTxOption *""'"); 
  }
  arg1 = reinterpret_cast< pj::SipTxOption * >(argp1);
  result = (pj::SipMultipartPartVector *)& ((arg1)->multipartParts);
  resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(result), SWIGTYPE_p_std__vectorT_pj__SipMultipartPart_std__allocatorT_pj__SipMultipartPart_t_t, 0 |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_SipTxOption_isEmpty(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::SipTxOption *arg1 = (pj::SipTxOption *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  bool result;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__SipTxOption, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "SipTxOption_isEmpty" "', argument " "1"" of type '" "pj::SipTxOption const *""'"); 
  }
  arg1 = reinterpret_cast< pj::SipTxOption * >(argp1);
  result = (bool)((pj::SipTxOption const *)arg1)->isEmpty();
  resultobj = SWIG_From_bool(static_cast< bool >(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_new_SipTxOption(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::SipTxOption *result = 0 ;
  
  if (!SWIG_Python_UnpackTuple(args, "new_SipTxOption", 0, 0, 0)) SWIG_fail;
  result = (pj::SipTxOption *)new pj::SipTxOption();
  resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(result), SWIGTYPE_p_pj__SipTxOption, SWIG_POINTER_NEW |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_delete_SipTxOption(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::SipTxOption *arg1 = (pj::SipTxOption *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__SipTxOption, SWIG_POINTER_DISOWN |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "delete_SipTxOption" "', argument " "1"" of type '" "pj::SipTxOption *""'"); 
  }
  arg1 = reinterpret_cast< pj::SipTxOption * >(argp1);
  delete arg1;
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *SipTxOption_swigregister(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *obj;
  if (!SWIG_Python_UnpackTuple(args, "swigregister", 1, 1, &obj)) return NULL;
  SWIG_TypeNewClientData(SWIGTYPE_p_pj__SipTxOption, SWIG_NewClientData(obj));
  return SWIG_Py_Void();
}

SWIGINTERN PyObject *SipTxOption_swiginit(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  return SWIG_Python_InitShadowInstance(args);
}

SWIGINTERN PyObject *_wrap_SendInstantMessageParam_contentType_set(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::SendInstantMessageParam *arg1 = (pj::SendInstantMessageParam *) 0 ;
  pj::string *arg2 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  int res2 = SWIG_OLDOBJ ;
  PyObject *swig_obj[2] ;
  
  if (!SWIG_Python_UnpackTuple(args, "SendInstantMessageParam_contentType_set", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__SendInstantMessageParam, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "SendInstantMessageParam_contentType_set" "', argument " "1"" of type '" "pj::SendInstantMessageParam *""'"); 
  }
  arg1 = reinterpret_cast< pj::SendInstantMessageParam * >(argp1);
  {
    std::string *ptr = (std::string *)0;
    res2 = SWIG_AsPtr_std_string(swig_obj[1], &ptr);
    if (!SWIG_IsOK(res2)) {
      SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "SendInstantMessageParam_contentType_set" "', argument " "2"" of type '" "pj::string const &""'"); 
    }
    if (!ptr) {
      SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "SendInstantMessageParam_contentType_set" "', argument " "2"" of type '" "pj::string const &""'"); 
    }
    arg2 = ptr;
  }
  if (arg1) (arg1)->contentType = *arg2;
  resultobj = SWIG_Py_Void();
  if (SWIG_IsNewObj(res2)) delete arg2;
  return resultobj;
fail:
  if (SWIG_IsNewObj(res2)) delete arg2;
  return NULL;
}


SWIGINTERN PyObject *_wrap_SendInstantMessageParam_contentType_get(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::SendInstantMessageParam *arg1 = (pj::SendInstantMessageParam *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  pj::string *result = 0 ;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__SendInstantMessageParam, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "SendInstantMessageParam_contentType_get" "', argument " "1"" of type '" "pj::SendInstantMessageParam *""'"); 
  }
  arg1 = reinterpret_cast< pj::SendInstantMessageParam * >(argp1);
  result = (pj::string *) & ((arg1)->contentType);
  resultobj = SWIG_From_std_string(static_cast< std::string >(*result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_SendInstantMessageParam_content_set(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::SendInstantMessageParam *arg1 = (pj::SendInstantMessageParam *) 0 ;
  pj::string *arg2 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  int res2 = SWIG_OLDOBJ ;
  PyObject *swig_obj[2] ;
  
  if (!SWIG_Python_UnpackTuple(args, "SendInstantMessageParam_content_set", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__SendInstantMessageParam, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "SendInstantMessageParam_content_set" "', argument " "1"" of type '" "pj::SendInstantMessageParam *""'"); 
  }
  arg1 = reinterpret_cast< pj::SendInstantMessageParam * >(argp1);
  {
    std::string *ptr = (std::string *)0;
    res2 = SWIG_AsPtr_std_string(swig_obj[1], &ptr);
    if (!SWIG_IsOK(res2)) {
      SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "SendInstantMessageParam_content_set" "', argument " "2"" of type '" "pj::string const &""'"); 
    }
    if (!ptr) {
      SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "SendInstantMessageParam_content_set" "', argument " "2"" of type '" "pj::string const &""'"); 
    }
    arg2 = ptr;
  }
  if (arg1) (arg1)->content = *arg2;
  resultobj = SWIG_Py_Void();
  if (SWIG_IsNewObj(res2)) delete arg2;
  return resultobj;
fail:
  if (SWIG_IsNewObj(res2)) delete arg2;
  return NULL;
}


SWIGINTERN PyObject *_wrap_SendInstantMessageParam_content_get(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::SendInstantMessageParam *arg1 = (pj::SendInstantMessageParam *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  pj::string *result = 0 ;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__SendInstantMessageParam, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "SendInstantMessageParam_content_get" "', argument " "1"" of type '" "pj::SendInstantMessageParam *""'"); 
  }
  arg1 = reinterpret_cast< pj::SendInstantMessageParam * >(argp1);
  result = (pj::string *) & ((arg1)->content);
  resultobj = SWIG_From_std_string(static_cast< std::string >(*result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_SendInstantMessageParam_txOption_set(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::SendInstantMessageParam *arg1 = (pj::SendInstantMessageParam *) 0 ;
  pj::SipTxOption *arg2 = (pj::SipTxOption *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  void *argp2 = 0 ;
  int res2 = 0 ;
  PyObject *swig_obj[2] ;
  
  if (!SWIG_Python_UnpackTuple(args, "SendInstantMessageParam_txOption_set", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__SendInstantMessageParam, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "SendInstantMessageParam_txOption_set" "', argument " "1"" of type '" "pj::SendInstantMessageParam *""'"); 
  }
  arg1 = reinterpret_cast< pj::SendInstantMessageParam * >(argp1);
  res2 = SWIG_ConvertPtr(swig_obj[1], &argp2,SWIGTYPE_p_pj__SipTxOption, 0 |  0 );
  if (!SWIG_IsOK(res2)) {
    SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "SendInstantMessageParam_txOption_set" "', argument " "2"" of type '" "pj::SipTxOption *""'"); 
  }
  arg2 = reinterpret_cast< pj::SipTxOption * >(argp2);
  if (arg1) (arg1)->txOption = *arg2;
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_SendInstantMessageParam_txOption_get(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::SendInstantMessageParam *arg1 = (pj::SendInstantMessageParam *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  pj::SipTxOption *result = 0 ;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__SendInstantMessageParam, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "SendInstantMessageParam_txOption_get" "', argument " "1"" of type '" "pj::SendInstantMessageParam *""'"); 
  }
  arg1 = reinterpret_cast< pj::SendInstantMessageParam * >(argp1);
  result = (pj::SipTxOption *)& ((arg1)->txOption);
  resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(result), SWIGTYPE_p_pj__SipTxOption, 0 |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_SendInstantMessageParam_userData_set(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::SendInstantMessageParam *arg1 = (pj::SendInstantMessageParam *) 0 ;
  pj::Token arg2 = (pj::Token) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  int res2 ;
  PyObject *swig_obj[2] ;
  
  if (!SWIG_Python_UnpackTuple(args, "SendInstantMessageParam_userData_set", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__SendInstantMessageParam, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "SendInstantMessageParam_userData_set" "', argument " "1"" of type '" "pj::SendInstantMessageParam *""'"); 
  }
  arg1 = reinterpret_cast< pj::SendInstantMessageParam * >(argp1);
  res2 = SWIG_ConvertPtr(swig_obj[1],SWIG_as_voidptrptr(&arg2), 0, SWIG_POINTER_DISOWN);
  if (!SWIG_IsOK(res2)) {
    SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "SendInstantMessageParam_userData_set" "', argument " "2"" of type '" "pj::Token""'"); 
  }
  if (arg1) (arg1)->userData = arg2;
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_SendInstantMessageParam_userData_get(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::SendInstantMessageParam *arg1 = (pj::SendInstantMessageParam *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  pj::Token result;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__SendInstantMessageParam, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "SendInstantMessageParam_userData_get" "', argument " "1"" of type '" "pj::SendInstantMessageParam *""'"); 
  }
  arg1 = reinterpret_cast< pj::SendInstantMessageParam * >(argp1);
  result = (pj::Token) ((arg1)->userData);
  resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(result), SWIGTYPE_p_void, 0 |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_new_SendInstantMessageParam(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::SendInstantMessageParam *result = 0 ;
  
  if (!SWIG_Python_UnpackTuple(args, "new_SendInstantMessageParam", 0, 0, 0)) SWIG_fail;
  result = (pj::SendInstantMessageParam *)new pj::SendInstantMessageParam();
  resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(result), SWIGTYPE_p_pj__SendInstantMessageParam, SWIG_POINTER_NEW |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_delete_SendInstantMessageParam(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::SendInstantMessageParam *arg1 = (pj::SendInstantMessageParam *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__SendInstantMessageParam, SWIG_POINTER_DISOWN |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "delete_SendInstantMessageParam" "', argument " "1"" of type '" "pj::SendInstantMessageParam *""'"); 
  }
  arg1 = reinterpret_cast< pj::SendInstantMessageParam * >(argp1);
  delete arg1;
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *SendInstantMessageParam_swigregister(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *obj;
  if (!SWIG_Python_UnpackTuple(args, "swigregister", 1, 1, &obj)) return NULL;
  SWIG_TypeNewClientData(SWIGTYPE_p_pj__SendInstantMessageParam, SWIG_NewClientData(obj));
  return SWIG_Py_Void();
}

SWIGINTERN PyObject *SendInstantMessageParam_swiginit(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  return SWIG_Python_InitShadowInstance(args);
}

SWIGINTERN PyObject *_wrap_SendTypingIndicationParam_isTyping_set(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::SendTypingIndicationParam *arg1 = (pj::SendTypingIndicationParam *) 0 ;
  bool arg2 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  bool val2 ;
  int ecode2 = 0 ;
  PyObject *swig_obj[2] ;
  
  if (!SWIG_Python_UnpackTuple(args, "SendTypingIndicationParam_isTyping_set", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__SendTypingIndicationParam, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "SendTypingIndicationParam_isTyping_set" "', argument " "1"" of type '" "pj::SendTypingIndicationParam *""'"); 
  }
  arg1 = reinterpret_cast< pj::SendTypingIndicationParam * >(argp1);
  ecode2 = SWIG_AsVal_bool(swig_obj[1], &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "SendTypingIndicationParam_isTyping_set" "', argument " "2"" of type '" "bool""'");
  } 
  arg2 = static_cast< bool >(val2);
  if (arg1) (arg1)->isTyping = arg2;
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_SendTypingIndicationParam_isTyping_get(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::SendTypingIndicationParam *arg1 = (pj::SendTypingIndicationParam *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  bool result;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__SendTypingIndicationParam, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "SendTypingIndicationParam_isTyping_get" "', argument " "1"" of type '" "pj::SendTypingIndicationParam *""'"); 
  }
  arg1 = reinterpret_cast< pj::SendTypingIndicationParam * >(argp1);
  result = (bool) ((arg1)->isTyping);
  resultobj = SWIG_From_bool(static_cast< bool >(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_SendTypingIndicationParam_txOption_set(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::SendTypingIndicationParam *arg1 = (pj::SendTypingIndicationParam *) 0 ;
  pj::SipTxOption *arg2 = (pj::SipTxOption *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  void *argp2 = 0 ;
  int res2 = 0 ;
  PyObject *swig_obj[2] ;
  
  if (!SWIG_Python_UnpackTuple(args, "SendTypingIndicationParam_txOption_set", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__SendTypingIndicationParam, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "SendTypingIndicationParam_txOption_set" "', argument " "1"" of type '" "pj::SendTypingIndicationParam *""'"); 
  }
  arg1 = reinterpret_cast< pj::SendTypingIndicationParam * >(argp1);
  res2 = SWIG_ConvertPtr(swig_obj[1], &argp2,SWIGTYPE_p_pj__SipTxOption, 0 |  0 );
  if (!SWIG_IsOK(res2)) {
    SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "SendTypingIndicationParam_txOption_set" "', argument " "2"" of type '" "pj::SipTxOption *""'"); 
  }
  arg2 = reinterpret_cast< pj::SipTxOption * >(argp2);
  if (arg1) (arg1)->txOption = *arg2;
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_SendTypingIndicationParam_txOption_get(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::SendTypingIndicationParam *arg1 = (pj::SendTypingIndicationParam *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  pj::SipTxOption *result = 0 ;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__SendTypingIndicationParam, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "SendTypingIndicationParam_txOption_get" "', argument " "1"" of type '" "pj::SendTypingIndicationParam *""'"); 
  }
  arg1 = reinterpret_cast< pj::SendTypingIndicationParam * >(argp1);
  result = (pj::SipTxOption *)& ((arg1)->txOption);
  resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(result), SWIGTYPE_p_pj__SipTxOption, 0 |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_new_SendTypingIndicationParam(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::SendTypingIndicationParam *result = 0 ;
  
  if (!SWIG_Python_UnpackTuple(args, "new_SendTypingIndicationParam", 0, 0, 0)) SWIG_fail;
  result = (pj::SendTypingIndicationParam *)new pj::SendTypingIndicationParam();
  resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(result), SWIGTYPE_p_pj__SendTypingIndicationParam, SWIG_POINTER_NEW |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_delete_SendTypingIndicationParam(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::SendTypingIndicationParam *arg1 = (pj::SendTypingIndicationParam *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__SendTypingIndicationParam, SWIG_POINTER_DISOWN |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "delete_SendTypingIndicationParam" "', argument " "1"" of type '" "pj::SendTypingIndicationParam *""'"); 
  }
  arg1 = reinterpret_cast< pj::SendTypingIndicationParam * >(argp1);
  delete arg1;
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *SendTypingIndicationParam_swigregister(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *obj;
  if (!SWIG_Python_UnpackTuple(args, "swigregister", 1, 1, &obj)) return NULL;
  SWIG_TypeNewClientData(SWIGTYPE_p_pj__SendTypingIndicationParam, SWIG_NewClientData(obj));
  return SWIG_Py_Void();
}

SWIGINTERN PyObject *SendTypingIndicationParam_swiginit(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  return SWIG_Python_InitShadowInstance(args);
}

SWIGINTERN PyObject *_wrap_SipHeaderVector_iterator(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  std::vector< pj::SipHeader > *arg1 = (std::vector< pj::SipHeader > *) 0 ;
  PyObject **arg2 = (PyObject **) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  swig::SwigPyIterator *result = 0 ;
  
  arg2 = &swig_obj[0];
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__vectorT_pj__SipHeader_std__allocatorT_pj__SipHeader_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "SipHeaderVector_iterator" "', argument " "1"" of type '" "std::vector< pj::SipHeader > *""'"); 
  }
  arg1 = reinterpret_cast< std::vector< pj::SipHeader > * >(argp1);
  result = (swig::SwigPyIterator *)std_vector_Sl_pj_SipHeader_Sg__iterator(arg1,arg2);
  resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(result), SWIGTYPE_p_swig__SwigPyIterator, SWIG_POINTER_OWN |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_SipHeaderVector___nonzero__(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  std::vector< pj::SipHeader > *arg1 = (std::vector< pj::SipHeader > *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  bool result;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__vectorT_pj__SipHeader_std__allocatorT_pj__SipHeader_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "SipHeaderVector___nonzero__" "', argument " "1"" of type '" "std::vector< pj::SipHeader > const *""'"); 
  }
  arg1 = reinterpret_cast< std::vector< pj::SipHeader > * >(argp1);
  result = (bool)std_vector_Sl_pj_SipHeader_Sg____nonzero__((std::vector< pj::SipHeader > const *)arg1);
  resultobj = SWIG_From_bool(static_cast< bool >(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_SipHeaderVector___bool__(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  std::vector< pj::SipHeader > *arg1 = (std::vector< pj::SipHeader > *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  bool result;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__vectorT_pj__SipHeader_std__allocatorT_pj__SipHeader_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "SipHeaderVector___bool__" "', argument " "1"" of type '" "std::vector< pj::SipHeader > const *""'"); 
  }
  arg1 = reinterpret_cast< std::vector< pj::SipHeader > * >(argp1);
  result = (bool)std_vector_Sl_pj_SipHeader_Sg____bool__((std::vector< pj::SipHeader > const *)arg1);
  resultobj = SWIG_From_bool(static_cast< bool >(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_SipHeaderVector___len__(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  std::vector< pj::SipHeader > *arg1 = (std::vector< pj::SipHeader > *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  std::vector< pj::SipHeader >::size_type result;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__vectorT_pj__SipHeader_std__allocatorT_pj__SipHeader_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "SipHeaderVector___len__" "', argument " "1"" of type '" "std::vector< pj::SipHeader > const *""'"); 
  }
  arg1 = reinterpret_cast< std::vector< pj::SipHeader > * >(argp1);
  result = std_vector_Sl_pj_SipHeader_Sg____len__((std::vector< pj::SipHeader > const *)arg1);
  resultobj = SWIG_From_size_t(static_cast< size_t >(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_SipHeaderVector___getslice__(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  std::vector< pj::SipHeader > *arg1 = (std::vector< pj::SipHeader > *) 0 ;
  std::vector< pj::SipHeader >::difference_type arg2 ;
  std::vector< pj::SipHeader >::difference_type arg3 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  ptrdiff_t val2 ;
  int ecode2 = 0 ;
  ptrdiff_t val3 ;
  int ecode3 = 0 ;
  PyObject *swig_obj[3] ;
  std::vector< pj::SipHeader,std::allocator< pj::SipHeader > > *result = 0 ;
  
  if (!SWIG_Python_UnpackTuple(args, "SipHeaderVector___getslice__", 3, 3, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__vectorT_pj__SipHeader_std__allocatorT_pj__SipHeader_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "SipHeaderVector___getslice__" "', argument " "1"" of type '" "std::vector< pj::SipHeader > *""'"); 
  }
  arg1 = reinterpret_cast< std::vector< pj::SipHeader > * >(argp1);
  ecode2 = SWIG_AsVal_ptrdiff_t(swig_obj[1], &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "SipHeaderVector___getslice__" "', argument " "2"" of type '" "std::vector< pj::SipHeader >::difference_type""'");
  } 
  arg2 = static_cast< std::vector< pj::SipHeader >::difference_type >(val2);
  ecode3 = SWIG_AsVal_ptrdiff_t(swig_obj[2], &val3);
  if (!SWIG_IsOK(ecode3)) {
    SWIG_exception_fail(SWIG_ArgError(ecode3), "in method '" "SipHeaderVector___getslice__" "', argument " "3"" of type '" "std::vector< pj::SipHeader >::difference_type""'");
  } 
  arg3 = static_cast< std::vector< pj::SipHeader >::difference_type >(val3);
  try {
    result = (std::vector< pj::SipHeader,std::allocator< pj::SipHeader > > *)std_vector_Sl_pj_SipHeader_Sg____getslice__(arg1,arg2,arg3);
  } catch(std::out_of_range &_e) {
    SWIG_exception_fail(SWIG_IndexError, (&_e)->what());
  } catch(std::invalid_argument &_e) {
    SWIG_exception_fail(SWIG_ValueError, (&_e)->what());
  }
  resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(result), SWIGTYPE_p_std__vectorT_pj__SipHeader_std__allocatorT_pj__SipHeader_t_t, SWIG_POINTER_OWN |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_SipHeaderVector___setslice____SWIG_0(PyObject *SWIGUNUSEDPARM(self), Py_ssize_t nobjs, PyObject **swig_obj) {
  PyObject *resultobj = 0;
  std::vector< pj::SipHeader > *arg1 = (std::vector< pj::SipHeader > *) 0 ;
  std::vector< pj::SipHeader >::difference_type arg2 ;
  std::vector< pj::SipHeader >::difference_type arg3 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  ptrdiff_t val2 ;
  int ecode2 = 0 ;
  ptrdiff_t val3 ;
  int ecode3 = 0 ;
  
  if ((nobjs < 3) || (nobjs > 3)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__vectorT_pj__SipHeader_std__allocatorT_pj__SipHeader_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "SipHeaderVector___setslice__" "', argument " "1"" of type '" "std::vector< pj::SipHeader > *""'"); 
  }
  arg1 = reinterpret_cast< std::vector< pj::SipHeader > * >(argp1);
  ecode2 = SWIG_AsVal_ptrdiff_t(swig_obj[1], &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "SipHeaderVector___setslice__" "', argument " "2"" of type '" "std::vector< pj::SipHeader >::difference_type""'");
  } 
  arg2 = static_cast< std::vector< pj::SipHeader >::difference_type >(val2);
  ecode3 = SWIG_AsVal_ptrdiff_t(swig_obj[2], &val3);
  if (!SWIG_IsOK(ecode3)) {
    SWIG_exception_fail(SWIG_ArgError(ecode3), "in method '" "SipHeaderVector___setslice__" "', argument " "3"" of type '" "std::vector< pj::SipHeader >::difference_type""'");
  } 
  arg3 = static_cast< std::vector< pj::SipHeader >::difference_type >(val3);
  try {
    std_vector_Sl_pj_SipHeader_Sg____setslice____SWIG_0(arg1,arg2,arg3);
  } catch(std::out_of_range &_e) {
    SWIG_exception_fail(SWIG_IndexError, (&_e)->what());
  } catch(std::invalid_argument &_e) {
    SWIG_exception_fail(SWIG_ValueError, (&_e)->what());
  }
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_SipHeaderVector___setslice____SWIG_1(PyObject *SWIGUNUSEDPARM(self), Py_ssize_t nobjs, PyObject **swig_obj) {
  PyObject *resultobj = 0;
  std::vector< pj::SipHeader > *arg1 = (std::vector< pj::SipHeader > *) 0 ;
  std::vector< pj::SipHeader >::difference_type arg2 ;
  std::vector< pj::SipHeader >::difference_type arg3 ;
  std::vector< pj::SipHeader,std::allocator< pj::SipHeader > > *arg4 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  ptrdiff_t val2 ;
  int ecode2 = 0 ;
  ptrdiff_t val3 ;
  int ecode3 = 0 ;
  int res4 = SWIG_OLDOBJ ;
  
  if ((nobjs < 4) || (nobjs > 4)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__vectorT_pj__SipHeader_std__allocatorT_pj__SipHeader_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "SipHeaderVector___setslice__" "', argument " "1"" of type '" "std::vector< pj::SipHeader > *""'"); 
  }
  arg1 = reinterpret_cast< std::vector< pj::SipHeader > * >(argp1);
  ecode2 = SWIG_AsVal_ptrdiff_t(swig_obj[1], &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "SipHeaderVector___setslice__" "', argument " "2"" of type '" "std::vector< pj::SipHeader >::difference_type""'");
  } 
  arg2 = static_cast< std::vector< pj::SipHeader >::difference_type >(val2);
  ecode3 = SWIG_AsVal_ptrdiff_t(swig_obj[2], &val3);
  if (!SWIG_IsOK(ecode3)) {
    SWIG_exception_fail(SWIG_ArgError(ecode3), "in method '" "SipHeaderVector___setslice__" "', argument " "3"" of type '" "std::vector< pj::SipHeader >::difference_type""'");
  } 
  arg3 = static_cast< std::vector< pj::SipHeader >::difference_type >(val3);
  {
    std::vector< pj::SipHeader,std::allocator< pj::SipHeader > > *ptr = (std::vector< pj::SipHeader,std::allocator< pj::SipHeader > > *)0;
    res4 = swig::asptr(swig_obj[3], &ptr);
    if (!SWIG_IsOK(res4)) {
      SWIG_exception_fail(SWIG_ArgError(res4), "in method '" "SipHeaderVector___setslice__" "', argument " "4"" of type '" "std::vector< pj::SipHeader,std::allocator< pj::SipHeader > > const &""'"); 
    }
    if (!ptr) {
      SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "SipHeaderVector___setslice__" "', argument " "4"" of type '" "std::vector< pj::SipHeader,std::allocator< pj::SipHeader > > const &""'"); 
    }
    arg4 = ptr;
  }
  try {
    std_vector_Sl_pj_SipHeader_Sg____setslice____SWIG_1(arg1,arg2,arg3,(std::vector< pj::SipHeader,std::allocator< pj::SipHeader > > const &)*arg4);
  } catch(std::out_of_range &_e) {
    SWIG_exception_fail(SWIG_IndexError, (&_e)->what());
  } catch(std::invalid_argument &_e) {
    SWIG_exception_fail(SWIG_ValueError, (&_e)->what());
  }
  resultobj = SWIG_Py_Void();
  if (SWIG_IsNewObj(res4)) delete arg4;
  return resultobj;
fail:
  if (SWIG_IsNewObj(res4)) delete arg4;
  return NULL;
}


SWIGINTERN PyObject *_wrap_SipHeaderVector___setslice__(PyObject *self, PyObject *args) {
  Py_ssize_t argc;
  PyObject *argv[5] = {
    0
  };
  
  if (!(argc = SWIG_Python_UnpackTuple(args, "SipHeaderVector___setslice__", 0, 4, argv))) SWIG_fail;
  --argc;
  if (argc == 3) {
    int _v;
    int res = swig::asptr(argv[0], (std::vector< pj::SipHeader,std::allocator< pj::SipHeader > >**)(0));
    _v = SWIG_CheckState(res);
    if (_v) {
      {
        int res = SWIG_AsVal_ptrdiff_t(argv[1], NULL);
        _v = SWIG_CheckState(res);
      }
      if (_v) {
        {
          int res = SWIG_AsVal_ptrdiff_t(argv[2], NULL);
          _v = SWIG_CheckState(res);
        }
        if (_v) {
          return _wrap_SipHeaderVector___setslice____SWIG_0(self, argc, argv);
        }
      }
    }
  }
  if (argc == 4) {
    int _v;
    int res = swig::asptr(argv[0], (std::vector< pj::SipHeader,std::allocator< pj::SipHeader > >**)(0));
    _v = SWIG_CheckState(res);
    if (_v) {
      {
        int res = SWIG_AsVal_ptrdiff_t(argv[1], NULL);
        _v = SWIG_CheckState(res);
      }
      if (_v) {
        {
          int res = SWIG_AsVal_ptrdiff_t(argv[2], NULL);
          _v = SWIG_CheckState(res);
        }
        if (_v) {
          int res = swig::asptr(argv[3], (std::vector< pj::SipHeader,std::allocator< pj::SipHeader > >**)(0));
          _v = SWIG_CheckState(res);
          if (_v) {
            return _wrap_SipHeaderVector___setslice____SWIG_1(self, argc, argv);
          }
        }
      }
    }
  }
  
fail:
  SWIG_Python_RaiseOrModifyTypeError("Wrong number or type of arguments for overloaded function 'SipHeaderVector___setslice__'.\n"
    "  Possible C/C++ prototypes are:\n"
    "    std::vector< pj::SipHeader >::__setslice__(std::vector< pj::SipHeader >::difference_type,std::vector< pj::SipHeader >::difference_type)\n"
    "    std::vector< pj::SipHeader >::__setslice__(std::vector< pj::SipHeader >::difference_type,std::vector< pj::SipHeader >::difference_type,std::vector< pj::SipHeader,std::allocator< pj::SipHeader > > const &)\n");
  return 0;
}


SWIGINTERN PyObject *_wrap_SipHeaderVector___delslice__(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  std::vector< pj::SipHeader > *arg1 = (std::vector< pj::SipHeader > *) 0 ;
  std::vector< pj::SipHeader >::difference_type arg2 ;
  std::vector< pj::SipHeader >::difference_type arg3 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  ptrdiff_t val2 ;
  int ecode2 = 0 ;
  ptrdiff_t val3 ;
  int ecode3 = 0 ;
  PyObject *swig_obj[3] ;
  
  if (!SWIG_Python_UnpackTuple(args, "SipHeaderVector___delslice__", 3, 3, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__vectorT_pj__SipHeader_std__allocatorT_pj__SipHeader_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "SipHeaderVector___delslice__" "', argument " "1"" of type '" "std::vector< pj::SipHeader > *""'"); 
  }
  arg1 = reinterpret_cast< std::vector< pj::SipHeader > * >(argp1);
  ecode2 = SWIG_AsVal_ptrdiff_t(swig_obj[1], &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "SipHeaderVector___delslice__" "', argument " "2"" of type '" "std::vector< pj::SipHeader >::difference_type""'");
  } 
  arg2 = static_cast< std::vector< pj::SipHeader >::difference_type >(val2);
  ecode3 = SWIG_AsVal_ptrdiff_t(swig_obj[2], &val3);
  if (!SWIG_IsOK(ecode3)) {
    SWIG_exception_fail(SWIG_ArgError(ecode3), "in method '" "SipHeaderVector___delslice__" "', argument " "3"" of type '" "std::vector< pj::SipHeader >::difference_type""'");
  } 
  arg3 = static_cast< std::vector< pj::SipHeader >::difference_type >(val3);
  try {
    std_vector_Sl_pj_SipHeader_Sg____delslice__(arg1,arg2,arg3);
  } catch(std::out_of_range &_e) {
    SWIG_exception_fail(SWIG_IndexError, (&_e)->what());
  } catch(std::invalid_argument &_e) {
    SWIG_exception_fail(SWIG_ValueError, (&_e)->what());
  }
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_SipHeaderVector___delitem____SWIG_0(PyObject *SWIGUNUSEDPARM(self), Py_ssize_t nobjs, PyObject **swig_obj) {
  PyObject *resultobj = 0;
  std::vector< pj::SipHeader > *arg1 = (std::vector< pj::SipHeader > *) 0 ;
  std::vector< pj::SipHeader >::difference_type arg2 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  ptrdiff_t val2 ;
  int ecode2 = 0 ;
  
  if ((nobjs < 2) || (nobjs > 2)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__vectorT_pj__SipHeader_std__allocatorT_pj__SipHeader_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "SipHeaderVector___delitem__" "', argument " "1"" of type '" "std::vector< pj::SipHeader > *""'"); 
  }
  arg1 = reinterpret_cast< std::vector< pj::SipHeader > * >(argp1);
  ecode2 = SWIG_AsVal_ptrdiff_t(swig_obj[1], &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "SipHeaderVector___delitem__" "', argument " "2"" of type '" "std::vector< pj::SipHeader >::difference_type""'");
  } 
  arg2 = static_cast< std::vector< pj::SipHeader >::difference_type >(val2);
  try {
    std_vector_Sl_pj_SipHeader_Sg____delitem____SWIG_0(arg1,arg2);
  } catch(std::out_of_range &_e) {
    SWIG_exception_fail(SWIG_IndexError, (&_e)->what());
  } catch(std::invalid_argument &_e) {
    SWIG_exception_fail(SWIG_ValueError, (&_e)->what());
  }
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_SipHeaderVector___getitem____SWIG_0(PyObject *SWIGUNUSEDPARM(self), Py_ssize_t nobjs, PyObject **swig_obj) {
  PyObject *resultobj = 0;
  std::vector< pj::SipHeader > *arg1 = (std::vector< pj::SipHeader > *) 0 ;
  PySliceObject *arg2 = (PySliceObject *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  std::vector< pj::SipHeader,std::allocator< pj::SipHeader > > *result = 0 ;
  
  if ((nobjs < 2) || (nobjs > 2)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__vectorT_pj__SipHeader_std__allocatorT_pj__SipHeader_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "SipHeaderVector___getitem__" "', argument " "1"" of type '" "std::vector< pj::SipHeader > *""'"); 
  }
  arg1 = reinterpret_cast< std::vector< pj::SipHeader > * >(argp1);
  {
    if (!PySlice_Check(swig_obj[1])) {
      SWIG_exception_fail(SWIG_ArgError(SWIG_TypeError), "in method '" "SipHeaderVector___getitem__" "', argument " "2"" of type '" "PySliceObject *""'");
    }
    arg2 = (PySliceObject *) swig_obj[1];
  }
  try {
    result = (std::vector< pj::SipHeader,std::allocator< pj::SipHeader > > *)std_vector_Sl_pj_SipHeader_Sg____getitem____SWIG_0(arg1,arg2);
  } catch(std::out_of_range &_e) {
    SWIG_exception_fail(SWIG_IndexError, (&_e)->what());
  } catch(std::invalid_argument &_e) {
    SWIG_exception_fail(SWIG_ValueError, (&_e)->what());
  }
  resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(result), SWIGTYPE_p_std__vectorT_pj__SipHeader_std__allocatorT_pj__SipHeader_t_t, SWIG_POINTER_OWN |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_SipHeaderVector___setitem____SWIG_0(PyObject *SWIGUNUSEDPARM(self), Py_ssize_t nobjs, PyObject **swig_obj) {
  PyObject *resultobj = 0;
  std::vector< pj::SipHeader > *arg1 = (std::vector< pj::SipHeader > *) 0 ;
  PySliceObject *arg2 = (PySliceObject *) 0 ;
  std::vector< pj::SipHeader,std::allocator< pj::SipHeader > > *arg3 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  int res3 = SWIG_OLDOBJ ;
  
  if ((nobjs < 3) || (nobjs > 3)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__vectorT_pj__SipHeader_std__allocatorT_pj__SipHeader_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "SipHeaderVector___setitem__" "', argument " "1"" of type '" "std::vector< pj::SipHeader > *""'"); 
  }
  arg1 = reinterpret_cast< std::vector< pj::SipHeader > * >(argp1);
  {
    if (!PySlice_Check(swig_obj[1])) {
      SWIG_exception_fail(SWIG_ArgError(SWIG_TypeError), "in method '" "SipHeaderVector___setitem__" "', argument " "2"" of type '" "PySliceObject *""'");
    }
    arg2 = (PySliceObject *) swig_obj[1];
  }
  {
    std::vector< pj::SipHeader,std::allocator< pj::SipHeader > > *ptr = (std::vector< pj::SipHeader,std::allocator< pj::SipHeader > > *)0;
    res3 = swig::asptr(swig_obj[2], &ptr);
    if (!SWIG_IsOK(res3)) {
      SWIG_exception_fail(SWIG_ArgError(res3), "in method '" "SipHeaderVector___setitem__" "', argument " "3"" of type '" "std::vector< pj::SipHeader,std::allocator< pj::SipHeader > > const &""'"); 
    }
    if (!ptr) {
      SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "SipHeaderVector___setitem__" "', argument " "3"" of type '" "std::vector< pj::SipHeader,std::allocator< pj::SipHeader > > const &""'"); 
    }
    arg3 = ptr;
  }
  try {
    std_vector_Sl_pj_SipHeader_Sg____setitem____SWIG_0(arg1,arg2,(std::vector< pj::SipHeader,std::allocator< pj::SipHeader > > const &)*arg3);
  } catch(std::out_of_range &_e) {
    SWIG_exception_fail(SWIG_IndexError, (&_e)->what());
  } catch(std::invalid_argument &_e) {
    SWIG_exception_fail(SWIG_ValueError, (&_e)->what());
  }
  resultobj = SWIG_Py_Void();
  if (SWIG_IsNewObj(res3)) delete arg3;
  return resultobj;
fail:
  if (SWIG_IsNewObj(res3)) delete arg3;
  return NULL;
}


SWIGINTERN PyObject *_wrap_SipHeaderVector___setitem____SWIG_1(PyObject *SWIGUNUSEDPARM(self), Py_ssize_t nobjs, PyObject **swig_obj) {
  PyObject *resultobj = 0;
  std::vector< pj::SipHeader > *arg1 = (std::vector< pj::SipHeader > *) 0 ;
  PySliceObject *arg2 = (PySliceObject *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  
  if ((nobjs < 2) || (nobjs > 2)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__vectorT_pj__SipHeader_std__allocatorT_pj__SipHeader_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "SipHeaderVector___setitem__" "', argument " "1"" of type '" "std::vector< pj::SipHeader > *""'"); 
  }
  arg1 = reinterpret_cast< std::vector< pj::SipHeader > * >(argp1);
  {
    if (!PySlice_Check(swig_obj[1])) {
      SWIG_exception_fail(SWIG_ArgError(SWIG_TypeError), "in method '" "SipHeaderVector___setitem__" "', argument " "2"" of type '" "PySliceObject *""'");
    }
    arg2 = (PySliceObject *) swig_obj[1];
  }
  try {
    std_vector_Sl_pj_SipHeader_Sg____setitem____SWIG_1(arg1,arg2);
  } catch(std::out_of_range &_e) {
    SWIG_exception_fail(SWIG_IndexError, (&_e)->what());
  } catch(std::invalid_argument &_e) {
    SWIG_exception_fail(SWIG_ValueError, (&_e)->what());
  }
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_SipHeaderVector___delitem____SWIG_1(PyObject *SWIGUNUSEDPARM(self), Py_ssize_t nobjs, PyObject **swig_obj) {
  PyObject *resultobj = 0;
  std::vector< pj::SipHeader > *arg1 = (std::vector< pj::SipHeader > *) 0 ;
  PySliceObject *arg2 = (PySliceObject *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  
  if ((nobjs < 2) || (nobjs > 2)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__vectorT_pj__SipHeader_std__allocatorT_pj__SipHeader_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "SipHeaderVector___delitem__" "', argument " "1"" of type '" "std::vector< pj::SipHeader > *""'"); 
  }
  arg1 = reinterpret_cast< std::vector< pj::SipHeader > * >(argp1);
  {
    if (!PySlice_Check(swig_obj[1])) {
      SWIG_exception_fail(SWIG_ArgError(SWIG_TypeError), "in method '" "SipHeaderVector___delitem__" "', argument " "2"" of type '" "PySliceObject *""'");
    }
    arg2 = (PySliceObject *) swig_obj[1];
  }
  try {
    std_vector_Sl_pj_SipHeader_Sg____delitem____SWIG_1(arg1,arg2);
  } catch(std::out_of_range &_e) {
    SWIG_exception_fail(SWIG_IndexError, (&_e)->what());
  } catch(std::invalid_argument &_e) {
    SWIG_exception_fail(SWIG_ValueError, (&_e)->what());
  }
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_SipHeaderVector___delitem__(PyObject *self, PyObject *args) {
  Py_ssize_t argc;
  PyObject *argv[3] = {
    0
  };
  
  if (!(argc = SWIG_Python_UnpackTuple(args, "SipHeaderVector___delitem__", 0, 2, argv))) SWIG_fail;
  --argc;
  if (argc == 2) {
    int _v;
    int res = swig::asptr(argv[0], (std::vector< pj::SipHeader,std::allocator< pj::SipHeader > >**)(0));
    _v = SWIG_CheckState(res);
    if (_v) {
      {
        _v = PySlice_Check(argv[1]);
      }
      if (_v) {
        return _wrap_SipHeaderVector___delitem____SWIG_1(self, argc, argv);
      }
    }
  }
  if (argc == 2) {
    int _v;
    int res = swig::asptr(argv[0], (std::vector< pj::SipHeader,std::allocator< pj::SipHeader > >**)(0));
    _v = SWIG_CheckState(res);
    if (_v) {
      {
        int res = SWIG_AsVal_ptrdiff_t(argv[1], NULL);
        _v = SWIG_CheckState(res);
      }
      if (_v) {
        return _wrap_SipHeaderVector___delitem____SWIG_0(self, argc, argv);
      }
    }
  }
  
fail:
  SWIG_Python_RaiseOrModifyTypeError("Wrong number or type of arguments for overloaded function 'SipHeaderVector___delitem__'.\n"
    "  Possible C/C++ prototypes are:\n"
    "    std::vector< pj::SipHeader >::__delitem__(std::vector< pj::SipHeader >::difference_type)\n"
    "    std::vector< pj::SipHeader >::__delitem__(PySliceObject *)\n");
  return 0;
}


SWIGINTERN PyObject *_wrap_SipHeaderVector___getitem____SWIG_1(PyObject *SWIGUNUSEDPARM(self), Py_ssize_t nobjs, PyObject **swig_obj) {
  PyObject *resultobj = 0;
  std::vector< pj::SipHeader > *arg1 = (std::vector< pj::SipHeader > *) 0 ;
  std::vector< pj::SipHeader >::difference_type arg2 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  ptrdiff_t val2 ;
  int ecode2 = 0 ;
  std::vector< pj::SipHeader >::value_type *result = 0 ;
  
  if ((nobjs < 2) || (nobjs > 2)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__vectorT_pj__SipHeader_std__allocatorT_pj__SipHeader_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "SipHeaderVector___getitem__" "', argument " "1"" of type '" "std::vector< pj::SipHeader > const *""'"); 
  }
  arg1 = reinterpret_cast< std::vector< pj::SipHeader > * >(argp1);
  ecode2 = SWIG_AsVal_ptrdiff_t(swig_obj[1], &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "SipHeaderVector___getitem__" "', argument " "2"" of type '" "std::vector< pj::SipHeader >::difference_type""'");
  } 
  arg2 = static_cast< std::vector< pj::SipHeader >::difference_type >(val2);
  try {
    result = (std::vector< pj::SipHeader >::value_type *) &std_vector_Sl_pj_SipHeader_Sg____getitem____SWIG_1((std::vector< pj::SipHeader > const *)arg1,arg2);
  } catch(std::out_of_range &_e) {
    SWIG_exception_fail(SWIG_IndexError, (&_e)->what());
  }
  resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(result), SWIGTYPE_p_pj__SipHeader, 0 |  0 );
  (void)swig::container_owner<swig::traits<std::vector< pj::SipHeader >::value_type>::category>::back_reference(resultobj, swig_obj[0]);
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_SipHeaderVector___getitem__(PyObject *self, PyObject *args) {
  Py_ssize_t argc;
  PyObject *argv[3] = {
    0
  };
  
  if (!(argc = SWIG_Python_UnpackTuple(args, "SipHeaderVector___getitem__", 0, 2, argv))) SWIG_fail;
  --argc;
  if (argc == 2) {
    int _v;
    int res = swig::asptr(argv[0], (std::vector< pj::SipHeader,std::allocator< pj::SipHeader > >**)(0));
    _v = SWIG_CheckState(res);
    if (_v) {
      {
        _v = PySlice_Check(argv[1]);
      }
      if (_v) {
        return _wrap_SipHeaderVector___getitem____SWIG_0(self, argc, argv);
      }
    }
  }
  if (argc == 2) {
    int _v;
    int res = swig::asptr(argv[0], (std::vector< pj::SipHeader,std::allocator< pj::SipHeader > >**)(0));
    _v = SWIG_CheckState(res);
    if (_v) {
      {
        int res = SWIG_AsVal_ptrdiff_t(argv[1], NULL);
        _v = SWIG_CheckState(res);
      }
      if (_v) {
        return _wrap_SipHeaderVector___getitem____SWIG_1(self, argc, argv);
      }
    }
  }
  
fail:
  SWIG_Python_RaiseOrModifyTypeError("Wrong number or type of arguments for overloaded function 'SipHeaderVector___getitem__'.\n"
    "  Possible C/C++ prototypes are:\n"
    "    std::vector< pj::SipHeader >::__getitem__(PySliceObject *)\n"
    "    std::vector< pj::SipHeader >::__getitem__(std::vector< pj::SipHeader >::difference_type) const\n");
  return 0;
}


SWIGINTERN PyObject *_wrap_SipHeaderVector___setitem____SWIG_2(PyObject *SWIGUNUSEDPARM(self), Py_ssize_t nobjs, PyObject **swig_obj) {
  PyObject *resultobj = 0;
  std::vector< pj::SipHeader > *arg1 = (std::vector< pj::SipHeader > *) 0 ;
  std::vector< pj::SipHeader >::difference_type arg2 ;
  std::vector< pj::SipHeader >::value_type *arg3 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  ptrdiff_t val2 ;
  int ecode2 = 0 ;
  void *argp3 = 0 ;
  int res3 = 0 ;
  
  if ((nobjs < 3) || (nobjs > 3)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__vectorT_pj__SipHeader_std__allocatorT_pj__SipHeader_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "SipHeaderVector___setitem__" "', argument " "1"" of type '" "std::vector< pj::SipHeader > *""'"); 
  }
  arg1 = reinterpret_cast< std::vector< pj::SipHeader > * >(argp1);
  ecode2 = SWIG_AsVal_ptrdiff_t(swig_obj[1], &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "SipHeaderVector___setitem__" "', argument " "2"" of type '" "std::vector< pj::SipHeader >::difference_type""'");
  } 
  arg2 = static_cast< std::vector< pj::SipHeader >::difference_type >(val2);
  res3 = SWIG_ConvertPtr(swig_obj[2], &argp3, SWIGTYPE_p_pj__SipHeader,  0  | 0);
  if (!SWIG_IsOK(res3)) {
    SWIG_exception_fail(SWIG_ArgError(res3), "in method '" "SipHeaderVector___setitem__" "', argument " "3"" of type '" "std::vector< pj::SipHeader >::value_type const &""'"); 
  }
  if (!argp3) {
    SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "SipHeaderVector___setitem__" "', argument " "3"" of type '" "std::vector< pj::SipHeader >::value_type const &""'"); 
  }
  arg3 = reinterpret_cast< std::vector< pj::SipHeader >::value_type * >(argp3);
  try {
    std_vector_Sl_pj_SipHeader_Sg____setitem____SWIG_2(arg1,arg2,(pj::SipHeader const &)*arg3);
  } catch(std::out_of_range &_e) {
    SWIG_exception_fail(SWIG_IndexError, (&_e)->what());
  }
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_SipHeaderVector___setitem__(PyObject *self, PyObject *args) {
  Py_ssize_t argc;
  PyObject *argv[4] = {
    0
  };
  
  if (!(argc = SWIG_Python_UnpackTuple(args, "SipHeaderVector___setitem__", 0, 3, argv))) SWIG_fail;
  --argc;
  if (argc == 2) {
    int _v;
    int res = swig::asptr(argv[0], (std::vector< pj::SipHeader,std::allocator< pj::SipHeader > >**)(0));
    _v = SWIG_CheckState(res);
    if (_v) {
      {
        _v = PySlice_Check(argv[1]);
      }
      if (_v) {
        return _wrap_SipHeaderVector___setitem____SWIG_1(self, argc, argv);
      }
    }
  }
  if (argc == 3) {
    int _v;
    int res = swig::asptr(argv[0], (std::vector< pj::SipHeader,std::allocator< pj::SipHeader > >**)(0));
    _v = SWIG_CheckState(res);
    if (_v) {
      {
        _v = PySlice_Check(argv[1]);
      }
      if (_v) {
        int res = swig::asptr(argv[2], (std::vector< pj::SipHeader,std::allocator< pj::SipHeader > >**)(0));
        _v = SWIG_CheckState(res);
        if (_v) {
          return _wrap_SipHeaderVector___setitem____SWIG_0(self, argc, argv);
        }
      }
    }
  }
  if (argc == 3) {
    int _v;
    int res = swig::asptr(argv[0], (std::vector< pj::SipHeader,std::allocator< pj::SipHeader > >**)(0));
    _v = SWIG_CheckState(res);
    if (_v) {
      {
        int res = SWIG_AsVal_ptrdiff_t(argv[1], NULL);
        _v = SWIG_CheckState(res);
      }
      if (_v) {
        int res = SWIG_ConvertPtr(argv[2], 0, SWIGTYPE_p_pj__SipHeader, SWIG_POINTER_NO_NULL | 0);
        _v = SWIG_CheckState(res);
        if (_v) {
          return _wrap_SipHeaderVector___setitem____SWIG_2(self, argc, argv);
        }
      }
    }
  }
  
fail:
  SWIG_Python_RaiseOrModifyTypeError("Wrong number or type of arguments for overloaded function 'SipHeaderVector___setitem__'.\n"
    "  Possible C/C++ prototypes are:\n"
    "    std::vector< pj::SipHeader >::__setitem__(PySliceObject *,std::vector< pj::SipHeader,std::allocator< pj::SipHeader > > const &)\n"
    "    std::vector< pj::SipHeader >::__setitem__(PySliceObject *)\n"
    "    std::vector< pj::SipHeader >::__setitem__(std::vector< pj::SipHeader >::difference_type,std::vector< pj::SipHeader >::value_type const &)\n");
  return 0;
}


SWIGINTERN PyObject *_wrap_SipHeaderVector_pop(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  std::vector< pj::SipHeader > *arg1 = (std::vector< pj::SipHeader > *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  std::vector< pj::SipHeader >::value_type result;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__vectorT_pj__SipHeader_std__allocatorT_pj__SipHeader_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "SipHeaderVector_pop" "', argument " "1"" of type '" "std::vector< pj::SipHeader > *""'"); 
  }
  arg1 = reinterpret_cast< std::vector< pj::SipHeader > * >(argp1);
  try {
    result = std_vector_Sl_pj_SipHeader_Sg__pop(arg1);
  } catch(std::out_of_range &_e) {
    SWIG_exception_fail(SWIG_IndexError, (&_e)->what());
  }
  resultobj = SWIG_NewPointerObj((new std::vector< pj::SipHeader >::value_type(static_cast< const std::vector< pj::SipHeader >::value_type& >(result))), SWIGTYPE_p_pj__SipHeader, SWIG_POINTER_OWN |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_SipHeaderVector_append(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  std::vector< pj::SipHeader > *arg1 = (std::vector< pj::SipHeader > *) 0 ;
  std::vector< pj::SipHeader >::value_type *arg2 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  void *argp2 = 0 ;
  int res2 = 0 ;
  PyObject *swig_obj[2] ;
  
  if (!SWIG_Python_UnpackTuple(args, "SipHeaderVector_append", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__vectorT_pj__SipHeader_std__allocatorT_pj__SipHeader_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "SipHeaderVector_append" "', argument " "1"" of type '" "std::vector< pj::SipHeader > *""'"); 
  }
  arg1 = reinterpret_cast< std::vector< pj::SipHeader > * >(argp1);
  res2 = SWIG_ConvertPtr(swig_obj[1], &argp2, SWIGTYPE_p_pj__SipHeader,  0  | 0);
  if (!SWIG_IsOK(res2)) {
    SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "SipHeaderVector_append" "', argument " "2"" of type '" "std::vector< pj::SipHeader >::value_type const &""'"); 
  }
  if (!argp2) {
    SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "SipHeaderVector_append" "', argument " "2"" of type '" "std::vector< pj::SipHeader >::value_type const &""'"); 
  }
  arg2 = reinterpret_cast< std::vector< pj::SipHeader >::value_type * >(argp2);
  std_vector_Sl_pj_SipHeader_Sg__append(arg1,(pj::SipHeader const &)*arg2);
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_new_SipHeaderVector__SWIG_0(PyObject *SWIGUNUSEDPARM(self), Py_ssize_t nobjs, PyObject **SWIGUNUSEDPARM(swig_obj)) {
  PyObject *resultobj = 0;
  std::vector< pj::SipHeader > *result = 0 ;
  
  if ((nobjs < 0) || (nobjs > 0)) SWIG_fail;
  result = (std::vector< pj::SipHeader > *)new std::vector< pj::SipHeader >();
  resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(result), SWIGTYPE_p_std__vectorT_pj__SipHeader_std__allocatorT_pj__SipHeader_t_t, SWIG_POINTER_NEW |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_new_SipHeaderVector__SWIG_1(PyObject *SWIGUNUSEDPARM(self), Py_ssize_t nobjs, PyObject **swig_obj) {
  PyObject *resultobj = 0;
  std::vector< pj::SipHeader > *arg1 = 0 ;
  int res1 = SWIG_OLDOBJ ;
  std::vector< pj::SipHeader > *result = 0 ;
  
  if ((nobjs < 1) || (nobjs > 1)) SWIG_fail;
  {
    std::vector< pj::SipHeader,std::allocator< pj::SipHeader > > *ptr = (std::vector< pj::SipHeader,std::allocator< pj::SipHeader > > *)0;
    res1 = swig::asptr(swig_obj[0], &ptr);
    if (!SWIG_IsOK(res1)) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "new_SipHeaderVector" "', argument " "1"" of type '" "std::vector< pj::SipHeader > const &""'"); 
    }
    if (!ptr) {
      SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "new_SipHeaderVector" "', argument " "1"" of type '" "std::vector< pj::SipHeader > const &""'"); 
    }
    arg1 = ptr;
  }
  result = (std::vector< pj::SipHeader > *)new std::vector< pj::SipHeader >((std::vector< pj::SipHeader > const &)*arg1);
  resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(result), SWIGTYPE_p_std__vectorT_pj__SipHeader_std__allocatorT_pj__SipHeader_t_t, SWIG_POINTER_NEW |  0 );
  if (SWIG_IsNewObj(res1)) delete arg1;
  return resultobj;
fail:
  if (SWIG_IsNewObj(res1)) delete arg1;
  return NULL;
}


SWIGINTERN PyObject *_wrap_SipHeaderVector_empty(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  std::vector< pj::SipHeader > *arg1 = (std::vector< pj::SipHeader > *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  bool result;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__vectorT_pj__SipHeader_std__allocatorT_pj__SipHeader_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "SipHeaderVector_empty" "', argument " "1"" of type '" "std::vector< pj::SipHeader > const *""'"); 
  }
  arg1 = reinterpret_cast< std::vector< pj::SipHeader > * >(argp1);
  result = (bool)((std::vector< pj::SipHeader > const *)arg1)->empty();
  resultobj = SWIG_From_bool(static_cast< bool >(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_SipHeaderVector_size(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  std::vector< pj::SipHeader > *arg1 = (std::vector< pj::SipHeader > *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  std::vector< pj::SipHeader >::size_type result;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__vectorT_pj__SipHeader_std__allocatorT_pj__SipHeader_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "SipHeaderVector_size" "', argument " "1"" of type '" "std::vector< pj::SipHeader > const *""'"); 
  }
  arg1 = reinterpret_cast< std::vector< pj::SipHeader > * >(argp1);
  result = ((std::vector< pj::SipHeader > const *)arg1)->size();
  resultobj = SWIG_From_size_t(static_cast< size_t >(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_SipHeaderVector_swap(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  std::vector< pj::SipHeader > *arg1 = (std::vector< pj::SipHeader > *) 0 ;
  std::vector< pj::SipHeader > *arg2 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  void *argp2 = 0 ;
  int res2 = 0 ;
  PyObject *swig_obj[2] ;
  
  if (!SWIG_Python_UnpackTuple(args, "SipHeaderVector_swap", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__vectorT_pj__SipHeader_std__allocatorT_pj__SipHeader_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "SipHeaderVector_swap" "', argument " "1"" of type '" "std::vector< pj::SipHeader > *""'"); 
  }
  arg1 = reinterpret_cast< std::vector< pj::SipHeader > * >(argp1);
  res2 = SWIG_ConvertPtr(swig_obj[1], &argp2, SWIGTYPE_p_std__vectorT_pj__SipHeader_std__allocatorT_pj__SipHeader_t_t,  0 );
  if (!SWIG_IsOK(res2)) {
    SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "SipHeaderVector_swap" "', argument " "2"" of type '" "std::vector< pj::SipHeader > &""'"); 
  }
  if (!argp2) {
    SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "SipHeaderVector_swap" "', argument " "2"" of type '" "std::vector< pj::SipHeader > &""'"); 
  }
  arg2 = reinterpret_cast< std::vector< pj::SipHeader > * >(argp2);
  (arg1)->swap(*arg2);
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_SipHeaderVector_begin(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  std::vector< pj::SipHeader > *arg1 = (std::vector< pj::SipHeader > *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  std::vector< pj::SipHeader >::iterator result;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__vectorT_pj__SipHeader_std__allocatorT_pj__SipHeader_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "SipHeaderVector_begin" "', argument " "1"" of type '" "std::vector< pj::SipHeader > *""'"); 
  }
  arg1 = reinterpret_cast< std::vector< pj::SipHeader > * >(argp1);
  result = (arg1)->begin();
  resultobj = SWIG_NewPointerObj(swig::make_output_iterator(static_cast< const std::vector< pj::SipHeader >::iterator & >(result)),
    swig::SwigPyIterator::descriptor(),SWIG_POINTER_OWN);
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_SipHeaderVector_end(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  std::vector< pj::SipHeader > *arg1 = (std::vector< pj::SipHeader > *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  std::vector< pj::SipHeader >::iterator result;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__vectorT_pj__SipHeader_std__allocatorT_pj__SipHeader_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "SipHeaderVector_end" "', argument " "1"" of type '" "std::vector< pj::SipHeader > *""'"); 
  }
  arg1 = reinterpret_cast< std::vector< pj::SipHeader > * >(argp1);
  result = (arg1)->end();
  resultobj = SWIG_NewPointerObj(swig::make_output_iterator(static_cast< const std::vector< pj::SipHeader >::iterator & >(result)),
    swig::SwigPyIterator::descriptor(),SWIG_POINTER_OWN);
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_SipHeaderVector_rbegin(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  std::vector< pj::SipHeader > *arg1 = (std::vector< pj::SipHeader > *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  std::vector< pj::SipHeader >::reverse_iterator result;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__vectorT_pj__SipHeader_std__allocatorT_pj__SipHeader_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "SipHeaderVector_rbegin" "', argument " "1"" of type '" "std::vector< pj::SipHeader > *""'"); 
  }
  arg1 = reinterpret_cast< std::vector< pj::SipHeader > * >(argp1);
  result = (arg1)->rbegin();
  resultobj = SWIG_NewPointerObj(swig::make_output_iterator(static_cast< const std::vector< pj::SipHeader >::reverse_iterator & >(result)),
    swig::SwigPyIterator::descriptor(),SWIG_POINTER_OWN);
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_SipHeaderVector_rend(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  std::vector< pj::SipHeader > *arg1 = (std::vector< pj::SipHeader > *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  std::vector< pj::SipHeader >::reverse_iterator result;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__vectorT_pj__SipHeader_std__allocatorT_pj__SipHeader_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "SipHeaderVector_rend" "', argument " "1"" of type '" "std::vector< pj::SipHeader > *""'"); 
  }
  arg1 = reinterpret_cast< std::vector< pj::SipHeader > * >(argp1);
  result = (arg1)->rend();
  resultobj = SWIG_NewPointerObj(swig::make_output_iterator(static_cast< const std::vector< pj::SipHeader >::reverse_iterator & >(result)),
    swig::SwigPyIterator::descriptor(),SWIG_POINTER_OWN);
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_SipHeaderVector_clear(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  std::vector< pj::SipHeader > *arg1 = (std::vector< pj::SipHeader > *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__vectorT_pj__SipHeader_std__allocatorT_pj__SipHeader_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "SipHeaderVector_clear" "', argument " "1"" of type '" "std::vector< pj::SipHeader > *""'"); 
  }
  arg1 = reinterpret_cast< std::vector< pj::SipHeader > * >(argp1);
  (arg1)->clear();
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_SipHeaderVector_get_allocator(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  std::vector< pj::SipHeader > *arg1 = (std::vector< pj::SipHeader > *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  SwigValueWrapper< std::allocator< pj::SipHeader > > result;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__vectorT_pj__SipHeader_std__allocatorT_pj__SipHeader_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "SipHeaderVector_get_allocator" "', argument " "1"" of type '" "std::vector< pj::SipHeader > const *""'"); 
  }
  arg1 = reinterpret_cast< std::vector< pj::SipHeader > * >(argp1);
  result = ((std::vector< pj::SipHeader > const *)arg1)->get_allocator();
  resultobj = SWIG_NewPointerObj((new std::vector< pj::SipHeader >::allocator_type(static_cast< const std::vector< pj::SipHeader >::allocator_type& >(result))), SWIGTYPE_p_std__allocatorT_pj__SipHeader_t, SWIG_POINTER_OWN |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_new_SipHeaderVector__SWIG_2(PyObject *SWIGUNUSEDPARM(self), Py_ssize_t nobjs, PyObject **swig_obj) {
  PyObject *resultobj = 0;
  std::vector< pj::SipHeader >::size_type arg1 ;
  size_t val1 ;
  int ecode1 = 0 ;
  std::vector< pj::SipHeader > *result = 0 ;
  
  if ((nobjs < 1) || (nobjs > 1)) SWIG_fail;
  ecode1 = SWIG_AsVal_size_t(swig_obj[0], &val1);
  if (!SWIG_IsOK(ecode1)) {
    SWIG_exception_fail(SWIG_ArgError(ecode1), "in method '" "new_SipHeaderVector" "', argument " "1"" of type '" "std::vector< pj::SipHeader >::size_type""'");
  } 
  arg1 = static_cast< std::vector< pj::SipHeader >::size_type >(val1);
  result = (std::vector< pj::SipHeader > *)new std::vector< pj::SipHeader >(arg1);
  resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(result), SWIGTYPE_p_std__vectorT_pj__SipHeader_std__allocatorT_pj__SipHeader_t_t, SWIG_POINTER_NEW |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_SipHeaderVector_pop_back(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  std::vector< pj::SipHeader > *arg1 = (std::vector< pj::SipHeader > *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__vectorT_pj__SipHeader_std__allocatorT_pj__SipHeader_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "SipHeaderVector_pop_back" "', argument " "1"" of type '" "std::vector< pj::SipHeader > *""'"); 
  }
  arg1 = reinterpret_cast< std::vector< pj::SipHeader > * >(argp1);
  (arg1)->pop_back();
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_SipHeaderVector_resize__SWIG_0(PyObject *SWIGUNUSEDPARM(self), Py_ssize_t nobjs, PyObject **swig_obj) {
  PyObject *resultobj = 0;
  std::vector< pj::SipHeader > *arg1 = (std::vector< pj::SipHeader > *) 0 ;
  std::vector< pj::SipHeader >::size_type arg2 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  size_t val2 ;
  int ecode2 = 0 ;
  
  if ((nobjs < 2) || (nobjs > 2)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__vectorT_pj__SipHeader_std__allocatorT_pj__SipHeader_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "SipHeaderVector_resize" "', argument " "1"" of type '" "std::vector< pj::SipHeader > *""'"); 
  }
  arg1 = reinterpret_cast< std::vector< pj::SipHeader > * >(argp1);
  ecode2 = SWIG_AsVal_size_t(swig_obj[1], &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "SipHeaderVector_resize" "', argument " "2"" of type '" "std::vector< pj::SipHeader >::size_type""'");
  } 
  arg2 = static_cast< std::vector< pj::SipHeader >::size_type >(val2);
  (arg1)->resize(arg2);
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_SipHeaderVector_erase__SWIG_0(PyObject *SWIGUNUSEDPARM(self), Py_ssize_t nobjs, PyObject **swig_obj) {
  PyObject *resultobj = 0;
  std::vector< pj::SipHeader > *arg1 = (std::vector< pj::SipHeader > *) 0 ;
  std::vector< pj::SipHeader >::iterator arg2 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  swig::SwigPyIterator *iter2 = 0 ;
  int res2 ;
  std::vector< pj::SipHeader >::iterator result;
  
  if ((nobjs < 2) || (nobjs > 2)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__vectorT_pj__SipHeader_std__allocatorT_pj__SipHeader_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "SipHeaderVector_erase" "', argument " "1"" of type '" "std::vector< pj::SipHeader > *""'"); 
  }
  arg1 = reinterpret_cast< std::vector< pj::SipHeader > * >(argp1);
  res2 = SWIG_ConvertPtr(swig_obj[1], SWIG_as_voidptrptr(&iter2), swig::SwigPyIterator::descriptor(), 0);
  if (!SWIG_IsOK(res2) || !iter2) {
    SWIG_exception_fail(SWIG_ArgError(SWIG_TypeError), "in method '" "SipHeaderVector_erase" "', argument " "2"" of type '" "std::vector< pj::SipHeader >::iterator""'");
  } else {
    swig::SwigPyIterator_T<std::vector< pj::SipHeader >::iterator > *iter_t = dynamic_cast<swig::SwigPyIterator_T<std::vector< pj::SipHeader >::iterator > *>(iter2);
    if (iter_t) {
      arg2 = iter_t->get_current();
    } else {
      SWIG_exception_fail(SWIG_ArgError(SWIG_TypeError), "in method '" "SipHeaderVector_erase" "', argument " "2"" of type '" "std::vector< pj::SipHeader >::iterator""'");
    }
  }
  result = std_vector_Sl_pj_SipHeader_Sg__erase__SWIG_0(arg1,arg2);
  resultobj = SWIG_NewPointerObj(swig::make_output_iterator(static_cast< const std::vector< pj::SipHeader >::iterator & >(result)),
    swig::SwigPyIterator::descriptor(),SWIG_POINTER_OWN);
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_SipHeaderVector_erase__SWIG_1(PyObject *SWIGUNUSEDPARM(self), Py_ssize_t nobjs, PyObject **swig_obj) {
  PyObject *resultobj = 0;
  std::vector< pj::SipHeader > *arg1 = (std::vector< pj::SipHeader > *) 0 ;
  std::vector< pj::SipHeader >::iterator arg2 ;
  std::vector< pj::SipHeader >::iterator arg3 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  swig::SwigPyIterator *iter2 = 0 ;
  int res2 ;
  swig::SwigPyIterator *iter3 = 0 ;
  int res3 ;
  std::vector< pj::SipHeader >::iterator result;
  
  if ((nobjs < 3) || (nobjs > 3)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__vectorT_pj__SipHeader_std__allocatorT_pj__SipHeader_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "SipHeaderVector_erase" "', argument " "1"" of type '" "std::vector< pj::SipHeader > *""'"); 
  }
  arg1 = reinterpret_cast< std::vector< pj::SipHeader > * >(argp1);
  res2 = SWIG_ConvertPtr(swig_obj[1], SWIG_as_voidptrptr(&iter2), swig::SwigPyIterator::descriptor(), 0);
  if (!SWIG_IsOK(res2) || !iter2) {
    SWIG_exception_fail(SWIG_ArgError(SWIG_TypeError), "in method '" "SipHeaderVector_erase" "', argument " "2"" of type '" "std::vector< pj::SipHeader >::iterator""'");
  } else {
    swig::SwigPyIterator_T<std::vector< pj::SipHeader >::iterator > *iter_t = dynamic_cast<swig::SwigPyIterator_T<std::vector< pj::SipHeader >::iterator > *>(iter2);
    if (iter_t) {
      arg2 = iter_t->get_current();
    } else {
      SWIG_exception_fail(SWIG_ArgError(SWIG_TypeError), "in method '" "SipHeaderVector_erase" "', argument " "2"" of type '" "std::vector< pj::SipHeader >::iterator""'");
    }
  }
  res3 = SWIG_ConvertPtr(swig_obj[2], SWIG_as_voidptrptr(&iter3), swig::SwigPyIterator::descriptor(), 0);
  if (!SWIG_IsOK(res3) || !iter3) {
    SWIG_exception_fail(SWIG_ArgError(SWIG_TypeError), "in method '" "SipHeaderVector_erase" "', argument " "3"" of type '" "std::vector< pj::SipHeader >::iterator""'");
  } else {
    swig::SwigPyIterator_T<std::vector< pj::SipHeader >::iterator > *iter_t = dynamic_cast<swig::SwigPyIterator_T<std::vector< pj::SipHeader >::iterator > *>(iter3);
    if (iter_t) {
      arg3 = iter_t->get_current();
    } else {
      SWIG_exception_fail(SWIG_ArgError(SWIG_TypeError), "in method '" "SipHeaderVector_erase" "', argument " "3"" of type '" "std::vector< pj::SipHeader >::iterator""'");
    }
  }
  result = std_vector_Sl_pj_SipHeader_Sg__erase__SWIG_1(arg1,arg2,arg3);
  resultobj = SWIG_NewPointerObj(swig::make_output_iterator(static_cast< const std::vector< pj::SipHeader >::iterator & >(result)),
    swig::SwigPyIterator::descriptor(),SWIG_POINTER_OWN);
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_SipHeaderVector_erase(PyObject *self, PyObject *args) {
  Py_ssize_t argc;
  PyObject *argv[4] = {
    0
  };
  
  if (!(argc = SWIG_Python_UnpackTuple(args, "SipHeaderVector_erase", 0, 3, argv))) SWIG_fail;
  --argc;
  if (argc == 2) {
    int _v;
    int res = swig::asptr(argv[0], (std::vector< pj::SipHeader,std::allocator< pj::SipHeader > >**)(0));
    _v = SWIG_CheckState(res);
    if (_v) {
      swig::SwigPyIterator *iter = 0;
      int res = SWIG_ConvertPtr(argv[1], SWIG_as_voidptrptr(&iter), swig::SwigPyIterator::descriptor(), 0);
      _v = (SWIG_IsOK(res) && iter && (dynamic_cast<swig::SwigPyIterator_T<std::vector< pj::SipHeader >::iterator > *>(iter) != 0));
      if (_v) {
        return _wrap_SipHeaderVector_erase__SWIG_0(self, argc, argv);
      }
    }
  }
  if (argc == 3) {
    int _v;
    int res = swig::asptr(argv[0], (std::vector< pj::SipHeader,std::allocator< pj::SipHeader > >**)(0));
    _v = SWIG_CheckState(res);
    if (_v) {
      swig::SwigPyIterator *iter = 0;
      int res = SWIG_ConvertPtr(argv[1], SWIG_as_voidptrptr(&iter), swig::SwigPyIterator::descriptor(), 0);
      _v = (SWIG_IsOK(res) && iter && (dynamic_cast<swig::SwigPyIterator_T<std::vector< pj::SipHeader >::iterator > *>(iter) != 0));
      if (_v) {
        swig::SwigPyIterator *iter = 0;
        int res = SWIG_ConvertPtr(argv[2], SWIG_as_voidptrptr(&iter), swig::SwigPyIterator::descriptor(), 0);
        _v = (SWIG_IsOK(res) && iter && (dynamic_cast<swig::SwigPyIterator_T<std::vector< pj::SipHeader >::iterator > *>(iter) != 0));
        if (_v) {
          return _wrap_SipHeaderVector_erase__SWIG_1(self, argc, argv);
        }
      }
    }
  }
  
fail:
  SWIG_Python_RaiseOrModifyTypeError("Wrong number or type of arguments for overloaded function 'SipHeaderVector_erase'.\n"
    "  Possible C/C++ prototypes are:\n"
    "    std::vector< pj::SipHeader >::erase(std::vector< pj::SipHeader >::iterator)\n"
    "    std::vector< pj::SipHeader >::erase(std::vector< pj::SipHeader >::iterator,std::vector< pj::SipHeader >::iterator)\n");
  return 0;
}


SWIGINTERN PyObject *_wrap_new_SipHeaderVector__SWIG_3(PyObject *SWIGUNUSEDPARM(self), Py_ssize_t nobjs, PyObject **swig_obj) {
  PyObject *resultobj = 0;
  std::vector< pj::SipHeader >::size_type arg1 ;
  std::vector< pj::SipHeader >::value_type *arg2 = 0 ;
  size_t val1 ;
  int ecode1 = 0 ;
  void *argp2 = 0 ;
  int res2 = 0 ;
  std::vector< pj::SipHeader > *result = 0 ;
  
  if ((nobjs < 2) || (nobjs > 2)) SWIG_fail;
  ecode1 = SWIG_AsVal_size_t(swig_obj[0], &val1);
  if (!SWIG_IsOK(ecode1)) {
    SWIG_exception_fail(SWIG_ArgError(ecode1), "in method '" "new_SipHeaderVector" "', argument " "1"" of type '" "std::vector< pj::SipHeader >::size_type""'");
  } 
  arg1 = static_cast< std::vector< pj::SipHeader >::size_type >(val1);
  res2 = SWIG_ConvertPtr(swig_obj[1], &argp2, SWIGTYPE_p_pj__SipHeader,  0  | 0);
  if (!SWIG_IsOK(res2)) {
    SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "new_SipHeaderVector" "', argument " "2"" of type '" "std::vector< pj::SipHeader >::value_type const &""'"); 
  }
  if (!argp2) {
    SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "new_SipHeaderVector" "', argument " "2"" of type '" "std::vector< pj::SipHeader >::value_type const &""'"); 
  }
  arg2 = reinterpret_cast< std::vector< pj::SipHeader >::value_type * >(argp2);
  result = (std::vector< pj::SipHeader > *)new std::vector< pj::SipHeader >(arg1,(std::vector< pj::SipHeader >::value_type const &)*arg2);
  resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(result), SWIGTYPE_p_std__vectorT_pj__SipHeader_std__allocatorT_pj__SipHeader_t_t, SWIG_POINTER_NEW |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_new_SipHeaderVector(PyObject *self, PyObject *args) {
  Py_ssize_t argc;
  PyObject *argv[3] = {
    0
  };
  
  if (!(argc = SWIG_Python_UnpackTuple(args, "new_SipHeaderVector", 0, 2, argv))) SWIG_fail;
  --argc;
  if (argc == 0) {
    return _wrap_new_SipHeaderVector__SWIG_0(self, argc, argv);
  }
  if (argc == 1) {
    int _v;
    {
      int res = SWIG_AsVal_size_t(argv[0], NULL);
      _v = SWIG_CheckState(res);
    }
    if (_v) {
      return _wrap_new_SipHeaderVector__SWIG_2(self, argc, argv);
    }
  }
  if (argc == 1) {
    int _v;
    int res = swig::asptr(argv[0], (std::vector< pj::SipHeader,std::allocator< pj::SipHeader > >**)(0));
    _v = SWIG_CheckState(res);
    if (_v) {
      return _wrap_new_SipHeaderVector__SWIG_1(self, argc, argv);
    }
  }
  if (argc == 2) {
    int _v;
    {
      int res = SWIG_AsVal_size_t(argv[0], NULL);
      _v = SWIG_CheckState(res);
    }
    if (_v) {
      int res = SWIG_ConvertPtr(argv[1], 0, SWIGTYPE_p_pj__SipHeader, SWIG_POINTER_NO_NULL | 0);
      _v = SWIG_CheckState(res);
      if (_v) {
        return _wrap_new_SipHeaderVector__SWIG_3(self, argc, argv);
      }
    }
  }
  
fail:
  SWIG_Python_RaiseOrModifyTypeError("Wrong number or type of arguments for overloaded function 'new_SipHeaderVector'.\n"
    "  Possible C/C++ prototypes are:\n"
    "    std::vector< pj::SipHeader >::vector()\n"
    "    std::vector< pj::SipHeader >::vector(std::vector< pj::SipHeader > const &)\n"
    "    std::vector< pj::SipHeader >::vector(std::vector< pj::SipHeader >::size_type)\n"
    "    std::vector< pj::SipHeader >::vector(std::vector< pj::SipHeader >::size_type,std::vector< pj::SipHeader >::value_type const &)\n");
  return 0;
}


SWIGINTERN PyObject *_wrap_SipHeaderVector_push_back(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  std::vector< pj::SipHeader > *arg1 = (std::vector< pj::SipHeader > *) 0 ;
  std::vector< pj::SipHeader >::value_type *arg2 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  void *argp2 = 0 ;
  int res2 = 0 ;
  PyObject *swig_obj[2] ;
  
  if (!SWIG_Python_UnpackTuple(args, "SipHeaderVector_push_back", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__vectorT_pj__SipHeader_std__allocatorT_pj__SipHeader_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "SipHeaderVector_push_back" "', argument " "1"" of type '" "std::vector< pj::SipHeader > *""'"); 
  }
  arg1 = reinterpret_cast< std::vector< pj::SipHeader > * >(argp1);
  res2 = SWIG_ConvertPtr(swig_obj[1], &argp2, SWIGTYPE_p_pj__SipHeader,  0  | 0);
  if (!SWIG_IsOK(res2)) {
    SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "SipHeaderVector_push_back" "', argument " "2"" of type '" "std::vector< pj::SipHeader >::value_type const &""'"); 
  }
  if (!argp2) {
    SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "SipHeaderVector_push_back" "', argument " "2"" of type '" "std::vector< pj::SipHeader >::value_type const &""'"); 
  }
  arg2 = reinterpret_cast< std::vector< pj::SipHeader >::value_type * >(argp2);
  (arg1)->push_back((std::vector< pj::SipHeader >::value_type const &)*arg2);
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_SipHeaderVector_front(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  std::vector< pj::SipHeader > *arg1 = (std::vector< pj::SipHeader > *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  std::vector< pj::SipHeader >::value_type *result = 0 ;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__vectorT_pj__SipHeader_std__allocatorT_pj__SipHeader_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "SipHeaderVector_front" "', argument " "1"" of type '" "std::vector< pj::SipHeader > const *""'"); 
  }
  arg1 = reinterpret_cast< std::vector< pj::SipHeader > * >(argp1);
  result = (std::vector< pj::SipHeader >::value_type *) &((std::vector< pj::SipHeader > const *)arg1)->front();
  resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(result), SWIGTYPE_p_pj__SipHeader, 0 |  0 );
  (void)swig::container_owner<swig::traits<std::vector< pj::SipHeader >::value_type>::category>::back_reference(resultobj, swig_obj[0]);
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_SipHeaderVector_back(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  std::vector< pj::SipHeader > *arg1 = (std::vector< pj::SipHeader > *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  std::vector< pj::SipHeader >::value_type *result = 0 ;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__vectorT_pj__SipHeader_std__allocatorT_pj__SipHeader_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "SipHeaderVector_back" "', argument " "1"" of type '" "std::vector< pj::SipHeader > const *""'"); 
  }
  arg1 = reinterpret_cast< std::vector< pj::SipHeader > * >(argp1);
  result = (std::vector< pj::SipHeader >::value_type *) &((std::vector< pj::SipHeader > const *)arg1)->back();
  resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(result), SWIGTYPE_p_pj__SipHeader, 0 |  0 );
  (void)swig::container_owner<swig::traits<std::vector< pj::SipHeader >::value_type>::category>::back_reference(resultobj, swig_obj[0]);
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_SipHeaderVector_assign(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  std::vector< pj::SipHeader > *arg1 = (std::vector< pj::SipHeader > *) 0 ;
  std::vector< pj::SipHeader >::size_type arg2 ;
  std::vector< pj::SipHeader >::value_type *arg3 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  size_t val2 ;
  int ecode2 = 0 ;
  void *argp3 = 0 ;
  int res3 = 0 ;
  PyObject *swig_obj[3] ;
  
  if (!SWIG_Python_UnpackTuple(args, "SipHeaderVector_assign", 3, 3, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__vectorT_pj__SipHeader_std__allocatorT_pj__SipHeader_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "SipHeaderVector_assign" "', argument " "1"" of type '" "std::vector< pj::SipHeader > *""'"); 
  }
  arg1 = reinterpret_cast< std::vector< pj::SipHeader > * >(argp1);
  ecode2 = SWIG_AsVal_size_t(swig_obj[1], &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "SipHeaderVector_assign" "', argument " "2"" of type '" "std::vector< pj::SipHeader >::size_type""'");
  } 
  arg2 = static_cast< std::vector< pj::SipHeader >::size_type >(val2);
  res3 = SWIG_ConvertPtr(swig_obj[2], &argp3, SWIGTYPE_p_pj__SipHeader,  0  | 0);
  if (!SWIG_IsOK(res3)) {
    SWIG_exception_fail(SWIG_ArgError(res3), "in method '" "SipHeaderVector_assign" "', argument " "3"" of type '" "std::vector< pj::SipHeader >::value_type const &""'"); 
  }
  if (!argp3) {
    SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "SipHeaderVector_assign" "', argument " "3"" of type '" "std::vector< pj::SipHeader >::value_type const &""'"); 
  }
  arg3 = reinterpret_cast< std::vector< pj::SipHeader >::value_type * >(argp3);
  (arg1)->assign(arg2,(std::vector< pj::SipHeader >::value_type const &)*arg3);
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_SipHeaderVector_resize__SWIG_1(PyObject *SWIGUNUSEDPARM(self), Py_ssize_t nobjs, PyObject **swig_obj) {
  PyObject *resultobj = 0;
  std::vector< pj::SipHeader > *arg1 = (std::vector< pj::SipHeader > *) 0 ;
  std::vector< pj::SipHeader >::size_type arg2 ;
  std::vector< pj::SipHeader >::value_type *arg3 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  size_t val2 ;
  int ecode2 = 0 ;
  void *argp3 = 0 ;
  int res3 = 0 ;
  
  if ((nobjs < 3) || (nobjs > 3)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__vectorT_pj__SipHeader_std__allocatorT_pj__SipHeader_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "SipHeaderVector_resize" "', argument " "1"" of type '" "std::vector< pj::SipHeader > *""'"); 
  }
  arg1 = reinterpret_cast< std::vector< pj::SipHeader > * >(argp1);
  ecode2 = SWIG_AsVal_size_t(swig_obj[1], &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "SipHeaderVector_resize" "', argument " "2"" of type '" "std::vector< pj::SipHeader >::size_type""'");
  } 
  arg2 = static_cast< std::vector< pj::SipHeader >::size_type >(val2);
  res3 = SWIG_ConvertPtr(swig_obj[2], &argp3, SWIGTYPE_p_pj__SipHeader,  0  | 0);
  if (!SWIG_IsOK(res3)) {
    SWIG_exception_fail(SWIG_ArgError(res3), "in method '" "SipHeaderVector_resize" "', argument " "3"" of type '" "std::vector< pj::SipHeader >::value_type const &""'"); 
  }
  if (!argp3) {
    SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "SipHeaderVector_resize" "', argument " "3"" of type '" "std::vector< pj::SipHeader >::value_type const &""'"); 
  }
  arg3 = reinterpret_cast< std::vector< pj::SipHeader >::value_type * >(argp3);
  (arg1)->resize(arg2,(std::vector< pj::SipHeader >::value_type const &)*arg3);
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_SipHeaderVector_resize(PyObject *self, PyObject *args) {
  Py_ssize_t argc;
  PyObject *argv[4] = {
    0
  };
  
  if (!(argc = SWIG_Python_UnpackTuple(args, "SipHeaderVector_resize", 0, 3, argv))) SWIG_fail;
  --argc;
  if (argc == 2) {
    int _v;
    int res = swig::asptr(argv[0], (std::vector< pj::SipHeader,std::allocator< pj::SipHeader > >**)(0));
    _v = SWIG_CheckState(res);
    if (_v) {
      {
        int res = SWIG_AsVal_size_t(argv[1], NULL);
        _v = SWIG_CheckState(res);
      }
      if (_v) {
        return _wrap_SipHeaderVector_resize__SWIG_0(self, argc, argv);
      }
    }
  }
  if (argc == 3) {
    int _v;
    int res = swig::asptr(argv[0], (std::vector< pj::SipHeader,std::allocator< pj::SipHeader > >**)(0));
    _v = SWIG_CheckState(res);
    if (_v) {
      {
        int res = SWIG_AsVal_size_t(argv[1], NULL);
        _v = SWIG_CheckState(res);
      }
      if (_v) {
        int res = SWIG_ConvertPtr(argv[2], 0, SWIGTYPE_p_pj__SipHeader, SWIG_POINTER_NO_NULL | 0);
        _v = SWIG_CheckState(res);
        if (_v) {
          return _wrap_SipHeaderVector_resize__SWIG_1(self, argc, argv);
        }
      }
    }
  }
  
fail:
  SWIG_Python_RaiseOrModifyTypeError("Wrong number or type of arguments for overloaded function 'SipHeaderVector_resize'.\n"
    "  Possible C/C++ prototypes are:\n"
    "    std::vector< pj::SipHeader >::resize(std::vector< pj::SipHeader >::size_type)\n"
    "    std::vector< pj::SipHeader >::resize(std::vector< pj::SipHeader >::size_type,std::vector< pj::SipHeader >::value_type const &)\n");
  return 0;
}


SWIGINTERN PyObject *_wrap_SipHeaderVector_insert__SWIG_0(PyObject *SWIGUNUSEDPARM(self), Py_ssize_t nobjs, PyObject **swig_obj) {
  PyObject *resultobj = 0;
  std::vector< pj::SipHeader > *arg1 = (std::vector< pj::SipHeader > *) 0 ;
  std::vector< pj::SipHeader >::iterator arg2 ;
  std::vector< pj::SipHeader >::value_type *arg3 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  swig::SwigPyIterator *iter2 = 0 ;
  int res2 ;
  void *argp3 = 0 ;
  int res3 = 0 ;
  std::vector< pj::SipHeader >::iterator result;
  
  if ((nobjs < 3) || (nobjs > 3)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__vectorT_pj__SipHeader_std__allocatorT_pj__SipHeader_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "SipHeaderVector_insert" "', argument " "1"" of type '" "std::vector< pj::SipHeader > *""'"); 
  }
  arg1 = reinterpret_cast< std::vector< pj::SipHeader > * >(argp1);
  res2 = SWIG_ConvertPtr(swig_obj[1], SWIG_as_voidptrptr(&iter2), swig::SwigPyIterator::descriptor(), 0);
  if (!SWIG_IsOK(res2) || !iter2) {
    SWIG_exception_fail(SWIG_ArgError(SWIG_TypeError), "in method '" "SipHeaderVector_insert" "', argument " "2"" of type '" "std::vector< pj::SipHeader >::iterator""'");
  } else {
    swig::SwigPyIterator_T<std::vector< pj::SipHeader >::iterator > *iter_t = dynamic_cast<swig::SwigPyIterator_T<std::vector< pj::SipHeader >::iterator > *>(iter2);
    if (iter_t) {
      arg2 = iter_t->get_current();
    } else {
      SWIG_exception_fail(SWIG_ArgError(SWIG_TypeError), "in method '" "SipHeaderVector_insert" "', argument " "2"" of type '" "std::vector< pj::SipHeader >::iterator""'");
    }
  }
  res3 = SWIG_ConvertPtr(swig_obj[2], &argp3, SWIGTYPE_p_pj__SipHeader,  0  | 0);
  if (!SWIG_IsOK(res3)) {
    SWIG_exception_fail(SWIG_ArgError(res3), "in method '" "SipHeaderVector_insert" "', argument " "3"" of type '" "std::vector< pj::SipHeader >::value_type const &""'"); 
  }
  if (!argp3) {
    SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "SipHeaderVector_insert" "', argument " "3"" of type '" "std::vector< pj::SipHeader >::value_type const &""'"); 
  }
  arg3 = reinterpret_cast< std::vector< pj::SipHeader >::value_type * >(argp3);
  result = std_vector_Sl_pj_SipHeader_Sg__insert__SWIG_0(arg1,arg2,(pj::SipHeader const &)*arg3);
  resultobj = SWIG_NewPointerObj(swig::make_output_iterator(static_cast< const std::vector< pj::SipHeader >::iterator & >(result)),
    swig::SwigPyIterator::descriptor(),SWIG_POINTER_OWN);
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_SipHeaderVector_insert__SWIG_1(PyObject *SWIGUNUSEDPARM(self), Py_ssize_t nobjs, PyObject **swig_obj) {
  PyObject *resultobj = 0;
  std::vector< pj::SipHeader > *arg1 = (std::vector< pj::SipHeader > *) 0 ;
  std::vector< pj::SipHeader >::iterator arg2 ;
  std::vector< pj::SipHeader >::size_type arg3 ;
  std::vector< pj::SipHeader >::value_type *arg4 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  swig::SwigPyIterator *iter2 = 0 ;
  int res2 ;
  size_t val3 ;
  int ecode3 = 0 ;
  void *argp4 = 0 ;
  int res4 = 0 ;
  
  if ((nobjs < 4) || (nobjs > 4)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__vectorT_pj__SipHeader_std__allocatorT_pj__SipHeader_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "SipHeaderVector_insert" "', argument " "1"" of type '" "std::vector< pj::SipHeader > *""'"); 
  }
  arg1 = reinterpret_cast< std::vector< pj::SipHeader > * >(argp1);
  res2 = SWIG_ConvertPtr(swig_obj[1], SWIG_as_voidptrptr(&iter2), swig::SwigPyIterator::descriptor(), 0);
  if (!SWIG_IsOK(res2) || !iter2) {
    SWIG_exception_fail(SWIG_ArgError(SWIG_TypeError), "in method '" "SipHeaderVector_insert" "', argument " "2"" of type '" "std::vector< pj::SipHeader >::iterator""'");
  } else {
    swig::SwigPyIterator_T<std::vector< pj::SipHeader >::iterator > *iter_t = dynamic_cast<swig::SwigPyIterator_T<std::vector< pj::SipHeader >::iterator > *>(iter2);
    if (iter_t) {
      arg2 = iter_t->get_current();
    } else {
      SWIG_exception_fail(SWIG_ArgError(SWIG_TypeError), "in method '" "SipHeaderVector_insert" "', argument " "2"" of type '" "std::vector< pj::SipHeader >::iterator""'");
    }
  }
  ecode3 = SWIG_AsVal_size_t(swig_obj[2], &val3);
  if (!SWIG_IsOK(ecode3)) {
    SWIG_exception_fail(SWIG_ArgError(ecode3), "in method '" "SipHeaderVector_insert" "', argument " "3"" of type '" "std::vector< pj::SipHeader >::size_type""'");
  } 
  arg3 = static_cast< std::vector< pj::SipHeader >::size_type >(val3);
  res4 = SWIG_ConvertPtr(swig_obj[3], &argp4, SWIGTYPE_p_pj__SipHeader,  0  | 0);
  if (!SWIG_IsOK(res4)) {
    SWIG_exception_fail(SWIG_ArgError(res4), "in method '" "SipHeaderVector_insert" "', argument " "4"" of type '" "std::vector< pj::SipHeader >::value_type const &""'"); 
  }
  if (!argp4) {
    SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "SipHeaderVector_insert" "', argument " "4"" of type '" "std::vector< pj::SipHeader >::value_type const &""'"); 
  }
  arg4 = reinterpret_cast< std::vector< pj::SipHeader >::value_type * >(argp4);
  std_vector_Sl_pj_SipHeader_Sg__insert__SWIG_1(arg1,arg2,arg3,(pj::SipHeader const &)*arg4);
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_SipHeaderVector_insert(PyObject *self, PyObject *args) {
  Py_ssize_t argc;
  PyObject *argv[5] = {
    0
  };
  
  if (!(argc = SWIG_Python_UnpackTuple(args, "SipHeaderVector_insert", 0, 4, argv))) SWIG_fail;
  --argc;
  if (argc == 3) {
    int _v;
    int res = swig::asptr(argv[0], (std::vector< pj::SipHeader,std::allocator< pj::SipHeader > >**)(0));
    _v = SWIG_CheckState(res);
    if (_v) {
      swig::SwigPyIterator *iter = 0;
      int res = SWIG_ConvertPtr(argv[1], SWIG_as_voidptrptr(&iter), swig::SwigPyIterator::descriptor(), 0);
      _v = (SWIG_IsOK(res) && iter && (dynamic_cast<swig::SwigPyIterator_T<std::vector< pj::SipHeader >::iterator > *>(iter) != 0));
      if (_v) {
        int res = SWIG_ConvertPtr(argv[2], 0, SWIGTYPE_p_pj__SipHeader, SWIG_POINTER_NO_NULL | 0);
        _v = SWIG_CheckState(res);
        if (_v) {
          return _wrap_SipHeaderVector_insert__SWIG_0(self, argc, argv);
        }
      }
    }
  }
  if (argc == 4) {
    int _v;
    int res = swig::asptr(argv[0], (std::vector< pj::SipHeader,std::allocator< pj::SipHeader > >**)(0));
    _v = SWIG_CheckState(res);
    if (_v) {
      swig::SwigPyIterator *iter = 0;
      int res = SWIG_ConvertPtr(argv[1], SWIG_as_voidptrptr(&iter), swig::SwigPyIterator::descriptor(), 0);
      _v = (SWIG_IsOK(res) && iter && (dynamic_cast<swig::SwigPyIterator_T<std::vector< pj::SipHeader >::iterator > *>(iter) != 0));
      if (_v) {
        {
          int res = SWIG_AsVal_size_t(argv[2], NULL);
          _v = SWIG_CheckState(res);
        }
        if (_v) {
          int res = SWIG_ConvertPtr(argv[3], 0, SWIGTYPE_p_pj__SipHeader, SWIG_POINTER_NO_NULL | 0);
          _v = SWIG_CheckState(res);
          if (_v) {
            return _wrap_SipHeaderVector_insert__SWIG_1(self, argc, argv);
          }
        }
      }
    }
  }
  
fail:
  SWIG_Python_RaiseOrModifyTypeError("Wrong number or type of arguments for overloaded function 'SipHeaderVector_insert'.\n"
    "  Possible C/C++ prototypes are:\n"
    "    std::vector< pj::SipHeader >::insert(std::vector< pj::SipHeader >::iterator,std::vector< pj::SipHeader >::value_type const &)\n"
    "    std::vector< pj::SipHeader >::insert(std::vector< pj::SipHeader >::iterator,std::vector< pj::SipHeader >::size_type,std::vector< pj::SipHeader >::value_type const &)\n");
  return 0;
}


SWIGINTERN PyObject *_wrap_SipHeaderVector_reserve(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  std::vector< pj::SipHeader > *arg1 = (std::vector< pj::SipHeader > *) 0 ;
  std::vector< pj::SipHeader >::size_type arg2 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  size_t val2 ;
  int ecode2 = 0 ;
  PyObject *swig_obj[2] ;
  
  if (!SWIG_Python_UnpackTuple(args, "SipHeaderVector_reserve", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__vectorT_pj__SipHeader_std__allocatorT_pj__SipHeader_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "SipHeaderVector_reserve" "', argument " "1"" of type '" "std::vector< pj::SipHeader > *""'"); 
  }
  arg1 = reinterpret_cast< std::vector< pj::SipHeader > * >(argp1);
  ecode2 = SWIG_AsVal_size_t(swig_obj[1], &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "SipHeaderVector_reserve" "', argument " "2"" of type '" "std::vector< pj::SipHeader >::size_type""'");
  } 
  arg2 = static_cast< std::vector< pj::SipHeader >::size_type >(val2);
  (arg1)->reserve(arg2);
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_SipHeaderVector_capacity(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  std::vector< pj::SipHeader > *arg1 = (std::vector< pj::SipHeader > *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  std::vector< pj::SipHeader >::size_type result;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__vectorT_pj__SipHeader_std__allocatorT_pj__SipHeader_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "SipHeaderVector_capacity" "', argument " "1"" of type '" "std::vector< pj::SipHeader > const *""'"); 
  }
  arg1 = reinterpret_cast< std::vector< pj::SipHeader > * >(argp1);
  result = ((std::vector< pj::SipHeader > const *)arg1)->capacity();
  resultobj = SWIG_From_size_t(static_cast< size_t >(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_delete_SipHeaderVector(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  std::vector< pj::SipHeader > *arg1 = (std::vector< pj::SipHeader > *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__vectorT_pj__SipHeader_std__allocatorT_pj__SipHeader_t_t, SWIG_POINTER_DISOWN |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "delete_SipHeaderVector" "', argument " "1"" of type '" "std::vector< pj::SipHeader > *""'"); 
  }
  arg1 = reinterpret_cast< std::vector< pj::SipHeader > * >(argp1);
  delete arg1;
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *SipHeaderVector_swigregister(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *obj;
  if (!SWIG_Python_UnpackTuple(args, "swigregister", 1, 1, &obj)) return NULL;
  SWIG_TypeNewClientData(SWIGTYPE_p_std__vectorT_pj__SipHeader_std__allocatorT_pj__SipHeader_t_t, SWIG_NewClientData(obj));
  return SWIG_Py_Void();
}

SWIGINTERN PyObject *SipHeaderVector_swiginit(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  return SWIG_Python_InitShadowInstance(args);
}

SWIGINTERN PyObject *_wrap_AuthCredInfoVector_iterator(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  std::vector< pj::AuthCredInfo > *arg1 = (std::vector< pj::AuthCredInfo > *) 0 ;
  PyObject **arg2 = (PyObject **) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  swig::SwigPyIterator *result = 0 ;
  
  arg2 = &swig_obj[0];
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__vectorT_pj__AuthCredInfo_std__allocatorT_pj__AuthCredInfo_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "AuthCredInfoVector_iterator" "', argument " "1"" of type '" "std::vector< pj::AuthCredInfo > *""'"); 
  }
  arg1 = reinterpret_cast< std::vector< pj::AuthCredInfo > * >(argp1);
  result = (swig::SwigPyIterator *)std_vector_Sl_pj_AuthCredInfo_Sg__iterator(arg1,arg2);
  resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(result), SWIGTYPE_p_swig__SwigPyIterator, SWIG_POINTER_OWN |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_AuthCredInfoVector___nonzero__(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  std::vector< pj::AuthCredInfo > *arg1 = (std::vector< pj::AuthCredInfo > *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  bool result;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__vectorT_pj__AuthCredInfo_std__allocatorT_pj__AuthCredInfo_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "AuthCredInfoVector___nonzero__" "', argument " "1"" of type '" "std::vector< pj::AuthCredInfo > const *""'"); 
  }
  arg1 = reinterpret_cast< std::vector< pj::AuthCredInfo > * >(argp1);
  result = (bool)std_vector_Sl_pj_AuthCredInfo_Sg____nonzero__((std::vector< pj::AuthCredInfo > const *)arg1);
  resultobj = SWIG_From_bool(static_cast< bool >(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_AuthCredInfoVector___bool__(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  std::vector< pj::AuthCredInfo > *arg1 = (std::vector< pj::AuthCredInfo > *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  bool result;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__vectorT_pj__AuthCredInfo_std__allocatorT_pj__AuthCredInfo_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "AuthCredInfoVector___bool__" "', argument " "1"" of type '" "std::vector< pj::AuthCredInfo > const *""'"); 
  }
  arg1 = reinterpret_cast< std::vector< pj::AuthCredInfo > * >(argp1);
  result = (bool)std_vector_Sl_pj_AuthCredInfo_Sg____bool__((std::vector< pj::AuthCredInfo > const *)arg1);
  resultobj = SWIG_From_bool(static_cast< bool >(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_AuthCredInfoVector___len__(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  std::vector< pj::AuthCredInfo > *arg1 = (std::vector< pj::AuthCredInfo > *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  std::vector< pj::AuthCredInfo >::size_type result;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__vectorT_pj__AuthCredInfo_std__allocatorT_pj__AuthCredInfo_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "AuthCredInfoVector___len__" "', argument " "1"" of type '" "std::vector< pj::AuthCredInfo > const *""'"); 
  }
  arg1 = reinterpret_cast< std::vector< pj::AuthCredInfo > * >(argp1);
  result = std_vector_Sl_pj_AuthCredInfo_Sg____len__((std::vector< pj::AuthCredInfo > const *)arg1);
  resultobj = SWIG_From_size_t(static_cast< size_t >(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_AuthCredInfoVector___getslice__(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  std::vector< pj::AuthCredInfo > *arg1 = (std::vector< pj::AuthCredInfo > *) 0 ;
  std::vector< pj::AuthCredInfo >::difference_type arg2 ;
  std::vector< pj::AuthCredInfo >::difference_type arg3 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  ptrdiff_t val2 ;
  int ecode2 = 0 ;
  ptrdiff_t val3 ;
  int ecode3 = 0 ;
  PyObject *swig_obj[3] ;
  std::vector< pj::AuthCredInfo,std::allocator< pj::AuthCredInfo > > *result = 0 ;
  
  if (!SWIG_Python_UnpackTuple(args, "AuthCredInfoVector___getslice__", 3, 3, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__vectorT_pj__AuthCredInfo_std__allocatorT_pj__AuthCredInfo_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "AuthCredInfoVector___getslice__" "', argument " "1"" of type '" "std::vector< pj::AuthCredInfo > *""'"); 
  }
  arg1 = reinterpret_cast< std::vector< pj::AuthCredInfo > * >(argp1);
  ecode2 = SWIG_AsVal_ptrdiff_t(swig_obj[1], &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "AuthCredInfoVector___getslice__" "', argument " "2"" of type '" "std::vector< pj::AuthCredInfo >::difference_type""'");
  } 
  arg2 = static_cast< std::vector< pj::AuthCredInfo >::difference_type >(val2);
  ecode3 = SWIG_AsVal_ptrdiff_t(swig_obj[2], &val3);
  if (!SWIG_IsOK(ecode3)) {
    SWIG_exception_fail(SWIG_ArgError(ecode3), "in method '" "AuthCredInfoVector___getslice__" "', argument " "3"" of type '" "std::vector< pj::AuthCredInfo >::difference_type""'");
  } 
  arg3 = static_cast< std::vector< pj::AuthCredInfo >::difference_type >(val3);
  try {
    result = (std::vector< pj::AuthCredInfo,std::allocator< pj::AuthCredInfo > > *)std_vector_Sl_pj_AuthCredInfo_Sg____getslice__(arg1,arg2,arg3);
  } catch(std::out_of_range &_e) {
    SWIG_exception_fail(SWIG_IndexError, (&_e)->what());
  } catch(std::invalid_argument &_e) {
    SWIG_exception_fail(SWIG_ValueError, (&_e)->what());
  }
  resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(result), SWIGTYPE_p_std__vectorT_pj__AuthCredInfo_std__allocatorT_pj__AuthCredInfo_t_t, SWIG_POINTER_OWN |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_AuthCredInfoVector___setslice____SWIG_0(PyObject *SWIGUNUSEDPARM(self), Py_ssize_t nobjs, PyObject **swig_obj) {
  PyObject *resultobj = 0;
  std::vector< pj::AuthCredInfo > *arg1 = (std::vector< pj::AuthCredInfo > *) 0 ;
  std::vector< pj::AuthCredInfo >::difference_type arg2 ;
  std::vector< pj::AuthCredInfo >::difference_type arg3 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  ptrdiff_t val2 ;
  int ecode2 = 0 ;
  ptrdiff_t val3 ;
  int ecode3 = 0 ;
  
  if ((nobjs < 3) || (nobjs > 3)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__vectorT_pj__AuthCredInfo_std__allocatorT_pj__AuthCredInfo_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "AuthCredInfoVector___setslice__" "', argument " "1"" of type '" "std::vector< pj::AuthCredInfo > *""'"); 
  }
  arg1 = reinterpret_cast< std::vector< pj::AuthCredInfo > * >(argp1);
  ecode2 = SWIG_AsVal_ptrdiff_t(swig_obj[1], &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "AuthCredInfoVector___setslice__" "', argument " "2"" of type '" "std::vector< pj::AuthCredInfo >::difference_type""'");
  } 
  arg2 = static_cast< std::vector< pj::AuthCredInfo >::difference_type >(val2);
  ecode3 = SWIG_AsVal_ptrdiff_t(swig_obj[2], &val3);
  if (!SWIG_IsOK(ecode3)) {
    SWIG_exception_fail(SWIG_ArgError(ecode3), "in method '" "AuthCredInfoVector___setslice__" "', argument " "3"" of type '" "std::vector< pj::AuthCredInfo >::difference_type""'");
  } 
  arg3 = static_cast< std::vector< pj::AuthCredInfo >::difference_type >(val3);
  try {
    std_vector_Sl_pj_AuthCredInfo_Sg____setslice____SWIG_0(arg1,arg2,arg3);
  } catch(std::out_of_range &_e) {
    SWIG_exception_fail(SWIG_IndexError, (&_e)->what());
  } catch(std::invalid_argument &_e) {
    SWIG_exception_fail(SWIG_ValueError, (&_e)->what());
  }
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_AuthCredInfoVector___setslice____SWIG_1(PyObject *SWIGUNUSEDPARM(self), Py_ssize_t nobjs, PyObject **swig_obj) {
  PyObject *resultobj = 0;
  std::vector< pj::AuthCredInfo > *arg1 = (std::vector< pj::AuthCredInfo > *) 0 ;
  std::vector< pj::AuthCredInfo >::difference_type arg2 ;
  std::vector< pj::AuthCredInfo >::difference_type arg3 ;
  std::vector< pj::AuthCredInfo,std::allocator< pj::AuthCredInfo > > *arg4 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  ptrdiff_t val2 ;
  int ecode2 = 0 ;
  ptrdiff_t val3 ;
  int ecode3 = 0 ;
  int res4 = SWIG_OLDOBJ ;
  
  if ((nobjs < 4) || (nobjs > 4)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__vectorT_pj__AuthCredInfo_std__allocatorT_pj__AuthCredInfo_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "AuthCredInfoVector___setslice__" "', argument " "1"" of type '" "std::vector< pj::AuthCredInfo > *""'"); 
  }
  arg1 = reinterpret_cast< std::vector< pj::AuthCredInfo > * >(argp1);
  ecode2 = SWIG_AsVal_ptrdiff_t(swig_obj[1], &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "AuthCredInfoVector___setslice__" "', argument " "2"" of type '" "std::vector< pj::AuthCredInfo >::difference_type""'");
  } 
  arg2 = static_cast< std::vector< pj::AuthCredInfo >::difference_type >(val2);
  ecode3 = SWIG_AsVal_ptrdiff_t(swig_obj[2], &val3);
  if (!SWIG_IsOK(ecode3)) {
    SWIG_exception_fail(SWIG_ArgError(ecode3), "in method '" "AuthCredInfoVector___setslice__" "', argument " "3"" of type '" "std::vector< pj::AuthCredInfo >::difference_type""'");
  } 
  arg3 = static_cast< std::vector< pj::AuthCredInfo >::difference_type >(val3);
  {
    std::vector< pj::AuthCredInfo,std::allocator< pj::AuthCredInfo > > *ptr = (std::vector< pj::AuthCredInfo,std::allocator< pj::AuthCredInfo > > *)0;
    res4 = swig::asptr(swig_obj[3], &ptr);
    if (!SWIG_IsOK(res4)) {
      SWIG_exception_fail(SWIG_ArgError(res4), "in method '" "AuthCredInfoVector___setslice__" "', argument " "4"" of type '" "std::vector< pj::AuthCredInfo,std::allocator< pj::AuthCredInfo > > const &""'"); 
    }
    if (!ptr) {
      SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "AuthCredInfoVector___setslice__" "', argument " "4"" of type '" "std::vector< pj::AuthCredInfo,std::allocator< pj::AuthCredInfo > > const &""'"); 
    }
    arg4 = ptr;
  }
  try {
    std_vector_Sl_pj_AuthCredInfo_Sg____setslice____SWIG_1(arg1,arg2,arg3,(std::vector< pj::AuthCredInfo,std::allocator< pj::AuthCredInfo > > const &)*arg4);
  } catch(std::out_of_range &_e) {
    SWIG_exception_fail(SWIG_IndexError, (&_e)->what());
  } catch(std::invalid_argument &_e) {
    SWIG_exception_fail(SWIG_ValueError, (&_e)->what());
  }
  resultobj = SWIG_Py_Void();
  if (SWIG_IsNewObj(res4)) delete arg4;
  return resultobj;
fail:
  if (SWIG_IsNewObj(res4)) delete arg4;
  return NULL;
}


SWIGINTERN PyObject *_wrap_AuthCredInfoVector___setslice__(PyObject *self, PyObject *args) {
  Py_ssize_t argc;
  PyObject *argv[5] = {
    0
  };
  
  if (!(argc = SWIG_Python_UnpackTuple(args, "AuthCredInfoVector___setslice__", 0, 4, argv))) SWIG_fail;
  --argc;
  if (argc == 3) {
    int _v;
    int res = swig::asptr(argv[0], (std::vector< pj::AuthCredInfo,std::allocator< pj::AuthCredInfo > >**)(0));
    _v = SWIG_CheckState(res);
    if (_v) {
      {
        int res = SWIG_AsVal_ptrdiff_t(argv[1], NULL);
        _v = SWIG_CheckState(res);
      }
      if (_v) {
        {
          int res = SWIG_AsVal_ptrdiff_t(argv[2], NULL);
          _v = SWIG_CheckState(res);
        }
        if (_v) {
          return _wrap_AuthCredInfoVector___setslice____SWIG_0(self, argc, argv);
        }
      }
    }
  }
  if (argc == 4) {
    int _v;
    int res = swig::asptr(argv[0], (std::vector< pj::AuthCredInfo,std::allocator< pj::AuthCredInfo > >**)(0));
    _v = SWIG_CheckState(res);
    if (_v) {
      {
        int res = SWIG_AsVal_ptrdiff_t(argv[1], NULL);
        _v = SWIG_CheckState(res);
      }
      if (_v) {
        {
          int res = SWIG_AsVal_ptrdiff_t(argv[2], NULL);
          _v = SWIG_CheckState(res);
        }
        if (_v) {
          int res = swig::asptr(argv[3], (std::vector< pj::AuthCredInfo,std::allocator< pj::AuthCredInfo > >**)(0));
          _v = SWIG_CheckState(res);
          if (_v) {
            return _wrap_AuthCredInfoVector___setslice____SWIG_1(self, argc, argv);
          }
        }
      }
    }
  }
  
fail:
  SWIG_Python_RaiseOrModifyTypeError("Wrong number or type of arguments for overloaded function 'AuthCredInfoVector___setslice__'.\n"
    "  Possible C/C++ prototypes are:\n"
    "    std::vector< pj::AuthCredInfo >::__setslice__(std::vector< pj::AuthCredInfo >::difference_type,std::vector< pj::AuthCredInfo >::difference_type)\n"
    "    std::vector< pj::AuthCredInfo >::__setslice__(std::vector< pj::AuthCredInfo >::difference_type,std::vector< pj::AuthCredInfo >::difference_type,std::vector< pj::AuthCredInfo,std::allocator< pj::AuthCredInfo > > const &)\n");
  return 0;
}


SWIGINTERN PyObject *_wrap_AuthCredInfoVector___delslice__(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  std::vector< pj::AuthCredInfo > *arg1 = (std::vector< pj::AuthCredInfo > *) 0 ;
  std::vector< pj::AuthCredInfo >::difference_type arg2 ;
  std::vector< pj::AuthCredInfo >::difference_type arg3 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  ptrdiff_t val2 ;
  int ecode2 = 0 ;
  ptrdiff_t val3 ;
  int ecode3 = 0 ;
  PyObject *swig_obj[3] ;
  
  if (!SWIG_Python_UnpackTuple(args, "AuthCredInfoVector___delslice__", 3, 3, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__vectorT_pj__AuthCredInfo_std__allocatorT_pj__AuthCredInfo_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "AuthCredInfoVector___delslice__" "', argument " "1"" of type '" "std::vector< pj::AuthCredInfo > *""'"); 
  }
  arg1 = reinterpret_cast< std::vector< pj::AuthCredInfo > * >(argp1);
  ecode2 = SWIG_AsVal_ptrdiff_t(swig_obj[1], &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "AuthCredInfoVector___delslice__" "', argument " "2"" of type '" "std::vector< pj::AuthCredInfo >::difference_type""'");
  } 
  arg2 = static_cast< std::vector< pj::AuthCredInfo >::difference_type >(val2);
  ecode3 = SWIG_AsVal_ptrdiff_t(swig_obj[2], &val3);
  if (!SWIG_IsOK(ecode3)) {
    SWIG_exception_fail(SWIG_ArgError(ecode3), "in method '" "AuthCredInfoVector___delslice__" "', argument " "3"" of type '" "std::vector< pj::AuthCredInfo >::difference_type""'");
  } 
  arg3 = static_cast< std::vector< pj::AuthCredInfo >::difference_type >(val3);
  try {
    std_vector_Sl_pj_AuthCredInfo_Sg____delslice__(arg1,arg2,arg3);
  } catch(std::out_of_range &_e) {
    SWIG_exception_fail(SWIG_IndexError, (&_e)->what());
  } catch(std::invalid_argument &_e) {
    SWIG_exception_fail(SWIG_ValueError, (&_e)->what());
  }
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_AuthCredInfoVector___delitem____SWIG_0(PyObject *SWIGUNUSEDPARM(self), Py_ssize_t nobjs, PyObject **swig_obj) {
  PyObject *resultobj = 0;
  std::vector< pj::AuthCredInfo > *arg1 = (std::vector< pj::AuthCredInfo > *) 0 ;
  std::vector< pj::AuthCredInfo >::difference_type arg2 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  ptrdiff_t val2 ;
  int ecode2 = 0 ;
  
  if ((nobjs < 2) || (nobjs > 2)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__vectorT_pj__AuthCredInfo_std__allocatorT_pj__AuthCredInfo_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "AuthCredInfoVector___delitem__" "', argument " "1"" of type '" "std::vector< pj::AuthCredInfo > *""'"); 
  }
  arg1 = reinterpret_cast< std::vector< pj::AuthCredInfo > * >(argp1);
  ecode2 = SWIG_AsVal_ptrdiff_t(swig_obj[1], &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "AuthCredInfoVector___delitem__" "', argument " "2"" of type '" "std::vector< pj::AuthCredInfo >::difference_type""'");
  } 
  arg2 = static_cast< std::vector< pj::AuthCredInfo >::difference_type >(val2);
  try {
    std_vector_Sl_pj_AuthCredInfo_Sg____delitem____SWIG_0(arg1,arg2);
  } catch(std::out_of_range &_e) {
    SWIG_exception_fail(SWIG_IndexError, (&_e)->what());
  } catch(std::invalid_argument &_e) {
    SWIG_exception_fail(SWIG_ValueError, (&_e)->what());
  }
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_AuthCredInfoVector___getitem____SWIG_0(PyObject *SWIGUNUSEDPARM(self), Py_ssize_t nobjs, PyObject **swig_obj) {
  PyObject *resultobj = 0;
  std::vector< pj::AuthCredInfo > *arg1 = (std::vector< pj::AuthCredInfo > *) 0 ;
  PySliceObject *arg2 = (PySliceObject *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  std::vector< pj::AuthCredInfo,std::allocator< pj::AuthCredInfo > > *result = 0 ;
  
  if ((nobjs < 2) || (nobjs > 2)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__vectorT_pj__AuthCredInfo_std__allocatorT_pj__AuthCredInfo_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "AuthCredInfoVector___getitem__" "', argument " "1"" of type '" "std::vector< pj::AuthCredInfo > *""'"); 
  }
  arg1 = reinterpret_cast< std::vector< pj::AuthCredInfo > * >(argp1);
  {
    if (!PySlice_Check(swig_obj[1])) {
      SWIG_exception_fail(SWIG_ArgError(SWIG_TypeError), "in method '" "AuthCredInfoVector___getitem__" "', argument " "2"" of type '" "PySliceObject *""'");
    }
    arg2 = (PySliceObject *) swig_obj[1];
  }
  try {
    result = (std::vector< pj::AuthCredInfo,std::allocator< pj::AuthCredInfo > > *)std_vector_Sl_pj_AuthCredInfo_Sg____getitem____SWIG_0(arg1,arg2);
  } catch(std::out_of_range &_e) {
    SWIG_exception_fail(SWIG_IndexError, (&_e)->what());
  } catch(std::invalid_argument &_e) {
    SWIG_exception_fail(SWIG_ValueError, (&_e)->what());
  }
  resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(result), SWIGTYPE_p_std__vectorT_pj__AuthCredInfo_std__allocatorT_pj__AuthCredInfo_t_t, SWIG_POINTER_OWN |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_AuthCredInfoVector___setitem____SWIG_0(PyObject *SWIGUNUSEDPARM(self), Py_ssize_t nobjs, PyObject **swig_obj) {
  PyObject *resultobj = 0;
  std::vector< pj::AuthCredInfo > *arg1 = (std::vector< pj::AuthCredInfo > *) 0 ;
  PySliceObject *arg2 = (PySliceObject *) 0 ;
  std::vector< pj::AuthCredInfo,std::allocator< pj::AuthCredInfo > > *arg3 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  int res3 = SWIG_OLDOBJ ;
  
  if ((nobjs < 3) || (nobjs > 3)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__vectorT_pj__AuthCredInfo_std__allocatorT_pj__AuthCredInfo_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "AuthCredInfoVector___setitem__" "', argument " "1"" of type '" "std::vector< pj::AuthCredInfo > *""'"); 
  }
  arg1 = reinterpret_cast< std::vector< pj::AuthCredInfo > * >(argp1);
  {
    if (!PySlice_Check(swig_obj[1])) {
      SWIG_exception_fail(SWIG_ArgError(SWIG_TypeError), "in method '" "AuthCredInfoVector___setitem__" "', argument " "2"" of type '" "PySliceObject *""'");
    }
    arg2 = (PySliceObject *) swig_obj[1];
  }
  {
    std::vector< pj::AuthCredInfo,std::allocator< pj::AuthCredInfo > > *ptr = (std::vector< pj::AuthCredInfo,std::allocator< pj::AuthCredInfo > > *)0;
    res3 = swig::asptr(swig_obj[2], &ptr);
    if (!SWIG_IsOK(res3)) {
      SWIG_exception_fail(SWIG_ArgError(res3), "in method '" "AuthCredInfoVector___setitem__" "', argument " "3"" of type '" "std::vector< pj::AuthCredInfo,std::allocator< pj::AuthCredInfo > > const &""'"); 
    }
    if (!ptr) {
      SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "AuthCredInfoVector___setitem__" "', argument " "3"" of type '" "std::vector< pj::AuthCredInfo,std::allocator< pj::AuthCredInfo > > const &""'"); 
    }
    arg3 = ptr;
  }
  try {
    std_vector_Sl_pj_AuthCredInfo_Sg____setitem____SWIG_0(arg1,arg2,(std::vector< pj::AuthCredInfo,std::allocator< pj::AuthCredInfo > > const &)*arg3);
  } catch(std::out_of_range &_e) {
    SWIG_exception_fail(SWIG_IndexError, (&_e)->what());
  } catch(std::invalid_argument &_e) {
    SWIG_exception_fail(SWIG_ValueError, (&_e)->what());
  }
  resultobj = SWIG_Py_Void();
  if (SWIG_IsNewObj(res3)) delete arg3;
  return resultobj;
fail:
  if (SWIG_IsNewObj(res3)) delete arg3;
  return NULL;
}


SWIGINTERN PyObject *_wrap_AuthCredInfoVector___setitem____SWIG_1(PyObject *SWIGUNUSEDPARM(self), Py_ssize_t nobjs, PyObject **swig_obj) {
  PyObject *resultobj = 0;
  std::vector< pj::AuthCredInfo > *arg1 = (std::vector< pj::AuthCredInfo > *) 0 ;
  PySliceObject *arg2 = (PySliceObject *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  
  if ((nobjs < 2) || (nobjs > 2)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__vectorT_pj__AuthCredInfo_std__allocatorT_pj__AuthCredInfo_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "AuthCredInfoVector___setitem__" "', argument " "1"" of type '" "std::vector< pj::AuthCredInfo > *""'"); 
  }
  arg1 = reinterpret_cast< std::vector< pj::AuthCredInfo > * >(argp1);
  {
    if (!PySlice_Check(swig_obj[1])) {
      SWIG_exception_fail(SWIG_ArgError(SWIG_TypeError), "in method '" "AuthCredInfoVector___setitem__" "', argument " "2"" of type '" "PySliceObject *""'");
    }
    arg2 = (PySliceObject *) swig_obj[1];
  }
  try {
    std_vector_Sl_pj_AuthCredInfo_Sg____setitem____SWIG_1(arg1,arg2);
  } catch(std::out_of_range &_e) {
    SWIG_exception_fail(SWIG_IndexError, (&_e)->what());
  } catch(std::invalid_argument &_e) {
    SWIG_exception_fail(SWIG_ValueError, (&_e)->what());
  }
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_AuthCredInfoVector___delitem____SWIG_1(PyObject *SWIGUNUSEDPARM(self), Py_ssize_t nobjs, PyObject **swig_obj) {
  PyObject *resultobj = 0;
  std::vector< pj::AuthCredInfo > *arg1 = (std::vector< pj::AuthCredInfo > *) 0 ;
  PySliceObject *arg2 = (PySliceObject *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  
  if ((nobjs < 2) || (nobjs > 2)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__vectorT_pj__AuthCredInfo_std__allocatorT_pj__AuthCredInfo_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "AuthCredInfoVector___delitem__" "', argument " "1"" of type '" "std::vector< pj::AuthCredInfo > *""'"); 
  }
  arg1 = reinterpret_cast< std::vector< pj::AuthCredInfo > * >(argp1);
  {
    if (!PySlice_Check(swig_obj[1])) {
      SWIG_exception_fail(SWIG_ArgError(SWIG_TypeError), "in method '" "AuthCredInfoVector___delitem__" "', argument " "2"" of type '" "PySliceObject *""'");
    }
    arg2 = (PySliceObject *) swig_obj[1];
  }
  try {
    std_vector_Sl_pj_AuthCredInfo_Sg____delitem____SWIG_1(arg1,arg2);
  } catch(std::out_of_range &_e) {
    SWIG_exception_fail(SWIG_IndexError, (&_e)->what());
  } catch(std::invalid_argument &_e) {
    SWIG_exception_fail(SWIG_ValueError, (&_e)->what());
  }
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_AuthCredInfoVector___delitem__(PyObject *self, PyObject *args) {
  Py_ssize_t argc;
  PyObject *argv[3] = {
    0
  };
  
  if (!(argc = SWIG_Python_UnpackTuple(args, "AuthCredInfoVector___delitem__", 0, 2, argv))) SWIG_fail;
  --argc;
  if (argc == 2) {
    int _v;
    int res = swig::asptr(argv[0], (std::vector< pj::AuthCredInfo,std::allocator< pj::AuthCredInfo > >**)(0));
    _v = SWIG_CheckState(res);
    if (_v) {
      {
        _v = PySlice_Check(argv[1]);
      }
      if (_v) {
        return _wrap_AuthCredInfoVector___delitem____SWIG_1(self, argc, argv);
      }
    }
  }
  if (argc == 2) {
    int _v;
    int res = swig::asptr(argv[0], (std::vector< pj::AuthCredInfo,std::allocator< pj::AuthCredInfo > >**)(0));
    _v = SWIG_CheckState(res);
    if (_v) {
      {
        int res = SWIG_AsVal_ptrdiff_t(argv[1], NULL);
        _v = SWIG_CheckState(res);
      }
      if (_v) {
        return _wrap_AuthCredInfoVector___delitem____SWIG_0(self, argc, argv);
      }
    }
  }
  
fail:
  SWIG_Python_RaiseOrModifyTypeError("Wrong number or type of arguments for overloaded function 'AuthCredInfoVector___delitem__'.\n"
    "  Possible C/C++ prototypes are:\n"
    "    std::vector< pj::AuthCredInfo >::__delitem__(std::vector< pj::AuthCredInfo >::difference_type)\n"
    "    std::vector< pj::AuthCredInfo >::__delitem__(PySliceObject *)\n");
  return 0;
}


SWIGINTERN PyObject *_wrap_AuthCredInfoVector___getitem____SWIG_1(PyObject *SWIGUNUSEDPARM(self), Py_ssize_t nobjs, PyObject **swig_obj) {
  PyObject *resultobj = 0;
  std::vector< pj::AuthCredInfo > *arg1 = (std::vector< pj::AuthCredInfo > *) 0 ;
  std::vector< pj::AuthCredInfo >::difference_type arg2 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  ptrdiff_t val2 ;
  int ecode2 = 0 ;
  std::vector< pj::AuthCredInfo >::value_type *result = 0 ;
  
  if ((nobjs < 2) || (nobjs > 2)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__vectorT_pj__AuthCredInfo_std__allocatorT_pj__AuthCredInfo_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "AuthCredInfoVector___getitem__" "', argument " "1"" of type '" "std::vector< pj::AuthCredInfo > const *""'"); 
  }
  arg1 = reinterpret_cast< std::vector< pj::AuthCredInfo > * >(argp1);
  ecode2 = SWIG_AsVal_ptrdiff_t(swig_obj[1], &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "AuthCredInfoVector___getitem__" "', argument " "2"" of type '" "std::vector< pj::AuthCredInfo >::difference_type""'");
  } 
  arg2 = static_cast< std::vector< pj::AuthCredInfo >::difference_type >(val2);
  try {
    result = (std::vector< pj::AuthCredInfo >::value_type *) &std_vector_Sl_pj_AuthCredInfo_Sg____getitem____SWIG_1((std::vector< pj::AuthCredInfo > const *)arg1,arg2);
  } catch(std::out_of_range &_e) {
    SWIG_exception_fail(SWIG_IndexError, (&_e)->what());
  }
  resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(result), SWIGTYPE_p_pj__AuthCredInfo, 0 |  0 );
  (void)swig::container_owner<swig::traits<std::vector< pj::AuthCredInfo >::value_type>::category>::back_reference(resultobj, swig_obj[0]);
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_AuthCredInfoVector___getitem__(PyObject *self, PyObject *args) {
  Py_ssize_t argc;
  PyObject *argv[3] = {
    0
  };
  
  if (!(argc = SWIG_Python_UnpackTuple(args, "AuthCredInfoVector___getitem__", 0, 2, argv))) SWIG_fail;
  --argc;
  if (argc == 2) {
    int _v;
    int res = swig::asptr(argv[0], (std::vector< pj::AuthCredInfo,std::allocator< pj::AuthCredInfo > >**)(0));
    _v = SWIG_CheckState(res);
    if (_v) {
      {
        _v = PySlice_Check(argv[1]);
      }
      if (_v) {
        return _wrap_AuthCredInfoVector___getitem____SWIG_0(self, argc, argv);
      }
    }
  }
  if (argc == 2) {
    int _v;
    int res = swig::asptr(argv[0], (std::vector< pj::AuthCredInfo,std::allocator< pj::AuthCredInfo > >**)(0));
    _v = SWIG_CheckState(res);
    if (_v) {
      {
        int res = SWIG_AsVal_ptrdiff_t(argv[1], NULL);
        _v = SWIG_CheckState(res);
      }
      if (_v) {
        return _wrap_AuthCredInfoVector___getitem____SWIG_1(self, argc, argv);
      }
    }
  }
  
fail:
  SWIG_Python_RaiseOrModifyTypeError("Wrong number or type of arguments for overloaded function 'AuthCredInfoVector___getitem__'.\n"
    "  Possible C/C++ prototypes are:\n"
    "    std::vector< pj::AuthCredInfo >::__getitem__(PySliceObject *)\n"
    "    std::vector< pj::AuthCredInfo >::__getitem__(std::vector< pj::AuthCredInfo >::difference_type) const\n");
  return 0;
}


SWIGINTERN PyObject *_wrap_AuthCredInfoVector___setitem____SWIG_2(PyObject *SWIGUNUSEDPARM(self), Py_ssize_t nobjs, PyObject **swig_obj) {
  PyObject *resultobj = 0;
  std::vector< pj::AuthCredInfo > *arg1 = (std::vector< pj::AuthCredInfo > *) 0 ;
  std::vector< pj::AuthCredInfo >::difference_type arg2 ;
  std::vector< pj::AuthCredInfo >::value_type *arg3 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  ptrdiff_t val2 ;
  int ecode2 = 0 ;
  void *argp3 = 0 ;
  int res3 = 0 ;
  
  if ((nobjs < 3) || (nobjs > 3)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__vectorT_pj__AuthCredInfo_std__allocatorT_pj__AuthCredInfo_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "AuthCredInfoVector___setitem__" "', argument " "1"" of type '" "std::vector< pj::AuthCredInfo > *""'"); 
  }
  arg1 = reinterpret_cast< std::vector< pj::AuthCredInfo > * >(argp1);
  ecode2 = SWIG_AsVal_ptrdiff_t(swig_obj[1], &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "AuthCredInfoVector___setitem__" "', argument " "2"" of type '" "std::vector< pj::AuthCredInfo >::difference_type""'");
  } 
  arg2 = static_cast< std::vector< pj::AuthCredInfo >::difference_type >(val2);
  res3 = SWIG_ConvertPtr(swig_obj[2], &argp3, SWIGTYPE_p_pj__AuthCredInfo,  0  | 0);
  if (!SWIG_IsOK(res3)) {
    SWIG_exception_fail(SWIG_ArgError(res3), "in method '" "AuthCredInfoVector___setitem__" "', argument " "3"" of type '" "std::vector< pj::AuthCredInfo >::value_type const &""'"); 
  }
  if (!argp3) {
    SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "AuthCredInfoVector___setitem__" "', argument " "3"" of type '" "std::vector< pj::AuthCredInfo >::value_type const &""'"); 
  }
  arg3 = reinterpret_cast< std::vector< pj::AuthCredInfo >::value_type * >(argp3);
  try {
    std_vector_Sl_pj_AuthCredInfo_Sg____setitem____SWIG_2(arg1,arg2,(pj::AuthCredInfo const &)*arg3);
  } catch(std::out_of_range &_e) {
    SWIG_exception_fail(SWIG_IndexError, (&_e)->what());
  }
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_AuthCredInfoVector___setitem__(PyObject *self, PyObject *args) {
  Py_ssize_t argc;
  PyObject *argv[4] = {
    0
  };
  
  if (!(argc = SWIG_Python_UnpackTuple(args, "AuthCredInfoVector___setitem__", 0, 3, argv))) SWIG_fail;
  --argc;
  if (argc == 2) {
    int _v;
    int res = swig::asptr(argv[0], (std::vector< pj::AuthCredInfo,std::allocator< pj::AuthCredInfo > >**)(0));
    _v = SWIG_CheckState(res);
    if (_v) {
      {
        _v = PySlice_Check(argv[1]);
      }
      if (_v) {
        return _wrap_AuthCredInfoVector___setitem____SWIG_1(self, argc, argv);
      }
    }
  }
  if (argc == 3) {
    int _v;
    int res = swig::asptr(argv[0], (std::vector< pj::AuthCredInfo,std::allocator< pj::AuthCredInfo > >**)(0));
    _v = SWIG_CheckState(res);
    if (_v) {
      {
        _v = PySlice_Check(argv[1]);
      }
      if (_v) {
        int res = swig::asptr(argv[2], (std::vector< pj::AuthCredInfo,std::allocator< pj::AuthCredInfo > >**)(0));
        _v = SWIG_CheckState(res);
        if (_v) {
          return _wrap_AuthCredInfoVector___setitem____SWIG_0(self, argc, argv);
        }
      }
    }
  }
  if (argc == 3) {
    int _v;
    int res = swig::asptr(argv[0], (std::vector< pj::AuthCredInfo,std::allocator< pj::AuthCredInfo > >**)(0));
    _v = SWIG_CheckState(res);
    if (_v) {
      {
        int res = SWIG_AsVal_ptrdiff_t(argv[1], NULL);
        _v = SWIG_CheckState(res);
      }
      if (_v) {
        int res = SWIG_ConvertPtr(argv[2], 0, SWIGTYPE_p_pj__AuthCredInfo, SWIG_POINTER_NO_NULL | 0);
        _v = SWIG_CheckState(res);
        if (_v) {
          return _wrap_AuthCredInfoVector___setitem____SWIG_2(self, argc, argv);
        }
      }
    }
  }
  
fail:
  SWIG_Python_RaiseOrModifyTypeError("Wrong number or type of arguments for overloaded function 'AuthCredInfoVector___setitem__'.\n"
    "  Possible C/C++ prototypes are:\n"
    "    std::vector< pj::AuthCredInfo >::__setitem__(PySliceObject *,std::vector< pj::AuthCredInfo,std::allocator< pj::AuthCredInfo > > const &)\n"
    "    std::vector< pj::AuthCredInfo >::__setitem__(PySliceObject *)\n"
    "    std::vector< pj::AuthCredInfo >::__setitem__(std::vector< pj::AuthCredInfo >::difference_type,std::vector< pj::AuthCredInfo >::value_type const &)\n");
  return 0;
}


SWIGINTERN PyObject *_wrap_AuthCredInfoVector_pop(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  std::vector< pj::AuthCredInfo > *arg1 = (std::vector< pj::AuthCredInfo > *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  std::vector< pj::AuthCredInfo >::value_type result;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__vectorT_pj__AuthCredInfo_std__allocatorT_pj__AuthCredInfo_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "AuthCredInfoVector_pop" "', argument " "1"" of type '" "std::vector< pj::AuthCredInfo > *""'"); 
  }
  arg1 = reinterpret_cast< std::vector< pj::AuthCredInfo > * >(argp1);
  try {
    result = std_vector_Sl_pj_AuthCredInfo_Sg__pop(arg1);
  } catch(std::out_of_range &_e) {
    SWIG_exception_fail(SWIG_IndexError, (&_e)->what());
  }
  resultobj = SWIG_NewPointerObj((new std::vector< pj::AuthCredInfo >::value_type(static_cast< const std::vector< pj::AuthCredInfo >::value_type& >(result))), SWIGTYPE_p_pj__AuthCredInfo, SWIG_POINTER_OWN |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_AuthCredInfoVector_append(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  std::vector< pj::AuthCredInfo > *arg1 = (std::vector< pj::AuthCredInfo > *) 0 ;
  std::vector< pj::AuthCredInfo >::value_type *arg2 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  void *argp2 = 0 ;
  int res2 = 0 ;
  PyObject *swig_obj[2] ;
  
  if (!SWIG_Python_UnpackTuple(args, "AuthCredInfoVector_append", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__vectorT_pj__AuthCredInfo_std__allocatorT_pj__AuthCredInfo_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "AuthCredInfoVector_append" "', argument " "1"" of type '" "std::vector< pj::AuthCredInfo > *""'"); 
  }
  arg1 = reinterpret_cast< std::vector< pj::AuthCredInfo > * >(argp1);
  res2 = SWIG_ConvertPtr(swig_obj[1], &argp2, SWIGTYPE_p_pj__AuthCredInfo,  0  | 0);
  if (!SWIG_IsOK(res2)) {
    SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "AuthCredInfoVector_append" "', argument " "2"" of type '" "std::vector< pj::AuthCredInfo >::value_type const &""'"); 
  }
  if (!argp2) {
    SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "AuthCredInfoVector_append" "', argument " "2"" of type '" "std::vector< pj::AuthCredInfo >::value_type const &""'"); 
  }
  arg2 = reinterpret_cast< std::vector< pj::AuthCredInfo >::value_type * >(argp2);
  std_vector_Sl_pj_AuthCredInfo_Sg__append(arg1,(pj::AuthCredInfo const &)*arg2);
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_new_AuthCredInfoVector__SWIG_0(PyObject *SWIGUNUSEDPARM(self), Py_ssize_t nobjs, PyObject **SWIGUNUSEDPARM(swig_obj)) {
  PyObject *resultobj = 0;
  std::vector< pj::AuthCredInfo > *result = 0 ;
  
  if ((nobjs < 0) || (nobjs > 0)) SWIG_fail;
  result = (std::vector< pj::AuthCredInfo > *)new std::vector< pj::AuthCredInfo >();
  resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(result), SWIGTYPE_p_std__vectorT_pj__AuthCredInfo_std__allocatorT_pj__AuthCredInfo_t_t, SWIG_POINTER_NEW |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_new_AuthCredInfoVector__SWIG_1(PyObject *SWIGUNUSEDPARM(self), Py_ssize_t nobjs, PyObject **swig_obj) {
  PyObject *resultobj = 0;
  std::vector< pj::AuthCredInfo > *arg1 = 0 ;
  int res1 = SWIG_OLDOBJ ;
  std::vector< pj::AuthCredInfo > *result = 0 ;
  
  if ((nobjs < 1) || (nobjs > 1)) SWIG_fail;
  {
    std::vector< pj::AuthCredInfo,std::allocator< pj::AuthCredInfo > > *ptr = (std::vector< pj::AuthCredInfo,std::allocator< pj::AuthCredInfo > > *)0;
    res1 = swig::asptr(swig_obj[0], &ptr);
    if (!SWIG_IsOK(res1)) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "new_AuthCredInfoVector" "', argument " "1"" of type '" "std::vector< pj::AuthCredInfo > const &""'"); 
    }
    if (!ptr) {
      SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "new_AuthCredInfoVector" "', argument " "1"" of type '" "std::vector< pj::AuthCredInfo > const &""'"); 
    }
    arg1 = ptr;
  }
  result = (std::vector< pj::AuthCredInfo > *)new std::vector< pj::AuthCredInfo >((std::vector< pj::AuthCredInfo > const &)*arg1);
  resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(result), SWIGTYPE_p_std__vectorT_pj__AuthCredInfo_std__allocatorT_pj__AuthCredInfo_t_t, SWIG_POINTER_NEW |  0 );
  if (SWIG_IsNewObj(res1)) delete arg1;
  return resultobj;
fail:
  if (SWIG_IsNewObj(res1)) delete arg1;
  return NULL;
}


SWIGINTERN PyObject *_wrap_AuthCredInfoVector_empty(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  std::vector< pj::AuthCredInfo > *arg1 = (std::vector< pj::AuthCredInfo > *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  bool result;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__vectorT_pj__AuthCredInfo_std__allocatorT_pj__AuthCredInfo_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "AuthCredInfoVector_empty" "', argument " "1"" of type '" "std::vector< pj::AuthCredInfo > const *""'"); 
  }
  arg1 = reinterpret_cast< std::vector< pj::AuthCredInfo > * >(argp1);
  result = (bool)((std::vector< pj::AuthCredInfo > const *)arg1)->empty();
  resultobj = SWIG_From_bool(static_cast< bool >(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_AuthCredInfoVector_size(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  std::vector< pj::AuthCredInfo > *arg1 = (std::vector< pj::AuthCredInfo > *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  std::vector< pj::AuthCredInfo >::size_type result;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__vectorT_pj__AuthCredInfo_std__allocatorT_pj__AuthCredInfo_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "AuthCredInfoVector_size" "', argument " "1"" of type '" "std::vector< pj::AuthCredInfo > const *""'"); 
  }
  arg1 = reinterpret_cast< std::vector< pj::AuthCredInfo > * >(argp1);
  result = ((std::vector< pj::AuthCredInfo > const *)arg1)->size();
  resultobj = SWIG_From_size_t(static_cast< size_t >(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_AuthCredInfoVector_swap(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  std::vector< pj::AuthCredInfo > *arg1 = (std::vector< pj::AuthCredInfo > *) 0 ;
  std::vector< pj::AuthCredInfo > *arg2 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  void *argp2 = 0 ;
  int res2 = 0 ;
  PyObject *swig_obj[2] ;
  
  if (!SWIG_Python_UnpackTuple(args, "AuthCredInfoVector_swap", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__vectorT_pj__AuthCredInfo_std__allocatorT_pj__AuthCredInfo_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "AuthCredInfoVector_swap" "', argument " "1"" of type '" "std::vector< pj::AuthCredInfo > *""'"); 
  }
  arg1 = reinterpret_cast< std::vector< pj::AuthCredInfo > * >(argp1);
  res2 = SWIG_ConvertPtr(swig_obj[1], &argp2, SWIGTYPE_p_std__vectorT_pj__AuthCredInfo_std__allocatorT_pj__AuthCredInfo_t_t,  0 );
  if (!SWIG_IsOK(res2)) {
    SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "AuthCredInfoVector_swap" "', argument " "2"" of type '" "std::vector< pj::AuthCredInfo > &""'"); 
  }
  if (!argp2) {
    SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "AuthCredInfoVector_swap" "', argument " "2"" of type '" "std::vector< pj::AuthCredInfo > &""'"); 
  }
  arg2 = reinterpret_cast< std::vector< pj::AuthCredInfo > * >(argp2);
  (arg1)->swap(*arg2);
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_AuthCredInfoVector_begin(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  std::vector< pj::AuthCredInfo > *arg1 = (std::vector< pj::AuthCredInfo > *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  std::vector< pj::AuthCredInfo >::iterator result;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__vectorT_pj__AuthCredInfo_std__allocatorT_pj__AuthCredInfo_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "AuthCredInfoVector_begin" "', argument " "1"" of type '" "std::vector< pj::AuthCredInfo > *""'"); 
  }
  arg1 = reinterpret_cast< std::vector< pj::AuthCredInfo > * >(argp1);
  result = (arg1)->begin();
  resultobj = SWIG_NewPointerObj(swig::make_output_iterator(static_cast< const std::vector< pj::AuthCredInfo >::iterator & >(result)),
    swig::SwigPyIterator::descriptor(),SWIG_POINTER_OWN);
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_AuthCredInfoVector_end(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  std::vector< pj::AuthCredInfo > *arg1 = (std::vector< pj::AuthCredInfo > *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  std::vector< pj::AuthCredInfo >::iterator result;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__vectorT_pj__AuthCredInfo_std__allocatorT_pj__AuthCredInfo_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "AuthCredInfoVector_end" "', argument " "1"" of type '" "std::vector< pj::AuthCredInfo > *""'"); 
  }
  arg1 = reinterpret_cast< std::vector< pj::AuthCredInfo > * >(argp1);
  result = (arg1)->end();
  resultobj = SWIG_NewPointerObj(swig::make_output_iterator(static_cast< const std::vector< pj::AuthCredInfo >::iterator & >(result)),
    swig::SwigPyIterator::descriptor(),SWIG_POINTER_OWN);
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_AuthCredInfoVector_rbegin(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  std::vector< pj::AuthCredInfo > *arg1 = (std::vector< pj::AuthCredInfo > *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  std::vector< pj::AuthCredInfo >::reverse_iterator result;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__vectorT_pj__AuthCredInfo_std__allocatorT_pj__AuthCredInfo_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "AuthCredInfoVector_rbegin" "', argument " "1"" of type '" "std::vector< pj::AuthCredInfo > *""'"); 
  }
  arg1 = reinterpret_cast< std::vector< pj::AuthCredInfo > * >(argp1);
  result = (arg1)->rbegin();
  resultobj = SWIG_NewPointerObj(swig::make_output_iterator(static_cast< const std::vector< pj::AuthCredInfo >::reverse_iterator & >(result)),
    swig::SwigPyIterator::descriptor(),SWIG_POINTER_OWN);
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_AuthCredInfoVector_rend(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  std::vector< pj::AuthCredInfo > *arg1 = (std::vector< pj::AuthCredInfo > *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  std::vector< pj::AuthCredInfo >::reverse_iterator result;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__vectorT_pj__AuthCredInfo_std__allocatorT_pj__AuthCredInfo_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "AuthCredInfoVector_rend" "', argument " "1"" of type '" "std::vector< pj::AuthCredInfo > *""'"); 
  }
  arg1 = reinterpret_cast< std::vector< pj::AuthCredInfo > * >(argp1);
  result = (arg1)->rend();
  resultobj = SWIG_NewPointerObj(swig::make_output_iterator(static_cast< const std::vector< pj::AuthCredInfo >::reverse_iterator & >(result)),
    swig::SwigPyIterator::descriptor(),SWIG_POINTER_OWN);
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_AuthCredInfoVector_clear(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  std::vector< pj::AuthCredInfo > *arg1 = (std::vector< pj::AuthCredInfo > *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__vectorT_pj__AuthCredInfo_std__allocatorT_pj__AuthCredInfo_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "AuthCredInfoVector_clear" "', argument " "1"" of type '" "std::vector< pj::AuthCredInfo > *""'"); 
  }
  arg1 = reinterpret_cast< std::vector< pj::AuthCredInfo > * >(argp1);
  (arg1)->clear();
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_AuthCredInfoVector_get_allocator(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  std::vector< pj::AuthCredInfo > *arg1 = (std::vector< pj::AuthCredInfo > *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  SwigValueWrapper< std::allocator< pj::AuthCredInfo > > result;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__vectorT_pj__AuthCredInfo_std__allocatorT_pj__AuthCredInfo_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "AuthCredInfoVector_get_allocator" "', argument " "1"" of type '" "std::vector< pj::AuthCredInfo > const *""'"); 
  }
  arg1 = reinterpret_cast< std::vector< pj::AuthCredInfo > * >(argp1);
  result = ((std::vector< pj::AuthCredInfo > const *)arg1)->get_allocator();
  resultobj = SWIG_NewPointerObj((new std::vector< pj::AuthCredInfo >::allocator_type(static_cast< const std::vector< pj::AuthCredInfo >::allocator_type& >(result))), SWIGTYPE_p_std__allocatorT_pj__AuthCredInfo_t, SWIG_POINTER_OWN |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_new_AuthCredInfoVector__SWIG_2(PyObject *SWIGUNUSEDPARM(self), Py_ssize_t nobjs, PyObject **swig_obj) {
  PyObject *resultobj = 0;
  std::vector< pj::AuthCredInfo >::size_type arg1 ;
  size_t val1 ;
  int ecode1 = 0 ;
  std::vector< pj::AuthCredInfo > *result = 0 ;
  
  if ((nobjs < 1) || (nobjs > 1)) SWIG_fail;
  ecode1 = SWIG_AsVal_size_t(swig_obj[0], &val1);
  if (!SWIG_IsOK(ecode1)) {
    SWIG_exception_fail(SWIG_ArgError(ecode1), "in method '" "new_AuthCredInfoVector" "', argument " "1"" of type '" "std::vector< pj::AuthCredInfo >::size_type""'");
  } 
  arg1 = static_cast< std::vector< pj::AuthCredInfo >::size_type >(val1);
  result = (std::vector< pj::AuthCredInfo > *)new std::vector< pj::AuthCredInfo >(arg1);
  resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(result), SWIGTYPE_p_std__vectorT_pj__AuthCredInfo_std__allocatorT_pj__AuthCredInfo_t_t, SWIG_POINTER_NEW |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_AuthCredInfoVector_pop_back(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  std::vector< pj::AuthCredInfo > *arg1 = (std::vector< pj::AuthCredInfo > *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__vectorT_pj__AuthCredInfo_std__allocatorT_pj__AuthCredInfo_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "AuthCredInfoVector_pop_back" "', argument " "1"" of type '" "std::vector< pj::AuthCredInfo > *""'"); 
  }
  arg1 = reinterpret_cast< std::vector< pj::AuthCredInfo > * >(argp1);
  (arg1)->pop_back();
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_AuthCredInfoVector_resize__SWIG_0(PyObject *SWIGUNUSEDPARM(self), Py_ssize_t nobjs, PyObject **swig_obj) {
  PyObject *resultobj = 0;
  std::vector< pj::AuthCredInfo > *arg1 = (std::vector< pj::AuthCredInfo > *) 0 ;
  std::vector< pj::AuthCredInfo >::size_type arg2 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  size_t val2 ;
  int ecode2 = 0 ;
  
  if ((nobjs < 2) || (nobjs > 2)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__vectorT_pj__AuthCredInfo_std__allocatorT_pj__AuthCredInfo_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "AuthCredInfoVector_resize" "', argument " "1"" of type '" "std::vector< pj::AuthCredInfo > *""'"); 
  }
  arg1 = reinterpret_cast< std::vector< pj::AuthCredInfo > * >(argp1);
  ecode2 = SWIG_AsVal_size_t(swig_obj[1], &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "AuthCredInfoVector_resize" "', argument " "2"" of type '" "std::vector< pj::AuthCredInfo >::size_type""'");
  } 
  arg2 = static_cast< std::vector< pj::AuthCredInfo >::size_type >(val2);
  (arg1)->resize(arg2);
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_AuthCredInfoVector_erase__SWIG_0(PyObject *SWIGUNUSEDPARM(self), Py_ssize_t nobjs, PyObject **swig_obj) {
  PyObject *resultobj = 0;
  std::vector< pj::AuthCredInfo > *arg1 = (std::vector< pj::AuthCredInfo > *) 0 ;
  std::vector< pj::AuthCredInfo >::iterator arg2 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  swig::SwigPyIterator *iter2 = 0 ;
  int res2 ;
  std::vector< pj::AuthCredInfo >::iterator result;
  
  if ((nobjs < 2) || (nobjs > 2)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__vectorT_pj__AuthCredInfo_std__allocatorT_pj__AuthCredInfo_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "AuthCredInfoVector_erase" "', argument " "1"" of type '" "std::vector< pj::AuthCredInfo > *""'"); 
  }
  arg1 = reinterpret_cast< std::vector< pj::AuthCredInfo > * >(argp1);
  res2 = SWIG_ConvertPtr(swig_obj[1], SWIG_as_voidptrptr(&iter2), swig::SwigPyIterator::descriptor(), 0);
  if (!SWIG_IsOK(res2) || !iter2) {
    SWIG_exception_fail(SWIG_ArgError(SWIG_TypeError), "in method '" "AuthCredInfoVector_erase" "', argument " "2"" of type '" "std::vector< pj::AuthCredInfo >::iterator""'");
  } else {
    swig::SwigPyIterator_T<std::vector< pj::AuthCredInfo >::iterator > *iter_t = dynamic_cast<swig::SwigPyIterator_T<std::vector< pj::AuthCredInfo >::iterator > *>(iter2);
    if (iter_t) {
      arg2 = iter_t->get_current();
    } else {
      SWIG_exception_fail(SWIG_ArgError(SWIG_TypeError), "in method '" "AuthCredInfoVector_erase" "', argument " "2"" of type '" "std::vector< pj::AuthCredInfo >::iterator""'");
    }
  }
  result = std_vector_Sl_pj_AuthCredInfo_Sg__erase__SWIG_0(arg1,arg2);
  resultobj = SWIG_NewPointerObj(swig::make_output_iterator(static_cast< const std::vector< pj::AuthCredInfo >::iterator & >(result)),
    swig::SwigPyIterator::descriptor(),SWIG_POINTER_OWN);
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_AuthCredInfoVector_erase__SWIG_1(PyObject *SWIGUNUSEDPARM(self), Py_ssize_t nobjs, PyObject **swig_obj) {
  PyObject *resultobj = 0;
  std::vector< pj::AuthCredInfo > *arg1 = (std::vector< pj::AuthCredInfo > *) 0 ;
  std::vector< pj::AuthCredInfo >::iterator arg2 ;
  std::vector< pj::AuthCredInfo >::iterator arg3 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  swig::SwigPyIterator *iter2 = 0 ;
  int res2 ;
  swig::SwigPyIterator *iter3 = 0 ;
  int res3 ;
  std::vector< pj::AuthCredInfo >::iterator result;
  
  if ((nobjs < 3) || (nobjs > 3)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__vectorT_pj__AuthCredInfo_std__allocatorT_pj__AuthCredInfo_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "AuthCredInfoVector_erase" "', argument " "1"" of type '" "std::vector< pj::AuthCredInfo > *""'"); 
  }
  arg1 = reinterpret_cast< std::vector< pj::AuthCredInfo > * >(argp1);
  res2 = SWIG_ConvertPtr(swig_obj[1], SWIG_as_voidptrptr(&iter2), swig::SwigPyIterator::descriptor(), 0);
  if (!SWIG_IsOK(res2) || !iter2) {
    SWIG_exception_fail(SWIG_ArgError(SWIG_TypeError), "in method '" "AuthCredInfoVector_erase" "', argument " "2"" of type '" "std::vector< pj::AuthCredInfo >::iterator""'");
  } else {
    swig::SwigPyIterator_T<std::vector< pj::AuthCredInfo >::iterator > *iter_t = dynamic_cast<swig::SwigPyIterator_T<std::vector< pj::AuthCredInfo >::iterator > *>(iter2);
    if (iter_t) {
      arg2 = iter_t->get_current();
    } else {
      SWIG_exception_fail(SWIG_ArgError(SWIG_TypeError), "in method '" "AuthCredInfoVector_erase" "', argument " "2"" of type '" "std::vector< pj::AuthCredInfo >::iterator""'");
    }
  }
  res3 = SWIG_ConvertPtr(swig_obj[2], SWIG_as_voidptrptr(&iter3), swig::SwigPyIterator::descriptor(), 0);
  if (!SWIG_IsOK(res3) || !iter3) {
    SWIG_exception_fail(SWIG_ArgError(SWIG_TypeError), "in method '" "AuthCredInfoVector_erase" "', argument " "3"" of type '" "std::vector< pj::AuthCredInfo >::iterator""'");
  } else {
    swig::SwigPyIterator_T<std::vector< pj::AuthCredInfo >::iterator > *iter_t = dynamic_cast<swig::SwigPyIterator_T<std::vector< pj::AuthCredInfo >::iterator > *>(iter3);
    if (iter_t) {
      arg3 = iter_t->get_current();
    } else {
      SWIG_exception_fail(SWIG_ArgError(SWIG_TypeError), "in method '" "AuthCredInfoVector_erase" "', argument " "3"" of type '" "std::vector< pj::AuthCredInfo >::iterator""'");
    }
  }
  result = std_vector_Sl_pj_AuthCredInfo_Sg__erase__SWIG_1(arg1,arg2,arg3);
  resultobj = SWIG_NewPointerObj(swig::make_output_iterator(static_cast< const std::vector< pj::AuthCredInfo >::iterator & >(result)),
    swig::SwigPyIterator::descriptor(),SWIG_POINTER_OWN);
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_AuthCredInfoVector_erase(PyObject *self, PyObject *args) {
  Py_ssize_t argc;
  PyObject *argv[4] = {
    0
  };
  
  if (!(argc = SWIG_Python_UnpackTuple(args, "AuthCredInfoVector_erase", 0, 3, argv))) SWIG_fail;
  --argc;
  if (argc == 2) {
    int _v;
    int res = swig::asptr(argv[0], (std::vector< pj::AuthCredInfo,std::allocator< pj::AuthCredInfo > >**)(0));
    _v = SWIG_CheckState(res);
    if (_v) {
      swig::SwigPyIterator *iter = 0;
      int res = SWIG_ConvertPtr(argv[1], SWIG_as_voidptrptr(&iter), swig::SwigPyIterator::descriptor(), 0);
      _v = (SWIG_IsOK(res) && iter && (dynamic_cast<swig::SwigPyIterator_T<std::vector< pj::AuthCredInfo >::iterator > *>(iter) != 0));
      if (_v) {
        return _wrap_AuthCredInfoVector_erase__SWIG_0(self, argc, argv);
      }
    }
  }
  if (argc == 3) {
    int _v;
    int res = swig::asptr(argv[0], (std::vector< pj::AuthCredInfo,std::allocator< pj::AuthCredInfo > >**)(0));
    _v = SWIG_CheckState(res);
    if (_v) {
      swig::SwigPyIterator *iter = 0;
      int res = SWIG_ConvertPtr(argv[1], SWIG_as_voidptrptr(&iter), swig::SwigPyIterator::descriptor(), 0);
      _v = (SWIG_IsOK(res) && iter && (dynamic_cast<swig::SwigPyIterator_T<std::vector< pj::AuthCredInfo >::iterator > *>(iter) != 0));
      if (_v) {
        swig::SwigPyIterator *iter = 0;
        int res = SWIG_ConvertPtr(argv[2], SWIG_as_voidptrptr(&iter), swig::SwigPyIterator::descriptor(), 0);
        _v = (SWIG_IsOK(res) && iter && (dynamic_cast<swig::SwigPyIterator_T<std::vector< pj::AuthCredInfo >::iterator > *>(iter) != 0));
        if (_v) {
          return _wrap_AuthCredInfoVector_erase__SWIG_1(self, argc, argv);
        }
      }
    }
  }
  
fail:
  SWIG_Python_RaiseOrModifyTypeError("Wrong number or type of arguments for overloaded function 'AuthCredInfoVector_erase'.\n"
    "  Possible C/C++ prototypes are:\n"
    "    std::vector< pj::AuthCredInfo >::erase(std::vector< pj::AuthCredInfo >::iterator)\n"
    "    std::vector< pj::AuthCredInfo >::erase(std::vector< pj::AuthCredInfo >::iterator,std::vector< pj::AuthCredInfo >::iterator)\n");
  return 0;
}


SWIGINTERN PyObject *_wrap_new_AuthCredInfoVector__SWIG_3(PyObject *SWIGUNUSEDPARM(self), Py_ssize_t nobjs, PyObject **swig_obj) {
  PyObject *resultobj = 0;
  std::vector< pj::AuthCredInfo >::size_type arg1 ;
  std::vector< pj::AuthCredInfo >::value_type *arg2 = 0 ;
  size_t val1 ;
  int ecode1 = 0 ;
  void *argp2 = 0 ;
  int res2 = 0 ;
  std::vector< pj::AuthCredInfo > *result = 0 ;
  
  if ((nobjs < 2) || (nobjs > 2)) SWIG_fail;
  ecode1 = SWIG_AsVal_size_t(swig_obj[0], &val1);
  if (!SWIG_IsOK(ecode1)) {
    SWIG_exception_fail(SWIG_ArgError(ecode1), "in method '" "new_AuthCredInfoVector" "', argument " "1"" of type '" "std::vector< pj::AuthCredInfo >::size_type""'");
  } 
  arg1 = static_cast< std::vector< pj::AuthCredInfo >::size_type >(val1);
  res2 = SWIG_ConvertPtr(swig_obj[1], &argp2, SWIGTYPE_p_pj__AuthCredInfo,  0  | 0);
  if (!SWIG_IsOK(res2)) {
    SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "new_AuthCredInfoVector" "', argument " "2"" of type '" "std::vector< pj::AuthCredInfo >::value_type const &""'"); 
  }
  if (!argp2) {
    SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "new_AuthCredInfoVector" "', argument " "2"" of type '" "std::vector< pj::AuthCredInfo >::value_type const &""'"); 
  }
  arg2 = reinterpret_cast< std::vector< pj::AuthCredInfo >::value_type * >(argp2);
  result = (std::vector< pj::AuthCredInfo > *)new std::vector< pj::AuthCredInfo >(arg1,(std::vector< pj::AuthCredInfo >::value_type const &)*arg2);
  resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(result), SWIGTYPE_p_std__vectorT_pj__AuthCredInfo_std__allocatorT_pj__AuthCredInfo_t_t, SWIG_POINTER_NEW |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_new_AuthCredInfoVector(PyObject *self, PyObject *args) {
  Py_ssize_t argc;
  PyObject *argv[3] = {
    0
  };
  
  if (!(argc = SWIG_Python_UnpackTuple(args, "new_AuthCredInfoVector", 0, 2, argv))) SWIG_fail;
  --argc;
  if (argc == 0) {
    return _wrap_new_AuthCredInfoVector__SWIG_0(self, argc, argv);
  }
  if (argc == 1) {
    int _v;
    {
      int res = SWIG_AsVal_size_t(argv[0], NULL);
      _v = SWIG_CheckState(res);
    }
    if (_v) {
      return _wrap_new_AuthCredInfoVector__SWIG_2(self, argc, argv);
    }
  }
  if (argc == 1) {
    int _v;
    int res = swig::asptr(argv[0], (std::vector< pj::AuthCredInfo,std::allocator< pj::AuthCredInfo > >**)(0));
    _v = SWIG_CheckState(res);
    if (_v) {
      return _wrap_new_AuthCredInfoVector__SWIG_1(self, argc, argv);
    }
  }
  if (argc == 2) {
    int _v;
    {
      int res = SWIG_AsVal_size_t(argv[0], NULL);
      _v = SWIG_CheckState(res);
    }
    if (_v) {
      int res = SWIG_ConvertPtr(argv[1], 0, SWIGTYPE_p_pj__AuthCredInfo, SWIG_POINTER_NO_NULL | 0);
      _v = SWIG_CheckState(res);
      if (_v) {
        return _wrap_new_AuthCredInfoVector__SWIG_3(self, argc, argv);
      }
    }
  }
  
fail:
  SWIG_Python_RaiseOrModifyTypeError("Wrong number or type of arguments for overloaded function 'new_AuthCredInfoVector'.\n"
    "  Possible C/C++ prototypes are:\n"
    "    std::vector< pj::AuthCredInfo >::vector()\n"
    "    std::vector< pj::AuthCredInfo >::vector(std::vector< pj::AuthCredInfo > const &)\n"
    "    std::vector< pj::AuthCredInfo >::vector(std::vector< pj::AuthCredInfo >::size_type)\n"
    "    std::vector< pj::AuthCredInfo >::vector(std::vector< pj::AuthCredInfo >::size_type,std::vector< pj::AuthCredInfo >::value_type const &)\n");
  return 0;
}


SWIGINTERN PyObject *_wrap_AuthCredInfoVector_push_back(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  std::vector< pj::AuthCredInfo > *arg1 = (std::vector< pj::AuthCredInfo > *) 0 ;
  std::vector< pj::AuthCredInfo >::value_type *arg2 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  void *argp2 = 0 ;
  int res2 = 0 ;
  PyObject *swig_obj[2] ;
  
  if (!SWIG_Python_UnpackTuple(args, "AuthCredInfoVector_push_back", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__vectorT_pj__AuthCredInfo_std__allocatorT_pj__AuthCredInfo_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "AuthCredInfoVector_push_back" "', argument " "1"" of type '" "std::vector< pj::AuthCredInfo > *""'"); 
  }
  arg1 = reinterpret_cast< std::vector< pj::AuthCredInfo > * >(argp1);
  res2 = SWIG_ConvertPtr(swig_obj[1], &argp2, SWIGTYPE_p_pj__AuthCredInfo,  0  | 0);
  if (!SWIG_IsOK(res2)) {
    SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "AuthCredInfoVector_push_back" "', argument " "2"" of type '" "std::vector< pj::AuthCredInfo >::value_type const &""'"); 
  }
  if (!argp2) {
    SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "AuthCredInfoVector_push_back" "', argument " "2"" of type '" "std::vector< pj::AuthCredInfo >::value_type const &""'"); 
  }
  arg2 = reinterpret_cast< std::vector< pj::AuthCredInfo >::value_type * >(argp2);
  (arg1)->push_back((std::vector< pj::AuthCredInfo >::value_type const &)*arg2);
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_AuthCredInfoVector_front(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  std::vector< pj::AuthCredInfo > *arg1 = (std::vector< pj::AuthCredInfo > *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  std::vector< pj::AuthCredInfo >::value_type *result = 0 ;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__vectorT_pj__AuthCredInfo_std__allocatorT_pj__AuthCredInfo_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "AuthCredInfoVector_front" "', argument " "1"" of type '" "std::vector< pj::AuthCredInfo > const *""'"); 
  }
  arg1 = reinterpret_cast< std::vector< pj::AuthCredInfo > * >(argp1);
  result = (std::vector< pj::AuthCredInfo >::value_type *) &((std::vector< pj::AuthCredInfo > const *)arg1)->front();
  resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(result), SWIGTYPE_p_pj__AuthCredInfo, 0 |  0 );
  (void)swig::container_owner<swig::traits<std::vector< pj::AuthCredInfo >::value_type>::category>::back_reference(resultobj, swig_obj[0]);
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_AuthCredInfoVector_back(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  std::vector< pj::AuthCredInfo > *arg1 = (std::vector< pj::AuthCredInfo > *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  std::vector< pj::AuthCredInfo >::value_type *result = 0 ;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__vectorT_pj__AuthCredInfo_std__allocatorT_pj__AuthCredInfo_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "AuthCredInfoVector_back" "', argument " "1"" of type '" "std::vector< pj::AuthCredInfo > const *""'"); 
  }
  arg1 = reinterpret_cast< std::vector< pj::AuthCredInfo > * >(argp1);
  result = (std::vector< pj::AuthCredInfo >::value_type *) &((std::vector< pj::AuthCredInfo > const *)arg1)->back();
  resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(result), SWIGTYPE_p_pj__AuthCredInfo, 0 |  0 );
  (void)swig::container_owner<swig::traits<std::vector< pj::AuthCredInfo >::value_type>::category>::back_reference(resultobj, swig_obj[0]);
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_AuthCredInfoVector_assign(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  std::vector< pj::AuthCredInfo > *arg1 = (std::vector< pj::AuthCredInfo > *) 0 ;
  std::vector< pj::AuthCredInfo >::size_type arg2 ;
  std::vector< pj::AuthCredInfo >::value_type *arg3 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  size_t val2 ;
  int ecode2 = 0 ;
  void *argp3 = 0 ;
  int res3 = 0 ;
  PyObject *swig_obj[3] ;
  
  if (!SWIG_Python_UnpackTuple(args, "AuthCredInfoVector_assign", 3, 3, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__vectorT_pj__AuthCredInfo_std__allocatorT_pj__AuthCredInfo_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "AuthCredInfoVector_assign" "', argument " "1"" of type '" "std::vector< pj::AuthCredInfo > *""'"); 
  }
  arg1 = reinterpret_cast< std::vector< pj::AuthCredInfo > * >(argp1);
  ecode2 = SWIG_AsVal_size_t(swig_obj[1], &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "AuthCredInfoVector_assign" "', argument " "2"" of type '" "std::vector< pj::AuthCredInfo >::size_type""'");
  } 
  arg2 = static_cast< std::vector< pj::AuthCredInfo >::size_type >(val2);
  res3 = SWIG_ConvertPtr(swig_obj[2], &argp3, SWIGTYPE_p_pj__AuthCredInfo,  0  | 0);
  if (!SWIG_IsOK(res3)) {
    SWIG_exception_fail(SWIG_ArgError(res3), "in method '" "AuthCredInfoVector_assign" "', argument " "3"" of type '" "std::vector< pj::AuthCredInfo >::value_type const &""'"); 
  }
  if (!argp3) {
    SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "AuthCredInfoVector_assign" "', argument " "3"" of type '" "std::vector< pj::AuthCredInfo >::value_type const &""'"); 
  }
  arg3 = reinterpret_cast< std::vector< pj::AuthCredInfo >::value_type * >(argp3);
  (arg1)->assign(arg2,(std::vector< pj::AuthCredInfo >::value_type const &)*arg3);
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_AuthCredInfoVector_resize__SWIG_1(PyObject *SWIGUNUSEDPARM(self), Py_ssize_t nobjs, PyObject **swig_obj) {
  PyObject *resultobj = 0;
  std::vector< pj::AuthCredInfo > *arg1 = (std::vector< pj::AuthCredInfo > *) 0 ;
  std::vector< pj::AuthCredInfo >::size_type arg2 ;
  std::vector< pj::AuthCredInfo >::value_type *arg3 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  size_t val2 ;
  int ecode2 = 0 ;
  void *argp3 = 0 ;
  int res3 = 0 ;
  
  if ((nobjs < 3) || (nobjs > 3)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__vectorT_pj__AuthCredInfo_std__allocatorT_pj__AuthCredInfo_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "AuthCredInfoVector_resize" "', argument " "1"" of type '" "std::vector< pj::AuthCredInfo > *""'"); 
  }
  arg1 = reinterpret_cast< std::vector< pj::AuthCredInfo > * >(argp1);
  ecode2 = SWIG_AsVal_size_t(swig_obj[1], &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "AuthCredInfoVector_resize" "', argument " "2"" of type '" "std::vector< pj::AuthCredInfo >::size_type""'");
  } 
  arg2 = static_cast< std::vector< pj::AuthCredInfo >::size_type >(val2);
  res3 = SWIG_ConvertPtr(swig_obj[2], &argp3, SWIGTYPE_p_pj__AuthCredInfo,  0  | 0);
  if (!SWIG_IsOK(res3)) {
    SWIG_exception_fail(SWIG_ArgError(res3), "in method '" "AuthCredInfoVector_resize" "', argument " "3"" of type '" "std::vector< pj::AuthCredInfo >::value_type const &""'"); 
  }
  if (!argp3) {
    SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "AuthCredInfoVector_resize" "', argument " "3"" of type '" "std::vector< pj::AuthCredInfo >::value_type const &""'"); 
  }
  arg3 = reinterpret_cast< std::vector< pj::AuthCredInfo >::value_type * >(argp3);
  (arg1)->resize(arg2,(std::vector< pj::AuthCredInfo >::value_type const &)*arg3);
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_AuthCredInfoVector_resize(PyObject *self, PyObject *args) {
  Py_ssize_t argc;
  PyObject *argv[4] = {
    0
  };
  
  if (!(argc = SWIG_Python_UnpackTuple(args, "AuthCredInfoVector_resize", 0, 3, argv))) SWIG_fail;
  --argc;
  if (argc == 2) {
    int _v;
    int res = swig::asptr(argv[0], (std::vector< pj::AuthCredInfo,std::allocator< pj::AuthCredInfo > >**)(0));
    _v = SWIG_CheckState(res);
    if (_v) {
      {
        int res = SWIG_AsVal_size_t(argv[1], NULL);
        _v = SWIG_CheckState(res);
      }
      if (_v) {
        return _wrap_AuthCredInfoVector_resize__SWIG_0(self, argc, argv);
      }
    }
  }
  if (argc == 3) {
    int _v;
    int res = swig::asptr(argv[0], (std::vector< pj::AuthCredInfo,std::allocator< pj::AuthCredInfo > >**)(0));
    _v = SWIG_CheckState(res);
    if (_v) {
      {
        int res = SWIG_AsVal_size_t(argv[1], NULL);
        _v = SWIG_CheckState(res);
      }
      if (_v) {
        int res = SWIG_ConvertPtr(argv[2], 0, SWIGTYPE_p_pj__AuthCredInfo, SWIG_POINTER_NO_NULL | 0);
        _v = SWIG_CheckState(res);
        if (_v) {
          return _wrap_AuthCredInfoVector_resize__SWIG_1(self, argc, argv);
        }
      }
    }
  }
  
fail:
  SWIG_Python_RaiseOrModifyTypeError("Wrong number or type of arguments for overloaded function 'AuthCredInfoVector_resize'.\n"
    "  Possible C/C++ prototypes are:\n"
    "    std::vector< pj::AuthCredInfo >::resize(std::vector< pj::AuthCredInfo >::size_type)\n"
    "    std::vector< pj::AuthCredInfo >::resize(std::vector< pj::AuthCredInfo >::size_type,std::vector< pj::AuthCredInfo >::value_type const &)\n");
  return 0;
}


SWIGINTERN PyObject *_wrap_AuthCredInfoVector_insert__SWIG_0(PyObject *SWIGUNUSEDPARM(self), Py_ssize_t nobjs, PyObject **swig_obj) {
  PyObject *resultobj = 0;
  std::vector< pj::AuthCredInfo > *arg1 = (std::vector< pj::AuthCredInfo > *) 0 ;
  std::vector< pj::AuthCredInfo >::iterator arg2 ;
  std::vector< pj::AuthCredInfo >::value_type *arg3 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  swig::SwigPyIterator *iter2 = 0 ;
  int res2 ;
  void *argp3 = 0 ;
  int res3 = 0 ;
  std::vector< pj::AuthCredInfo >::iterator result;
  
  if ((nobjs < 3) || (nobjs > 3)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__vectorT_pj__AuthCredInfo_std__allocatorT_pj__AuthCredInfo_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "AuthCredInfoVector_insert" "', argument " "1"" of type '" "std::vector< pj::AuthCredInfo > *""'"); 
  }
  arg1 = reinterpret_cast< std::vector< pj::AuthCredInfo > * >(argp1);
  res2 = SWIG_ConvertPtr(swig_obj[1], SWIG_as_voidptrptr(&iter2), swig::SwigPyIterator::descriptor(), 0);
  if (!SWIG_IsOK(res2) || !iter2) {
    SWIG_exception_fail(SWIG_ArgError(SWIG_TypeError), "in method '" "AuthCredInfoVector_insert" "', argument " "2"" of type '" "std::vector< pj::AuthCredInfo >::iterator""'");
  } else {
    swig::SwigPyIterator_T<std::vector< pj::AuthCredInfo >::iterator > *iter_t = dynamic_cast<swig::SwigPyIterator_T<std::vector< pj::AuthCredInfo >::iterator > *>(iter2);
    if (iter_t) {
      arg2 = iter_t->get_current();
    } else {
      SWIG_exception_fail(SWIG_ArgError(SWIG_TypeError), "in method '" "AuthCredInfoVector_insert" "', argument " "2"" of type '" "std::vector< pj::AuthCredInfo >::iterator""'");
    }
  }
  res3 = SWIG_ConvertPtr(swig_obj[2], &argp3, SWIGTYPE_p_pj__AuthCredInfo,  0  | 0);
  if (!SWIG_IsOK(res3)) {
    SWIG_exception_fail(SWIG_ArgError(res3), "in method '" "AuthCredInfoVector_insert" "', argument " "3"" of type '" "std::vector< pj::AuthCredInfo >::value_type const &""'"); 
  }
  if (!argp3) {
    SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "AuthCredInfoVector_insert" "', argument " "3"" of type '" "std::vector< pj::AuthCredInfo >::value_type const &""'"); 
  }
  arg3 = reinterpret_cast< std::vector< pj::AuthCredInfo >::value_type * >(argp3);
  result = std_vector_Sl_pj_AuthCredInfo_Sg__insert__SWIG_0(arg1,arg2,(pj::AuthCredInfo const &)*arg3);
  resultobj = SWIG_NewPointerObj(swig::make_output_iterator(static_cast< const std::vector< pj::AuthCredInfo >::iterator & >(result)),
    swig::SwigPyIterator::descriptor(),SWIG_POINTER_OWN);
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_AuthCredInfoVector_insert__SWIG_1(PyObject *SWIGUNUSEDPARM(self), Py_ssize_t nobjs, PyObject **swig_obj) {
  PyObject *resultobj = 0;
  std::vector< pj::AuthCredInfo > *arg1 = (std::vector< pj::AuthCredInfo > *) 0 ;
  std::vector< pj::AuthCredInfo >::iterator arg2 ;
  std::vector< pj::AuthCredInfo >::size_type arg3 ;
  std::vector< pj::AuthCredInfo >::value_type *arg4 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  swig::SwigPyIterator *iter2 = 0 ;
  int res2 ;
  size_t val3 ;
  int ecode3 = 0 ;
  void *argp4 = 0 ;
  int res4 = 0 ;
  
  if ((nobjs < 4) || (nobjs > 4)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__vectorT_pj__AuthCredInfo_std__allocatorT_pj__AuthCredInfo_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "AuthCredInfoVector_insert" "', argument " "1"" of type '" "std::vector< pj::AuthCredInfo > *""'"); 
  }
  arg1 = reinterpret_cast< std::vector< pj::AuthCredInfo > * >(argp1);
  res2 = SWIG_ConvertPtr(swig_obj[1], SWIG_as_voidptrptr(&iter2), swig::SwigPyIterator::descriptor(), 0);
  if (!SWIG_IsOK(res2) || !iter2) {
    SWIG_exception_fail(SWIG_ArgError(SWIG_TypeError), "in method '" "AuthCredInfoVector_insert" "', argument " "2"" of type '" "std::vector< pj::AuthCredInfo >::iterator""'");
  } else {
    swig::SwigPyIterator_T<std::vector< pj::AuthCredInfo >::iterator > *iter_t = dynamic_cast<swig::SwigPyIterator_T<std::vector< pj::AuthCredInfo >::iterator > *>(iter2);
    if (iter_t) {
      arg2 = iter_t->get_current();
    } else {
      SWIG_exception_fail(SWIG_ArgError(SWIG_TypeError), "in method '" "AuthCredInfoVector_insert" "', argument " "2"" of type '" "std::vector< pj::AuthCredInfo >::iterator""'");
    }
  }
  ecode3 = SWIG_AsVal_size_t(swig_obj[2], &val3);
  if (!SWIG_IsOK(ecode3)) {
    SWIG_exception_fail(SWIG_ArgError(ecode3), "in method '" "AuthCredInfoVector_insert" "', argument " "3"" of type '" "std::vector< pj::AuthCredInfo >::size_type""'");
  } 
  arg3 = static_cast< std::vector< pj::AuthCredInfo >::size_type >(val3);
  res4 = SWIG_ConvertPtr(swig_obj[3], &argp4, SWIGTYPE_p_pj__AuthCredInfo,  0  | 0);
  if (!SWIG_IsOK(res4)) {
    SWIG_exception_fail(SWIG_ArgError(res4), "in method '" "AuthCredInfoVector_insert" "', argument " "4"" of type '" "std::vector< pj::AuthCredInfo >::value_type const &""'"); 
  }
  if (!argp4) {
    SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "AuthCredInfoVector_insert" "', argument " "4"" of type '" "std::vector< pj::AuthCredInfo >::value_type const &""'"); 
  }
  arg4 = reinterpret_cast< std::vector< pj::AuthCredInfo >::value_type * >(argp4);
  std_vector_Sl_pj_AuthCredInfo_Sg__insert__SWIG_1(arg1,arg2,arg3,(pj::AuthCredInfo const &)*arg4);
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_AuthCredInfoVector_insert(PyObject *self, PyObject *args) {
  Py_ssize_t argc;
  PyObject *argv[5] = {
    0
  };
  
  if (!(argc = SWIG_Python_UnpackTuple(args, "AuthCredInfoVector_insert", 0, 4, argv))) SWIG_fail;
  --argc;
  if (argc == 3) {
    int _v;
    int res = swig::asptr(argv[0], (std::vector< pj::AuthCredInfo,std::allocator< pj::AuthCredInfo > >**)(0));
    _v = SWIG_CheckState(res);
    if (_v) {
      swig::SwigPyIterator *iter = 0;
      int res = SWIG_ConvertPtr(argv[1], SWIG_as_voidptrptr(&iter), swig::SwigPyIterator::descriptor(), 0);
      _v = (SWIG_IsOK(res) && iter && (dynamic_cast<swig::SwigPyIterator_T<std::vector< pj::AuthCredInfo >::iterator > *>(iter) != 0));
      if (_v) {
        int res = SWIG_ConvertPtr(argv[2], 0, SWIGTYPE_p_pj__AuthCredInfo, SWIG_POINTER_NO_NULL | 0);
        _v = SWIG_CheckState(res);
        if (_v) {
          return _wrap_AuthCredInfoVector_insert__SWIG_0(self, argc, argv);
        }
      }
    }
  }
  if (argc == 4) {
    int _v;
    int res = swig::asptr(argv[0], (std::vector< pj::AuthCredInfo,std::allocator< pj::AuthCredInfo > >**)(0));
    _v = SWIG_CheckState(res);
    if (_v) {
      swig::SwigPyIterator *iter = 0;
      int res = SWIG_ConvertPtr(argv[1], SWIG_as_voidptrptr(&iter), swig::SwigPyIterator::descriptor(), 0);
      _v = (SWIG_IsOK(res) && iter && (dynamic_cast<swig::SwigPyIterator_T<std::vector< pj::AuthCredInfo >::iterator > *>(iter) != 0));
      if (_v) {
        {
          int res = SWIG_AsVal_size_t(argv[2], NULL);
          _v = SWIG_CheckState(res);
        }
        if (_v) {
          int res = SWIG_ConvertPtr(argv[3], 0, SWIGTYPE_p_pj__AuthCredInfo, SWIG_POINTER_NO_NULL | 0);
          _v = SWIG_CheckState(res);
          if (_v) {
            return _wrap_AuthCredInfoVector_insert__SWIG_1(self, argc, argv);
          }
        }
      }
    }
  }
  
fail:
  SWIG_Python_RaiseOrModifyTypeError("Wrong number or type of arguments for overloaded function 'AuthCredInfoVector_insert'.\n"
    "  Possible C/C++ prototypes are:\n"
    "    std::vector< pj::AuthCredInfo >::insert(std::vector< pj::AuthCredInfo >::iterator,std::vector< pj::AuthCredInfo >::value_type const &)\n"
    "    std::vector< pj::AuthCredInfo >::insert(std::vector< pj::AuthCredInfo >::iterator,std::vector< pj::AuthCredInfo >::size_type,std::vector< pj::AuthCredInfo >::value_type const &)\n");
  return 0;
}


SWIGINTERN PyObject *_wrap_AuthCredInfoVector_reserve(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  std::vector< pj::AuthCredInfo > *arg1 = (std::vector< pj::AuthCredInfo > *) 0 ;
  std::vector< pj::AuthCredInfo >::size_type arg2 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  size_t val2 ;
  int ecode2 = 0 ;
  PyObject *swig_obj[2] ;
  
  if (!SWIG_Python_UnpackTuple(args, "AuthCredInfoVector_reserve", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__vectorT_pj__AuthCredInfo_std__allocatorT_pj__AuthCredInfo_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "AuthCredInfoVector_reserve" "', argument " "1"" of type '" "std::vector< pj::AuthCredInfo > *""'"); 
  }
  arg1 = reinterpret_cast< std::vector< pj::AuthCredInfo > * >(argp1);
  ecode2 = SWIG_AsVal_size_t(swig_obj[1], &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "AuthCredInfoVector_reserve" "', argument " "2"" of type '" "std::vector< pj::AuthCredInfo >::size_type""'");
  } 
  arg2 = static_cast< std::vector< pj::AuthCredInfo >::size_type >(val2);
  (arg1)->reserve(arg2);
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_AuthCredInfoVector_capacity(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  std::vector< pj::AuthCredInfo > *arg1 = (std::vector< pj::AuthCredInfo > *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  std::vector< pj::AuthCredInfo >::size_type result;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__vectorT_pj__AuthCredInfo_std__allocatorT_pj__AuthCredInfo_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "AuthCredInfoVector_capacity" "', argument " "1"" of type '" "std::vector< pj::AuthCredInfo > const *""'"); 
  }
  arg1 = reinterpret_cast< std::vector< pj::AuthCredInfo > * >(argp1);
  result = ((std::vector< pj::AuthCredInfo > const *)arg1)->capacity();
  resultobj = SWIG_From_size_t(static_cast< size_t >(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_delete_AuthCredInfoVector(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  std::vector< pj::AuthCredInfo > *arg1 = (std::vector< pj::AuthCredInfo > *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__vectorT_pj__AuthCredInfo_std__allocatorT_pj__AuthCredInfo_t_t, SWIG_POINTER_DISOWN |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "delete_AuthCredInfoVector" "', argument " "1"" of type '" "std::vector< pj::AuthCredInfo > *""'"); 
  }
  arg1 = reinterpret_cast< std::vector< pj::AuthCredInfo > * >(argp1);
  delete arg1;
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *AuthCredInfoVector_swigregister(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *obj;
  if (!SWIG_Python_UnpackTuple(args, "swigregister", 1, 1, &obj)) return NULL;
  SWIG_TypeNewClientData(SWIGTYPE_p_std__vectorT_pj__AuthCredInfo_std__allocatorT_pj__AuthCredInfo_t_t, SWIG_NewClientData(obj));
  return SWIG_Py_Void();
}

SWIGINTERN PyObject *AuthCredInfoVector_swiginit(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  return SWIG_Python_InitShadowInstance(args);
}

SWIGINTERN PyObject *_wrap_SrtpCryptoVector_iterator(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  std::vector< pj::SrtpCrypto > *arg1 = (std::vector< pj::SrtpCrypto > *) 0 ;
  PyObject **arg2 = (PyObject **) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  swig::SwigPyIterator *result = 0 ;
  
  arg2 = &swig_obj[0];
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__vectorT_pj__SrtpCrypto_std__allocatorT_pj__SrtpCrypto_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "SrtpCryptoVector_iterator" "', argument " "1"" of type '" "std::vector< pj::SrtpCrypto > *""'"); 
  }
  arg1 = reinterpret_cast< std::vector< pj::SrtpCrypto > * >(argp1);
  result = (swig::SwigPyIterator *)std_vector_Sl_pj_SrtpCrypto_Sg__iterator(arg1,arg2);
  resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(result), SWIGTYPE_p_swig__SwigPyIterator, SWIG_POINTER_OWN |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_SrtpCryptoVector___nonzero__(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  std::vector< pj::SrtpCrypto > *arg1 = (std::vector< pj::SrtpCrypto > *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  bool result;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__vectorT_pj__SrtpCrypto_std__allocatorT_pj__SrtpCrypto_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "SrtpCryptoVector___nonzero__" "', argument " "1"" of type '" "std::vector< pj::SrtpCrypto > const *""'"); 
  }
  arg1 = reinterpret_cast< std::vector< pj::SrtpCrypto > * >(argp1);
  result = (bool)std_vector_Sl_pj_SrtpCrypto_Sg____nonzero__((std::vector< pj::SrtpCrypto > const *)arg1);
  resultobj = SWIG_From_bool(static_cast< bool >(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_SrtpCryptoVector___bool__(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  std::vector< pj::SrtpCrypto > *arg1 = (std::vector< pj::SrtpCrypto > *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  bool result;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__vectorT_pj__SrtpCrypto_std__allocatorT_pj__SrtpCrypto_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "SrtpCryptoVector___bool__" "', argument " "1"" of type '" "std::vector< pj::SrtpCrypto > const *""'"); 
  }
  arg1 = reinterpret_cast< std::vector< pj::SrtpCrypto > * >(argp1);
  result = (bool)std_vector_Sl_pj_SrtpCrypto_Sg____bool__((std::vector< pj::SrtpCrypto > const *)arg1);
  resultobj = SWIG_From_bool(static_cast< bool >(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_SrtpCryptoVector___len__(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  std::vector< pj::SrtpCrypto > *arg1 = (std::vector< pj::SrtpCrypto > *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  std::vector< pj::SrtpCrypto >::size_type result;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__vectorT_pj__SrtpCrypto_std__allocatorT_pj__SrtpCrypto_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "SrtpCryptoVector___len__" "', argument " "1"" of type '" "std::vector< pj::SrtpCrypto > const *""'"); 
  }
  arg1 = reinterpret_cast< std::vector< pj::SrtpCrypto > * >(argp1);
  result = std_vector_Sl_pj_SrtpCrypto_Sg____len__((std::vector< pj::SrtpCrypto > const *)arg1);
  resultobj = SWIG_From_size_t(static_cast< size_t >(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_SrtpCryptoVector___getslice__(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  std::vector< pj::SrtpCrypto > *arg1 = (std::vector< pj::SrtpCrypto > *) 0 ;
  std::vector< pj::SrtpCrypto >::difference_type arg2 ;
  std::vector< pj::SrtpCrypto >::difference_type arg3 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  ptrdiff_t val2 ;
  int ecode2 = 0 ;
  ptrdiff_t val3 ;
  int ecode3 = 0 ;
  PyObject *swig_obj[3] ;
  std::vector< pj::SrtpCrypto,std::allocator< pj::SrtpCrypto > > *result = 0 ;
  
  if (!SWIG_Python_UnpackTuple(args, "SrtpCryptoVector___getslice__", 3, 3, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__vectorT_pj__SrtpCrypto_std__allocatorT_pj__SrtpCrypto_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "SrtpCryptoVector___getslice__" "', argument " "1"" of type '" "std::vector< pj::SrtpCrypto > *""'"); 
  }
  arg1 = reinterpret_cast< std::vector< pj::SrtpCrypto > * >(argp1);
  ecode2 = SWIG_AsVal_ptrdiff_t(swig_obj[1], &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "SrtpCryptoVector___getslice__" "', argument " "2"" of type '" "std::vector< pj::SrtpCrypto >::difference_type""'");
  } 
  arg2 = static_cast< std::vector< pj::SrtpCrypto >::difference_type >(val2);
  ecode3 = SWIG_AsVal_ptrdiff_t(swig_obj[2], &val3);
  if (!SWIG_IsOK(ecode3)) {
    SWIG_exception_fail(SWIG_ArgError(ecode3), "in method '" "SrtpCryptoVector___getslice__" "', argument " "3"" of type '" "std::vector< pj::SrtpCrypto >::difference_type""'");
  } 
  arg3 = static_cast< std::vector< pj::SrtpCrypto >::difference_type >(val3);
  try {
    result = (std::vector< pj::SrtpCrypto,std::allocator< pj::SrtpCrypto > > *)std_vector_Sl_pj_SrtpCrypto_Sg____getslice__(arg1,arg2,arg3);
  } catch(std::out_of_range &_e) {
    SWIG_exception_fail(SWIG_IndexError, (&_e)->what());
  } catch(std::invalid_argument &_e) {
    SWIG_exception_fail(SWIG_ValueError, (&_e)->what());
  }
  resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(result), SWIGTYPE_p_std__vectorT_pj__SrtpCrypto_std__allocatorT_pj__SrtpCrypto_t_t, SWIG_POINTER_OWN |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_SrtpCryptoVector___setslice____SWIG_0(PyObject *SWIGUNUSEDPARM(self), Py_ssize_t nobjs, PyObject **swig_obj) {
  PyObject *resultobj = 0;
  std::vector< pj::SrtpCrypto > *arg1 = (std::vector< pj::SrtpCrypto > *) 0 ;
  std::vector< pj::SrtpCrypto >::difference_type arg2 ;
  std::vector< pj::SrtpCrypto >::difference_type arg3 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  ptrdiff_t val2 ;
  int ecode2 = 0 ;
  ptrdiff_t val3 ;
  int ecode3 = 0 ;
  
  if ((nobjs < 3) || (nobjs > 3)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__vectorT_pj__SrtpCrypto_std__allocatorT_pj__SrtpCrypto_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "SrtpCryptoVector___setslice__" "', argument " "1"" of type '" "std::vector< pj::SrtpCrypto > *""'"); 
  }
  arg1 = reinterpret_cast< std::vector< pj::SrtpCrypto > * >(argp1);
  ecode2 = SWIG_AsVal_ptrdiff_t(swig_obj[1], &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "SrtpCryptoVector___setslice__" "', argument " "2"" of type '" "std::vector< pj::SrtpCrypto >::difference_type""'");
  } 
  arg2 = static_cast< std::vector< pj::SrtpCrypto >::difference_type >(val2);
  ecode3 = SWIG_AsVal_ptrdiff_t(swig_obj[2], &val3);
  if (!SWIG_IsOK(ecode3)) {
    SWIG_exception_fail(SWIG_ArgError(ecode3), "in method '" "SrtpCryptoVector___setslice__" "', argument " "3"" of type '" "std::vector< pj::SrtpCrypto >::difference_type""'");
  } 
  arg3 = static_cast< std::vector< pj::SrtpCrypto >::difference_type >(val3);
  try {
    std_vector_Sl_pj_SrtpCrypto_Sg____setslice____SWIG_0(arg1,arg2,arg3);
  } catch(std::out_of_range &_e) {
    SWIG_exception_fail(SWIG_IndexError, (&_e)->what());
  } catch(std::invalid_argument &_e) {
    SWIG_exception_fail(SWIG_ValueError, (&_e)->what());
  }
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_SrtpCryptoVector___setslice____SWIG_1(PyObject *SWIGUNUSEDPARM(self), Py_ssize_t nobjs, PyObject **swig_obj) {
  PyObject *resultobj = 0;
  std::vector< pj::SrtpCrypto > *arg1 = (std::vector< pj::SrtpCrypto > *) 0 ;
  std::vector< pj::SrtpCrypto >::difference_type arg2 ;
  std::vector< pj::SrtpCrypto >::difference_type arg3 ;
  std::vector< pj::SrtpCrypto,std::allocator< pj::SrtpCrypto > > *arg4 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  ptrdiff_t val2 ;
  int ecode2 = 0 ;
  ptrdiff_t val3 ;
  int ecode3 = 0 ;
  int res4 = SWIG_OLDOBJ ;
  
  if ((nobjs < 4) || (nobjs > 4)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__vectorT_pj__SrtpCrypto_std__allocatorT_pj__SrtpCrypto_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "SrtpCryptoVector___setslice__" "', argument " "1"" of type '" "std::vector< pj::SrtpCrypto > *""'"); 
  }
  arg1 = reinterpret_cast< std::vector< pj::SrtpCrypto > * >(argp1);
  ecode2 = SWIG_AsVal_ptrdiff_t(swig_obj[1], &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "SrtpCryptoVector___setslice__" "', argument " "2"" of type '" "std::vector< pj::SrtpCrypto >::difference_type""'");
  } 
  arg2 = static_cast< std::vector< pj::SrtpCrypto >::difference_type >(val2);
  ecode3 = SWIG_AsVal_ptrdiff_t(swig_obj[2], &val3);
  if (!SWIG_IsOK(ecode3)) {
    SWIG_exception_fail(SWIG_ArgError(ecode3), "in method '" "SrtpCryptoVector___setslice__" "', argument " "3"" of type '" "std::vector< pj::SrtpCrypto >::difference_type""'");
  } 
  arg3 = static_cast< std::vector< pj::SrtpCrypto >::difference_type >(val3);
  {
    std::vector< pj::SrtpCrypto,std::allocator< pj::SrtpCrypto > > *ptr = (std::vector< pj::SrtpCrypto,std::allocator< pj::SrtpCrypto > > *)0;
    res4 = swig::asptr(swig_obj[3], &ptr);
    if (!SWIG_IsOK(res4)) {
      SWIG_exception_fail(SWIG_ArgError(res4), "in method '" "SrtpCryptoVector___setslice__" "', argument " "4"" of type '" "std::vector< pj::SrtpCrypto,std::allocator< pj::SrtpCrypto > > const &""'"); 
    }
    if (!ptr) {
      SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "SrtpCryptoVector___setslice__" "', argument " "4"" of type '" "std::vector< pj::SrtpCrypto,std::allocator< pj::SrtpCrypto > > const &""'"); 
    }
    arg4 = ptr;
  }
  try {
    std_vector_Sl_pj_SrtpCrypto_Sg____setslice____SWIG_1(arg1,arg2,arg3,(std::vector< pj::SrtpCrypto,std::allocator< pj::SrtpCrypto > > const &)*arg4);
  } catch(std::out_of_range &_e) {
    SWIG_exception_fail(SWIG_IndexError, (&_e)->what());
  } catch(std::invalid_argument &_e) {
    SWIG_exception_fail(SWIG_ValueError, (&_e)->what());
  }
  resultobj = SWIG_Py_Void();
  if (SWIG_IsNewObj(res4)) delete arg4;
  return resultobj;
fail:
  if (SWIG_IsNewObj(res4)) delete arg4;
  return NULL;
}


SWIGINTERN PyObject *_wrap_SrtpCryptoVector___setslice__(PyObject *self, PyObject *args) {
  Py_ssize_t argc;
  PyObject *argv[5] = {
    0
  };
  
  if (!(argc = SWIG_Python_UnpackTuple(args, "SrtpCryptoVector___setslice__", 0, 4, argv))) SWIG_fail;
  --argc;
  if (argc == 3) {
    int _v;
    int res = swig::asptr(argv[0], (std::vector< pj::SrtpCrypto,std::allocator< pj::SrtpCrypto > >**)(0));
    _v = SWIG_CheckState(res);
    if (_v) {
      {
        int res = SWIG_AsVal_ptrdiff_t(argv[1], NULL);
        _v = SWIG_CheckState(res);
      }
      if (_v) {
        {
          int res = SWIG_AsVal_ptrdiff_t(argv[2], NULL);
          _v = SWIG_CheckState(res);
        }
        if (_v) {
          return _wrap_SrtpCryptoVector___setslice____SWIG_0(self, argc, argv);
        }
      }
    }
  }
  if (argc == 4) {
    int _v;
    int res = swig::asptr(argv[0], (std::vector< pj::SrtpCrypto,std::allocator< pj::SrtpCrypto > >**)(0));
    _v = SWIG_CheckState(res);
    if (_v) {
      {
        int res = SWIG_AsVal_ptrdiff_t(argv[1], NULL);
        _v = SWIG_CheckState(res);
      }
      if (_v) {
        {
          int res = SWIG_AsVal_ptrdiff_t(argv[2], NULL);
          _v = SWIG_CheckState(res);
        }
        if (_v) {
          int res = swig::asptr(argv[3], (std::vector< pj::SrtpCrypto,std::allocator< pj::SrtpCrypto > >**)(0));
          _v = SWIG_CheckState(res);
          if (_v) {
            return _wrap_SrtpCryptoVector___setslice____SWIG_1(self, argc, argv);
          }
        }
      }
    }
  }
  
fail:
  SWIG_Python_RaiseOrModifyTypeError("Wrong number or type of arguments for overloaded function 'SrtpCryptoVector___setslice__'.\n"
    "  Possible C/C++ prototypes are:\n"
    "    std::vector< pj::SrtpCrypto >::__setslice__(std::vector< pj::SrtpCrypto >::difference_type,std::vector< pj::SrtpCrypto >::difference_type)\n"
    "    std::vector< pj::SrtpCrypto >::__setslice__(std::vector< pj::SrtpCrypto >::difference_type,std::vector< pj::SrtpCrypto >::difference_type,std::vector< pj::SrtpCrypto,std::allocator< pj::SrtpCrypto > > const &)\n");
  return 0;
}


SWIGINTERN PyObject *_wrap_SrtpCryptoVector___delslice__(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  std::vector< pj::SrtpCrypto > *arg1 = (std::vector< pj::SrtpCrypto > *) 0 ;
  std::vector< pj::SrtpCrypto >::difference_type arg2 ;
  std::vector< pj::SrtpCrypto >::difference_type arg3 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  ptrdiff_t val2 ;
  int ecode2 = 0 ;
  ptrdiff_t val3 ;
  int ecode3 = 0 ;
  PyObject *swig_obj[3] ;
  
  if (!SWIG_Python_UnpackTuple(args, "SrtpCryptoVector___delslice__", 3, 3, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__vectorT_pj__SrtpCrypto_std__allocatorT_pj__SrtpCrypto_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "SrtpCryptoVector___delslice__" "', argument " "1"" of type '" "std::vector< pj::SrtpCrypto > *""'"); 
  }
  arg1 = reinterpret_cast< std::vector< pj::SrtpCrypto > * >(argp1);
  ecode2 = SWIG_AsVal_ptrdiff_t(swig_obj[1], &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "SrtpCryptoVector___delslice__" "', argument " "2"" of type '" "std::vector< pj::SrtpCrypto >::difference_type""'");
  } 
  arg2 = static_cast< std::vector< pj::SrtpCrypto >::difference_type >(val2);
  ecode3 = SWIG_AsVal_ptrdiff_t(swig_obj[2], &val3);
  if (!SWIG_IsOK(ecode3)) {
    SWIG_exception_fail(SWIG_ArgError(ecode3), "in method '" "SrtpCryptoVector___delslice__" "', argument " "3"" of type '" "std::vector< pj::SrtpCrypto >::difference_type""'");
  } 
  arg3 = static_cast< std::vector< pj::SrtpCrypto >::difference_type >(val3);
  try {
    std_vector_Sl_pj_SrtpCrypto_Sg____delslice__(arg1,arg2,arg3);
  } catch(std::out_of_range &_e) {
    SWIG_exception_fail(SWIG_IndexError, (&_e)->what());
  } catch(std::invalid_argument &_e) {
    SWIG_exception_fail(SWIG_ValueError, (&_e)->what());
  }
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_SrtpCryptoVector___delitem____SWIG_0(PyObject *SWIGUNUSEDPARM(self), Py_ssize_t nobjs, PyObject **swig_obj) {
  PyObject *resultobj = 0;
  std::vector< pj::SrtpCrypto > *arg1 = (std::vector< pj::SrtpCrypto > *) 0 ;
  std::vector< pj::SrtpCrypto >::difference_type arg2 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  ptrdiff_t val2 ;
  int ecode2 = 0 ;
  
  if ((nobjs < 2) || (nobjs > 2)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__vectorT_pj__SrtpCrypto_std__allocatorT_pj__SrtpCrypto_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "SrtpCryptoVector___delitem__" "', argument " "1"" of type '" "std::vector< pj::SrtpCrypto > *""'"); 
  }
  arg1 = reinterpret_cast< std::vector< pj::SrtpCrypto > * >(argp1);
  ecode2 = SWIG_AsVal_ptrdiff_t(swig_obj[1], &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "SrtpCryptoVector___delitem__" "', argument " "2"" of type '" "std::vector< pj::SrtpCrypto >::difference_type""'");
  } 
  arg2 = static_cast< std::vector< pj::SrtpCrypto >::difference_type >(val2);
  try {
    std_vector_Sl_pj_SrtpCrypto_Sg____delitem____SWIG_0(arg1,arg2);
  } catch(std::out_of_range &_e) {
    SWIG_exception_fail(SWIG_IndexError, (&_e)->what());
  } catch(std::invalid_argument &_e) {
    SWIG_exception_fail(SWIG_ValueError, (&_e)->what());
  }
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_SrtpCryptoVector___getitem____SWIG_0(PyObject *SWIGUNUSEDPARM(self), Py_ssize_t nobjs, PyObject **swig_obj) {
  PyObject *resultobj = 0;
  std::vector< pj::SrtpCrypto > *arg1 = (std::vector< pj::SrtpCrypto > *) 0 ;
  PySliceObject *arg2 = (PySliceObject *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  std::vector< pj::SrtpCrypto,std::allocator< pj::SrtpCrypto > > *result = 0 ;
  
  if ((nobjs < 2) || (nobjs > 2)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__vectorT_pj__SrtpCrypto_std__allocatorT_pj__SrtpCrypto_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "SrtpCryptoVector___getitem__" "', argument " "1"" of type '" "std::vector< pj::SrtpCrypto > *""'"); 
  }
  arg1 = reinterpret_cast< std::vector< pj::SrtpCrypto > * >(argp1);
  {
    if (!PySlice_Check(swig_obj[1])) {
      SWIG_exception_fail(SWIG_ArgError(SWIG_TypeError), "in method '" "SrtpCryptoVector___getitem__" "', argument " "2"" of type '" "PySliceObject *""'");
    }
    arg2 = (PySliceObject *) swig_obj[1];
  }
  try {
    result = (std::vector< pj::SrtpCrypto,std::allocator< pj::SrtpCrypto > > *)std_vector_Sl_pj_SrtpCrypto_Sg____getitem____SWIG_0(arg1,arg2);
  } catch(std::out_of_range &_e) {
    SWIG_exception_fail(SWIG_IndexError, (&_e)->what());
  } catch(std::invalid_argument &_e) {
    SWIG_exception_fail(SWIG_ValueError, (&_e)->what());
  }
  resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(result), SWIGTYPE_p_std__vectorT_pj__SrtpCrypto_std__allocatorT_pj__SrtpCrypto_t_t, SWIG_POINTER_OWN |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_SrtpCryptoVector___setitem____SWIG_0(PyObject *SWIGUNUSEDPARM(self), Py_ssize_t nobjs, PyObject **swig_obj) {
  PyObject *resultobj = 0;
  std::vector< pj::SrtpCrypto > *arg1 = (std::vector< pj::SrtpCrypto > *) 0 ;
  PySliceObject *arg2 = (PySliceObject *) 0 ;
  std::vector< pj::SrtpCrypto,std::allocator< pj::SrtpCrypto > > *arg3 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  int res3 = SWIG_OLDOBJ ;
  
  if ((nobjs < 3) || (nobjs > 3)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__vectorT_pj__SrtpCrypto_std__allocatorT_pj__SrtpCrypto_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "SrtpCryptoVector___setitem__" "', argument " "1"" of type '" "std::vector< pj::SrtpCrypto > *""'"); 
  }
  arg1 = reinterpret_cast< std::vector< pj::SrtpCrypto > * >(argp1);
  {
    if (!PySlice_Check(swig_obj[1])) {
      SWIG_exception_fail(SWIG_ArgError(SWIG_TypeError), "in method '" "SrtpCryptoVector___setitem__" "', argument " "2"" of type '" "PySliceObject *""'");
    }
    arg2 = (PySliceObject *) swig_obj[1];
  }
  {
    std::vector< pj::SrtpCrypto,std::allocator< pj::SrtpCrypto > > *ptr = (std::vector< pj::SrtpCrypto,std::allocator< pj::SrtpCrypto > > *)0;
    res3 = swig::asptr(swig_obj[2], &ptr);
    if (!SWIG_IsOK(res3)) {
      SWIG_exception_fail(SWIG_ArgError(res3), "in method '" "SrtpCryptoVector___setitem__" "', argument " "3"" of type '" "std::vector< pj::SrtpCrypto,std::allocator< pj::SrtpCrypto > > const &""'"); 
    }
    if (!ptr) {
      SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "SrtpCryptoVector___setitem__" "', argument " "3"" of type '" "std::vector< pj::SrtpCrypto,std::allocator< pj::SrtpCrypto > > const &""'"); 
    }
    arg3 = ptr;
  }
  try {
    std_vector_Sl_pj_SrtpCrypto_Sg____setitem____SWIG_0(arg1,arg2,(std::vector< pj::SrtpCrypto,std::allocator< pj::SrtpCrypto > > const &)*arg3);
  } catch(std::out_of_range &_e) {
    SWIG_exception_fail(SWIG_IndexError, (&_e)->what());
  } catch(std::invalid_argument &_e) {
    SWIG_exception_fail(SWIG_ValueError, (&_e)->what());
  }
  resultobj = SWIG_Py_Void();
  if (SWIG_IsNewObj(res3)) delete arg3;
  return resultobj;
fail:
  if (SWIG_IsNewObj(res3)) delete arg3;
  return NULL;
}


SWIGINTERN PyObject *_wrap_SrtpCryptoVector___setitem____SWIG_1(PyObject *SWIGUNUSEDPARM(self), Py_ssize_t nobjs, PyObject **swig_obj) {
  PyObject *resultobj = 0;
  std::vector< pj::SrtpCrypto > *arg1 = (std::vector< pj::SrtpCrypto > *) 0 ;
  PySliceObject *arg2 = (PySliceObject *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  
  if ((nobjs < 2) || (nobjs > 2)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__vectorT_pj__SrtpCrypto_std__allocatorT_pj__SrtpCrypto_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "SrtpCryptoVector___setitem__" "', argument " "1"" of type '" "std::vector< pj::SrtpCrypto > *""'"); 
  }
  arg1 = reinterpret_cast< std::vector< pj::SrtpCrypto > * >(argp1);
  {
    if (!PySlice_Check(swig_obj[1])) {
      SWIG_exception_fail(SWIG_ArgError(SWIG_TypeError), "in method '" "SrtpCryptoVector___setitem__" "', argument " "2"" of type '" "PySliceObject *""'");
    }
    arg2 = (PySliceObject *) swig_obj[1];
  }
  try {
    std_vector_Sl_pj_SrtpCrypto_Sg____setitem____SWIG_1(arg1,arg2);
  } catch(std::out_of_range &_e) {
    SWIG_exception_fail(SWIG_IndexError, (&_e)->what());
  } catch(std::invalid_argument &_e) {
    SWIG_exception_fail(SWIG_ValueError, (&_e)->what());
  }
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_SrtpCryptoVector___delitem____SWIG_1(PyObject *SWIGUNUSEDPARM(self), Py_ssize_t nobjs, PyObject **swig_obj) {
  PyObject *resultobj = 0;
  std::vector< pj::SrtpCrypto > *arg1 = (std::vector< pj::SrtpCrypto > *) 0 ;
  PySliceObject *arg2 = (PySliceObject *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  
  if ((nobjs < 2) || (nobjs > 2)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__vectorT_pj__SrtpCrypto_std__allocatorT_pj__SrtpCrypto_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "SrtpCryptoVector___delitem__" "', argument " "1"" of type '" "std::vector< pj::SrtpCrypto > *""'"); 
  }
  arg1 = reinterpret_cast< std::vector< pj::SrtpCrypto > * >(argp1);
  {
    if (!PySlice_Check(swig_obj[1])) {
      SWIG_exception_fail(SWIG_ArgError(SWIG_TypeError), "in method '" "SrtpCryptoVector___delitem__" "', argument " "2"" of type '" "PySliceObject *""'");
    }
    arg2 = (PySliceObject *) swig_obj[1];
  }
  try {
    std_vector_Sl_pj_SrtpCrypto_Sg____delitem____SWIG_1(arg1,arg2);
  } catch(std::out_of_range &_e) {
    SWIG_exception_fail(SWIG_IndexError, (&_e)->what());
  } catch(std::invalid_argument &_e) {
    SWIG_exception_fail(SWIG_ValueError, (&_e)->what());
  }
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_SrtpCryptoVector___delitem__(PyObject *self, PyObject *args) {
  Py_ssize_t argc;
  PyObject *argv[3] = {
    0
  };
  
  if (!(argc = SWIG_Python_UnpackTuple(args, "SrtpCryptoVector___delitem__", 0, 2, argv))) SWIG_fail;
  --argc;
  if (argc == 2) {
    int _v;
    int res = swig::asptr(argv[0], (std::vector< pj::SrtpCrypto,std::allocator< pj::SrtpCrypto > >**)(0));
    _v = SWIG_CheckState(res);
    if (_v) {
      {
        _v = PySlice_Check(argv[1]);
      }
      if (_v) {
        return _wrap_SrtpCryptoVector___delitem____SWIG_1(self, argc, argv);
      }
    }
  }
  if (argc == 2) {
    int _v;
    int res = swig::asptr(argv[0], (std::vector< pj::SrtpCrypto,std::allocator< pj::SrtpCrypto > >**)(0));
    _v = SWIG_CheckState(res);
    if (_v) {
      {
        int res = SWIG_AsVal_ptrdiff_t(argv[1], NULL);
        _v = SWIG_CheckState(res);
      }
      if (_v) {
        return _wrap_SrtpCryptoVector___delitem____SWIG_0(self, argc, argv);
      }
    }
  }
  
fail:
  SWIG_Python_RaiseOrModifyTypeError("Wrong number or type of arguments for overloaded function 'SrtpCryptoVector___delitem__'.\n"
    "  Possible C/C++ prototypes are:\n"
    "    std::vector< pj::SrtpCrypto >::__delitem__(std::vector< pj::SrtpCrypto >::difference_type)\n"
    "    std::vector< pj::SrtpCrypto >::__delitem__(PySliceObject *)\n");
  return 0;
}


SWIGINTERN PyObject *_wrap_SrtpCryptoVector___getitem____SWIG_1(PyObject *SWIGUNUSEDPARM(self), Py_ssize_t nobjs, PyObject **swig_obj) {
  PyObject *resultobj = 0;
  std::vector< pj::SrtpCrypto > *arg1 = (std::vector< pj::SrtpCrypto > *) 0 ;
  std::vector< pj::SrtpCrypto >::difference_type arg2 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  ptrdiff_t val2 ;
  int ecode2 = 0 ;
  std::vector< pj::SrtpCrypto >::value_type *result = 0 ;
  
  if ((nobjs < 2) || (nobjs > 2)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__vectorT_pj__SrtpCrypto_std__allocatorT_pj__SrtpCrypto_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "SrtpCryptoVector___getitem__" "', argument " "1"" of type '" "std::vector< pj::SrtpCrypto > const *""'"); 
  }
  arg1 = reinterpret_cast< std::vector< pj::SrtpCrypto > * >(argp1);
  ecode2 = SWIG_AsVal_ptrdiff_t(swig_obj[1], &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "SrtpCryptoVector___getitem__" "', argument " "2"" of type '" "std::vector< pj::SrtpCrypto >::difference_type""'");
  } 
  arg2 = static_cast< std::vector< pj::SrtpCrypto >::difference_type >(val2);
  try {
    result = (std::vector< pj::SrtpCrypto >::value_type *) &std_vector_Sl_pj_SrtpCrypto_Sg____getitem____SWIG_1((std::vector< pj::SrtpCrypto > const *)arg1,arg2);
  } catch(std::out_of_range &_e) {
    SWIG_exception_fail(SWIG_IndexError, (&_e)->what());
  }
  resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(result), SWIGTYPE_p_pj__SrtpCrypto, 0 |  0 );
  (void)swig::container_owner<swig::traits<std::vector< pj::SrtpCrypto >::value_type>::category>::back_reference(resultobj, swig_obj[0]);
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_SrtpCryptoVector___getitem__(PyObject *self, PyObject *args) {
  Py_ssize_t argc;
  PyObject *argv[3] = {
    0
  };
  
  if (!(argc = SWIG_Python_UnpackTuple(args, "SrtpCryptoVector___getitem__", 0, 2, argv))) SWIG_fail;
  --argc;
  if (argc == 2) {
    int _v;
    int res = swig::asptr(argv[0], (std::vector< pj::SrtpCrypto,std::allocator< pj::SrtpCrypto > >**)(0));
    _v = SWIG_CheckState(res);
    if (_v) {
      {
        _v = PySlice_Check(argv[1]);
      }
      if (_v) {
        return _wrap_SrtpCryptoVector___getitem____SWIG_0(self, argc, argv);
      }
    }
  }
  if (argc == 2) {
    int _v;
    int res = swig::asptr(argv[0], (std::vector< pj::SrtpCrypto,std::allocator< pj::SrtpCrypto > >**)(0));
    _v = SWIG_CheckState(res);
    if (_v) {
      {
        int res = SWIG_AsVal_ptrdiff_t(argv[1], NULL);
        _v = SWIG_CheckState(res);
      }
      if (_v) {
        return _wrap_SrtpCryptoVector___getitem____SWIG_1(self, argc, argv);
      }
    }
  }
  
fail:
  SWIG_Python_RaiseOrModifyTypeError("Wrong number or type of arguments for overloaded function 'SrtpCryptoVector___getitem__'.\n"
    "  Possible C/C++ prototypes are:\n"
    "    std::vector< pj::SrtpCrypto >::__getitem__(PySliceObject *)\n"
    "    std::vector< pj::SrtpCrypto >::__getitem__(std::vector< pj::SrtpCrypto >::difference_type) const\n");
  return 0;
}


SWIGINTERN PyObject *_wrap_SrtpCryptoVector___setitem____SWIG_2(PyObject *SWIGUNUSEDPARM(self), Py_ssize_t nobjs, PyObject **swig_obj) {
  PyObject *resultobj = 0;
  std::vector< pj::SrtpCrypto > *arg1 = (std::vector< pj::SrtpCrypto > *) 0 ;
  std::vector< pj::SrtpCrypto >::difference_type arg2 ;
  std::vector< pj::SrtpCrypto >::value_type *arg3 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  ptrdiff_t val2 ;
  int ecode2 = 0 ;
  void *argp3 = 0 ;
  int res3 = 0 ;
  
  if ((nobjs < 3) || (nobjs > 3)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__vectorT_pj__SrtpCrypto_std__allocatorT_pj__SrtpCrypto_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "SrtpCryptoVector___setitem__" "', argument " "1"" of type '" "std::vector< pj::SrtpCrypto > *""'"); 
  }
  arg1 = reinterpret_cast< std::vector< pj::SrtpCrypto > * >(argp1);
  ecode2 = SWIG_AsVal_ptrdiff_t(swig_obj[1], &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "SrtpCryptoVector___setitem__" "', argument " "2"" of type '" "std::vector< pj::SrtpCrypto >::difference_type""'");
  } 
  arg2 = static_cast< std::vector< pj::SrtpCrypto >::difference_type >(val2);
  res3 = SWIG_ConvertPtr(swig_obj[2], &argp3, SWIGTYPE_p_pj__SrtpCrypto,  0  | 0);
  if (!SWIG_IsOK(res3)) {
    SWIG_exception_fail(SWIG_ArgError(res3), "in method '" "SrtpCryptoVector___setitem__" "', argument " "3"" of type '" "std::vector< pj::SrtpCrypto >::value_type const &""'"); 
  }
  if (!argp3) {
    SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "SrtpCryptoVector___setitem__" "', argument " "3"" of type '" "std::vector< pj::SrtpCrypto >::value_type const &""'"); 
  }
  arg3 = reinterpret_cast< std::vector< pj::SrtpCrypto >::value_type * >(argp3);
  try {
    std_vector_Sl_pj_SrtpCrypto_Sg____setitem____SWIG_2(arg1,arg2,(pj::SrtpCrypto const &)*arg3);
  } catch(std::out_of_range &_e) {
    SWIG_exception_fail(SWIG_IndexError, (&_e)->what());
  }
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_SrtpCryptoVector___setitem__(PyObject *self, PyObject *args) {
  Py_ssize_t argc;
  PyObject *argv[4] = {
    0
  };
  
  if (!(argc = SWIG_Python_UnpackTuple(args, "SrtpCryptoVector___setitem__", 0, 3, argv))) SWIG_fail;
  --argc;
  if (argc == 2) {
    int _v;
    int res = swig::asptr(argv[0], (std::vector< pj::SrtpCrypto,std::allocator< pj::SrtpCrypto > >**)(0));
    _v = SWIG_CheckState(res);
    if (_v) {
      {
        _v = PySlice_Check(argv[1]);
      }
      if (_v) {
        return _wrap_SrtpCryptoVector___setitem____SWIG_1(self, argc, argv);
      }
    }
  }
  if (argc == 3) {
    int _v;
    int res = swig::asptr(argv[0], (std::vector< pj::SrtpCrypto,std::allocator< pj::SrtpCrypto > >**)(0));
    _v = SWIG_CheckState(res);
    if (_v) {
      {
        _v = PySlice_Check(argv[1]);
      }
      if (_v) {
        int res = swig::asptr(argv[2], (std::vector< pj::SrtpCrypto,std::allocator< pj::SrtpCrypto > >**)(0));
        _v = SWIG_CheckState(res);
        if (_v) {
          return _wrap_SrtpCryptoVector___setitem____SWIG_0(self, argc, argv);
        }
      }
    }
  }
  if (argc == 3) {
    int _v;
    int res = swig::asptr(argv[0], (std::vector< pj::SrtpCrypto,std::allocator< pj::SrtpCrypto > >**)(0));
    _v = SWIG_CheckState(res);
    if (_v) {
      {
        int res = SWIG_AsVal_ptrdiff_t(argv[1], NULL);
        _v = SWIG_CheckState(res);
      }
      if (_v) {
        int res = SWIG_ConvertPtr(argv[2], 0, SWIGTYPE_p_pj__SrtpCrypto, SWIG_POINTER_NO_NULL | 0);
        _v = SWIG_CheckState(res);
        if (_v) {
          return _wrap_SrtpCryptoVector___setitem____SWIG_2(self, argc, argv);
        }
      }
    }
  }
  
fail:
  SWIG_Python_RaiseOrModifyTypeError("Wrong number or type of arguments for overloaded function 'SrtpCryptoVector___setitem__'.\n"
    "  Possible C/C++ prototypes are:\n"
    "    std::vector< pj::SrtpCrypto >::__setitem__(PySliceObject *,std::vector< pj::SrtpCrypto,std::allocator< pj::SrtpCrypto > > const &)\n"
    "    std::vector< pj::SrtpCrypto >::__setitem__(PySliceObject *)\n"
    "    std::vector< pj::SrtpCrypto >::__setitem__(std::vector< pj::SrtpCrypto >::difference_type,std::vector< pj::SrtpCrypto >::value_type const &)\n");
  return 0;
}


SWIGINTERN PyObject *_wrap_SrtpCryptoVector_pop(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  std::vector< pj::SrtpCrypto > *arg1 = (std::vector< pj::SrtpCrypto > *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  std::vector< pj::SrtpCrypto >::value_type result;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__vectorT_pj__SrtpCrypto_std__allocatorT_pj__SrtpCrypto_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "SrtpCryptoVector_pop" "', argument " "1"" of type '" "std::vector< pj::SrtpCrypto > *""'"); 
  }
  arg1 = reinterpret_cast< std::vector< pj::SrtpCrypto > * >(argp1);
  try {
    result = std_vector_Sl_pj_SrtpCrypto_Sg__pop(arg1);
  } catch(std::out_of_range &_e) {
    SWIG_exception_fail(SWIG_IndexError, (&_e)->what());
  }
  resultobj = SWIG_NewPointerObj((new std::vector< pj::SrtpCrypto >::value_type(static_cast< const std::vector< pj::SrtpCrypto >::value_type& >(result))), SWIGTYPE_p_pj__SrtpCrypto, SWIG_POINTER_OWN |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_SrtpCryptoVector_append(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  std::vector< pj::SrtpCrypto > *arg1 = (std::vector< pj::SrtpCrypto > *) 0 ;
  std::vector< pj::SrtpCrypto >::value_type *arg2 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  void *argp2 = 0 ;
  int res2 = 0 ;
  PyObject *swig_obj[2] ;
  
  if (!SWIG_Python_UnpackTuple(args, "SrtpCryptoVector_append", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__vectorT_pj__SrtpCrypto_std__allocatorT_pj__SrtpCrypto_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "SrtpCryptoVector_append" "', argument " "1"" of type '" "std::vector< pj::SrtpCrypto > *""'"); 
  }
  arg1 = reinterpret_cast< std::vector< pj::SrtpCrypto > * >(argp1);
  res2 = SWIG_ConvertPtr(swig_obj[1], &argp2, SWIGTYPE_p_pj__SrtpCrypto,  0  | 0);
  if (!SWIG_IsOK(res2)) {
    SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "SrtpCryptoVector_append" "', argument " "2"" of type '" "std::vector< pj::SrtpCrypto >::value_type const &""'"); 
  }
  if (!argp2) {
    SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "SrtpCryptoVector_append" "', argument " "2"" of type '" "std::vector< pj::SrtpCrypto >::value_type const &""'"); 
  }
  arg2 = reinterpret_cast< std::vector< pj::SrtpCrypto >::value_type * >(argp2);
  std_vector_Sl_pj_SrtpCrypto_Sg__append(arg1,(pj::SrtpCrypto const &)*arg2);
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_new_SrtpCryptoVector__SWIG_0(PyObject *SWIGUNUSEDPARM(self), Py_ssize_t nobjs, PyObject **SWIGUNUSEDPARM(swig_obj)) {
  PyObject *resultobj = 0;
  std::vector< pj::SrtpCrypto > *result = 0 ;
  
  if ((nobjs < 0) || (nobjs > 0)) SWIG_fail;
  result = (std::vector< pj::SrtpCrypto > *)new std::vector< pj::SrtpCrypto >();
  resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(result), SWIGTYPE_p_std__vectorT_pj__SrtpCrypto_std__allocatorT_pj__SrtpCrypto_t_t, SWIG_POINTER_NEW |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_new_SrtpCryptoVector__SWIG_1(PyObject *SWIGUNUSEDPARM(self), Py_ssize_t nobjs, PyObject **swig_obj) {
  PyObject *resultobj = 0;
  std::vector< pj::SrtpCrypto > *arg1 = 0 ;
  int res1 = SWIG_OLDOBJ ;
  std::vector< pj::SrtpCrypto > *result = 0 ;
  
  if ((nobjs < 1) || (nobjs > 1)) SWIG_fail;
  {
    std::vector< pj::SrtpCrypto,std::allocator< pj::SrtpCrypto > > *ptr = (std::vector< pj::SrtpCrypto,std::allocator< pj::SrtpCrypto > > *)0;
    res1 = swig::asptr(swig_obj[0], &ptr);
    if (!SWIG_IsOK(res1)) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "new_SrtpCryptoVector" "', argument " "1"" of type '" "std::vector< pj::SrtpCrypto > const &""'"); 
    }
    if (!ptr) {
      SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "new_SrtpCryptoVector" "', argument " "1"" of type '" "std::vector< pj::SrtpCrypto > const &""'"); 
    }
    arg1 = ptr;
  }
  result = (std::vector< pj::SrtpCrypto > *)new std::vector< pj::SrtpCrypto >((std::vector< pj::SrtpCrypto > const &)*arg1);
  resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(result), SWIGTYPE_p_std__vectorT_pj__SrtpCrypto_std__allocatorT_pj__SrtpCrypto_t_t, SWIG_POINTER_NEW |  0 );
  if (SWIG_IsNewObj(res1)) delete arg1;
  return resultobj;
fail:
  if (SWIG_IsNewObj(res1)) delete arg1;
  return NULL;
}


SWIGINTERN PyObject *_wrap_SrtpCryptoVector_empty(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  std::vector< pj::SrtpCrypto > *arg1 = (std::vector< pj::SrtpCrypto > *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  bool result;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__vectorT_pj__SrtpCrypto_std__allocatorT_pj__SrtpCrypto_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "SrtpCryptoVector_empty" "', argument " "1"" of type '" "std::vector< pj::SrtpCrypto > const *""'"); 
  }
  arg1 = reinterpret_cast< std::vector< pj::SrtpCrypto > * >(argp1);
  result = (bool)((std::vector< pj::SrtpCrypto > const *)arg1)->empty();
  resultobj = SWIG_From_bool(static_cast< bool >(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_SrtpCryptoVector_size(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  std::vector< pj::SrtpCrypto > *arg1 = (std::vector< pj::SrtpCrypto > *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  std::vector< pj::SrtpCrypto >::size_type result;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__vectorT_pj__SrtpCrypto_std__allocatorT_pj__SrtpCrypto_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "SrtpCryptoVector_size" "', argument " "1"" of type '" "std::vector< pj::SrtpCrypto > const *""'"); 
  }
  arg1 = reinterpret_cast< std::vector< pj::SrtpCrypto > * >(argp1);
  result = ((std::vector< pj::SrtpCrypto > const *)arg1)->size();
  resultobj = SWIG_From_size_t(static_cast< size_t >(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_SrtpCryptoVector_swap(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  std::vector< pj::SrtpCrypto > *arg1 = (std::vector< pj::SrtpCrypto > *) 0 ;
  std::vector< pj::SrtpCrypto > *arg2 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  void *argp2 = 0 ;
  int res2 = 0 ;
  PyObject *swig_obj[2] ;
  
  if (!SWIG_Python_UnpackTuple(args, "SrtpCryptoVector_swap", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__vectorT_pj__SrtpCrypto_std__allocatorT_pj__SrtpCrypto_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "SrtpCryptoVector_swap" "', argument " "1"" of type '" "std::vector< pj::SrtpCrypto > *""'"); 
  }
  arg1 = reinterpret_cast< std::vector< pj::SrtpCrypto > * >(argp1);
  res2 = SWIG_ConvertPtr(swig_obj[1], &argp2, SWIGTYPE_p_std__vectorT_pj__SrtpCrypto_std__allocatorT_pj__SrtpCrypto_t_t,  0 );
  if (!SWIG_IsOK(res2)) {
    SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "SrtpCryptoVector_swap" "', argument " "2"" of type '" "std::vector< pj::SrtpCrypto > &""'"); 
  }
  if (!argp2) {
    SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "SrtpCryptoVector_swap" "', argument " "2"" of type '" "std::vector< pj::SrtpCrypto > &""'"); 
  }
  arg2 = reinterpret_cast< std::vector< pj::SrtpCrypto > * >(argp2);
  (arg1)->swap(*arg2);
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_SrtpCryptoVector_begin(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  std::vector< pj::SrtpCrypto > *arg1 = (std::vector< pj::SrtpCrypto > *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  std::vector< pj::SrtpCrypto >::iterator result;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__vectorT_pj__SrtpCrypto_std__allocatorT_pj__SrtpCrypto_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "SrtpCryptoVector_begin" "', argument " "1"" of type '" "std::vector< pj::SrtpCrypto > *""'"); 
  }
  arg1 = reinterpret_cast< std::vector< pj::SrtpCrypto > * >(argp1);
  result = (arg1)->begin();
  resultobj = SWIG_NewPointerObj(swig::make_output_iterator(static_cast< const std::vector< pj::SrtpCrypto >::iterator & >(result)),
    swig::SwigPyIterator::descriptor(),SWIG_POINTER_OWN);
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_SrtpCryptoVector_end(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  std::vector< pj::SrtpCrypto > *arg1 = (std::vector< pj::SrtpCrypto > *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  std::vector< pj::SrtpCrypto >::iterator result;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__vectorT_pj__SrtpCrypto_std__allocatorT_pj__SrtpCrypto_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "SrtpCryptoVector_end" "', argument " "1"" of type '" "std::vector< pj::SrtpCrypto > *""'"); 
  }
  arg1 = reinterpret_cast< std::vector< pj::SrtpCrypto > * >(argp1);
  result = (arg1)->end();
  resultobj = SWIG_NewPointerObj(swig::make_output_iterator(static_cast< const std::vector< pj::SrtpCrypto >::iterator & >(result)),
    swig::SwigPyIterator::descriptor(),SWIG_POINTER_OWN);
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_SrtpCryptoVector_rbegin(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  std::vector< pj::SrtpCrypto > *arg1 = (std::vector< pj::SrtpCrypto > *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  std::vector< pj::SrtpCrypto >::reverse_iterator result;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__vectorT_pj__SrtpCrypto_std__allocatorT_pj__SrtpCrypto_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "SrtpCryptoVector_rbegin" "', argument " "1"" of type '" "std::vector< pj::SrtpCrypto > *""'"); 
  }
  arg1 = reinterpret_cast< std::vector< pj::SrtpCrypto > * >(argp1);
  result = (arg1)->rbegin();
  resultobj = SWIG_NewPointerObj(swig::make_output_iterator(static_cast< const std::vector< pj::SrtpCrypto >::reverse_iterator & >(result)),
    swig::SwigPyIterator::descriptor(),SWIG_POINTER_OWN);
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_SrtpCryptoVector_rend(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  std::vector< pj::SrtpCrypto > *arg1 = (std::vector< pj::SrtpCrypto > *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  std::vector< pj::SrtpCrypto >::reverse_iterator result;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__vectorT_pj__SrtpCrypto_std__allocatorT_pj__SrtpCrypto_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "SrtpCryptoVector_rend" "', argument " "1"" of type '" "std::vector< pj::SrtpCrypto > *""'"); 
  }
  arg1 = reinterpret_cast< std::vector< pj::SrtpCrypto > * >(argp1);
  result = (arg1)->rend();
  resultobj = SWIG_NewPointerObj(swig::make_output_iterator(static_cast< const std::vector< pj::SrtpCrypto >::reverse_iterator & >(result)),
    swig::SwigPyIterator::descriptor(),SWIG_POINTER_OWN);
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_SrtpCryptoVector_clear(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  std::vector< pj::SrtpCrypto > *arg1 = (std::vector< pj::SrtpCrypto > *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__vectorT_pj__SrtpCrypto_std__allocatorT_pj__SrtpCrypto_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "SrtpCryptoVector_clear" "', argument " "1"" of type '" "std::vector< pj::SrtpCrypto > *""'"); 
  }
  arg1 = reinterpret_cast< std::vector< pj::SrtpCrypto > * >(argp1);
  (arg1)->clear();
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_SrtpCryptoVector_get_allocator(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  std::vector< pj::SrtpCrypto > *arg1 = (std::vector< pj::SrtpCrypto > *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  SwigValueWrapper< std::allocator< pj::SrtpCrypto > > result;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__vectorT_pj__SrtpCrypto_std__allocatorT_pj__SrtpCrypto_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "SrtpCryptoVector_get_allocator" "', argument " "1"" of type '" "std::vector< pj::SrtpCrypto > const *""'"); 
  }
  arg1 = reinterpret_cast< std::vector< pj::SrtpCrypto > * >(argp1);
  result = ((std::vector< pj::SrtpCrypto > const *)arg1)->get_allocator();
  resultobj = SWIG_NewPointerObj((new std::vector< pj::SrtpCrypto >::allocator_type(static_cast< const std::vector< pj::SrtpCrypto >::allocator_type& >(result))), SWIGTYPE_p_std__allocatorT_pj__SrtpCrypto_t, SWIG_POINTER_OWN |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_new_SrtpCryptoVector__SWIG_2(PyObject *SWIGUNUSEDPARM(self), Py_ssize_t nobjs, PyObject **swig_obj) {
  PyObject *resultobj = 0;
  std::vector< pj::SrtpCrypto >::size_type arg1 ;
  size_t val1 ;
  int ecode1 = 0 ;
  std::vector< pj::SrtpCrypto > *result = 0 ;
  
  if ((nobjs < 1) || (nobjs > 1)) SWIG_fail;
  ecode1 = SWIG_AsVal_size_t(swig_obj[0], &val1);
  if (!SWIG_IsOK(ecode1)) {
    SWIG_exception_fail(SWIG_ArgError(ecode1), "in method '" "new_SrtpCryptoVector" "', argument " "1"" of type '" "std::vector< pj::SrtpCrypto >::size_type""'");
  } 
  arg1 = static_cast< std::vector< pj::SrtpCrypto >::size_type >(val1);
  result = (std::vector< pj::SrtpCrypto > *)new std::vector< pj::SrtpCrypto >(arg1);
  resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(result), SWIGTYPE_p_std__vectorT_pj__SrtpCrypto_std__allocatorT_pj__SrtpCrypto_t_t, SWIG_POINTER_NEW |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_SrtpCryptoVector_pop_back(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  std::vector< pj::SrtpCrypto > *arg1 = (std::vector< pj::SrtpCrypto > *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__vectorT_pj__SrtpCrypto_std__allocatorT_pj__SrtpCrypto_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "SrtpCryptoVector_pop_back" "', argument " "1"" of type '" "std::vector< pj::SrtpCrypto > *""'"); 
  }
  arg1 = reinterpret_cast< std::vector< pj::SrtpCrypto > * >(argp1);
  (arg1)->pop_back();
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_SrtpCryptoVector_resize__SWIG_0(PyObject *SWIGUNUSEDPARM(self), Py_ssize_t nobjs, PyObject **swig_obj) {
  PyObject *resultobj = 0;
  std::vector< pj::SrtpCrypto > *arg1 = (std::vector< pj::SrtpCrypto > *) 0 ;
  std::vector< pj::SrtpCrypto >::size_type arg2 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  size_t val2 ;
  int ecode2 = 0 ;
  
  if ((nobjs < 2) || (nobjs > 2)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__vectorT_pj__SrtpCrypto_std__allocatorT_pj__SrtpCrypto_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "SrtpCryptoVector_resize" "', argument " "1"" of type '" "std::vector< pj::SrtpCrypto > *""'"); 
  }
  arg1 = reinterpret_cast< std::vector< pj::SrtpCrypto > * >(argp1);
  ecode2 = SWIG_AsVal_size_t(swig_obj[1], &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "SrtpCryptoVector_resize" "', argument " "2"" of type '" "std::vector< pj::SrtpCrypto >::size_type""'");
  } 
  arg2 = static_cast< std::vector< pj::SrtpCrypto >::size_type >(val2);
  (arg1)->resize(arg2);
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_SrtpCryptoVector_erase__SWIG_0(PyObject *SWIGUNUSEDPARM(self), Py_ssize_t nobjs, PyObject **swig_obj) {
  PyObject *resultobj = 0;
  std::vector< pj::SrtpCrypto > *arg1 = (std::vector< pj::SrtpCrypto > *) 0 ;
  std::vector< pj::SrtpCrypto >::iterator arg2 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  swig::SwigPyIterator *iter2 = 0 ;
  int res2 ;
  std::vector< pj::SrtpCrypto >::iterator result;
  
  if ((nobjs < 2) || (nobjs > 2)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__vectorT_pj__SrtpCrypto_std__allocatorT_pj__SrtpCrypto_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "SrtpCryptoVector_erase" "', argument " "1"" of type '" "std::vector< pj::SrtpCrypto > *""'"); 
  }
  arg1 = reinterpret_cast< std::vector< pj::SrtpCrypto > * >(argp1);
  res2 = SWIG_ConvertPtr(swig_obj[1], SWIG_as_voidptrptr(&iter2), swig::SwigPyIterator::descriptor(), 0);
  if (!SWIG_IsOK(res2) || !iter2) {
    SWIG_exception_fail(SWIG_ArgError(SWIG_TypeError), "in method '" "SrtpCryptoVector_erase" "', argument " "2"" of type '" "std::vector< pj::SrtpCrypto >::iterator""'");
  } else {
    swig::SwigPyIterator_T<std::vector< pj::SrtpCrypto >::iterator > *iter_t = dynamic_cast<swig::SwigPyIterator_T<std::vector< pj::SrtpCrypto >::iterator > *>(iter2);
    if (iter_t) {
      arg2 = iter_t->get_current();
    } else {
      SWIG_exception_fail(SWIG_ArgError(SWIG_TypeError), "in method '" "SrtpCryptoVector_erase" "', argument " "2"" of type '" "std::vector< pj::SrtpCrypto >::iterator""'");
    }
  }
  result = std_vector_Sl_pj_SrtpCrypto_Sg__erase__SWIG_0(arg1,arg2);
  resultobj = SWIG_NewPointerObj(swig::make_output_iterator(static_cast< const std::vector< pj::SrtpCrypto >::iterator & >(result)),
    swig::SwigPyIterator::descriptor(),SWIG_POINTER_OWN);
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_SrtpCryptoVector_erase__SWIG_1(PyObject *SWIGUNUSEDPARM(self), Py_ssize_t nobjs, PyObject **swig_obj) {
  PyObject *resultobj = 0;
  std::vector< pj::SrtpCrypto > *arg1 = (std::vector< pj::SrtpCrypto > *) 0 ;
  std::vector< pj::SrtpCrypto >::iterator arg2 ;
  std::vector< pj::SrtpCrypto >::iterator arg3 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  swig::SwigPyIterator *iter2 = 0 ;
  int res2 ;
  swig::SwigPyIterator *iter3 = 0 ;
  int res3 ;
  std::vector< pj::SrtpCrypto >::iterator result;
  
  if ((nobjs < 3) || (nobjs > 3)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__vectorT_pj__SrtpCrypto_std__allocatorT_pj__SrtpCrypto_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "SrtpCryptoVector_erase" "', argument " "1"" of type '" "std::vector< pj::SrtpCrypto > *""'"); 
  }
  arg1 = reinterpret_cast< std::vector< pj::SrtpCrypto > * >(argp1);
  res2 = SWIG_ConvertPtr(swig_obj[1], SWIG_as_voidptrptr(&iter2), swig::SwigPyIterator::descriptor(), 0);
  if (!SWIG_IsOK(res2) || !iter2) {
    SWIG_exception_fail(SWIG_ArgError(SWIG_TypeError), "in method '" "SrtpCryptoVector_erase" "', argument " "2"" of type '" "std::vector< pj::SrtpCrypto >::iterator""'");
  } else {
    swig::SwigPyIterator_T<std::vector< pj::SrtpCrypto >::iterator > *iter_t = dynamic_cast<swig::SwigPyIterator_T<std::vector< pj::SrtpCrypto >::iterator > *>(iter2);
    if (iter_t) {
      arg2 = iter_t->get_current();
    } else {
      SWIG_exception_fail(SWIG_ArgError(SWIG_TypeError), "in method '" "SrtpCryptoVector_erase" "', argument " "2"" of type '" "std::vector< pj::SrtpCrypto >::iterator""'");
    }
  }
  res3 = SWIG_ConvertPtr(swig_obj[2], SWIG_as_voidptrptr(&iter3), swig::SwigPyIterator::descriptor(), 0);
  if (!SWIG_IsOK(res3) || !iter3) {
    SWIG_exception_fail(SWIG_ArgError(SWIG_TypeError), "in method '" "SrtpCryptoVector_erase" "', argument " "3"" of type '" "std::vector< pj::SrtpCrypto >::iterator""'");
  } else {
    swig::SwigPyIterator_T<std::vector< pj::SrtpCrypto >::iterator > *iter_t = dynamic_cast<swig::SwigPyIterator_T<std::vector< pj::SrtpCrypto >::iterator > *>(iter3);
    if (iter_t) {
      arg3 = iter_t->get_current();
    } else {
      SWIG_exception_fail(SWIG_ArgError(SWIG_TypeError), "in method '" "SrtpCryptoVector_erase" "', argument " "3"" of type '" "std::vector< pj::SrtpCrypto >::iterator""'");
    }
  }
  result = std_vector_Sl_pj_SrtpCrypto_Sg__erase__SWIG_1(arg1,arg2,arg3);
  resultobj = SWIG_NewPointerObj(swig::make_output_iterator(static_cast< const std::vector< pj::SrtpCrypto >::iterator & >(result)),
    swig::SwigPyIterator::descriptor(),SWIG_POINTER_OWN);
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_SrtpCryptoVector_erase(PyObject *self, PyObject *args) {
  Py_ssize_t argc;
  PyObject *argv[4] = {
    0
  };
  
  if (!(argc = SWIG_Python_UnpackTuple(args, "SrtpCryptoVector_erase", 0, 3, argv))) SWIG_fail;
  --argc;
  if (argc == 2) {
    int _v;
    int res = swig::asptr(argv[0], (std::vector< pj::SrtpCrypto,std::allocator< pj::SrtpCrypto > >**)(0));
    _v = SWIG_CheckState(res);
    if (_v) {
      swig::SwigPyIterator *iter = 0;
      int res = SWIG_ConvertPtr(argv[1], SWIG_as_voidptrptr(&iter), swig::SwigPyIterator::descriptor(), 0);
      _v = (SWIG_IsOK(res) && iter && (dynamic_cast<swig::SwigPyIterator_T<std::vector< pj::SrtpCrypto >::iterator > *>(iter) != 0));
      if (_v) {
        return _wrap_SrtpCryptoVector_erase__SWIG_0(self, argc, argv);
      }
    }
  }
  if (argc == 3) {
    int _v;
    int res = swig::asptr(argv[0], (std::vector< pj::SrtpCrypto,std::allocator< pj::SrtpCrypto > >**)(0));
    _v = SWIG_CheckState(res);
    if (_v) {
      swig::SwigPyIterator *iter = 0;
      int res = SWIG_ConvertPtr(argv[1], SWIG_as_voidptrptr(&iter), swig::SwigPyIterator::descriptor(), 0);
      _v = (SWIG_IsOK(res) && iter && (dynamic_cast<swig::SwigPyIterator_T<std::vector< pj::SrtpCrypto >::iterator > *>(iter) != 0));
      if (_v) {
        swig::SwigPyIterator *iter = 0;
        int res = SWIG_ConvertPtr(argv[2], SWIG_as_voidptrptr(&iter), swig::SwigPyIterator::descriptor(), 0);
        _v = (SWIG_IsOK(res) && iter && (dynamic_cast<swig::SwigPyIterator_T<std::vector< pj::SrtpCrypto >::iterator > *>(iter) != 0));
        if (_v) {
          return _wrap_SrtpCryptoVector_erase__SWIG_1(self, argc, argv);
        }
      }
    }
  }
  
fail:
  SWIG_Python_RaiseOrModifyTypeError("Wrong number or type of arguments for overloaded function 'SrtpCryptoVector_erase'.\n"
    "  Possible C/C++ prototypes are:\n"
    "    std::vector< pj::SrtpCrypto >::erase(std::vector< pj::SrtpCrypto >::iterator)\n"
    "    std::vector< pj::SrtpCrypto >::erase(std::vector< pj::SrtpCrypto >::iterator,std::vector< pj::SrtpCrypto >::iterator)\n");
  return 0;
}


SWIGINTERN PyObject *_wrap_new_SrtpCryptoVector__SWIG_3(PyObject *SWIGUNUSEDPARM(self), Py_ssize_t nobjs, PyObject **swig_obj) {
  PyObject *resultobj = 0;
  std::vector< pj::SrtpCrypto >::size_type arg1 ;
  std::vector< pj::SrtpCrypto >::value_type *arg2 = 0 ;
  size_t val1 ;
  int ecode1 = 0 ;
  void *argp2 = 0 ;
  int res2 = 0 ;
  std::vector< pj::SrtpCrypto > *result = 0 ;
  
  if ((nobjs < 2) || (nobjs > 2)) SWIG_fail;
  ecode1 = SWIG_AsVal_size_t(swig_obj[0], &val1);
  if (!SWIG_IsOK(ecode1)) {
    SWIG_exception_fail(SWIG_ArgError(ecode1), "in method '" "new_SrtpCryptoVector" "', argument " "1"" of type '" "std::vector< pj::SrtpCrypto >::size_type""'");
  } 
  arg1 = static_cast< std::vector< pj::SrtpCrypto >::size_type >(val1);
  res2 = SWIG_ConvertPtr(swig_obj[1], &argp2, SWIGTYPE_p_pj__SrtpCrypto,  0  | 0);
  if (!SWIG_IsOK(res2)) {
    SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "new_SrtpCryptoVector" "', argument " "2"" of type '" "std::vector< pj::SrtpCrypto >::value_type const &""'"); 
  }
  if (!argp2) {
    SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "new_SrtpCryptoVector" "', argument " "2"" of type '" "std::vector< pj::SrtpCrypto >::value_type const &""'"); 
  }
  arg2 = reinterpret_cast< std::vector< pj::SrtpCrypto >::value_type * >(argp2);
  result = (std::vector< pj::SrtpCrypto > *)new std::vector< pj::SrtpCrypto >(arg1,(std::vector< pj::SrtpCrypto >::value_type const &)*arg2);
  resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(result), SWIGTYPE_p_std__vectorT_pj__SrtpCrypto_std__allocatorT_pj__SrtpCrypto_t_t, SWIG_POINTER_NEW |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_new_SrtpCryptoVector(PyObject *self, PyObject *args) {
  Py_ssize_t argc;
  PyObject *argv[3] = {
    0
  };
  
  if (!(argc = SWIG_Python_UnpackTuple(args, "new_SrtpCryptoVector", 0, 2, argv))) SWIG_fail;
  --argc;
  if (argc == 0) {
    return _wrap_new_SrtpCryptoVector__SWIG_0(self, argc, argv);
  }
  if (argc == 1) {
    int _v;
    {
      int res = SWIG_AsVal_size_t(argv[0], NULL);
      _v = SWIG_CheckState(res);
    }
    if (_v) {
      return _wrap_new_SrtpCryptoVector__SWIG_2(self, argc, argv);
    }
  }
  if (argc == 1) {
    int _v;
    int res = swig::asptr(argv[0], (std::vector< pj::SrtpCrypto,std::allocator< pj::SrtpCrypto > >**)(0));
    _v = SWIG_CheckState(res);
    if (_v) {
      return _wrap_new_SrtpCryptoVector__SWIG_1(self, argc, argv);
    }
  }
  if (argc == 2) {
    int _v;
    {
      int res = SWIG_AsVal_size_t(argv[0], NULL);
      _v = SWIG_CheckState(res);
    }
    if (_v) {
      int res = SWIG_ConvertPtr(argv[1], 0, SWIGTYPE_p_pj__SrtpCrypto, SWIG_POINTER_NO_NULL | 0);
      _v = SWIG_CheckState(res);
      if (_v) {
        return _wrap_new_SrtpCryptoVector__SWIG_3(self, argc, argv);
      }
    }
  }
  
fail:
  SWIG_Python_RaiseOrModifyTypeError("Wrong number or type of arguments for overloaded function 'new_SrtpCryptoVector'.\n"
    "  Possible C/C++ prototypes are:\n"
    "    std::vector< pj::SrtpCrypto >::vector()\n"
    "    std::vector< pj::SrtpCrypto >::vector(std::vector< pj::SrtpCrypto > const &)\n"
    "    std::vector< pj::SrtpCrypto >::vector(std::vector< pj::SrtpCrypto >::size_type)\n"
    "    std::vector< pj::SrtpCrypto >::vector(std::vector< pj::SrtpCrypto >::size_type,std::vector< pj::SrtpCrypto >::value_type const &)\n");
  return 0;
}


SWIGINTERN PyObject *_wrap_SrtpCryptoVector_push_back(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  std::vector< pj::SrtpCrypto > *arg1 = (std::vector< pj::SrtpCrypto > *) 0 ;
  std::vector< pj::SrtpCrypto >::value_type *arg2 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  void *argp2 = 0 ;
  int res2 = 0 ;
  PyObject *swig_obj[2] ;
  
  if (!SWIG_Python_UnpackTuple(args, "SrtpCryptoVector_push_back", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__vectorT_pj__SrtpCrypto_std__allocatorT_pj__SrtpCrypto_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "SrtpCryptoVector_push_back" "', argument " "1"" of type '" "std::vector< pj::SrtpCrypto > *""'"); 
  }
  arg1 = reinterpret_cast< std::vector< pj::SrtpCrypto > * >(argp1);
  res2 = SWIG_ConvertPtr(swig_obj[1], &argp2, SWIGTYPE_p_pj__SrtpCrypto,  0  | 0);
  if (!SWIG_IsOK(res2)) {
    SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "SrtpCryptoVector_push_back" "', argument " "2"" of type '" "std::vector< pj::SrtpCrypto >::value_type const &""'"); 
  }
  if (!argp2) {
    SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "SrtpCryptoVector_push_back" "', argument " "2"" of type '" "std::vector< pj::SrtpCrypto >::value_type const &""'"); 
  }
  arg2 = reinterpret_cast< std::vector< pj::SrtpCrypto >::value_type * >(argp2);
  (arg1)->push_back((std::vector< pj::SrtpCrypto >::value_type const &)*arg2);
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_SrtpCryptoVector_front(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  std::vector< pj::SrtpCrypto > *arg1 = (std::vector< pj::SrtpCrypto > *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  std::vector< pj::SrtpCrypto >::value_type *result = 0 ;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__vectorT_pj__SrtpCrypto_std__allocatorT_pj__SrtpCrypto_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "SrtpCryptoVector_front" "', argument " "1"" of type '" "std::vector< pj::SrtpCrypto > const *""'"); 
  }
  arg1 = reinterpret_cast< std::vector< pj::SrtpCrypto > * >(argp1);
  result = (std::vector< pj::SrtpCrypto >::value_type *) &((std::vector< pj::SrtpCrypto > const *)arg1)->front();
  resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(result), SWIGTYPE_p_pj__SrtpCrypto, 0 |  0 );
  (void)swig::container_owner<swig::traits<std::vector< pj::SrtpCrypto >::value_type>::category>::back_reference(resultobj, swig_obj[0]);
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_SrtpCryptoVector_back(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  std::vector< pj::SrtpCrypto > *arg1 = (std::vector< pj::SrtpCrypto > *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  std::vector< pj::SrtpCrypto >::value_type *result = 0 ;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__vectorT_pj__SrtpCrypto_std__allocatorT_pj__SrtpCrypto_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "SrtpCryptoVector_back" "', argument " "1"" of type '" "std::vector< pj::SrtpCrypto > const *""'"); 
  }
  arg1 = reinterpret_cast< std::vector< pj::SrtpCrypto > * >(argp1);
  result = (std::vector< pj::SrtpCrypto >::value_type *) &((std::vector< pj::SrtpCrypto > const *)arg1)->back();
  resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(result), SWIGTYPE_p_pj__SrtpCrypto, 0 |  0 );
  (void)swig::container_owner<swig::traits<std::vector< pj::SrtpCrypto >::value_type>::category>::back_reference(resultobj, swig_obj[0]);
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_SrtpCryptoVector_assign(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  std::vector< pj::SrtpCrypto > *arg1 = (std::vector< pj::SrtpCrypto > *) 0 ;
  std::vector< pj::SrtpCrypto >::size_type arg2 ;
  std::vector< pj::SrtpCrypto >::value_type *arg3 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  size_t val2 ;
  int ecode2 = 0 ;
  void *argp3 = 0 ;
  int res3 = 0 ;
  PyObject *swig_obj[3] ;
  
  if (!SWIG_Python_UnpackTuple(args, "SrtpCryptoVector_assign", 3, 3, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__vectorT_pj__SrtpCrypto_std__allocatorT_pj__SrtpCrypto_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "SrtpCryptoVector_assign" "', argument " "1"" of type '" "std::vector< pj::SrtpCrypto > *""'"); 
  }
  arg1 = reinterpret_cast< std::vector< pj::SrtpCrypto > * >(argp1);
  ecode2 = SWIG_AsVal_size_t(swig_obj[1], &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "SrtpCryptoVector_assign" "', argument " "2"" of type '" "std::vector< pj::SrtpCrypto >::size_type""'");
  } 
  arg2 = static_cast< std::vector< pj::SrtpCrypto >::size_type >(val2);
  res3 = SWIG_ConvertPtr(swig_obj[2], &argp3, SWIGTYPE_p_pj__SrtpCrypto,  0  | 0);
  if (!SWIG_IsOK(res3)) {
    SWIG_exception_fail(SWIG_ArgError(res3), "in method '" "SrtpCryptoVector_assign" "', argument " "3"" of type '" "std::vector< pj::SrtpCrypto >::value_type const &""'"); 
  }
  if (!argp3) {
    SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "SrtpCryptoVector_assign" "', argument " "3"" of type '" "std::vector< pj::SrtpCrypto >::value_type const &""'"); 
  }
  arg3 = reinterpret_cast< std::vector< pj::SrtpCrypto >::value_type * >(argp3);
  (arg1)->assign(arg2,(std::vector< pj::SrtpCrypto >::value_type const &)*arg3);
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_SrtpCryptoVector_resize__SWIG_1(PyObject *SWIGUNUSEDPARM(self), Py_ssize_t nobjs, PyObject **swig_obj) {
  PyObject *resultobj = 0;
  std::vector< pj::SrtpCrypto > *arg1 = (std::vector< pj::SrtpCrypto > *) 0 ;
  std::vector< pj::SrtpCrypto >::size_type arg2 ;
  std::vector< pj::SrtpCrypto >::value_type *arg3 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  size_t val2 ;
  int ecode2 = 0 ;
  void *argp3 = 0 ;
  int res3 = 0 ;
  
  if ((nobjs < 3) || (nobjs > 3)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__vectorT_pj__SrtpCrypto_std__allocatorT_pj__SrtpCrypto_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "SrtpCryptoVector_resize" "', argument " "1"" of type '" "std::vector< pj::SrtpCrypto > *""'"); 
  }
  arg1 = reinterpret_cast< std::vector< pj::SrtpCrypto > * >(argp1);
  ecode2 = SWIG_AsVal_size_t(swig_obj[1], &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "SrtpCryptoVector_resize" "', argument " "2"" of type '" "std::vector< pj::SrtpCrypto >::size_type""'");
  } 
  arg2 = static_cast< std::vector< pj::SrtpCrypto >::size_type >(val2);
  res3 = SWIG_ConvertPtr(swig_obj[2], &argp3, SWIGTYPE_p_pj__SrtpCrypto,  0  | 0);
  if (!SWIG_IsOK(res3)) {
    SWIG_exception_fail(SWIG_ArgError(res3), "in method '" "SrtpCryptoVector_resize" "', argument " "3"" of type '" "std::vector< pj::SrtpCrypto >::value_type const &""'"); 
  }
  if (!argp3) {
    SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "SrtpCryptoVector_resize" "', argument " "3"" of type '" "std::vector< pj::SrtpCrypto >::value_type const &""'"); 
  }
  arg3 = reinterpret_cast< std::vector< pj::SrtpCrypto >::value_type * >(argp3);
  (arg1)->resize(arg2,(std::vector< pj::SrtpCrypto >::value_type const &)*arg3);
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_SrtpCryptoVector_resize(PyObject *self, PyObject *args) {
  Py_ssize_t argc;
  PyObject *argv[4] = {
    0
  };
  
  if (!(argc = SWIG_Python_UnpackTuple(args, "SrtpCryptoVector_resize", 0, 3, argv))) SWIG_fail;
  --argc;
  if (argc == 2) {
    int _v;
    int res = swig::asptr(argv[0], (std::vector< pj::SrtpCrypto,std::allocator< pj::SrtpCrypto > >**)(0));
    _v = SWIG_CheckState(res);
    if (_v) {
      {
        int res = SWIG_AsVal_size_t(argv[1], NULL);
        _v = SWIG_CheckState(res);
      }
      if (_v) {
        return _wrap_SrtpCryptoVector_resize__SWIG_0(self, argc, argv);
      }
    }
  }
  if (argc == 3) {
    int _v;
    int res = swig::asptr(argv[0], (std::vector< pj::SrtpCrypto,std::allocator< pj::SrtpCrypto > >**)(0));
    _v = SWIG_CheckState(res);
    if (_v) {
      {
        int res = SWIG_AsVal_size_t(argv[1], NULL);
        _v = SWIG_CheckState(res);
      }
      if (_v) {
        int res = SWIG_ConvertPtr(argv[2], 0, SWIGTYPE_p_pj__SrtpCrypto, SWIG_POINTER_NO_NULL | 0);
        _v = SWIG_CheckState(res);
        if (_v) {
          return _wrap_SrtpCryptoVector_resize__SWIG_1(self, argc, argv);
        }
      }
    }
  }
  
fail:
  SWIG_Python_RaiseOrModifyTypeError("Wrong number or type of arguments for overloaded function 'SrtpCryptoVector_resize'.\n"
    "  Possible C/C++ prototypes are:\n"
    "    std::vector< pj::SrtpCrypto >::resize(std::vector< pj::SrtpCrypto >::size_type)\n"
    "    std::vector< pj::SrtpCrypto >::resize(std::vector< pj::SrtpCrypto >::size_type,std::vector< pj::SrtpCrypto >::value_type const &)\n");
  return 0;
}


SWIGINTERN PyObject *_wrap_SrtpCryptoVector_insert__SWIG_0(PyObject *SWIGUNUSEDPARM(self), Py_ssize_t nobjs, PyObject **swig_obj) {
  PyObject *resultobj = 0;
  std::vector< pj::SrtpCrypto > *arg1 = (std::vector< pj::SrtpCrypto > *) 0 ;
  std::vector< pj::SrtpCrypto >::iterator arg2 ;
  std::vector< pj::SrtpCrypto >::value_type *arg3 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  swig::SwigPyIterator *iter2 = 0 ;
  int res2 ;
  void *argp3 = 0 ;
  int res3 = 0 ;
  std::vector< pj::SrtpCrypto >::iterator result;
  
  if ((nobjs < 3) || (nobjs > 3)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__vectorT_pj__SrtpCrypto_std__allocatorT_pj__SrtpCrypto_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "SrtpCryptoVector_insert" "', argument " "1"" of type '" "std::vector< pj::SrtpCrypto > *""'"); 
  }
  arg1 = reinterpret_cast< std::vector< pj::SrtpCrypto > * >(argp1);
  res2 = SWIG_ConvertPtr(swig_obj[1], SWIG_as_voidptrptr(&iter2), swig::SwigPyIterator::descriptor(), 0);
  if (!SWIG_IsOK(res2) || !iter2) {
    SWIG_exception_fail(SWIG_ArgError(SWIG_TypeError), "in method '" "SrtpCryptoVector_insert" "', argument " "2"" of type '" "std::vector< pj::SrtpCrypto >::iterator""'");
  } else {
    swig::SwigPyIterator_T<std::vector< pj::SrtpCrypto >::iterator > *iter_t = dynamic_cast<swig::SwigPyIterator_T<std::vector< pj::SrtpCrypto >::iterator > *>(iter2);
    if (iter_t) {
      arg2 = iter_t->get_current();
    } else {
      SWIG_exception_fail(SWIG_ArgError(SWIG_TypeError), "in method '" "SrtpCryptoVector_insert" "', argument " "2"" of type '" "std::vector< pj::SrtpCrypto >::iterator""'");
    }
  }
  res3 = SWIG_ConvertPtr(swig_obj[2], &argp3, SWIGTYPE_p_pj__SrtpCrypto,  0  | 0);
  if (!SWIG_IsOK(res3)) {
    SWIG_exception_fail(SWIG_ArgError(res3), "in method '" "SrtpCryptoVector_insert" "', argument " "3"" of type '" "std::vector< pj::SrtpCrypto >::value_type const &""'"); 
  }
  if (!argp3) {
    SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "SrtpCryptoVector_insert" "', argument " "3"" of type '" "std::vector< pj::SrtpCrypto >::value_type const &""'"); 
  }
  arg3 = reinterpret_cast< std::vector< pj::SrtpCrypto >::value_type * >(argp3);
  result = std_vector_Sl_pj_SrtpCrypto_Sg__insert__SWIG_0(arg1,arg2,(pj::SrtpCrypto const &)*arg3);
  resultobj = SWIG_NewPointerObj(swig::make_output_iterator(static_cast< const std::vector< pj::SrtpCrypto >::iterator & >(result)),
    swig::SwigPyIterator::descriptor(),SWIG_POINTER_OWN);
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_SrtpCryptoVector_insert__SWIG_1(PyObject *SWIGUNUSEDPARM(self), Py_ssize_t nobjs, PyObject **swig_obj) {
  PyObject *resultobj = 0;
  std::vector< pj::SrtpCrypto > *arg1 = (std::vector< pj::SrtpCrypto > *) 0 ;
  std::vector< pj::SrtpCrypto >::iterator arg2 ;
  std::vector< pj::SrtpCrypto >::size_type arg3 ;
  std::vector< pj::SrtpCrypto >::value_type *arg4 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  swig::SwigPyIterator *iter2 = 0 ;
  int res2 ;
  size_t val3 ;
  int ecode3 = 0 ;
  void *argp4 = 0 ;
  int res4 = 0 ;
  
  if ((nobjs < 4) || (nobjs > 4)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__vectorT_pj__SrtpCrypto_std__allocatorT_pj__SrtpCrypto_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "SrtpCryptoVector_insert" "', argument " "1"" of type '" "std::vector< pj::SrtpCrypto > *""'"); 
  }
  arg1 = reinterpret_cast< std::vector< pj::SrtpCrypto > * >(argp1);
  res2 = SWIG_ConvertPtr(swig_obj[1], SWIG_as_voidptrptr(&iter2), swig::SwigPyIterator::descriptor(), 0);
  if (!SWIG_IsOK(res2) || !iter2) {
    SWIG_exception_fail(SWIG_ArgError(SWIG_TypeError), "in method '" "SrtpCryptoVector_insert" "', argument " "2"" of type '" "std::vector< pj::SrtpCrypto >::iterator""'");
  } else {
    swig::SwigPyIterator_T<std::vector< pj::SrtpCrypto >::iterator > *iter_t = dynamic_cast<swig::SwigPyIterator_T<std::vector< pj::SrtpCrypto >::iterator > *>(iter2);
    if (iter_t) {
      arg2 = iter_t->get_current();
    } else {
      SWIG_exception_fail(SWIG_ArgError(SWIG_TypeError), "in method '" "SrtpCryptoVector_insert" "', argument " "2"" of type '" "std::vector< pj::SrtpCrypto >::iterator""'");
    }
  }
  ecode3 = SWIG_AsVal_size_t(swig_obj[2], &val3);
  if (!SWIG_IsOK(ecode3)) {
    SWIG_exception_fail(SWIG_ArgError(ecode3), "in method '" "SrtpCryptoVector_insert" "', argument " "3"" of type '" "std::vector< pj::SrtpCrypto >::size_type""'");
  } 
  arg3 = static_cast< std::vector< pj::SrtpCrypto >::size_type >(val3);
  res4 = SWIG_ConvertPtr(swig_obj[3], &argp4, SWIGTYPE_p_pj__SrtpCrypto,  0  | 0);
  if (!SWIG_IsOK(res4)) {
    SWIG_exception_fail(SWIG_ArgError(res4), "in method '" "SrtpCryptoVector_insert" "', argument " "4"" of type '" "std::vector< pj::SrtpCrypto >::value_type const &""'"); 
  }
  if (!argp4) {
    SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "SrtpCryptoVector_insert" "', argument " "4"" of type '" "std::vector< pj::SrtpCrypto >::value_type const &""'"); 
  }
  arg4 = reinterpret_cast< std::vector< pj::SrtpCrypto >::value_type * >(argp4);
  std_vector_Sl_pj_SrtpCrypto_Sg__insert__SWIG_1(arg1,arg2,arg3,(pj::SrtpCrypto const &)*arg4);
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_SrtpCryptoVector_insert(PyObject *self, PyObject *args) {
  Py_ssize_t argc;
  PyObject *argv[5] = {
    0
  };
  
  if (!(argc = SWIG_Python_UnpackTuple(args, "SrtpCryptoVector_insert", 0, 4, argv))) SWIG_fail;
  --argc;
  if (argc == 3) {
    int _v;
    int res = swig::asptr(argv[0], (std::vector< pj::SrtpCrypto,std::allocator< pj::SrtpCrypto > >**)(0));
    _v = SWIG_CheckState(res);
    if (_v) {
      swig::SwigPyIterator *iter = 0;
      int res = SWIG_ConvertPtr(argv[1], SWIG_as_voidptrptr(&iter), swig::SwigPyIterator::descriptor(), 0);
      _v = (SWIG_IsOK(res) && iter && (dynamic_cast<swig::SwigPyIterator_T<std::vector< pj::SrtpCrypto >::iterator > *>(iter) != 0));
      if (_v) {
        int res = SWIG_ConvertPtr(argv[2], 0, SWIGTYPE_p_pj__SrtpCrypto, SWIG_POINTER_NO_NULL | 0);
        _v = SWIG_CheckState(res);
        if (_v) {
          return _wrap_SrtpCryptoVector_insert__SWIG_0(self, argc, argv);
        }
      }
    }
  }
  if (argc == 4) {
    int _v;
    int res = swig::asptr(argv[0], (std::vector< pj::SrtpCrypto,std::allocator< pj::SrtpCrypto > >**)(0));
    _v = SWIG_CheckState(res);
    if (_v) {
      swig::SwigPyIterator *iter = 0;
      int res = SWIG_ConvertPtr(argv[1], SWIG_as_voidptrptr(&iter), swig::SwigPyIterator::descriptor(), 0);
      _v = (SWIG_IsOK(res) && iter && (dynamic_cast<swig::SwigPyIterator_T<std::vector< pj::SrtpCrypto >::iterator > *>(iter) != 0));
      if (_v) {
        {
          int res = SWIG_AsVal_size_t(argv[2], NULL);
          _v = SWIG_CheckState(res);
        }
        if (_v) {
          int res = SWIG_ConvertPtr(argv[3], 0, SWIGTYPE_p_pj__SrtpCrypto, SWIG_POINTER_NO_NULL | 0);
          _v = SWIG_CheckState(res);
          if (_v) {
            return _wrap_SrtpCryptoVector_insert__SWIG_1(self, argc, argv);
          }
        }
      }
    }
  }
  
fail:
  SWIG_Python_RaiseOrModifyTypeError("Wrong number or type of arguments for overloaded function 'SrtpCryptoVector_insert'.\n"
    "  Possible C/C++ prototypes are:\n"
    "    std::vector< pj::SrtpCrypto >::insert(std::vector< pj::SrtpCrypto >::iterator,std::vector< pj::SrtpCrypto >::value_type const &)\n"
    "    std::vector< pj::SrtpCrypto >::insert(std::vector< pj::SrtpCrypto >::iterator,std::vector< pj::SrtpCrypto >::size_type,std::vector< pj::SrtpCrypto >::value_type const &)\n");
  return 0;
}


SWIGINTERN PyObject *_wrap_SrtpCryptoVector_reserve(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  std::vector< pj::SrtpCrypto > *arg1 = (std::vector< pj::SrtpCrypto > *) 0 ;
  std::vector< pj::SrtpCrypto >::size_type arg2 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  size_t val2 ;
  int ecode2 = 0 ;
  PyObject *swig_obj[2] ;
  
  if (!SWIG_Python_UnpackTuple(args, "SrtpCryptoVector_reserve", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__vectorT_pj__SrtpCrypto_std__allocatorT_pj__SrtpCrypto_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "SrtpCryptoVector_reserve" "', argument " "1"" of type '" "std::vector< pj::SrtpCrypto > *""'"); 
  }
  arg1 = reinterpret_cast< std::vector< pj::SrtpCrypto > * >(argp1);
  ecode2 = SWIG_AsVal_size_t(swig_obj[1], &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "SrtpCryptoVector_reserve" "', argument " "2"" of type '" "std::vector< pj::SrtpCrypto >::size_type""'");
  } 
  arg2 = static_cast< std::vector< pj::SrtpCrypto >::size_type >(val2);
  (arg1)->reserve(arg2);
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_SrtpCryptoVector_capacity(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  std::vector< pj::SrtpCrypto > *arg1 = (std::vector< pj::SrtpCrypto > *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  std::vector< pj::SrtpCrypto >::size_type result;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__vectorT_pj__SrtpCrypto_std__allocatorT_pj__SrtpCrypto_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "SrtpCryptoVector_capacity" "', argument " "1"" of type '" "std::vector< pj::SrtpCrypto > const *""'"); 
  }
  arg1 = reinterpret_cast< std::vector< pj::SrtpCrypto > * >(argp1);
  result = ((std::vector< pj::SrtpCrypto > const *)arg1)->capacity();
  resultobj = SWIG_From_size_t(static_cast< size_t >(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_delete_SrtpCryptoVector(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  std::vector< pj::SrtpCrypto > *arg1 = (std::vector< pj::SrtpCrypto > *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__vectorT_pj__SrtpCrypto_std__allocatorT_pj__SrtpCrypto_t_t, SWIG_POINTER_DISOWN |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "delete_SrtpCryptoVector" "', argument " "1"" of type '" "std::vector< pj::SrtpCrypto > *""'"); 
  }
  arg1 = reinterpret_cast< std::vector< pj::SrtpCrypto > * >(argp1);
  delete arg1;
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *SrtpCryptoVector_swigregister(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *obj;
  if (!SWIG_Python_UnpackTuple(args, "swigregister", 1, 1, &obj)) return NULL;
  SWIG_TypeNewClientData(SWIGTYPE_p_std__vectorT_pj__SrtpCrypto_std__allocatorT_pj__SrtpCrypto_t_t, SWIG_NewClientData(obj));
  return SWIG_Py_Void();
}

SWIGINTERN PyObject *SrtpCryptoVector_swiginit(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  return SWIG_Python_InitShadowInstance(args);
}

SWIGINTERN PyObject *_wrap_SipMultipartPartVector_iterator(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  std::vector< pj::SipMultipartPart > *arg1 = (std::vector< pj::SipMultipartPart > *) 0 ;
  PyObject **arg2 = (PyObject **) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  swig::SwigPyIterator *result = 0 ;
  
  arg2 = &swig_obj[0];
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__vectorT_pj__SipMultipartPart_std__allocatorT_pj__SipMultipartPart_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "SipMultipartPartVector_iterator" "', argument " "1"" of type '" "std::vector< pj::SipMultipartPart > *""'"); 
  }
  arg1 = reinterpret_cast< std::vector< pj::SipMultipartPart > * >(argp1);
  result = (swig::SwigPyIterator *)std_vector_Sl_pj_SipMultipartPart_Sg__iterator(arg1,arg2);
  resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(result), SWIGTYPE_p_swig__SwigPyIterator, SWIG_POINTER_OWN |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_SipMultipartPartVector___nonzero__(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  std::vector< pj::SipMultipartPart > *arg1 = (std::vector< pj::SipMultipartPart > *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  bool result;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__vectorT_pj__SipMultipartPart_std__allocatorT_pj__SipMultipartPart_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "SipMultipartPartVector___nonzero__" "', argument " "1"" of type '" "std::vector< pj::SipMultipartPart > const *""'"); 
  }
  arg1 = reinterpret_cast< std::vector< pj::SipMultipartPart > * >(argp1);
  result = (bool)std_vector_Sl_pj_SipMultipartPart_Sg____nonzero__((std::vector< pj::SipMultipartPart > const *)arg1);
  resultobj = SWIG_From_bool(static_cast< bool >(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_SipMultipartPartVector___bool__(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  std::vector< pj::SipMultipartPart > *arg1 = (std::vector< pj::SipMultipartPart > *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  bool result;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__vectorT_pj__SipMultipartPart_std__allocatorT_pj__SipMultipartPart_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "SipMultipartPartVector___bool__" "', argument " "1"" of type '" "std::vector< pj::SipMultipartPart > const *""'"); 
  }
  arg1 = reinterpret_cast< std::vector< pj::SipMultipartPart > * >(argp1);
  result = (bool)std_vector_Sl_pj_SipMultipartPart_Sg____bool__((std::vector< pj::SipMultipartPart > const *)arg1);
  resultobj = SWIG_From_bool(static_cast< bool >(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_SipMultipartPartVector___len__(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  std::vector< pj::SipMultipartPart > *arg1 = (std::vector< pj::SipMultipartPart > *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  std::vector< pj::SipMultipartPart >::size_type result;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__vectorT_pj__SipMultipartPart_std__allocatorT_pj__SipMultipartPart_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "SipMultipartPartVector___len__" "', argument " "1"" of type '" "std::vector< pj::SipMultipartPart > const *""'"); 
  }
  arg1 = reinterpret_cast< std::vector< pj::SipMultipartPart > * >(argp1);
  result = std_vector_Sl_pj_SipMultipartPart_Sg____len__((std::vector< pj::SipMultipartPart > const *)arg1);
  resultobj = SWIG_From_size_t(static_cast< size_t >(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_SipMultipartPartVector___getslice__(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  std::vector< pj::SipMultipartPart > *arg1 = (std::vector< pj::SipMultipartPart > *) 0 ;
  std::vector< pj::SipMultipartPart >::difference_type arg2 ;
  std::vector< pj::SipMultipartPart >::difference_type arg3 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  ptrdiff_t val2 ;
  int ecode2 = 0 ;
  ptrdiff_t val3 ;
  int ecode3 = 0 ;
  PyObject *swig_obj[3] ;
  std::vector< pj::SipMultipartPart,std::allocator< pj::SipMultipartPart > > *result = 0 ;
  
  if (!SWIG_Python_UnpackTuple(args, "SipMultipartPartVector___getslice__", 3, 3, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__vectorT_pj__SipMultipartPart_std__allocatorT_pj__SipMultipartPart_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "SipMultipartPartVector___getslice__" "', argument " "1"" of type '" "std::vector< pj::SipMultipartPart > *""'"); 
  }
  arg1 = reinterpret_cast< std::vector< pj::SipMultipartPart > * >(argp1);
  ecode2 = SWIG_AsVal_ptrdiff_t(swig_obj[1], &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "SipMultipartPartVector___getslice__" "', argument " "2"" of type '" "std::vector< pj::SipMultipartPart >::difference_type""'");
  } 
  arg2 = static_cast< std::vector< pj::SipMultipartPart >::difference_type >(val2);
  ecode3 = SWIG_AsVal_ptrdiff_t(swig_obj[2], &val3);
  if (!SWIG_IsOK(ecode3)) {
    SWIG_exception_fail(SWIG_ArgError(ecode3), "in method '" "SipMultipartPartVector___getslice__" "', argument " "3"" of type '" "std::vector< pj::SipMultipartPart >::difference_type""'");
  } 
  arg3 = static_cast< std::vector< pj::SipMultipartPart >::difference_type >(val3);
  try {
    result = (std::vector< pj::SipMultipartPart,std::allocator< pj::SipMultipartPart > > *)std_vector_Sl_pj_SipMultipartPart_Sg____getslice__(arg1,arg2,arg3);
  } catch(std::out_of_range &_e) {
    SWIG_exception_fail(SWIG_IndexError, (&_e)->what());
  } catch(std::invalid_argument &_e) {
    SWIG_exception_fail(SWIG_ValueError, (&_e)->what());
  }
  resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(result), SWIGTYPE_p_std__vectorT_pj__SipMultipartPart_std__allocatorT_pj__SipMultipartPart_t_t, SWIG_POINTER_OWN |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_SipMultipartPartVector___setslice____SWIG_0(PyObject *SWIGUNUSEDPARM(self), Py_ssize_t nobjs, PyObject **swig_obj) {
  PyObject *resultobj = 0;
  std::vector< pj::SipMultipartPart > *arg1 = (std::vector< pj::SipMultipartPart > *) 0 ;
  std::vector< pj::SipMultipartPart >::difference_type arg2 ;
  std::vector< pj::SipMultipartPart >::difference_type arg3 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  ptrdiff_t val2 ;
  int ecode2 = 0 ;
  ptrdiff_t val3 ;
  int ecode3 = 0 ;
  
  if ((nobjs < 3) || (nobjs > 3)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__vectorT_pj__SipMultipartPart_std__allocatorT_pj__SipMultipartPart_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "SipMultipartPartVector___setslice__" "', argument " "1"" of type '" "std::vector< pj::SipMultipartPart > *""'"); 
  }
  arg1 = reinterpret_cast< std::vector< pj::SipMultipartPart > * >(argp1);
  ecode2 = SWIG_AsVal_ptrdiff_t(swig_obj[1], &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "SipMultipartPartVector___setslice__" "', argument " "2"" of type '" "std::vector< pj::SipMultipartPart >::difference_type""'");
  } 
  arg2 = static_cast< std::vector< pj::SipMultipartPart >::difference_type >(val2);
  ecode3 = SWIG_AsVal_ptrdiff_t(swig_obj[2], &val3);
  if (!SWIG_IsOK(ecode3)) {
    SWIG_exception_fail(SWIG_ArgError(ecode3), "in method '" "SipMultipartPartVector___setslice__" "', argument " "3"" of type '" "std::vector< pj::SipMultipartPart >::difference_type""'");
  } 
  arg3 = static_cast< std::vector< pj::SipMultipartPart >::difference_type >(val3);
  try {
    std_vector_Sl_pj_SipMultipartPart_Sg____setslice____SWIG_0(arg1,arg2,arg3);
  } catch(std::out_of_range &_e) {
    SWIG_exception_fail(SWIG_IndexError, (&_e)->what());
  } catch(std::invalid_argument &_e) {
    SWIG_exception_fail(SWIG_ValueError, (&_e)->what());
  }
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_SipMultipartPartVector___setslice____SWIG_1(PyObject *SWIGUNUSEDPARM(self), Py_ssize_t nobjs, PyObject **swig_obj) {
  PyObject *resultobj = 0;
  std::vector< pj::SipMultipartPart > *arg1 = (std::vector< pj::SipMultipartPart > *) 0 ;
  std::vector< pj::SipMultipartPart >::difference_type arg2 ;
  std::vector< pj::SipMultipartPart >::difference_type arg3 ;
  std::vector< pj::SipMultipartPart,std::allocator< pj::SipMultipartPart > > *arg4 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  ptrdiff_t val2 ;
  int ecode2 = 0 ;
  ptrdiff_t val3 ;
  int ecode3 = 0 ;
  int res4 = SWIG_OLDOBJ ;
  
  if ((nobjs < 4) || (nobjs > 4)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__vectorT_pj__SipMultipartPart_std__allocatorT_pj__SipMultipartPart_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "SipMultipartPartVector___setslice__" "', argument " "1"" of type '" "std::vector< pj::SipMultipartPart > *""'"); 
  }
  arg1 = reinterpret_cast< std::vector< pj::SipMultipartPart > * >(argp1);
  ecode2 = SWIG_AsVal_ptrdiff_t(swig_obj[1], &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "SipMultipartPartVector___setslice__" "', argument " "2"" of type '" "std::vector< pj::SipMultipartPart >::difference_type""'");
  } 
  arg2 = static_cast< std::vector< pj::SipMultipartPart >::difference_type >(val2);
  ecode3 = SWIG_AsVal_ptrdiff_t(swig_obj[2], &val3);
  if (!SWIG_IsOK(ecode3)) {
    SWIG_exception_fail(SWIG_ArgError(ecode3), "in method '" "SipMultipartPartVector___setslice__" "', argument " "3"" of type '" "std::vector< pj::SipMultipartPart >::difference_type""'");
  } 
  arg3 = static_cast< std::vector< pj::SipMultipartPart >::difference_type >(val3);
  {
    std::vector< pj::SipMultipartPart,std::allocator< pj::SipMultipartPart > > *ptr = (std::vector< pj::SipMultipartPart,std::allocator< pj::SipMultipartPart > > *)0;
    res4 = swig::asptr(swig_obj[3], &ptr);
    if (!SWIG_IsOK(res4)) {
      SWIG_exception_fail(SWIG_ArgError(res4), "in method '" "SipMultipartPartVector___setslice__" "', argument " "4"" of type '" "std::vector< pj::SipMultipartPart,std::allocator< pj::SipMultipartPart > > const &""'"); 
    }
    if (!ptr) {
      SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "SipMultipartPartVector___setslice__" "', argument " "4"" of type '" "std::vector< pj::SipMultipartPart,std::allocator< pj::SipMultipartPart > > const &""'"); 
    }
    arg4 = ptr;
  }
  try {
    std_vector_Sl_pj_SipMultipartPart_Sg____setslice____SWIG_1(arg1,arg2,arg3,(std::vector< pj::SipMultipartPart,std::allocator< pj::SipMultipartPart > > const &)*arg4);
  } catch(std::out_of_range &_e) {
    SWIG_exception_fail(SWIG_IndexError, (&_e)->what());
  } catch(std::invalid_argument &_e) {
    SWIG_exception_fail(SWIG_ValueError, (&_e)->what());
  }
  resultobj = SWIG_Py_Void();
  if (SWIG_IsNewObj(res4)) delete arg4;
  return resultobj;
fail:
  if (SWIG_IsNewObj(res4)) delete arg4;
  return NULL;
}


SWIGINTERN PyObject *_wrap_SipMultipartPartVector___setslice__(PyObject *self, PyObject *args) {
  Py_ssize_t argc;
  PyObject *argv[5] = {
    0
  };
  
  if (!(argc = SWIG_Python_UnpackTuple(args, "SipMultipartPartVector___setslice__", 0, 4, argv))) SWIG_fail;
  --argc;
  if (argc == 3) {
    int _v;
    int res = swig::asptr(argv[0], (std::vector< pj::SipMultipartPart,std::allocator< pj::SipMultipartPart > >**)(0));
    _v = SWIG_CheckState(res);
    if (_v) {
      {
        int res = SWIG_AsVal_ptrdiff_t(argv[1], NULL);
        _v = SWIG_CheckState(res);
      }
      if (_v) {
        {
          int res = SWIG_AsVal_ptrdiff_t(argv[2], NULL);
          _v = SWIG_CheckState(res);
        }
        if (_v) {
          return _wrap_SipMultipartPartVector___setslice____SWIG_0(self, argc, argv);
        }
      }
    }
  }
  if (argc == 4) {
    int _v;
    int res = swig::asptr(argv[0], (std::vector< pj::SipMultipartPart,std::allocator< pj::SipMultipartPart > >**)(0));
    _v = SWIG_CheckState(res);
    if (_v) {
      {
        int res = SWIG_AsVal_ptrdiff_t(argv[1], NULL);
        _v = SWIG_CheckState(res);
      }
      if (_v) {
        {
          int res = SWIG_AsVal_ptrdiff_t(argv[2], NULL);
          _v = SWIG_CheckState(res);
        }
        if (_v) {
          int res = swig::asptr(argv[3], (std::vector< pj::SipMultipartPart,std::allocator< pj::SipMultipartPart > >**)(0));
          _v = SWIG_CheckState(res);
          if (_v) {
            return _wrap_SipMultipartPartVector___setslice____SWIG_1(self, argc, argv);
          }
        }
      }
    }
  }
  
fail:
  SWIG_Python_RaiseOrModifyTypeError("Wrong number or type of arguments for overloaded function 'SipMultipartPartVector___setslice__'.\n"
    "  Possible C/C++ prototypes are:\n"
    "    std::vector< pj::SipMultipartPart >::__setslice__(std::vector< pj::SipMultipartPart >::difference_type,std::vector< pj::SipMultipartPart >::difference_type)\n"
    "    std::vector< pj::SipMultipartPart >::__setslice__(std::vector< pj::SipMultipartPart >::difference_type,std::vector< pj::SipMultipartPart >::difference_type,std::vector< pj::SipMultipartPart,std::allocator< pj::SipMultipartPart > > const &)\n");
  return 0;
}


SWIGINTERN PyObject *_wrap_SipMultipartPartVector___delslice__(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  std::vector< pj::SipMultipartPart > *arg1 = (std::vector< pj::SipMultipartPart > *) 0 ;
  std::vector< pj::SipMultipartPart >::difference_type arg2 ;
  std::vector< pj::SipMultipartPart >::difference_type arg3 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  ptrdiff_t val2 ;
  int ecode2 = 0 ;
  ptrdiff_t val3 ;
  int ecode3 = 0 ;
  PyObject *swig_obj[3] ;
  
  if (!SWIG_Python_UnpackTuple(args, "SipMultipartPartVector___delslice__", 3, 3, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__vectorT_pj__SipMultipartPart_std__allocatorT_pj__SipMultipartPart_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "SipMultipartPartVector___delslice__" "', argument " "1"" of type '" "std::vector< pj::SipMultipartPart > *""'"); 
  }
  arg1 = reinterpret_cast< std::vector< pj::SipMultipartPart > * >(argp1);
  ecode2 = SWIG_AsVal_ptrdiff_t(swig_obj[1], &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "SipMultipartPartVector___delslice__" "', argument " "2"" of type '" "std::vector< pj::SipMultipartPart >::difference_type""'");
  } 
  arg2 = static_cast< std::vector< pj::SipMultipartPart >::difference_type >(val2);
  ecode3 = SWIG_AsVal_ptrdiff_t(swig_obj[2], &val3);
  if (!SWIG_IsOK(ecode3)) {
    SWIG_exception_fail(SWIG_ArgError(ecode3), "in method '" "SipMultipartPartVector___delslice__" "', argument " "3"" of type '" "std::vector< pj::SipMultipartPart >::difference_type""'");
  } 
  arg3 = static_cast< std::vector< pj::SipMultipartPart >::difference_type >(val3);
  try {
    std_vector_Sl_pj_SipMultipartPart_Sg____delslice__(arg1,arg2,arg3);
  } catch(std::out_of_range &_e) {
    SWIG_exception_fail(SWIG_IndexError, (&_e)->what());
  } catch(std::invalid_argument &_e) {
    SWIG_exception_fail(SWIG_ValueError, (&_e)->what());
  }
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_SipMultipartPartVector___delitem____SWIG_0(PyObject *SWIGUNUSEDPARM(self), Py_ssize_t nobjs, PyObject **swig_obj) {
  PyObject *resultobj = 0;
  std::vector< pj::SipMultipartPart > *arg1 = (std::vector< pj::SipMultipartPart > *) 0 ;
  std::vector< pj::SipMultipartPart >::difference_type arg2 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  ptrdiff_t val2 ;
  int ecode2 = 0 ;
  
  if ((nobjs < 2) || (nobjs > 2)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__vectorT_pj__SipMultipartPart_std__allocatorT_pj__SipMultipartPart_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "SipMultipartPartVector___delitem__" "', argument " "1"" of type '" "std::vector< pj::SipMultipartPart > *""'"); 
  }
  arg1 = reinterpret_cast< std::vector< pj::SipMultipartPart > * >(argp1);
  ecode2 = SWIG_AsVal_ptrdiff_t(swig_obj[1], &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "SipMultipartPartVector___delitem__" "', argument " "2"" of type '" "std::vector< pj::SipMultipartPart >::difference_type""'");
  } 
  arg2 = static_cast< std::vector< pj::SipMultipartPart >::difference_type >(val2);
  try {
    std_vector_Sl_pj_SipMultipartPart_Sg____delitem____SWIG_0(arg1,arg2);
  } catch(std::out_of_range &_e) {
    SWIG_exception_fail(SWIG_IndexError, (&_e)->what());
  } catch(std::invalid_argument &_e) {
    SWIG_exception_fail(SWIG_ValueError, (&_e)->what());
  }
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_SipMultipartPartVector___getitem____SWIG_0(PyObject *SWIGUNUSEDPARM(self), Py_ssize_t nobjs, PyObject **swig_obj) {
  PyObject *resultobj = 0;
  std::vector< pj::SipMultipartPart > *arg1 = (std::vector< pj::SipMultipartPart > *) 0 ;
  PySliceObject *arg2 = (PySliceObject *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  std::vector< pj::SipMultipartPart,std::allocator< pj::SipMultipartPart > > *result = 0 ;
  
  if ((nobjs < 2) || (nobjs > 2)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__vectorT_pj__SipMultipartPart_std__allocatorT_pj__SipMultipartPart_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "SipMultipartPartVector___getitem__" "', argument " "1"" of type '" "std::vector< pj::SipMultipartPart > *""'"); 
  }
  arg1 = reinterpret_cast< std::vector< pj::SipMultipartPart > * >(argp1);
  {
    if (!PySlice_Check(swig_obj[1])) {
      SWIG_exception_fail(SWIG_ArgError(SWIG_TypeError), "in method '" "SipMultipartPartVector___getitem__" "', argument " "2"" of type '" "PySliceObject *""'");
    }
    arg2 = (PySliceObject *) swig_obj[1];
  }
  try {
    result = (std::vector< pj::SipMultipartPart,std::allocator< pj::SipMultipartPart > > *)std_vector_Sl_pj_SipMultipartPart_Sg____getitem____SWIG_0(arg1,arg2);
  } catch(std::out_of_range &_e) {
    SWIG_exception_fail(SWIG_IndexError, (&_e)->what());
  } catch(std::invalid_argument &_e) {
    SWIG_exception_fail(SWIG_ValueError, (&_e)->what());
  }
  resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(result), SWIGTYPE_p_std__vectorT_pj__SipMultipartPart_std__allocatorT_pj__SipMultipartPart_t_t, SWIG_POINTER_OWN |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_SipMultipartPartVector___setitem____SWIG_0(PyObject *SWIGUNUSEDPARM(self), Py_ssize_t nobjs, PyObject **swig_obj) {
  PyObject *resultobj = 0;
  std::vector< pj::SipMultipartPart > *arg1 = (std::vector< pj::SipMultipartPart > *) 0 ;
  PySliceObject *arg2 = (PySliceObject *) 0 ;
  std::vector< pj::SipMultipartPart,std::allocator< pj::SipMultipartPart > > *arg3 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  int res3 = SWIG_OLDOBJ ;
  
  if ((nobjs < 3) || (nobjs > 3)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__vectorT_pj__SipMultipartPart_std__allocatorT_pj__SipMultipartPart_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "SipMultipartPartVector___setitem__" "', argument " "1"" of type '" "std::vector< pj::SipMultipartPart > *""'"); 
  }
  arg1 = reinterpret_cast< std::vector< pj::SipMultipartPart > * >(argp1);
  {
    if (!PySlice_Check(swig_obj[1])) {
      SWIG_exception_fail(SWIG_ArgError(SWIG_TypeError), "in method '" "SipMultipartPartVector___setitem__" "', argument " "2"" of type '" "PySliceObject *""'");
    }
    arg2 = (PySliceObject *) swig_obj[1];
  }
  {
    std::vector< pj::SipMultipartPart,std::allocator< pj::SipMultipartPart > > *ptr = (std::vector< pj::SipMultipartPart,std::allocator< pj::SipMultipartPart > > *)0;
    res3 = swig::asptr(swig_obj[2], &ptr);
    if (!SWIG_IsOK(res3)) {
      SWIG_exception_fail(SWIG_ArgError(res3), "in method '" "SipMultipartPartVector___setitem__" "', argument " "3"" of type '" "std::vector< pj::SipMultipartPart,std::allocator< pj::SipMultipartPart > > const &""'"); 
    }
    if (!ptr) {
      SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "SipMultipartPartVector___setitem__" "', argument " "3"" of type '" "std::vector< pj::SipMultipartPart,std::allocator< pj::SipMultipartPart > > const &""'"); 
    }
    arg3 = ptr;
  }
  try {
    std_vector_Sl_pj_SipMultipartPart_Sg____setitem____SWIG_0(arg1,arg2,(std::vector< pj::SipMultipartPart,std::allocator< pj::SipMultipartPart > > const &)*arg3);
  } catch(std::out_of_range &_e) {
    SWIG_exception_fail(SWIG_IndexError, (&_e)->what());
  } catch(std::invalid_argument &_e) {
    SWIG_exception_fail(SWIG_ValueError, (&_e)->what());
  }
  resultobj = SWIG_Py_Void();
  if (SWIG_IsNewObj(res3)) delete arg3;
  return resultobj;
fail:
  if (SWIG_IsNewObj(res3)) delete arg3;
  return NULL;
}


SWIGINTERN PyObject *_wrap_SipMultipartPartVector___setitem____SWIG_1(PyObject *SWIGUNUSEDPARM(self), Py_ssize_t nobjs, PyObject **swig_obj) {
  PyObject *resultobj = 0;
  std::vector< pj::SipMultipartPart > *arg1 = (std::vector< pj::SipMultipartPart > *) 0 ;
  PySliceObject *arg2 = (PySliceObject *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  
  if ((nobjs < 2) || (nobjs > 2)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__vectorT_pj__SipMultipartPart_std__allocatorT_pj__SipMultipartPart_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "SipMultipartPartVector___setitem__" "', argument " "1"" of type '" "std::vector< pj::SipMultipartPart > *""'"); 
  }
  arg1 = reinterpret_cast< std::vector< pj::SipMultipartPart > * >(argp1);
  {
    if (!PySlice_Check(swig_obj[1])) {
      SWIG_exception_fail(SWIG_ArgError(SWIG_TypeError), "in method '" "SipMultipartPartVector___setitem__" "', argument " "2"" of type '" "PySliceObject *""'");
    }
    arg2 = (PySliceObject *) swig_obj[1];
  }
  try {
    std_vector_Sl_pj_SipMultipartPart_Sg____setitem____SWIG_1(arg1,arg2);
  } catch(std::out_of_range &_e) {
    SWIG_exception_fail(SWIG_IndexError, (&_e)->what());
  } catch(std::invalid_argument &_e) {
    SWIG_exception_fail(SWIG_ValueError, (&_e)->what());
  }
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_SipMultipartPartVector___delitem____SWIG_1(PyObject *SWIGUNUSEDPARM(self), Py_ssize_t nobjs, PyObject **swig_obj) {
  PyObject *resultobj = 0;
  std::vector< pj::SipMultipartPart > *arg1 = (std::vector< pj::SipMultipartPart > *) 0 ;
  PySliceObject *arg2 = (PySliceObject *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  
  if ((nobjs < 2) || (nobjs > 2)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__vectorT_pj__SipMultipartPart_std__allocatorT_pj__SipMultipartPart_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "SipMultipartPartVector___delitem__" "', argument " "1"" of type '" "std::vector< pj::SipMultipartPart > *""'"); 
  }
  arg1 = reinterpret_cast< std::vector< pj::SipMultipartPart > * >(argp1);
  {
    if (!PySlice_Check(swig_obj[1])) {
      SWIG_exception_fail(SWIG_ArgError(SWIG_TypeError), "in method '" "SipMultipartPartVector___delitem__" "', argument " "2"" of type '" "PySliceObject *""'");
    }
    arg2 = (PySliceObject *) swig_obj[1];
  }
  try {
    std_vector_Sl_pj_SipMultipartPart_Sg____delitem____SWIG_1(arg1,arg2);
  } catch(std::out_of_range &_e) {
    SWIG_exception_fail(SWIG_IndexError, (&_e)->what());
  } catch(std::invalid_argument &_e) {
    SWIG_exception_fail(SWIG_ValueError, (&_e)->what());
  }
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_SipMultipartPartVector___delitem__(PyObject *self, PyObject *args) {
  Py_ssize_t argc;
  PyObject *argv[3] = {
    0
  };
  
  if (!(argc = SWIG_Python_UnpackTuple(args, "SipMultipartPartVector___delitem__", 0, 2, argv))) SWIG_fail;
  --argc;
  if (argc == 2) {
    int _v;
    int res = swig::asptr(argv[0], (std::vector< pj::SipMultipartPart,std::allocator< pj::SipMultipartPart > >**)(0));
    _v = SWIG_CheckState(res);
    if (_v) {
      {
        _v = PySlice_Check(argv[1]);
      }
      if (_v) {
        return _wrap_SipMultipartPartVector___delitem____SWIG_1(self, argc, argv);
      }
    }
  }
  if (argc == 2) {
    int _v;
    int res = swig::asptr(argv[0], (std::vector< pj::SipMultipartPart,std::allocator< pj::SipMultipartPart > >**)(0));
    _v = SWIG_CheckState(res);
    if (_v) {
      {
        int res = SWIG_AsVal_ptrdiff_t(argv[1], NULL);
        _v = SWIG_CheckState(res);
      }
      if (_v) {
        return _wrap_SipMultipartPartVector___delitem____SWIG_0(self, argc, argv);
      }
    }
  }
  
fail:
  SWIG_Python_RaiseOrModifyTypeError("Wrong number or type of arguments for overloaded function 'SipMultipartPartVector___delitem__'.\n"
    "  Possible C/C++ prototypes are:\n"
    "    std::vector< pj::SipMultipartPart >::__delitem__(std::vector< pj::SipMultipartPart >::difference_type)\n"
    "    std::vector< pj::SipMultipartPart >::__delitem__(PySliceObject *)\n");
  return 0;
}


SWIGINTERN PyObject *_wrap_SipMultipartPartVector___getitem____SWIG_1(PyObject *SWIGUNUSEDPARM(self), Py_ssize_t nobjs, PyObject **swig_obj) {
  PyObject *resultobj = 0;
  std::vector< pj::SipMultipartPart > *arg1 = (std::vector< pj::SipMultipartPart > *) 0 ;
  std::vector< pj::SipMultipartPart >::difference_type arg2 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  ptrdiff_t val2 ;
  int ecode2 = 0 ;
  std::vector< pj::SipMultipartPart >::value_type *result = 0 ;
  
  if ((nobjs < 2) || (nobjs > 2)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__vectorT_pj__SipMultipartPart_std__allocatorT_pj__SipMultipartPart_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "SipMultipartPartVector___getitem__" "', argument " "1"" of type '" "std::vector< pj::SipMultipartPart > const *""'"); 
  }
  arg1 = reinterpret_cast< std::vector< pj::SipMultipartPart > * >(argp1);
  ecode2 = SWIG_AsVal_ptrdiff_t(swig_obj[1], &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "SipMultipartPartVector___getitem__" "', argument " "2"" of type '" "std::vector< pj::SipMultipartPart >::difference_type""'");
  } 
  arg2 = static_cast< std::vector< pj::SipMultipartPart >::difference_type >(val2);
  try {
    result = (std::vector< pj::SipMultipartPart >::value_type *) &std_vector_Sl_pj_SipMultipartPart_Sg____getitem____SWIG_1((std::vector< pj::SipMultipartPart > const *)arg1,arg2);
  } catch(std::out_of_range &_e) {
    SWIG_exception_fail(SWIG_IndexError, (&_e)->what());
  }
  resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(result), SWIGTYPE_p_pj__SipMultipartPart, 0 |  0 );
  (void)swig::container_owner<swig::traits<std::vector< pj::SipMultipartPart >::value_type>::category>::back_reference(resultobj, swig_obj[0]);
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_SipMultipartPartVector___getitem__(PyObject *self, PyObject *args) {
  Py_ssize_t argc;
  PyObject *argv[3] = {
    0
  };
  
  if (!(argc = SWIG_Python_UnpackTuple(args, "SipMultipartPartVector___getitem__", 0, 2, argv))) SWIG_fail;
  --argc;
  if (argc == 2) {
    int _v;
    int res = swig::asptr(argv[0], (std::vector< pj::SipMultipartPart,std::allocator< pj::SipMultipartPart > >**)(0));
    _v = SWIG_CheckState(res);
    if (_v) {
      {
        _v = PySlice_Check(argv[1]);
      }
      if (_v) {
        return _wrap_SipMultipartPartVector___getitem____SWIG_0(self, argc, argv);
      }
    }
  }
  if (argc == 2) {
    int _v;
    int res = swig::asptr(argv[0], (std::vector< pj::SipMultipartPart,std::allocator< pj::SipMultipartPart > >**)(0));
    _v = SWIG_CheckState(res);
    if (_v) {
      {
        int res = SWIG_AsVal_ptrdiff_t(argv[1], NULL);
        _v = SWIG_CheckState(res);
      }
      if (_v) {
        return _wrap_SipMultipartPartVector___getitem____SWIG_1(self, argc, argv);
      }
    }
  }
  
fail:
  SWIG_Python_RaiseOrModifyTypeError("Wrong number or type of arguments for overloaded function 'SipMultipartPartVector___getitem__'.\n"
    "  Possible C/C++ prototypes are:\n"
    "    std::vector< pj::SipMultipartPart >::__getitem__(PySliceObject *)\n"
    "    std::vector< pj::SipMultipartPart >::__getitem__(std::vector< pj::SipMultipartPart >::difference_type) const\n");
  return 0;
}


SWIGINTERN PyObject *_wrap_SipMultipartPartVector___setitem____SWIG_2(PyObject *SWIGUNUSEDPARM(self), Py_ssize_t nobjs, PyObject **swig_obj) {
  PyObject *resultobj = 0;
  std::vector< pj::SipMultipartPart > *arg1 = (std::vector< pj::SipMultipartPart > *) 0 ;
  std::vector< pj::SipMultipartPart >::difference_type arg2 ;
  std::vector< pj::SipMultipartPart >::value_type *arg3 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  ptrdiff_t val2 ;
  int ecode2 = 0 ;
  void *argp3 = 0 ;
  int res3 = 0 ;
  
  if ((nobjs < 3) || (nobjs > 3)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__vectorT_pj__SipMultipartPart_std__allocatorT_pj__SipMultipartPart_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "SipMultipartPartVector___setitem__" "', argument " "1"" of type '" "std::vector< pj::SipMultipartPart > *""'"); 
  }
  arg1 = reinterpret_cast< std::vector< pj::SipMultipartPart > * >(argp1);
  ecode2 = SWIG_AsVal_ptrdiff_t(swig_obj[1], &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "SipMultipartPartVector___setitem__" "', argument " "2"" of type '" "std::vector< pj::SipMultipartPart >::difference_type""'");
  } 
  arg2 = static_cast< std::vector< pj::SipMultipartPart >::difference_type >(val2);
  res3 = SWIG_ConvertPtr(swig_obj[2], &argp3, SWIGTYPE_p_pj__SipMultipartPart,  0  | 0);
  if (!SWIG_IsOK(res3)) {
    SWIG_exception_fail(SWIG_ArgError(res3), "in method '" "SipMultipartPartVector___setitem__" "', argument " "3"" of type '" "std::vector< pj::SipMultipartPart >::value_type const &""'"); 
  }
  if (!argp3) {
    SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "SipMultipartPartVector___setitem__" "', argument " "3"" of type '" "std::vector< pj::SipMultipartPart >::value_type const &""'"); 
  }
  arg3 = reinterpret_cast< std::vector< pj::SipMultipartPart >::value_type * >(argp3);
  try {
    std_vector_Sl_pj_SipMultipartPart_Sg____setitem____SWIG_2(arg1,arg2,(pj::SipMultipartPart const &)*arg3);
  } catch(std::out_of_range &_e) {
    SWIG_exception_fail(SWIG_IndexError, (&_e)->what());
  }
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_SipMultipartPartVector___setitem__(PyObject *self, PyObject *args) {
  Py_ssize_t argc;
  PyObject *argv[4] = {
    0
  };
  
  if (!(argc = SWIG_Python_UnpackTuple(args, "SipMultipartPartVector___setitem__", 0, 3, argv))) SWIG_fail;
  --argc;
  if (argc == 2) {
    int _v;
    int res = swig::asptr(argv[0], (std::vector< pj::SipMultipartPart,std::allocator< pj::SipMultipartPart > >**)(0));
    _v = SWIG_CheckState(res);
    if (_v) {
      {
        _v = PySlice_Check(argv[1]);
      }
      if (_v) {
        return _wrap_SipMultipartPartVector___setitem____SWIG_1(self, argc, argv);
      }
    }
  }
  if (argc == 3) {
    int _v;
    int res = swig::asptr(argv[0], (std::vector< pj::SipMultipartPart,std::allocator< pj::SipMultipartPart > >**)(0));
    _v = SWIG_CheckState(res);
    if (_v) {
      {
        _v = PySlice_Check(argv[1]);
      }
      if (_v) {
        int res = swig::asptr(argv[2], (std::vector< pj::SipMultipartPart,std::allocator< pj::SipMultipartPart > >**)(0));
        _v = SWIG_CheckState(res);
        if (_v) {
          return _wrap_SipMultipartPartVector___setitem____SWIG_0(self, argc, argv);
        }
      }
    }
  }
  if (argc == 3) {
    int _v;
    int res = swig::asptr(argv[0], (std::vector< pj::SipMultipartPart,std::allocator< pj::SipMultipartPart > >**)(0));
    _v = SWIG_CheckState(res);
    if (_v) {
      {
        int res = SWIG_AsVal_ptrdiff_t(argv[1], NULL);
        _v = SWIG_CheckState(res);
      }
      if (_v) {
        int res = SWIG_ConvertPtr(argv[2], 0, SWIGTYPE_p_pj__SipMultipartPart, SWIG_POINTER_NO_NULL | 0);
        _v = SWIG_CheckState(res);
        if (_v) {
          return _wrap_SipMultipartPartVector___setitem____SWIG_2(self, argc, argv);
        }
      }
    }
  }
  
fail:
  SWIG_Python_RaiseOrModifyTypeError("Wrong number or type of arguments for overloaded function 'SipMultipartPartVector___setitem__'.\n"
    "  Possible C/C++ prototypes are:\n"
    "    std::vector< pj::SipMultipartPart >::__setitem__(PySliceObject *,std::vector< pj::SipMultipartPart,std::allocator< pj::SipMultipartPart > > const &)\n"
    "    std::vector< pj::SipMultipartPart >::__setitem__(PySliceObject *)\n"
    "    std::vector< pj::SipMultipartPart >::__setitem__(std::vector< pj::SipMultipartPart >::difference_type,std::vector< pj::SipMultipartPart >::value_type const &)\n");
  return 0;
}


SWIGINTERN PyObject *_wrap_SipMultipartPartVector_pop(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  std::vector< pj::SipMultipartPart > *arg1 = (std::vector< pj::SipMultipartPart > *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  std::vector< pj::SipMultipartPart >::value_type result;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__vectorT_pj__SipMultipartPart_std__allocatorT_pj__SipMultipartPart_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "SipMultipartPartVector_pop" "', argument " "1"" of type '" "std::vector< pj::SipMultipartPart > *""'"); 
  }
  arg1 = reinterpret_cast< std::vector< pj::SipMultipartPart > * >(argp1);
  try {
    result = std_vector_Sl_pj_SipMultipartPart_Sg__pop(arg1);
  } catch(std::out_of_range &_e) {
    SWIG_exception_fail(SWIG_IndexError, (&_e)->what());
  }
  resultobj = SWIG_NewPointerObj((new std::vector< pj::SipMultipartPart >::value_type(static_cast< const std::vector< pj::SipMultipartPart >::value_type& >(result))), SWIGTYPE_p_pj__SipMultipartPart, SWIG_POINTER_OWN |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_SipMultipartPartVector_append(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  std::vector< pj::SipMultipartPart > *arg1 = (std::vector< pj::SipMultipartPart > *) 0 ;
  std::vector< pj::SipMultipartPart >::value_type *arg2 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  void *argp2 = 0 ;
  int res2 = 0 ;
  PyObject *swig_obj[2] ;
  
  if (!SWIG_Python_UnpackTuple(args, "SipMultipartPartVector_append", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__vectorT_pj__SipMultipartPart_std__allocatorT_pj__SipMultipartPart_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "SipMultipartPartVector_append" "', argument " "1"" of type '" "std::vector< pj::SipMultipartPart > *""'"); 
  }
  arg1 = reinterpret_cast< std::vector< pj::SipMultipartPart > * >(argp1);
  res2 = SWIG_ConvertPtr(swig_obj[1], &argp2, SWIGTYPE_p_pj__SipMultipartPart,  0  | 0);
  if (!SWIG_IsOK(res2)) {
    SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "SipMultipartPartVector_append" "', argument " "2"" of type '" "std::vector< pj::SipMultipartPart >::value_type const &""'"); 
  }
  if (!argp2) {
    SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "SipMultipartPartVector_append" "', argument " "2"" of type '" "std::vector< pj::SipMultipartPart >::value_type const &""'"); 
  }
  arg2 = reinterpret_cast< std::vector< pj::SipMultipartPart >::value_type * >(argp2);
  std_vector_Sl_pj_SipMultipartPart_Sg__append(arg1,(pj::SipMultipartPart const &)*arg2);
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_new_SipMultipartPartVector__SWIG_0(PyObject *SWIGUNUSEDPARM(self), Py_ssize_t nobjs, PyObject **SWIGUNUSEDPARM(swig_obj)) {
  PyObject *resultobj = 0;
  std::vector< pj::SipMultipartPart > *result = 0 ;
  
  if ((nobjs < 0) || (nobjs > 0)) SWIG_fail;
  result = (std::vector< pj::SipMultipartPart > *)new std::vector< pj::SipMultipartPart >();
  resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(result), SWIGTYPE_p_std__vectorT_pj__SipMultipartPart_std__allocatorT_pj__SipMultipartPart_t_t, SWIG_POINTER_NEW |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_new_SipMultipartPartVector__SWIG_1(PyObject *SWIGUNUSEDPARM(self), Py_ssize_t nobjs, PyObject **swig_obj) {
  PyObject *resultobj = 0;
  std::vector< pj::SipMultipartPart > *arg1 = 0 ;
  int res1 = SWIG_OLDOBJ ;
  std::vector< pj::SipMultipartPart > *result = 0 ;
  
  if ((nobjs < 1) || (nobjs > 1)) SWIG_fail;
  {
    std::vector< pj::SipMultipartPart,std::allocator< pj::SipMultipartPart > > *ptr = (std::vector< pj::SipMultipartPart,std::allocator< pj::SipMultipartPart > > *)0;
    res1 = swig::asptr(swig_obj[0], &ptr);
    if (!SWIG_IsOK(res1)) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "new_SipMultipartPartVector" "', argument " "1"" of type '" "std::vector< pj::SipMultipartPart > const &""'"); 
    }
    if (!ptr) {
      SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "new_SipMultipartPartVector" "', argument " "1"" of type '" "std::vector< pj::SipMultipartPart > const &""'"); 
    }
    arg1 = ptr;
  }
  result = (std::vector< pj::SipMultipartPart > *)new std::vector< pj::SipMultipartPart >((std::vector< pj::SipMultipartPart > const &)*arg1);
  resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(result), SWIGTYPE_p_std__vectorT_pj__SipMultipartPart_std__allocatorT_pj__SipMultipartPart_t_t, SWIG_POINTER_NEW |  0 );
  if (SWIG_IsNewObj(res1)) delete arg1;
  return resultobj;
fail:
  if (SWIG_IsNewObj(res1)) delete arg1;
  return NULL;
}


SWIGINTERN PyObject *_wrap_SipMultipartPartVector_empty(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  std::vector< pj::SipMultipartPart > *arg1 = (std::vector< pj::SipMultipartPart > *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  bool result;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__vectorT_pj__SipMultipartPart_std__allocatorT_pj__SipMultipartPart_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "SipMultipartPartVector_empty" "', argument " "1"" of type '" "std::vector< pj::SipMultipartPart > const *""'"); 
  }
  arg1 = reinterpret_cast< std::vector< pj::SipMultipartPart > * >(argp1);
  result = (bool)((std::vector< pj::SipMultipartPart > const *)arg1)->empty();
  resultobj = SWIG_From_bool(static_cast< bool >(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_SipMultipartPartVector_size(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  std::vector< pj::SipMultipartPart > *arg1 = (std::vector< pj::SipMultipartPart > *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  std::vector< pj::SipMultipartPart >::size_type result;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__vectorT_pj__SipMultipartPart_std__allocatorT_pj__SipMultipartPart_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "SipMultipartPartVector_size" "', argument " "1"" of type '" "std::vector< pj::SipMultipartPart > const *""'"); 
  }
  arg1 = reinterpret_cast< std::vector< pj::SipMultipartPart > * >(argp1);
  result = ((std::vector< pj::SipMultipartPart > const *)arg1)->size();
  resultobj = SWIG_From_size_t(static_cast< size_t >(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_SipMultipartPartVector_swap(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  std::vector< pj::SipMultipartPart > *arg1 = (std::vector< pj::SipMultipartPart > *) 0 ;
  std::vector< pj::SipMultipartPart > *arg2 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  void *argp2 = 0 ;
  int res2 = 0 ;
  PyObject *swig_obj[2] ;
  
  if (!SWIG_Python_UnpackTuple(args, "SipMultipartPartVector_swap", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__vectorT_pj__SipMultipartPart_std__allocatorT_pj__SipMultipartPart_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "SipMultipartPartVector_swap" "', argument " "1"" of type '" "std::vector< pj::SipMultipartPart > *""'"); 
  }
  arg1 = reinterpret_cast< std::vector< pj::SipMultipartPart > * >(argp1);
  res2 = SWIG_ConvertPtr(swig_obj[1], &argp2, SWIGTYPE_p_std__vectorT_pj__SipMultipartPart_std__allocatorT_pj__SipMultipartPart_t_t,  0 );
  if (!SWIG_IsOK(res2)) {
    SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "SipMultipartPartVector_swap" "', argument " "2"" of type '" "std::vector< pj::SipMultipartPart > &""'"); 
  }
  if (!argp2) {
    SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "SipMultipartPartVector_swap" "', argument " "2"" of type '" "std::vector< pj::SipMultipartPart > &""'"); 
  }
  arg2 = reinterpret_cast< std::vector< pj::SipMultipartPart > * >(argp2);
  (arg1)->swap(*arg2);
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_SipMultipartPartVector_begin(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  std::vector< pj::SipMultipartPart > *arg1 = (std::vector< pj::SipMultipartPart > *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  std::vector< pj::SipMultipartPart >::iterator result;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__vectorT_pj__SipMultipartPart_std__allocatorT_pj__SipMultipartPart_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "SipMultipartPartVector_begin" "', argument " "1"" of type '" "std::vector< pj::SipMultipartPart > *""'"); 
  }
  arg1 = reinterpret_cast< std::vector< pj::SipMultipartPart > * >(argp1);
  result = (arg1)->begin();
  resultobj = SWIG_NewPointerObj(swig::make_output_iterator(static_cast< const std::vector< pj::SipMultipartPart >::iterator & >(result)),
    swig::SwigPyIterator::descriptor(),SWIG_POINTER_OWN);
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_SipMultipartPartVector_end(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  std::vector< pj::SipMultipartPart > *arg1 = (std::vector< pj::SipMultipartPart > *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  std::vector< pj::SipMultipartPart >::iterator result;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__vectorT_pj__SipMultipartPart_std__allocatorT_pj__SipMultipartPart_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "SipMultipartPartVector_end" "', argument " "1"" of type '" "std::vector< pj::SipMultipartPart > *""'"); 
  }
  arg1 = reinterpret_cast< std::vector< pj::SipMultipartPart > * >(argp1);
  result = (arg1)->end();
  resultobj = SWIG_NewPointerObj(swig::make_output_iterator(static_cast< const std::vector< pj::SipMultipartPart >::iterator & >(result)),
    swig::SwigPyIterator::descriptor(),SWIG_POINTER_OWN);
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_SipMultipartPartVector_rbegin(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  std::vector< pj::SipMultipartPart > *arg1 = (std::vector< pj::SipMultipartPart > *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  std::vector< pj::SipMultipartPart >::reverse_iterator result;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__vectorT_pj__SipMultipartPart_std__allocatorT_pj__SipMultipartPart_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "SipMultipartPartVector_rbegin" "', argument " "1"" of type '" "std::vector< pj::SipMultipartPart > *""'"); 
  }
  arg1 = reinterpret_cast< std::vector< pj::SipMultipartPart > * >(argp1);
  result = (arg1)->rbegin();
  resultobj = SWIG_NewPointerObj(swig::make_output_iterator(static_cast< const std::vector< pj::SipMultipartPart >::reverse_iterator & >(result)),
    swig::SwigPyIterator::descriptor(),SWIG_POINTER_OWN);
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_SipMultipartPartVector_rend(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  std::vector< pj::SipMultipartPart > *arg1 = (std::vector< pj::SipMultipartPart > *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  std::vector< pj::SipMultipartPart >::reverse_iterator result;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__vectorT_pj__SipMultipartPart_std__allocatorT_pj__SipMultipartPart_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "SipMultipartPartVector_rend" "', argument " "1"" of type '" "std::vector< pj::SipMultipartPart > *""'"); 
  }
  arg1 = reinterpret_cast< std::vector< pj::SipMultipartPart > * >(argp1);
  result = (arg1)->rend();
  resultobj = SWIG_NewPointerObj(swig::make_output_iterator(static_cast< const std::vector< pj::SipMultipartPart >::reverse_iterator & >(result)),
    swig::SwigPyIterator::descriptor(),SWIG_POINTER_OWN);
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_SipMultipartPartVector_clear(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  std::vector< pj::SipMultipartPart > *arg1 = (std::vector< pj::SipMultipartPart > *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__vectorT_pj__SipMultipartPart_std__allocatorT_pj__SipMultipartPart_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "SipMultipartPartVector_clear" "', argument " "1"" of type '" "std::vector< pj::SipMultipartPart > *""'"); 
  }
  arg1 = reinterpret_cast< std::vector< pj::SipMultipartPart > * >(argp1);
  (arg1)->clear();
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_SipMultipartPartVector_get_allocator(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  std::vector< pj::SipMultipartPart > *arg1 = (std::vector< pj::SipMultipartPart > *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  SwigValueWrapper< std::allocator< pj::SipMultipartPart > > result;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__vectorT_pj__SipMultipartPart_std__allocatorT_pj__SipMultipartPart_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "SipMultipartPartVector_get_allocator" "', argument " "1"" of type '" "std::vector< pj::SipMultipartPart > const *""'"); 
  }
  arg1 = reinterpret_cast< std::vector< pj::SipMultipartPart > * >(argp1);
  result = ((std::vector< pj::SipMultipartPart > const *)arg1)->get_allocator();
  resultobj = SWIG_NewPointerObj((new std::vector< pj::SipMultipartPart >::allocator_type(static_cast< const std::vector< pj::SipMultipartPart >::allocator_type& >(result))), SWIGTYPE_p_std__allocatorT_pj__SipMultipartPart_t, SWIG_POINTER_OWN |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_new_SipMultipartPartVector__SWIG_2(PyObject *SWIGUNUSEDPARM(self), Py_ssize_t nobjs, PyObject **swig_obj) {
  PyObject *resultobj = 0;
  std::vector< pj::SipMultipartPart >::size_type arg1 ;
  size_t val1 ;
  int ecode1 = 0 ;
  std::vector< pj::SipMultipartPart > *result = 0 ;
  
  if ((nobjs < 1) || (nobjs > 1)) SWIG_fail;
  ecode1 = SWIG_AsVal_size_t(swig_obj[0], &val1);
  if (!SWIG_IsOK(ecode1)) {
    SWIG_exception_fail(SWIG_ArgError(ecode1), "in method '" "new_SipMultipartPartVector" "', argument " "1"" of type '" "std::vector< pj::SipMultipartPart >::size_type""'");
  } 
  arg1 = static_cast< std::vector< pj::SipMultipartPart >::size_type >(val1);
  result = (std::vector< pj::SipMultipartPart > *)new std::vector< pj::SipMultipartPart >(arg1);
  resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(result), SWIGTYPE_p_std__vectorT_pj__SipMultipartPart_std__allocatorT_pj__SipMultipartPart_t_t, SWIG_POINTER_NEW |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_SipMultipartPartVector_pop_back(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  std::vector< pj::SipMultipartPart > *arg1 = (std::vector< pj::SipMultipartPart > *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__vectorT_pj__SipMultipartPart_std__allocatorT_pj__SipMultipartPart_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "SipMultipartPartVector_pop_back" "', argument " "1"" of type '" "std::vector< pj::SipMultipartPart > *""'"); 
  }
  arg1 = reinterpret_cast< std::vector< pj::SipMultipartPart > * >(argp1);
  (arg1)->pop_back();
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_SipMultipartPartVector_resize__SWIG_0(PyObject *SWIGUNUSEDPARM(self), Py_ssize_t nobjs, PyObject **swig_obj) {
  PyObject *resultobj = 0;
  std::vector< pj::SipMultipartPart > *arg1 = (std::vector< pj::SipMultipartPart > *) 0 ;
  std::vector< pj::SipMultipartPart >::size_type arg2 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  size_t val2 ;
  int ecode2 = 0 ;
  
  if ((nobjs < 2) || (nobjs > 2)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__vectorT_pj__SipMultipartPart_std__allocatorT_pj__SipMultipartPart_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "SipMultipartPartVector_resize" "', argument " "1"" of type '" "std::vector< pj::SipMultipartPart > *""'"); 
  }
  arg1 = reinterpret_cast< std::vector< pj::SipMultipartPart > * >(argp1);
  ecode2 = SWIG_AsVal_size_t(swig_obj[1], &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "SipMultipartPartVector_resize" "', argument " "2"" of type '" "std::vector< pj::SipMultipartPart >::size_type""'");
  } 
  arg2 = static_cast< std::vector< pj::SipMultipartPart >::size_type >(val2);
  (arg1)->resize(arg2);
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_SipMultipartPartVector_erase__SWIG_0(PyObject *SWIGUNUSEDPARM(self), Py_ssize_t nobjs, PyObject **swig_obj) {
  PyObject *resultobj = 0;
  std::vector< pj::SipMultipartPart > *arg1 = (std::vector< pj::SipMultipartPart > *) 0 ;
  std::vector< pj::SipMultipartPart >::iterator arg2 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  swig::SwigPyIterator *iter2 = 0 ;
  int res2 ;
  std::vector< pj::SipMultipartPart >::iterator result;
  
  if ((nobjs < 2) || (nobjs > 2)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__vectorT_pj__SipMultipartPart_std__allocatorT_pj__SipMultipartPart_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "SipMultipartPartVector_erase" "', argument " "1"" of type '" "std::vector< pj::SipMultipartPart > *""'"); 
  }
  arg1 = reinterpret_cast< std::vector< pj::SipMultipartPart > * >(argp1);
  res2 = SWIG_ConvertPtr(swig_obj[1], SWIG_as_voidptrptr(&iter2), swig::SwigPyIterator::descriptor(), 0);
  if (!SWIG_IsOK(res2) || !iter2) {
    SWIG_exception_fail(SWIG_ArgError(SWIG_TypeError), "in method '" "SipMultipartPartVector_erase" "', argument " "2"" of type '" "std::vector< pj::SipMultipartPart >::iterator""'");
  } else {
    swig::SwigPyIterator_T<std::vector< pj::SipMultipartPart >::iterator > *iter_t = dynamic_cast<swig::SwigPyIterator_T<std::vector< pj::SipMultipartPart >::iterator > *>(iter2);
    if (iter_t) {
      arg2 = iter_t->get_current();
    } else {
      SWIG_exception_fail(SWIG_ArgError(SWIG_TypeError), "in method '" "SipMultipartPartVector_erase" "', argument " "2"" of type '" "std::vector< pj::SipMultipartPart >::iterator""'");
    }
  }
  result = std_vector_Sl_pj_SipMultipartPart_Sg__erase__SWIG_0(arg1,arg2);
  resultobj = SWIG_NewPointerObj(swig::make_output_iterator(static_cast< const std::vector< pj::SipMultipartPart >::iterator & >(result)),
    swig::SwigPyIterator::descriptor(),SWIG_POINTER_OWN);
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_SipMultipartPartVector_erase__SWIG_1(PyObject *SWIGUNUSEDPARM(self), Py_ssize_t nobjs, PyObject **swig_obj) {
  PyObject *resultobj = 0;
  std::vector< pj::SipMultipartPart > *arg1 = (std::vector< pj::SipMultipartPart > *) 0 ;
  std::vector< pj::SipMultipartPart >::iterator arg2 ;
  std::vector< pj::SipMultipartPart >::iterator arg3 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  swig::SwigPyIterator *iter2 = 0 ;
  int res2 ;
  swig::SwigPyIterator *iter3 = 0 ;
  int res3 ;
  std::vector< pj::SipMultipartPart >::iterator result;
  
  if ((nobjs < 3) || (nobjs > 3)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__vectorT_pj__SipMultipartPart_std__allocatorT_pj__SipMultipartPart_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "SipMultipartPartVector_erase" "', argument " "1"" of type '" "std::vector< pj::SipMultipartPart > *""'"); 
  }
  arg1 = reinterpret_cast< std::vector< pj::SipMultipartPart > * >(argp1);
  res2 = SWIG_ConvertPtr(swig_obj[1], SWIG_as_voidptrptr(&iter2), swig::SwigPyIterator::descriptor(), 0);
  if (!SWIG_IsOK(res2) || !iter2) {
    SWIG_exception_fail(SWIG_ArgError(SWIG_TypeError), "in method '" "SipMultipartPartVector_erase" "', argument " "2"" of type '" "std::vector< pj::SipMultipartPart >::iterator""'");
  } else {
    swig::SwigPyIterator_T<std::vector< pj::SipMultipartPart >::iterator > *iter_t = dynamic_cast<swig::SwigPyIterator_T<std::vector< pj::SipMultipartPart >::iterator > *>(iter2);
    if (iter_t) {
      arg2 = iter_t->get_current();
    } else {
      SWIG_exception_fail(SWIG_ArgError(SWIG_TypeError), "in method '" "SipMultipartPartVector_erase" "', argument " "2"" of type '" "std::vector< pj::SipMultipartPart >::iterator""'");
    }
  }
  res3 = SWIG_ConvertPtr(swig_obj[2], SWIG_as_voidptrptr(&iter3), swig::SwigPyIterator::descriptor(), 0);
  if (!SWIG_IsOK(res3) || !iter3) {
    SWIG_exception_fail(SWIG_ArgError(SWIG_TypeError), "in method '" "SipMultipartPartVector_erase" "', argument " "3"" of type '" "std::vector< pj::SipMultipartPart >::iterator""'");
  } else {
    swig::SwigPyIterator_T<std::vector< pj::SipMultipartPart >::iterator > *iter_t = dynamic_cast<swig::SwigPyIterator_T<std::vector< pj::SipMultipartPart >::iterator > *>(iter3);
    if (iter_t) {
      arg3 = iter_t->get_current();
    } else {
      SWIG_exception_fail(SWIG_ArgError(SWIG_TypeError), "in method '" "SipMultipartPartVector_erase" "', argument " "3"" of type '" "std::vector< pj::SipMultipartPart >::iterator""'");
    }
  }
  result = std_vector_Sl_pj_SipMultipartPart_Sg__erase__SWIG_1(arg1,arg2,arg3);
  resultobj = SWIG_NewPointerObj(swig::make_output_iterator(static_cast< const std::vector< pj::SipMultipartPart >::iterator & >(result)),
    swig::SwigPyIterator::descriptor(),SWIG_POINTER_OWN);
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_SipMultipartPartVector_erase(PyObject *self, PyObject *args) {
  Py_ssize_t argc;
  PyObject *argv[4] = {
    0
  };
  
  if (!(argc = SWIG_Python_UnpackTuple(args, "SipMultipartPartVector_erase", 0, 3, argv))) SWIG_fail;
  --argc;
  if (argc == 2) {
    int _v;
    int res = swig::asptr(argv[0], (std::vector< pj::SipMultipartPart,std::allocator< pj::SipMultipartPart > >**)(0));
    _v = SWIG_CheckState(res);
    if (_v) {
      swig::SwigPyIterator *iter = 0;
      int res = SWIG_ConvertPtr(argv[1], SWIG_as_voidptrptr(&iter), swig::SwigPyIterator::descriptor(), 0);
      _v = (SWIG_IsOK(res) && iter && (dynamic_cast<swig::SwigPyIterator_T<std::vector< pj::SipMultipartPart >::iterator > *>(iter) != 0));
      if (_v) {
        return _wrap_SipMultipartPartVector_erase__SWIG_0(self, argc, argv);
      }
    }
  }
  if (argc == 3) {
    int _v;
    int res = swig::asptr(argv[0], (std::vector< pj::SipMultipartPart,std::allocator< pj::SipMultipartPart > >**)(0));
    _v = SWIG_CheckState(res);
    if (_v) {
      swig::SwigPyIterator *iter = 0;
      int res = SWIG_ConvertPtr(argv[1], SWIG_as_voidptrptr(&iter), swig::SwigPyIterator::descriptor(), 0);
      _v = (SWIG_IsOK(res) && iter && (dynamic_cast<swig::SwigPyIterator_T<std::vector< pj::SipMultipartPart >::iterator > *>(iter) != 0));
      if (_v) {
        swig::SwigPyIterator *iter = 0;
        int res = SWIG_ConvertPtr(argv[2], SWIG_as_voidptrptr(&iter), swig::SwigPyIterator::descriptor(), 0);
        _v = (SWIG_IsOK(res) && iter && (dynamic_cast<swig::SwigPyIterator_T<std::vector< pj::SipMultipartPart >::iterator > *>(iter) != 0));
        if (_v) {
          return _wrap_SipMultipartPartVector_erase__SWIG_1(self, argc, argv);
        }
      }
    }
  }
  
fail:
  SWIG_Python_RaiseOrModifyTypeError("Wrong number or type of arguments for overloaded function 'SipMultipartPartVector_erase'.\n"
    "  Possible C/C++ prototypes are:\n"
    "    std::vector< pj::SipMultipartPart >::erase(std::vector< pj::SipMultipartPart >::iterator)\n"
    "    std::vector< pj::SipMultipartPart >::erase(std::vector< pj::SipMultipartPart >::iterator,std::vector< pj::SipMultipartPart >::iterator)\n");
  return 0;
}


SWIGINTERN PyObject *_wrap_new_SipMultipartPartVector__SWIG_3(PyObject *SWIGUNUSEDPARM(self), Py_ssize_t nobjs, PyObject **swig_obj) {
  PyObject *resultobj = 0;
  std::vector< pj::SipMultipartPart >::size_type arg1 ;
  std::vector< pj::SipMultipartPart >::value_type *arg2 = 0 ;
  size_t val1 ;
  int ecode1 = 0 ;
  void *argp2 = 0 ;
  int res2 = 0 ;
  std::vector< pj::SipMultipartPart > *result = 0 ;
  
  if ((nobjs < 2) || (nobjs > 2)) SWIG_fail;
  ecode1 = SWIG_AsVal_size_t(swig_obj[0], &val1);
  if (!SWIG_IsOK(ecode1)) {
    SWIG_exception_fail(SWIG_ArgError(ecode1), "in method '" "new_SipMultipartPartVector" "', argument " "1"" of type '" "std::vector< pj::SipMultipartPart >::size_type""'");
  } 
  arg1 = static_cast< std::vector< pj::SipMultipartPart >::size_type >(val1);
  res2 = SWIG_ConvertPtr(swig_obj[1], &argp2, SWIGTYPE_p_pj__SipMultipartPart,  0  | 0);
  if (!SWIG_IsOK(res2)) {
    SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "new_SipMultipartPartVector" "', argument " "2"" of type '" "std::vector< pj::SipMultipartPart >::value_type const &""'"); 
  }
  if (!argp2) {
    SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "new_SipMultipartPartVector" "', argument " "2"" of type '" "std::vector< pj::SipMultipartPart >::value_type const &""'"); 
  }
  arg2 = reinterpret_cast< std::vector< pj::SipMultipartPart >::value_type * >(argp2);
  result = (std::vector< pj::SipMultipartPart > *)new std::vector< pj::SipMultipartPart >(arg1,(std::vector< pj::SipMultipartPart >::value_type const &)*arg2);
  resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(result), SWIGTYPE_p_std__vectorT_pj__SipMultipartPart_std__allocatorT_pj__SipMultipartPart_t_t, SWIG_POINTER_NEW |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_new_SipMultipartPartVector(PyObject *self, PyObject *args) {
  Py_ssize_t argc;
  PyObject *argv[3] = {
    0
  };
  
  if (!(argc = SWIG_Python_UnpackTuple(args, "new_SipMultipartPartVector", 0, 2, argv))) SWIG_fail;
  --argc;
  if (argc == 0) {
    return _wrap_new_SipMultipartPartVector__SWIG_0(self, argc, argv);
  }
  if (argc == 1) {
    int _v;
    {
      int res = SWIG_AsVal_size_t(argv[0], NULL);
      _v = SWIG_CheckState(res);
    }
    if (_v) {
      return _wrap_new_SipMultipartPartVector__SWIG_2(self, argc, argv);
    }
  }
  if (argc == 1) {
    int _v;
    int res = swig::asptr(argv[0], (std::vector< pj::SipMultipartPart,std::allocator< pj::SipMultipartPart > >**)(0));
    _v = SWIG_CheckState(res);
    if (_v) {
      return _wrap_new_SipMultipartPartVector__SWIG_1(self, argc, argv);
    }
  }
  if (argc == 2) {
    int _v;
    {
      int res = SWIG_AsVal_size_t(argv[0], NULL);
      _v = SWIG_CheckState(res);
    }
    if (_v) {
      int res = SWIG_ConvertPtr(argv[1], 0, SWIGTYPE_p_pj__SipMultipartPart, SWIG_POINTER_NO_NULL | 0);
      _v = SWIG_CheckState(res);
      if (_v) {
        return _wrap_new_SipMultipartPartVector__SWIG_3(self, argc, argv);
      }
    }
  }
  
fail:
  SWIG_Python_RaiseOrModifyTypeError("Wrong number or type of arguments for overloaded function 'new_SipMultipartPartVector'.\n"
    "  Possible C/C++ prototypes are:\n"
    "    std::vector< pj::SipMultipartPart >::vector()\n"
    "    std::vector< pj::SipMultipartPart >::vector(std::vector< pj::SipMultipartPart > const &)\n"
    "    std::vector< pj::SipMultipartPart >::vector(std::vector< pj::SipMultipartPart >::size_type)\n"
    "    std::vector< pj::SipMultipartPart >::vector(std::vector< pj::SipMultipartPart >::size_type,std::vector< pj::SipMultipartPart >::value_type const &)\n");
  return 0;
}


SWIGINTERN PyObject *_wrap_SipMultipartPartVector_push_back(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  std::vector< pj::SipMultipartPart > *arg1 = (std::vector< pj::SipMultipartPart > *) 0 ;
  std::vector< pj::SipMultipartPart >::value_type *arg2 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  void *argp2 = 0 ;
  int res2 = 0 ;
  PyObject *swig_obj[2] ;
  
  if (!SWIG_Python_UnpackTuple(args, "SipMultipartPartVector_push_back", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__vectorT_pj__SipMultipartPart_std__allocatorT_pj__SipMultipartPart_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "SipMultipartPartVector_push_back" "', argument " "1"" of type '" "std::vector< pj::SipMultipartPart > *""'"); 
  }
  arg1 = reinterpret_cast< std::vector< pj::SipMultipartPart > * >(argp1);
  res2 = SWIG_ConvertPtr(swig_obj[1], &argp2, SWIGTYPE_p_pj__SipMultipartPart,  0  | 0);
  if (!SWIG_IsOK(res2)) {
    SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "SipMultipartPartVector_push_back" "', argument " "2"" of type '" "std::vector< pj::SipMultipartPart >::value_type const &""'"); 
  }
  if (!argp2) {
    SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "SipMultipartPartVector_push_back" "', argument " "2"" of type '" "std::vector< pj::SipMultipartPart >::value_type const &""'"); 
  }
  arg2 = reinterpret_cast< std::vector< pj::SipMultipartPart >::value_type * >(argp2);
  (arg1)->push_back((std::vector< pj::SipMultipartPart >::value_type const &)*arg2);
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_SipMultipartPartVector_front(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  std::vector< pj::SipMultipartPart > *arg1 = (std::vector< pj::SipMultipartPart > *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  std::vector< pj::SipMultipartPart >::value_type *result = 0 ;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__vectorT_pj__SipMultipartPart_std__allocatorT_pj__SipMultipartPart_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "SipMultipartPartVector_front" "', argument " "1"" of type '" "std::vector< pj::SipMultipartPart > const *""'"); 
  }
  arg1 = reinterpret_cast< std::vector< pj::SipMultipartPart > * >(argp1);
  result = (std::vector< pj::SipMultipartPart >::value_type *) &((std::vector< pj::SipMultipartPart > const *)arg1)->front();
  resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(result), SWIGTYPE_p_pj__SipMultipartPart, 0 |  0 );
  (void)swig::container_owner<swig::traits<std::vector< pj::SipMultipartPart >::value_type>::category>::back_reference(resultobj, swig_obj[0]);
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_SipMultipartPartVector_back(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  std::vector< pj::SipMultipartPart > *arg1 = (std::vector< pj::SipMultipartPart > *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  std::vector< pj::SipMultipartPart >::value_type *result = 0 ;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__vectorT_pj__SipMultipartPart_std__allocatorT_pj__SipMultipartPart_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "SipMultipartPartVector_back" "', argument " "1"" of type '" "std::vector< pj::SipMultipartPart > const *""'"); 
  }
  arg1 = reinterpret_cast< std::vector< pj::SipMultipartPart > * >(argp1);
  result = (std::vector< pj::SipMultipartPart >::value_type *) &((std::vector< pj::SipMultipartPart > const *)arg1)->back();
  resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(result), SWIGTYPE_p_pj__SipMultipartPart, 0 |  0 );
  (void)swig::container_owner<swig::traits<std::vector< pj::SipMultipartPart >::value_type>::category>::back_reference(resultobj, swig_obj[0]);
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_SipMultipartPartVector_assign(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  std::vector< pj::SipMultipartPart > *arg1 = (std::vector< pj::SipMultipartPart > *) 0 ;
  std::vector< pj::SipMultipartPart >::size_type arg2 ;
  std::vector< pj::SipMultipartPart >::value_type *arg3 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  size_t val2 ;
  int ecode2 = 0 ;
  void *argp3 = 0 ;
  int res3 = 0 ;
  PyObject *swig_obj[3] ;
  
  if (!SWIG_Python_UnpackTuple(args, "SipMultipartPartVector_assign", 3, 3, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__vectorT_pj__SipMultipartPart_std__allocatorT_pj__SipMultipartPart_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "SipMultipartPartVector_assign" "', argument " "1"" of type '" "std::vector< pj::SipMultipartPart > *""'"); 
  }
  arg1 = reinterpret_cast< std::vector< pj::SipMultipartPart > * >(argp1);
  ecode2 = SWIG_AsVal_size_t(swig_obj[1], &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "SipMultipartPartVector_assign" "', argument " "2"" of type '" "std::vector< pj::SipMultipartPart >::size_type""'");
  } 
  arg2 = static_cast< std::vector< pj::SipMultipartPart >::size_type >(val2);
  res3 = SWIG_ConvertPtr(swig_obj[2], &argp3, SWIGTYPE_p_pj__SipMultipartPart,  0  | 0);
  if (!SWIG_IsOK(res3)) {
    SWIG_exception_fail(SWIG_ArgError(res3), "in method '" "SipMultipartPartVector_assign" "', argument " "3"" of type '" "std::vector< pj::SipMultipartPart >::value_type const &""'"); 
  }
  if (!argp3) {
    SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "SipMultipartPartVector_assign" "', argument " "3"" of type '" "std::vector< pj::SipMultipartPart >::value_type const &""'"); 
  }
  arg3 = reinterpret_cast< std::vector< pj::SipMultipartPart >::value_type * >(argp3);
  (arg1)->assign(arg2,(std::vector< pj::SipMultipartPart >::value_type const &)*arg3);
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_SipMultipartPartVector_resize__SWIG_1(PyObject *SWIGUNUSEDPARM(self), Py_ssize_t nobjs, PyObject **swig_obj) {
  PyObject *resultobj = 0;
  std::vector< pj::SipMultipartPart > *arg1 = (std::vector< pj::SipMultipartPart > *) 0 ;
  std::vector< pj::SipMultipartPart >::size_type arg2 ;
  std::vector< pj::SipMultipartPart >::value_type *arg3 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  size_t val2 ;
  int ecode2 = 0 ;
  void *argp3 = 0 ;
  int res3 = 0 ;
  
  if ((nobjs < 3) || (nobjs > 3)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__vectorT_pj__SipMultipartPart_std__allocatorT_pj__SipMultipartPart_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "SipMultipartPartVector_resize" "', argument " "1"" of type '" "std::vector< pj::SipMultipartPart > *""'"); 
  }
  arg1 = reinterpret_cast< std::vector< pj::SipMultipartPart > * >(argp1);
  ecode2 = SWIG_AsVal_size_t(swig_obj[1], &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "SipMultipartPartVector_resize" "', argument " "2"" of type '" "std::vector< pj::SipMultipartPart >::size_type""'");
  } 
  arg2 = static_cast< std::vector< pj::SipMultipartPart >::size_type >(val2);
  res3 = SWIG_ConvertPtr(swig_obj[2], &argp3, SWIGTYPE_p_pj__SipMultipartPart,  0  | 0);
  if (!SWIG_IsOK(res3)) {
    SWIG_exception_fail(SWIG_ArgError(res3), "in method '" "SipMultipartPartVector_resize" "', argument " "3"" of type '" "std::vector< pj::SipMultipartPart >::value_type const &""'"); 
  }
  if (!argp3) {
    SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "SipMultipartPartVector_resize" "', argument " "3"" of type '" "std::vector< pj::SipMultipartPart >::value_type const &""'"); 
  }
  arg3 = reinterpret_cast< std::vector< pj::SipMultipartPart >::value_type * >(argp3);
  (arg1)->resize(arg2,(std::vector< pj::SipMultipartPart >::value_type const &)*arg3);
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_SipMultipartPartVector_resize(PyObject *self, PyObject *args) {
  Py_ssize_t argc;
  PyObject *argv[4] = {
    0
  };
  
  if (!(argc = SWIG_Python_UnpackTuple(args, "SipMultipartPartVector_resize", 0, 3, argv))) SWIG_fail;
  --argc;
  if (argc == 2) {
    int _v;
    int res = swig::asptr(argv[0], (std::vector< pj::SipMultipartPart,std::allocator< pj::SipMultipartPart > >**)(0));
    _v = SWIG_CheckState(res);
    if (_v) {
      {
        int res = SWIG_AsVal_size_t(argv[1], NULL);
        _v = SWIG_CheckState(res);
      }
      if (_v) {
        return _wrap_SipMultipartPartVector_resize__SWIG_0(self, argc, argv);
      }
    }
  }
  if (argc == 3) {
    int _v;
    int res = swig::asptr(argv[0], (std::vector< pj::SipMultipartPart,std::allocator< pj::SipMultipartPart > >**)(0));
    _v = SWIG_CheckState(res);
    if (_v) {
      {
        int res = SWIG_AsVal_size_t(argv[1], NULL);
        _v = SWIG_CheckState(res);
      }
      if (_v) {
        int res = SWIG_ConvertPtr(argv[2], 0, SWIGTYPE_p_pj__SipMultipartPart, SWIG_POINTER_NO_NULL | 0);
        _v = SWIG_CheckState(res);
        if (_v) {
          return _wrap_SipMultipartPartVector_resize__SWIG_1(self, argc, argv);
        }
      }
    }
  }
  
fail:
  SWIG_Python_RaiseOrModifyTypeError("Wrong number or type of arguments for overloaded function 'SipMultipartPartVector_resize'.\n"
    "  Possible C/C++ prototypes are:\n"
    "    std::vector< pj::SipMultipartPart >::resize(std::vector< pj::SipMultipartPart >::size_type)\n"
    "    std::vector< pj::SipMultipartPart >::resize(std::vector< pj::SipMultipartPart >::size_type,std::vector< pj::SipMultipartPart >::value_type const &)\n");
  return 0;
}


SWIGINTERN PyObject *_wrap_SipMultipartPartVector_insert__SWIG_0(PyObject *SWIGUNUSEDPARM(self), Py_ssize_t nobjs, PyObject **swig_obj) {
  PyObject *resultobj = 0;
  std::vector< pj::SipMultipartPart > *arg1 = (std::vector< pj::SipMultipartPart > *) 0 ;
  std::vector< pj::SipMultipartPart >::iterator arg2 ;
  std::vector< pj::SipMultipartPart >::value_type *arg3 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  swig::SwigPyIterator *iter2 = 0 ;
  int res2 ;
  void *argp3 = 0 ;
  int res3 = 0 ;
  std::vector< pj::SipMultipartPart >::iterator result;
  
  if ((nobjs < 3) || (nobjs > 3)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__vectorT_pj__SipMultipartPart_std__allocatorT_pj__SipMultipartPart_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "SipMultipartPartVector_insert" "', argument " "1"" of type '" "std::vector< pj::SipMultipartPart > *""'"); 
  }
  arg1 = reinterpret_cast< std::vector< pj::SipMultipartPart > * >(argp1);
  res2 = SWIG_ConvertPtr(swig_obj[1], SWIG_as_voidptrptr(&iter2), swig::SwigPyIterator::descriptor(), 0);
  if (!SWIG_IsOK(res2) || !iter2) {
    SWIG_exception_fail(SWIG_ArgError(SWIG_TypeError), "in method '" "SipMultipartPartVector_insert" "', argument " "2"" of type '" "std::vector< pj::SipMultipartPart >::iterator""'");
  } else {
    swig::SwigPyIterator_T<std::vector< pj::SipMultipartPart >::iterator > *iter_t = dynamic_cast<swig::SwigPyIterator_T<std::vector< pj::SipMultipartPart >::iterator > *>(iter2);
    if (iter_t) {
      arg2 = iter_t->get_current();
    } else {
      SWIG_exception_fail(SWIG_ArgError(SWIG_TypeError), "in method '" "SipMultipartPartVector_insert" "', argument " "2"" of type '" "std::vector< pj::SipMultipartPart >::iterator""'");
    }
  }
  res3 = SWIG_ConvertPtr(swig_obj[2], &argp3, SWIGTYPE_p_pj__SipMultipartPart,  0  | 0);
  if (!SWIG_IsOK(res3)) {
    SWIG_exception_fail(SWIG_ArgError(res3), "in method '" "SipMultipartPartVector_insert" "', argument " "3"" of type '" "std::vector< pj::SipMultipartPart >::value_type const &""'"); 
  }
  if (!argp3) {
    SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "SipMultipartPartVector_insert" "', argument " "3"" of type '" "std::vector< pj::SipMultipartPart >::value_type const &""'"); 
  }
  arg3 = reinterpret_cast< std::vector< pj::SipMultipartPart >::value_type * >(argp3);
  result = std_vector_Sl_pj_SipMultipartPart_Sg__insert__SWIG_0(arg1,arg2,(pj::SipMultipartPart const &)*arg3);
  resultobj = SWIG_NewPointerObj(swig::make_output_iterator(static_cast< const std::vector< pj::SipMultipartPart >::iterator & >(result)),
    swig::SwigPyIterator::descriptor(),SWIG_POINTER_OWN);
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_SipMultipartPartVector_insert__SWIG_1(PyObject *SWIGUNUSEDPARM(self), Py_ssize_t nobjs, PyObject **swig_obj) {
  PyObject *resultobj = 0;
  std::vector< pj::SipMultipartPart > *arg1 = (std::vector< pj::SipMultipartPart > *) 0 ;
  std::vector< pj::SipMultipartPart >::iterator arg2 ;
  std::vector< pj::SipMultipartPart >::size_type arg3 ;
  std::vector< pj::SipMultipartPart >::value_type *arg4 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  swig::SwigPyIterator *iter2 = 0 ;
  int res2 ;
  size_t val3 ;
  int ecode3 = 0 ;
  void *argp4 = 0 ;
  int res4 = 0 ;
  
  if ((nobjs < 4) || (nobjs > 4)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__vectorT_pj__SipMultipartPart_std__allocatorT_pj__SipMultipartPart_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "SipMultipartPartVector_insert" "', argument " "1"" of type '" "std::vector< pj::SipMultipartPart > *""'"); 
  }
  arg1 = reinterpret_cast< std::vector< pj::SipMultipartPart > * >(argp1);
  res2 = SWIG_ConvertPtr(swig_obj[1], SWIG_as_voidptrptr(&iter2), swig::SwigPyIterator::descriptor(), 0);
  if (!SWIG_IsOK(res2) || !iter2) {
    SWIG_exception_fail(SWIG_ArgError(SWIG_TypeError), "in method '" "SipMultipartPartVector_insert" "', argument " "2"" of type '" "std::vector< pj::SipMultipartPart >::iterator""'");
  } else {
    swig::SwigPyIterator_T<std::vector< pj::SipMultipartPart >::iterator > *iter_t = dynamic_cast<swig::SwigPyIterator_T<std::vector< pj::SipMultipartPart >::iterator > *>(iter2);
    if (iter_t) {
      arg2 = iter_t->get_current();
    } else {
      SWIG_exception_fail(SWIG_ArgError(SWIG_TypeError), "in method '" "SipMultipartPartVector_insert" "', argument " "2"" of type '" "std::vector< pj::SipMultipartPart >::iterator""'");
    }
  }
  ecode3 = SWIG_AsVal_size_t(swig_obj[2], &val3);
  if (!SWIG_IsOK(ecode3)) {
    SWIG_exception_fail(SWIG_ArgError(ecode3), "in method '" "SipMultipartPartVector_insert" "', argument " "3"" of type '" "std::vector< pj::SipMultipartPart >::size_type""'");
  } 
  arg3 = static_cast< std::vector< pj::SipMultipartPart >::size_type >(val3);
  res4 = SWIG_ConvertPtr(swig_obj[3], &argp4, SWIGTYPE_p_pj__SipMultipartPart,  0  | 0);
  if (!SWIG_IsOK(res4)) {
    SWIG_exception_fail(SWIG_ArgError(res4), "in method '" "SipMultipartPartVector_insert" "', argument " "4"" of type '" "std::vector< pj::SipMultipartPart >::value_type const &""'"); 
  }
  if (!argp4) {
    SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "SipMultipartPartVector_insert" "', argument " "4"" of type '" "std::vector< pj::SipMultipartPart >::value_type const &""'"); 
  }
  arg4 = reinterpret_cast< std::vector< pj::SipMultipartPart >::value_type * >(argp4);
  std_vector_Sl_pj_SipMultipartPart_Sg__insert__SWIG_1(arg1,arg2,arg3,(pj::SipMultipartPart const &)*arg4);
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_SipMultipartPartVector_insert(PyObject *self, PyObject *args) {
  Py_ssize_t argc;
  PyObject *argv[5] = {
    0
  };
  
  if (!(argc = SWIG_Python_UnpackTuple(args, "SipMultipartPartVector_insert", 0, 4, argv))) SWIG_fail;
  --argc;
  if (argc == 3) {
    int _v;
    int res = swig::asptr(argv[0], (std::vector< pj::SipMultipartPart,std::allocator< pj::SipMultipartPart > >**)(0));
    _v = SWIG_CheckState(res);
    if (_v) {
      swig::SwigPyIterator *iter = 0;
      int res = SWIG_ConvertPtr(argv[1], SWIG_as_voidptrptr(&iter), swig::SwigPyIterator::descriptor(), 0);
      _v = (SWIG_IsOK(res) && iter && (dynamic_cast<swig::SwigPyIterator_T<std::vector< pj::SipMultipartPart >::iterator > *>(iter) != 0));
      if (_v) {
        int res = SWIG_ConvertPtr(argv[2], 0, SWIGTYPE_p_pj__SipMultipartPart, SWIG_POINTER_NO_NULL | 0);
        _v = SWIG_CheckState(res);
        if (_v) {
          return _wrap_SipMultipartPartVector_insert__SWIG_0(self, argc, argv);
        }
      }
    }
  }
  if (argc == 4) {
    int _v;
    int res = swig::asptr(argv[0], (std::vector< pj::SipMultipartPart,std::allocator< pj::SipMultipartPart > >**)(0));
    _v = SWIG_CheckState(res);
    if (_v) {
      swig::SwigPyIterator *iter = 0;
      int res = SWIG_ConvertPtr(argv[1], SWIG_as_voidptrptr(&iter), swig::SwigPyIterator::descriptor(), 0);
      _v = (SWIG_IsOK(res) && iter && (dynamic_cast<swig::SwigPyIterator_T<std::vector< pj::SipMultipartPart >::iterator > *>(iter) != 0));
      if (_v) {
        {
          int res = SWIG_AsVal_size_t(argv[2], NULL);
          _v = SWIG_CheckState(res);
        }
        if (_v) {
          int res = SWIG_ConvertPtr(argv[3], 0, SWIGTYPE_p_pj__SipMultipartPart, SWIG_POINTER_NO_NULL | 0);
          _v = SWIG_CheckState(res);
          if (_v) {
            return _wrap_SipMultipartPartVector_insert__SWIG_1(self, argc, argv);
          }
        }
      }
    }
  }
  
fail:
  SWIG_Python_RaiseOrModifyTypeError("Wrong number or type of arguments for overloaded function 'SipMultipartPartVector_insert'.\n"
    "  Possible C/C++ prototypes are:\n"
    "    std::vector< pj::SipMultipartPart >::insert(std::vector< pj::SipMultipartPart >::iterator,std::vector< pj::SipMultipartPart >::value_type const &)\n"
    "    std::vector< pj::SipMultipartPart >::insert(std::vector< pj::SipMultipartPart >::iterator,std::vector< pj::SipMultipartPart >::size_type,std::vector< pj::SipMultipartPart >::value_type const &)\n");
  return 0;
}


SWIGINTERN PyObject *_wrap_SipMultipartPartVector_reserve(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  std::vector< pj::SipMultipartPart > *arg1 = (std::vector< pj::SipMultipartPart > *) 0 ;
  std::vector< pj::SipMultipartPart >::size_type arg2 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  size_t val2 ;
  int ecode2 = 0 ;
  PyObject *swig_obj[2] ;
  
  if (!SWIG_Python_UnpackTuple(args, "SipMultipartPartVector_reserve", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__vectorT_pj__SipMultipartPart_std__allocatorT_pj__SipMultipartPart_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "SipMultipartPartVector_reserve" "', argument " "1"" of type '" "std::vector< pj::SipMultipartPart > *""'"); 
  }
  arg1 = reinterpret_cast< std::vector< pj::SipMultipartPart > * >(argp1);
  ecode2 = SWIG_AsVal_size_t(swig_obj[1], &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "SipMultipartPartVector_reserve" "', argument " "2"" of type '" "std::vector< pj::SipMultipartPart >::size_type""'");
  } 
  arg2 = static_cast< std::vector< pj::SipMultipartPart >::size_type >(val2);
  (arg1)->reserve(arg2);
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_SipMultipartPartVector_capacity(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  std::vector< pj::SipMultipartPart > *arg1 = (std::vector< pj::SipMultipartPart > *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  std::vector< pj::SipMultipartPart >::size_type result;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__vectorT_pj__SipMultipartPart_std__allocatorT_pj__SipMultipartPart_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "SipMultipartPartVector_capacity" "', argument " "1"" of type '" "std::vector< pj::SipMultipartPart > const *""'"); 
  }
  arg1 = reinterpret_cast< std::vector< pj::SipMultipartPart > * >(argp1);
  result = ((std::vector< pj::SipMultipartPart > const *)arg1)->capacity();
  resultobj = SWIG_From_size_t(static_cast< size_t >(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_delete_SipMultipartPartVector(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  std::vector< pj::SipMultipartPart > *arg1 = (std::vector< pj::SipMultipartPart > *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__vectorT_pj__SipMultipartPart_std__allocatorT_pj__SipMultipartPart_t_t, SWIG_POINTER_DISOWN |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "delete_SipMultipartPartVector" "', argument " "1"" of type '" "std::vector< pj::SipMultipartPart > *""'"); 
  }
  arg1 = reinterpret_cast< std::vector< pj::SipMultipartPart > * >(argp1);
  delete arg1;
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *SipMultipartPartVector_swigregister(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *obj;
  if (!SWIG_Python_UnpackTuple(args, "swigregister", 1, 1, &obj)) return NULL;
  SWIG_TypeNewClientData(SWIGTYPE_p_std__vectorT_pj__SipMultipartPart_std__allocatorT_pj__SipMultipartPart_t_t, SWIG_NewClientData(obj));
  return SWIG_Py_Void();
}

SWIGINTERN PyObject *SipMultipartPartVector_swiginit(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  return SWIG_Python_InitShadowInstance(args);
}

SWIGINTERN PyObject *_wrap_BuddyVector_iterator(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  std::vector< pj::Buddy * > *arg1 = (std::vector< pj::Buddy * > *) 0 ;
  PyObject **arg2 = (PyObject **) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  swig::SwigPyIterator *result = 0 ;
  
  arg2 = &swig_obj[0];
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__vectorT_pj__Buddy_p_std__allocatorT_pj__Buddy_p_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "BuddyVector_iterator" "', argument " "1"" of type '" "std::vector< pj::Buddy * > *""'"); 
  }
  arg1 = reinterpret_cast< std::vector< pj::Buddy * > * >(argp1);
  result = (swig::SwigPyIterator *)std_vector_Sl_pj_Buddy_Sm__Sg__iterator(arg1,arg2);
  resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(result), SWIGTYPE_p_swig__SwigPyIterator, SWIG_POINTER_OWN |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_BuddyVector___nonzero__(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  std::vector< pj::Buddy * > *arg1 = (std::vector< pj::Buddy * > *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  bool result;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__vectorT_pj__Buddy_p_std__allocatorT_pj__Buddy_p_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "BuddyVector___nonzero__" "', argument " "1"" of type '" "std::vector< pj::Buddy * > const *""'"); 
  }
  arg1 = reinterpret_cast< std::vector< pj::Buddy * > * >(argp1);
  result = (bool)std_vector_Sl_pj_Buddy_Sm__Sg____nonzero__((std::vector< pj::Buddy * > const *)arg1);
  resultobj = SWIG_From_bool(static_cast< bool >(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_BuddyVector___bool__(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  std::vector< pj::Buddy * > *arg1 = (std::vector< pj::Buddy * > *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  bool result;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__vectorT_pj__Buddy_p_std__allocatorT_pj__Buddy_p_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "BuddyVector___bool__" "', argument " "1"" of type '" "std::vector< pj::Buddy * > const *""'"); 
  }
  arg1 = reinterpret_cast< std::vector< pj::Buddy * > * >(argp1);
  result = (bool)std_vector_Sl_pj_Buddy_Sm__Sg____bool__((std::vector< pj::Buddy * > const *)arg1);
  resultobj = SWIG_From_bool(static_cast< bool >(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_BuddyVector___len__(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  std::vector< pj::Buddy * > *arg1 = (std::vector< pj::Buddy * > *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  std::vector< pj::Buddy * >::size_type result;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__vectorT_pj__Buddy_p_std__allocatorT_pj__Buddy_p_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "BuddyVector___len__" "', argument " "1"" of type '" "std::vector< pj::Buddy * > const *""'"); 
  }
  arg1 = reinterpret_cast< std::vector< pj::Buddy * > * >(argp1);
  result = std_vector_Sl_pj_Buddy_Sm__Sg____len__((std::vector< pj::Buddy * > const *)arg1);
  resultobj = SWIG_From_size_t(static_cast< size_t >(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_BuddyVector___getslice__(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  std::vector< pj::Buddy * > *arg1 = (std::vector< pj::Buddy * > *) 0 ;
  std::vector< pj::Buddy * >::difference_type arg2 ;
  std::vector< pj::Buddy * >::difference_type arg3 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  ptrdiff_t val2 ;
  int ecode2 = 0 ;
  ptrdiff_t val3 ;
  int ecode3 = 0 ;
  PyObject *swig_obj[3] ;
  std::vector< pj::Buddy *,std::allocator< pj::Buddy * > > *result = 0 ;
  
  if (!SWIG_Python_UnpackTuple(args, "BuddyVector___getslice__", 3, 3, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__vectorT_pj__Buddy_p_std__allocatorT_pj__Buddy_p_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "BuddyVector___getslice__" "', argument " "1"" of type '" "std::vector< pj::Buddy * > *""'"); 
  }
  arg1 = reinterpret_cast< std::vector< pj::Buddy * > * >(argp1);
  ecode2 = SWIG_AsVal_ptrdiff_t(swig_obj[1], &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "BuddyVector___getslice__" "', argument " "2"" of type '" "std::vector< pj::Buddy * >::difference_type""'");
  } 
  arg2 = static_cast< std::vector< pj::Buddy * >::difference_type >(val2);
  ecode3 = SWIG_AsVal_ptrdiff_t(swig_obj[2], &val3);
  if (!SWIG_IsOK(ecode3)) {
    SWIG_exception_fail(SWIG_ArgError(ecode3), "in method '" "BuddyVector___getslice__" "', argument " "3"" of type '" "std::vector< pj::Buddy * >::difference_type""'");
  } 
  arg3 = static_cast< std::vector< pj::Buddy * >::difference_type >(val3);
  try {
    result = (std::vector< pj::Buddy *,std::allocator< pj::Buddy * > > *)std_vector_Sl_pj_Buddy_Sm__Sg____getslice__(arg1,arg2,arg3);
  } catch(std::out_of_range &_e) {
    SWIG_exception_fail(SWIG_IndexError, (&_e)->what());
  } catch(std::invalid_argument &_e) {
    SWIG_exception_fail(SWIG_ValueError, (&_e)->what());
  }
  resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(result), SWIGTYPE_p_std__vectorT_pj__Buddy_p_std__allocatorT_pj__Buddy_p_t_t, SWIG_POINTER_OWN |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_BuddyVector___setslice____SWIG_0(PyObject *SWIGUNUSEDPARM(self), Py_ssize_t nobjs, PyObject **swig_obj) {
  PyObject *resultobj = 0;
  std::vector< pj::Buddy * > *arg1 = (std::vector< pj::Buddy * > *) 0 ;
  std::vector< pj::Buddy * >::difference_type arg2 ;
  std::vector< pj::Buddy * >::difference_type arg3 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  ptrdiff_t val2 ;
  int ecode2 = 0 ;
  ptrdiff_t val3 ;
  int ecode3 = 0 ;
  
  if ((nobjs < 3) || (nobjs > 3)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__vectorT_pj__Buddy_p_std__allocatorT_pj__Buddy_p_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "BuddyVector___setslice__" "', argument " "1"" of type '" "std::vector< pj::Buddy * > *""'"); 
  }
  arg1 = reinterpret_cast< std::vector< pj::Buddy * > * >(argp1);
  ecode2 = SWIG_AsVal_ptrdiff_t(swig_obj[1], &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "BuddyVector___setslice__" "', argument " "2"" of type '" "std::vector< pj::Buddy * >::difference_type""'");
  } 
  arg2 = static_cast< std::vector< pj::Buddy * >::difference_type >(val2);
  ecode3 = SWIG_AsVal_ptrdiff_t(swig_obj[2], &val3);
  if (!SWIG_IsOK(ecode3)) {
    SWIG_exception_fail(SWIG_ArgError(ecode3), "in method '" "BuddyVector___setslice__" "', argument " "3"" of type '" "std::vector< pj::Buddy * >::difference_type""'");
  } 
  arg3 = static_cast< std::vector< pj::Buddy * >::difference_type >(val3);
  try {
    std_vector_Sl_pj_Buddy_Sm__Sg____setslice____SWIG_0(arg1,arg2,arg3);
  } catch(std::out_of_range &_e) {
    SWIG_exception_fail(SWIG_IndexError, (&_e)->what());
  } catch(std::invalid_argument &_e) {
    SWIG_exception_fail(SWIG_ValueError, (&_e)->what());
  }
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_BuddyVector___setslice____SWIG_1(PyObject *SWIGUNUSEDPARM(self), Py_ssize_t nobjs, PyObject **swig_obj) {
  PyObject *resultobj = 0;
  std::vector< pj::Buddy * > *arg1 = (std::vector< pj::Buddy * > *) 0 ;
  std::vector< pj::Buddy * >::difference_type arg2 ;
  std::vector< pj::Buddy * >::difference_type arg3 ;
  std::vector< pj::Buddy *,std::allocator< pj::Buddy * > > *arg4 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  ptrdiff_t val2 ;
  int ecode2 = 0 ;
  ptrdiff_t val3 ;
  int ecode3 = 0 ;
  int res4 = SWIG_OLDOBJ ;
  
  if ((nobjs < 4) || (nobjs > 4)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__vectorT_pj__Buddy_p_std__allocatorT_pj__Buddy_p_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "BuddyVector___setslice__" "', argument " "1"" of type '" "std::vector< pj::Buddy * > *""'"); 
  }
  arg1 = reinterpret_cast< std::vector< pj::Buddy * > * >(argp1);
  ecode2 = SWIG_AsVal_ptrdiff_t(swig_obj[1], &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "BuddyVector___setslice__" "', argument " "2"" of type '" "std::vector< pj::Buddy * >::difference_type""'");
  } 
  arg2 = static_cast< std::vector< pj::Buddy * >::difference_type >(val2);
  ecode3 = SWIG_AsVal_ptrdiff_t(swig_obj[2], &val3);
  if (!SWIG_IsOK(ecode3)) {
    SWIG_exception_fail(SWIG_ArgError(ecode3), "in method '" "BuddyVector___setslice__" "', argument " "3"" of type '" "std::vector< pj::Buddy * >::difference_type""'");
  } 
  arg3 = static_cast< std::vector< pj::Buddy * >::difference_type >(val3);
  {
    std::vector< pj::Buddy*,std::allocator< pj::Buddy * > > *ptr = (std::vector< pj::Buddy*,std::allocator< pj::Buddy * > > *)0;
    res4 = swig::asptr(swig_obj[3], &ptr);
    if (!SWIG_IsOK(res4)) {
      SWIG_exception_fail(SWIG_ArgError(res4), "in method '" "BuddyVector___setslice__" "', argument " "4"" of type '" "std::vector< pj::Buddy *,std::allocator< pj::Buddy * > > const &""'"); 
    }
    if (!ptr) {
      SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "BuddyVector___setslice__" "', argument " "4"" of type '" "std::vector< pj::Buddy *,std::allocator< pj::Buddy * > > const &""'"); 
    }
    arg4 = ptr;
  }
  try {
    std_vector_Sl_pj_Buddy_Sm__Sg____setslice____SWIG_1(arg1,arg2,arg3,(std::vector< pj::Buddy *,std::allocator< pj::Buddy * > > const &)*arg4);
  } catch(std::out_of_range &_e) {
    SWIG_exception_fail(SWIG_IndexError, (&_e)->what());
  } catch(std::invalid_argument &_e) {
    SWIG_exception_fail(SWIG_ValueError, (&_e)->what());
  }
  resultobj = SWIG_Py_Void();
  if (SWIG_IsNewObj(res4)) delete arg4;
  return resultobj;
fail:
  if (SWIG_IsNewObj(res4)) delete arg4;
  return NULL;
}


SWIGINTERN PyObject *_wrap_BuddyVector___setslice__(PyObject *self, PyObject *args) {
  Py_ssize_t argc;
  PyObject *argv[5] = {
    0
  };
  
  if (!(argc = SWIG_Python_UnpackTuple(args, "BuddyVector___setslice__", 0, 4, argv))) SWIG_fail;
  --argc;
  if (argc == 3) {
    int _v;
    int res = swig::asptr(argv[0], (std::vector< pj::Buddy*,std::allocator< pj::Buddy * > >**)(0));
    _v = SWIG_CheckState(res);
    if (_v) {
      {
        int res = SWIG_AsVal_ptrdiff_t(argv[1], NULL);
        _v = SWIG_CheckState(res);
      }
      if (_v) {
        {
          int res = SWIG_AsVal_ptrdiff_t(argv[2], NULL);
          _v = SWIG_CheckState(res);
        }
        if (_v) {
          return _wrap_BuddyVector___setslice____SWIG_0(self, argc, argv);
        }
      }
    }
  }
  if (argc == 4) {
    int _v;
    int res = swig::asptr(argv[0], (std::vector< pj::Buddy*,std::allocator< pj::Buddy * > >**)(0));
    _v = SWIG_CheckState(res);
    if (_v) {
      {
        int res = SWIG_AsVal_ptrdiff_t(argv[1], NULL);
        _v = SWIG_CheckState(res);
      }
      if (_v) {
        {
          int res = SWIG_AsVal_ptrdiff_t(argv[2], NULL);
          _v = SWIG_CheckState(res);
        }
        if (_v) {
          int res = swig::asptr(argv[3], (std::vector< pj::Buddy*,std::allocator< pj::Buddy * > >**)(0));
          _v = SWIG_CheckState(res);
          if (_v) {
            return _wrap_BuddyVector___setslice____SWIG_1(self, argc, argv);
          }
        }
      }
    }
  }
  
fail:
  SWIG_Python_RaiseOrModifyTypeError("Wrong number or type of arguments for overloaded function 'BuddyVector___setslice__'.\n"
    "  Possible C/C++ prototypes are:\n"
    "    std::vector< pj::Buddy * >::__setslice__(std::vector< pj::Buddy * >::difference_type,std::vector< pj::Buddy * >::difference_type)\n"
    "    std::vector< pj::Buddy * >::__setslice__(std::vector< pj::Buddy * >::difference_type,std::vector< pj::Buddy * >::difference_type,std::vector< pj::Buddy *,std::allocator< pj::Buddy * > > const &)\n");
  return 0;
}


SWIGINTERN PyObject *_wrap_BuddyVector___delslice__(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  std::vector< pj::Buddy * > *arg1 = (std::vector< pj::Buddy * > *) 0 ;
  std::vector< pj::Buddy * >::difference_type arg2 ;
  std::vector< pj::Buddy * >::difference_type arg3 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  ptrdiff_t val2 ;
  int ecode2 = 0 ;
  ptrdiff_t val3 ;
  int ecode3 = 0 ;
  PyObject *swig_obj[3] ;
  
  if (!SWIG_Python_UnpackTuple(args, "BuddyVector___delslice__", 3, 3, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__vectorT_pj__Buddy_p_std__allocatorT_pj__Buddy_p_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "BuddyVector___delslice__" "', argument " "1"" of type '" "std::vector< pj::Buddy * > *""'"); 
  }
  arg1 = reinterpret_cast< std::vector< pj::Buddy * > * >(argp1);
  ecode2 = SWIG_AsVal_ptrdiff_t(swig_obj[1], &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "BuddyVector___delslice__" "', argument " "2"" of type '" "std::vector< pj::Buddy * >::difference_type""'");
  } 
  arg2 = static_cast< std::vector< pj::Buddy * >::difference_type >(val2);
  ecode3 = SWIG_AsVal_ptrdiff_t(swig_obj[2], &val3);
  if (!SWIG_IsOK(ecode3)) {
    SWIG_exception_fail(SWIG_ArgError(ecode3), "in method '" "BuddyVector___delslice__" "', argument " "3"" of type '" "std::vector< pj::Buddy * >::difference_type""'");
  } 
  arg3 = static_cast< std::vector< pj::Buddy * >::difference_type >(val3);
  try {
    std_vector_Sl_pj_Buddy_Sm__Sg____delslice__(arg1,arg2,arg3);
  } catch(std::out_of_range &_e) {
    SWIG_exception_fail(SWIG_IndexError, (&_e)->what());
  } catch(std::invalid_argument &_e) {
    SWIG_exception_fail(SWIG_ValueError, (&_e)->what());
  }
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_BuddyVector___delitem____SWIG_0(PyObject *SWIGUNUSEDPARM(self), Py_ssize_t nobjs, PyObject **swig_obj) {
  PyObject *resultobj = 0;
  std::vector< pj::Buddy * > *arg1 = (std::vector< pj::Buddy * > *) 0 ;
  std::vector< pj::Buddy * >::difference_type arg2 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  ptrdiff_t val2 ;
  int ecode2 = 0 ;
  
  if ((nobjs < 2) || (nobjs > 2)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__vectorT_pj__Buddy_p_std__allocatorT_pj__Buddy_p_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "BuddyVector___delitem__" "', argument " "1"" of type '" "std::vector< pj::Buddy * > *""'"); 
  }
  arg1 = reinterpret_cast< std::vector< pj::Buddy * > * >(argp1);
  ecode2 = SWIG_AsVal_ptrdiff_t(swig_obj[1], &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "BuddyVector___delitem__" "', argument " "2"" of type '" "std::vector< pj::Buddy * >::difference_type""'");
  } 
  arg2 = static_cast< std::vector< pj::Buddy * >::difference_type >(val2);
  try {
    std_vector_Sl_pj_Buddy_Sm__Sg____delitem____SWIG_0(arg1,arg2);
  } catch(std::out_of_range &_e) {
    SWIG_exception_fail(SWIG_IndexError, (&_e)->what());
  } catch(std::invalid_argument &_e) {
    SWIG_exception_fail(SWIG_ValueError, (&_e)->what());
  }
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_BuddyVector___getitem____SWIG_0(PyObject *SWIGUNUSEDPARM(self), Py_ssize_t nobjs, PyObject **swig_obj) {
  PyObject *resultobj = 0;
  std::vector< pj::Buddy * > *arg1 = (std::vector< pj::Buddy * > *) 0 ;
  PySliceObject *arg2 = (PySliceObject *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  std::vector< pj::Buddy *,std::allocator< pj::Buddy * > > *result = 0 ;
  
  if ((nobjs < 2) || (nobjs > 2)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__vectorT_pj__Buddy_p_std__allocatorT_pj__Buddy_p_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "BuddyVector___getitem__" "', argument " "1"" of type '" "std::vector< pj::Buddy * > *""'"); 
  }
  arg1 = reinterpret_cast< std::vector< pj::Buddy * > * >(argp1);
  {
    if (!PySlice_Check(swig_obj[1])) {
      SWIG_exception_fail(SWIG_ArgError(SWIG_TypeError), "in method '" "BuddyVector___getitem__" "', argument " "2"" of type '" "PySliceObject *""'");
    }
    arg2 = (PySliceObject *) swig_obj[1];
  }
  try {
    result = (std::vector< pj::Buddy *,std::allocator< pj::Buddy * > > *)std_vector_Sl_pj_Buddy_Sm__Sg____getitem____SWIG_0(arg1,arg2);
  } catch(std::out_of_range &_e) {
    SWIG_exception_fail(SWIG_IndexError, (&_e)->what());
  } catch(std::invalid_argument &_e) {
    SWIG_exception_fail(SWIG_ValueError, (&_e)->what());
  }
  resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(result), SWIGTYPE_p_std__vectorT_pj__Buddy_p_std__allocatorT_pj__Buddy_p_t_t, SWIG_POINTER_OWN |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_BuddyVector___setitem____SWIG_0(PyObject *SWIGUNUSEDPARM(self), Py_ssize_t nobjs, PyObject **swig_obj) {
  PyObject *resultobj = 0;
  std::vector< pj::Buddy * > *arg1 = (std::vector< pj::Buddy * > *) 0 ;
  PySliceObject *arg2 = (PySliceObject *) 0 ;
  std::vector< pj::Buddy *,std::allocator< pj::Buddy * > > *arg3 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  int res3 = SWIG_OLDOBJ ;
  
  if ((nobjs < 3) || (nobjs > 3)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__vectorT_pj__Buddy_p_std__allocatorT_pj__Buddy_p_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "BuddyVector___setitem__" "', argument " "1"" of type '" "std::vector< pj::Buddy * > *""'"); 
  }
  arg1 = reinterpret_cast< std::vector< pj::Buddy * > * >(argp1);
  {
    if (!PySlice_Check(swig_obj[1])) {
      SWIG_exception_fail(SWIG_ArgError(SWIG_TypeError), "in method '" "BuddyVector___setitem__" "', argument " "2"" of type '" "PySliceObject *""'");
    }
    arg2 = (PySliceObject *) swig_obj[1];
  }
  {
    std::vector< pj::Buddy*,std::allocator< pj::Buddy * > > *ptr = (std::vector< pj::Buddy*,std::allocator< pj::Buddy * > > *)0;
    res3 = swig::asptr(swig_obj[2], &ptr);
    if (!SWIG_IsOK(res3)) {
      SWIG_exception_fail(SWIG_ArgError(res3), "in method '" "BuddyVector___setitem__" "', argument " "3"" of type '" "std::vector< pj::Buddy *,std::allocator< pj::Buddy * > > const &""'"); 
    }
    if (!ptr) {
      SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "BuddyVector___setitem__" "', argument " "3"" of type '" "std::vector< pj::Buddy *,std::allocator< pj::Buddy * > > const &""'"); 
    }
    arg3 = ptr;
  }
  try {
    std_vector_Sl_pj_Buddy_Sm__Sg____setitem____SWIG_0(arg1,arg2,(std::vector< pj::Buddy *,std::allocator< pj::Buddy * > > const &)*arg3);
  } catch(std::out_of_range &_e) {
    SWIG_exception_fail(SWIG_IndexError, (&_e)->what());
  } catch(std::invalid_argument &_e) {
    SWIG_exception_fail(SWIG_ValueError, (&_e)->what());
  }
  resultobj = SWIG_Py_Void();
  if (SWIG_IsNewObj(res3)) delete arg3;
  return resultobj;
fail:
  if (SWIG_IsNewObj(res3)) delete arg3;
  return NULL;
}


SWIGINTERN PyObject *_wrap_BuddyVector___setitem____SWIG_1(PyObject *SWIGUNUSEDPARM(self), Py_ssize_t nobjs, PyObject **swig_obj) {
  PyObject *resultobj = 0;
  std::vector< pj::Buddy * > *arg1 = (std::vector< pj::Buddy * > *) 0 ;
  PySliceObject *arg2 = (PySliceObject *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  
  if ((nobjs < 2) || (nobjs > 2)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__vectorT_pj__Buddy_p_std__allocatorT_pj__Buddy_p_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "BuddyVector___setitem__" "', argument " "1"" of type '" "std::vector< pj::Buddy * > *""'"); 
  }
  arg1 = reinterpret_cast< std::vector< pj::Buddy * > * >(argp1);
  {
    if (!PySlice_Check(swig_obj[1])) {
      SWIG_exception_fail(SWIG_ArgError(SWIG_TypeError), "in method '" "BuddyVector___setitem__" "', argument " "2"" of type '" "PySliceObject *""'");
    }
    arg2 = (PySliceObject *) swig_obj[1];
  }
  try {
    std_vector_Sl_pj_Buddy_Sm__Sg____setitem____SWIG_1(arg1,arg2);
  } catch(std::out_of_range &_e) {
    SWIG_exception_fail(SWIG_IndexError, (&_e)->what());
  } catch(std::invalid_argument &_e) {
    SWIG_exception_fail(SWIG_ValueError, (&_e)->what());
  }
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_BuddyVector___delitem____SWIG_1(PyObject *SWIGUNUSEDPARM(self), Py_ssize_t nobjs, PyObject **swig_obj) {
  PyObject *resultobj = 0;
  std::vector< pj::Buddy * > *arg1 = (std::vector< pj::Buddy * > *) 0 ;
  PySliceObject *arg2 = (PySliceObject *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  
  if ((nobjs < 2) || (nobjs > 2)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__vectorT_pj__Buddy_p_std__allocatorT_pj__Buddy_p_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "BuddyVector___delitem__" "', argument " "1"" of type '" "std::vector< pj::Buddy * > *""'"); 
  }
  arg1 = reinterpret_cast< std::vector< pj::Buddy * > * >(argp1);
  {
    if (!PySlice_Check(swig_obj[1])) {
      SWIG_exception_fail(SWIG_ArgError(SWIG_TypeError), "in method '" "BuddyVector___delitem__" "', argument " "2"" of type '" "PySliceObject *""'");
    }
    arg2 = (PySliceObject *) swig_obj[1];
  }
  try {
    std_vector_Sl_pj_Buddy_Sm__Sg____delitem____SWIG_1(arg1,arg2);
  } catch(std::out_of_range &_e) {
    SWIG_exception_fail(SWIG_IndexError, (&_e)->what());
  } catch(std::invalid_argument &_e) {
    SWIG_exception_fail(SWIG_ValueError, (&_e)->what());
  }
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_BuddyVector___delitem__(PyObject *self, PyObject *args) {
  Py_ssize_t argc;
  PyObject *argv[3] = {
    0
  };
  
  if (!(argc = SWIG_Python_UnpackTuple(args, "BuddyVector___delitem__", 0, 2, argv))) SWIG_fail;
  --argc;
  if (argc == 2) {
    int _v;
    int res = swig::asptr(argv[0], (std::vector< pj::Buddy*,std::allocator< pj::Buddy * > >**)(0));
    _v = SWIG_CheckState(res);
    if (_v) {
      {
        _v = PySlice_Check(argv[1]);
      }
      if (_v) {
        return _wrap_BuddyVector___delitem____SWIG_1(self, argc, argv);
      }
    }
  }
  if (argc == 2) {
    int _v;
    int res = swig::asptr(argv[0], (std::vector< pj::Buddy*,std::allocator< pj::Buddy * > >**)(0));
    _v = SWIG_CheckState(res);
    if (_v) {
      {
        int res = SWIG_AsVal_ptrdiff_t(argv[1], NULL);
        _v = SWIG_CheckState(res);
      }
      if (_v) {
        return _wrap_BuddyVector___delitem____SWIG_0(self, argc, argv);
      }
    }
  }
  
fail:
  SWIG_Python_RaiseOrModifyTypeError("Wrong number or type of arguments for overloaded function 'BuddyVector___delitem__'.\n"
    "  Possible C/C++ prototypes are:\n"
    "    std::vector< pj::Buddy * >::__delitem__(std::vector< pj::Buddy * >::difference_type)\n"
    "    std::vector< pj::Buddy * >::__delitem__(PySliceObject *)\n");
  return 0;
}


SWIGINTERN PyObject *_wrap_BuddyVector___getitem____SWIG_1(PyObject *SWIGUNUSEDPARM(self), Py_ssize_t nobjs, PyObject **swig_obj) {
  PyObject *resultobj = 0;
  std::vector< pj::Buddy * > *arg1 = (std::vector< pj::Buddy * > *) 0 ;
  std::vector< pj::Buddy * >::difference_type arg2 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  ptrdiff_t val2 ;
  int ecode2 = 0 ;
  std::vector< pj::Buddy * >::value_type result;
  
  if ((nobjs < 2) || (nobjs > 2)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__vectorT_pj__Buddy_p_std__allocatorT_pj__Buddy_p_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "BuddyVector___getitem__" "', argument " "1"" of type '" "std::vector< pj::Buddy * > *""'"); 
  }
  arg1 = reinterpret_cast< std::vector< pj::Buddy * > * >(argp1);
  ecode2 = SWIG_AsVal_ptrdiff_t(swig_obj[1], &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "BuddyVector___getitem__" "', argument " "2"" of type '" "std::vector< pj::Buddy * >::difference_type""'");
  } 
  arg2 = static_cast< std::vector< pj::Buddy * >::difference_type >(val2);
  try {
    result = (std::vector< pj::Buddy * >::value_type)std_vector_Sl_pj_Buddy_Sm__Sg____getitem____SWIG_1(arg1,arg2);
  } catch(std::out_of_range &_e) {
    SWIG_exception_fail(SWIG_IndexError, (&_e)->what());
  }
  resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(result), SWIGTYPE_p_pj__Buddy, 0 |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_BuddyVector___getitem__(PyObject *self, PyObject *args) {
  Py_ssize_t argc;
  PyObject *argv[3] = {
    0
  };
  
  if (!(argc = SWIG_Python_UnpackTuple(args, "BuddyVector___getitem__", 0, 2, argv))) SWIG_fail;
  --argc;
  if (argc == 2) {
    int _v;
    int res = swig::asptr(argv[0], (std::vector< pj::Buddy*,std::allocator< pj::Buddy * > >**)(0));
    _v = SWIG_CheckState(res);
    if (_v) {
      {
        _v = PySlice_Check(argv[1]);
      }
      if (_v) {
        return _wrap_BuddyVector___getitem____SWIG_0(self, argc, argv);
      }
    }
  }
  if (argc == 2) {
    int _v;
    int res = swig::asptr(argv[0], (std::vector< pj::Buddy*,std::allocator< pj::Buddy * > >**)(0));
    _v = SWIG_CheckState(res);
    if (_v) {
      {
        int res = SWIG_AsVal_ptrdiff_t(argv[1], NULL);
        _v = SWIG_CheckState(res);
      }
      if (_v) {
        return _wrap_BuddyVector___getitem____SWIG_1(self, argc, argv);
      }
    }
  }
  
fail:
  SWIG_Python_RaiseOrModifyTypeError("Wrong number or type of arguments for overloaded function 'BuddyVector___getitem__'.\n"
    "  Possible C/C++ prototypes are:\n"
    "    std::vector< pj::Buddy * >::__getitem__(PySliceObject *)\n"
    "    std::vector< pj::Buddy * >::__getitem__(std::vector< pj::Buddy * >::difference_type)\n");
  return 0;
}


SWIGINTERN PyObject *_wrap_BuddyVector___setitem____SWIG_2(PyObject *SWIGUNUSEDPARM(self), Py_ssize_t nobjs, PyObject **swig_obj) {
  PyObject *resultobj = 0;
  std::vector< pj::Buddy * > *arg1 = (std::vector< pj::Buddy * > *) 0 ;
  std::vector< pj::Buddy * >::difference_type arg2 ;
  std::vector< pj::Buddy * >::value_type arg3 = (std::vector< pj::Buddy * >::value_type) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  ptrdiff_t val2 ;
  int ecode2 = 0 ;
  void *argp3 = 0 ;
  int res3 = 0 ;
  
  if ((nobjs < 3) || (nobjs > 3)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__vectorT_pj__Buddy_p_std__allocatorT_pj__Buddy_p_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "BuddyVector___setitem__" "', argument " "1"" of type '" "std::vector< pj::Buddy * > *""'"); 
  }
  arg1 = reinterpret_cast< std::vector< pj::Buddy * > * >(argp1);
  ecode2 = SWIG_AsVal_ptrdiff_t(swig_obj[1], &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "BuddyVector___setitem__" "', argument " "2"" of type '" "std::vector< pj::Buddy * >::difference_type""'");
  } 
  arg2 = static_cast< std::vector< pj::Buddy * >::difference_type >(val2);
  res3 = SWIG_ConvertPtr(swig_obj[2], &argp3,SWIGTYPE_p_pj__Buddy, 0 |  0 );
  if (!SWIG_IsOK(res3)) {
    SWIG_exception_fail(SWIG_ArgError(res3), "in method '" "BuddyVector___setitem__" "', argument " "3"" of type '" "std::vector< pj::Buddy * >::value_type""'"); 
  }
  arg3 = reinterpret_cast< std::vector< pj::Buddy * >::value_type >(argp3);
  try {
    std_vector_Sl_pj_Buddy_Sm__Sg____setitem____SWIG_2(arg1,arg2,arg3);
  } catch(std::out_of_range &_e) {
    SWIG_exception_fail(SWIG_IndexError, (&_e)->what());
  }
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_BuddyVector___setitem__(PyObject *self, PyObject *args) {
  Py_ssize_t argc;
  PyObject *argv[4] = {
    0
  };
  
  if (!(argc = SWIG_Python_UnpackTuple(args, "BuddyVector___setitem__", 0, 3, argv))) SWIG_fail;
  --argc;
  if (argc == 2) {
    int _v;
    int res = swig::asptr(argv[0], (std::vector< pj::Buddy*,std::allocator< pj::Buddy * > >**)(0));
    _v = SWIG_CheckState(res);
    if (_v) {
      {
        _v = PySlice_Check(argv[1]);
      }
      if (_v) {
        return _wrap_BuddyVector___setitem____SWIG_1(self, argc, argv);
      }
    }
  }
  if (argc == 3) {
    int _v;
    int res = swig::asptr(argv[0], (std::vector< pj::Buddy*,std::allocator< pj::Buddy * > >**)(0));
    _v = SWIG_CheckState(res);
    if (_v) {
      {
        _v = PySlice_Check(argv[1]);
      }
      if (_v) {
        int res = swig::asptr(argv[2], (std::vector< pj::Buddy*,std::allocator< pj::Buddy * > >**)(0));
        _v = SWIG_CheckState(res);
        if (_v) {
          return _wrap_BuddyVector___setitem____SWIG_0(self, argc, argv);
        }
      }
    }
  }
  if (argc == 3) {
    int _v;
    int res = swig::asptr(argv[0], (std::vector< pj::Buddy*,std::allocator< pj::Buddy * > >**)(0));
    _v = SWIG_CheckState(res);
    if (_v) {
      {
        int res = SWIG_AsVal_ptrdiff_t(argv[1], NULL);
        _v = SWIG_CheckState(res);
      }
      if (_v) {
        void *vptr = 0;
        int res = SWIG_ConvertPtr(argv[2], &vptr, SWIGTYPE_p_pj__Buddy, 0);
        _v = SWIG_CheckState(res);
        if (_v) {
          return _wrap_BuddyVector___setitem____SWIG_2(self, argc, argv);
        }
      }
    }
  }
  
fail:
  SWIG_Python_RaiseOrModifyTypeError("Wrong number or type of arguments for overloaded function 'BuddyVector___setitem__'.\n"
    "  Possible C/C++ prototypes are:\n"
    "    std::vector< pj::Buddy * >::__setitem__(PySliceObject *,std::vector< pj::Buddy *,std::allocator< pj::Buddy * > > const &)\n"
    "    std::vector< pj::Buddy * >::__setitem__(PySliceObject *)\n"
    "    std::vector< pj::Buddy * >::__setitem__(std::vector< pj::Buddy * >::difference_type,std::vector< pj::Buddy * >::value_type)\n");
  return 0;
}


SWIGINTERN PyObject *_wrap_BuddyVector_pop(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  std::vector< pj::Buddy * > *arg1 = (std::vector< pj::Buddy * > *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  std::vector< pj::Buddy * >::value_type result;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__vectorT_pj__Buddy_p_std__allocatorT_pj__Buddy_p_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "BuddyVector_pop" "', argument " "1"" of type '" "std::vector< pj::Buddy * > *""'"); 
  }
  arg1 = reinterpret_cast< std::vector< pj::Buddy * > * >(argp1);
  try {
    result = (std::vector< pj::Buddy * >::value_type)std_vector_Sl_pj_Buddy_Sm__Sg__pop(arg1);
  } catch(std::out_of_range &_e) {
    SWIG_exception_fail(SWIG_IndexError, (&_e)->what());
  }
  resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(result), SWIGTYPE_p_pj__Buddy, 0 |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_BuddyVector_append(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  std::vector< pj::Buddy * > *arg1 = (std::vector< pj::Buddy * > *) 0 ;
  std::vector< pj::Buddy * >::value_type arg2 = (std::vector< pj::Buddy * >::value_type) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  void *argp2 = 0 ;
  int res2 = 0 ;
  PyObject *swig_obj[2] ;
  
  if (!SWIG_Python_UnpackTuple(args, "BuddyVector_append", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__vectorT_pj__Buddy_p_std__allocatorT_pj__Buddy_p_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "BuddyVector_append" "', argument " "1"" of type '" "std::vector< pj::Buddy * > *""'"); 
  }
  arg1 = reinterpret_cast< std::vector< pj::Buddy * > * >(argp1);
  res2 = SWIG_ConvertPtr(swig_obj[1], &argp2,SWIGTYPE_p_pj__Buddy, 0 |  0 );
  if (!SWIG_IsOK(res2)) {
    SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "BuddyVector_append" "', argument " "2"" of type '" "std::vector< pj::Buddy * >::value_type""'"); 
  }
  arg2 = reinterpret_cast< std::vector< pj::Buddy * >::value_type >(argp2);
  std_vector_Sl_pj_Buddy_Sm__Sg__append(arg1,arg2);
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_new_BuddyVector__SWIG_0(PyObject *SWIGUNUSEDPARM(self), Py_ssize_t nobjs, PyObject **SWIGUNUSEDPARM(swig_obj)) {
  PyObject *resultobj = 0;
  std::vector< pj::Buddy * > *result = 0 ;
  
  if ((nobjs < 0) || (nobjs > 0)) SWIG_fail;
  result = (std::vector< pj::Buddy * > *)new std::vector< pj::Buddy * >();
  resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(result), SWIGTYPE_p_std__vectorT_pj__Buddy_p_std__allocatorT_pj__Buddy_p_t_t, SWIG_POINTER_NEW |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_new_BuddyVector__SWIG_1(PyObject *SWIGUNUSEDPARM(self), Py_ssize_t nobjs, PyObject **swig_obj) {
  PyObject *resultobj = 0;
  std::vector< pj::Buddy * > *arg1 = 0 ;
  int res1 = SWIG_OLDOBJ ;
  std::vector< pj::Buddy * > *result = 0 ;
  
  if ((nobjs < 1) || (nobjs > 1)) SWIG_fail;
  {
    std::vector< pj::Buddy*,std::allocator< pj::Buddy * > > *ptr = (std::vector< pj::Buddy*,std::allocator< pj::Buddy * > > *)0;
    res1 = swig::asptr(swig_obj[0], &ptr);
    if (!SWIG_IsOK(res1)) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "new_BuddyVector" "', argument " "1"" of type '" "std::vector< pj::Buddy * > const &""'"); 
    }
    if (!ptr) {
      SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "new_BuddyVector" "', argument " "1"" of type '" "std::vector< pj::Buddy * > const &""'"); 
    }
    arg1 = ptr;
  }
  result = (std::vector< pj::Buddy * > *)new std::vector< pj::Buddy * >((std::vector< pj::Buddy * > const &)*arg1);
  resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(result), SWIGTYPE_p_std__vectorT_pj__Buddy_p_std__allocatorT_pj__Buddy_p_t_t, SWIG_POINTER_NEW |  0 );
  if (SWIG_IsNewObj(res1)) delete arg1;
  return resultobj;
fail:
  if (SWIG_IsNewObj(res1)) delete arg1;
  return NULL;
}


SWIGINTERN PyObject *_wrap_BuddyVector_empty(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  std::vector< pj::Buddy * > *arg1 = (std::vector< pj::Buddy * > *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  bool result;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__vectorT_pj__Buddy_p_std__allocatorT_pj__Buddy_p_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "BuddyVector_empty" "', argument " "1"" of type '" "std::vector< pj::Buddy * > const *""'"); 
  }
  arg1 = reinterpret_cast< std::vector< pj::Buddy * > * >(argp1);
  result = (bool)((std::vector< pj::Buddy * > const *)arg1)->empty();
  resultobj = SWIG_From_bool(static_cast< bool >(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_BuddyVector_size(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  std::vector< pj::Buddy * > *arg1 = (std::vector< pj::Buddy * > *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  std::vector< pj::Buddy * >::size_type result;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__vectorT_pj__Buddy_p_std__allocatorT_pj__Buddy_p_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "BuddyVector_size" "', argument " "1"" of type '" "std::vector< pj::Buddy * > const *""'"); 
  }
  arg1 = reinterpret_cast< std::vector< pj::Buddy * > * >(argp1);
  result = ((std::vector< pj::Buddy * > const *)arg1)->size();
  resultobj = SWIG_From_size_t(static_cast< size_t >(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_BuddyVector_swap(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  std::vector< pj::Buddy * > *arg1 = (std::vector< pj::Buddy * > *) 0 ;
  std::vector< pj::Buddy * > *arg2 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  void *argp2 = 0 ;
  int res2 = 0 ;
  PyObject *swig_obj[2] ;
  
  if (!SWIG_Python_UnpackTuple(args, "BuddyVector_swap", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__vectorT_pj__Buddy_p_std__allocatorT_pj__Buddy_p_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "BuddyVector_swap" "', argument " "1"" of type '" "std::vector< pj::Buddy * > *""'"); 
  }
  arg1 = reinterpret_cast< std::vector< pj::Buddy * > * >(argp1);
  res2 = SWIG_ConvertPtr(swig_obj[1], &argp2, SWIGTYPE_p_std__vectorT_pj__Buddy_p_std__allocatorT_pj__Buddy_p_t_t,  0 );
  if (!SWIG_IsOK(res2)) {
    SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "BuddyVector_swap" "', argument " "2"" of type '" "std::vector< pj::Buddy * > &""'"); 
  }
  if (!argp2) {
    SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "BuddyVector_swap" "', argument " "2"" of type '" "std::vector< pj::Buddy * > &""'"); 
  }
  arg2 = reinterpret_cast< std::vector< pj::Buddy * > * >(argp2);
  (arg1)->swap(*arg2);
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_BuddyVector_begin(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  std::vector< pj::Buddy * > *arg1 = (std::vector< pj::Buddy * > *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  std::vector< pj::Buddy * >::iterator result;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__vectorT_pj__Buddy_p_std__allocatorT_pj__Buddy_p_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "BuddyVector_begin" "', argument " "1"" of type '" "std::vector< pj::Buddy * > *""'"); 
  }
  arg1 = reinterpret_cast< std::vector< pj::Buddy * > * >(argp1);
  result = (arg1)->begin();
  resultobj = SWIG_NewPointerObj(swig::make_output_iterator(static_cast< const std::vector< pj::Buddy * >::iterator & >(result)),
    swig::SwigPyIterator::descriptor(),SWIG_POINTER_OWN);
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_BuddyVector_end(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  std::vector< pj::Buddy * > *arg1 = (std::vector< pj::Buddy * > *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  std::vector< pj::Buddy * >::iterator result;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__vectorT_pj__Buddy_p_std__allocatorT_pj__Buddy_p_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "BuddyVector_end" "', argument " "1"" of type '" "std::vector< pj::Buddy * > *""'"); 
  }
  arg1 = reinterpret_cast< std::vector< pj::Buddy * > * >(argp1);
  result = (arg1)->end();
  resultobj = SWIG_NewPointerObj(swig::make_output_iterator(static_cast< const std::vector< pj::Buddy * >::iterator & >(result)),
    swig::SwigPyIterator::descriptor(),SWIG_POINTER_OWN);
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_BuddyVector_rbegin(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  std::vector< pj::Buddy * > *arg1 = (std::vector< pj::Buddy * > *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  std::vector< pj::Buddy * >::reverse_iterator result;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__vectorT_pj__Buddy_p_std__allocatorT_pj__Buddy_p_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "BuddyVector_rbegin" "', argument " "1"" of type '" "std::vector< pj::Buddy * > *""'"); 
  }
  arg1 = reinterpret_cast< std::vector< pj::Buddy * > * >(argp1);
  result = (arg1)->rbegin();
  resultobj = SWIG_NewPointerObj(swig::make_output_iterator(static_cast< const std::vector< pj::Buddy * >::reverse_iterator & >(result)),
    swig::SwigPyIterator::descriptor(),SWIG_POINTER_OWN);
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_BuddyVector_rend(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  std::vector< pj::Buddy * > *arg1 = (std::vector< pj::Buddy * > *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  std::vector< pj::Buddy * >::reverse_iterator result;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__vectorT_pj__Buddy_p_std__allocatorT_pj__Buddy_p_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "BuddyVector_rend" "', argument " "1"" of type '" "std::vector< pj::Buddy * > *""'"); 
  }
  arg1 = reinterpret_cast< std::vector< pj::Buddy * > * >(argp1);
  result = (arg1)->rend();
  resultobj = SWIG_NewPointerObj(swig::make_output_iterator(static_cast< const std::vector< pj::Buddy * >::reverse_iterator & >(result)),
    swig::SwigPyIterator::descriptor(),SWIG_POINTER_OWN);
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_BuddyVector_clear(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  std::vector< pj::Buddy * > *arg1 = (std::vector< pj::Buddy * > *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__vectorT_pj__Buddy_p_std__allocatorT_pj__Buddy_p_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "BuddyVector_clear" "', argument " "1"" of type '" "std::vector< pj::Buddy * > *""'"); 
  }
  arg1 = reinterpret_cast< std::vector< pj::Buddy * > * >(argp1);
  (arg1)->clear();
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_BuddyVector_get_allocator(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  std::vector< pj::Buddy * > *arg1 = (std::vector< pj::Buddy * > *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  SwigValueWrapper< std::allocator< pj::Buddy * > > result;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__vectorT_pj__Buddy_p_std__allocatorT_pj__Buddy_p_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "BuddyVector_get_allocator" "', argument " "1"" of type '" "std::vector< pj::Buddy * > const *""'"); 
  }
  arg1 = reinterpret_cast< std::vector< pj::Buddy * > * >(argp1);
  result = ((std::vector< pj::Buddy * > const *)arg1)->get_allocator();
  resultobj = SWIG_NewPointerObj((new std::vector< pj::Buddy * >::allocator_type(static_cast< const std::vector< pj::Buddy * >::allocator_type& >(result))), SWIGTYPE_p_std__allocatorT_pj__Buddy_p_t, SWIG_POINTER_OWN |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_new_BuddyVector__SWIG_2(PyObject *SWIGUNUSEDPARM(self), Py_ssize_t nobjs, PyObject **swig_obj) {
  PyObject *resultobj = 0;
  std::vector< pj::Buddy * >::size_type arg1 ;
  size_t val1 ;
  int ecode1 = 0 ;
  std::vector< pj::Buddy * > *result = 0 ;
  
  if ((nobjs < 1) || (nobjs > 1)) SWIG_fail;
  ecode1 = SWIG_AsVal_size_t(swig_obj[0], &val1);
  if (!SWIG_IsOK(ecode1)) {
    SWIG_exception_fail(SWIG_ArgError(ecode1), "in method '" "new_BuddyVector" "', argument " "1"" of type '" "std::vector< pj::Buddy * >::size_type""'");
  } 
  arg1 = static_cast< std::vector< pj::Buddy * >::size_type >(val1);
  result = (std::vector< pj::Buddy * > *)new std::vector< pj::Buddy * >(arg1);
  resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(result), SWIGTYPE_p_std__vectorT_pj__Buddy_p_std__allocatorT_pj__Buddy_p_t_t, SWIG_POINTER_NEW |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_BuddyVector_pop_back(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  std::vector< pj::Buddy * > *arg1 = (std::vector< pj::Buddy * > *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__vectorT_pj__Buddy_p_std__allocatorT_pj__Buddy_p_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "BuddyVector_pop_back" "', argument " "1"" of type '" "std::vector< pj::Buddy * > *""'"); 
  }
  arg1 = reinterpret_cast< std::vector< pj::Buddy * > * >(argp1);
  (arg1)->pop_back();
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_BuddyVector_resize__SWIG_0(PyObject *SWIGUNUSEDPARM(self), Py_ssize_t nobjs, PyObject **swig_obj) {
  PyObject *resultobj = 0;
  std::vector< pj::Buddy * > *arg1 = (std::vector< pj::Buddy * > *) 0 ;
  std::vector< pj::Buddy * >::size_type arg2 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  size_t val2 ;
  int ecode2 = 0 ;
  
  if ((nobjs < 2) || (nobjs > 2)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__vectorT_pj__Buddy_p_std__allocatorT_pj__Buddy_p_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "BuddyVector_resize" "', argument " "1"" of type '" "std::vector< pj::Buddy * > *""'"); 
  }
  arg1 = reinterpret_cast< std::vector< pj::Buddy * > * >(argp1);
  ecode2 = SWIG_AsVal_size_t(swig_obj[1], &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "BuddyVector_resize" "', argument " "2"" of type '" "std::vector< pj::Buddy * >::size_type""'");
  } 
  arg2 = static_cast< std::vector< pj::Buddy * >::size_type >(val2);
  (arg1)->resize(arg2);
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_BuddyVector_erase__SWIG_0(PyObject *SWIGUNUSEDPARM(self), Py_ssize_t nobjs, PyObject **swig_obj) {
  PyObject *resultobj = 0;
  std::vector< pj::Buddy * > *arg1 = (std::vector< pj::Buddy * > *) 0 ;
  std::vector< pj::Buddy * >::iterator arg2 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  swig::SwigPyIterator *iter2 = 0 ;
  int res2 ;
  std::vector< pj::Buddy * >::iterator result;
  
  if ((nobjs < 2) || (nobjs > 2)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__vectorT_pj__Buddy_p_std__allocatorT_pj__Buddy_p_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "BuddyVector_erase" "', argument " "1"" of type '" "std::vector< pj::Buddy * > *""'"); 
  }
  arg1 = reinterpret_cast< std::vector< pj::Buddy * > * >(argp1);
  res2 = SWIG_ConvertPtr(swig_obj[1], SWIG_as_voidptrptr(&iter2), swig::SwigPyIterator::descriptor(), 0);
  if (!SWIG_IsOK(res2) || !iter2) {
    SWIG_exception_fail(SWIG_ArgError(SWIG_TypeError), "in method '" "BuddyVector_erase" "', argument " "2"" of type '" "std::vector< pj::Buddy * >::iterator""'");
  } else {
    swig::SwigPyIterator_T<std::vector< pj::Buddy * >::iterator > *iter_t = dynamic_cast<swig::SwigPyIterator_T<std::vector< pj::Buddy * >::iterator > *>(iter2);
    if (iter_t) {
      arg2 = iter_t->get_current();
    } else {
      SWIG_exception_fail(SWIG_ArgError(SWIG_TypeError), "in method '" "BuddyVector_erase" "', argument " "2"" of type '" "std::vector< pj::Buddy * >::iterator""'");
    }
  }
  result = std_vector_Sl_pj_Buddy_Sm__Sg__erase__SWIG_0(arg1,arg2);
  resultobj = SWIG_NewPointerObj(swig::make_output_iterator(static_cast< const std::vector< pj::Buddy * >::iterator & >(result)),
    swig::SwigPyIterator::descriptor(),SWIG_POINTER_OWN);
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_BuddyVector_erase__SWIG_1(PyObject *SWIGUNUSEDPARM(self), Py_ssize_t nobjs, PyObject **swig_obj) {
  PyObject *resultobj = 0;
  std::vector< pj::Buddy * > *arg1 = (std::vector< pj::Buddy * > *) 0 ;
  std::vector< pj::Buddy * >::iterator arg2 ;
  std::vector< pj::Buddy * >::iterator arg3 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  swig::SwigPyIterator *iter2 = 0 ;
  int res2 ;
  swig::SwigPyIterator *iter3 = 0 ;
  int res3 ;
  std::vector< pj::Buddy * >::iterator result;
  
  if ((nobjs < 3) || (nobjs > 3)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__vectorT_pj__Buddy_p_std__allocatorT_pj__Buddy_p_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "BuddyVector_erase" "', argument " "1"" of type '" "std::vector< pj::Buddy * > *""'"); 
  }
  arg1 = reinterpret_cast< std::vector< pj::Buddy * > * >(argp1);
  res2 = SWIG_ConvertPtr(swig_obj[1], SWIG_as_voidptrptr(&iter2), swig::SwigPyIterator::descriptor(), 0);
  if (!SWIG_IsOK(res2) || !iter2) {
    SWIG_exception_fail(SWIG_ArgError(SWIG_TypeError), "in method '" "BuddyVector_erase" "', argument " "2"" of type '" "std::vector< pj::Buddy * >::iterator""'");
  } else {
    swig::SwigPyIterator_T<std::vector< pj::Buddy * >::iterator > *iter_t = dynamic_cast<swig::SwigPyIterator_T<std::vector< pj::Buddy * >::iterator > *>(iter2);
    if (iter_t) {
      arg2 = iter_t->get_current();
    } else {
      SWIG_exception_fail(SWIG_ArgError(SWIG_TypeError), "in method '" "BuddyVector_erase" "', argument " "2"" of type '" "std::vector< pj::Buddy * >::iterator""'");
    }
  }
  res3 = SWIG_ConvertPtr(swig_obj[2], SWIG_as_voidptrptr(&iter3), swig::SwigPyIterator::descriptor(), 0);
  if (!SWIG_IsOK(res3) || !iter3) {
    SWIG_exception_fail(SWIG_ArgError(SWIG_TypeError), "in method '" "BuddyVector_erase" "', argument " "3"" of type '" "std::vector< pj::Buddy * >::iterator""'");
  } else {
    swig::SwigPyIterator_T<std::vector< pj::Buddy * >::iterator > *iter_t = dynamic_cast<swig::SwigPyIterator_T<std::vector< pj::Buddy * >::iterator > *>(iter3);
    if (iter_t) {
      arg3 = iter_t->get_current();
    } else {
      SWIG_exception_fail(SWIG_ArgError(SWIG_TypeError), "in method '" "BuddyVector_erase" "', argument " "3"" of type '" "std::vector< pj::Buddy * >::iterator""'");
    }
  }
  result = std_vector_Sl_pj_Buddy_Sm__Sg__erase__SWIG_1(arg1,arg2,arg3);
  resultobj = SWIG_NewPointerObj(swig::make_output_iterator(static_cast< const std::vector< pj::Buddy * >::iterator & >(result)),
    swig::SwigPyIterator::descriptor(),SWIG_POINTER_OWN);
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_BuddyVector_erase(PyObject *self, PyObject *args) {
  Py_ssize_t argc;
  PyObject *argv[4] = {
    0
  };
  
  if (!(argc = SWIG_Python_UnpackTuple(args, "BuddyVector_erase", 0, 3, argv))) SWIG_fail;
  --argc;
  if (argc == 2) {
    int _v;
    int res = swig::asptr(argv[0], (std::vector< pj::Buddy*,std::allocator< pj::Buddy * > >**)(0));
    _v = SWIG_CheckState(res);
    if (_v) {
      swig::SwigPyIterator *iter = 0;
      int res = SWIG_ConvertPtr(argv[1], SWIG_as_voidptrptr(&iter), swig::SwigPyIterator::descriptor(), 0);
      _v = (SWIG_IsOK(res) && iter && (dynamic_cast<swig::SwigPyIterator_T<std::vector< pj::Buddy * >::iterator > *>(iter) != 0));
      if (_v) {
        return _wrap_BuddyVector_erase__SWIG_0(self, argc, argv);
      }
    }
  }
  if (argc == 3) {
    int _v;
    int res = swig::asptr(argv[0], (std::vector< pj::Buddy*,std::allocator< pj::Buddy * > >**)(0));
    _v = SWIG_CheckState(res);
    if (_v) {
      swig::SwigPyIterator *iter = 0;
      int res = SWIG_ConvertPtr(argv[1], SWIG_as_voidptrptr(&iter), swig::SwigPyIterator::descriptor(), 0);
      _v = (SWIG_IsOK(res) && iter && (dynamic_cast<swig::SwigPyIterator_T<std::vector< pj::Buddy * >::iterator > *>(iter) != 0));
      if (_v) {
        swig::SwigPyIterator *iter = 0;
        int res = SWIG_ConvertPtr(argv[2], SWIG_as_voidptrptr(&iter), swig::SwigPyIterator::descriptor(), 0);
        _v = (SWIG_IsOK(res) && iter && (dynamic_cast<swig::SwigPyIterator_T<std::vector< pj::Buddy * >::iterator > *>(iter) != 0));
        if (_v) {
          return _wrap_BuddyVector_erase__SWIG_1(self, argc, argv);
        }
      }
    }
  }
  
fail:
  SWIG_Python_RaiseOrModifyTypeError("Wrong number or type of arguments for overloaded function 'BuddyVector_erase'.\n"
    "  Possible C/C++ prototypes are:\n"
    "    std::vector< pj::Buddy * >::erase(std::vector< pj::Buddy * >::iterator)\n"
    "    std::vector< pj::Buddy * >::erase(std::vector< pj::Buddy * >::iterator,std::vector< pj::Buddy * >::iterator)\n");
  return 0;
}


SWIGINTERN PyObject *_wrap_new_BuddyVector__SWIG_3(PyObject *SWIGUNUSEDPARM(self), Py_ssize_t nobjs, PyObject **swig_obj) {
  PyObject *resultobj = 0;
  std::vector< pj::Buddy * >::size_type arg1 ;
  std::vector< pj::Buddy * >::value_type arg2 = (std::vector< pj::Buddy * >::value_type) 0 ;
  size_t val1 ;
  int ecode1 = 0 ;
  void *argp2 = 0 ;
  int res2 = 0 ;
  std::vector< pj::Buddy * > *result = 0 ;
  
  if ((nobjs < 2) || (nobjs > 2)) SWIG_fail;
  ecode1 = SWIG_AsVal_size_t(swig_obj[0], &val1);
  if (!SWIG_IsOK(ecode1)) {
    SWIG_exception_fail(SWIG_ArgError(ecode1), "in method '" "new_BuddyVector" "', argument " "1"" of type '" "std::vector< pj::Buddy * >::size_type""'");
  } 
  arg1 = static_cast< std::vector< pj::Buddy * >::size_type >(val1);
  res2 = SWIG_ConvertPtr(swig_obj[1], &argp2,SWIGTYPE_p_pj__Buddy, 0 |  0 );
  if (!SWIG_IsOK(res2)) {
    SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "new_BuddyVector" "', argument " "2"" of type '" "std::vector< pj::Buddy * >::value_type""'"); 
  }
  arg2 = reinterpret_cast< std::vector< pj::Buddy * >::value_type >(argp2);
  result = (std::vector< pj::Buddy * > *)new std::vector< pj::Buddy * >(arg1,arg2);
  resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(result), SWIGTYPE_p_std__vectorT_pj__Buddy_p_std__allocatorT_pj__Buddy_p_t_t, SWIG_POINTER_NEW |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_new_BuddyVector(PyObject *self, PyObject *args) {
  Py_ssize_t argc;
  PyObject *argv[3] = {
    0
  };
  
  if (!(argc = SWIG_Python_UnpackTuple(args, "new_BuddyVector", 0, 2, argv))) SWIG_fail;
  --argc;
  if (argc == 0) {
    return _wrap_new_BuddyVector__SWIG_0(self, argc, argv);
  }
  if (argc == 1) {
    int _v;
    {
      int res = SWIG_AsVal_size_t(argv[0], NULL);
      _v = SWIG_CheckState(res);
    }
    if (_v) {
      return _wrap_new_BuddyVector__SWIG_2(self, argc, argv);
    }
  }
  if (argc == 1) {
    int _v;
    int res = swig::asptr(argv[0], (std::vector< pj::Buddy*,std::allocator< pj::Buddy * > >**)(0));
    _v = SWIG_CheckState(res);
    if (_v) {
      return _wrap_new_BuddyVector__SWIG_1(self, argc, argv);
    }
  }
  if (argc == 2) {
    int _v;
    {
      int res = SWIG_AsVal_size_t(argv[0], NULL);
      _v = SWIG_CheckState(res);
    }
    if (_v) {
      void *vptr = 0;
      int res = SWIG_ConvertPtr(argv[1], &vptr, SWIGTYPE_p_pj__Buddy, 0);
      _v = SWIG_CheckState(res);
      if (_v) {
        return _wrap_new_BuddyVector__SWIG_3(self, argc, argv);
      }
    }
  }
  
fail:
  SWIG_Python_RaiseOrModifyTypeError("Wrong number or type of arguments for overloaded function 'new_BuddyVector'.\n"
    "  Possible C/C++ prototypes are:\n"
    "    std::vector< pj::Buddy * >::vector()\n"
    "    std::vector< pj::Buddy * >::vector(std::vector< pj::Buddy * > const &)\n"
    "    std::vector< pj::Buddy * >::vector(std::vector< pj::Buddy * >::size_type)\n"
    "    std::vector< pj::Buddy * >::vector(std::vector< pj::Buddy * >::size_type,std::vector< pj::Buddy * >::value_type)\n");
  return 0;
}


SWIGINTERN PyObject *_wrap_BuddyVector_push_back(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  std::vector< pj::Buddy * > *arg1 = (std::vector< pj::Buddy * > *) 0 ;
  std::vector< pj::Buddy * >::value_type arg2 = (std::vector< pj::Buddy * >::value_type) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  void *argp2 = 0 ;
  int res2 = 0 ;
  PyObject *swig_obj[2] ;
  
  if (!SWIG_Python_UnpackTuple(args, "BuddyVector_push_back", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__vectorT_pj__Buddy_p_std__allocatorT_pj__Buddy_p_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "BuddyVector_push_back" "', argument " "1"" of type '" "std::vector< pj::Buddy * > *""'"); 
  }
  arg1 = reinterpret_cast< std::vector< pj::Buddy * > * >(argp1);
  res2 = SWIG_ConvertPtr(swig_obj[1], &argp2,SWIGTYPE_p_pj__Buddy, 0 |  0 );
  if (!SWIG_IsOK(res2)) {
    SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "BuddyVector_push_back" "', argument " "2"" of type '" "std::vector< pj::Buddy * >::value_type""'"); 
  }
  arg2 = reinterpret_cast< std::vector< pj::Buddy * >::value_type >(argp2);
  (arg1)->push_back(arg2);
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_BuddyVector_front(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  std::vector< pj::Buddy * > *arg1 = (std::vector< pj::Buddy * > *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  std::vector< pj::Buddy * >::value_type result;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__vectorT_pj__Buddy_p_std__allocatorT_pj__Buddy_p_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "BuddyVector_front" "', argument " "1"" of type '" "std::vector< pj::Buddy * > const *""'"); 
  }
  arg1 = reinterpret_cast< std::vector< pj::Buddy * > * >(argp1);
  result = (std::vector< pj::Buddy * >::value_type)((std::vector< pj::Buddy * > const *)arg1)->front();
  resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(result), SWIGTYPE_p_pj__Buddy, 0 |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_BuddyVector_back(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  std::vector< pj::Buddy * > *arg1 = (std::vector< pj::Buddy * > *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  std::vector< pj::Buddy * >::value_type result;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__vectorT_pj__Buddy_p_std__allocatorT_pj__Buddy_p_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "BuddyVector_back" "', argument " "1"" of type '" "std::vector< pj::Buddy * > const *""'"); 
  }
  arg1 = reinterpret_cast< std::vector< pj::Buddy * > * >(argp1);
  result = (std::vector< pj::Buddy * >::value_type)((std::vector< pj::Buddy * > const *)arg1)->back();
  resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(result), SWIGTYPE_p_pj__Buddy, 0 |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_BuddyVector_assign(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  std::vector< pj::Buddy * > *arg1 = (std::vector< pj::Buddy * > *) 0 ;
  std::vector< pj::Buddy * >::size_type arg2 ;
  std::vector< pj::Buddy * >::value_type arg3 = (std::vector< pj::Buddy * >::value_type) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  size_t val2 ;
  int ecode2 = 0 ;
  void *argp3 = 0 ;
  int res3 = 0 ;
  PyObject *swig_obj[3] ;
  
  if (!SWIG_Python_UnpackTuple(args, "BuddyVector_assign", 3, 3, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__vectorT_pj__Buddy_p_std__allocatorT_pj__Buddy_p_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "BuddyVector_assign" "', argument " "1"" of type '" "std::vector< pj::Buddy * > *""'"); 
  }
  arg1 = reinterpret_cast< std::vector< pj::Buddy * > * >(argp1);
  ecode2 = SWIG_AsVal_size_t(swig_obj[1], &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "BuddyVector_assign" "', argument " "2"" of type '" "std::vector< pj::Buddy * >::size_type""'");
  } 
  arg2 = static_cast< std::vector< pj::Buddy * >::size_type >(val2);
  res3 = SWIG_ConvertPtr(swig_obj[2], &argp3,SWIGTYPE_p_pj__Buddy, 0 |  0 );
  if (!SWIG_IsOK(res3)) {
    SWIG_exception_fail(SWIG_ArgError(res3), "in method '" "BuddyVector_assign" "', argument " "3"" of type '" "std::vector< pj::Buddy * >::value_type""'"); 
  }
  arg3 = reinterpret_cast< std::vector< pj::Buddy * >::value_type >(argp3);
  (arg1)->assign(arg2,arg3);
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_BuddyVector_resize__SWIG_1(PyObject *SWIGUNUSEDPARM(self), Py_ssize_t nobjs, PyObject **swig_obj) {
  PyObject *resultobj = 0;
  std::vector< pj::Buddy * > *arg1 = (std::vector< pj::Buddy * > *) 0 ;
  std::vector< pj::Buddy * >::size_type arg2 ;
  std::vector< pj::Buddy * >::value_type arg3 = (std::vector< pj::Buddy * >::value_type) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  size_t val2 ;
  int ecode2 = 0 ;
  void *argp3 = 0 ;
  int res3 = 0 ;
  
  if ((nobjs < 3) || (nobjs > 3)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__vectorT_pj__Buddy_p_std__allocatorT_pj__Buddy_p_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "BuddyVector_resize" "', argument " "1"" of type '" "std::vector< pj::Buddy * > *""'"); 
  }
  arg1 = reinterpret_cast< std::vector< pj::Buddy * > * >(argp1);
  ecode2 = SWIG_AsVal_size_t(swig_obj[1], &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "BuddyVector_resize" "', argument " "2"" of type '" "std::vector< pj::Buddy * >::size_type""'");
  } 
  arg2 = static_cast< std::vector< pj::Buddy * >::size_type >(val2);
  res3 = SWIG_ConvertPtr(swig_obj[2], &argp3,SWIGTYPE_p_pj__Buddy, 0 |  0 );
  if (!SWIG_IsOK(res3)) {
    SWIG_exception_fail(SWIG_ArgError(res3), "in method '" "BuddyVector_resize" "', argument " "3"" of type '" "std::vector< pj::Buddy * >::value_type""'"); 
  }
  arg3 = reinterpret_cast< std::vector< pj::Buddy * >::value_type >(argp3);
  (arg1)->resize(arg2,arg3);
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_BuddyVector_resize(PyObject *self, PyObject *args) {
  Py_ssize_t argc;
  PyObject *argv[4] = {
    0
  };
  
  if (!(argc = SWIG_Python_UnpackTuple(args, "BuddyVector_resize", 0, 3, argv))) SWIG_fail;
  --argc;
  if (argc == 2) {
    int _v;
    int res = swig::asptr(argv[0], (std::vector< pj::Buddy*,std::allocator< pj::Buddy * > >**)(0));
    _v = SWIG_CheckState(res);
    if (_v) {
      {
        int res = SWIG_AsVal_size_t(argv[1], NULL);
        _v = SWIG_CheckState(res);
      }
      if (_v) {
        return _wrap_BuddyVector_resize__SWIG_0(self, argc, argv);
      }
    }
  }
  if (argc == 3) {
    int _v;
    int res = swig::asptr(argv[0], (std::vector< pj::Buddy*,std::allocator< pj::Buddy * > >**)(0));
    _v = SWIG_CheckState(res);
    if (_v) {
      {
        int res = SWIG_AsVal_size_t(argv[1], NULL);
        _v = SWIG_CheckState(res);
      }
      if (_v) {
        void *vptr = 0;
        int res = SWIG_ConvertPtr(argv[2], &vptr, SWIGTYPE_p_pj__Buddy, 0);
        _v = SWIG_CheckState(res);
        if (_v) {
          return _wrap_BuddyVector_resize__SWIG_1(self, argc, argv);
        }
      }
    }
  }
  
fail:
  SWIG_Python_RaiseOrModifyTypeError("Wrong number or type of arguments for overloaded function 'BuddyVector_resize'.\n"
    "  Possible C/C++ prototypes are:\n"
    "    std::vector< pj::Buddy * >::resize(std::vector< pj::Buddy * >::size_type)\n"
    "    std::vector< pj::Buddy * >::resize(std::vector< pj::Buddy * >::size_type,std::vector< pj::Buddy * >::value_type)\n");
  return 0;
}


SWIGINTERN PyObject *_wrap_BuddyVector_insert__SWIG_0(PyObject *SWIGUNUSEDPARM(self), Py_ssize_t nobjs, PyObject **swig_obj) {
  PyObject *resultobj = 0;
  std::vector< pj::Buddy * > *arg1 = (std::vector< pj::Buddy * > *) 0 ;
  std::vector< pj::Buddy * >::iterator arg2 ;
  std::vector< pj::Buddy * >::value_type arg3 = (std::vector< pj::Buddy * >::value_type) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  swig::SwigPyIterator *iter2 = 0 ;
  int res2 ;
  void *argp3 = 0 ;
  int res3 = 0 ;
  std::vector< pj::Buddy * >::iterator result;
  
  if ((nobjs < 3) || (nobjs > 3)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__vectorT_pj__Buddy_p_std__allocatorT_pj__Buddy_p_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "BuddyVector_insert" "', argument " "1"" of type '" "std::vector< pj::Buddy * > *""'"); 
  }
  arg1 = reinterpret_cast< std::vector< pj::Buddy * > * >(argp1);
  res2 = SWIG_ConvertPtr(swig_obj[1], SWIG_as_voidptrptr(&iter2), swig::SwigPyIterator::descriptor(), 0);
  if (!SWIG_IsOK(res2) || !iter2) {
    SWIG_exception_fail(SWIG_ArgError(SWIG_TypeError), "in method '" "BuddyVector_insert" "', argument " "2"" of type '" "std::vector< pj::Buddy * >::iterator""'");
  } else {
    swig::SwigPyIterator_T<std::vector< pj::Buddy * >::iterator > *iter_t = dynamic_cast<swig::SwigPyIterator_T<std::vector< pj::Buddy * >::iterator > *>(iter2);
    if (iter_t) {
      arg2 = iter_t->get_current();
    } else {
      SWIG_exception_fail(SWIG_ArgError(SWIG_TypeError), "in method '" "BuddyVector_insert" "', argument " "2"" of type '" "std::vector< pj::Buddy * >::iterator""'");
    }
  }
  res3 = SWIG_ConvertPtr(swig_obj[2], &argp3,SWIGTYPE_p_pj__Buddy, 0 |  0 );
  if (!SWIG_IsOK(res3)) {
    SWIG_exception_fail(SWIG_ArgError(res3), "in method '" "BuddyVector_insert" "', argument " "3"" of type '" "std::vector< pj::Buddy * >::value_type""'"); 
  }
  arg3 = reinterpret_cast< std::vector< pj::Buddy * >::value_type >(argp3);
  result = std_vector_Sl_pj_Buddy_Sm__Sg__insert__SWIG_0(arg1,arg2,arg3);
  resultobj = SWIG_NewPointerObj(swig::make_output_iterator(static_cast< const std::vector< pj::Buddy * >::iterator & >(result)),
    swig::SwigPyIterator::descriptor(),SWIG_POINTER_OWN);
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_BuddyVector_insert__SWIG_1(PyObject *SWIGUNUSEDPARM(self), Py_ssize_t nobjs, PyObject **swig_obj) {
  PyObject *resultobj = 0;
  std::vector< pj::Buddy * > *arg1 = (std::vector< pj::Buddy * > *) 0 ;
  std::vector< pj::Buddy * >::iterator arg2 ;
  std::vector< pj::Buddy * >::size_type arg3 ;
  std::vector< pj::Buddy * >::value_type arg4 = (std::vector< pj::Buddy * >::value_type) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  swig::SwigPyIterator *iter2 = 0 ;
  int res2 ;
  size_t val3 ;
  int ecode3 = 0 ;
  void *argp4 = 0 ;
  int res4 = 0 ;
  
  if ((nobjs < 4) || (nobjs > 4)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__vectorT_pj__Buddy_p_std__allocatorT_pj__Buddy_p_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "BuddyVector_insert" "', argument " "1"" of type '" "std::vector< pj::Buddy * > *""'"); 
  }
  arg1 = reinterpret_cast< std::vector< pj::Buddy * > * >(argp1);
  res2 = SWIG_ConvertPtr(swig_obj[1], SWIG_as_voidptrptr(&iter2), swig::SwigPyIterator::descriptor(), 0);
  if (!SWIG_IsOK(res2) || !iter2) {
    SWIG_exception_fail(SWIG_ArgError(SWIG_TypeError), "in method '" "BuddyVector_insert" "', argument " "2"" of type '" "std::vector< pj::Buddy * >::iterator""'");
  } else {
    swig::SwigPyIterator_T<std::vector< pj::Buddy * >::iterator > *iter_t = dynamic_cast<swig::SwigPyIterator_T<std::vector< pj::Buddy * >::iterator > *>(iter2);
    if (iter_t) {
      arg2 = iter_t->get_current();
    } else {
      SWIG_exception_fail(SWIG_ArgError(SWIG_TypeError), "in method '" "BuddyVector_insert" "', argument " "2"" of type '" "std::vector< pj::Buddy * >::iterator""'");
    }
  }
  ecode3 = SWIG_AsVal_size_t(swig_obj[2], &val3);
  if (!SWIG_IsOK(ecode3)) {
    SWIG_exception_fail(SWIG_ArgError(ecode3), "in method '" "BuddyVector_insert" "', argument " "3"" of type '" "std::vector< pj::Buddy * >::size_type""'");
  } 
  arg3 = static_cast< std::vector< pj::Buddy * >::size_type >(val3);
  res4 = SWIG_ConvertPtr(swig_obj[3], &argp4,SWIGTYPE_p_pj__Buddy, 0 |  0 );
  if (!SWIG_IsOK(res4)) {
    SWIG_exception_fail(SWIG_ArgError(res4), "in method '" "BuddyVector_insert" "', argument " "4"" of type '" "std::vector< pj::Buddy * >::value_type""'"); 
  }
  arg4 = reinterpret_cast< std::vector< pj::Buddy * >::value_type >(argp4);
  std_vector_Sl_pj_Buddy_Sm__Sg__insert__SWIG_1(arg1,arg2,arg3,arg4);
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_BuddyVector_insert(PyObject *self, PyObject *args) {
  Py_ssize_t argc;
  PyObject *argv[5] = {
    0
  };
  
  if (!(argc = SWIG_Python_UnpackTuple(args, "BuddyVector_insert", 0, 4, argv))) SWIG_fail;
  --argc;
  if (argc == 3) {
    int _v;
    int res = swig::asptr(argv[0], (std::vector< pj::Buddy*,std::allocator< pj::Buddy * > >**)(0));
    _v = SWIG_CheckState(res);
    if (_v) {
      swig::SwigPyIterator *iter = 0;
      int res = SWIG_ConvertPtr(argv[1], SWIG_as_voidptrptr(&iter), swig::SwigPyIterator::descriptor(), 0);
      _v = (SWIG_IsOK(res) && iter && (dynamic_cast<swig::SwigPyIterator_T<std::vector< pj::Buddy * >::iterator > *>(iter) != 0));
      if (_v) {
        void *vptr = 0;
        int res = SWIG_ConvertPtr(argv[2], &vptr, SWIGTYPE_p_pj__Buddy, 0);
        _v = SWIG_CheckState(res);
        if (_v) {
          return _wrap_BuddyVector_insert__SWIG_0(self, argc, argv);
        }
      }
    }
  }
  if (argc == 4) {
    int _v;
    int res = swig::asptr(argv[0], (std::vector< pj::Buddy*,std::allocator< pj::Buddy * > >**)(0));
    _v = SWIG_CheckState(res);
    if (_v) {
      swig::SwigPyIterator *iter = 0;
      int res = SWIG_ConvertPtr(argv[1], SWIG_as_voidptrptr(&iter), swig::SwigPyIterator::descriptor(), 0);
      _v = (SWIG_IsOK(res) && iter && (dynamic_cast<swig::SwigPyIterator_T<std::vector< pj::Buddy * >::iterator > *>(iter) != 0));
      if (_v) {
        {
          int res = SWIG_AsVal_size_t(argv[2], NULL);
          _v = SWIG_CheckState(res);
        }
        if (_v) {
          void *vptr = 0;
          int res = SWIG_ConvertPtr(argv[3], &vptr, SWIGTYPE_p_pj__Buddy, 0);
          _v = SWIG_CheckState(res);
          if (_v) {
            return _wrap_BuddyVector_insert__SWIG_1(self, argc, argv);
          }
        }
      }
    }
  }
  
fail:
  SWIG_Python_RaiseOrModifyTypeError("Wrong number or type of arguments for overloaded function 'BuddyVector_insert'.\n"
    "  Possible C/C++ prototypes are:\n"
    "    std::vector< pj::Buddy * >::insert(std::vector< pj::Buddy * >::iterator,std::vector< pj::Buddy * >::value_type)\n"
    "    std::vector< pj::Buddy * >::insert(std::vector< pj::Buddy * >::iterator,std::vector< pj::Buddy * >::size_type,std::vector< pj::Buddy * >::value_type)\n");
  return 0;
}


SWIGINTERN PyObject *_wrap_BuddyVector_reserve(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  std::vector< pj::Buddy * > *arg1 = (std::vector< pj::Buddy * > *) 0 ;
  std::vector< pj::Buddy * >::size_type arg2 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  size_t val2 ;
  int ecode2 = 0 ;
  PyObject *swig_obj[2] ;
  
  if (!SWIG_Python_UnpackTuple(args, "BuddyVector_reserve", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__vectorT_pj__Buddy_p_std__allocatorT_pj__Buddy_p_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "BuddyVector_reserve" "', argument " "1"" of type '" "std::vector< pj::Buddy * > *""'"); 
  }
  arg1 = reinterpret_cast< std::vector< pj::Buddy * > * >(argp1);
  ecode2 = SWIG_AsVal_size_t(swig_obj[1], &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "BuddyVector_reserve" "', argument " "2"" of type '" "std::vector< pj::Buddy * >::size_type""'");
  } 
  arg2 = static_cast< std::vector< pj::Buddy * >::size_type >(val2);
  (arg1)->reserve(arg2);
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_BuddyVector_capacity(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  std::vector< pj::Buddy * > *arg1 = (std::vector< pj::Buddy * > *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  std::vector< pj::Buddy * >::size_type result;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__vectorT_pj__Buddy_p_std__allocatorT_pj__Buddy_p_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "BuddyVector_capacity" "', argument " "1"" of type '" "std::vector< pj::Buddy * > const *""'"); 
  }
  arg1 = reinterpret_cast< std::vector< pj::Buddy * > * >(argp1);
  result = ((std::vector< pj::Buddy * > const *)arg1)->capacity();
  resultobj = SWIG_From_size_t(static_cast< size_t >(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_delete_BuddyVector(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  std::vector< pj::Buddy * > *arg1 = (std::vector< pj::Buddy * > *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__vectorT_pj__Buddy_p_std__allocatorT_pj__Buddy_p_t_t, SWIG_POINTER_DISOWN |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "delete_BuddyVector" "', argument " "1"" of type '" "std::vector< pj::Buddy * > *""'"); 
  }
  arg1 = reinterpret_cast< std::vector< pj::Buddy * > * >(argp1);
  delete arg1;
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *BuddyVector_swigregister(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *obj;
  if (!SWIG_Python_UnpackTuple(args, "swigregister", 1, 1, &obj)) return NULL;
  SWIG_TypeNewClientData(SWIGTYPE_p_std__vectorT_pj__Buddy_p_std__allocatorT_pj__Buddy_p_t_t, SWIG_NewClientData(obj));
  return SWIG_Py_Void();
}

SWIGINTERN PyObject *BuddyVector_swiginit(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  return SWIG_Python_InitShadowInstance(args);
}

SWIGINTERN PyObject *_wrap_BuddyVector2_iterator(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  std::vector< pj::Buddy > *arg1 = (std::vector< pj::Buddy > *) 0 ;
  PyObject **arg2 = (PyObject **) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  swig::SwigPyIterator *result = 0 ;
  
  arg2 = &swig_obj[0];
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__vectorT_pj__Buddy_std__allocatorT_pj__Buddy_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "BuddyVector2_iterator" "', argument " "1"" of type '" "std::vector< pj::Buddy > *""'"); 
  }
  arg1 = reinterpret_cast< std::vector< pj::Buddy > * >(argp1);
  result = (swig::SwigPyIterator *)std_vector_Sl_pj_Buddy_Sg__iterator(arg1,arg2);
  resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(result), SWIGTYPE_p_swig__SwigPyIterator, SWIG_POINTER_OWN |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_BuddyVector2___nonzero__(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  std::vector< pj::Buddy > *arg1 = (std::vector< pj::Buddy > *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  bool result;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__vectorT_pj__Buddy_std__allocatorT_pj__Buddy_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "BuddyVector2___nonzero__" "', argument " "1"" of type '" "std::vector< pj::Buddy > const *""'"); 
  }
  arg1 = reinterpret_cast< std::vector< pj::Buddy > * >(argp1);
  result = (bool)std_vector_Sl_pj_Buddy_Sg____nonzero__((std::vector< pj::Buddy > const *)arg1);
  resultobj = SWIG_From_bool(static_cast< bool >(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_BuddyVector2___bool__(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  std::vector< pj::Buddy > *arg1 = (std::vector< pj::Buddy > *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  bool result;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__vectorT_pj__Buddy_std__allocatorT_pj__Buddy_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "BuddyVector2___bool__" "', argument " "1"" of type '" "std::vector< pj::Buddy > const *""'"); 
  }
  arg1 = reinterpret_cast< std::vector< pj::Buddy > * >(argp1);
  result = (bool)std_vector_Sl_pj_Buddy_Sg____bool__((std::vector< pj::Buddy > const *)arg1);
  resultobj = SWIG_From_bool(static_cast< bool >(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_BuddyVector2___len__(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  std::vector< pj::Buddy > *arg1 = (std::vector< pj::Buddy > *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  std::vector< pj::Buddy >::size_type result;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__vectorT_pj__Buddy_std__allocatorT_pj__Buddy_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "BuddyVector2___len__" "', argument " "1"" of type '" "std::vector< pj::Buddy > const *""'"); 
  }
  arg1 = reinterpret_cast< std::vector< pj::Buddy > * >(argp1);
  result = std_vector_Sl_pj_Buddy_Sg____len__((std::vector< pj::Buddy > const *)arg1);
  resultobj = SWIG_From_size_t(static_cast< size_t >(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_BuddyVector2___getslice__(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  std::vector< pj::Buddy > *arg1 = (std::vector< pj::Buddy > *) 0 ;
  std::vector< pj::Buddy >::difference_type arg2 ;
  std::vector< pj::Buddy >::difference_type arg3 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  ptrdiff_t val2 ;
  int ecode2 = 0 ;
  ptrdiff_t val3 ;
  int ecode3 = 0 ;
  PyObject *swig_obj[3] ;
  std::vector< pj::Buddy,std::allocator< pj::Buddy > > *result = 0 ;
  
  if (!SWIG_Python_UnpackTuple(args, "BuddyVector2___getslice__", 3, 3, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__vectorT_pj__Buddy_std__allocatorT_pj__Buddy_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "BuddyVector2___getslice__" "', argument " "1"" of type '" "std::vector< pj::Buddy > *""'"); 
  }
  arg1 = reinterpret_cast< std::vector< pj::Buddy > * >(argp1);
  ecode2 = SWIG_AsVal_ptrdiff_t(swig_obj[1], &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "BuddyVector2___getslice__" "', argument " "2"" of type '" "std::vector< pj::Buddy >::difference_type""'");
  } 
  arg2 = static_cast< std::vector< pj::Buddy >::difference_type >(val2);
  ecode3 = SWIG_AsVal_ptrdiff_t(swig_obj[2], &val3);
  if (!SWIG_IsOK(ecode3)) {
    SWIG_exception_fail(SWIG_ArgError(ecode3), "in method '" "BuddyVector2___getslice__" "', argument " "3"" of type '" "std::vector< pj::Buddy >::difference_type""'");
  } 
  arg3 = static_cast< std::vector< pj::Buddy >::difference_type >(val3);
  try {
    result = (std::vector< pj::Buddy,std::allocator< pj::Buddy > > *)std_vector_Sl_pj_Buddy_Sg____getslice__(arg1,arg2,arg3);
  } catch(std::out_of_range &_e) {
    SWIG_exception_fail(SWIG_IndexError, (&_e)->what());
  } catch(std::invalid_argument &_e) {
    SWIG_exception_fail(SWIG_ValueError, (&_e)->what());
  }
  resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(result), SWIGTYPE_p_std__vectorT_pj__Buddy_std__allocatorT_pj__Buddy_t_t, SWIG_POINTER_OWN |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_BuddyVector2___setslice____SWIG_0(PyObject *SWIGUNUSEDPARM(self), Py_ssize_t nobjs, PyObject **swig_obj) {
  PyObject *resultobj = 0;
  std::vector< pj::Buddy > *arg1 = (std::vector< pj::Buddy > *) 0 ;
  std::vector< pj::Buddy >::difference_type arg2 ;
  std::vector< pj::Buddy >::difference_type arg3 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  ptrdiff_t val2 ;
  int ecode2 = 0 ;
  ptrdiff_t val3 ;
  int ecode3 = 0 ;
  
  if ((nobjs < 3) || (nobjs > 3)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__vectorT_pj__Buddy_std__allocatorT_pj__Buddy_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "BuddyVector2___setslice__" "', argument " "1"" of type '" "std::vector< pj::Buddy > *""'"); 
  }
  arg1 = reinterpret_cast< std::vector< pj::Buddy > * >(argp1);
  ecode2 = SWIG_AsVal_ptrdiff_t(swig_obj[1], &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "BuddyVector2___setslice__" "', argument " "2"" of type '" "std::vector< pj::Buddy >::difference_type""'");
  } 
  arg2 = static_cast< std::vector< pj::Buddy >::difference_type >(val2);
  ecode3 = SWIG_AsVal_ptrdiff_t(swig_obj[2], &val3);
  if (!SWIG_IsOK(ecode3)) {
    SWIG_exception_fail(SWIG_ArgError(ecode3), "in method '" "BuddyVector2___setslice__" "', argument " "3"" of type '" "std::vector< pj::Buddy >::difference_type""'");
  } 
  arg3 = static_cast< std::vector< pj::Buddy >::difference_type >(val3);
  try {
    std_vector_Sl_pj_Buddy_Sg____setslice____SWIG_0(arg1,arg2,arg3);
  } catch(std::out_of_range &_e) {
    SWIG_exception_fail(SWIG_IndexError, (&_e)->what());
  } catch(std::invalid_argument &_e) {
    SWIG_exception_fail(SWIG_ValueError, (&_e)->what());
  }
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_BuddyVector2___setslice____SWIG_1(PyObject *SWIGUNUSEDPARM(self), Py_ssize_t nobjs, PyObject **swig_obj) {
  PyObject *resultobj = 0;
  std::vector< pj::Buddy > *arg1 = (std::vector< pj::Buddy > *) 0 ;
  std::vector< pj::Buddy >::difference_type arg2 ;
  std::vector< pj::Buddy >::difference_type arg3 ;
  std::vector< pj::Buddy,std::allocator< pj::Buddy > > *arg4 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  ptrdiff_t val2 ;
  int ecode2 = 0 ;
  ptrdiff_t val3 ;
  int ecode3 = 0 ;
  int res4 = SWIG_OLDOBJ ;
  
  if ((nobjs < 4) || (nobjs > 4)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__vectorT_pj__Buddy_std__allocatorT_pj__Buddy_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "BuddyVector2___setslice__" "', argument " "1"" of type '" "std::vector< pj::Buddy > *""'"); 
  }
  arg1 = reinterpret_cast< std::vector< pj::Buddy > * >(argp1);
  ecode2 = SWIG_AsVal_ptrdiff_t(swig_obj[1], &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "BuddyVector2___setslice__" "', argument " "2"" of type '" "std::vector< pj::Buddy >::difference_type""'");
  } 
  arg2 = static_cast< std::vector< pj::Buddy >::difference_type >(val2);
  ecode3 = SWIG_AsVal_ptrdiff_t(swig_obj[2], &val3);
  if (!SWIG_IsOK(ecode3)) {
    SWIG_exception_fail(SWIG_ArgError(ecode3), "in method '" "BuddyVector2___setslice__" "', argument " "3"" of type '" "std::vector< pj::Buddy >::difference_type""'");
  } 
  arg3 = static_cast< std::vector< pj::Buddy >::difference_type >(val3);
  {
    std::vector< pj::Buddy,std::allocator< pj::Buddy > > *ptr = (std::vector< pj::Buddy,std::allocator< pj::Buddy > > *)0;
    res4 = swig::asptr(swig_obj[3], &ptr);
    if (!SWIG_IsOK(res4)) {
      SWIG_exception_fail(SWIG_ArgError(res4), "in method '" "BuddyVector2___setslice__" "', argument " "4"" of type '" "std::vector< pj::Buddy,std::allocator< pj::Buddy > > const &""'"); 
    }
    if (!ptr) {
      SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "BuddyVector2___setslice__" "', argument " "4"" of type '" "std::vector< pj::Buddy,std::allocator< pj::Buddy > > const &""'"); 
    }
    arg4 = ptr;
  }
  try {
    std_vector_Sl_pj_Buddy_Sg____setslice____SWIG_1(arg1,arg2,arg3,(std::vector< pj::Buddy,std::allocator< pj::Buddy > > const &)*arg4);
  } catch(std::out_of_range &_e) {
    SWIG_exception_fail(SWIG_IndexError, (&_e)->what());
  } catch(std::invalid_argument &_e) {
    SWIG_exception_fail(SWIG_ValueError, (&_e)->what());
  }
  resultobj = SWIG_Py_Void();
  if (SWIG_IsNewObj(res4)) delete arg4;
  return resultobj;
fail:
  if (SWIG_IsNewObj(res4)) delete arg4;
  return NULL;
}


SWIGINTERN PyObject *_wrap_BuddyVector2___setslice__(PyObject *self, PyObject *args) {
  Py_ssize_t argc;
  PyObject *argv[5] = {
    0
  };
  
  if (!(argc = SWIG_Python_UnpackTuple(args, "BuddyVector2___setslice__", 0, 4, argv))) SWIG_fail;
  --argc;
  if (argc == 3) {
    int _v;
    int res = swig::asptr(argv[0], (std::vector< pj::Buddy,std::allocator< pj::Buddy > >**)(0));
    _v = SWIG_CheckState(res);
    if (_v) {
      {
        int res = SWIG_AsVal_ptrdiff_t(argv[1], NULL);
        _v = SWIG_CheckState(res);
      }
      if (_v) {
        {
          int res = SWIG_AsVal_ptrdiff_t(argv[2], NULL);
          _v = SWIG_CheckState(res);
        }
        if (_v) {
          return _wrap_BuddyVector2___setslice____SWIG_0(self, argc, argv);
        }
      }
    }
  }
  if (argc == 4) {
    int _v;
    int res = swig::asptr(argv[0], (std::vector< pj::Buddy,std::allocator< pj::Buddy > >**)(0));
    _v = SWIG_CheckState(res);
    if (_v) {
      {
        int res = SWIG_AsVal_ptrdiff_t(argv[1], NULL);
        _v = SWIG_CheckState(res);
      }
      if (_v) {
        {
          int res = SWIG_AsVal_ptrdiff_t(argv[2], NULL);
          _v = SWIG_CheckState(res);
        }
        if (_v) {
          int res = swig::asptr(argv[3], (std::vector< pj::Buddy,std::allocator< pj::Buddy > >**)(0));
          _v = SWIG_CheckState(res);
          if (_v) {
            return _wrap_BuddyVector2___setslice____SWIG_1(self, argc, argv);
          }
        }
      }
    }
  }
  
fail:
  SWIG_Python_RaiseOrModifyTypeError("Wrong number or type of arguments for overloaded function 'BuddyVector2___setslice__'.\n"
    "  Possible C/C++ prototypes are:\n"
    "    std::vector< pj::Buddy >::__setslice__(std::vector< pj::Buddy >::difference_type,std::vector< pj::Buddy >::difference_type)\n"
    "    std::vector< pj::Buddy >::__setslice__(std::vector< pj::Buddy >::difference_type,std::vector< pj::Buddy >::difference_type,std::vector< pj::Buddy,std::allocator< pj::Buddy > > const &)\n");
  return 0;
}


SWIGINTERN PyObject *_wrap_BuddyVector2___delslice__(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  std::vector< pj::Buddy > *arg1 = (std::vector< pj::Buddy > *) 0 ;
  std::vector< pj::Buddy >::difference_type arg2 ;
  std::vector< pj::Buddy >::difference_type arg3 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  ptrdiff_t val2 ;
  int ecode2 = 0 ;
  ptrdiff_t val3 ;
  int ecode3 = 0 ;
  PyObject *swig_obj[3] ;
  
  if (!SWIG_Python_UnpackTuple(args, "BuddyVector2___delslice__", 3, 3, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__vectorT_pj__Buddy_std__allocatorT_pj__Buddy_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "BuddyVector2___delslice__" "', argument " "1"" of type '" "std::vector< pj::Buddy > *""'"); 
  }
  arg1 = reinterpret_cast< std::vector< pj::Buddy > * >(argp1);
  ecode2 = SWIG_AsVal_ptrdiff_t(swig_obj[1], &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "BuddyVector2___delslice__" "', argument " "2"" of type '" "std::vector< pj::Buddy >::difference_type""'");
  } 
  arg2 = static_cast< std::vector< pj::Buddy >::difference_type >(val2);
  ecode3 = SWIG_AsVal_ptrdiff_t(swig_obj[2], &val3);
  if (!SWIG_IsOK(ecode3)) {
    SWIG_exception_fail(SWIG_ArgError(ecode3), "in method '" "BuddyVector2___delslice__" "', argument " "3"" of type '" "std::vector< pj::Buddy >::difference_type""'");
  } 
  arg3 = static_cast< std::vector< pj::Buddy >::difference_type >(val3);
  try {
    std_vector_Sl_pj_Buddy_Sg____delslice__(arg1,arg2,arg3);
  } catch(std::out_of_range &_e) {
    SWIG_exception_fail(SWIG_IndexError, (&_e)->what());
  } catch(std::invalid_argument &_e) {
    SWIG_exception_fail(SWIG_ValueError, (&_e)->what());
  }
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_BuddyVector2___delitem____SWIG_0(PyObject *SWIGUNUSEDPARM(self), Py_ssize_t nobjs, PyObject **swig_obj) {
  PyObject *resultobj = 0;
  std::vector< pj::Buddy > *arg1 = (std::vector< pj::Buddy > *) 0 ;
  std::vector< pj::Buddy >::difference_type arg2 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  ptrdiff_t val2 ;
  int ecode2 = 0 ;
  
  if ((nobjs < 2) || (nobjs > 2)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__vectorT_pj__Buddy_std__allocatorT_pj__Buddy_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "BuddyVector2___delitem__" "', argument " "1"" of type '" "std::vector< pj::Buddy > *""'"); 
  }
  arg1 = reinterpret_cast< std::vector< pj::Buddy > * >(argp1);
  ecode2 = SWIG_AsVal_ptrdiff_t(swig_obj[1], &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "BuddyVector2___delitem__" "', argument " "2"" of type '" "std::vector< pj::Buddy >::difference_type""'");
  } 
  arg2 = static_cast< std::vector< pj::Buddy >::difference_type >(val2);
  try {
    std_vector_Sl_pj_Buddy_Sg____delitem____SWIG_0(arg1,arg2);
  } catch(std::out_of_range &_e) {
    SWIG_exception_fail(SWIG_IndexError, (&_e)->what());
  } catch(std::invalid_argument &_e) {
    SWIG_exception_fail(SWIG_ValueError, (&_e)->what());
  }
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_BuddyVector2___getitem____SWIG_0(PyObject *SWIGUNUSEDPARM(self), Py_ssize_t nobjs, PyObject **swig_obj) {
  PyObject *resultobj = 0;
  std::vector< pj::Buddy > *arg1 = (std::vector< pj::Buddy > *) 0 ;
  PySliceObject *arg2 = (PySliceObject *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  std::vector< pj::Buddy,std::allocator< pj::Buddy > > *result = 0 ;
  
  if ((nobjs < 2) || (nobjs > 2)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__vectorT_pj__Buddy_std__allocatorT_pj__Buddy_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "BuddyVector2___getitem__" "', argument " "1"" of type '" "std::vector< pj::Buddy > *""'"); 
  }
  arg1 = reinterpret_cast< std::vector< pj::Buddy > * >(argp1);
  {
    if (!PySlice_Check(swig_obj[1])) {
      SWIG_exception_fail(SWIG_ArgError(SWIG_TypeError), "in method '" "BuddyVector2___getitem__" "', argument " "2"" of type '" "PySliceObject *""'");
    }
    arg2 = (PySliceObject *) swig_obj[1];
  }
  try {
    result = (std::vector< pj::Buddy,std::allocator< pj::Buddy > > *)std_vector_Sl_pj_Buddy_Sg____getitem____SWIG_0(arg1,arg2);
  } catch(std::out_of_range &_e) {
    SWIG_exception_fail(SWIG_IndexError, (&_e)->what());
  } catch(std::invalid_argument &_e) {
    SWIG_exception_fail(SWIG_ValueError, (&_e)->what());
  }
  resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(result), SWIGTYPE_p_std__vectorT_pj__Buddy_std__allocatorT_pj__Buddy_t_t, SWIG_POINTER_OWN |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_BuddyVector2___setitem____SWIG_0(PyObject *SWIGUNUSEDPARM(self), Py_ssize_t nobjs, PyObject **swig_obj) {
  PyObject *resultobj = 0;
  std::vector< pj::Buddy > *arg1 = (std::vector< pj::Buddy > *) 0 ;
  PySliceObject *arg2 = (PySliceObject *) 0 ;
  std::vector< pj::Buddy,std::allocator< pj::Buddy > > *arg3 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  int res3 = SWIG_OLDOBJ ;
  
  if ((nobjs < 3) || (nobjs > 3)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__vectorT_pj__Buddy_std__allocatorT_pj__Buddy_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "BuddyVector2___setitem__" "', argument " "1"" of type '" "std::vector< pj::Buddy > *""'"); 
  }
  arg1 = reinterpret_cast< std::vector< pj::Buddy > * >(argp1);
  {
    if (!PySlice_Check(swig_obj[1])) {
      SWIG_exception_fail(SWIG_ArgError(SWIG_TypeError), "in method '" "BuddyVector2___setitem__" "', argument " "2"" of type '" "PySliceObject *""'");
    }
    arg2 = (PySliceObject *) swig_obj[1];
  }
  {
    std::vector< pj::Buddy,std::allocator< pj::Buddy > > *ptr = (std::vector< pj::Buddy,std::allocator< pj::Buddy > > *)0;
    res3 = swig::asptr(swig_obj[2], &ptr);
    if (!SWIG_IsOK(res3)) {
      SWIG_exception_fail(SWIG_ArgError(res3), "in method '" "BuddyVector2___setitem__" "', argument " "3"" of type '" "std::vector< pj::Buddy,std::allocator< pj::Buddy > > const &""'"); 
    }
    if (!ptr) {
      SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "BuddyVector2___setitem__" "', argument " "3"" of type '" "std::vector< pj::Buddy,std::allocator< pj::Buddy > > const &""'"); 
    }
    arg3 = ptr;
  }
  try {
    std_vector_Sl_pj_Buddy_Sg____setitem____SWIG_0(arg1,arg2,(std::vector< pj::Buddy,std::allocator< pj::Buddy > > const &)*arg3);
  } catch(std::out_of_range &_e) {
    SWIG_exception_fail(SWIG_IndexError, (&_e)->what());
  } catch(std::invalid_argument &_e) {
    SWIG_exception_fail(SWIG_ValueError, (&_e)->what());
  }
  resultobj = SWIG_Py_Void();
  if (SWIG_IsNewObj(res3)) delete arg3;
  return resultobj;
fail:
  if (SWIG_IsNewObj(res3)) delete arg3;
  return NULL;
}


SWIGINTERN PyObject *_wrap_BuddyVector2___setitem____SWIG_1(PyObject *SWIGUNUSEDPARM(self), Py_ssize_t nobjs, PyObject **swig_obj) {
  PyObject *resultobj = 0;
  std::vector< pj::Buddy > *arg1 = (std::vector< pj::Buddy > *) 0 ;
  PySliceObject *arg2 = (PySliceObject *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  
  if ((nobjs < 2) || (nobjs > 2)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__vectorT_pj__Buddy_std__allocatorT_pj__Buddy_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "BuddyVector2___setitem__" "', argument " "1"" of type '" "std::vector< pj::Buddy > *""'"); 
  }
  arg1 = reinterpret_cast< std::vector< pj::Buddy > * >(argp1);
  {
    if (!PySlice_Check(swig_obj[1])) {
      SWIG_exception_fail(SWIG_ArgError(SWIG_TypeError), "in method '" "BuddyVector2___setitem__" "', argument " "2"" of type '" "PySliceObject *""'");
    }
    arg2 = (PySliceObject *) swig_obj[1];
  }
  try {
    std_vector_Sl_pj_Buddy_Sg____setitem____SWIG_1(arg1,arg2);
  } catch(std::out_of_range &_e) {
    SWIG_exception_fail(SWIG_IndexError, (&_e)->what());
  } catch(std::invalid_argument &_e) {
    SWIG_exception_fail(SWIG_ValueError, (&_e)->what());
  }
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_BuddyVector2___delitem____SWIG_1(PyObject *SWIGUNUSEDPARM(self), Py_ssize_t nobjs, PyObject **swig_obj) {
  PyObject *resultobj = 0;
  std::vector< pj::Buddy > *arg1 = (std::vector< pj::Buddy > *) 0 ;
  PySliceObject *arg2 = (PySliceObject *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  
  if ((nobjs < 2) || (nobjs > 2)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__vectorT_pj__Buddy_std__allocatorT_pj__Buddy_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "BuddyVector2___delitem__" "', argument " "1"" of type '" "std::vector< pj::Buddy > *""'"); 
  }
  arg1 = reinterpret_cast< std::vector< pj::Buddy > * >(argp1);
  {
    if (!PySlice_Check(swig_obj[1])) {
      SWIG_exception_fail(SWIG_ArgError(SWIG_TypeError), "in method '" "BuddyVector2___delitem__" "', argument " "2"" of type '" "PySliceObject *""'");
    }
    arg2 = (PySliceObject *) swig_obj[1];
  }
  try {
    std_vector_Sl_pj_Buddy_Sg____delitem____SWIG_1(arg1,arg2);
  } catch(std::out_of_range &_e) {
    SWIG_exception_fail(SWIG_IndexError, (&_e)->what());
  } catch(std::invalid_argument &_e) {
    SWIG_exception_fail(SWIG_ValueError, (&_e)->what());
  }
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_BuddyVector2___delitem__(PyObject *self, PyObject *args) {
  Py_ssize_t argc;
  PyObject *argv[3] = {
    0
  };
  
  if (!(argc = SWIG_Python_UnpackTuple(args, "BuddyVector2___delitem__", 0, 2, argv))) SWIG_fail;
  --argc;
  if (argc == 2) {
    int _v;
    int res = swig::asptr(argv[0], (std::vector< pj::Buddy,std::allocator< pj::Buddy > >**)(0));
    _v = SWIG_CheckState(res);
    if (_v) {
      {
        _v = PySlice_Check(argv[1]);
      }
      if (_v) {
        return _wrap_BuddyVector2___delitem____SWIG_1(self, argc, argv);
      }
    }
  }
  if (argc == 2) {
    int _v;
    int res = swig::asptr(argv[0], (std::vector< pj::Buddy,std::allocator< pj::Buddy > >**)(0));
    _v = SWIG_CheckState(res);
    if (_v) {
      {
        int res = SWIG_AsVal_ptrdiff_t(argv[1], NULL);
        _v = SWIG_CheckState(res);
      }
      if (_v) {
        return _wrap_BuddyVector2___delitem____SWIG_0(self, argc, argv);
      }
    }
  }
  
fail:
  SWIG_Python_RaiseOrModifyTypeError("Wrong number or type of arguments for overloaded function 'BuddyVector2___delitem__'.\n"
    "  Possible C/C++ prototypes are:\n"
    "    std::vector< pj::Buddy >::__delitem__(std::vector< pj::Buddy >::difference_type)\n"
    "    std::vector< pj::Buddy >::__delitem__(PySliceObject *)\n");
  return 0;
}


SWIGINTERN PyObject *_wrap_BuddyVector2___getitem____SWIG_1(PyObject *SWIGUNUSEDPARM(self), Py_ssize_t nobjs, PyObject **swig_obj) {
  PyObject *resultobj = 0;
  std::vector< pj::Buddy > *arg1 = (std::vector< pj::Buddy > *) 0 ;
  std::vector< pj::Buddy >::difference_type arg2 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  ptrdiff_t val2 ;
  int ecode2 = 0 ;
  std::vector< pj::Buddy >::value_type *result = 0 ;
  
  if ((nobjs < 2) || (nobjs > 2)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__vectorT_pj__Buddy_std__allocatorT_pj__Buddy_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "BuddyVector2___getitem__" "', argument " "1"" of type '" "std::vector< pj::Buddy > const *""'"); 
  }
  arg1 = reinterpret_cast< std::vector< pj::Buddy > * >(argp1);
  ecode2 = SWIG_AsVal_ptrdiff_t(swig_obj[1], &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "BuddyVector2___getitem__" "', argument " "2"" of type '" "std::vector< pj::Buddy >::difference_type""'");
  } 
  arg2 = static_cast< std::vector< pj::Buddy >::difference_type >(val2);
  try {
    result = (std::vector< pj::Buddy >::value_type *) &std_vector_Sl_pj_Buddy_Sg____getitem____SWIG_1((std::vector< pj::Buddy > const *)arg1,arg2);
  } catch(std::out_of_range &_e) {
    SWIG_exception_fail(SWIG_IndexError, (&_e)->what());
  }
  resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(result), SWIGTYPE_p_pj__Buddy, 0 |  0 );
  (void)swig::container_owner<swig::traits<std::vector< pj::Buddy >::value_type>::category>::back_reference(resultobj, swig_obj[0]);
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_BuddyVector2___getitem__(PyObject *self, PyObject *args) {
  Py_ssize_t argc;
  PyObject *argv[3] = {
    0
  };
  
  if (!(argc = SWIG_Python_UnpackTuple(args, "BuddyVector2___getitem__", 0, 2, argv))) SWIG_fail;
  --argc;
  if (argc == 2) {
    int _v;
    int res = swig::asptr(argv[0], (std::vector< pj::Buddy,std::allocator< pj::Buddy > >**)(0));
    _v = SWIG_CheckState(res);
    if (_v) {
      {
        _v = PySlice_Check(argv[1]);
      }
      if (_v) {
        return _wrap_BuddyVector2___getitem____SWIG_0(self, argc, argv);
      }
    }
  }
  if (argc == 2) {
    int _v;
    int res = swig::asptr(argv[0], (std::vector< pj::Buddy,std::allocator< pj::Buddy > >**)(0));
    _v = SWIG_CheckState(res);
    if (_v) {
      {
        int res = SWIG_AsVal_ptrdiff_t(argv[1], NULL);
        _v = SWIG_CheckState(res);
      }
      if (_v) {
        return _wrap_BuddyVector2___getitem____SWIG_1(self, argc, argv);
      }
    }
  }
  
fail:
  SWIG_Python_RaiseOrModifyTypeError("Wrong number or type of arguments for overloaded function 'BuddyVector2___getitem__'.\n"
    "  Possible C/C++ prototypes are:\n"
    "    std::vector< pj::Buddy >::__getitem__(PySliceObject *)\n"
    "    std::vector< pj::Buddy >::__getitem__(std::vector< pj::Buddy >::difference_type) const\n");
  return 0;
}


SWIGINTERN PyObject *_wrap_BuddyVector2___setitem____SWIG_2(PyObject *SWIGUNUSEDPARM(self), Py_ssize_t nobjs, PyObject **swig_obj) {
  PyObject *resultobj = 0;
  std::vector< pj::Buddy > *arg1 = (std::vector< pj::Buddy > *) 0 ;
  std::vector< pj::Buddy >::difference_type arg2 ;
  std::vector< pj::Buddy >::value_type *arg3 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  ptrdiff_t val2 ;
  int ecode2 = 0 ;
  void *argp3 = 0 ;
  int res3 = 0 ;
  
  if ((nobjs < 3) || (nobjs > 3)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__vectorT_pj__Buddy_std__allocatorT_pj__Buddy_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "BuddyVector2___setitem__" "', argument " "1"" of type '" "std::vector< pj::Buddy > *""'"); 
  }
  arg1 = reinterpret_cast< std::vector< pj::Buddy > * >(argp1);
  ecode2 = SWIG_AsVal_ptrdiff_t(swig_obj[1], &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "BuddyVector2___setitem__" "', argument " "2"" of type '" "std::vector< pj::Buddy >::difference_type""'");
  } 
  arg2 = static_cast< std::vector< pj::Buddy >::difference_type >(val2);
  res3 = SWIG_ConvertPtr(swig_obj[2], &argp3, SWIGTYPE_p_pj__Buddy,  0  | 0);
  if (!SWIG_IsOK(res3)) {
    SWIG_exception_fail(SWIG_ArgError(res3), "in method '" "BuddyVector2___setitem__" "', argument " "3"" of type '" "std::vector< pj::Buddy >::value_type const &""'"); 
  }
  if (!argp3) {
    SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "BuddyVector2___setitem__" "', argument " "3"" of type '" "std::vector< pj::Buddy >::value_type const &""'"); 
  }
  arg3 = reinterpret_cast< std::vector< pj::Buddy >::value_type * >(argp3);
  try {
    std_vector_Sl_pj_Buddy_Sg____setitem____SWIG_2(arg1,arg2,(pj::Buddy const &)*arg3);
  } catch(std::out_of_range &_e) {
    SWIG_exception_fail(SWIG_IndexError, (&_e)->what());
  }
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_BuddyVector2___setitem__(PyObject *self, PyObject *args) {
  Py_ssize_t argc;
  PyObject *argv[4] = {
    0
  };
  
  if (!(argc = SWIG_Python_UnpackTuple(args, "BuddyVector2___setitem__", 0, 3, argv))) SWIG_fail;
  --argc;
  if (argc == 2) {
    int _v;
    int res = swig::asptr(argv[0], (std::vector< pj::Buddy,std::allocator< pj::Buddy > >**)(0));
    _v = SWIG_CheckState(res);
    if (_v) {
      {
        _v = PySlice_Check(argv[1]);
      }
      if (_v) {
        return _wrap_BuddyVector2___setitem____SWIG_1(self, argc, argv);
      }
    }
  }
  if (argc == 3) {
    int _v;
    int res = swig::asptr(argv[0], (std::vector< pj::Buddy,std::allocator< pj::Buddy > >**)(0));
    _v = SWIG_CheckState(res);
    if (_v) {
      {
        _v = PySlice_Check(argv[1]);
      }
      if (_v) {
        int res = swig::asptr(argv[2], (std::vector< pj::Buddy,std::allocator< pj::Buddy > >**)(0));
        _v = SWIG_CheckState(res);
        if (_v) {
          return _wrap_BuddyVector2___setitem____SWIG_0(self, argc, argv);
        }
      }
    }
  }
  if (argc == 3) {
    int _v;
    int res = swig::asptr(argv[0], (std::vector< pj::Buddy,std::allocator< pj::Buddy > >**)(0));
    _v = SWIG_CheckState(res);
    if (_v) {
      {
        int res = SWIG_AsVal_ptrdiff_t(argv[1], NULL);
        _v = SWIG_CheckState(res);
      }
      if (_v) {
        int res = SWIG_ConvertPtr(argv[2], 0, SWIGTYPE_p_pj__Buddy, SWIG_POINTER_NO_NULL | 0);
        _v = SWIG_CheckState(res);
        if (_v) {
          return _wrap_BuddyVector2___setitem____SWIG_2(self, argc, argv);
        }
      }
    }
  }
  
fail:
  SWIG_Python_RaiseOrModifyTypeError("Wrong number or type of arguments for overloaded function 'BuddyVector2___setitem__'.\n"
    "  Possible C/C++ prototypes are:\n"
    "    std::vector< pj::Buddy >::__setitem__(PySliceObject *,std::vector< pj::Buddy,std::allocator< pj::Buddy > > const &)\n"
    "    std::vector< pj::Buddy >::__setitem__(PySliceObject *)\n"
    "    std::vector< pj::Buddy >::__setitem__(std::vector< pj::Buddy >::difference_type,std::vector< pj::Buddy >::value_type const &)\n");
  return 0;
}


SWIGINTERN PyObject *_wrap_BuddyVector2_pop(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  std::vector< pj::Buddy > *arg1 = (std::vector< pj::Buddy > *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  std::vector< pj::Buddy >::value_type result;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__vectorT_pj__Buddy_std__allocatorT_pj__Buddy_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "BuddyVector2_pop" "', argument " "1"" of type '" "std::vector< pj::Buddy > *""'"); 
  }
  arg1 = reinterpret_cast< std::vector< pj::Buddy > * >(argp1);
  try {
    result = std_vector_Sl_pj_Buddy_Sg__pop(arg1);
  } catch(std::out_of_range &_e) {
    SWIG_exception_fail(SWIG_IndexError, (&_e)->what());
  }
  resultobj = SWIG_NewPointerObj((new std::vector< pj::Buddy >::value_type(static_cast< const std::vector< pj::Buddy >::value_type& >(result))), SWIGTYPE_p_pj__Buddy, SWIG_POINTER_OWN |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_BuddyVector2_append(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  std::vector< pj::Buddy > *arg1 = (std::vector< pj::Buddy > *) 0 ;
  std::vector< pj::Buddy >::value_type *arg2 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  void *argp2 = 0 ;
  int res2 = 0 ;
  PyObject *swig_obj[2] ;
  
  if (!SWIG_Python_UnpackTuple(args, "BuddyVector2_append", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__vectorT_pj__Buddy_std__allocatorT_pj__Buddy_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "BuddyVector2_append" "', argument " "1"" of type '" "std::vector< pj::Buddy > *""'"); 
  }
  arg1 = reinterpret_cast< std::vector< pj::Buddy > * >(argp1);
  res2 = SWIG_ConvertPtr(swig_obj[1], &argp2, SWIGTYPE_p_pj__Buddy,  0  | 0);
  if (!SWIG_IsOK(res2)) {
    SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "BuddyVector2_append" "', argument " "2"" of type '" "std::vector< pj::Buddy >::value_type const &""'"); 
  }
  if (!argp2) {
    SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "BuddyVector2_append" "', argument " "2"" of type '" "std::vector< pj::Buddy >::value_type const &""'"); 
  }
  arg2 = reinterpret_cast< std::vector< pj::Buddy >::value_type * >(argp2);
  std_vector_Sl_pj_Buddy_Sg__append(arg1,(pj::Buddy const &)*arg2);
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_new_BuddyVector2__SWIG_0(PyObject *SWIGUNUSEDPARM(self), Py_ssize_t nobjs, PyObject **SWIGUNUSEDPARM(swig_obj)) {
  PyObject *resultobj = 0;
  std::vector< pj::Buddy > *result = 0 ;
  
  if ((nobjs < 0) || (nobjs > 0)) SWIG_fail;
  result = (std::vector< pj::Buddy > *)new std::vector< pj::Buddy >();
  resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(result), SWIGTYPE_p_std__vectorT_pj__Buddy_std__allocatorT_pj__Buddy_t_t, SWIG_POINTER_NEW |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_new_BuddyVector2__SWIG_1(PyObject *SWIGUNUSEDPARM(self), Py_ssize_t nobjs, PyObject **swig_obj) {
  PyObject *resultobj = 0;
  std::vector< pj::Buddy > *arg1 = 0 ;
  int res1 = SWIG_OLDOBJ ;
  std::vector< pj::Buddy > *result = 0 ;
  
  if ((nobjs < 1) || (nobjs > 1)) SWIG_fail;
  {
    std::vector< pj::Buddy,std::allocator< pj::Buddy > > *ptr = (std::vector< pj::Buddy,std::allocator< pj::Buddy > > *)0;
    res1 = swig::asptr(swig_obj[0], &ptr);
    if (!SWIG_IsOK(res1)) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "new_BuddyVector2" "', argument " "1"" of type '" "std::vector< pj::Buddy > const &""'"); 
    }
    if (!ptr) {
      SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "new_BuddyVector2" "', argument " "1"" of type '" "std::vector< pj::Buddy > const &""'"); 
    }
    arg1 = ptr;
  }
  result = (std::vector< pj::Buddy > *)new std::vector< pj::Buddy >((std::vector< pj::Buddy > const &)*arg1);
  resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(result), SWIGTYPE_p_std__vectorT_pj__Buddy_std__allocatorT_pj__Buddy_t_t, SWIG_POINTER_NEW |  0 );
  if (SWIG_IsNewObj(res1)) delete arg1;
  return resultobj;
fail:
  if (SWIG_IsNewObj(res1)) delete arg1;
  return NULL;
}


SWIGINTERN PyObject *_wrap_BuddyVector2_empty(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  std::vector< pj::Buddy > *arg1 = (std::vector< pj::Buddy > *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  bool result;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__vectorT_pj__Buddy_std__allocatorT_pj__Buddy_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "BuddyVector2_empty" "', argument " "1"" of type '" "std::vector< pj::Buddy > const *""'"); 
  }
  arg1 = reinterpret_cast< std::vector< pj::Buddy > * >(argp1);
  result = (bool)((std::vector< pj::Buddy > const *)arg1)->empty();
  resultobj = SWIG_From_bool(static_cast< bool >(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_BuddyVector2_size(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  std::vector< pj::Buddy > *arg1 = (std::vector< pj::Buddy > *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  std::vector< pj::Buddy >::size_type result;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__vectorT_pj__Buddy_std__allocatorT_pj__Buddy_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "BuddyVector2_size" "', argument " "1"" of type '" "std::vector< pj::Buddy > const *""'"); 
  }
  arg1 = reinterpret_cast< std::vector< pj::Buddy > * >(argp1);
  result = ((std::vector< pj::Buddy > const *)arg1)->size();
  resultobj = SWIG_From_size_t(static_cast< size_t >(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_BuddyVector2_swap(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  std::vector< pj::Buddy > *arg1 = (std::vector< pj::Buddy > *) 0 ;
  std::vector< pj::Buddy > *arg2 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  void *argp2 = 0 ;
  int res2 = 0 ;
  PyObject *swig_obj[2] ;
  
  if (!SWIG_Python_UnpackTuple(args, "BuddyVector2_swap", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__vectorT_pj__Buddy_std__allocatorT_pj__Buddy_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "BuddyVector2_swap" "', argument " "1"" of type '" "std::vector< pj::Buddy > *""'"); 
  }
  arg1 = reinterpret_cast< std::vector< pj::Buddy > * >(argp1);
  res2 = SWIG_ConvertPtr(swig_obj[1], &argp2, SWIGTYPE_p_std__vectorT_pj__Buddy_std__allocatorT_pj__Buddy_t_t,  0 );
  if (!SWIG_IsOK(res2)) {
    SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "BuddyVector2_swap" "', argument " "2"" of type '" "std::vector< pj::Buddy > &""'"); 
  }
  if (!argp2) {
    SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "BuddyVector2_swap" "', argument " "2"" of type '" "std::vector< pj::Buddy > &""'"); 
  }
  arg2 = reinterpret_cast< std::vector< pj::Buddy > * >(argp2);
  (arg1)->swap(*arg2);
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_BuddyVector2_begin(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  std::vector< pj::Buddy > *arg1 = (std::vector< pj::Buddy > *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  std::vector< pj::Buddy >::iterator result;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__vectorT_pj__Buddy_std__allocatorT_pj__Buddy_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "BuddyVector2_begin" "', argument " "1"" of type '" "std::vector< pj::Buddy > *""'"); 
  }
  arg1 = reinterpret_cast< std::vector< pj::Buddy > * >(argp1);
  result = (arg1)->begin();
  resultobj = SWIG_NewPointerObj(swig::make_output_iterator(static_cast< const std::vector< pj::Buddy >::iterator & >(result)),
    swig::SwigPyIterator::descriptor(),SWIG_POINTER_OWN);
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_BuddyVector2_end(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  std::vector< pj::Buddy > *arg1 = (std::vector< pj::Buddy > *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  std::vector< pj::Buddy >::iterator result;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__vectorT_pj__Buddy_std__allocatorT_pj__Buddy_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "BuddyVector2_end" "', argument " "1"" of type '" "std::vector< pj::Buddy > *""'"); 
  }
  arg1 = reinterpret_cast< std::vector< pj::Buddy > * >(argp1);
  result = (arg1)->end();
  resultobj = SWIG_NewPointerObj(swig::make_output_iterator(static_cast< const std::vector< pj::Buddy >::iterator & >(result)),
    swig::SwigPyIterator::descriptor(),SWIG_POINTER_OWN);
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_BuddyVector2_rbegin(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  std::vector< pj::Buddy > *arg1 = (std::vector< pj::Buddy > *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  std::vector< pj::Buddy >::reverse_iterator result;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__vectorT_pj__Buddy_std__allocatorT_pj__Buddy_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "BuddyVector2_rbegin" "', argument " "1"" of type '" "std::vector< pj::Buddy > *""'"); 
  }
  arg1 = reinterpret_cast< std::vector< pj::Buddy > * >(argp1);
  result = (arg1)->rbegin();
  resultobj = SWIG_NewPointerObj(swig::make_output_iterator(static_cast< const std::vector< pj::Buddy >::reverse_iterator & >(result)),
    swig::SwigPyIterator::descriptor(),SWIG_POINTER_OWN);
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_BuddyVector2_rend(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  std::vector< pj::Buddy > *arg1 = (std::vector< pj::Buddy > *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  std::vector< pj::Buddy >::reverse_iterator result;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__vectorT_pj__Buddy_std__allocatorT_pj__Buddy_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "BuddyVector2_rend" "', argument " "1"" of type '" "std::vector< pj::Buddy > *""'"); 
  }
  arg1 = reinterpret_cast< std::vector< pj::Buddy > * >(argp1);
  result = (arg1)->rend();
  resultobj = SWIG_NewPointerObj(swig::make_output_iterator(static_cast< const std::vector< pj::Buddy >::reverse_iterator & >(result)),
    swig::SwigPyIterator::descriptor(),SWIG_POINTER_OWN);
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_BuddyVector2_clear(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  std::vector< pj::Buddy > *arg1 = (std::vector< pj::Buddy > *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__vectorT_pj__Buddy_std__allocatorT_pj__Buddy_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "BuddyVector2_clear" "', argument " "1"" of type '" "std::vector< pj::Buddy > *""'"); 
  }
  arg1 = reinterpret_cast< std::vector< pj::Buddy > * >(argp1);
  (arg1)->clear();
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_BuddyVector2_get_allocator(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  std::vector< pj::Buddy > *arg1 = (std::vector< pj::Buddy > *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  SwigValueWrapper< std::allocator< pj::Buddy > > result;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__vectorT_pj__Buddy_std__allocatorT_pj__Buddy_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "BuddyVector2_get_allocator" "', argument " "1"" of type '" "std::vector< pj::Buddy > const *""'"); 
  }
  arg1 = reinterpret_cast< std::vector< pj::Buddy > * >(argp1);
  result = ((std::vector< pj::Buddy > const *)arg1)->get_allocator();
  resultobj = SWIG_NewPointerObj((new std::vector< pj::Buddy >::allocator_type(static_cast< const std::vector< pj::Buddy >::allocator_type& >(result))), SWIGTYPE_p_std__allocatorT_pj__Buddy_t, SWIG_POINTER_OWN |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_new_BuddyVector2__SWIG_2(PyObject *SWIGUNUSEDPARM(self), Py_ssize_t nobjs, PyObject **swig_obj) {
  PyObject *resultobj = 0;
  std::vector< pj::Buddy >::size_type arg1 ;
  size_t val1 ;
  int ecode1 = 0 ;
  std::vector< pj::Buddy > *result = 0 ;
  
  if ((nobjs < 1) || (nobjs > 1)) SWIG_fail;
  ecode1 = SWIG_AsVal_size_t(swig_obj[0], &val1);
  if (!SWIG_IsOK(ecode1)) {
    SWIG_exception_fail(SWIG_ArgError(ecode1), "in method '" "new_BuddyVector2" "', argument " "1"" of type '" "std::vector< pj::Buddy >::size_type""'");
  } 
  arg1 = static_cast< std::vector< pj::Buddy >::size_type >(val1);
  result = (std::vector< pj::Buddy > *)new std::vector< pj::Buddy >(arg1);
  resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(result), SWIGTYPE_p_std__vectorT_pj__Buddy_std__allocatorT_pj__Buddy_t_t, SWIG_POINTER_NEW |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_BuddyVector2_pop_back(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  std::vector< pj::Buddy > *arg1 = (std::vector< pj::Buddy > *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__vectorT_pj__Buddy_std__allocatorT_pj__Buddy_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "BuddyVector2_pop_back" "', argument " "1"" of type '" "std::vector< pj::Buddy > *""'"); 
  }
  arg1 = reinterpret_cast< std::vector< pj::Buddy > * >(argp1);
  (arg1)->pop_back();
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_BuddyVector2_resize__SWIG_0(PyObject *SWIGUNUSEDPARM(self), Py_ssize_t nobjs, PyObject **swig_obj) {
  PyObject *resultobj = 0;
  std::vector< pj::Buddy > *arg1 = (std::vector< pj::Buddy > *) 0 ;
  std::vector< pj::Buddy >::size_type arg2 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  size_t val2 ;
  int ecode2 = 0 ;
  
  if ((nobjs < 2) || (nobjs > 2)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__vectorT_pj__Buddy_std__allocatorT_pj__Buddy_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "BuddyVector2_resize" "', argument " "1"" of type '" "std::vector< pj::Buddy > *""'"); 
  }
  arg1 = reinterpret_cast< std::vector< pj::Buddy > * >(argp1);
  ecode2 = SWIG_AsVal_size_t(swig_obj[1], &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "BuddyVector2_resize" "', argument " "2"" of type '" "std::vector< pj::Buddy >::size_type""'");
  } 
  arg2 = static_cast< std::vector< pj::Buddy >::size_type >(val2);
  (arg1)->resize(arg2);
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_BuddyVector2_erase__SWIG_0(PyObject *SWIGUNUSEDPARM(self), Py_ssize_t nobjs, PyObject **swig_obj) {
  PyObject *resultobj = 0;
  std::vector< pj::Buddy > *arg1 = (std::vector< pj::Buddy > *) 0 ;
  std::vector< pj::Buddy >::iterator arg2 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  swig::SwigPyIterator *iter2 = 0 ;
  int res2 ;
  std::vector< pj::Buddy >::iterator result;
  
  if ((nobjs < 2) || (nobjs > 2)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__vectorT_pj__Buddy_std__allocatorT_pj__Buddy_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "BuddyVector2_erase" "', argument " "1"" of type '" "std::vector< pj::Buddy > *""'"); 
  }
  arg1 = reinterpret_cast< std::vector< pj::Buddy > * >(argp1);
  res2 = SWIG_ConvertPtr(swig_obj[1], SWIG_as_voidptrptr(&iter2), swig::SwigPyIterator::descriptor(), 0);
  if (!SWIG_IsOK(res2) || !iter2) {
    SWIG_exception_fail(SWIG_ArgError(SWIG_TypeError), "in method '" "BuddyVector2_erase" "', argument " "2"" of type '" "std::vector< pj::Buddy >::iterator""'");
  } else {
    swig::SwigPyIterator_T<std::vector< pj::Buddy >::iterator > *iter_t = dynamic_cast<swig::SwigPyIterator_T<std::vector< pj::Buddy >::iterator > *>(iter2);
    if (iter_t) {
      arg2 = iter_t->get_current();
    } else {
      SWIG_exception_fail(SWIG_ArgError(SWIG_TypeError), "in method '" "BuddyVector2_erase" "', argument " "2"" of type '" "std::vector< pj::Buddy >::iterator""'");
    }
  }
  result = std_vector_Sl_pj_Buddy_Sg__erase__SWIG_0(arg1,arg2);
  resultobj = SWIG_NewPointerObj(swig::make_output_iterator(static_cast< const std::vector< pj::Buddy >::iterator & >(result)),
    swig::SwigPyIterator::descriptor(),SWIG_POINTER_OWN);
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_BuddyVector2_erase__SWIG_1(PyObject *SWIGUNUSEDPARM(self), Py_ssize_t nobjs, PyObject **swig_obj) {
  PyObject *resultobj = 0;
  std::vector< pj::Buddy > *arg1 = (std::vector< pj::Buddy > *) 0 ;
  std::vector< pj::Buddy >::iterator arg2 ;
  std::vector< pj::Buddy >::iterator arg3 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  swig::SwigPyIterator *iter2 = 0 ;
  int res2 ;
  swig::SwigPyIterator *iter3 = 0 ;
  int res3 ;
  std::vector< pj::Buddy >::iterator result;
  
  if ((nobjs < 3) || (nobjs > 3)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__vectorT_pj__Buddy_std__allocatorT_pj__Buddy_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "BuddyVector2_erase" "', argument " "1"" of type '" "std::vector< pj::Buddy > *""'"); 
  }
  arg1 = reinterpret_cast< std::vector< pj::Buddy > * >(argp1);
  res2 = SWIG_ConvertPtr(swig_obj[1], SWIG_as_voidptrptr(&iter2), swig::SwigPyIterator::descriptor(), 0);
  if (!SWIG_IsOK(res2) || !iter2) {
    SWIG_exception_fail(SWIG_ArgError(SWIG_TypeError), "in method '" "BuddyVector2_erase" "', argument " "2"" of type '" "std::vector< pj::Buddy >::iterator""'");
  } else {
    swig::SwigPyIterator_T<std::vector< pj::Buddy >::iterator > *iter_t = dynamic_cast<swig::SwigPyIterator_T<std::vector< pj::Buddy >::iterator > *>(iter2);
    if (iter_t) {
      arg2 = iter_t->get_current();
    } else {
      SWIG_exception_fail(SWIG_ArgError(SWIG_TypeError), "in method '" "BuddyVector2_erase" "', argument " "2"" of type '" "std::vector< pj::Buddy >::iterator""'");
    }
  }
  res3 = SWIG_ConvertPtr(swig_obj[2], SWIG_as_voidptrptr(&iter3), swig::SwigPyIterator::descriptor(), 0);
  if (!SWIG_IsOK(res3) || !iter3) {
    SWIG_exception_fail(SWIG_ArgError(SWIG_TypeError), "in method '" "BuddyVector2_erase" "', argument " "3"" of type '" "std::vector< pj::Buddy >::iterator""'");
  } else {
    swig::SwigPyIterator_T<std::vector< pj::Buddy >::iterator > *iter_t = dynamic_cast<swig::SwigPyIterator_T<std::vector< pj::Buddy >::iterator > *>(iter3);
    if (iter_t) {
      arg3 = iter_t->get_current();
    } else {
      SWIG_exception_fail(SWIG_ArgError(SWIG_TypeError), "in method '" "BuddyVector2_erase" "', argument " "3"" of type '" "std::vector< pj::Buddy >::iterator""'");
    }
  }
  result = std_vector_Sl_pj_Buddy_Sg__erase__SWIG_1(arg1,arg2,arg3);
  resultobj = SWIG_NewPointerObj(swig::make_output_iterator(static_cast< const std::vector< pj::Buddy >::iterator & >(result)),
    swig::SwigPyIterator::descriptor(),SWIG_POINTER_OWN);
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_BuddyVector2_erase(PyObject *self, PyObject *args) {
  Py_ssize_t argc;
  PyObject *argv[4] = {
    0
  };
  
  if (!(argc = SWIG_Python_UnpackTuple(args, "BuddyVector2_erase", 0, 3, argv))) SWIG_fail;
  --argc;
  if (argc == 2) {
    int _v;
    int res = swig::asptr(argv[0], (std::vector< pj::Buddy,std::allocator< pj::Buddy > >**)(0));
    _v = SWIG_CheckState(res);
    if (_v) {
      swig::SwigPyIterator *iter = 0;
      int res = SWIG_ConvertPtr(argv[1], SWIG_as_voidptrptr(&iter), swig::SwigPyIterator::descriptor(), 0);
      _v = (SWIG_IsOK(res) && iter && (dynamic_cast<swig::SwigPyIterator_T<std::vector< pj::Buddy >::iterator > *>(iter) != 0));
      if (_v) {
        return _wrap_BuddyVector2_erase__SWIG_0(self, argc, argv);
      }
    }
  }
  if (argc == 3) {
    int _v;
    int res = swig::asptr(argv[0], (std::vector< pj::Buddy,std::allocator< pj::Buddy > >**)(0));
    _v = SWIG_CheckState(res);
    if (_v) {
      swig::SwigPyIterator *iter = 0;
      int res = SWIG_ConvertPtr(argv[1], SWIG_as_voidptrptr(&iter), swig::SwigPyIterator::descriptor(), 0);
      _v = (SWIG_IsOK(res) && iter && (dynamic_cast<swig::SwigPyIterator_T<std::vector< pj::Buddy >::iterator > *>(iter) != 0));
      if (_v) {
        swig::SwigPyIterator *iter = 0;
        int res = SWIG_ConvertPtr(argv[2], SWIG_as_voidptrptr(&iter), swig::SwigPyIterator::descriptor(), 0);
        _v = (SWIG_IsOK(res) && iter && (dynamic_cast<swig::SwigPyIterator_T<std::vector< pj::Buddy >::iterator > *>(iter) != 0));
        if (_v) {
          return _wrap_BuddyVector2_erase__SWIG_1(self, argc, argv);
        }
      }
    }
  }
  
fail:
  SWIG_Python_RaiseOrModifyTypeError("Wrong number or type of arguments for overloaded function 'BuddyVector2_erase'.\n"
    "  Possible C/C++ prototypes are:\n"
    "    std::vector< pj::Buddy >::erase(std::vector< pj::Buddy >::iterator)\n"
    "    std::vector< pj::Buddy >::erase(std::vector< pj::Buddy >::iterator,std::vector< pj::Buddy >::iterator)\n");
  return 0;
}


SWIGINTERN PyObject *_wrap_new_BuddyVector2__SWIG_3(PyObject *SWIGUNUSEDPARM(self), Py_ssize_t nobjs, PyObject **swig_obj) {
  PyObject *resultobj = 0;
  std::vector< pj::Buddy >::size_type arg1 ;
  std::vector< pj::Buddy >::value_type *arg2 = 0 ;
  size_t val1 ;
  int ecode1 = 0 ;
  void *argp2 = 0 ;
  int res2 = 0 ;
  std::vector< pj::Buddy > *result = 0 ;
  
  if ((nobjs < 2) || (nobjs > 2)) SWIG_fail;
  ecode1 = SWIG_AsVal_size_t(swig_obj[0], &val1);
  if (!SWIG_IsOK(ecode1)) {
    SWIG_exception_fail(SWIG_ArgError(ecode1), "in method '" "new_BuddyVector2" "', argument " "1"" of type '" "std::vector< pj::Buddy >::size_type""'");
  } 
  arg1 = static_cast< std::vector< pj::Buddy >::size_type >(val1);
  res2 = SWIG_ConvertPtr(swig_obj[1], &argp2, SWIGTYPE_p_pj__Buddy,  0  | 0);
  if (!SWIG_IsOK(res2)) {
    SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "new_BuddyVector2" "', argument " "2"" of type '" "std::vector< pj::Buddy >::value_type const &""'"); 
  }
  if (!argp2) {
    SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "new_BuddyVector2" "', argument " "2"" of type '" "std::vector< pj::Buddy >::value_type const &""'"); 
  }
  arg2 = reinterpret_cast< std::vector< pj::Buddy >::value_type * >(argp2);
  result = (std::vector< pj::Buddy > *)new std::vector< pj::Buddy >(arg1,(std::vector< pj::Buddy >::value_type const &)*arg2);
  resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(result), SWIGTYPE_p_std__vectorT_pj__Buddy_std__allocatorT_pj__Buddy_t_t, SWIG_POINTER_NEW |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_new_BuddyVector2(PyObject *self, PyObject *args) {
  Py_ssize_t argc;
  PyObject *argv[3] = {
    0
  };
  
  if (!(argc = SWIG_Python_UnpackTuple(args, "new_BuddyVector2", 0, 2, argv))) SWIG_fail;
  --argc;
  if (argc == 0) {
    return _wrap_new_BuddyVector2__SWIG_0(self, argc, argv);
  }
  if (argc == 1) {
    int _v;
    {
      int res = SWIG_AsVal_size_t(argv[0], NULL);
      _v = SWIG_CheckState(res);
    }
    if (_v) {
      return _wrap_new_BuddyVector2__SWIG_2(self, argc, argv);
    }
  }
  if (argc == 1) {
    int _v;
    int res = swig::asptr(argv[0], (std::vector< pj::Buddy,std::allocator< pj::Buddy > >**)(0));
    _v = SWIG_CheckState(res);
    if (_v) {
      return _wrap_new_BuddyVector2__SWIG_1(self, argc, argv);
    }
  }
  if (argc == 2) {
    int _v;
    {
      int res = SWIG_AsVal_size_t(argv[0], NULL);
      _v = SWIG_CheckState(res);
    }
    if (_v) {
      int res = SWIG_ConvertPtr(argv[1], 0, SWIGTYPE_p_pj__Buddy, SWIG_POINTER_NO_NULL | 0);
      _v = SWIG_CheckState(res);
      if (_v) {
        return _wrap_new_BuddyVector2__SWIG_3(self, argc, argv);
      }
    }
  }
  
fail:
  SWIG_Python_RaiseOrModifyTypeError("Wrong number or type of arguments for overloaded function 'new_BuddyVector2'.\n"
    "  Possible C/C++ prototypes are:\n"
    "    std::vector< pj::Buddy >::vector()\n"
    "    std::vector< pj::Buddy >::vector(std::vector< pj::Buddy > const &)\n"
    "    std::vector< pj::Buddy >::vector(std::vector< pj::Buddy >::size_type)\n"
    "    std::vector< pj::Buddy >::vector(std::vector< pj::Buddy >::size_type,std::vector< pj::Buddy >::value_type const &)\n");
  return 0;
}


SWIGINTERN PyObject *_wrap_BuddyVector2_push_back(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  std::vector< pj::Buddy > *arg1 = (std::vector< pj::Buddy > *) 0 ;
  std::vector< pj::Buddy >::value_type *arg2 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  void *argp2 = 0 ;
  int res2 = 0 ;
  PyObject *swig_obj[2] ;
  
  if (!SWIG_Python_UnpackTuple(args, "BuddyVector2_push_back", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__vectorT_pj__Buddy_std__allocatorT_pj__Buddy_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "BuddyVector2_push_back" "', argument " "1"" of type '" "std::vector< pj::Buddy > *""'"); 
  }
  arg1 = reinterpret_cast< std::vector< pj::Buddy > * >(argp1);
  res2 = SWIG_ConvertPtr(swig_obj[1], &argp2, SWIGTYPE_p_pj__Buddy,  0  | 0);
  if (!SWIG_IsOK(res2)) {
    SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "BuddyVector2_push_back" "', argument " "2"" of type '" "std::vector< pj::Buddy >::value_type const &""'"); 
  }
  if (!argp2) {
    SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "BuddyVector2_push_back" "', argument " "2"" of type '" "std::vector< pj::Buddy >::value_type const &""'"); 
  }
  arg2 = reinterpret_cast< std::vector< pj::Buddy >::value_type * >(argp2);
  (arg1)->push_back((std::vector< pj::Buddy >::value_type const &)*arg2);
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_BuddyVector2_front(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  std::vector< pj::Buddy > *arg1 = (std::vector< pj::Buddy > *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  std::vector< pj::Buddy >::value_type *result = 0 ;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__vectorT_pj__Buddy_std__allocatorT_pj__Buddy_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "BuddyVector2_front" "', argument " "1"" of type '" "std::vector< pj::Buddy > const *""'"); 
  }
  arg1 = reinterpret_cast< std::vector< pj::Buddy > * >(argp1);
  result = (std::vector< pj::Buddy >::value_type *) &((std::vector< pj::Buddy > const *)arg1)->front();
  resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(result), SWIGTYPE_p_pj__Buddy, 0 |  0 );
  (void)swig::container_owner<swig::traits<std::vector< pj::Buddy >::value_type>::category>::back_reference(resultobj, swig_obj[0]);
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_BuddyVector2_back(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  std::vector< pj::Buddy > *arg1 = (std::vector< pj::Buddy > *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  std::vector< pj::Buddy >::value_type *result = 0 ;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__vectorT_pj__Buddy_std__allocatorT_pj__Buddy_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "BuddyVector2_back" "', argument " "1"" of type '" "std::vector< pj::Buddy > const *""'"); 
  }
  arg1 = reinterpret_cast< std::vector< pj::Buddy > * >(argp1);
  result = (std::vector< pj::Buddy >::value_type *) &((std::vector< pj::Buddy > const *)arg1)->back();
  resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(result), SWIGTYPE_p_pj__Buddy, 0 |  0 );
  (void)swig::container_owner<swig::traits<std::vector< pj::Buddy >::value_type>::category>::back_reference(resultobj, swig_obj[0]);
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_BuddyVector2_assign(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  std::vector< pj::Buddy > *arg1 = (std::vector< pj::Buddy > *) 0 ;
  std::vector< pj::Buddy >::size_type arg2 ;
  std::vector< pj::Buddy >::value_type *arg3 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  size_t val2 ;
  int ecode2 = 0 ;
  void *argp3 = 0 ;
  int res3 = 0 ;
  PyObject *swig_obj[3] ;
  
  if (!SWIG_Python_UnpackTuple(args, "BuddyVector2_assign", 3, 3, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__vectorT_pj__Buddy_std__allocatorT_pj__Buddy_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "BuddyVector2_assign" "', argument " "1"" of type '" "std::vector< pj::Buddy > *""'"); 
  }
  arg1 = reinterpret_cast< std::vector< pj::Buddy > * >(argp1);
  ecode2 = SWIG_AsVal_size_t(swig_obj[1], &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "BuddyVector2_assign" "', argument " "2"" of type '" "std::vector< pj::Buddy >::size_type""'");
  } 
  arg2 = static_cast< std::vector< pj::Buddy >::size_type >(val2);
  res3 = SWIG_ConvertPtr(swig_obj[2], &argp3, SWIGTYPE_p_pj__Buddy,  0  | 0);
  if (!SWIG_IsOK(res3)) {
    SWIG_exception_fail(SWIG_ArgError(res3), "in method '" "BuddyVector2_assign" "', argument " "3"" of type '" "std::vector< pj::Buddy >::value_type const &""'"); 
  }
  if (!argp3) {
    SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "BuddyVector2_assign" "', argument " "3"" of type '" "std::vector< pj::Buddy >::value_type const &""'"); 
  }
  arg3 = reinterpret_cast< std::vector< pj::Buddy >::value_type * >(argp3);
  (arg1)->assign(arg2,(std::vector< pj::Buddy >::value_type const &)*arg3);
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_BuddyVector2_resize__SWIG_1(PyObject *SWIGUNUSEDPARM(self), Py_ssize_t nobjs, PyObject **swig_obj) {
  PyObject *resultobj = 0;
  std::vector< pj::Buddy > *arg1 = (std::vector< pj::Buddy > *) 0 ;
  std::vector< pj::Buddy >::size_type arg2 ;
  std::vector< pj::Buddy >::value_type *arg3 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  size_t val2 ;
  int ecode2 = 0 ;
  void *argp3 = 0 ;
  int res3 = 0 ;
  
  if ((nobjs < 3) || (nobjs > 3)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__vectorT_pj__Buddy_std__allocatorT_pj__Buddy_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "BuddyVector2_resize" "', argument " "1"" of type '" "std::vector< pj::Buddy > *""'"); 
  }
  arg1 = reinterpret_cast< std::vector< pj::Buddy > * >(argp1);
  ecode2 = SWIG_AsVal_size_t(swig_obj[1], &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "BuddyVector2_resize" "', argument " "2"" of type '" "std::vector< pj::Buddy >::size_type""'");
  } 
  arg2 = static_cast< std::vector< pj::Buddy >::size_type >(val2);
  res3 = SWIG_ConvertPtr(swig_obj[2], &argp3, SWIGTYPE_p_pj__Buddy,  0  | 0);
  if (!SWIG_IsOK(res3)) {
    SWIG_exception_fail(SWIG_ArgError(res3), "in method '" "BuddyVector2_resize" "', argument " "3"" of type '" "std::vector< pj::Buddy >::value_type const &""'"); 
  }
  if (!argp3) {
    SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "BuddyVector2_resize" "', argument " "3"" of type '" "std::vector< pj::Buddy >::value_type const &""'"); 
  }
  arg3 = reinterpret_cast< std::vector< pj::Buddy >::value_type * >(argp3);
  (arg1)->resize(arg2,(std::vector< pj::Buddy >::value_type const &)*arg3);
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_BuddyVector2_resize(PyObject *self, PyObject *args) {
  Py_ssize_t argc;
  PyObject *argv[4] = {
    0
  };
  
  if (!(argc = SWIG_Python_UnpackTuple(args, "BuddyVector2_resize", 0, 3, argv))) SWIG_fail;
  --argc;
  if (argc == 2) {
    int _v;
    int res = swig::asptr(argv[0], (std::vector< pj::Buddy,std::allocator< pj::Buddy > >**)(0));
    _v = SWIG_CheckState(res);
    if (_v) {
      {
        int res = SWIG_AsVal_size_t(argv[1], NULL);
        _v = SWIG_CheckState(res);
      }
      if (_v) {
        return _wrap_BuddyVector2_resize__SWIG_0(self, argc, argv);
      }
    }
  }
  if (argc == 3) {
    int _v;
    int res = swig::asptr(argv[0], (std::vector< pj::Buddy,std::allocator< pj::Buddy > >**)(0));
    _v = SWIG_CheckState(res);
    if (_v) {
      {
        int res = SWIG_AsVal_size_t(argv[1], NULL);
        _v = SWIG_CheckState(res);
      }
      if (_v) {
        int res = SWIG_ConvertPtr(argv[2], 0, SWIGTYPE_p_pj__Buddy, SWIG_POINTER_NO_NULL | 0);
        _v = SWIG_CheckState(res);
        if (_v) {
          return _wrap_BuddyVector2_resize__SWIG_1(self, argc, argv);
        }
      }
    }
  }
  
fail:
  SWIG_Python_RaiseOrModifyTypeError("Wrong number or type of arguments for overloaded function 'BuddyVector2_resize'.\n"
    "  Possible C/C++ prototypes are:\n"
    "    std::vector< pj::Buddy >::resize(std::vector< pj::Buddy >::size_type)\n"
    "    std::vector< pj::Buddy >::resize(std::vector< pj::Buddy >::size_type,std::vector< pj::Buddy >::value_type const &)\n");
  return 0;
}


SWIGINTERN PyObject *_wrap_BuddyVector2_insert__SWIG_0(PyObject *SWIGUNUSEDPARM(self), Py_ssize_t nobjs, PyObject **swig_obj) {
  PyObject *resultobj = 0;
  std::vector< pj::Buddy > *arg1 = (std::vector< pj::Buddy > *) 0 ;
  std::vector< pj::Buddy >::iterator arg2 ;
  std::vector< pj::Buddy >::value_type *arg3 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  swig::SwigPyIterator *iter2 = 0 ;
  int res2 ;
  void *argp3 = 0 ;
  int res3 = 0 ;
  std::vector< pj::Buddy >::iterator result;
  
  if ((nobjs < 3) || (nobjs > 3)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__vectorT_pj__Buddy_std__allocatorT_pj__Buddy_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "BuddyVector2_insert" "', argument " "1"" of type '" "std::vector< pj::Buddy > *""'"); 
  }
  arg1 = reinterpret_cast< std::vector< pj::Buddy > * >(argp1);
  res2 = SWIG_ConvertPtr(swig_obj[1], SWIG_as_voidptrptr(&iter2), swig::SwigPyIterator::descriptor(), 0);
  if (!SWIG_IsOK(res2) || !iter2) {
    SWIG_exception_fail(SWIG_ArgError(SWIG_TypeError), "in method '" "BuddyVector2_insert" "', argument " "2"" of type '" "std::vector< pj::Buddy >::iterator""'");
  } else {
    swig::SwigPyIterator_T<std::vector< pj::Buddy >::iterator > *iter_t = dynamic_cast<swig::SwigPyIterator_T<std::vector< pj::Buddy >::iterator > *>(iter2);
    if (iter_t) {
      arg2 = iter_t->get_current();
    } else {
      SWIG_exception_fail(SWIG_ArgError(SWIG_TypeError), "in method '" "BuddyVector2_insert" "', argument " "2"" of type '" "std::vector< pj::Buddy >::iterator""'");
    }
  }
  res3 = SWIG_ConvertPtr(swig_obj[2], &argp3, SWIGTYPE_p_pj__Buddy,  0  | 0);
  if (!SWIG_IsOK(res3)) {
    SWIG_exception_fail(SWIG_ArgError(res3), "in method '" "BuddyVector2_insert" "', argument " "3"" of type '" "std::vector< pj::Buddy >::value_type const &""'"); 
  }
  if (!argp3) {
    SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "BuddyVector2_insert" "', argument " "3"" of type '" "std::vector< pj::Buddy >::value_type const &""'"); 
  }
  arg3 = reinterpret_cast< std::vector< pj::Buddy >::value_type * >(argp3);
  result = std_vector_Sl_pj_Buddy_Sg__insert__SWIG_0(arg1,arg2,(pj::Buddy const &)*arg3);
  resultobj = SWIG_NewPointerObj(swig::make_output_iterator(static_cast< const std::vector< pj::Buddy >::iterator & >(result)),
    swig::SwigPyIterator::descriptor(),SWIG_POINTER_OWN);
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_BuddyVector2_insert__SWIG_1(PyObject *SWIGUNUSEDPARM(self), Py_ssize_t nobjs, PyObject **swig_obj) {
  PyObject *resultobj = 0;
  std::vector< pj::Buddy > *arg1 = (std::vector< pj::Buddy > *) 0 ;
  std::vector< pj::Buddy >::iterator arg2 ;
  std::vector< pj::Buddy >::size_type arg3 ;
  std::vector< pj::Buddy >::value_type *arg4 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  swig::SwigPyIterator *iter2 = 0 ;
  int res2 ;
  size_t val3 ;
  int ecode3 = 0 ;
  void *argp4 = 0 ;
  int res4 = 0 ;
  
  if ((nobjs < 4) || (nobjs > 4)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__vectorT_pj__Buddy_std__allocatorT_pj__Buddy_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "BuddyVector2_insert" "', argument " "1"" of type '" "std::vector< pj::Buddy > *""'"); 
  }
  arg1 = reinterpret_cast< std::vector< pj::Buddy > * >(argp1);
  res2 = SWIG_ConvertPtr(swig_obj[1], SWIG_as_voidptrptr(&iter2), swig::SwigPyIterator::descriptor(), 0);
  if (!SWIG_IsOK(res2) || !iter2) {
    SWIG_exception_fail(SWIG_ArgError(SWIG_TypeError), "in method '" "BuddyVector2_insert" "', argument " "2"" of type '" "std::vector< pj::Buddy >::iterator""'");
  } else {
    swig::SwigPyIterator_T<std::vector< pj::Buddy >::iterator > *iter_t = dynamic_cast<swig::SwigPyIterator_T<std::vector< pj::Buddy >::iterator > *>(iter2);
    if (iter_t) {
      arg2 = iter_t->get_current();
    } else {
      SWIG_exception_fail(SWIG_ArgError(SWIG_TypeError), "in method '" "BuddyVector2_insert" "', argument " "2"" of type '" "std::vector< pj::Buddy >::iterator""'");
    }
  }
  ecode3 = SWIG_AsVal_size_t(swig_obj[2], &val3);
  if (!SWIG_IsOK(ecode3)) {
    SWIG_exception_fail(SWIG_ArgError(ecode3), "in method '" "BuddyVector2_insert" "', argument " "3"" of type '" "std::vector< pj::Buddy >::size_type""'");
  } 
  arg3 = static_cast< std::vector< pj::Buddy >::size_type >(val3);
  res4 = SWIG_ConvertPtr(swig_obj[3], &argp4, SWIGTYPE_p_pj__Buddy,  0  | 0);
  if (!SWIG_IsOK(res4)) {
    SWIG_exception_fail(SWIG_ArgError(res4), "in method '" "BuddyVector2_insert" "', argument " "4"" of type '" "std::vector< pj::Buddy >::value_type const &""'"); 
  }
  if (!argp4) {
    SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "BuddyVector2_insert" "', argument " "4"" of type '" "std::vector< pj::Buddy >::value_type const &""'"); 
  }
  arg4 = reinterpret_cast< std::vector< pj::Buddy >::value_type * >(argp4);
  std_vector_Sl_pj_Buddy_Sg__insert__SWIG_1(arg1,arg2,arg3,(pj::Buddy const &)*arg4);
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_BuddyVector2_insert(PyObject *self, PyObject *args) {
  Py_ssize_t argc;
  PyObject *argv[5] = {
    0
  };
  
  if (!(argc = SWIG_Python_UnpackTuple(args, "BuddyVector2_insert", 0, 4, argv))) SWIG_fail;
  --argc;
  if (argc == 3) {
    int _v;
    int res = swig::asptr(argv[0], (std::vector< pj::Buddy,std::allocator< pj::Buddy > >**)(0));
    _v = SWIG_CheckState(res);
    if (_v) {
      swig::SwigPyIterator *iter = 0;
      int res = SWIG_ConvertPtr(argv[1], SWIG_as_voidptrptr(&iter), swig::SwigPyIterator::descriptor(), 0);
      _v = (SWIG_IsOK(res) && iter && (dynamic_cast<swig::SwigPyIterator_T<std::vector< pj::Buddy >::iterator > *>(iter) != 0));
      if (_v) {
        int res = SWIG_ConvertPtr(argv[2], 0, SWIGTYPE_p_pj__Buddy, SWIG_POINTER_NO_NULL | 0);
        _v = SWIG_CheckState(res);
        if (_v) {
          return _wrap_BuddyVector2_insert__SWIG_0(self, argc, argv);
        }
      }
    }
  }
  if (argc == 4) {
    int _v;
    int res = swig::asptr(argv[0], (std::vector< pj::Buddy,std::allocator< pj::Buddy > >**)(0));
    _v = SWIG_CheckState(res);
    if (_v) {
      swig::SwigPyIterator *iter = 0;
      int res = SWIG_ConvertPtr(argv[1], SWIG_as_voidptrptr(&iter), swig::SwigPyIterator::descriptor(), 0);
      _v = (SWIG_IsOK(res) && iter && (dynamic_cast<swig::SwigPyIterator_T<std::vector< pj::Buddy >::iterator > *>(iter) != 0));
      if (_v) {
        {
          int res = SWIG_AsVal_size_t(argv[2], NULL);
          _v = SWIG_CheckState(res);
        }
        if (_v) {
          int res = SWIG_ConvertPtr(argv[3], 0, SWIGTYPE_p_pj__Buddy, SWIG_POINTER_NO_NULL | 0);
          _v = SWIG_CheckState(res);
          if (_v) {
            return _wrap_BuddyVector2_insert__SWIG_1(self, argc, argv);
          }
        }
      }
    }
  }
  
fail:
  SWIG_Python_RaiseOrModifyTypeError("Wrong number or type of arguments for overloaded function 'BuddyVector2_insert'.\n"
    "  Possible C/C++ prototypes are:\n"
    "    std::vector< pj::Buddy >::insert(std::vector< pj::Buddy >::iterator,std::vector< pj::Buddy >::value_type const &)\n"
    "    std::vector< pj::Buddy >::insert(std::vector< pj::Buddy >::iterator,std::vector< pj::Buddy >::size_type,std::vector< pj::Buddy >::value_type const &)\n");
  return 0;
}


SWIGINTERN PyObject *_wrap_BuddyVector2_reserve(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  std::vector< pj::Buddy > *arg1 = (std::vector< pj::Buddy > *) 0 ;
  std::vector< pj::Buddy >::size_type arg2 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  size_t val2 ;
  int ecode2 = 0 ;
  PyObject *swig_obj[2] ;
  
  if (!SWIG_Python_UnpackTuple(args, "BuddyVector2_reserve", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__vectorT_pj__Buddy_std__allocatorT_pj__Buddy_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "BuddyVector2_reserve" "', argument " "1"" of type '" "std::vector< pj::Buddy > *""'"); 
  }
  arg1 = reinterpret_cast< std::vector< pj::Buddy > * >(argp1);
  ecode2 = SWIG_AsVal_size_t(swig_obj[1], &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "BuddyVector2_reserve" "', argument " "2"" of type '" "std::vector< pj::Buddy >::size_type""'");
  } 
  arg2 = static_cast< std::vector< pj::Buddy >::size_type >(val2);
  (arg1)->reserve(arg2);
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_BuddyVector2_capacity(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  std::vector< pj::Buddy > *arg1 = (std::vector< pj::Buddy > *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  std::vector< pj::Buddy >::size_type result;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__vectorT_pj__Buddy_std__allocatorT_pj__Buddy_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "BuddyVector2_capacity" "', argument " "1"" of type '" "std::vector< pj::Buddy > const *""'"); 
  }
  arg1 = reinterpret_cast< std::vector< pj::Buddy > * >(argp1);
  result = ((std::vector< pj::Buddy > const *)arg1)->capacity();
  resultobj = SWIG_From_size_t(static_cast< size_t >(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_delete_BuddyVector2(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  std::vector< pj::Buddy > *arg1 = (std::vector< pj::Buddy > *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__vectorT_pj__Buddy_std__allocatorT_pj__Buddy_t_t, SWIG_POINTER_DISOWN |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "delete_BuddyVector2" "', argument " "1"" of type '" "std::vector< pj::Buddy > *""'"); 
  }
  arg1 = reinterpret_cast< std::vector< pj::Buddy > * >(argp1);
  delete arg1;
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *BuddyVector2_swigregister(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *obj;
  if (!SWIG_Python_UnpackTuple(args, "swigregister", 1, 1, &obj)) return NULL;
  SWIG_TypeNewClientData(SWIGTYPE_p_std__vectorT_pj__Buddy_std__allocatorT_pj__Buddy_t_t, SWIG_NewClientData(obj));
  return SWIG_Py_Void();
}

SWIGINTERN PyObject *BuddyVector2_swiginit(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  return SWIG_Python_InitShadowInstance(args);
}

SWIGINTERN PyObject *_wrap_AudioMediaVector_iterator(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  std::vector< pj::AudioMedia * > *arg1 = (std::vector< pj::AudioMedia * > *) 0 ;
  PyObject **arg2 = (PyObject **) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  swig::SwigPyIterator *result = 0 ;
  
  arg2 = &swig_obj[0];
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__vectorT_pj__AudioMedia_p_std__allocatorT_pj__AudioMedia_p_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "AudioMediaVector_iterator" "', argument " "1"" of type '" "std::vector< pj::AudioMedia * > *""'"); 
  }
  arg1 = reinterpret_cast< std::vector< pj::AudioMedia * > * >(argp1);
  result = (swig::SwigPyIterator *)std_vector_Sl_pj_AudioMedia_Sm__Sg__iterator(arg1,arg2);
  resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(result), SWIGTYPE_p_swig__SwigPyIterator, SWIG_POINTER_OWN |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_AudioMediaVector___nonzero__(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  std::vector< pj::AudioMedia * > *arg1 = (std::vector< pj::AudioMedia * > *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  bool result;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__vectorT_pj__AudioMedia_p_std__allocatorT_pj__AudioMedia_p_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "AudioMediaVector___nonzero__" "', argument " "1"" of type '" "std::vector< pj::AudioMedia * > const *""'"); 
  }
  arg1 = reinterpret_cast< std::vector< pj::AudioMedia * > * >(argp1);
  result = (bool)std_vector_Sl_pj_AudioMedia_Sm__Sg____nonzero__((std::vector< pj::AudioMedia * > const *)arg1);
  resultobj = SWIG_From_bool(static_cast< bool >(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_AudioMediaVector___bool__(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  std::vector< pj::AudioMedia * > *arg1 = (std::vector< pj::AudioMedia * > *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  bool result;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__vectorT_pj__AudioMedia_p_std__allocatorT_pj__AudioMedia_p_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "AudioMediaVector___bool__" "', argument " "1"" of type '" "std::vector< pj::AudioMedia * > const *""'"); 
  }
  arg1 = reinterpret_cast< std::vector< pj::AudioMedia * > * >(argp1);
  result = (bool)std_vector_Sl_pj_AudioMedia_Sm__Sg____bool__((std::vector< pj::AudioMedia * > const *)arg1);
  resultobj = SWIG_From_bool(static_cast< bool >(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_AudioMediaVector___len__(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  std::vector< pj::AudioMedia * > *arg1 = (std::vector< pj::AudioMedia * > *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  std::vector< pj::AudioMedia * >::size_type result;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__vectorT_pj__AudioMedia_p_std__allocatorT_pj__AudioMedia_p_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "AudioMediaVector___len__" "', argument " "1"" of type '" "std::vector< pj::AudioMedia * > const *""'"); 
  }
  arg1 = reinterpret_cast< std::vector< pj::AudioMedia * > * >(argp1);
  result = std_vector_Sl_pj_AudioMedia_Sm__Sg____len__((std::vector< pj::AudioMedia * > const *)arg1);
  resultobj = SWIG_From_size_t(static_cast< size_t >(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_AudioMediaVector___getslice__(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  std::vector< pj::AudioMedia * > *arg1 = (std::vector< pj::AudioMedia * > *) 0 ;
  std::vector< pj::AudioMedia * >::difference_type arg2 ;
  std::vector< pj::AudioMedia * >::difference_type arg3 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  ptrdiff_t val2 ;
  int ecode2 = 0 ;
  ptrdiff_t val3 ;
  int ecode3 = 0 ;
  PyObject *swig_obj[3] ;
  std::vector< pj::AudioMedia *,std::allocator< pj::AudioMedia * > > *result = 0 ;
  
  if (!SWIG_Python_UnpackTuple(args, "AudioMediaVector___getslice__", 3, 3, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__vectorT_pj__AudioMedia_p_std__allocatorT_pj__AudioMedia_p_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "AudioMediaVector___getslice__" "', argument " "1"" of type '" "std::vector< pj::AudioMedia * > *""'"); 
  }
  arg1 = reinterpret_cast< std::vector< pj::AudioMedia * > * >(argp1);
  ecode2 = SWIG_AsVal_ptrdiff_t(swig_obj[1], &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "AudioMediaVector___getslice__" "', argument " "2"" of type '" "std::vector< pj::AudioMedia * >::difference_type""'");
  } 
  arg2 = static_cast< std::vector< pj::AudioMedia * >::difference_type >(val2);
  ecode3 = SWIG_AsVal_ptrdiff_t(swig_obj[2], &val3);
  if (!SWIG_IsOK(ecode3)) {
    SWIG_exception_fail(SWIG_ArgError(ecode3), "in method '" "AudioMediaVector___getslice__" "', argument " "3"" of type '" "std::vector< pj::AudioMedia * >::difference_type""'");
  } 
  arg3 = static_cast< std::vector< pj::AudioMedia * >::difference_type >(val3);
  try {
    result = (std::vector< pj::AudioMedia *,std::allocator< pj::AudioMedia * > > *)std_vector_Sl_pj_AudioMedia_Sm__Sg____getslice__(arg1,arg2,arg3);
  } catch(std::out_of_range &_e) {
    SWIG_exception_fail(SWIG_IndexError, (&_e)->what());
  } catch(std::invalid_argument &_e) {
    SWIG_exception_fail(SWIG_ValueError, (&_e)->what());
  }
  resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(result), SWIGTYPE_p_std__vectorT_pj__AudioMedia_p_std__allocatorT_pj__AudioMedia_p_t_t, SWIG_POINTER_OWN |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_AudioMediaVector___setslice____SWIG_0(PyObject *SWIGUNUSEDPARM(self), Py_ssize_t nobjs, PyObject **swig_obj) {
  PyObject *resultobj = 0;
  std::vector< pj::AudioMedia * > *arg1 = (std::vector< pj::AudioMedia * > *) 0 ;
  std::vector< pj::AudioMedia * >::difference_type arg2 ;
  std::vector< pj::AudioMedia * >::difference_type arg3 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  ptrdiff_t val2 ;
  int ecode2 = 0 ;
  ptrdiff_t val3 ;
  int ecode3 = 0 ;
  
  if ((nobjs < 3) || (nobjs > 3)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__vectorT_pj__AudioMedia_p_std__allocatorT_pj__AudioMedia_p_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "AudioMediaVector___setslice__" "', argument " "1"" of type '" "std::vector< pj::AudioMedia * > *""'"); 
  }
  arg1 = reinterpret_cast< std::vector< pj::AudioMedia * > * >(argp1);
  ecode2 = SWIG_AsVal_ptrdiff_t(swig_obj[1], &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "AudioMediaVector___setslice__" "', argument " "2"" of type '" "std::vector< pj::AudioMedia * >::difference_type""'");
  } 
  arg2 = static_cast< std::vector< pj::AudioMedia * >::difference_type >(val2);
  ecode3 = SWIG_AsVal_ptrdiff_t(swig_obj[2], &val3);
  if (!SWIG_IsOK(ecode3)) {
    SWIG_exception_fail(SWIG_ArgError(ecode3), "in method '" "AudioMediaVector___setslice__" "', argument " "3"" of type '" "std::vector< pj::AudioMedia * >::difference_type""'");
  } 
  arg3 = static_cast< std::vector< pj::AudioMedia * >::difference_type >(val3);
  try {
    std_vector_Sl_pj_AudioMedia_Sm__Sg____setslice____SWIG_0(arg1,arg2,arg3);
  } catch(std::out_of_range &_e) {
    SWIG_exception_fail(SWIG_IndexError, (&_e)->what());
  } catch(std::invalid_argument &_e) {
    SWIG_exception_fail(SWIG_ValueError, (&_e)->what());
  }
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_AudioMediaVector___setslice____SWIG_1(PyObject *SWIGUNUSEDPARM(self), Py_ssize_t nobjs, PyObject **swig_obj) {
  PyObject *resultobj = 0;
  std::vector< pj::AudioMedia * > *arg1 = (std::vector< pj::AudioMedia * > *) 0 ;
  std::vector< pj::AudioMedia * >::difference_type arg2 ;
  std::vector< pj::AudioMedia * >::difference_type arg3 ;
  std::vector< pj::AudioMedia *,std::allocator< pj::AudioMedia * > > *arg4 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  ptrdiff_t val2 ;
  int ecode2 = 0 ;
  ptrdiff_t val3 ;
  int ecode3 = 0 ;
  int res4 = SWIG_OLDOBJ ;
  
  if ((nobjs < 4) || (nobjs > 4)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__vectorT_pj__AudioMedia_p_std__allocatorT_pj__AudioMedia_p_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "AudioMediaVector___setslice__" "', argument " "1"" of type '" "std::vector< pj::AudioMedia * > *""'"); 
  }
  arg1 = reinterpret_cast< std::vector< pj::AudioMedia * > * >(argp1);
  ecode2 = SWIG_AsVal_ptrdiff_t(swig_obj[1], &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "AudioMediaVector___setslice__" "', argument " "2"" of type '" "std::vector< pj::AudioMedia * >::difference_type""'");
  } 
  arg2 = static_cast< std::vector< pj::AudioMedia * >::difference_type >(val2);
  ecode3 = SWIG_AsVal_ptrdiff_t(swig_obj[2], &val3);
  if (!SWIG_IsOK(ecode3)) {
    SWIG_exception_fail(SWIG_ArgError(ecode3), "in method '" "AudioMediaVector___setslice__" "', argument " "3"" of type '" "std::vector< pj::AudioMedia * >::difference_type""'");
  } 
  arg3 = static_cast< std::vector< pj::AudioMedia * >::difference_type >(val3);
  {
    std::vector< pj::AudioMedia*,std::allocator< pj::AudioMedia * > > *ptr = (std::vector< pj::AudioMedia*,std::allocator< pj::AudioMedia * > > *)0;
    res4 = swig::asptr(swig_obj[3], &ptr);
    if (!SWIG_IsOK(res4)) {
      SWIG_exception_fail(SWIG_ArgError(res4), "in method '" "AudioMediaVector___setslice__" "', argument " "4"" of type '" "std::vector< pj::AudioMedia *,std::allocator< pj::AudioMedia * > > const &""'"); 
    }
    if (!ptr) {
      SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "AudioMediaVector___setslice__" "', argument " "4"" of type '" "std::vector< pj::AudioMedia *,std::allocator< pj::AudioMedia * > > const &""'"); 
    }
    arg4 = ptr;
  }
  try {
    std_vector_Sl_pj_AudioMedia_Sm__Sg____setslice____SWIG_1(arg1,arg2,arg3,(std::vector< pj::AudioMedia *,std::allocator< pj::AudioMedia * > > const &)*arg4);
  } catch(std::out_of_range &_e) {
    SWIG_exception_fail(SWIG_IndexError, (&_e)->what());
  } catch(std::invalid_argument &_e) {
    SWIG_exception_fail(SWIG_ValueError, (&_e)->what());
  }
  resultobj = SWIG_Py_Void();
  if (SWIG_IsNewObj(res4)) delete arg4;
  return resultobj;
fail:
  if (SWIG_IsNewObj(res4)) delete arg4;
  return NULL;
}


SWIGINTERN PyObject *_wrap_AudioMediaVector___setslice__(PyObject *self, PyObject *args) {
  Py_ssize_t argc;
  PyObject *argv[5] = {
    0
  };
  
  if (!(argc = SWIG_Python_UnpackTuple(args, "AudioMediaVector___setslice__", 0, 4, argv))) SWIG_fail;
  --argc;
  if (argc == 3) {
    int _v;
    int res = swig::asptr(argv[0], (std::vector< pj::AudioMedia*,std::allocator< pj::AudioMedia * > >**)(0));
    _v = SWIG_CheckState(res);
    if (_v) {
      {
        int res = SWIG_AsVal_ptrdiff_t(argv[1], NULL);
        _v = SWIG_CheckState(res);
      }
      if (_v) {
        {
          int res = SWIG_AsVal_ptrdiff_t(argv[2], NULL);
          _v = SWIG_CheckState(res);
        }
        if (_v) {
          return _wrap_AudioMediaVector___setslice____SWIG_0(self, argc, argv);
        }
      }
    }
  }
  if (argc == 4) {
    int _v;
    int res = swig::asptr(argv[0], (std::vector< pj::AudioMedia*,std::allocator< pj::AudioMedia * > >**)(0));
    _v = SWIG_CheckState(res);
    if (_v) {
      {
        int res = SWIG_AsVal_ptrdiff_t(argv[1], NULL);
        _v = SWIG_CheckState(res);
      }
      if (_v) {
        {
          int res = SWIG_AsVal_ptrdiff_t(argv[2], NULL);
          _v = SWIG_CheckState(res);
        }
        if (_v) {
          int res = swig::asptr(argv[3], (std::vector< pj::AudioMedia*,std::allocator< pj::AudioMedia * > >**)(0));
          _v = SWIG_CheckState(res);
          if (_v) {
            return _wrap_AudioMediaVector___setslice____SWIG_1(self, argc, argv);
          }
        }
      }
    }
  }
  
fail:
  SWIG_Python_RaiseOrModifyTypeError("Wrong number or type of arguments for overloaded function 'AudioMediaVector___setslice__'.\n"
    "  Possible C/C++ prototypes are:\n"
    "    std::vector< pj::AudioMedia * >::__setslice__(std::vector< pj::AudioMedia * >::difference_type,std::vector< pj::AudioMedia * >::difference_type)\n"
    "    std::vector< pj::AudioMedia * >::__setslice__(std::vector< pj::AudioMedia * >::difference_type,std::vector< pj::AudioMedia * >::difference_type,std::vector< pj::AudioMedia *,std::allocator< pj::AudioMedia * > > const &)\n");
  return 0;
}


SWIGINTERN PyObject *_wrap_AudioMediaVector___delslice__(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  std::vector< pj::AudioMedia * > *arg1 = (std::vector< pj::AudioMedia * > *) 0 ;
  std::vector< pj::AudioMedia * >::difference_type arg2 ;
  std::vector< pj::AudioMedia * >::difference_type arg3 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  ptrdiff_t val2 ;
  int ecode2 = 0 ;
  ptrdiff_t val3 ;
  int ecode3 = 0 ;
  PyObject *swig_obj[3] ;
  
  if (!SWIG_Python_UnpackTuple(args, "AudioMediaVector___delslice__", 3, 3, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__vectorT_pj__AudioMedia_p_std__allocatorT_pj__AudioMedia_p_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "AudioMediaVector___delslice__" "', argument " "1"" of type '" "std::vector< pj::AudioMedia * > *""'"); 
  }
  arg1 = reinterpret_cast< std::vector< pj::AudioMedia * > * >(argp1);
  ecode2 = SWIG_AsVal_ptrdiff_t(swig_obj[1], &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "AudioMediaVector___delslice__" "', argument " "2"" of type '" "std::vector< pj::AudioMedia * >::difference_type""'");
  } 
  arg2 = static_cast< std::vector< pj::AudioMedia * >::difference_type >(val2);
  ecode3 = SWIG_AsVal_ptrdiff_t(swig_obj[2], &val3);
  if (!SWIG_IsOK(ecode3)) {
    SWIG_exception_fail(SWIG_ArgError(ecode3), "in method '" "AudioMediaVector___delslice__" "', argument " "3"" of type '" "std::vector< pj::AudioMedia * >::difference_type""'");
  } 
  arg3 = static_cast< std::vector< pj::AudioMedia * >::difference_type >(val3);
  try {
    std_vector_Sl_pj_AudioMedia_Sm__Sg____delslice__(arg1,arg2,arg3);
  } catch(std::out_of_range &_e) {
    SWIG_exception_fail(SWIG_IndexError, (&_e)->what());
  } catch(std::invalid_argument &_e) {
    SWIG_exception_fail(SWIG_ValueError, (&_e)->what());
  }
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_AudioMediaVector___delitem____SWIG_0(PyObject *SWIGUNUSEDPARM(self), Py_ssize_t nobjs, PyObject **swig_obj) {
  PyObject *resultobj = 0;
  std::vector< pj::AudioMedia * > *arg1 = (std::vector< pj::AudioMedia * > *) 0 ;
  std::vector< pj::AudioMedia * >::difference_type arg2 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  ptrdiff_t val2 ;
  int ecode2 = 0 ;
  
  if ((nobjs < 2) || (nobjs > 2)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__vectorT_pj__AudioMedia_p_std__allocatorT_pj__AudioMedia_p_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "AudioMediaVector___delitem__" "', argument " "1"" of type '" "std::vector< pj::AudioMedia * > *""'"); 
  }
  arg1 = reinterpret_cast< std::vector< pj::AudioMedia * > * >(argp1);
  ecode2 = SWIG_AsVal_ptrdiff_t(swig_obj[1], &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "AudioMediaVector___delitem__" "', argument " "2"" of type '" "std::vector< pj::AudioMedia * >::difference_type""'");
  } 
  arg2 = static_cast< std::vector< pj::AudioMedia * >::difference_type >(val2);
  try {
    std_vector_Sl_pj_AudioMedia_Sm__Sg____delitem____SWIG_0(arg1,arg2);
  } catch(std::out_of_range &_e) {
    SWIG_exception_fail(SWIG_IndexError, (&_e)->what());
  } catch(std::invalid_argument &_e) {
    SWIG_exception_fail(SWIG_ValueError, (&_e)->what());
  }
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_AudioMediaVector___getitem____SWIG_0(PyObject *SWIGUNUSEDPARM(self), Py_ssize_t nobjs, PyObject **swig_obj) {
  PyObject *resultobj = 0;
  std::vector< pj::AudioMedia * > *arg1 = (std::vector< pj::AudioMedia * > *) 0 ;
  PySliceObject *arg2 = (PySliceObject *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  std::vector< pj::AudioMedia *,std::allocator< pj::AudioMedia * > > *result = 0 ;
  
  if ((nobjs < 2) || (nobjs > 2)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__vectorT_pj__AudioMedia_p_std__allocatorT_pj__AudioMedia_p_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "AudioMediaVector___getitem__" "', argument " "1"" of type '" "std::vector< pj::AudioMedia * > *""'"); 
  }
  arg1 = reinterpret_cast< std::vector< pj::AudioMedia * > * >(argp1);
  {
    if (!PySlice_Check(swig_obj[1])) {
      SWIG_exception_fail(SWIG_ArgError(SWIG_TypeError), "in method '" "AudioMediaVector___getitem__" "', argument " "2"" of type '" "PySliceObject *""'");
    }
    arg2 = (PySliceObject *) swig_obj[1];
  }
  try {
    result = (std::vector< pj::AudioMedia *,std::allocator< pj::AudioMedia * > > *)std_vector_Sl_pj_AudioMedia_Sm__Sg____getitem____SWIG_0(arg1,arg2);
  } catch(std::out_of_range &_e) {
    SWIG_exception_fail(SWIG_IndexError, (&_e)->what());
  } catch(std::invalid_argument &_e) {
    SWIG_exception_fail(SWIG_ValueError, (&_e)->what());
  }
  resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(result), SWIGTYPE_p_std__vectorT_pj__AudioMedia_p_std__allocatorT_pj__AudioMedia_p_t_t, SWIG_POINTER_OWN |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_AudioMediaVector___setitem____SWIG_0(PyObject *SWIGUNUSEDPARM(self), Py_ssize_t nobjs, PyObject **swig_obj) {
  PyObject *resultobj = 0;
  std::vector< pj::AudioMedia * > *arg1 = (std::vector< pj::AudioMedia * > *) 0 ;
  PySliceObject *arg2 = (PySliceObject *) 0 ;
  std::vector< pj::AudioMedia *,std::allocator< pj::AudioMedia * > > *arg3 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  int res3 = SWIG_OLDOBJ ;
  
  if ((nobjs < 3) || (nobjs > 3)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__vectorT_pj__AudioMedia_p_std__allocatorT_pj__AudioMedia_p_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "AudioMediaVector___setitem__" "', argument " "1"" of type '" "std::vector< pj::AudioMedia * > *""'"); 
  }
  arg1 = reinterpret_cast< std::vector< pj::AudioMedia * > * >(argp1);
  {
    if (!PySlice_Check(swig_obj[1])) {
      SWIG_exception_fail(SWIG_ArgError(SWIG_TypeError), "in method '" "AudioMediaVector___setitem__" "', argument " "2"" of type '" "PySliceObject *""'");
    }
    arg2 = (PySliceObject *) swig_obj[1];
  }
  {
    std::vector< pj::AudioMedia*,std::allocator< pj::AudioMedia * > > *ptr = (std::vector< pj::AudioMedia*,std::allocator< pj::AudioMedia * > > *)0;
    res3 = swig::asptr(swig_obj[2], &ptr);
    if (!SWIG_IsOK(res3)) {
      SWIG_exception_fail(SWIG_ArgError(res3), "in method '" "AudioMediaVector___setitem__" "', argument " "3"" of type '" "std::vector< pj::AudioMedia *,std::allocator< pj::AudioMedia * > > const &""'"); 
    }
    if (!ptr) {
      SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "AudioMediaVector___setitem__" "', argument " "3"" of type '" "std::vector< pj::AudioMedia *,std::allocator< pj::AudioMedia * > > const &""'"); 
    }
    arg3 = ptr;
  }
  try {
    std_vector_Sl_pj_AudioMedia_Sm__Sg____setitem____SWIG_0(arg1,arg2,(std::vector< pj::AudioMedia *,std::allocator< pj::AudioMedia * > > const &)*arg3);
  } catch(std::out_of_range &_e) {
    SWIG_exception_fail(SWIG_IndexError, (&_e)->what());
  } catch(std::invalid_argument &_e) {
    SWIG_exception_fail(SWIG_ValueError, (&_e)->what());
  }
  resultobj = SWIG_Py_Void();
  if (SWIG_IsNewObj(res3)) delete arg3;
  return resultobj;
fail:
  if (SWIG_IsNewObj(res3)) delete arg3;
  return NULL;
}


SWIGINTERN PyObject *_wrap_AudioMediaVector___setitem____SWIG_1(PyObject *SWIGUNUSEDPARM(self), Py_ssize_t nobjs, PyObject **swig_obj) {
  PyObject *resultobj = 0;
  std::vector< pj::AudioMedia * > *arg1 = (std::vector< pj::AudioMedia * > *) 0 ;
  PySliceObject *arg2 = (PySliceObject *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  
  if ((nobjs < 2) || (nobjs > 2)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__vectorT_pj__AudioMedia_p_std__allocatorT_pj__AudioMedia_p_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "AudioMediaVector___setitem__" "', argument " "1"" of type '" "std::vector< pj::AudioMedia * > *""'"); 
  }
  arg1 = reinterpret_cast< std::vector< pj::AudioMedia * > * >(argp1);
  {
    if (!PySlice_Check(swig_obj[1])) {
      SWIG_exception_fail(SWIG_ArgError(SWIG_TypeError), "in method '" "AudioMediaVector___setitem__" "', argument " "2"" of type '" "PySliceObject *""'");
    }
    arg2 = (PySliceObject *) swig_obj[1];
  }
  try {
    std_vector_Sl_pj_AudioMedia_Sm__Sg____setitem____SWIG_1(arg1,arg2);
  } catch(std::out_of_range &_e) {
    SWIG_exception_fail(SWIG_IndexError, (&_e)->what());
  } catch(std::invalid_argument &_e) {
    SWIG_exception_fail(SWIG_ValueError, (&_e)->what());
  }
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_AudioMediaVector___delitem____SWIG_1(PyObject *SWIGUNUSEDPARM(self), Py_ssize_t nobjs, PyObject **swig_obj) {
  PyObject *resultobj = 0;
  std::vector< pj::AudioMedia * > *arg1 = (std::vector< pj::AudioMedia * > *) 0 ;
  PySliceObject *arg2 = (PySliceObject *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  
  if ((nobjs < 2) || (nobjs > 2)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__vectorT_pj__AudioMedia_p_std__allocatorT_pj__AudioMedia_p_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "AudioMediaVector___delitem__" "', argument " "1"" of type '" "std::vector< pj::AudioMedia * > *""'"); 
  }
  arg1 = reinterpret_cast< std::vector< pj::AudioMedia * > * >(argp1);
  {
    if (!PySlice_Check(swig_obj[1])) {
      SWIG_exception_fail(SWIG_ArgError(SWIG_TypeError), "in method '" "AudioMediaVector___delitem__" "', argument " "2"" of type '" "PySliceObject *""'");
    }
    arg2 = (PySliceObject *) swig_obj[1];
  }
  try {
    std_vector_Sl_pj_AudioMedia_Sm__Sg____delitem____SWIG_1(arg1,arg2);
  } catch(std::out_of_range &_e) {
    SWIG_exception_fail(SWIG_IndexError, (&_e)->what());
  } catch(std::invalid_argument &_e) {
    SWIG_exception_fail(SWIG_ValueError, (&_e)->what());
  }
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_AudioMediaVector___delitem__(PyObject *self, PyObject *args) {
  Py_ssize_t argc;
  PyObject *argv[3] = {
    0
  };
  
  if (!(argc = SWIG_Python_UnpackTuple(args, "AudioMediaVector___delitem__", 0, 2, argv))) SWIG_fail;
  --argc;
  if (argc == 2) {
    int _v;
    int res = swig::asptr(argv[0], (std::vector< pj::AudioMedia*,std::allocator< pj::AudioMedia * > >**)(0));
    _v = SWIG_CheckState(res);
    if (_v) {
      {
        _v = PySlice_Check(argv[1]);
      }
      if (_v) {
        return _wrap_AudioMediaVector___delitem____SWIG_1(self, argc, argv);
      }
    }
  }
  if (argc == 2) {
    int _v;
    int res = swig::asptr(argv[0], (std::vector< pj::AudioMedia*,std::allocator< pj::AudioMedia * > >**)(0));
    _v = SWIG_CheckState(res);
    if (_v) {
      {
        int res = SWIG_AsVal_ptrdiff_t(argv[1], NULL);
        _v = SWIG_CheckState(res);
      }
      if (_v) {
        return _wrap_AudioMediaVector___delitem____SWIG_0(self, argc, argv);
      }
    }
  }
  
fail:
  SWIG_Python_RaiseOrModifyTypeError("Wrong number or type of arguments for overloaded function 'AudioMediaVector___delitem__'.\n"
    "  Possible C/C++ prototypes are:\n"
    "    std::vector< pj::AudioMedia * >::__delitem__(std::vector< pj::AudioMedia * >::difference_type)\n"
    "    std::vector< pj::AudioMedia * >::__delitem__(PySliceObject *)\n");
  return 0;
}


SWIGINTERN PyObject *_wrap_AudioMediaVector___getitem____SWIG_1(PyObject *SWIGUNUSEDPARM(self), Py_ssize_t nobjs, PyObject **swig_obj) {
  PyObject *resultobj = 0;
  std::vector< pj::AudioMedia * > *arg1 = (std::vector< pj::AudioMedia * > *) 0 ;
  std::vector< pj::AudioMedia * >::difference_type arg2 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  ptrdiff_t val2 ;
  int ecode2 = 0 ;
  std::vector< pj::AudioMedia * >::value_type result;
  
  if ((nobjs < 2) || (nobjs > 2)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__vectorT_pj__AudioMedia_p_std__allocatorT_pj__AudioMedia_p_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "AudioMediaVector___getitem__" "', argument " "1"" of type '" "std::vector< pj::AudioMedia * > *""'"); 
  }
  arg1 = reinterpret_cast< std::vector< pj::AudioMedia * > * >(argp1);
  ecode2 = SWIG_AsVal_ptrdiff_t(swig_obj[1], &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "AudioMediaVector___getitem__" "', argument " "2"" of type '" "std::vector< pj::AudioMedia * >::difference_type""'");
  } 
  arg2 = static_cast< std::vector< pj::AudioMedia * >::difference_type >(val2);
  try {
    result = (std::vector< pj::AudioMedia * >::value_type)std_vector_Sl_pj_AudioMedia_Sm__Sg____getitem____SWIG_1(arg1,arg2);
  } catch(std::out_of_range &_e) {
    SWIG_exception_fail(SWIG_IndexError, (&_e)->what());
  }
  resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(result), SWIGTYPE_p_pj__AudioMedia, 0 |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_AudioMediaVector___getitem__(PyObject *self, PyObject *args) {
  Py_ssize_t argc;
  PyObject *argv[3] = {
    0
  };
  
  if (!(argc = SWIG_Python_UnpackTuple(args, "AudioMediaVector___getitem__", 0, 2, argv))) SWIG_fail;
  --argc;
  if (argc == 2) {
    int _v;
    int res = swig::asptr(argv[0], (std::vector< pj::AudioMedia*,std::allocator< pj::AudioMedia * > >**)(0));
    _v = SWIG_CheckState(res);
    if (_v) {
      {
        _v = PySlice_Check(argv[1]);
      }
      if (_v) {
        return _wrap_AudioMediaVector___getitem____SWIG_0(self, argc, argv);
      }
    }
  }
  if (argc == 2) {
    int _v;
    int res = swig::asptr(argv[0], (std::vector< pj::AudioMedia*,std::allocator< pj::AudioMedia * > >**)(0));
    _v = SWIG_CheckState(res);
    if (_v) {
      {
        int res = SWIG_AsVal_ptrdiff_t(argv[1], NULL);
        _v = SWIG_CheckState(res);
      }
      if (_v) {
        return _wrap_AudioMediaVector___getitem____SWIG_1(self, argc, argv);
      }
    }
  }
  
fail:
  SWIG_Python_RaiseOrModifyTypeError("Wrong number or type of arguments for overloaded function 'AudioMediaVector___getitem__'.\n"
    "  Possible C/C++ prototypes are:\n"
    "    std::vector< pj::AudioMedia * >::__getitem__(PySliceObject *)\n"
    "    std::vector< pj::AudioMedia * >::__getitem__(std::vector< pj::AudioMedia * >::difference_type)\n");
  return 0;
}


SWIGINTERN PyObject *_wrap_AudioMediaVector___setitem____SWIG_2(PyObject *SWIGUNUSEDPARM(self), Py_ssize_t nobjs, PyObject **swig_obj) {
  PyObject *resultobj = 0;
  std::vector< pj::AudioMedia * > *arg1 = (std::vector< pj::AudioMedia * > *) 0 ;
  std::vector< pj::AudioMedia * >::difference_type arg2 ;
  std::vector< pj::AudioMedia * >::value_type arg3 = (std::vector< pj::AudioMedia * >::value_type) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  ptrdiff_t val2 ;
  int ecode2 = 0 ;
  void *argp3 = 0 ;
  int res3 = 0 ;
  
  if ((nobjs < 3) || (nobjs > 3)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__vectorT_pj__AudioMedia_p_std__allocatorT_pj__AudioMedia_p_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "AudioMediaVector___setitem__" "', argument " "1"" of type '" "std::vector< pj::AudioMedia * > *""'"); 
  }
  arg1 = reinterpret_cast< std::vector< pj::AudioMedia * > * >(argp1);
  ecode2 = SWIG_AsVal_ptrdiff_t(swig_obj[1], &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "AudioMediaVector___setitem__" "', argument " "2"" of type '" "std::vector< pj::AudioMedia * >::difference_type""'");
  } 
  arg2 = static_cast< std::vector< pj::AudioMedia * >::difference_type >(val2);
  res3 = SWIG_ConvertPtr(swig_obj[2], &argp3,SWIGTYPE_p_pj__AudioMedia, 0 |  0 );
  if (!SWIG_IsOK(res3)) {
    SWIG_exception_fail(SWIG_ArgError(res3), "in method '" "AudioMediaVector___setitem__" "', argument " "3"" of type '" "std::vector< pj::AudioMedia * >::value_type""'"); 
  }
  arg3 = reinterpret_cast< std::vector< pj::AudioMedia * >::value_type >(argp3);
  try {
    std_vector_Sl_pj_AudioMedia_Sm__Sg____setitem____SWIG_2(arg1,arg2,arg3);
  } catch(std::out_of_range &_e) {
    SWIG_exception_fail(SWIG_IndexError, (&_e)->what());
  }
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_AudioMediaVector___setitem__(PyObject *self, PyObject *args) {
  Py_ssize_t argc;
  PyObject *argv[4] = {
    0
  };
  
  if (!(argc = SWIG_Python_UnpackTuple(args, "AudioMediaVector___setitem__", 0, 3, argv))) SWIG_fail;
  --argc;
  if (argc == 2) {
    int _v;
    int res = swig::asptr(argv[0], (std::vector< pj::AudioMedia*,std::allocator< pj::AudioMedia * > >**)(0));
    _v = SWIG_CheckState(res);
    if (_v) {
      {
        _v = PySlice_Check(argv[1]);
      }
      if (_v) {
        return _wrap_AudioMediaVector___setitem____SWIG_1(self, argc, argv);
      }
    }
  }
  if (argc == 3) {
    int _v;
    int res = swig::asptr(argv[0], (std::vector< pj::AudioMedia*,std::allocator< pj::AudioMedia * > >**)(0));
    _v = SWIG_CheckState(res);
    if (_v) {
      {
        _v = PySlice_Check(argv[1]);
      }
      if (_v) {
        int res = swig::asptr(argv[2], (std::vector< pj::AudioMedia*,std::allocator< pj::AudioMedia * > >**)(0));
        _v = SWIG_CheckState(res);
        if (_v) {
          return _wrap_AudioMediaVector___setitem____SWIG_0(self, argc, argv);
        }
      }
    }
  }
  if (argc == 3) {
    int _v;
    int res = swig::asptr(argv[0], (std::vector< pj::AudioMedia*,std::allocator< pj::AudioMedia * > >**)(0));
    _v = SWIG_CheckState(res);
    if (_v) {
      {
        int res = SWIG_AsVal_ptrdiff_t(argv[1], NULL);
        _v = SWIG_CheckState(res);
      }
      if (_v) {
        void *vptr = 0;
        int res = SWIG_ConvertPtr(argv[2], &vptr, SWIGTYPE_p_pj__AudioMedia, 0);
        _v = SWIG_CheckState(res);
        if (_v) {
          return _wrap_AudioMediaVector___setitem____SWIG_2(self, argc, argv);
        }
      }
    }
  }
  
fail:
  SWIG_Python_RaiseOrModifyTypeError("Wrong number or type of arguments for overloaded function 'AudioMediaVector___setitem__'.\n"
    "  Possible C/C++ prototypes are:\n"
    "    std::vector< pj::AudioMedia * >::__setitem__(PySliceObject *,std::vector< pj::AudioMedia *,std::allocator< pj::AudioMedia * > > const &)\n"
    "    std::vector< pj::AudioMedia * >::__setitem__(PySliceObject *)\n"
    "    std::vector< pj::AudioMedia * >::__setitem__(std::vector< pj::AudioMedia * >::difference_type,std::vector< pj::AudioMedia * >::value_type)\n");
  return 0;
}


SWIGINTERN PyObject *_wrap_AudioMediaVector_pop(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  std::vector< pj::AudioMedia * > *arg1 = (std::vector< pj::AudioMedia * > *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  std::vector< pj::AudioMedia * >::value_type result;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__vectorT_pj__AudioMedia_p_std__allocatorT_pj__AudioMedia_p_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "AudioMediaVector_pop" "', argument " "1"" of type '" "std::vector< pj::AudioMedia * > *""'"); 
  }
  arg1 = reinterpret_cast< std::vector< pj::AudioMedia * > * >(argp1);
  try {
    result = (std::vector< pj::AudioMedia * >::value_type)std_vector_Sl_pj_AudioMedia_Sm__Sg__pop(arg1);
  } catch(std::out_of_range &_e) {
    SWIG_exception_fail(SWIG_IndexError, (&_e)->what());
  }
  resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(result), SWIGTYPE_p_pj__AudioMedia, 0 |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_AudioMediaVector_append(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  std::vector< pj::AudioMedia * > *arg1 = (std::vector< pj::AudioMedia * > *) 0 ;
  std::vector< pj::AudioMedia * >::value_type arg2 = (std::vector< pj::AudioMedia * >::value_type) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  void *argp2 = 0 ;
  int res2 = 0 ;
  PyObject *swig_obj[2] ;
  
  if (!SWIG_Python_UnpackTuple(args, "AudioMediaVector_append", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__vectorT_pj__AudioMedia_p_std__allocatorT_pj__AudioMedia_p_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "AudioMediaVector_append" "', argument " "1"" of type '" "std::vector< pj::AudioMedia * > *""'"); 
  }
  arg1 = reinterpret_cast< std::vector< pj::AudioMedia * > * >(argp1);
  res2 = SWIG_ConvertPtr(swig_obj[1], &argp2,SWIGTYPE_p_pj__AudioMedia, 0 |  0 );
  if (!SWIG_IsOK(res2)) {
    SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "AudioMediaVector_append" "', argument " "2"" of type '" "std::vector< pj::AudioMedia * >::value_type""'"); 
  }
  arg2 = reinterpret_cast< std::vector< pj::AudioMedia * >::value_type >(argp2);
  std_vector_Sl_pj_AudioMedia_Sm__Sg__append(arg1,arg2);
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_new_AudioMediaVector__SWIG_0(PyObject *SWIGUNUSEDPARM(self), Py_ssize_t nobjs, PyObject **SWIGUNUSEDPARM(swig_obj)) {
  PyObject *resultobj = 0;
  std::vector< pj::AudioMedia * > *result = 0 ;
  
  if ((nobjs < 0) || (nobjs > 0)) SWIG_fail;
  result = (std::vector< pj::AudioMedia * > *)new std::vector< pj::AudioMedia * >();
  resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(result), SWIGTYPE_p_std__vectorT_pj__AudioMedia_p_std__allocatorT_pj__AudioMedia_p_t_t, SWIG_POINTER_NEW |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_new_AudioMediaVector__SWIG_1(PyObject *SWIGUNUSEDPARM(self), Py_ssize_t nobjs, PyObject **swig_obj) {
  PyObject *resultobj = 0;
  std::vector< pj::AudioMedia * > *arg1 = 0 ;
  int res1 = SWIG_OLDOBJ ;
  std::vector< pj::AudioMedia * > *result = 0 ;
  
  if ((nobjs < 1) || (nobjs > 1)) SWIG_fail;
  {
    std::vector< pj::AudioMedia*,std::allocator< pj::AudioMedia * > > *ptr = (std::vector< pj::AudioMedia*,std::allocator< pj::AudioMedia * > > *)0;
    res1 = swig::asptr(swig_obj[0], &ptr);
    if (!SWIG_IsOK(res1)) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "new_AudioMediaVector" "', argument " "1"" of type '" "std::vector< pj::AudioMedia * > const &""'"); 
    }
    if (!ptr) {
      SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "new_AudioMediaVector" "', argument " "1"" of type '" "std::vector< pj::AudioMedia * > const &""'"); 
    }
    arg1 = ptr;
  }
  result = (std::vector< pj::AudioMedia * > *)new std::vector< pj::AudioMedia * >((std::vector< pj::AudioMedia * > const &)*arg1);
  resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(result), SWIGTYPE_p_std__vectorT_pj__AudioMedia_p_std__allocatorT_pj__AudioMedia_p_t_t, SWIG_POINTER_NEW |  0 );
  if (SWIG_IsNewObj(res1)) delete arg1;
  return resultobj;
fail:
  if (SWIG_IsNewObj(res1)) delete arg1;
  return NULL;
}


SWIGINTERN PyObject *_wrap_AudioMediaVector_empty(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  std::vector< pj::AudioMedia * > *arg1 = (std::vector< pj::AudioMedia * > *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  bool result;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__vectorT_pj__AudioMedia_p_std__allocatorT_pj__AudioMedia_p_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "AudioMediaVector_empty" "', argument " "1"" of type '" "std::vector< pj::AudioMedia * > const *""'"); 
  }
  arg1 = reinterpret_cast< std::vector< pj::AudioMedia * > * >(argp1);
  result = (bool)((std::vector< pj::AudioMedia * > const *)arg1)->empty();
  resultobj = SWIG_From_bool(static_cast< bool >(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_AudioMediaVector_size(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  std::vector< pj::AudioMedia * > *arg1 = (std::vector< pj::AudioMedia * > *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  std::vector< pj::AudioMedia * >::size_type result;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__vectorT_pj__AudioMedia_p_std__allocatorT_pj__AudioMedia_p_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "AudioMediaVector_size" "', argument " "1"" of type '" "std::vector< pj::AudioMedia * > const *""'"); 
  }
  arg1 = reinterpret_cast< std::vector< pj::AudioMedia * > * >(argp1);
  result = ((std::vector< pj::AudioMedia * > const *)arg1)->size();
  resultobj = SWIG_From_size_t(static_cast< size_t >(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_AudioMediaVector_swap(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  std::vector< pj::AudioMedia * > *arg1 = (std::vector< pj::AudioMedia * > *) 0 ;
  std::vector< pj::AudioMedia * > *arg2 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  void *argp2 = 0 ;
  int res2 = 0 ;
  PyObject *swig_obj[2] ;
  
  if (!SWIG_Python_UnpackTuple(args, "AudioMediaVector_swap", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__vectorT_pj__AudioMedia_p_std__allocatorT_pj__AudioMedia_p_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "AudioMediaVector_swap" "', argument " "1"" of type '" "std::vector< pj::AudioMedia * > *""'"); 
  }
  arg1 = reinterpret_cast< std::vector< pj::AudioMedia * > * >(argp1);
  res2 = SWIG_ConvertPtr(swig_obj[1], &argp2, SWIGTYPE_p_std__vectorT_pj__AudioMedia_p_std__allocatorT_pj__AudioMedia_p_t_t,  0 );
  if (!SWIG_IsOK(res2)) {
    SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "AudioMediaVector_swap" "', argument " "2"" of type '" "std::vector< pj::AudioMedia * > &""'"); 
  }
  if (!argp2) {
    SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "AudioMediaVector_swap" "', argument " "2"" of type '" "std::vector< pj::AudioMedia * > &""'"); 
  }
  arg2 = reinterpret_cast< std::vector< pj::AudioMedia * > * >(argp2);
  (arg1)->swap(*arg2);
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_AudioMediaVector_begin(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  std::vector< pj::AudioMedia * > *arg1 = (std::vector< pj::AudioMedia * > *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  std::vector< pj::AudioMedia * >::iterator result;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__vectorT_pj__AudioMedia_p_std__allocatorT_pj__AudioMedia_p_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "AudioMediaVector_begin" "', argument " "1"" of type '" "std::vector< pj::AudioMedia * > *""'"); 
  }
  arg1 = reinterpret_cast< std::vector< pj::AudioMedia * > * >(argp1);
  result = (arg1)->begin();
  resultobj = SWIG_NewPointerObj(swig::make_output_iterator(static_cast< const std::vector< pj::AudioMedia * >::iterator & >(result)),
    swig::SwigPyIterator::descriptor(),SWIG_POINTER_OWN);
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_AudioMediaVector_end(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  std::vector< pj::AudioMedia * > *arg1 = (std::vector< pj::AudioMedia * > *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  std::vector< pj::AudioMedia * >::iterator result;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__vectorT_pj__AudioMedia_p_std__allocatorT_pj__AudioMedia_p_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "AudioMediaVector_end" "', argument " "1"" of type '" "std::vector< pj::AudioMedia * > *""'"); 
  }
  arg1 = reinterpret_cast< std::vector< pj::AudioMedia * > * >(argp1);
  result = (arg1)->end();
  resultobj = SWIG_NewPointerObj(swig::make_output_iterator(static_cast< const std::vector< pj::AudioMedia * >::iterator & >(result)),
    swig::SwigPyIterator::descriptor(),SWIG_POINTER_OWN);
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_AudioMediaVector_rbegin(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  std::vector< pj::AudioMedia * > *arg1 = (std::vector< pj::AudioMedia * > *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  std::vector< pj::AudioMedia * >::reverse_iterator result;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__vectorT_pj__AudioMedia_p_std__allocatorT_pj__AudioMedia_p_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "AudioMediaVector_rbegin" "', argument " "1"" of type '" "std::vector< pj::AudioMedia * > *""'"); 
  }
  arg1 = reinterpret_cast< std::vector< pj::AudioMedia * > * >(argp1);
  result = (arg1)->rbegin();
  resultobj = SWIG_NewPointerObj(swig::make_output_iterator(static_cast< const std::vector< pj::AudioMedia * >::reverse_iterator & >(result)),
    swig::SwigPyIterator::descriptor(),SWIG_POINTER_OWN);
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_AudioMediaVector_rend(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  std::vector< pj::AudioMedia * > *arg1 = (std::vector< pj::AudioMedia * > *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  std::vector< pj::AudioMedia * >::reverse_iterator result;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__vectorT_pj__AudioMedia_p_std__allocatorT_pj__AudioMedia_p_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "AudioMediaVector_rend" "', argument " "1"" of type '" "std::vector< pj::AudioMedia * > *""'"); 
  }
  arg1 = reinterpret_cast< std::vector< pj::AudioMedia * > * >(argp1);
  result = (arg1)->rend();
  resultobj = SWIG_NewPointerObj(swig::make_output_iterator(static_cast< const std::vector< pj::AudioMedia * >::reverse_iterator & >(result)),
    swig::SwigPyIterator::descriptor(),SWIG_POINTER_OWN);
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_AudioMediaVector_clear(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  std::vector< pj::AudioMedia * > *arg1 = (std::vector< pj::AudioMedia * > *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__vectorT_pj__AudioMedia_p_std__allocatorT_pj__AudioMedia_p_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "AudioMediaVector_clear" "', argument " "1"" of type '" "std::vector< pj::AudioMedia * > *""'"); 
  }
  arg1 = reinterpret_cast< std::vector< pj::AudioMedia * > * >(argp1);
  (arg1)->clear();
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_AudioMediaVector_get_allocator(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  std::vector< pj::AudioMedia * > *arg1 = (std::vector< pj::AudioMedia * > *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  SwigValueWrapper< std::allocator< pj::AudioMedia * > > result;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__vectorT_pj__AudioMedia_p_std__allocatorT_pj__AudioMedia_p_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "AudioMediaVector_get_allocator" "', argument " "1"" of type '" "std::vector< pj::AudioMedia * > const *""'"); 
  }
  arg1 = reinterpret_cast< std::vector< pj::AudioMedia * > * >(argp1);
  result = ((std::vector< pj::AudioMedia * > const *)arg1)->get_allocator();
  resultobj = SWIG_NewPointerObj((new std::vector< pj::AudioMedia * >::allocator_type(static_cast< const std::vector< pj::AudioMedia * >::allocator_type& >(result))), SWIGTYPE_p_std__allocatorT_pj__AudioMedia_p_t, SWIG_POINTER_OWN |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_new_AudioMediaVector__SWIG_2(PyObject *SWIGUNUSEDPARM(self), Py_ssize_t nobjs, PyObject **swig_obj) {
  PyObject *resultobj = 0;
  std::vector< pj::AudioMedia * >::size_type arg1 ;
  size_t val1 ;
  int ecode1 = 0 ;
  std::vector< pj::AudioMedia * > *result = 0 ;
  
  if ((nobjs < 1) || (nobjs > 1)) SWIG_fail;
  ecode1 = SWIG_AsVal_size_t(swig_obj[0], &val1);
  if (!SWIG_IsOK(ecode1)) {
    SWIG_exception_fail(SWIG_ArgError(ecode1), "in method '" "new_AudioMediaVector" "', argument " "1"" of type '" "std::vector< pj::AudioMedia * >::size_type""'");
  } 
  arg1 = static_cast< std::vector< pj::AudioMedia * >::size_type >(val1);
  result = (std::vector< pj::AudioMedia * > *)new std::vector< pj::AudioMedia * >(arg1);
  resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(result), SWIGTYPE_p_std__vectorT_pj__AudioMedia_p_std__allocatorT_pj__AudioMedia_p_t_t, SWIG_POINTER_NEW |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_AudioMediaVector_pop_back(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  std::vector< pj::AudioMedia * > *arg1 = (std::vector< pj::AudioMedia * > *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__vectorT_pj__AudioMedia_p_std__allocatorT_pj__AudioMedia_p_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "AudioMediaVector_pop_back" "', argument " "1"" of type '" "std::vector< pj::AudioMedia * > *""'"); 
  }
  arg1 = reinterpret_cast< std::vector< pj::AudioMedia * > * >(argp1);
  (arg1)->pop_back();
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_AudioMediaVector_resize__SWIG_0(PyObject *SWIGUNUSEDPARM(self), Py_ssize_t nobjs, PyObject **swig_obj) {
  PyObject *resultobj = 0;
  std::vector< pj::AudioMedia * > *arg1 = (std::vector< pj::AudioMedia * > *) 0 ;
  std::vector< pj::AudioMedia * >::size_type arg2 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  size_t val2 ;
  int ecode2 = 0 ;
  
  if ((nobjs < 2) || (nobjs > 2)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__vectorT_pj__AudioMedia_p_std__allocatorT_pj__AudioMedia_p_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "AudioMediaVector_resize" "', argument " "1"" of type '" "std::vector< pj::AudioMedia * > *""'"); 
  }
  arg1 = reinterpret_cast< std::vector< pj::AudioMedia * > * >(argp1);
  ecode2 = SWIG_AsVal_size_t(swig_obj[1], &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "AudioMediaVector_resize" "', argument " "2"" of type '" "std::vector< pj::AudioMedia * >::size_type""'");
  } 
  arg2 = static_cast< std::vector< pj::AudioMedia * >::size_type >(val2);
  (arg1)->resize(arg2);
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_AudioMediaVector_erase__SWIG_0(PyObject *SWIGUNUSEDPARM(self), Py_ssize_t nobjs, PyObject **swig_obj) {
  PyObject *resultobj = 0;
  std::vector< pj::AudioMedia * > *arg1 = (std::vector< pj::AudioMedia * > *) 0 ;
  std::vector< pj::AudioMedia * >::iterator arg2 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  swig::SwigPyIterator *iter2 = 0 ;
  int res2 ;
  std::vector< pj::AudioMedia * >::iterator result;
  
  if ((nobjs < 2) || (nobjs > 2)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__vectorT_pj__AudioMedia_p_std__allocatorT_pj__AudioMedia_p_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "AudioMediaVector_erase" "', argument " "1"" of type '" "std::vector< pj::AudioMedia * > *""'"); 
  }
  arg1 = reinterpret_cast< std::vector< pj::AudioMedia * > * >(argp1);
  res2 = SWIG_ConvertPtr(swig_obj[1], SWIG_as_voidptrptr(&iter2), swig::SwigPyIterator::descriptor(), 0);
  if (!SWIG_IsOK(res2) || !iter2) {
    SWIG_exception_fail(SWIG_ArgError(SWIG_TypeError), "in method '" "AudioMediaVector_erase" "', argument " "2"" of type '" "std::vector< pj::AudioMedia * >::iterator""'");
  } else {
    swig::SwigPyIterator_T<std::vector< pj::AudioMedia * >::iterator > *iter_t = dynamic_cast<swig::SwigPyIterator_T<std::vector< pj::AudioMedia * >::iterator > *>(iter2);
    if (iter_t) {
      arg2 = iter_t->get_current();
    } else {
      SWIG_exception_fail(SWIG_ArgError(SWIG_TypeError), "in method '" "AudioMediaVector_erase" "', argument " "2"" of type '" "std::vector< pj::AudioMedia * >::iterator""'");
    }
  }
  result = std_vector_Sl_pj_AudioMedia_Sm__Sg__erase__SWIG_0(arg1,arg2);
  resultobj = SWIG_NewPointerObj(swig::make_output_iterator(static_cast< const std::vector< pj::AudioMedia * >::iterator & >(result)),
    swig::SwigPyIterator::descriptor(),SWIG_POINTER_OWN);
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_AudioMediaVector_erase__SWIG_1(PyObject *SWIGUNUSEDPARM(self), Py_ssize_t nobjs, PyObject **swig_obj) {
  PyObject *resultobj = 0;
  std::vector< pj::AudioMedia * > *arg1 = (std::vector< pj::AudioMedia * > *) 0 ;
  std::vector< pj::AudioMedia * >::iterator arg2 ;
  std::vector< pj::AudioMedia * >::iterator arg3 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  swig::SwigPyIterator *iter2 = 0 ;
  int res2 ;
  swig::SwigPyIterator *iter3 = 0 ;
  int res3 ;
  std::vector< pj::AudioMedia * >::iterator result;
  
  if ((nobjs < 3) || (nobjs > 3)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__vectorT_pj__AudioMedia_p_std__allocatorT_pj__AudioMedia_p_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "AudioMediaVector_erase" "', argument " "1"" of type '" "std::vector< pj::AudioMedia * > *""'"); 
  }
  arg1 = reinterpret_cast< std::vector< pj::AudioMedia * > * >(argp1);
  res2 = SWIG_ConvertPtr(swig_obj[1], SWIG_as_voidptrptr(&iter2), swig::SwigPyIterator::descriptor(), 0);
  if (!SWIG_IsOK(res2) || !iter2) {
    SWIG_exception_fail(SWIG_ArgError(SWIG_TypeError), "in method '" "AudioMediaVector_erase" "', argument " "2"" of type '" "std::vector< pj::AudioMedia * >::iterator""'");
  } else {
    swig::SwigPyIterator_T<std::vector< pj::AudioMedia * >::iterator > *iter_t = dynamic_cast<swig::SwigPyIterator_T<std::vector< pj::AudioMedia * >::iterator > *>(iter2);
    if (iter_t) {
      arg2 = iter_t->get_current();
    } else {
      SWIG_exception_fail(SWIG_ArgError(SWIG_TypeError), "in method '" "AudioMediaVector_erase" "', argument " "2"" of type '" "std::vector< pj::AudioMedia * >::iterator""'");
    }
  }
  res3 = SWIG_ConvertPtr(swig_obj[2], SWIG_as_voidptrptr(&iter3), swig::SwigPyIterator::descriptor(), 0);
  if (!SWIG_IsOK(res3) || !iter3) {
    SWIG_exception_fail(SWIG_ArgError(SWIG_TypeError), "in method '" "AudioMediaVector_erase" "', argument " "3"" of type '" "std::vector< pj::AudioMedia * >::iterator""'");
  } else {
    swig::SwigPyIterator_T<std::vector< pj::AudioMedia * >::iterator > *iter_t = dynamic_cast<swig::SwigPyIterator_T<std::vector< pj::AudioMedia * >::iterator > *>(iter3);
    if (iter_t) {
      arg3 = iter_t->get_current();
    } else {
      SWIG_exception_fail(SWIG_ArgError(SWIG_TypeError), "in method '" "AudioMediaVector_erase" "', argument " "3"" of type '" "std::vector< pj::AudioMedia * >::iterator""'");
    }
  }
  result = std_vector_Sl_pj_AudioMedia_Sm__Sg__erase__SWIG_1(arg1,arg2,arg3);
  resultobj = SWIG_NewPointerObj(swig::make_output_iterator(static_cast< const std::vector< pj::AudioMedia * >::iterator & >(result)),
    swig::SwigPyIterator::descriptor(),SWIG_POINTER_OWN);
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_AudioMediaVector_erase(PyObject *self, PyObject *args) {
  Py_ssize_t argc;
  PyObject *argv[4] = {
    0
  };
  
  if (!(argc = SWIG_Python_UnpackTuple(args, "AudioMediaVector_erase", 0, 3, argv))) SWIG_fail;
  --argc;
  if (argc == 2) {
    int _v;
    int res = swig::asptr(argv[0], (std::vector< pj::AudioMedia*,std::allocator< pj::AudioMedia * > >**)(0));
    _v = SWIG_CheckState(res);
    if (_v) {
      swig::SwigPyIterator *iter = 0;
      int res = SWIG_ConvertPtr(argv[1], SWIG_as_voidptrptr(&iter), swig::SwigPyIterator::descriptor(), 0);
      _v = (SWIG_IsOK(res) && iter && (dynamic_cast<swig::SwigPyIterator_T<std::vector< pj::AudioMedia * >::iterator > *>(iter) != 0));
      if (_v) {
        return _wrap_AudioMediaVector_erase__SWIG_0(self, argc, argv);
      }
    }
  }
  if (argc == 3) {
    int _v;
    int res = swig::asptr(argv[0], (std::vector< pj::AudioMedia*,std::allocator< pj::AudioMedia * > >**)(0));
    _v = SWIG_CheckState(res);
    if (_v) {
      swig::SwigPyIterator *iter = 0;
      int res = SWIG_ConvertPtr(argv[1], SWIG_as_voidptrptr(&iter), swig::SwigPyIterator::descriptor(), 0);
      _v = (SWIG_IsOK(res) && iter && (dynamic_cast<swig::SwigPyIterator_T<std::vector< pj::AudioMedia * >::iterator > *>(iter) != 0));
      if (_v) {
        swig::SwigPyIterator *iter = 0;
        int res = SWIG_ConvertPtr(argv[2], SWIG_as_voidptrptr(&iter), swig::SwigPyIterator::descriptor(), 0);
        _v = (SWIG_IsOK(res) && iter && (dynamic_cast<swig::SwigPyIterator_T<std::vector< pj::AudioMedia * >::iterator > *>(iter) != 0));
        if (_v) {
          return _wrap_AudioMediaVector_erase__SWIG_1(self, argc, argv);
        }
      }
    }
  }
  
fail:
  SWIG_Python_RaiseOrModifyTypeError("Wrong number or type of arguments for overloaded function 'AudioMediaVector_erase'.\n"
    "  Possible C/C++ prototypes are:\n"
    "    std::vector< pj::AudioMedia * >::erase(std::vector< pj::AudioMedia * >::iterator)\n"
    "    std::vector< pj::AudioMedia * >::erase(std::vector< pj::AudioMedia * >::iterator,std::vector< pj::AudioMedia * >::iterator)\n");
  return 0;
}


SWIGINTERN PyObject *_wrap_new_AudioMediaVector__SWIG_3(PyObject *SWIGUNUSEDPARM(self), Py_ssize_t nobjs, PyObject **swig_obj) {
  PyObject *resultobj = 0;
  std::vector< pj::AudioMedia * >::size_type arg1 ;
  std::vector< pj::AudioMedia * >::value_type arg2 = (std::vector< pj::AudioMedia * >::value_type) 0 ;
  size_t val1 ;
  int ecode1 = 0 ;
  void *argp2 = 0 ;
  int res2 = 0 ;
  std::vector< pj::AudioMedia * > *result = 0 ;
  
  if ((nobjs < 2) || (nobjs > 2)) SWIG_fail;
  ecode1 = SWIG_AsVal_size_t(swig_obj[0], &val1);
  if (!SWIG_IsOK(ecode1)) {
    SWIG_exception_fail(SWIG_ArgError(ecode1), "in method '" "new_AudioMediaVector" "', argument " "1"" of type '" "std::vector< pj::AudioMedia * >::size_type""'");
  } 
  arg1 = static_cast< std::vector< pj::AudioMedia * >::size_type >(val1);
  res2 = SWIG_ConvertPtr(swig_obj[1], &argp2,SWIGTYPE_p_pj__AudioMedia, 0 |  0 );
  if (!SWIG_IsOK(res2)) {
    SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "new_AudioMediaVector" "', argument " "2"" of type '" "std::vector< pj::AudioMedia * >::value_type""'"); 
  }
  arg2 = reinterpret_cast< std::vector< pj::AudioMedia * >::value_type >(argp2);
  result = (std::vector< pj::AudioMedia * > *)new std::vector< pj::AudioMedia * >(arg1,arg2);
  resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(result), SWIGTYPE_p_std__vectorT_pj__AudioMedia_p_std__allocatorT_pj__AudioMedia_p_t_t, SWIG_POINTER_NEW |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_new_AudioMediaVector(PyObject *self, PyObject *args) {
  Py_ssize_t argc;
  PyObject *argv[3] = {
    0
  };
  
  if (!(argc = SWIG_Python_UnpackTuple(args, "new_AudioMediaVector", 0, 2, argv))) SWIG_fail;
  --argc;
  if (argc == 0) {
    return _wrap_new_AudioMediaVector__SWIG_0(self, argc, argv);
  }
  if (argc == 1) {
    int _v;
    {
      int res = SWIG_AsVal_size_t(argv[0], NULL);
      _v = SWIG_CheckState(res);
    }
    if (_v) {
      return _wrap_new_AudioMediaVector__SWIG_2(self, argc, argv);
    }
  }
  if (argc == 1) {
    int _v;
    int res = swig::asptr(argv[0], (std::vector< pj::AudioMedia*,std::allocator< pj::AudioMedia * > >**)(0));
    _v = SWIG_CheckState(res);
    if (_v) {
      return _wrap_new_AudioMediaVector__SWIG_1(self, argc, argv);
    }
  }
  if (argc == 2) {
    int _v;
    {
      int res = SWIG_AsVal_size_t(argv[0], NULL);
      _v = SWIG_CheckState(res);
    }
    if (_v) {
      void *vptr = 0;
      int res = SWIG_ConvertPtr(argv[1], &vptr, SWIGTYPE_p_pj__AudioMedia, 0);
      _v = SWIG_CheckState(res);
      if (_v) {
        return _wrap_new_AudioMediaVector__SWIG_3(self, argc, argv);
      }
    }
  }
  
fail:
  SWIG_Python_RaiseOrModifyTypeError("Wrong number or type of arguments for overloaded function 'new_AudioMediaVector'.\n"
    "  Possible C/C++ prototypes are:\n"
    "    std::vector< pj::AudioMedia * >::vector()\n"
    "    std::vector< pj::AudioMedia * >::vector(std::vector< pj::AudioMedia * > const &)\n"
    "    std::vector< pj::AudioMedia * >::vector(std::vector< pj::AudioMedia * >::size_type)\n"
    "    std::vector< pj::AudioMedia * >::vector(std::vector< pj::AudioMedia * >::size_type,std::vector< pj::AudioMedia * >::value_type)\n");
  return 0;
}


SWIGINTERN PyObject *_wrap_AudioMediaVector_push_back(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  std::vector< pj::AudioMedia * > *arg1 = (std::vector< pj::AudioMedia * > *) 0 ;
  std::vector< pj::AudioMedia * >::value_type arg2 = (std::vector< pj::AudioMedia * >::value_type) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  void *argp2 = 0 ;
  int res2 = 0 ;
  PyObject *swig_obj[2] ;
  
  if (!SWIG_Python_UnpackTuple(args, "AudioMediaVector_push_back", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__vectorT_pj__AudioMedia_p_std__allocatorT_pj__AudioMedia_p_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "AudioMediaVector_push_back" "', argument " "1"" of type '" "std::vector< pj::AudioMedia * > *""'"); 
  }
  arg1 = reinterpret_cast< std::vector< pj::AudioMedia * > * >(argp1);
  res2 = SWIG_ConvertPtr(swig_obj[1], &argp2,SWIGTYPE_p_pj__AudioMedia, 0 |  0 );
  if (!SWIG_IsOK(res2)) {
    SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "AudioMediaVector_push_back" "', argument " "2"" of type '" "std::vector< pj::AudioMedia * >::value_type""'"); 
  }
  arg2 = reinterpret_cast< std::vector< pj::AudioMedia * >::value_type >(argp2);
  (arg1)->push_back(arg2);
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_AudioMediaVector_front(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  std::vector< pj::AudioMedia * > *arg1 = (std::vector< pj::AudioMedia * > *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  std::vector< pj::AudioMedia * >::value_type result;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__vectorT_pj__AudioMedia_p_std__allocatorT_pj__AudioMedia_p_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "AudioMediaVector_front" "', argument " "1"" of type '" "std::vector< pj::AudioMedia * > const *""'"); 
  }
  arg1 = reinterpret_cast< std::vector< pj::AudioMedia * > * >(argp1);
  result = (std::vector< pj::AudioMedia * >::value_type)((std::vector< pj::AudioMedia * > const *)arg1)->front();
  resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(result), SWIGTYPE_p_pj__AudioMedia, 0 |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_AudioMediaVector_back(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  std::vector< pj::AudioMedia * > *arg1 = (std::vector< pj::AudioMedia * > *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  std::vector< pj::AudioMedia * >::value_type result;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__vectorT_pj__AudioMedia_p_std__allocatorT_pj__AudioMedia_p_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "AudioMediaVector_back" "', argument " "1"" of type '" "std::vector< pj::AudioMedia * > const *""'"); 
  }
  arg1 = reinterpret_cast< std::vector< pj::AudioMedia * > * >(argp1);
  result = (std::vector< pj::AudioMedia * >::value_type)((std::vector< pj::AudioMedia * > const *)arg1)->back();
  resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(result), SWIGTYPE_p_pj__AudioMedia, 0 |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_AudioMediaVector_assign(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  std::vector< pj::AudioMedia * > *arg1 = (std::vector< pj::AudioMedia * > *) 0 ;
  std::vector< pj::AudioMedia * >::size_type arg2 ;
  std::vector< pj::AudioMedia * >::value_type arg3 = (std::vector< pj::AudioMedia * >::value_type) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  size_t val2 ;
  int ecode2 = 0 ;
  void *argp3 = 0 ;
  int res3 = 0 ;
  PyObject *swig_obj[3] ;
  
  if (!SWIG_Python_UnpackTuple(args, "AudioMediaVector_assign", 3, 3, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__vectorT_pj__AudioMedia_p_std__allocatorT_pj__AudioMedia_p_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "AudioMediaVector_assign" "', argument " "1"" of type '" "std::vector< pj::AudioMedia * > *""'"); 
  }
  arg1 = reinterpret_cast< std::vector< pj::AudioMedia * > * >(argp1);
  ecode2 = SWIG_AsVal_size_t(swig_obj[1], &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "AudioMediaVector_assign" "', argument " "2"" of type '" "std::vector< pj::AudioMedia * >::size_type""'");
  } 
  arg2 = static_cast< std::vector< pj::AudioMedia * >::size_type >(val2);
  res3 = SWIG_ConvertPtr(swig_obj[2], &argp3,SWIGTYPE_p_pj__AudioMedia, 0 |  0 );
  if (!SWIG_IsOK(res3)) {
    SWIG_exception_fail(SWIG_ArgError(res3), "in method '" "AudioMediaVector_assign" "', argument " "3"" of type '" "std::vector< pj::AudioMedia * >::value_type""'"); 
  }
  arg3 = reinterpret_cast< std::vector< pj::AudioMedia * >::value_type >(argp3);
  (arg1)->assign(arg2,arg3);
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_AudioMediaVector_resize__SWIG_1(PyObject *SWIGUNUSEDPARM(self), Py_ssize_t nobjs, PyObject **swig_obj) {
  PyObject *resultobj = 0;
  std::vector< pj::AudioMedia * > *arg1 = (std::vector< pj::AudioMedia * > *) 0 ;
  std::vector< pj::AudioMedia * >::size_type arg2 ;
  std::vector< pj::AudioMedia * >::value_type arg3 = (std::vector< pj::AudioMedia * >::value_type) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  size_t val2 ;
  int ecode2 = 0 ;
  void *argp3 = 0 ;
  int res3 = 0 ;
  
  if ((nobjs < 3) || (nobjs > 3)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__vectorT_pj__AudioMedia_p_std__allocatorT_pj__AudioMedia_p_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "AudioMediaVector_resize" "', argument " "1"" of type '" "std::vector< pj::AudioMedia * > *""'"); 
  }
  arg1 = reinterpret_cast< std::vector< pj::AudioMedia * > * >(argp1);
  ecode2 = SWIG_AsVal_size_t(swig_obj[1], &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "AudioMediaVector_resize" "', argument " "2"" of type '" "std::vector< pj::AudioMedia * >::size_type""'");
  } 
  arg2 = static_cast< std::vector< pj::AudioMedia * >::size_type >(val2);
  res3 = SWIG_ConvertPtr(swig_obj[2], &argp3,SWIGTYPE_p_pj__AudioMedia, 0 |  0 );
  if (!SWIG_IsOK(res3)) {
    SWIG_exception_fail(SWIG_ArgError(res3), "in method '" "AudioMediaVector_resize" "', argument " "3"" of type '" "std::vector< pj::AudioMedia * >::value_type""'"); 
  }
  arg3 = reinterpret_cast< std::vector< pj::AudioMedia * >::value_type >(argp3);
  (arg1)->resize(arg2,arg3);
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_AudioMediaVector_resize(PyObject *self, PyObject *args) {
  Py_ssize_t argc;
  PyObject *argv[4] = {
    0
  };
  
  if (!(argc = SWIG_Python_UnpackTuple(args, "AudioMediaVector_resize", 0, 3, argv))) SWIG_fail;
  --argc;
  if (argc == 2) {
    int _v;
    int res = swig::asptr(argv[0], (std::vector< pj::AudioMedia*,std::allocator< pj::AudioMedia * > >**)(0));
    _v = SWIG_CheckState(res);
    if (_v) {
      {
        int res = SWIG_AsVal_size_t(argv[1], NULL);
        _v = SWIG_CheckState(res);
      }
      if (_v) {
        return _wrap_AudioMediaVector_resize__SWIG_0(self, argc, argv);
      }
    }
  }
  if (argc == 3) {
    int _v;
    int res = swig::asptr(argv[0], (std::vector< pj::AudioMedia*,std::allocator< pj::AudioMedia * > >**)(0));
    _v = SWIG_CheckState(res);
    if (_v) {
      {
        int res = SWIG_AsVal_size_t(argv[1], NULL);
        _v = SWIG_CheckState(res);
      }
      if (_v) {
        void *vptr = 0;
        int res = SWIG_ConvertPtr(argv[2], &vptr, SWIGTYPE_p_pj__AudioMedia, 0);
        _v = SWIG_CheckState(res);
        if (_v) {
          return _wrap_AudioMediaVector_resize__SWIG_1(self, argc, argv);
        }
      }
    }
  }
  
fail:
  SWIG_Python_RaiseOrModifyTypeError("Wrong number or type of arguments for overloaded function 'AudioMediaVector_resize'.\n"
    "  Possible C/C++ prototypes are:\n"
    "    std::vector< pj::AudioMedia * >::resize(std::vector< pj::AudioMedia * >::size_type)\n"
    "    std::vector< pj::AudioMedia * >::resize(std::vector< pj::AudioMedia * >::size_type,std::vector< pj::AudioMedia * >::value_type)\n");
  return 0;
}


SWIGINTERN PyObject *_wrap_AudioMediaVector_insert__SWIG_0(PyObject *SWIGUNUSEDPARM(self), Py_ssize_t nobjs, PyObject **swig_obj) {
  PyObject *resultobj = 0;
  std::vector< pj::AudioMedia * > *arg1 = (std::vector< pj::AudioMedia * > *) 0 ;
  std::vector< pj::AudioMedia * >::iterator arg2 ;
  std::vector< pj::AudioMedia * >::value_type arg3 = (std::vector< pj::AudioMedia * >::value_type) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  swig::SwigPyIterator *iter2 = 0 ;
  int res2 ;
  void *argp3 = 0 ;
  int res3 = 0 ;
  std::vector< pj::AudioMedia * >::iterator result;
  
  if ((nobjs < 3) || (nobjs > 3)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__vectorT_pj__AudioMedia_p_std__allocatorT_pj__AudioMedia_p_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "AudioMediaVector_insert" "', argument " "1"" of type '" "std::vector< pj::AudioMedia * > *""'"); 
  }
  arg1 = reinterpret_cast< std::vector< pj::AudioMedia * > * >(argp1);
  res2 = SWIG_ConvertPtr(swig_obj[1], SWIG_as_voidptrptr(&iter2), swig::SwigPyIterator::descriptor(), 0);
  if (!SWIG_IsOK(res2) || !iter2) {
    SWIG_exception_fail(SWIG_ArgError(SWIG_TypeError), "in method '" "AudioMediaVector_insert" "', argument " "2"" of type '" "std::vector< pj::AudioMedia * >::iterator""'");
  } else {
    swig::SwigPyIterator_T<std::vector< pj::AudioMedia * >::iterator > *iter_t = dynamic_cast<swig::SwigPyIterator_T<std::vector< pj::AudioMedia * >::iterator > *>(iter2);
    if (iter_t) {
      arg2 = iter_t->get_current();
    } else {
      SWIG_exception_fail(SWIG_ArgError(SWIG_TypeError), "in method '" "AudioMediaVector_insert" "', argument " "2"" of type '" "std::vector< pj::AudioMedia * >::iterator""'");
    }
  }
  res3 = SWIG_ConvertPtr(swig_obj[2], &argp3,SWIGTYPE_p_pj__AudioMedia, 0 |  0 );
  if (!SWIG_IsOK(res3)) {
    SWIG_exception_fail(SWIG_ArgError(res3), "in method '" "AudioMediaVector_insert" "', argument " "3"" of type '" "std::vector< pj::AudioMedia * >::value_type""'"); 
  }
  arg3 = reinterpret_cast< std::vector< pj::AudioMedia * >::value_type >(argp3);
  result = std_vector_Sl_pj_AudioMedia_Sm__Sg__insert__SWIG_0(arg1,arg2,arg3);
  resultobj = SWIG_NewPointerObj(swig::make_output_iterator(static_cast< const std::vector< pj::AudioMedia * >::iterator & >(result)),
    swig::SwigPyIterator::descriptor(),SWIG_POINTER_OWN);
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_AudioMediaVector_insert__SWIG_1(PyObject *SWIGUNUSEDPARM(self), Py_ssize_t nobjs, PyObject **swig_obj) {
  PyObject *resultobj = 0;
  std::vector< pj::AudioMedia * > *arg1 = (std::vector< pj::AudioMedia * > *) 0 ;
  std::vector< pj::AudioMedia * >::iterator arg2 ;
  std::vector< pj::AudioMedia * >::size_type arg3 ;
  std::vector< pj::AudioMedia * >::value_type arg4 = (std::vector< pj::AudioMedia * >::value_type) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  swig::SwigPyIterator *iter2 = 0 ;
  int res2 ;
  size_t val3 ;
  int ecode3 = 0 ;
  void *argp4 = 0 ;
  int res4 = 0 ;
  
  if ((nobjs < 4) || (nobjs > 4)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__vectorT_pj__AudioMedia_p_std__allocatorT_pj__AudioMedia_p_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "AudioMediaVector_insert" "', argument " "1"" of type '" "std::vector< pj::AudioMedia * > *""'"); 
  }
  arg1 = reinterpret_cast< std::vector< pj::AudioMedia * > * >(argp1);
  res2 = SWIG_ConvertPtr(swig_obj[1], SWIG_as_voidptrptr(&iter2), swig::SwigPyIterator::descriptor(), 0);
  if (!SWIG_IsOK(res2) || !iter2) {
    SWIG_exception_fail(SWIG_ArgError(SWIG_TypeError), "in method '" "AudioMediaVector_insert" "', argument " "2"" of type '" "std::vector< pj::AudioMedia * >::iterator""'");
  } else {
    swig::SwigPyIterator_T<std::vector< pj::AudioMedia * >::iterator > *iter_t = dynamic_cast<swig::SwigPyIterator_T<std::vector< pj::AudioMedia * >::iterator > *>(iter2);
    if (iter_t) {
      arg2 = iter_t->get_current();
    } else {
      SWIG_exception_fail(SWIG_ArgError(SWIG_TypeError), "in method '" "AudioMediaVector_insert" "', argument " "2"" of type '" "std::vector< pj::AudioMedia * >::iterator""'");
    }
  }
  ecode3 = SWIG_AsVal_size_t(swig_obj[2], &val3);
  if (!SWIG_IsOK(ecode3)) {
    SWIG_exception_fail(SWIG_ArgError(ecode3), "in method '" "AudioMediaVector_insert" "', argument " "3"" of type '" "std::vector< pj::AudioMedia * >::size_type""'");
  } 
  arg3 = static_cast< std::vector< pj::AudioMedia * >::size_type >(val3);
  res4 = SWIG_ConvertPtr(swig_obj[3], &argp4,SWIGTYPE_p_pj__AudioMedia, 0 |  0 );
  if (!SWIG_IsOK(res4)) {
    SWIG_exception_fail(SWIG_ArgError(res4), "in method '" "AudioMediaVector_insert" "', argument " "4"" of type '" "std::vector< pj::AudioMedia * >::value_type""'"); 
  }
  arg4 = reinterpret_cast< std::vector< pj::AudioMedia * >::value_type >(argp4);
  std_vector_Sl_pj_AudioMedia_Sm__Sg__insert__SWIG_1(arg1,arg2,arg3,arg4);
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_AudioMediaVector_insert(PyObject *self, PyObject *args) {
  Py_ssize_t argc;
  PyObject *argv[5] = {
    0
  };
  
  if (!(argc = SWIG_Python_UnpackTuple(args, "AudioMediaVector_insert", 0, 4, argv))) SWIG_fail;
  --argc;
  if (argc == 3) {
    int _v;
    int res = swig::asptr(argv[0], (std::vector< pj::AudioMedia*,std::allocator< pj::AudioMedia * > >**)(0));
    _v = SWIG_CheckState(res);
    if (_v) {
      swig::SwigPyIterator *iter = 0;
      int res = SWIG_ConvertPtr(argv[1], SWIG_as_voidptrptr(&iter), swig::SwigPyIterator::descriptor(), 0);
      _v = (SWIG_IsOK(res) && iter && (dynamic_cast<swig::SwigPyIterator_T<std::vector< pj::AudioMedia * >::iterator > *>(iter) != 0));
      if (_v) {
        void *vptr = 0;
        int res = SWIG_ConvertPtr(argv[2], &vptr, SWIGTYPE_p_pj__AudioMedia, 0);
        _v = SWIG_CheckState(res);
        if (_v) {
          return _wrap_AudioMediaVector_insert__SWIG_0(self, argc, argv);
        }
      }
    }
  }
  if (argc == 4) {
    int _v;
    int res = swig::asptr(argv[0], (std::vector< pj::AudioMedia*,std::allocator< pj::AudioMedia * > >**)(0));
    _v = SWIG_CheckState(res);
    if (_v) {
      swig::SwigPyIterator *iter = 0;
      int res = SWIG_ConvertPtr(argv[1], SWIG_as_voidptrptr(&iter), swig::SwigPyIterator::descriptor(), 0);
      _v = (SWIG_IsOK(res) && iter && (dynamic_cast<swig::SwigPyIterator_T<std::vector< pj::AudioMedia * >::iterator > *>(iter) != 0));
      if (_v) {
        {
          int res = SWIG_AsVal_size_t(argv[2], NULL);
          _v = SWIG_CheckState(res);
        }
        if (_v) {
          void *vptr = 0;
          int res = SWIG_ConvertPtr(argv[3], &vptr, SWIGTYPE_p_pj__AudioMedia, 0);
          _v = SWIG_CheckState(res);
          if (_v) {
            return _wrap_AudioMediaVector_insert__SWIG_1(self, argc, argv);
          }
        }
      }
    }
  }
  
fail:
  SWIG_Python_RaiseOrModifyTypeError("Wrong number or type of arguments for overloaded function 'AudioMediaVector_insert'.\n"
    "  Possible C/C++ prototypes are:\n"
    "    std::vector< pj::AudioMedia * >::insert(std::vector< pj::AudioMedia * >::iterator,std::vector< pj::AudioMedia * >::value_type)\n"
    "    std::vector< pj::AudioMedia * >::insert(std::vector< pj::AudioMedia * >::iterator,std::vector< pj::AudioMedia * >::size_type,std::vector< pj::AudioMedia * >::value_type)\n");
  return 0;
}


SWIGINTERN PyObject *_wrap_AudioMediaVector_reserve(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  std::vector< pj::AudioMedia * > *arg1 = (std::vector< pj::AudioMedia * > *) 0 ;
  std::vector< pj::AudioMedia * >::size_type arg2 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  size_t val2 ;
  int ecode2 = 0 ;
  PyObject *swig_obj[2] ;
  
  if (!SWIG_Python_UnpackTuple(args, "AudioMediaVector_reserve", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__vectorT_pj__AudioMedia_p_std__allocatorT_pj__AudioMedia_p_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "AudioMediaVector_reserve" "', argument " "1"" of type '" "std::vector< pj::AudioMedia * > *""'"); 
  }
  arg1 = reinterpret_cast< std::vector< pj::AudioMedia * > * >(argp1);
  ecode2 = SWIG_AsVal_size_t(swig_obj[1], &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "AudioMediaVector_reserve" "', argument " "2"" of type '" "std::vector< pj::AudioMedia * >::size_type""'");
  } 
  arg2 = static_cast< std::vector< pj::AudioMedia * >::size_type >(val2);
  (arg1)->reserve(arg2);
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_AudioMediaVector_capacity(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  std::vector< pj::AudioMedia * > *arg1 = (std::vector< pj::AudioMedia * > *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  std::vector< pj::AudioMedia * >::size_type result;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__vectorT_pj__AudioMedia_p_std__allocatorT_pj__AudioMedia_p_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "AudioMediaVector_capacity" "', argument " "1"" of type '" "std::vector< pj::AudioMedia * > const *""'"); 
  }
  arg1 = reinterpret_cast< std::vector< pj::AudioMedia * > * >(argp1);
  result = ((std::vector< pj::AudioMedia * > const *)arg1)->capacity();
  resultobj = SWIG_From_size_t(static_cast< size_t >(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_delete_AudioMediaVector(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  std::vector< pj::AudioMedia * > *arg1 = (std::vector< pj::AudioMedia * > *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__vectorT_pj__AudioMedia_p_std__allocatorT_pj__AudioMedia_p_t_t, SWIG_POINTER_DISOWN |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "delete_AudioMediaVector" "', argument " "1"" of type '" "std::vector< pj::AudioMedia * > *""'"); 
  }
  arg1 = reinterpret_cast< std::vector< pj::AudioMedia * > * >(argp1);
  delete arg1;
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *AudioMediaVector_swigregister(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *obj;
  if (!SWIG_Python_UnpackTuple(args, "swigregister", 1, 1, &obj)) return NULL;
  SWIG_TypeNewClientData(SWIGTYPE_p_std__vectorT_pj__AudioMedia_p_std__allocatorT_pj__AudioMedia_p_t_t, SWIG_NewClientData(obj));
  return SWIG_Py_Void();
}

SWIGINTERN PyObject *AudioMediaVector_swiginit(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  return SWIG_Python_InitShadowInstance(args);
}

SWIGINTERN PyObject *_wrap_AudioMediaVector2_iterator(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  std::vector< pj::AudioMedia > *arg1 = (std::vector< pj::AudioMedia > *) 0 ;
  PyObject **arg2 = (PyObject **) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  swig::SwigPyIterator *result = 0 ;
  
  arg2 = &swig_obj[0];
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__vectorT_pj__AudioMedia_std__allocatorT_pj__AudioMedia_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "AudioMediaVector2_iterator" "', argument " "1"" of type '" "std::vector< pj::AudioMedia > *""'"); 
  }
  arg1 = reinterpret_cast< std::vector< pj::AudioMedia > * >(argp1);
  result = (swig::SwigPyIterator *)std_vector_Sl_pj_AudioMedia_Sg__iterator(arg1,arg2);
  resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(result), SWIGTYPE_p_swig__SwigPyIterator, SWIG_POINTER_OWN |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_AudioMediaVector2___nonzero__(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  std::vector< pj::AudioMedia > *arg1 = (std::vector< pj::AudioMedia > *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  bool result;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__vectorT_pj__AudioMedia_std__allocatorT_pj__AudioMedia_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "AudioMediaVector2___nonzero__" "', argument " "1"" of type '" "std::vector< pj::AudioMedia > const *""'"); 
  }
  arg1 = reinterpret_cast< std::vector< pj::AudioMedia > * >(argp1);
  result = (bool)std_vector_Sl_pj_AudioMedia_Sg____nonzero__((std::vector< pj::AudioMedia > const *)arg1);
  resultobj = SWIG_From_bool(static_cast< bool >(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_AudioMediaVector2___bool__(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  std::vector< pj::AudioMedia > *arg1 = (std::vector< pj::AudioMedia > *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  bool result;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__vectorT_pj__AudioMedia_std__allocatorT_pj__AudioMedia_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "AudioMediaVector2___bool__" "', argument " "1"" of type '" "std::vector< pj::AudioMedia > const *""'"); 
  }
  arg1 = reinterpret_cast< std::vector< pj::AudioMedia > * >(argp1);
  result = (bool)std_vector_Sl_pj_AudioMedia_Sg____bool__((std::vector< pj::AudioMedia > const *)arg1);
  resultobj = SWIG_From_bool(static_cast< bool >(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_AudioMediaVector2___len__(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  std::vector< pj::AudioMedia > *arg1 = (std::vector< pj::AudioMedia > *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  std::vector< pj::AudioMedia >::size_type result;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__vectorT_pj__AudioMedia_std__allocatorT_pj__AudioMedia_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "AudioMediaVector2___len__" "', argument " "1"" of type '" "std::vector< pj::AudioMedia > const *""'"); 
  }
  arg1 = reinterpret_cast< std::vector< pj::AudioMedia > * >(argp1);
  result = std_vector_Sl_pj_AudioMedia_Sg____len__((std::vector< pj::AudioMedia > const *)arg1);
  resultobj = SWIG_From_size_t(static_cast< size_t >(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_AudioMediaVector2___getslice__(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  std::vector< pj::AudioMedia > *arg1 = (std::vector< pj::AudioMedia > *) 0 ;
  std::vector< pj::AudioMedia >::difference_type arg2 ;
  std::vector< pj::AudioMedia >::difference_type arg3 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  ptrdiff_t val2 ;
  int ecode2 = 0 ;
  ptrdiff_t val3 ;
  int ecode3 = 0 ;
  PyObject *swig_obj[3] ;
  std::vector< pj::AudioMedia,std::allocator< pj::AudioMedia > > *result = 0 ;
  
  if (!SWIG_Python_UnpackTuple(args, "AudioMediaVector2___getslice__", 3, 3, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__vectorT_pj__AudioMedia_std__allocatorT_pj__AudioMedia_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "AudioMediaVector2___getslice__" "', argument " "1"" of type '" "std::vector< pj::AudioMedia > *""'"); 
  }
  arg1 = reinterpret_cast< std::vector< pj::AudioMedia > * >(argp1);
  ecode2 = SWIG_AsVal_ptrdiff_t(swig_obj[1], &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "AudioMediaVector2___getslice__" "', argument " "2"" of type '" "std::vector< pj::AudioMedia >::difference_type""'");
  } 
  arg2 = static_cast< std::vector< pj::AudioMedia >::difference_type >(val2);
  ecode3 = SWIG_AsVal_ptrdiff_t(swig_obj[2], &val3);
  if (!SWIG_IsOK(ecode3)) {
    SWIG_exception_fail(SWIG_ArgError(ecode3), "in method '" "AudioMediaVector2___getslice__" "', argument " "3"" of type '" "std::vector< pj::AudioMedia >::difference_type""'");
  } 
  arg3 = static_cast< std::vector< pj::AudioMedia >::difference_type >(val3);
  try {
    result = (std::vector< pj::AudioMedia,std::allocator< pj::AudioMedia > > *)std_vector_Sl_pj_AudioMedia_Sg____getslice__(arg1,arg2,arg3);
  } catch(std::out_of_range &_e) {
    SWIG_exception_fail(SWIG_IndexError, (&_e)->what());
  } catch(std::invalid_argument &_e) {
    SWIG_exception_fail(SWIG_ValueError, (&_e)->what());
  }
  resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(result), SWIGTYPE_p_std__vectorT_pj__AudioMedia_std__allocatorT_pj__AudioMedia_t_t, SWIG_POINTER_OWN |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_AudioMediaVector2___setslice____SWIG_0(PyObject *SWIGUNUSEDPARM(self), Py_ssize_t nobjs, PyObject **swig_obj) {
  PyObject *resultobj = 0;
  std::vector< pj::AudioMedia > *arg1 = (std::vector< pj::AudioMedia > *) 0 ;
  std::vector< pj::AudioMedia >::difference_type arg2 ;
  std::vector< pj::AudioMedia >::difference_type arg3 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  ptrdiff_t val2 ;
  int ecode2 = 0 ;
  ptrdiff_t val3 ;
  int ecode3 = 0 ;
  
  if ((nobjs < 3) || (nobjs > 3)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__vectorT_pj__AudioMedia_std__allocatorT_pj__AudioMedia_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "AudioMediaVector2___setslice__" "', argument " "1"" of type '" "std::vector< pj::AudioMedia > *""'"); 
  }
  arg1 = reinterpret_cast< std::vector< pj::AudioMedia > * >(argp1);
  ecode2 = SWIG_AsVal_ptrdiff_t(swig_obj[1], &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "AudioMediaVector2___setslice__" "', argument " "2"" of type '" "std::vector< pj::AudioMedia >::difference_type""'");
  } 
  arg2 = static_cast< std::vector< pj::AudioMedia >::difference_type >(val2);
  ecode3 = SWIG_AsVal_ptrdiff_t(swig_obj[2], &val3);
  if (!SWIG_IsOK(ecode3)) {
    SWIG_exception_fail(SWIG_ArgError(ecode3), "in method '" "AudioMediaVector2___setslice__" "', argument " "3"" of type '" "std::vector< pj::AudioMedia >::difference_type""'");
  } 
  arg3 = static_cast< std::vector< pj::AudioMedia >::difference_type >(val3);
  try {
    std_vector_Sl_pj_AudioMedia_Sg____setslice____SWIG_0(arg1,arg2,arg3);
  } catch(std::out_of_range &_e) {
    SWIG_exception_fail(SWIG_IndexError, (&_e)->what());
  } catch(std::invalid_argument &_e) {
    SWIG_exception_fail(SWIG_ValueError, (&_e)->what());
  }
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_AudioMediaVector2___setslice____SWIG_1(PyObject *SWIGUNUSEDPARM(self), Py_ssize_t nobjs, PyObject **swig_obj) {
  PyObject *resultobj = 0;
  std::vector< pj::AudioMedia > *arg1 = (std::vector< pj::AudioMedia > *) 0 ;
  std::vector< pj::AudioMedia >::difference_type arg2 ;
  std::vector< pj::AudioMedia >::difference_type arg3 ;
  std::vector< pj::AudioMedia,std::allocator< pj::AudioMedia > > *arg4 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  ptrdiff_t val2 ;
  int ecode2 = 0 ;
  ptrdiff_t val3 ;
  int ecode3 = 0 ;
  int res4 = SWIG_OLDOBJ ;
  
  if ((nobjs < 4) || (nobjs > 4)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__vectorT_pj__AudioMedia_std__allocatorT_pj__AudioMedia_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "AudioMediaVector2___setslice__" "', argument " "1"" of type '" "std::vector< pj::AudioMedia > *""'"); 
  }
  arg1 = reinterpret_cast< std::vector< pj::AudioMedia > * >(argp1);
  ecode2 = SWIG_AsVal_ptrdiff_t(swig_obj[1], &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "AudioMediaVector2___setslice__" "', argument " "2"" of type '" "std::vector< pj::AudioMedia >::difference_type""'");
  } 
  arg2 = static_cast< std::vector< pj::AudioMedia >::difference_type >(val2);
  ecode3 = SWIG_AsVal_ptrdiff_t(swig_obj[2], &val3);
  if (!SWIG_IsOK(ecode3)) {
    SWIG_exception_fail(SWIG_ArgError(ecode3), "in method '" "AudioMediaVector2___setslice__" "', argument " "3"" of type '" "std::vector< pj::AudioMedia >::difference_type""'");
  } 
  arg3 = static_cast< std::vector< pj::AudioMedia >::difference_type >(val3);
  {
    std::vector< pj::AudioMedia,std::allocator< pj::AudioMedia > > *ptr = (std::vector< pj::AudioMedia,std::allocator< pj::AudioMedia > > *)0;
    res4 = swig::asptr(swig_obj[3], &ptr);
    if (!SWIG_IsOK(res4)) {
      SWIG_exception_fail(SWIG_ArgError(res4), "in method '" "AudioMediaVector2___setslice__" "', argument " "4"" of type '" "std::vector< pj::AudioMedia,std::allocator< pj::AudioMedia > > const &""'"); 
    }
    if (!ptr) {
      SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "AudioMediaVector2___setslice__" "', argument " "4"" of type '" "std::vector< pj::AudioMedia,std::allocator< pj::AudioMedia > > const &""'"); 
    }
    arg4 = ptr;
  }
  try {
    std_vector_Sl_pj_AudioMedia_Sg____setslice____SWIG_1(arg1,arg2,arg3,(std::vector< pj::AudioMedia,std::allocator< pj::AudioMedia > > const &)*arg4);
  } catch(std::out_of_range &_e) {
    SWIG_exception_fail(SWIG_IndexError, (&_e)->what());
  } catch(std::invalid_argument &_e) {
    SWIG_exception_fail(SWIG_ValueError, (&_e)->what());
  }
  resultobj = SWIG_Py_Void();
  if (SWIG_IsNewObj(res4)) delete arg4;
  return resultobj;
fail:
  if (SWIG_IsNewObj(res4)) delete arg4;
  return NULL;
}


SWIGINTERN PyObject *_wrap_AudioMediaVector2___setslice__(PyObject *self, PyObject *args) {
  Py_ssize_t argc;
  PyObject *argv[5] = {
    0
  };
  
  if (!(argc = SWIG_Python_UnpackTuple(args, "AudioMediaVector2___setslice__", 0, 4, argv))) SWIG_fail;
  --argc;
  if (argc == 3) {
    int _v;
    int res = swig::asptr(argv[0], (std::vector< pj::AudioMedia,std::allocator< pj::AudioMedia > >**)(0));
    _v = SWIG_CheckState(res);
    if (_v) {
      {
        int res = SWIG_AsVal_ptrdiff_t(argv[1], NULL);
        _v = SWIG_CheckState(res);
      }
      if (_v) {
        {
          int res = SWIG_AsVal_ptrdiff_t(argv[2], NULL);
          _v = SWIG_CheckState(res);
        }
        if (_v) {
          return _wrap_AudioMediaVector2___setslice____SWIG_0(self, argc, argv);
        }
      }
    }
  }
  if (argc == 4) {
    int _v;
    int res = swig::asptr(argv[0], (std::vector< pj::AudioMedia,std::allocator< pj::AudioMedia > >**)(0));
    _v = SWIG_CheckState(res);
    if (_v) {
      {
        int res = SWIG_AsVal_ptrdiff_t(argv[1], NULL);
        _v = SWIG_CheckState(res);
      }
      if (_v) {
        {
          int res = SWIG_AsVal_ptrdiff_t(argv[2], NULL);
          _v = SWIG_CheckState(res);
        }
        if (_v) {
          int res = swig::asptr(argv[3], (std::vector< pj::AudioMedia,std::allocator< pj::AudioMedia > >**)(0));
          _v = SWIG_CheckState(res);
          if (_v) {
            return _wrap_AudioMediaVector2___setslice____SWIG_1(self, argc, argv);
          }
        }
      }
    }
  }
  
fail:
  SWIG_Python_RaiseOrModifyTypeError("Wrong number or type of arguments for overloaded function 'AudioMediaVector2___setslice__'.\n"
    "  Possible C/C++ prototypes are:\n"
    "    std::vector< pj::AudioMedia >::__setslice__(std::vector< pj::AudioMedia >::difference_type,std::vector< pj::AudioMedia >::difference_type)\n"
    "    std::vector< pj::AudioMedia >::__setslice__(std::vector< pj::AudioMedia >::difference_type,std::vector< pj::AudioMedia >::difference_type,std::vector< pj::AudioMedia,std::allocator< pj::AudioMedia > > const &)\n");
  return 0;
}


SWIGINTERN PyObject *_wrap_AudioMediaVector2___delslice__(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  std::vector< pj::AudioMedia > *arg1 = (std::vector< pj::AudioMedia > *) 0 ;
  std::vector< pj::AudioMedia >::difference_type arg2 ;
  std::vector< pj::AudioMedia >::difference_type arg3 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  ptrdiff_t val2 ;
  int ecode2 = 0 ;
  ptrdiff_t val3 ;
  int ecode3 = 0 ;
  PyObject *swig_obj[3] ;
  
  if (!SWIG_Python_UnpackTuple(args, "AudioMediaVector2___delslice__", 3, 3, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__vectorT_pj__AudioMedia_std__allocatorT_pj__AudioMedia_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "AudioMediaVector2___delslice__" "', argument " "1"" of type '" "std::vector< pj::AudioMedia > *""'"); 
  }
  arg1 = reinterpret_cast< std::vector< pj::AudioMedia > * >(argp1);
  ecode2 = SWIG_AsVal_ptrdiff_t(swig_obj[1], &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "AudioMediaVector2___delslice__" "', argument " "2"" of type '" "std::vector< pj::AudioMedia >::difference_type""'");
  } 
  arg2 = static_cast< std::vector< pj::AudioMedia >::difference_type >(val2);
  ecode3 = SWIG_AsVal_ptrdiff_t(swig_obj[2], &val3);
  if (!SWIG_IsOK(ecode3)) {
    SWIG_exception_fail(SWIG_ArgError(ecode3), "in method '" "AudioMediaVector2___delslice__" "', argument " "3"" of type '" "std::vector< pj::AudioMedia >::difference_type""'");
  } 
  arg3 = static_cast< std::vector< pj::AudioMedia >::difference_type >(val3);
  try {
    std_vector_Sl_pj_AudioMedia_Sg____delslice__(arg1,arg2,arg3);
  } catch(std::out_of_range &_e) {
    SWIG_exception_fail(SWIG_IndexError, (&_e)->what());
  } catch(std::invalid_argument &_e) {
    SWIG_exception_fail(SWIG_ValueError, (&_e)->what());
  }
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_AudioMediaVector2___delitem____SWIG_0(PyObject *SWIGUNUSEDPARM(self), Py_ssize_t nobjs, PyObject **swig_obj) {
  PyObject *resultobj = 0;
  std::vector< pj::AudioMedia > *arg1 = (std::vector< pj::AudioMedia > *) 0 ;
  std::vector< pj::AudioMedia >::difference_type arg2 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  ptrdiff_t val2 ;
  int ecode2 = 0 ;
  
  if ((nobjs < 2) || (nobjs > 2)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__vectorT_pj__AudioMedia_std__allocatorT_pj__AudioMedia_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "AudioMediaVector2___delitem__" "', argument " "1"" of type '" "std::vector< pj::AudioMedia > *""'"); 
  }
  arg1 = reinterpret_cast< std::vector< pj::AudioMedia > * >(argp1);
  ecode2 = SWIG_AsVal_ptrdiff_t(swig_obj[1], &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "AudioMediaVector2___delitem__" "', argument " "2"" of type '" "std::vector< pj::AudioMedia >::difference_type""'");
  } 
  arg2 = static_cast< std::vector< pj::AudioMedia >::difference_type >(val2);
  try {
    std_vector_Sl_pj_AudioMedia_Sg____delitem____SWIG_0(arg1,arg2);
  } catch(std::out_of_range &_e) {
    SWIG_exception_fail(SWIG_IndexError, (&_e)->what());
  } catch(std::invalid_argument &_e) {
    SWIG_exception_fail(SWIG_ValueError, (&_e)->what());
  }
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_AudioMediaVector2___getitem____SWIG_0(PyObject *SWIGUNUSEDPARM(self), Py_ssize_t nobjs, PyObject **swig_obj) {
  PyObject *resultobj = 0;
  std::vector< pj::AudioMedia > *arg1 = (std::vector< pj::AudioMedia > *) 0 ;
  PySliceObject *arg2 = (PySliceObject *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  std::vector< pj::AudioMedia,std::allocator< pj::AudioMedia > > *result = 0 ;
  
  if ((nobjs < 2) || (nobjs > 2)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__vectorT_pj__AudioMedia_std__allocatorT_pj__AudioMedia_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "AudioMediaVector2___getitem__" "', argument " "1"" of type '" "std::vector< pj::AudioMedia > *""'"); 
  }
  arg1 = reinterpret_cast< std::vector< pj::AudioMedia > * >(argp1);
  {
    if (!PySlice_Check(swig_obj[1])) {
      SWIG_exception_fail(SWIG_ArgError(SWIG_TypeError), "in method '" "AudioMediaVector2___getitem__" "', argument " "2"" of type '" "PySliceObject *""'");
    }
    arg2 = (PySliceObject *) swig_obj[1];
  }
  try {
    result = (std::vector< pj::AudioMedia,std::allocator< pj::AudioMedia > > *)std_vector_Sl_pj_AudioMedia_Sg____getitem____SWIG_0(arg1,arg2);
  } catch(std::out_of_range &_e) {
    SWIG_exception_fail(SWIG_IndexError, (&_e)->what());
  } catch(std::invalid_argument &_e) {
    SWIG_exception_fail(SWIG_ValueError, (&_e)->what());
  }
  resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(result), SWIGTYPE_p_std__vectorT_pj__AudioMedia_std__allocatorT_pj__AudioMedia_t_t, SWIG_POINTER_OWN |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_AudioMediaVector2___setitem____SWIG_0(PyObject *SWIGUNUSEDPARM(self), Py_ssize_t nobjs, PyObject **swig_obj) {
  PyObject *resultobj = 0;
  std::vector< pj::AudioMedia > *arg1 = (std::vector< pj::AudioMedia > *) 0 ;
  PySliceObject *arg2 = (PySliceObject *) 0 ;
  std::vector< pj::AudioMedia,std::allocator< pj::AudioMedia > > *arg3 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  int res3 = SWIG_OLDOBJ ;
  
  if ((nobjs < 3) || (nobjs > 3)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__vectorT_pj__AudioMedia_std__allocatorT_pj__AudioMedia_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "AudioMediaVector2___setitem__" "', argument " "1"" of type '" "std::vector< pj::AudioMedia > *""'"); 
  }
  arg1 = reinterpret_cast< std::vector< pj::AudioMedia > * >(argp1);
  {
    if (!PySlice_Check(swig_obj[1])) {
      SWIG_exception_fail(SWIG_ArgError(SWIG_TypeError), "in method '" "AudioMediaVector2___setitem__" "', argument " "2"" of type '" "PySliceObject *""'");
    }
    arg2 = (PySliceObject *) swig_obj[1];
  }
  {
    std::vector< pj::AudioMedia,std::allocator< pj::AudioMedia > > *ptr = (std::vector< pj::AudioMedia,std::allocator< pj::AudioMedia > > *)0;
    res3 = swig::asptr(swig_obj[2], &ptr);
    if (!SWIG_IsOK(res3)) {
      SWIG_exception_fail(SWIG_ArgError(res3), "in method '" "AudioMediaVector2___setitem__" "', argument " "3"" of type '" "std::vector< pj::AudioMedia,std::allocator< pj::AudioMedia > > const &""'"); 
    }
    if (!ptr) {
      SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "AudioMediaVector2___setitem__" "', argument " "3"" of type '" "std::vector< pj::AudioMedia,std::allocator< pj::AudioMedia > > const &""'"); 
    }
    arg3 = ptr;
  }
  try {
    std_vector_Sl_pj_AudioMedia_Sg____setitem____SWIG_0(arg1,arg2,(std::vector< pj::AudioMedia,std::allocator< pj::AudioMedia > > const &)*arg3);
  } catch(std::out_of_range &_e) {
    SWIG_exception_fail(SWIG_IndexError, (&_e)->what());
  } catch(std::invalid_argument &_e) {
    SWIG_exception_fail(SWIG_ValueError, (&_e)->what());
  }
  resultobj = SWIG_Py_Void();
  if (SWIG_IsNewObj(res3)) delete arg3;
  return resultobj;
fail:
  if (SWIG_IsNewObj(res3)) delete arg3;
  return NULL;
}


SWIGINTERN PyObject *_wrap_AudioMediaVector2___setitem____SWIG_1(PyObject *SWIGUNUSEDPARM(self), Py_ssize_t nobjs, PyObject **swig_obj) {
  PyObject *resultobj = 0;
  std::vector< pj::AudioMedia > *arg1 = (std::vector< pj::AudioMedia > *) 0 ;
  PySliceObject *arg2 = (PySliceObject *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  
  if ((nobjs < 2) || (nobjs > 2)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__vectorT_pj__AudioMedia_std__allocatorT_pj__AudioMedia_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "AudioMediaVector2___setitem__" "', argument " "1"" of type '" "std::vector< pj::AudioMedia > *""'"); 
  }
  arg1 = reinterpret_cast< std::vector< pj::AudioMedia > * >(argp1);
  {
    if (!PySlice_Check(swig_obj[1])) {
      SWIG_exception_fail(SWIG_ArgError(SWIG_TypeError), "in method '" "AudioMediaVector2___setitem__" "', argument " "2"" of type '" "PySliceObject *""'");
    }
    arg2 = (PySliceObject *) swig_obj[1];
  }
  try {
    std_vector_Sl_pj_AudioMedia_Sg____setitem____SWIG_1(arg1,arg2);
  } catch(std::out_of_range &_e) {
    SWIG_exception_fail(SWIG_IndexError, (&_e)->what());
  } catch(std::invalid_argument &_e) {
    SWIG_exception_fail(SWIG_ValueError, (&_e)->what());
  }
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_AudioMediaVector2___delitem____SWIG_1(PyObject *SWIGUNUSEDPARM(self), Py_ssize_t nobjs, PyObject **swig_obj) {
  PyObject *resultobj = 0;
  std::vector< pj::AudioMedia > *arg1 = (std::vector< pj::AudioMedia > *) 0 ;
  PySliceObject *arg2 = (PySliceObject *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  
  if ((nobjs < 2) || (nobjs > 2)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__vectorT_pj__AudioMedia_std__allocatorT_pj__AudioMedia_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "AudioMediaVector2___delitem__" "', argument " "1"" of type '" "std::vector< pj::AudioMedia > *""'"); 
  }
  arg1 = reinterpret_cast< std::vector< pj::AudioMedia > * >(argp1);
  {
    if (!PySlice_Check(swig_obj[1])) {
      SWIG_exception_fail(SWIG_ArgError(SWIG_TypeError), "in method '" "AudioMediaVector2___delitem__" "', argument " "2"" of type '" "PySliceObject *""'");
    }
    arg2 = (PySliceObject *) swig_obj[1];
  }
  try {
    std_vector_Sl_pj_AudioMedia_Sg____delitem____SWIG_1(arg1,arg2);
  } catch(std::out_of_range &_e) {
    SWIG_exception_fail(SWIG_IndexError, (&_e)->what());
  } catch(std::invalid_argument &_e) {
    SWIG_exception_fail(SWIG_ValueError, (&_e)->what());
  }
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_AudioMediaVector2___delitem__(PyObject *self, PyObject *args) {
  Py_ssize_t argc;
  PyObject *argv[3] = {
    0
  };
  
  if (!(argc = SWIG_Python_UnpackTuple(args, "AudioMediaVector2___delitem__", 0, 2, argv))) SWIG_fail;
  --argc;
  if (argc == 2) {
    int _v;
    int res = swig::asptr(argv[0], (std::vector< pj::AudioMedia,std::allocator< pj::AudioMedia > >**)(0));
    _v = SWIG_CheckState(res);
    if (_v) {
      {
        _v = PySlice_Check(argv[1]);
      }
      if (_v) {
        return _wrap_AudioMediaVector2___delitem____SWIG_1(self, argc, argv);
      }
    }
  }
  if (argc == 2) {
    int _v;
    int res = swig::asptr(argv[0], (std::vector< pj::AudioMedia,std::allocator< pj::AudioMedia > >**)(0));
    _v = SWIG_CheckState(res);
    if (_v) {
      {
        int res = SWIG_AsVal_ptrdiff_t(argv[1], NULL);
        _v = SWIG_CheckState(res);
      }
      if (_v) {
        return _wrap_AudioMediaVector2___delitem____SWIG_0(self, argc, argv);
      }
    }
  }
  
fail:
  SWIG_Python_RaiseOrModifyTypeError("Wrong number or type of arguments for overloaded function 'AudioMediaVector2___delitem__'.\n"
    "  Possible C/C++ prototypes are:\n"
    "    std::vector< pj::AudioMedia >::__delitem__(std::vector< pj::AudioMedia >::difference_type)\n"
    "    std::vector< pj::AudioMedia >::__delitem__(PySliceObject *)\n");
  return 0;
}


SWIGINTERN PyObject *_wrap_AudioMediaVector2___getitem____SWIG_1(PyObject *SWIGUNUSEDPARM(self), Py_ssize_t nobjs, PyObject **swig_obj) {
  PyObject *resultobj = 0;
  std::vector< pj::AudioMedia > *arg1 = (std::vector< pj::AudioMedia > *) 0 ;
  std::vector< pj::AudioMedia >::difference_type arg2 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  ptrdiff_t val2 ;
  int ecode2 = 0 ;
  std::vector< pj::AudioMedia >::value_type *result = 0 ;
  
  if ((nobjs < 2) || (nobjs > 2)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__vectorT_pj__AudioMedia_std__allocatorT_pj__AudioMedia_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "AudioMediaVector2___getitem__" "', argument " "1"" of type '" "std::vector< pj::AudioMedia > const *""'"); 
  }
  arg1 = reinterpret_cast< std::vector< pj::AudioMedia > * >(argp1);
  ecode2 = SWIG_AsVal_ptrdiff_t(swig_obj[1], &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "AudioMediaVector2___getitem__" "', argument " "2"" of type '" "std::vector< pj::AudioMedia >::difference_type""'");
  } 
  arg2 = static_cast< std::vector< pj::AudioMedia >::difference_type >(val2);
  try {
    result = (std::vector< pj::AudioMedia >::value_type *) &std_vector_Sl_pj_AudioMedia_Sg____getitem____SWIG_1((std::vector< pj::AudioMedia > const *)arg1,arg2);
  } catch(std::out_of_range &_e) {
    SWIG_exception_fail(SWIG_IndexError, (&_e)->what());
  }
  resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(result), SWIGTYPE_p_pj__AudioMedia, 0 |  0 );
  (void)swig::container_owner<swig::traits<std::vector< pj::AudioMedia >::value_type>::category>::back_reference(resultobj, swig_obj[0]);
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_AudioMediaVector2___getitem__(PyObject *self, PyObject *args) {
  Py_ssize_t argc;
  PyObject *argv[3] = {
    0
  };
  
  if (!(argc = SWIG_Python_UnpackTuple(args, "AudioMediaVector2___getitem__", 0, 2, argv))) SWIG_fail;
  --argc;
  if (argc == 2) {
    int _v;
    int res = swig::asptr(argv[0], (std::vector< pj::AudioMedia,std::allocator< pj::AudioMedia > >**)(0));
    _v = SWIG_CheckState(res);
    if (_v) {
      {
        _v = PySlice_Check(argv[1]);
      }
      if (_v) {
        return _wrap_AudioMediaVector2___getitem____SWIG_0(self, argc, argv);
      }
    }
  }
  if (argc == 2) {
    int _v;
    int res = swig::asptr(argv[0], (std::vector< pj::AudioMedia,std::allocator< pj::AudioMedia > >**)(0));
    _v = SWIG_CheckState(res);
    if (_v) {
      {
        int res = SWIG_AsVal_ptrdiff_t(argv[1], NULL);
        _v = SWIG_CheckState(res);
      }
      if (_v) {
        return _wrap_AudioMediaVector2___getitem____SWIG_1(self, argc, argv);
      }
    }
  }
  
fail:
  SWIG_Python_RaiseOrModifyTypeError("Wrong number or type of arguments for overloaded function 'AudioMediaVector2___getitem__'.\n"
    "  Possible C/C++ prototypes are:\n"
    "    std::vector< pj::AudioMedia >::__getitem__(PySliceObject *)\n"
    "    std::vector< pj::AudioMedia >::__getitem__(std::vector< pj::AudioMedia >::difference_type) const\n");
  return 0;
}


SWIGINTERN PyObject *_wrap_AudioMediaVector2___setitem____SWIG_2(PyObject *SWIGUNUSEDPARM(self), Py_ssize_t nobjs, PyObject **swig_obj) {
  PyObject *resultobj = 0;
  std::vector< pj::AudioMedia > *arg1 = (std::vector< pj::AudioMedia > *) 0 ;
  std::vector< pj::AudioMedia >::difference_type arg2 ;
  std::vector< pj::AudioMedia >::value_type *arg3 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  ptrdiff_t val2 ;
  int ecode2 = 0 ;
  void *argp3 = 0 ;
  int res3 = 0 ;
  
  if ((nobjs < 3) || (nobjs > 3)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__vectorT_pj__AudioMedia_std__allocatorT_pj__AudioMedia_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "AudioMediaVector2___setitem__" "', argument " "1"" of type '" "std::vector< pj::AudioMedia > *""'"); 
  }
  arg1 = reinterpret_cast< std::vector< pj::AudioMedia > * >(argp1);
  ecode2 = SWIG_AsVal_ptrdiff_t(swig_obj[1], &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "AudioMediaVector2___setitem__" "', argument " "2"" of type '" "std::vector< pj::AudioMedia >::difference_type""'");
  } 
  arg2 = static_cast< std::vector< pj::AudioMedia >::difference_type >(val2);
  res3 = SWIG_ConvertPtr(swig_obj[2], &argp3, SWIGTYPE_p_pj__AudioMedia,  0  | 0);
  if (!SWIG_IsOK(res3)) {
    SWIG_exception_fail(SWIG_ArgError(res3), "in method '" "AudioMediaVector2___setitem__" "', argument " "3"" of type '" "std::vector< pj::AudioMedia >::value_type const &""'"); 
  }
  if (!argp3) {
    SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "AudioMediaVector2___setitem__" "', argument " "3"" of type '" "std::vector< pj::AudioMedia >::value_type const &""'"); 
  }
  arg3 = reinterpret_cast< std::vector< pj::AudioMedia >::value_type * >(argp3);
  try {
    std_vector_Sl_pj_AudioMedia_Sg____setitem____SWIG_2(arg1,arg2,(pj::AudioMedia const &)*arg3);
  } catch(std::out_of_range &_e) {
    SWIG_exception_fail(SWIG_IndexError, (&_e)->what());
  }
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_AudioMediaVector2___setitem__(PyObject *self, PyObject *args) {
  Py_ssize_t argc;
  PyObject *argv[4] = {
    0
  };
  
  if (!(argc = SWIG_Python_UnpackTuple(args, "AudioMediaVector2___setitem__", 0, 3, argv))) SWIG_fail;
  --argc;
  if (argc == 2) {
    int _v;
    int res = swig::asptr(argv[0], (std::vector< pj::AudioMedia,std::allocator< pj::AudioMedia > >**)(0));
    _v = SWIG_CheckState(res);
    if (_v) {
      {
        _v = PySlice_Check(argv[1]);
      }
      if (_v) {
        return _wrap_AudioMediaVector2___setitem____SWIG_1(self, argc, argv);
      }
    }
  }
  if (argc == 3) {
    int _v;
    int res = swig::asptr(argv[0], (std::vector< pj::AudioMedia,std::allocator< pj::AudioMedia > >**)(0));
    _v = SWIG_CheckState(res);
    if (_v) {
      {
        _v = PySlice_Check(argv[1]);
      }
      if (_v) {
        int res = swig::asptr(argv[2], (std::vector< pj::AudioMedia,std::allocator< pj::AudioMedia > >**)(0));
        _v = SWIG_CheckState(res);
        if (_v) {
          return _wrap_AudioMediaVector2___setitem____SWIG_0(self, argc, argv);
        }
      }
    }
  }
  if (argc == 3) {
    int _v;
    int res = swig::asptr(argv[0], (std::vector< pj::AudioMedia,std::allocator< pj::AudioMedia > >**)(0));
    _v = SWIG_CheckState(res);
    if (_v) {
      {
        int res = SWIG_AsVal_ptrdiff_t(argv[1], NULL);
        _v = SWIG_CheckState(res);
      }
      if (_v) {
        int res = SWIG_ConvertPtr(argv[2], 0, SWIGTYPE_p_pj__AudioMedia, SWIG_POINTER_NO_NULL | 0);
        _v = SWIG_CheckState(res);
        if (_v) {
          return _wrap_AudioMediaVector2___setitem____SWIG_2(self, argc, argv);
        }
      }
    }
  }
  
fail:
  SWIG_Python_RaiseOrModifyTypeError("Wrong number or type of arguments for overloaded function 'AudioMediaVector2___setitem__'.\n"
    "  Possible C/C++ prototypes are:\n"
    "    std::vector< pj::AudioMedia >::__setitem__(PySliceObject *,std::vector< pj::AudioMedia,std::allocator< pj::AudioMedia > > const &)\n"
    "    std::vector< pj::AudioMedia >::__setitem__(PySliceObject *)\n"
    "    std::vector< pj::AudioMedia >::__setitem__(std::vector< pj::AudioMedia >::difference_type,std::vector< pj::AudioMedia >::value_type const &)\n");
  return 0;
}


SWIGINTERN PyObject *_wrap_AudioMediaVector2_pop(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  std::vector< pj::AudioMedia > *arg1 = (std::vector< pj::AudioMedia > *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  std::vector< pj::AudioMedia >::value_type result;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__vectorT_pj__AudioMedia_std__allocatorT_pj__AudioMedia_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "AudioMediaVector2_pop" "', argument " "1"" of type '" "std::vector< pj::AudioMedia > *""'"); 
  }
  arg1 = reinterpret_cast< std::vector< pj::AudioMedia > * >(argp1);
  try {
    result = std_vector_Sl_pj_AudioMedia_Sg__pop(arg1);
  } catch(std::out_of_range &_e) {
    SWIG_exception_fail(SWIG_IndexError, (&_e)->what());
  }
  resultobj = SWIG_NewPointerObj((new std::vector< pj::AudioMedia >::value_type(static_cast< const std::vector< pj::AudioMedia >::value_type& >(result))), SWIGTYPE_p_pj__AudioMedia, SWIG_POINTER_OWN |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_AudioMediaVector2_append(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  std::vector< pj::AudioMedia > *arg1 = (std::vector< pj::AudioMedia > *) 0 ;
  std::vector< pj::AudioMedia >::value_type *arg2 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  void *argp2 = 0 ;
  int res2 = 0 ;
  PyObject *swig_obj[2] ;
  
  if (!SWIG_Python_UnpackTuple(args, "AudioMediaVector2_append", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__vectorT_pj__AudioMedia_std__allocatorT_pj__AudioMedia_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "AudioMediaVector2_append" "', argument " "1"" of type '" "std::vector< pj::AudioMedia > *""'"); 
  }
  arg1 = reinterpret_cast< std::vector< pj::AudioMedia > * >(argp1);
  res2 = SWIG_ConvertPtr(swig_obj[1], &argp2, SWIGTYPE_p_pj__AudioMedia,  0  | 0);
  if (!SWIG_IsOK(res2)) {
    SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "AudioMediaVector2_append" "', argument " "2"" of type '" "std::vector< pj::AudioMedia >::value_type const &""'"); 
  }
  if (!argp2) {
    SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "AudioMediaVector2_append" "', argument " "2"" of type '" "std::vector< pj::AudioMedia >::value_type const &""'"); 
  }
  arg2 = reinterpret_cast< std::vector< pj::AudioMedia >::value_type * >(argp2);
  std_vector_Sl_pj_AudioMedia_Sg__append(arg1,(pj::AudioMedia const &)*arg2);
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_new_AudioMediaVector2__SWIG_0(PyObject *SWIGUNUSEDPARM(self), Py_ssize_t nobjs, PyObject **SWIGUNUSEDPARM(swig_obj)) {
  PyObject *resultobj = 0;
  std::vector< pj::AudioMedia > *result = 0 ;
  
  if ((nobjs < 0) || (nobjs > 0)) SWIG_fail;
  result = (std::vector< pj::AudioMedia > *)new std::vector< pj::AudioMedia >();
  resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(result), SWIGTYPE_p_std__vectorT_pj__AudioMedia_std__allocatorT_pj__AudioMedia_t_t, SWIG_POINTER_NEW |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_new_AudioMediaVector2__SWIG_1(PyObject *SWIGUNUSEDPARM(self), Py_ssize_t nobjs, PyObject **swig_obj) {
  PyObject *resultobj = 0;
  std::vector< pj::AudioMedia > *arg1 = 0 ;
  int res1 = SWIG_OLDOBJ ;
  std::vector< pj::AudioMedia > *result = 0 ;
  
  if ((nobjs < 1) || (nobjs > 1)) SWIG_fail;
  {
    std::vector< pj::AudioMedia,std::allocator< pj::AudioMedia > > *ptr = (std::vector< pj::AudioMedia,std::allocator< pj::AudioMedia > > *)0;
    res1 = swig::asptr(swig_obj[0], &ptr);
    if (!SWIG_IsOK(res1)) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "new_AudioMediaVector2" "', argument " "1"" of type '" "std::vector< pj::AudioMedia > const &""'"); 
    }
    if (!ptr) {
      SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "new_AudioMediaVector2" "', argument " "1"" of type '" "std::vector< pj::AudioMedia > const &""'"); 
    }
    arg1 = ptr;
  }
  result = (std::vector< pj::AudioMedia > *)new std::vector< pj::AudioMedia >((std::vector< pj::AudioMedia > const &)*arg1);
  resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(result), SWIGTYPE_p_std__vectorT_pj__AudioMedia_std__allocatorT_pj__AudioMedia_t_t, SWIG_POINTER_NEW |  0 );
  if (SWIG_IsNewObj(res1)) delete arg1;
  return resultobj;
fail:
  if (SWIG_IsNewObj(res1)) delete arg1;
  return NULL;
}


SWIGINTERN PyObject *_wrap_AudioMediaVector2_empty(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  std::vector< pj::AudioMedia > *arg1 = (std::vector< pj::AudioMedia > *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  bool result;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__vectorT_pj__AudioMedia_std__allocatorT_pj__AudioMedia_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "AudioMediaVector2_empty" "', argument " "1"" of type '" "std::vector< pj::AudioMedia > const *""'"); 
  }
  arg1 = reinterpret_cast< std::vector< pj::AudioMedia > * >(argp1);
  result = (bool)((std::vector< pj::AudioMedia > const *)arg1)->empty();
  resultobj = SWIG_From_bool(static_cast< bool >(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_AudioMediaVector2_size(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  std::vector< pj::AudioMedia > *arg1 = (std::vector< pj::AudioMedia > *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  std::vector< pj::AudioMedia >::size_type result;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__vectorT_pj__AudioMedia_std__allocatorT_pj__AudioMedia_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "AudioMediaVector2_size" "', argument " "1"" of type '" "std::vector< pj::AudioMedia > const *""'"); 
  }
  arg1 = reinterpret_cast< std::vector< pj::AudioMedia > * >(argp1);
  result = ((std::vector< pj::AudioMedia > const *)arg1)->size();
  resultobj = SWIG_From_size_t(static_cast< size_t >(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_AudioMediaVector2_swap(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  std::vector< pj::AudioMedia > *arg1 = (std::vector< pj::AudioMedia > *) 0 ;
  std::vector< pj::AudioMedia > *arg2 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  void *argp2 = 0 ;
  int res2 = 0 ;
  PyObject *swig_obj[2] ;
  
  if (!SWIG_Python_UnpackTuple(args, "AudioMediaVector2_swap", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__vectorT_pj__AudioMedia_std__allocatorT_pj__AudioMedia_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "AudioMediaVector2_swap" "', argument " "1"" of type '" "std::vector< pj::AudioMedia > *""'"); 
  }
  arg1 = reinterpret_cast< std::vector< pj::AudioMedia > * >(argp1);
  res2 = SWIG_ConvertPtr(swig_obj[1], &argp2, SWIGTYPE_p_std__vectorT_pj__AudioMedia_std__allocatorT_pj__AudioMedia_t_t,  0 );
  if (!SWIG_IsOK(res2)) {
    SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "AudioMediaVector2_swap" "', argument " "2"" of type '" "std::vector< pj::AudioMedia > &""'"); 
  }
  if (!argp2) {
    SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "AudioMediaVector2_swap" "', argument " "2"" of type '" "std::vector< pj::AudioMedia > &""'"); 
  }
  arg2 = reinterpret_cast< std::vector< pj::AudioMedia > * >(argp2);
  (arg1)->swap(*arg2);
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_AudioMediaVector2_begin(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  std::vector< pj::AudioMedia > *arg1 = (std::vector< pj::AudioMedia > *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  std::vector< pj::AudioMedia >::iterator result;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__vectorT_pj__AudioMedia_std__allocatorT_pj__AudioMedia_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "AudioMediaVector2_begin" "', argument " "1"" of type '" "std::vector< pj::AudioMedia > *""'"); 
  }
  arg1 = reinterpret_cast< std::vector< pj::AudioMedia > * >(argp1);
  result = (arg1)->begin();
  resultobj = SWIG_NewPointerObj(swig::make_output_iterator(static_cast< const std::vector< pj::AudioMedia >::iterator & >(result)),
    swig::SwigPyIterator::descriptor(),SWIG_POINTER_OWN);
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_AudioMediaVector2_end(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  std::vector< pj::AudioMedia > *arg1 = (std::vector< pj::AudioMedia > *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  std::vector< pj::AudioMedia >::iterator result;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__vectorT_pj__AudioMedia_std__allocatorT_pj__AudioMedia_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "AudioMediaVector2_end" "', argument " "1"" of type '" "std::vector< pj::AudioMedia > *""'"); 
  }
  arg1 = reinterpret_cast< std::vector< pj::AudioMedia > * >(argp1);
  result = (arg1)->end();
  resultobj = SWIG_NewPointerObj(swig::make_output_iterator(static_cast< const std::vector< pj::AudioMedia >::iterator & >(result)),
    swig::SwigPyIterator::descriptor(),SWIG_POINTER_OWN);
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_AudioMediaVector2_rbegin(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  std::vector< pj::AudioMedia > *arg1 = (std::vector< pj::AudioMedia > *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  std::vector< pj::AudioMedia >::reverse_iterator result;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__vectorT_pj__AudioMedia_std__allocatorT_pj__AudioMedia_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "AudioMediaVector2_rbegin" "', argument " "1"" of type '" "std::vector< pj::AudioMedia > *""'"); 
  }
  arg1 = reinterpret_cast< std::vector< pj::AudioMedia > * >(argp1);
  result = (arg1)->rbegin();
  resultobj = SWIG_NewPointerObj(swig::make_output_iterator(static_cast< const std::vector< pj::AudioMedia >::reverse_iterator & >(result)),
    swig::SwigPyIterator::descriptor(),SWIG_POINTER_OWN);
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_AudioMediaVector2_rend(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  std::vector< pj::AudioMedia > *arg1 = (std::vector< pj::AudioMedia > *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  std::vector< pj::AudioMedia >::reverse_iterator result;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__vectorT_pj__AudioMedia_std__allocatorT_pj__AudioMedia_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "AudioMediaVector2_rend" "', argument " "1"" of type '" "std::vector< pj::AudioMedia > *""'"); 
  }
  arg1 = reinterpret_cast< std::vector< pj::AudioMedia > * >(argp1);
  result = (arg1)->rend();
  resultobj = SWIG_NewPointerObj(swig::make_output_iterator(static_cast< const std::vector< pj::AudioMedia >::reverse_iterator & >(result)),
    swig::SwigPyIterator::descriptor(),SWIG_POINTER_OWN);
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_AudioMediaVector2_clear(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  std::vector< pj::AudioMedia > *arg1 = (std::vector< pj::AudioMedia > *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__vectorT_pj__AudioMedia_std__allocatorT_pj__AudioMedia_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "AudioMediaVector2_clear" "', argument " "1"" of type '" "std::vector< pj::AudioMedia > *""'"); 
  }
  arg1 = reinterpret_cast< std::vector< pj::AudioMedia > * >(argp1);
  (arg1)->clear();
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_AudioMediaVector2_get_allocator(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  std::vector< pj::AudioMedia > *arg1 = (std::vector< pj::AudioMedia > *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  SwigValueWrapper< std::allocator< pj::AudioMedia > > result;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__vectorT_pj__AudioMedia_std__allocatorT_pj__AudioMedia_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "AudioMediaVector2_get_allocator" "', argument " "1"" of type '" "std::vector< pj::AudioMedia > const *""'"); 
  }
  arg1 = reinterpret_cast< std::vector< pj::AudioMedia > * >(argp1);
  result = ((std::vector< pj::AudioMedia > const *)arg1)->get_allocator();
  resultobj = SWIG_NewPointerObj((new std::vector< pj::AudioMedia >::allocator_type(static_cast< const std::vector< pj::AudioMedia >::allocator_type& >(result))), SWIGTYPE_p_std__allocatorT_pj__AudioMedia_t, SWIG_POINTER_OWN |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_new_AudioMediaVector2__SWIG_2(PyObject *SWIGUNUSEDPARM(self), Py_ssize_t nobjs, PyObject **swig_obj) {
  PyObject *resultobj = 0;
  std::vector< pj::AudioMedia >::size_type arg1 ;
  size_t val1 ;
  int ecode1 = 0 ;
  std::vector< pj::AudioMedia > *result = 0 ;
  
  if ((nobjs < 1) || (nobjs > 1)) SWIG_fail;
  ecode1 = SWIG_AsVal_size_t(swig_obj[0], &val1);
  if (!SWIG_IsOK(ecode1)) {
    SWIG_exception_fail(SWIG_ArgError(ecode1), "in method '" "new_AudioMediaVector2" "', argument " "1"" of type '" "std::vector< pj::AudioMedia >::size_type""'");
  } 
  arg1 = static_cast< std::vector< pj::AudioMedia >::size_type >(val1);
  result = (std::vector< pj::AudioMedia > *)new std::vector< pj::AudioMedia >(arg1);
  resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(result), SWIGTYPE_p_std__vectorT_pj__AudioMedia_std__allocatorT_pj__AudioMedia_t_t, SWIG_POINTER_NEW |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_AudioMediaVector2_pop_back(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  std::vector< pj::AudioMedia > *arg1 = (std::vector< pj::AudioMedia > *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__vectorT_pj__AudioMedia_std__allocatorT_pj__AudioMedia_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "AudioMediaVector2_pop_back" "', argument " "1"" of type '" "std::vector< pj::AudioMedia > *""'"); 
  }
  arg1 = reinterpret_cast< std::vector< pj::AudioMedia > * >(argp1);
  (arg1)->pop_back();
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_AudioMediaVector2_resize__SWIG_0(PyObject *SWIGUNUSEDPARM(self), Py_ssize_t nobjs, PyObject **swig_obj) {
  PyObject *resultobj = 0;
  std::vector< pj::AudioMedia > *arg1 = (std::vector< pj::AudioMedia > *) 0 ;
  std::vector< pj::AudioMedia >::size_type arg2 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  size_t val2 ;
  int ecode2 = 0 ;
  
  if ((nobjs < 2) || (nobjs > 2)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__vectorT_pj__AudioMedia_std__allocatorT_pj__AudioMedia_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "AudioMediaVector2_resize" "', argument " "1"" of type '" "std::vector< pj::AudioMedia > *""'"); 
  }
  arg1 = reinterpret_cast< std::vector< pj::AudioMedia > * >(argp1);
  ecode2 = SWIG_AsVal_size_t(swig_obj[1], &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "AudioMediaVector2_resize" "', argument " "2"" of type '" "std::vector< pj::AudioMedia >::size_type""'");
  } 
  arg2 = static_cast< std::vector< pj::AudioMedia >::size_type >(val2);
  (arg1)->resize(arg2);
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_AudioMediaVector2_erase__SWIG_0(PyObject *SWIGUNUSEDPARM(self), Py_ssize_t nobjs, PyObject **swig_obj) {
  PyObject *resultobj = 0;
  std::vector< pj::AudioMedia > *arg1 = (std::vector< pj::AudioMedia > *) 0 ;
  std::vector< pj::AudioMedia >::iterator arg2 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  swig::SwigPyIterator *iter2 = 0 ;
  int res2 ;
  std::vector< pj::AudioMedia >::iterator result;
  
  if ((nobjs < 2) || (nobjs > 2)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__vectorT_pj__AudioMedia_std__allocatorT_pj__AudioMedia_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "AudioMediaVector2_erase" "', argument " "1"" of type '" "std::vector< pj::AudioMedia > *""'"); 
  }
  arg1 = reinterpret_cast< std::vector< pj::AudioMedia > * >(argp1);
  res2 = SWIG_ConvertPtr(swig_obj[1], SWIG_as_voidptrptr(&iter2), swig::SwigPyIterator::descriptor(), 0);
  if (!SWIG_IsOK(res2) || !iter2) {
    SWIG_exception_fail(SWIG_ArgError(SWIG_TypeError), "in method '" "AudioMediaVector2_erase" "', argument " "2"" of type '" "std::vector< pj::AudioMedia >::iterator""'");
  } else {
    swig::SwigPyIterator_T<std::vector< pj::AudioMedia >::iterator > *iter_t = dynamic_cast<swig::SwigPyIterator_T<std::vector< pj::AudioMedia >::iterator > *>(iter2);
    if (iter_t) {
      arg2 = iter_t->get_current();
    } else {
      SWIG_exception_fail(SWIG_ArgError(SWIG_TypeError), "in method '" "AudioMediaVector2_erase" "', argument " "2"" of type '" "std::vector< pj::AudioMedia >::iterator""'");
    }
  }
  result = std_vector_Sl_pj_AudioMedia_Sg__erase__SWIG_0(arg1,arg2);
  resultobj = SWIG_NewPointerObj(swig::make_output_iterator(static_cast< const std::vector< pj::AudioMedia >::iterator & >(result)),
    swig::SwigPyIterator::descriptor(),SWIG_POINTER_OWN);
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_AudioMediaVector2_erase__SWIG_1(PyObject *SWIGUNUSEDPARM(self), Py_ssize_t nobjs, PyObject **swig_obj) {
  PyObject *resultobj = 0;
  std::vector< pj::AudioMedia > *arg1 = (std::vector< pj::AudioMedia > *) 0 ;
  std::vector< pj::AudioMedia >::iterator arg2 ;
  std::vector< pj::AudioMedia >::iterator arg3 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  swig::SwigPyIterator *iter2 = 0 ;
  int res2 ;
  swig::SwigPyIterator *iter3 = 0 ;
  int res3 ;
  std::vector< pj::AudioMedia >::iterator result;
  
  if ((nobjs < 3) || (nobjs > 3)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__vectorT_pj__AudioMedia_std__allocatorT_pj__AudioMedia_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "AudioMediaVector2_erase" "', argument " "1"" of type '" "std::vector< pj::AudioMedia > *""'"); 
  }
  arg1 = reinterpret_cast< std::vector< pj::AudioMedia > * >(argp1);
  res2 = SWIG_ConvertPtr(swig_obj[1], SWIG_as_voidptrptr(&iter2), swig::SwigPyIterator::descriptor(), 0);
  if (!SWIG_IsOK(res2) || !iter2) {
    SWIG_exception_fail(SWIG_ArgError(SWIG_TypeError), "in method '" "AudioMediaVector2_erase" "', argument " "2"" of type '" "std::vector< pj::AudioMedia >::iterator""'");
  } else {
    swig::SwigPyIterator_T<std::vector< pj::AudioMedia >::iterator > *iter_t = dynamic_cast<swig::SwigPyIterator_T<std::vector< pj::AudioMedia >::iterator > *>(iter2);
    if (iter_t) {
      arg2 = iter_t->get_current();
    } else {
      SWIG_exception_fail(SWIG_ArgError(SWIG_TypeError), "in method '" "AudioMediaVector2_erase" "', argument " "2"" of type '" "std::vector< pj::AudioMedia >::iterator""'");
    }
  }
  res3 = SWIG_ConvertPtr(swig_obj[2], SWIG_as_voidptrptr(&iter3), swig::SwigPyIterator::descriptor(), 0);
  if (!SWIG_IsOK(res3) || !iter3) {
    SWIG_exception_fail(SWIG_ArgError(SWIG_TypeError), "in method '" "AudioMediaVector2_erase" "', argument " "3"" of type '" "std::vector< pj::AudioMedia >::iterator""'");
  } else {
    swig::SwigPyIterator_T<std::vector< pj::AudioMedia >::iterator > *iter_t = dynamic_cast<swig::SwigPyIterator_T<std::vector< pj::AudioMedia >::iterator > *>(iter3);
    if (iter_t) {
      arg3 = iter_t->get_current();
    } else {
      SWIG_exception_fail(SWIG_ArgError(SWIG_TypeError), "in method '" "AudioMediaVector2_erase" "', argument " "3"" of type '" "std::vector< pj::AudioMedia >::iterator""'");
    }
  }
  result = std_vector_Sl_pj_AudioMedia_Sg__erase__SWIG_1(arg1,arg2,arg3);
  resultobj = SWIG_NewPointerObj(swig::make_output_iterator(static_cast< const std::vector< pj::AudioMedia >::iterator & >(result)),
    swig::SwigPyIterator::descriptor(),SWIG_POINTER_OWN);
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_AudioMediaVector2_erase(PyObject *self, PyObject *args) {
  Py_ssize_t argc;
  PyObject *argv[4] = {
    0
  };
  
  if (!(argc = SWIG_Python_UnpackTuple(args, "AudioMediaVector2_erase", 0, 3, argv))) SWIG_fail;
  --argc;
  if (argc == 2) {
    int _v;
    int res = swig::asptr(argv[0], (std::vector< pj::AudioMedia,std::allocator< pj::AudioMedia > >**)(0));
    _v = SWIG_CheckState(res);
    if (_v) {
      swig::SwigPyIterator *iter = 0;
      int res = SWIG_ConvertPtr(argv[1], SWIG_as_voidptrptr(&iter), swig::SwigPyIterator::descriptor(), 0);
      _v = (SWIG_IsOK(res) && iter && (dynamic_cast<swig::SwigPyIterator_T<std::vector< pj::AudioMedia >::iterator > *>(iter) != 0));
      if (_v) {
        return _wrap_AudioMediaVector2_erase__SWIG_0(self, argc, argv);
      }
    }
  }
  if (argc == 3) {
    int _v;
    int res = swig::asptr(argv[0], (std::vector< pj::AudioMedia,std::allocator< pj::AudioMedia > >**)(0));
    _v = SWIG_CheckState(res);
    if (_v) {
      swig::SwigPyIterator *iter = 0;
      int res = SWIG_ConvertPtr(argv[1], SWIG_as_voidptrptr(&iter), swig::SwigPyIterator::descriptor(), 0);
      _v = (SWIG_IsOK(res) && iter && (dynamic_cast<swig::SwigPyIterator_T<std::vector< pj::AudioMedia >::iterator > *>(iter) != 0));
      if (_v) {
        swig::SwigPyIterator *iter = 0;
        int res = SWIG_ConvertPtr(argv[2], SWIG_as_voidptrptr(&iter), swig::SwigPyIterator::descriptor(), 0);
        _v = (SWIG_IsOK(res) && iter && (dynamic_cast<swig::SwigPyIterator_T<std::vector< pj::AudioMedia >::iterator > *>(iter) != 0));
        if (_v) {
          return _wrap_AudioMediaVector2_erase__SWIG_1(self, argc, argv);
        }
      }
    }
  }
  
fail:
  SWIG_Python_RaiseOrModifyTypeError("Wrong number or type of arguments for overloaded function 'AudioMediaVector2_erase'.\n"
    "  Possible C/C++ prototypes are:\n"
    "    std::vector< pj::AudioMedia >::erase(std::vector< pj::AudioMedia >::iterator)\n"
    "    std::vector< pj::AudioMedia >::erase(std::vector< pj::AudioMedia >::iterator,std::vector< pj::AudioMedia >::iterator)\n");
  return 0;
}


SWIGINTERN PyObject *_wrap_new_AudioMediaVector2__SWIG_3(PyObject *SWIGUNUSEDPARM(self), Py_ssize_t nobjs, PyObject **swig_obj) {
  PyObject *resultobj = 0;
  std::vector< pj::AudioMedia >::size_type arg1 ;
  std::vector< pj::AudioMedia >::value_type *arg2 = 0 ;
  size_t val1 ;
  int ecode1 = 0 ;
  void *argp2 = 0 ;
  int res2 = 0 ;
  std::vector< pj::AudioMedia > *result = 0 ;
  
  if ((nobjs < 2) || (nobjs > 2)) SWIG_fail;
  ecode1 = SWIG_AsVal_size_t(swig_obj[0], &val1);
  if (!SWIG_IsOK(ecode1)) {
    SWIG_exception_fail(SWIG_ArgError(ecode1), "in method '" "new_AudioMediaVector2" "', argument " "1"" of type '" "std::vector< pj::AudioMedia >::size_type""'");
  } 
  arg1 = static_cast< std::vector< pj::AudioMedia >::size_type >(val1);
  res2 = SWIG_ConvertPtr(swig_obj[1], &argp2, SWIGTYPE_p_pj__AudioMedia,  0  | 0);
  if (!SWIG_IsOK(res2)) {
    SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "new_AudioMediaVector2" "', argument " "2"" of type '" "std::vector< pj::AudioMedia >::value_type const &""'"); 
  }
  if (!argp2) {
    SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "new_AudioMediaVector2" "', argument " "2"" of type '" "std::vector< pj::AudioMedia >::value_type const &""'"); 
  }
  arg2 = reinterpret_cast< std::vector< pj::AudioMedia >::value_type * >(argp2);
  result = (std::vector< pj::AudioMedia > *)new std::vector< pj::AudioMedia >(arg1,(std::vector< pj::AudioMedia >::value_type const &)*arg2);
  resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(result), SWIGTYPE_p_std__vectorT_pj__AudioMedia_std__allocatorT_pj__AudioMedia_t_t, SWIG_POINTER_NEW |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_new_AudioMediaVector2(PyObject *self, PyObject *args) {
  Py_ssize_t argc;
  PyObject *argv[3] = {
    0
  };
  
  if (!(argc = SWIG_Python_UnpackTuple(args, "new_AudioMediaVector2", 0, 2, argv))) SWIG_fail;
  --argc;
  if (argc == 0) {
    return _wrap_new_AudioMediaVector2__SWIG_0(self, argc, argv);
  }
  if (argc == 1) {
    int _v;
    {
      int res = SWIG_AsVal_size_t(argv[0], NULL);
      _v = SWIG_CheckState(res);
    }
    if (_v) {
      return _wrap_new_AudioMediaVector2__SWIG_2(self, argc, argv);
    }
  }
  if (argc == 1) {
    int _v;
    int res = swig::asptr(argv[0], (std::vector< pj::AudioMedia,std::allocator< pj::AudioMedia > >**)(0));
    _v = SWIG_CheckState(res);
    if (_v) {
      return _wrap_new_AudioMediaVector2__SWIG_1(self, argc, argv);
    }
  }
  if (argc == 2) {
    int _v;
    {
      int res = SWIG_AsVal_size_t(argv[0], NULL);
      _v = SWIG_CheckState(res);
    }
    if (_v) {
      int res = SWIG_ConvertPtr(argv[1], 0, SWIGTYPE_p_pj__AudioMedia, SWIG_POINTER_NO_NULL | 0);
      _v = SWIG_CheckState(res);
      if (_v) {
        return _wrap_new_AudioMediaVector2__SWIG_3(self, argc, argv);
      }
    }
  }
  
fail:
  SWIG_Python_RaiseOrModifyTypeError("Wrong number or type of arguments for overloaded function 'new_AudioMediaVector2'.\n"
    "  Possible C/C++ prototypes are:\n"
    "    std::vector< pj::AudioMedia >::vector()\n"
    "    std::vector< pj::AudioMedia >::vector(std::vector< pj::AudioMedia > const &)\n"
    "    std::vector< pj::AudioMedia >::vector(std::vector< pj::AudioMedia >::size_type)\n"
    "    std::vector< pj::AudioMedia >::vector(std::vector< pj::AudioMedia >::size_type,std::vector< pj::AudioMedia >::value_type const &)\n");
  return 0;
}


SWIGINTERN PyObject *_wrap_AudioMediaVector2_push_back(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  std::vector< pj::AudioMedia > *arg1 = (std::vector< pj::AudioMedia > *) 0 ;
  std::vector< pj::AudioMedia >::value_type *arg2 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  void *argp2 = 0 ;
  int res2 = 0 ;
  PyObject *swig_obj[2] ;
  
  if (!SWIG_Python_UnpackTuple(args, "AudioMediaVector2_push_back", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__vectorT_pj__AudioMedia_std__allocatorT_pj__AudioMedia_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "AudioMediaVector2_push_back" "', argument " "1"" of type '" "std::vector< pj::AudioMedia > *""'"); 
  }
  arg1 = reinterpret_cast< std::vector< pj::AudioMedia > * >(argp1);
  res2 = SWIG_ConvertPtr(swig_obj[1], &argp2, SWIGTYPE_p_pj__AudioMedia,  0  | 0);
  if (!SWIG_IsOK(res2)) {
    SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "AudioMediaVector2_push_back" "', argument " "2"" of type '" "std::vector< pj::AudioMedia >::value_type const &""'"); 
  }
  if (!argp2) {
    SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "AudioMediaVector2_push_back" "', argument " "2"" of type '" "std::vector< pj::AudioMedia >::value_type const &""'"); 
  }
  arg2 = reinterpret_cast< std::vector< pj::AudioMedia >::value_type * >(argp2);
  (arg1)->push_back((std::vector< pj::AudioMedia >::value_type const &)*arg2);
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_AudioMediaVector2_front(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  std::vector< pj::AudioMedia > *arg1 = (std::vector< pj::AudioMedia > *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  std::vector< pj::AudioMedia >::value_type *result = 0 ;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__vectorT_pj__AudioMedia_std__allocatorT_pj__AudioMedia_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "AudioMediaVector2_front" "', argument " "1"" of type '" "std::vector< pj::AudioMedia > const *""'"); 
  }
  arg1 = reinterpret_cast< std::vector< pj::AudioMedia > * >(argp1);
  result = (std::vector< pj::AudioMedia >::value_type *) &((std::vector< pj::AudioMedia > const *)arg1)->front();
  resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(result), SWIGTYPE_p_pj__AudioMedia, 0 |  0 );
  (void)swig::container_owner<swig::traits<std::vector< pj::AudioMedia >::value_type>::category>::back_reference(resultobj, swig_obj[0]);
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_AudioMediaVector2_back(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  std::vector< pj::AudioMedia > *arg1 = (std::vector< pj::AudioMedia > *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  std::vector< pj::AudioMedia >::value_type *result = 0 ;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__vectorT_pj__AudioMedia_std__allocatorT_pj__AudioMedia_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "AudioMediaVector2_back" "', argument " "1"" of type '" "std::vector< pj::AudioMedia > const *""'"); 
  }
  arg1 = reinterpret_cast< std::vector< pj::AudioMedia > * >(argp1);
  result = (std::vector< pj::AudioMedia >::value_type *) &((std::vector< pj::AudioMedia > const *)arg1)->back();
  resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(result), SWIGTYPE_p_pj__AudioMedia, 0 |  0 );
  (void)swig::container_owner<swig::traits<std::vector< pj::AudioMedia >::value_type>::category>::back_reference(resultobj, swig_obj[0]);
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_AudioMediaVector2_assign(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  std::vector< pj::AudioMedia > *arg1 = (std::vector< pj::AudioMedia > *) 0 ;
  std::vector< pj::AudioMedia >::size_type arg2 ;
  std::vector< pj::AudioMedia >::value_type *arg3 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  size_t val2 ;
  int ecode2 = 0 ;
  void *argp3 = 0 ;
  int res3 = 0 ;
  PyObject *swig_obj[3] ;
  
  if (!SWIG_Python_UnpackTuple(args, "AudioMediaVector2_assign", 3, 3, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__vectorT_pj__AudioMedia_std__allocatorT_pj__AudioMedia_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "AudioMediaVector2_assign" "', argument " "1"" of type '" "std::vector< pj::AudioMedia > *""'"); 
  }
  arg1 = reinterpret_cast< std::vector< pj::AudioMedia > * >(argp1);
  ecode2 = SWIG_AsVal_size_t(swig_obj[1], &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "AudioMediaVector2_assign" "', argument " "2"" of type '" "std::vector< pj::AudioMedia >::size_type""'");
  } 
  arg2 = static_cast< std::vector< pj::AudioMedia >::size_type >(val2);
  res3 = SWIG_ConvertPtr(swig_obj[2], &argp3, SWIGTYPE_p_pj__AudioMedia,  0  | 0);
  if (!SWIG_IsOK(res3)) {
    SWIG_exception_fail(SWIG_ArgError(res3), "in method '" "AudioMediaVector2_assign" "', argument " "3"" of type '" "std::vector< pj::AudioMedia >::value_type const &""'"); 
  }
  if (!argp3) {
    SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "AudioMediaVector2_assign" "', argument " "3"" of type '" "std::vector< pj::AudioMedia >::value_type const &""'"); 
  }
  arg3 = reinterpret_cast< std::vector< pj::AudioMedia >::value_type * >(argp3);
  (arg1)->assign(arg2,(std::vector< pj::AudioMedia >::value_type const &)*arg3);
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_AudioMediaVector2_resize__SWIG_1(PyObject *SWIGUNUSEDPARM(self), Py_ssize_t nobjs, PyObject **swig_obj) {
  PyObject *resultobj = 0;
  std::vector< pj::AudioMedia > *arg1 = (std::vector< pj::AudioMedia > *) 0 ;
  std::vector< pj::AudioMedia >::size_type arg2 ;
  std::vector< pj::AudioMedia >::value_type *arg3 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  size_t val2 ;
  int ecode2 = 0 ;
  void *argp3 = 0 ;
  int res3 = 0 ;
  
  if ((nobjs < 3) || (nobjs > 3)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__vectorT_pj__AudioMedia_std__allocatorT_pj__AudioMedia_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "AudioMediaVector2_resize" "', argument " "1"" of type '" "std::vector< pj::AudioMedia > *""'"); 
  }
  arg1 = reinterpret_cast< std::vector< pj::AudioMedia > * >(argp1);
  ecode2 = SWIG_AsVal_size_t(swig_obj[1], &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "AudioMediaVector2_resize" "', argument " "2"" of type '" "std::vector< pj::AudioMedia >::size_type""'");
  } 
  arg2 = static_cast< std::vector< pj::AudioMedia >::size_type >(val2);
  res3 = SWIG_ConvertPtr(swig_obj[2], &argp3, SWIGTYPE_p_pj__AudioMedia,  0  | 0);
  if (!SWIG_IsOK(res3)) {
    SWIG_exception_fail(SWIG_ArgError(res3), "in method '" "AudioMediaVector2_resize" "', argument " "3"" of type '" "std::vector< pj::AudioMedia >::value_type const &""'"); 
  }
  if (!argp3) {
    SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "AudioMediaVector2_resize" "', argument " "3"" of type '" "std::vector< pj::AudioMedia >::value_type const &""'"); 
  }
  arg3 = reinterpret_cast< std::vector< pj::AudioMedia >::value_type * >(argp3);
  (arg1)->resize(arg2,(std::vector< pj::AudioMedia >::value_type const &)*arg3);
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_AudioMediaVector2_resize(PyObject *self, PyObject *args) {
  Py_ssize_t argc;
  PyObject *argv[4] = {
    0
  };
  
  if (!(argc = SWIG_Python_UnpackTuple(args, "AudioMediaVector2_resize", 0, 3, argv))) SWIG_fail;
  --argc;
  if (argc == 2) {
    int _v;
    int res = swig::asptr(argv[0], (std::vector< pj::AudioMedia,std::allocator< pj::AudioMedia > >**)(0));
    _v = SWIG_CheckState(res);
    if (_v) {
      {
        int res = SWIG_AsVal_size_t(argv[1], NULL);
        _v = SWIG_CheckState(res);
      }
      if (_v) {
        return _wrap_AudioMediaVector2_resize__SWIG_0(self, argc, argv);
      }
    }
  }
  if (argc == 3) {
    int _v;
    int res = swig::asptr(argv[0], (std::vector< pj::AudioMedia,std::allocator< pj::AudioMedia > >**)(0));
    _v = SWIG_CheckState(res);
    if (_v) {
      {
        int res = SWIG_AsVal_size_t(argv[1], NULL);
        _v = SWIG_CheckState(res);
      }
      if (_v) {
        int res = SWIG_ConvertPtr(argv[2], 0, SWIGTYPE_p_pj__AudioMedia, SWIG_POINTER_NO_NULL | 0);
        _v = SWIG_CheckState(res);
        if (_v) {
          return _wrap_AudioMediaVector2_resize__SWIG_1(self, argc, argv);
        }
      }
    }
  }
  
fail:
  SWIG_Python_RaiseOrModifyTypeError("Wrong number or type of arguments for overloaded function 'AudioMediaVector2_resize'.\n"
    "  Possible C/C++ prototypes are:\n"
    "    std::vector< pj::AudioMedia >::resize(std::vector< pj::AudioMedia >::size_type)\n"
    "    std::vector< pj::AudioMedia >::resize(std::vector< pj::AudioMedia >::size_type,std::vector< pj::AudioMedia >::value_type const &)\n");
  return 0;
}


SWIGINTERN PyObject *_wrap_AudioMediaVector2_insert__SWIG_0(PyObject *SWIGUNUSEDPARM(self), Py_ssize_t nobjs, PyObject **swig_obj) {
  PyObject *resultobj = 0;
  std::vector< pj::AudioMedia > *arg1 = (std::vector< pj::AudioMedia > *) 0 ;
  std::vector< pj::AudioMedia >::iterator arg2 ;
  std::vector< pj::AudioMedia >::value_type *arg3 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  swig::SwigPyIterator *iter2 = 0 ;
  int res2 ;
  void *argp3 = 0 ;
  int res3 = 0 ;
  std::vector< pj::AudioMedia >::iterator result;
  
  if ((nobjs < 3) || (nobjs > 3)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__vectorT_pj__AudioMedia_std__allocatorT_pj__AudioMedia_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "AudioMediaVector2_insert" "', argument " "1"" of type '" "std::vector< pj::AudioMedia > *""'"); 
  }
  arg1 = reinterpret_cast< std::vector< pj::AudioMedia > * >(argp1);
  res2 = SWIG_ConvertPtr(swig_obj[1], SWIG_as_voidptrptr(&iter2), swig::SwigPyIterator::descriptor(), 0);
  if (!SWIG_IsOK(res2) || !iter2) {
    SWIG_exception_fail(SWIG_ArgError(SWIG_TypeError), "in method '" "AudioMediaVector2_insert" "', argument " "2"" of type '" "std::vector< pj::AudioMedia >::iterator""'");
  } else {
    swig::SwigPyIterator_T<std::vector< pj::AudioMedia >::iterator > *iter_t = dynamic_cast<swig::SwigPyIterator_T<std::vector< pj::AudioMedia >::iterator > *>(iter2);
    if (iter_t) {
      arg2 = iter_t->get_current();
    } else {
      SWIG_exception_fail(SWIG_ArgError(SWIG_TypeError), "in method '" "AudioMediaVector2_insert" "', argument " "2"" of type '" "std::vector< pj::AudioMedia >::iterator""'");
    }
  }
  res3 = SWIG_ConvertPtr(swig_obj[2], &argp3, SWIGTYPE_p_pj__AudioMedia,  0  | 0);
  if (!SWIG_IsOK(res3)) {
    SWIG_exception_fail(SWIG_ArgError(res3), "in method '" "AudioMediaVector2_insert" "', argument " "3"" of type '" "std::vector< pj::AudioMedia >::value_type const &""'"); 
  }
  if (!argp3) {
    SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "AudioMediaVector2_insert" "', argument " "3"" of type '" "std::vector< pj::AudioMedia >::value_type const &""'"); 
  }
  arg3 = reinterpret_cast< std::vector< pj::AudioMedia >::value_type * >(argp3);
  result = std_vector_Sl_pj_AudioMedia_Sg__insert__SWIG_0(arg1,arg2,(pj::AudioMedia const &)*arg3);
  resultobj = SWIG_NewPointerObj(swig::make_output_iterator(static_cast< const std::vector< pj::AudioMedia >::iterator & >(result)),
    swig::SwigPyIterator::descriptor(),SWIG_POINTER_OWN);
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_AudioMediaVector2_insert__SWIG_1(PyObject *SWIGUNUSEDPARM(self), Py_ssize_t nobjs, PyObject **swig_obj) {
  PyObject *resultobj = 0;
  std::vector< pj::AudioMedia > *arg1 = (std::vector< pj::AudioMedia > *) 0 ;
  std::vector< pj::AudioMedia >::iterator arg2 ;
  std::vector< pj::AudioMedia >::size_type arg3 ;
  std::vector< pj::AudioMedia >::value_type *arg4 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  swig::SwigPyIterator *iter2 = 0 ;
  int res2 ;
  size_t val3 ;
  int ecode3 = 0 ;
  void *argp4 = 0 ;
  int res4 = 0 ;
  
  if ((nobjs < 4) || (nobjs > 4)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__vectorT_pj__AudioMedia_std__allocatorT_pj__AudioMedia_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "AudioMediaVector2_insert" "', argument " "1"" of type '" "std::vector< pj::AudioMedia > *""'"); 
  }
  arg1 = reinterpret_cast< std::vector< pj::AudioMedia > * >(argp1);
  res2 = SWIG_ConvertPtr(swig_obj[1], SWIG_as_voidptrptr(&iter2), swig::SwigPyIterator::descriptor(), 0);
  if (!SWIG_IsOK(res2) || !iter2) {
    SWIG_exception_fail(SWIG_ArgError(SWIG_TypeError), "in method '" "AudioMediaVector2_insert" "', argument " "2"" of type '" "std::vector< pj::AudioMedia >::iterator""'");
  } else {
    swig::SwigPyIterator_T<std::vector< pj::AudioMedia >::iterator > *iter_t = dynamic_cast<swig::SwigPyIterator_T<std::vector< pj::AudioMedia >::iterator > *>(iter2);
    if (iter_t) {
      arg2 = iter_t->get_current();
    } else {
      SWIG_exception_fail(SWIG_ArgError(SWIG_TypeError), "in method '" "AudioMediaVector2_insert" "', argument " "2"" of type '" "std::vector< pj::AudioMedia >::iterator""'");
    }
  }
  ecode3 = SWIG_AsVal_size_t(swig_obj[2], &val3);
  if (!SWIG_IsOK(ecode3)) {
    SWIG_exception_fail(SWIG_ArgError(ecode3), "in method '" "AudioMediaVector2_insert" "', argument " "3"" of type '" "std::vector< pj::AudioMedia >::size_type""'");
  } 
  arg3 = static_cast< std::vector< pj::AudioMedia >::size_type >(val3);
  res4 = SWIG_ConvertPtr(swig_obj[3], &argp4, SWIGTYPE_p_pj__AudioMedia,  0  | 0);
  if (!SWIG_IsOK(res4)) {
    SWIG_exception_fail(SWIG_ArgError(res4), "in method '" "AudioMediaVector2_insert" "', argument " "4"" of type '" "std::vector< pj::AudioMedia >::value_type const &""'"); 
  }
  if (!argp4) {
    SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "AudioMediaVector2_insert" "', argument " "4"" of type '" "std::vector< pj::AudioMedia >::value_type const &""'"); 
  }
  arg4 = reinterpret_cast< std::vector< pj::AudioMedia >::value_type * >(argp4);
  std_vector_Sl_pj_AudioMedia_Sg__insert__SWIG_1(arg1,arg2,arg3,(pj::AudioMedia const &)*arg4);
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_AudioMediaVector2_insert(PyObject *self, PyObject *args) {
  Py_ssize_t argc;
  PyObject *argv[5] = {
    0
  };
  
  if (!(argc = SWIG_Python_UnpackTuple(args, "AudioMediaVector2_insert", 0, 4, argv))) SWIG_fail;
  --argc;
  if (argc == 3) {
    int _v;
    int res = swig::asptr(argv[0], (std::vector< pj::AudioMedia,std::allocator< pj::AudioMedia > >**)(0));
    _v = SWIG_CheckState(res);
    if (_v) {
      swig::SwigPyIterator *iter = 0;
      int res = SWIG_ConvertPtr(argv[1], SWIG_as_voidptrptr(&iter), swig::SwigPyIterator::descriptor(), 0);
      _v = (SWIG_IsOK(res) && iter && (dynamic_cast<swig::SwigPyIterator_T<std::vector< pj::AudioMedia >::iterator > *>(iter) != 0));
      if (_v) {
        int res = SWIG_ConvertPtr(argv[2], 0, SWIGTYPE_p_pj__AudioMedia, SWIG_POINTER_NO_NULL | 0);
        _v = SWIG_CheckState(res);
        if (_v) {
          return _wrap_AudioMediaVector2_insert__SWIG_0(self, argc, argv);
        }
      }
    }
  }
  if (argc == 4) {
    int _v;
    int res = swig::asptr(argv[0], (std::vector< pj::AudioMedia,std::allocator< pj::AudioMedia > >**)(0));
    _v = SWIG_CheckState(res);
    if (_v) {
      swig::SwigPyIterator *iter = 0;
      int res = SWIG_ConvertPtr(argv[1], SWIG_as_voidptrptr(&iter), swig::SwigPyIterator::descriptor(), 0);
      _v = (SWIG_IsOK(res) && iter && (dynamic_cast<swig::SwigPyIterator_T<std::vector< pj::AudioMedia >::iterator > *>(iter) != 0));
      if (_v) {
        {
          int res = SWIG_AsVal_size_t(argv[2], NULL);
          _v = SWIG_CheckState(res);
        }
        if (_v) {
          int res = SWIG_ConvertPtr(argv[3], 0, SWIGTYPE_p_pj__AudioMedia, SWIG_POINTER_NO_NULL | 0);
          _v = SWIG_CheckState(res);
          if (_v) {
            return _wrap_AudioMediaVector2_insert__SWIG_1(self, argc, argv);
          }
        }
      }
    }
  }
  
fail:
  SWIG_Python_RaiseOrModifyTypeError("Wrong number or type of arguments for overloaded function 'AudioMediaVector2_insert'.\n"
    "  Possible C/C++ prototypes are:\n"
    "    std::vector< pj::AudioMedia >::insert(std::vector< pj::AudioMedia >::iterator,std::vector< pj::AudioMedia >::value_type const &)\n"
    "    std::vector< pj::AudioMedia >::insert(std::vector< pj::AudioMedia >::iterator,std::vector< pj::AudioMedia >::size_type,std::vector< pj::AudioMedia >::value_type const &)\n");
  return 0;
}


SWIGINTERN PyObject *_wrap_AudioMediaVector2_reserve(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  std::vector< pj::AudioMedia > *arg1 = (std::vector< pj::AudioMedia > *) 0 ;
  std::vector< pj::AudioMedia >::size_type arg2 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  size_t val2 ;
  int ecode2 = 0 ;
  PyObject *swig_obj[2] ;
  
  if (!SWIG_Python_UnpackTuple(args, "AudioMediaVector2_reserve", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__vectorT_pj__AudioMedia_std__allocatorT_pj__AudioMedia_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "AudioMediaVector2_reserve" "', argument " "1"" of type '" "std::vector< pj::AudioMedia > *""'"); 
  }
  arg1 = reinterpret_cast< std::vector< pj::AudioMedia > * >(argp1);
  ecode2 = SWIG_AsVal_size_t(swig_obj[1], &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "AudioMediaVector2_reserve" "', argument " "2"" of type '" "std::vector< pj::AudioMedia >::size_type""'");
  } 
  arg2 = static_cast< std::vector< pj::AudioMedia >::size_type >(val2);
  (arg1)->reserve(arg2);
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_AudioMediaVector2_capacity(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  std::vector< pj::AudioMedia > *arg1 = (std::vector< pj::AudioMedia > *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  std::vector< pj::AudioMedia >::size_type result;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__vectorT_pj__AudioMedia_std__allocatorT_pj__AudioMedia_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "AudioMediaVector2_capacity" "', argument " "1"" of type '" "std::vector< pj::AudioMedia > const *""'"); 
  }
  arg1 = reinterpret_cast< std::vector< pj::AudioMedia > * >(argp1);
  result = ((std::vector< pj::AudioMedia > const *)arg1)->capacity();
  resultobj = SWIG_From_size_t(static_cast< size_t >(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_delete_AudioMediaVector2(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  std::vector< pj::AudioMedia > *arg1 = (std::vector< pj::AudioMedia > *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__vectorT_pj__AudioMedia_std__allocatorT_pj__AudioMedia_t_t, SWIG_POINTER_DISOWN |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "delete_AudioMediaVector2" "', argument " "1"" of type '" "std::vector< pj::AudioMedia > *""'"); 
  }
  arg1 = reinterpret_cast< std::vector< pj::AudioMedia > * >(argp1);
  delete arg1;
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *AudioMediaVector2_swigregister(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *obj;
  if (!SWIG_Python_UnpackTuple(args, "swigregister", 1, 1, &obj)) return NULL;
  SWIG_TypeNewClientData(SWIGTYPE_p_std__vectorT_pj__AudioMedia_std__allocatorT_pj__AudioMedia_t_t, SWIG_NewClientData(obj));
  return SWIG_Py_Void();
}

SWIGINTERN PyObject *AudioMediaVector2_swiginit(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  return SWIG_Python_InitShadowInstance(args);
}

SWIGINTERN PyObject *_wrap_VideoMediaVector_iterator(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  std::vector< pj::VideoMedia > *arg1 = (std::vector< pj::VideoMedia > *) 0 ;
  PyObject **arg2 = (PyObject **) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  swig::SwigPyIterator *result = 0 ;
  
  arg2 = &swig_obj[0];
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__vectorT_pj__VideoMedia_std__allocatorT_pj__VideoMedia_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "VideoMediaVector_iterator" "', argument " "1"" of type '" "std::vector< pj::VideoMedia > *""'"); 
  }
  arg1 = reinterpret_cast< std::vector< pj::VideoMedia > * >(argp1);
  result = (swig::SwigPyIterator *)std_vector_Sl_pj_VideoMedia_Sg__iterator(arg1,arg2);
  resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(result), SWIGTYPE_p_swig__SwigPyIterator, SWIG_POINTER_OWN |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_VideoMediaVector___nonzero__(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  std::vector< pj::VideoMedia > *arg1 = (std::vector< pj::VideoMedia > *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  bool result;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__vectorT_pj__VideoMedia_std__allocatorT_pj__VideoMedia_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "VideoMediaVector___nonzero__" "', argument " "1"" of type '" "std::vector< pj::VideoMedia > const *""'"); 
  }
  arg1 = reinterpret_cast< std::vector< pj::VideoMedia > * >(argp1);
  result = (bool)std_vector_Sl_pj_VideoMedia_Sg____nonzero__((std::vector< pj::VideoMedia > const *)arg1);
  resultobj = SWIG_From_bool(static_cast< bool >(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_VideoMediaVector___bool__(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  std::vector< pj::VideoMedia > *arg1 = (std::vector< pj::VideoMedia > *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  bool result;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__vectorT_pj__VideoMedia_std__allocatorT_pj__VideoMedia_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "VideoMediaVector___bool__" "', argument " "1"" of type '" "std::vector< pj::VideoMedia > const *""'"); 
  }
  arg1 = reinterpret_cast< std::vector< pj::VideoMedia > * >(argp1);
  result = (bool)std_vector_Sl_pj_VideoMedia_Sg____bool__((std::vector< pj::VideoMedia > const *)arg1);
  resultobj = SWIG_From_bool(static_cast< bool >(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_VideoMediaVector___len__(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  std::vector< pj::VideoMedia > *arg1 = (std::vector< pj::VideoMedia > *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  std::vector< pj::VideoMedia >::size_type result;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__vectorT_pj__VideoMedia_std__allocatorT_pj__VideoMedia_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "VideoMediaVector___len__" "', argument " "1"" of type '" "std::vector< pj::VideoMedia > const *""'"); 
  }
  arg1 = reinterpret_cast< std::vector< pj::VideoMedia > * >(argp1);
  result = std_vector_Sl_pj_VideoMedia_Sg____len__((std::vector< pj::VideoMedia > const *)arg1);
  resultobj = SWIG_From_size_t(static_cast< size_t >(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_VideoMediaVector___getslice__(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  std::vector< pj::VideoMedia > *arg1 = (std::vector< pj::VideoMedia > *) 0 ;
  std::vector< pj::VideoMedia >::difference_type arg2 ;
  std::vector< pj::VideoMedia >::difference_type arg3 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  ptrdiff_t val2 ;
  int ecode2 = 0 ;
  ptrdiff_t val3 ;
  int ecode3 = 0 ;
  PyObject *swig_obj[3] ;
  std::vector< pj::VideoMedia,std::allocator< pj::VideoMedia > > *result = 0 ;
  
  if (!SWIG_Python_UnpackTuple(args, "VideoMediaVector___getslice__", 3, 3, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__vectorT_pj__VideoMedia_std__allocatorT_pj__VideoMedia_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "VideoMediaVector___getslice__" "', argument " "1"" of type '" "std::vector< pj::VideoMedia > *""'"); 
  }
  arg1 = reinterpret_cast< std::vector< pj::VideoMedia > * >(argp1);
  ecode2 = SWIG_AsVal_ptrdiff_t(swig_obj[1], &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "VideoMediaVector___getslice__" "', argument " "2"" of type '" "std::vector< pj::VideoMedia >::difference_type""'");
  } 
  arg2 = static_cast< std::vector< pj::VideoMedia >::difference_type >(val2);
  ecode3 = SWIG_AsVal_ptrdiff_t(swig_obj[2], &val3);
  if (!SWIG_IsOK(ecode3)) {
    SWIG_exception_fail(SWIG_ArgError(ecode3), "in method '" "VideoMediaVector___getslice__" "', argument " "3"" of type '" "std::vector< pj::VideoMedia >::difference_type""'");
  } 
  arg3 = static_cast< std::vector< pj::VideoMedia >::difference_type >(val3);
  try {
    result = (std::vector< pj::VideoMedia,std::allocator< pj::VideoMedia > > *)std_vector_Sl_pj_VideoMedia_Sg____getslice__(arg1,arg2,arg3);
  } catch(std::out_of_range &_e) {
    SWIG_exception_fail(SWIG_IndexError, (&_e)->what());
  } catch(std::invalid_argument &_e) {
    SWIG_exception_fail(SWIG_ValueError, (&_e)->what());
  }
  resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(result), SWIGTYPE_p_std__vectorT_pj__VideoMedia_std__allocatorT_pj__VideoMedia_t_t, SWIG_POINTER_OWN |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_VideoMediaVector___setslice____SWIG_0(PyObject *SWIGUNUSEDPARM(self), Py_ssize_t nobjs, PyObject **swig_obj) {
  PyObject *resultobj = 0;
  std::vector< pj::VideoMedia > *arg1 = (std::vector< pj::VideoMedia > *) 0 ;
  std::vector< pj::VideoMedia >::difference_type arg2 ;
  std::vector< pj::VideoMedia >::difference_type arg3 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  ptrdiff_t val2 ;
  int ecode2 = 0 ;
  ptrdiff_t val3 ;
  int ecode3 = 0 ;
  
  if ((nobjs < 3) || (nobjs > 3)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__vectorT_pj__VideoMedia_std__allocatorT_pj__VideoMedia_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "VideoMediaVector___setslice__" "', argument " "1"" of type '" "std::vector< pj::VideoMedia > *""'"); 
  }
  arg1 = reinterpret_cast< std::vector< pj::VideoMedia > * >(argp1);
  ecode2 = SWIG_AsVal_ptrdiff_t(swig_obj[1], &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "VideoMediaVector___setslice__" "', argument " "2"" of type '" "std::vector< pj::VideoMedia >::difference_type""'");
  } 
  arg2 = static_cast< std::vector< pj::VideoMedia >::difference_type >(val2);
  ecode3 = SWIG_AsVal_ptrdiff_t(swig_obj[2], &val3);
  if (!SWIG_IsOK(ecode3)) {
    SWIG_exception_fail(SWIG_ArgError(ecode3), "in method '" "VideoMediaVector___setslice__" "', argument " "3"" of type '" "std::vector< pj::VideoMedia >::difference_type""'");
  } 
  arg3 = static_cast< std::vector< pj::VideoMedia >::difference_type >(val3);
  try {
    std_vector_Sl_pj_VideoMedia_Sg____setslice____SWIG_0(arg1,arg2,arg3);
  } catch(std::out_of_range &_e) {
    SWIG_exception_fail(SWIG_IndexError, (&_e)->what());
  } catch(std::invalid_argument &_e) {
    SWIG_exception_fail(SWIG_ValueError, (&_e)->what());
  }
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_VideoMediaVector___setslice____SWIG_1(PyObject *SWIGUNUSEDPARM(self), Py_ssize_t nobjs, PyObject **swig_obj) {
  PyObject *resultobj = 0;
  std::vector< pj::VideoMedia > *arg1 = (std::vector< pj::VideoMedia > *) 0 ;
  std::vector< pj::VideoMedia >::difference_type arg2 ;
  std::vector< pj::VideoMedia >::difference_type arg3 ;
  std::vector< pj::VideoMedia,std::allocator< pj::VideoMedia > > *arg4 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  ptrdiff_t val2 ;
  int ecode2 = 0 ;
  ptrdiff_t val3 ;
  int ecode3 = 0 ;
  int res4 = SWIG_OLDOBJ ;
  
  if ((nobjs < 4) || (nobjs > 4)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__vectorT_pj__VideoMedia_std__allocatorT_pj__VideoMedia_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "VideoMediaVector___setslice__" "', argument " "1"" of type '" "std::vector< pj::VideoMedia > *""'"); 
  }
  arg1 = reinterpret_cast< std::vector< pj::VideoMedia > * >(argp1);
  ecode2 = SWIG_AsVal_ptrdiff_t(swig_obj[1], &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "VideoMediaVector___setslice__" "', argument " "2"" of type '" "std::vector< pj::VideoMedia >::difference_type""'");
  } 
  arg2 = static_cast< std::vector< pj::VideoMedia >::difference_type >(val2);
  ecode3 = SWIG_AsVal_ptrdiff_t(swig_obj[2], &val3);
  if (!SWIG_IsOK(ecode3)) {
    SWIG_exception_fail(SWIG_ArgError(ecode3), "in method '" "VideoMediaVector___setslice__" "', argument " "3"" of type '" "std::vector< pj::VideoMedia >::difference_type""'");
  } 
  arg3 = static_cast< std::vector< pj::VideoMedia >::difference_type >(val3);
  {
    std::vector< pj::VideoMedia,std::allocator< pj::VideoMedia > > *ptr = (std::vector< pj::VideoMedia,std::allocator< pj::VideoMedia > > *)0;
    res4 = swig::asptr(swig_obj[3], &ptr);
    if (!SWIG_IsOK(res4)) {
      SWIG_exception_fail(SWIG_ArgError(res4), "in method '" "VideoMediaVector___setslice__" "', argument " "4"" of type '" "std::vector< pj::VideoMedia,std::allocator< pj::VideoMedia > > const &""'"); 
    }
    if (!ptr) {
      SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "VideoMediaVector___setslice__" "', argument " "4"" of type '" "std::vector< pj::VideoMedia,std::allocator< pj::VideoMedia > > const &""'"); 
    }
    arg4 = ptr;
  }
  try {
    std_vector_Sl_pj_VideoMedia_Sg____setslice____SWIG_1(arg1,arg2,arg3,(std::vector< pj::VideoMedia,std::allocator< pj::VideoMedia > > const &)*arg4);
  } catch(std::out_of_range &_e) {
    SWIG_exception_fail(SWIG_IndexError, (&_e)->what());
  } catch(std::invalid_argument &_e) {
    SWIG_exception_fail(SWIG_ValueError, (&_e)->what());
  }
  resultobj = SWIG_Py_Void();
  if (SWIG_IsNewObj(res4)) delete arg4;
  return resultobj;
fail:
  if (SWIG_IsNewObj(res4)) delete arg4;
  return NULL;
}


SWIGINTERN PyObject *_wrap_VideoMediaVector___setslice__(PyObject *self, PyObject *args) {
  Py_ssize_t argc;
  PyObject *argv[5] = {
    0
  };
  
  if (!(argc = SWIG_Python_UnpackTuple(args, "VideoMediaVector___setslice__", 0, 4, argv))) SWIG_fail;
  --argc;
  if (argc == 3) {
    int _v;
    int res = swig::asptr(argv[0], (std::vector< pj::VideoMedia,std::allocator< pj::VideoMedia > >**)(0));
    _v = SWIG_CheckState(res);
    if (_v) {
      {
        int res = SWIG_AsVal_ptrdiff_t(argv[1], NULL);
        _v = SWIG_CheckState(res);
      }
      if (_v) {
        {
          int res = SWIG_AsVal_ptrdiff_t(argv[2], NULL);
          _v = SWIG_CheckState(res);
        }
        if (_v) {
          return _wrap_VideoMediaVector___setslice____SWIG_0(self, argc, argv);
        }
      }
    }
  }
  if (argc == 4) {
    int _v;
    int res = swig::asptr(argv[0], (std::vector< pj::VideoMedia,std::allocator< pj::VideoMedia > >**)(0));
    _v = SWIG_CheckState(res);
    if (_v) {
      {
        int res = SWIG_AsVal_ptrdiff_t(argv[1], NULL);
        _v = SWIG_CheckState(res);
      }
      if (_v) {
        {
          int res = SWIG_AsVal_ptrdiff_t(argv[2], NULL);
          _v = SWIG_CheckState(res);
        }
        if (_v) {
          int res = swig::asptr(argv[3], (std::vector< pj::VideoMedia,std::allocator< pj::VideoMedia > >**)(0));
          _v = SWIG_CheckState(res);
          if (_v) {
            return _wrap_VideoMediaVector___setslice____SWIG_1(self, argc, argv);
          }
        }
      }
    }
  }
  
fail:
  SWIG_Python_RaiseOrModifyTypeError("Wrong number or type of arguments for overloaded function 'VideoMediaVector___setslice__'.\n"
    "  Possible C/C++ prototypes are:\n"
    "    std::vector< pj::VideoMedia >::__setslice__(std::vector< pj::VideoMedia >::difference_type,std::vector< pj::VideoMedia >::difference_type)\n"
    "    std::vector< pj::VideoMedia >::__setslice__(std::vector< pj::VideoMedia >::difference_type,std::vector< pj::VideoMedia >::difference_type,std::vector< pj::VideoMedia,std::allocator< pj::VideoMedia > > const &)\n");
  return 0;
}


SWIGINTERN PyObject *_wrap_VideoMediaVector___delslice__(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  std::vector< pj::VideoMedia > *arg1 = (std::vector< pj::VideoMedia > *) 0 ;
  std::vector< pj::VideoMedia >::difference_type arg2 ;
  std::vector< pj::VideoMedia >::difference_type arg3 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  ptrdiff_t val2 ;
  int ecode2 = 0 ;
  ptrdiff_t val3 ;
  int ecode3 = 0 ;
  PyObject *swig_obj[3] ;
  
  if (!SWIG_Python_UnpackTuple(args, "VideoMediaVector___delslice__", 3, 3, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__vectorT_pj__VideoMedia_std__allocatorT_pj__VideoMedia_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "VideoMediaVector___delslice__" "', argument " "1"" of type '" "std::vector< pj::VideoMedia > *""'"); 
  }
  arg1 = reinterpret_cast< std::vector< pj::VideoMedia > * >(argp1);
  ecode2 = SWIG_AsVal_ptrdiff_t(swig_obj[1], &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "VideoMediaVector___delslice__" "', argument " "2"" of type '" "std::vector< pj::VideoMedia >::difference_type""'");
  } 
  arg2 = static_cast< std::vector< pj::VideoMedia >::difference_type >(val2);
  ecode3 = SWIG_AsVal_ptrdiff_t(swig_obj[2], &val3);
  if (!SWIG_IsOK(ecode3)) {
    SWIG_exception_fail(SWIG_ArgError(ecode3), "in method '" "VideoMediaVector___delslice__" "', argument " "3"" of type '" "std::vector< pj::VideoMedia >::difference_type""'");
  } 
  arg3 = static_cast< std::vector< pj::VideoMedia >::difference_type >(val3);
  try {
    std_vector_Sl_pj_VideoMedia_Sg____delslice__(arg1,arg2,arg3);
  } catch(std::out_of_range &_e) {
    SWIG_exception_fail(SWIG_IndexError, (&_e)->what());
  } catch(std::invalid_argument &_e) {
    SWIG_exception_fail(SWIG_ValueError, (&_e)->what());
  }
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_VideoMediaVector___delitem____SWIG_0(PyObject *SWIGUNUSEDPARM(self), Py_ssize_t nobjs, PyObject **swig_obj) {
  PyObject *resultobj = 0;
  std::vector< pj::VideoMedia > *arg1 = (std::vector< pj::VideoMedia > *) 0 ;
  std::vector< pj::VideoMedia >::difference_type arg2 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  ptrdiff_t val2 ;
  int ecode2 = 0 ;
  
  if ((nobjs < 2) || (nobjs > 2)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__vectorT_pj__VideoMedia_std__allocatorT_pj__VideoMedia_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "VideoMediaVector___delitem__" "', argument " "1"" of type '" "std::vector< pj::VideoMedia > *""'"); 
  }
  arg1 = reinterpret_cast< std::vector< pj::VideoMedia > * >(argp1);
  ecode2 = SWIG_AsVal_ptrdiff_t(swig_obj[1], &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "VideoMediaVector___delitem__" "', argument " "2"" of type '" "std::vector< pj::VideoMedia >::difference_type""'");
  } 
  arg2 = static_cast< std::vector< pj::VideoMedia >::difference_type >(val2);
  try {
    std_vector_Sl_pj_VideoMedia_Sg____delitem____SWIG_0(arg1,arg2);
  } catch(std::out_of_range &_e) {
    SWIG_exception_fail(SWIG_IndexError, (&_e)->what());
  } catch(std::invalid_argument &_e) {
    SWIG_exception_fail(SWIG_ValueError, (&_e)->what());
  }
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_VideoMediaVector___getitem____SWIG_0(PyObject *SWIGUNUSEDPARM(self), Py_ssize_t nobjs, PyObject **swig_obj) {
  PyObject *resultobj = 0;
  std::vector< pj::VideoMedia > *arg1 = (std::vector< pj::VideoMedia > *) 0 ;
  PySliceObject *arg2 = (PySliceObject *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  std::vector< pj::VideoMedia,std::allocator< pj::VideoMedia > > *result = 0 ;
  
  if ((nobjs < 2) || (nobjs > 2)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__vectorT_pj__VideoMedia_std__allocatorT_pj__VideoMedia_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "VideoMediaVector___getitem__" "', argument " "1"" of type '" "std::vector< pj::VideoMedia > *""'"); 
  }
  arg1 = reinterpret_cast< std::vector< pj::VideoMedia > * >(argp1);
  {
    if (!PySlice_Check(swig_obj[1])) {
      SWIG_exception_fail(SWIG_ArgError(SWIG_TypeError), "in method '" "VideoMediaVector___getitem__" "', argument " "2"" of type '" "PySliceObject *""'");
    }
    arg2 = (PySliceObject *) swig_obj[1];
  }
  try {
    result = (std::vector< pj::VideoMedia,std::allocator< pj::VideoMedia > > *)std_vector_Sl_pj_VideoMedia_Sg____getitem____SWIG_0(arg1,arg2);
  } catch(std::out_of_range &_e) {
    SWIG_exception_fail(SWIG_IndexError, (&_e)->what());
  } catch(std::invalid_argument &_e) {
    SWIG_exception_fail(SWIG_ValueError, (&_e)->what());
  }
  resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(result), SWIGTYPE_p_std__vectorT_pj__VideoMedia_std__allocatorT_pj__VideoMedia_t_t, SWIG_POINTER_OWN |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_VideoMediaVector___setitem____SWIG_0(PyObject *SWIGUNUSEDPARM(self), Py_ssize_t nobjs, PyObject **swig_obj) {
  PyObject *resultobj = 0;
  std::vector< pj::VideoMedia > *arg1 = (std::vector< pj::VideoMedia > *) 0 ;
  PySliceObject *arg2 = (PySliceObject *) 0 ;
  std::vector< pj::VideoMedia,std::allocator< pj::VideoMedia > > *arg3 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  int res3 = SWIG_OLDOBJ ;
  
  if ((nobjs < 3) || (nobjs > 3)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__vectorT_pj__VideoMedia_std__allocatorT_pj__VideoMedia_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "VideoMediaVector___setitem__" "', argument " "1"" of type '" "std::vector< pj::VideoMedia > *""'"); 
  }
  arg1 = reinterpret_cast< std::vector< pj::VideoMedia > * >(argp1);
  {
    if (!PySlice_Check(swig_obj[1])) {
      SWIG_exception_fail(SWIG_ArgError(SWIG_TypeError), "in method '" "VideoMediaVector___setitem__" "', argument " "2"" of type '" "PySliceObject *""'");
    }
    arg2 = (PySliceObject *) swig_obj[1];
  }
  {
    std::vector< pj::VideoMedia,std::allocator< pj::VideoMedia > > *ptr = (std::vector< pj::VideoMedia,std::allocator< pj::VideoMedia > > *)0;
    res3 = swig::asptr(swig_obj[2], &ptr);
    if (!SWIG_IsOK(res3)) {
      SWIG_exception_fail(SWIG_ArgError(res3), "in method '" "VideoMediaVector___setitem__" "', argument " "3"" of type '" "std::vector< pj::VideoMedia,std::allocator< pj::VideoMedia > > const &""'"); 
    }
    if (!ptr) {
      SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "VideoMediaVector___setitem__" "', argument " "3"" of type '" "std::vector< pj::VideoMedia,std::allocator< pj::VideoMedia > > const &""'"); 
    }
    arg3 = ptr;
  }
  try {
    std_vector_Sl_pj_VideoMedia_Sg____setitem____SWIG_0(arg1,arg2,(std::vector< pj::VideoMedia,std::allocator< pj::VideoMedia > > const &)*arg3);
  } catch(std::out_of_range &_e) {
    SWIG_exception_fail(SWIG_IndexError, (&_e)->what());
  } catch(std::invalid_argument &_e) {
    SWIG_exception_fail(SWIG_ValueError, (&_e)->what());
  }
  resultobj = SWIG_Py_Void();
  if (SWIG_IsNewObj(res3)) delete arg3;
  return resultobj;
fail:
  if (SWIG_IsNewObj(res3)) delete arg3;
  return NULL;
}


SWIGINTERN PyObject *_wrap_VideoMediaVector___setitem____SWIG_1(PyObject *SWIGUNUSEDPARM(self), Py_ssize_t nobjs, PyObject **swig_obj) {
  PyObject *resultobj = 0;
  std::vector< pj::VideoMedia > *arg1 = (std::vector< pj::VideoMedia > *) 0 ;
  PySliceObject *arg2 = (PySliceObject *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  
  if ((nobjs < 2) || (nobjs > 2)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__vectorT_pj__VideoMedia_std__allocatorT_pj__VideoMedia_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "VideoMediaVector___setitem__" "', argument " "1"" of type '" "std::vector< pj::VideoMedia > *""'"); 
  }
  arg1 = reinterpret_cast< std::vector< pj::VideoMedia > * >(argp1);
  {
    if (!PySlice_Check(swig_obj[1])) {
      SWIG_exception_fail(SWIG_ArgError(SWIG_TypeError), "in method '" "VideoMediaVector___setitem__" "', argument " "2"" of type '" "PySliceObject *""'");
    }
    arg2 = (PySliceObject *) swig_obj[1];
  }
  try {
    std_vector_Sl_pj_VideoMedia_Sg____setitem____SWIG_1(arg1,arg2);
  } catch(std::out_of_range &_e) {
    SWIG_exception_fail(SWIG_IndexError, (&_e)->what());
  } catch(std::invalid_argument &_e) {
    SWIG_exception_fail(SWIG_ValueError, (&_e)->what());
  }
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_VideoMediaVector___delitem____SWIG_1(PyObject *SWIGUNUSEDPARM(self), Py_ssize_t nobjs, PyObject **swig_obj) {
  PyObject *resultobj = 0;
  std::vector< pj::VideoMedia > *arg1 = (std::vector< pj::VideoMedia > *) 0 ;
  PySliceObject *arg2 = (PySliceObject *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  
  if ((nobjs < 2) || (nobjs > 2)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__vectorT_pj__VideoMedia_std__allocatorT_pj__VideoMedia_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "VideoMediaVector___delitem__" "', argument " "1"" of type '" "std::vector< pj::VideoMedia > *""'"); 
  }
  arg1 = reinterpret_cast< std::vector< pj::VideoMedia > * >(argp1);
  {
    if (!PySlice_Check(swig_obj[1])) {
      SWIG_exception_fail(SWIG_ArgError(SWIG_TypeError), "in method '" "VideoMediaVector___delitem__" "', argument " "2"" of type '" "PySliceObject *""'");
    }
    arg2 = (PySliceObject *) swig_obj[1];
  }
  try {
    std_vector_Sl_pj_VideoMedia_Sg____delitem____SWIG_1(arg1,arg2);
  } catch(std::out_of_range &_e) {
    SWIG_exception_fail(SWIG_IndexError, (&_e)->what());
  } catch(std::invalid_argument &_e) {
    SWIG_exception_fail(SWIG_ValueError, (&_e)->what());
  }
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_VideoMediaVector___delitem__(PyObject *self, PyObject *args) {
  Py_ssize_t argc;
  PyObject *argv[3] = {
    0
  };
  
  if (!(argc = SWIG_Python_UnpackTuple(args, "VideoMediaVector___delitem__", 0, 2, argv))) SWIG_fail;
  --argc;
  if (argc == 2) {
    int _v;
    int res = swig::asptr(argv[0], (std::vector< pj::VideoMedia,std::allocator< pj::VideoMedia > >**)(0));
    _v = SWIG_CheckState(res);
    if (_v) {
      {
        _v = PySlice_Check(argv[1]);
      }
      if (_v) {
        return _wrap_VideoMediaVector___delitem____SWIG_1(self, argc, argv);
      }
    }
  }
  if (argc == 2) {
    int _v;
    int res = swig::asptr(argv[0], (std::vector< pj::VideoMedia,std::allocator< pj::VideoMedia > >**)(0));
    _v = SWIG_CheckState(res);
    if (_v) {
      {
        int res = SWIG_AsVal_ptrdiff_t(argv[1], NULL);
        _v = SWIG_CheckState(res);
      }
      if (_v) {
        return _wrap_VideoMediaVector___delitem____SWIG_0(self, argc, argv);
      }
    }
  }
  
fail:
  SWIG_Python_RaiseOrModifyTypeError("Wrong number or type of arguments for overloaded function 'VideoMediaVector___delitem__'.\n"
    "  Possible C/C++ prototypes are:\n"
    "    std::vector< pj::VideoMedia >::__delitem__(std::vector< pj::VideoMedia >::difference_type)\n"
    "    std::vector< pj::VideoMedia >::__delitem__(PySliceObject *)\n");
  return 0;
}


SWIGINTERN PyObject *_wrap_VideoMediaVector___getitem____SWIG_1(PyObject *SWIGUNUSEDPARM(self), Py_ssize_t nobjs, PyObject **swig_obj) {
  PyObject *resultobj = 0;
  std::vector< pj::VideoMedia > *arg1 = (std::vector< pj::VideoMedia > *) 0 ;
  std::vector< pj::VideoMedia >::difference_type arg2 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  ptrdiff_t val2 ;
  int ecode2 = 0 ;
  std::vector< pj::VideoMedia >::value_type *result = 0 ;
  
  if ((nobjs < 2) || (nobjs > 2)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__vectorT_pj__VideoMedia_std__allocatorT_pj__VideoMedia_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "VideoMediaVector___getitem__" "', argument " "1"" of type '" "std::vector< pj::VideoMedia > const *""'"); 
  }
  arg1 = reinterpret_cast< std::vector< pj::VideoMedia > * >(argp1);
  ecode2 = SWIG_AsVal_ptrdiff_t(swig_obj[1], &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "VideoMediaVector___getitem__" "', argument " "2"" of type '" "std::vector< pj::VideoMedia >::difference_type""'");
  } 
  arg2 = static_cast< std::vector< pj::VideoMedia >::difference_type >(val2);
  try {
    result = (std::vector< pj::VideoMedia >::value_type *) &std_vector_Sl_pj_VideoMedia_Sg____getitem____SWIG_1((std::vector< pj::VideoMedia > const *)arg1,arg2);
  } catch(std::out_of_range &_e) {
    SWIG_exception_fail(SWIG_IndexError, (&_e)->what());
  }
  resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(result), SWIGTYPE_p_pj__VideoMedia, 0 |  0 );
  (void)swig::container_owner<swig::traits<std::vector< pj::VideoMedia >::value_type>::category>::back_reference(resultobj, swig_obj[0]);
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_VideoMediaVector___getitem__(PyObject *self, PyObject *args) {
  Py_ssize_t argc;
  PyObject *argv[3] = {
    0
  };
  
  if (!(argc = SWIG_Python_UnpackTuple(args, "VideoMediaVector___getitem__", 0, 2, argv))) SWIG_fail;
  --argc;
  if (argc == 2) {
    int _v;
    int res = swig::asptr(argv[0], (std::vector< pj::VideoMedia,std::allocator< pj::VideoMedia > >**)(0));
    _v = SWIG_CheckState(res);
    if (_v) {
      {
        _v = PySlice_Check(argv[1]);
      }
      if (_v) {
        return _wrap_VideoMediaVector___getitem____SWIG_0(self, argc, argv);
      }
    }
  }
  if (argc == 2) {
    int _v;
    int res = swig::asptr(argv[0], (std::vector< pj::VideoMedia,std::allocator< pj::VideoMedia > >**)(0));
    _v = SWIG_CheckState(res);
    if (_v) {
      {
        int res = SWIG_AsVal_ptrdiff_t(argv[1], NULL);
        _v = SWIG_CheckState(res);
      }
      if (_v) {
        return _wrap_VideoMediaVector___getitem____SWIG_1(self, argc, argv);
      }
    }
  }
  
fail:
  SWIG_Python_RaiseOrModifyTypeError("Wrong number or type of arguments for overloaded function 'VideoMediaVector___getitem__'.\n"
    "  Possible C/C++ prototypes are:\n"
    "    std::vector< pj::VideoMedia >::__getitem__(PySliceObject *)\n"
    "    std::vector< pj::VideoMedia >::__getitem__(std::vector< pj::VideoMedia >::difference_type) const\n");
  return 0;
}


SWIGINTERN PyObject *_wrap_VideoMediaVector___setitem____SWIG_2(PyObject *SWIGUNUSEDPARM(self), Py_ssize_t nobjs, PyObject **swig_obj) {
  PyObject *resultobj = 0;
  std::vector< pj::VideoMedia > *arg1 = (std::vector< pj::VideoMedia > *) 0 ;
  std::vector< pj::VideoMedia >::difference_type arg2 ;
  std::vector< pj::VideoMedia >::value_type *arg3 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  ptrdiff_t val2 ;
  int ecode2 = 0 ;
  void *argp3 = 0 ;
  int res3 = 0 ;
  
  if ((nobjs < 3) || (nobjs > 3)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__vectorT_pj__VideoMedia_std__allocatorT_pj__VideoMedia_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "VideoMediaVector___setitem__" "', argument " "1"" of type '" "std::vector< pj::VideoMedia > *""'"); 
  }
  arg1 = reinterpret_cast< std::vector< pj::VideoMedia > * >(argp1);
  ecode2 = SWIG_AsVal_ptrdiff_t(swig_obj[1], &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "VideoMediaVector___setitem__" "', argument " "2"" of type '" "std::vector< pj::VideoMedia >::difference_type""'");
  } 
  arg2 = static_cast< std::vector< pj::VideoMedia >::difference_type >(val2);
  res3 = SWIG_ConvertPtr(swig_obj[2], &argp3, SWIGTYPE_p_pj__VideoMedia,  0  | 0);
  if (!SWIG_IsOK(res3)) {
    SWIG_exception_fail(SWIG_ArgError(res3), "in method '" "VideoMediaVector___setitem__" "', argument " "3"" of type '" "std::vector< pj::VideoMedia >::value_type const &""'"); 
  }
  if (!argp3) {
    SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "VideoMediaVector___setitem__" "', argument " "3"" of type '" "std::vector< pj::VideoMedia >::value_type const &""'"); 
  }
  arg3 = reinterpret_cast< std::vector< pj::VideoMedia >::value_type * >(argp3);
  try {
    std_vector_Sl_pj_VideoMedia_Sg____setitem____SWIG_2(arg1,arg2,(pj::VideoMedia const &)*arg3);
  } catch(std::out_of_range &_e) {
    SWIG_exception_fail(SWIG_IndexError, (&_e)->what());
  }
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_VideoMediaVector___setitem__(PyObject *self, PyObject *args) {
  Py_ssize_t argc;
  PyObject *argv[4] = {
    0
  };
  
  if (!(argc = SWIG_Python_UnpackTuple(args, "VideoMediaVector___setitem__", 0, 3, argv))) SWIG_fail;
  --argc;
  if (argc == 2) {
    int _v;
    int res = swig::asptr(argv[0], (std::vector< pj::VideoMedia,std::allocator< pj::VideoMedia > >**)(0));
    _v = SWIG_CheckState(res);
    if (_v) {
      {
        _v = PySlice_Check(argv[1]);
      }
      if (_v) {
        return _wrap_VideoMediaVector___setitem____SWIG_1(self, argc, argv);
      }
    }
  }
  if (argc == 3) {
    int _v;
    int res = swig::asptr(argv[0], (std::vector< pj::VideoMedia,std::allocator< pj::VideoMedia > >**)(0));
    _v = SWIG_CheckState(res);
    if (_v) {
      {
        _v = PySlice_Check(argv[1]);
      }
      if (_v) {
        int res = swig::asptr(argv[2], (std::vector< pj::VideoMedia,std::allocator< pj::VideoMedia > >**)(0));
        _v = SWIG_CheckState(res);
        if (_v) {
          return _wrap_VideoMediaVector___setitem____SWIG_0(self, argc, argv);
        }
      }
    }
  }
  if (argc == 3) {
    int _v;
    int res = swig::asptr(argv[0], (std::vector< pj::VideoMedia,std::allocator< pj::VideoMedia > >**)(0));
    _v = SWIG_CheckState(res);
    if (_v) {
      {
        int res = SWIG_AsVal_ptrdiff_t(argv[1], NULL);
        _v = SWIG_CheckState(res);
      }
      if (_v) {
        int res = SWIG_ConvertPtr(argv[2], 0, SWIGTYPE_p_pj__VideoMedia, SWIG_POINTER_NO_NULL | 0);
        _v = SWIG_CheckState(res);
        if (_v) {
          return _wrap_VideoMediaVector___setitem____SWIG_2(self, argc, argv);
        }
      }
    }
  }
  
fail:
  SWIG_Python_RaiseOrModifyTypeError("Wrong number or type of arguments for overloaded function 'VideoMediaVector___setitem__'.\n"
    "  Possible C/C++ prototypes are:\n"
    "    std::vector< pj::VideoMedia >::__setitem__(PySliceObject *,std::vector< pj::VideoMedia,std::allocator< pj::VideoMedia > > const &)\n"
    "    std::vector< pj::VideoMedia >::__setitem__(PySliceObject *)\n"
    "    std::vector< pj::VideoMedia >::__setitem__(std::vector< pj::VideoMedia >::difference_type,std::vector< pj::VideoMedia >::value_type const &)\n");
  return 0;
}


SWIGINTERN PyObject *_wrap_VideoMediaVector_pop(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  std::vector< pj::VideoMedia > *arg1 = (std::vector< pj::VideoMedia > *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  std::vector< pj::VideoMedia >::value_type result;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__vectorT_pj__VideoMedia_std__allocatorT_pj__VideoMedia_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "VideoMediaVector_pop" "', argument " "1"" of type '" "std::vector< pj::VideoMedia > *""'"); 
  }
  arg1 = reinterpret_cast< std::vector< pj::VideoMedia > * >(argp1);
  try {
    result = std_vector_Sl_pj_VideoMedia_Sg__pop(arg1);
  } catch(std::out_of_range &_e) {
    SWIG_exception_fail(SWIG_IndexError, (&_e)->what());
  }
  resultobj = SWIG_NewPointerObj((new std::vector< pj::VideoMedia >::value_type(static_cast< const std::vector< pj::VideoMedia >::value_type& >(result))), SWIGTYPE_p_pj__VideoMedia, SWIG_POINTER_OWN |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_VideoMediaVector_append(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  std::vector< pj::VideoMedia > *arg1 = (std::vector< pj::VideoMedia > *) 0 ;
  std::vector< pj::VideoMedia >::value_type *arg2 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  void *argp2 = 0 ;
  int res2 = 0 ;
  PyObject *swig_obj[2] ;
  
  if (!SWIG_Python_UnpackTuple(args, "VideoMediaVector_append", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__vectorT_pj__VideoMedia_std__allocatorT_pj__VideoMedia_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "VideoMediaVector_append" "', argument " "1"" of type '" "std::vector< pj::VideoMedia > *""'"); 
  }
  arg1 = reinterpret_cast< std::vector< pj::VideoMedia > * >(argp1);
  res2 = SWIG_ConvertPtr(swig_obj[1], &argp2, SWIGTYPE_p_pj__VideoMedia,  0  | 0);
  if (!SWIG_IsOK(res2)) {
    SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "VideoMediaVector_append" "', argument " "2"" of type '" "std::vector< pj::VideoMedia >::value_type const &""'"); 
  }
  if (!argp2) {
    SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "VideoMediaVector_append" "', argument " "2"" of type '" "std::vector< pj::VideoMedia >::value_type const &""'"); 
  }
  arg2 = reinterpret_cast< std::vector< pj::VideoMedia >::value_type * >(argp2);
  std_vector_Sl_pj_VideoMedia_Sg__append(arg1,(pj::VideoMedia const &)*arg2);
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_new_VideoMediaVector__SWIG_0(PyObject *SWIGUNUSEDPARM(self), Py_ssize_t nobjs, PyObject **SWIGUNUSEDPARM(swig_obj)) {
  PyObject *resultobj = 0;
  std::vector< pj::VideoMedia > *result = 0 ;
  
  if ((nobjs < 0) || (nobjs > 0)) SWIG_fail;
  result = (std::vector< pj::VideoMedia > *)new std::vector< pj::VideoMedia >();
  resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(result), SWIGTYPE_p_std__vectorT_pj__VideoMedia_std__allocatorT_pj__VideoMedia_t_t, SWIG_POINTER_NEW |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_new_VideoMediaVector__SWIG_1(PyObject *SWIGUNUSEDPARM(self), Py_ssize_t nobjs, PyObject **swig_obj) {
  PyObject *resultobj = 0;
  std::vector< pj::VideoMedia > *arg1 = 0 ;
  int res1 = SWIG_OLDOBJ ;
  std::vector< pj::VideoMedia > *result = 0 ;
  
  if ((nobjs < 1) || (nobjs > 1)) SWIG_fail;
  {
    std::vector< pj::VideoMedia,std::allocator< pj::VideoMedia > > *ptr = (std::vector< pj::VideoMedia,std::allocator< pj::VideoMedia > > *)0;
    res1 = swig::asptr(swig_obj[0], &ptr);
    if (!SWIG_IsOK(res1)) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "new_VideoMediaVector" "', argument " "1"" of type '" "std::vector< pj::VideoMedia > const &""'"); 
    }
    if (!ptr) {
      SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "new_VideoMediaVector" "', argument " "1"" of type '" "std::vector< pj::VideoMedia > const &""'"); 
    }
    arg1 = ptr;
  }
  result = (std::vector< pj::VideoMedia > *)new std::vector< pj::VideoMedia >((std::vector< pj::VideoMedia > const &)*arg1);
  resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(result), SWIGTYPE_p_std__vectorT_pj__VideoMedia_std__allocatorT_pj__VideoMedia_t_t, SWIG_POINTER_NEW |  0 );
  if (SWIG_IsNewObj(res1)) delete arg1;
  return resultobj;
fail:
  if (SWIG_IsNewObj(res1)) delete arg1;
  return NULL;
}


SWIGINTERN PyObject *_wrap_VideoMediaVector_empty(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  std::vector< pj::VideoMedia > *arg1 = (std::vector< pj::VideoMedia > *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  bool result;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__vectorT_pj__VideoMedia_std__allocatorT_pj__VideoMedia_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "VideoMediaVector_empty" "', argument " "1"" of type '" "std::vector< pj::VideoMedia > const *""'"); 
  }
  arg1 = reinterpret_cast< std::vector< pj::VideoMedia > * >(argp1);
  result = (bool)((std::vector< pj::VideoMedia > const *)arg1)->empty();
  resultobj = SWIG_From_bool(static_cast< bool >(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_VideoMediaVector_size(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  std::vector< pj::VideoMedia > *arg1 = (std::vector< pj::VideoMedia > *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  std::vector< pj::VideoMedia >::size_type result;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__vectorT_pj__VideoMedia_std__allocatorT_pj__VideoMedia_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "VideoMediaVector_size" "', argument " "1"" of type '" "std::vector< pj::VideoMedia > const *""'"); 
  }
  arg1 = reinterpret_cast< std::vector< pj::VideoMedia > * >(argp1);
  result = ((std::vector< pj::VideoMedia > const *)arg1)->size();
  resultobj = SWIG_From_size_t(static_cast< size_t >(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_VideoMediaVector_swap(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  std::vector< pj::VideoMedia > *arg1 = (std::vector< pj::VideoMedia > *) 0 ;
  std::vector< pj::VideoMedia > *arg2 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  void *argp2 = 0 ;
  int res2 = 0 ;
  PyObject *swig_obj[2] ;
  
  if (!SWIG_Python_UnpackTuple(args, "VideoMediaVector_swap", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__vectorT_pj__VideoMedia_std__allocatorT_pj__VideoMedia_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "VideoMediaVector_swap" "', argument " "1"" of type '" "std::vector< pj::VideoMedia > *""'"); 
  }
  arg1 = reinterpret_cast< std::vector< pj::VideoMedia > * >(argp1);
  res2 = SWIG_ConvertPtr(swig_obj[1], &argp2, SWIGTYPE_p_std__vectorT_pj__VideoMedia_std__allocatorT_pj__VideoMedia_t_t,  0 );
  if (!SWIG_IsOK(res2)) {
    SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "VideoMediaVector_swap" "', argument " "2"" of type '" "std::vector< pj::VideoMedia > &""'"); 
  }
  if (!argp2) {
    SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "VideoMediaVector_swap" "', argument " "2"" of type '" "std::vector< pj::VideoMedia > &""'"); 
  }
  arg2 = reinterpret_cast< std::vector< pj::VideoMedia > * >(argp2);
  (arg1)->swap(*arg2);
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_VideoMediaVector_begin(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  std::vector< pj::VideoMedia > *arg1 = (std::vector< pj::VideoMedia > *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  std::vector< pj::VideoMedia >::iterator result;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__vectorT_pj__VideoMedia_std__allocatorT_pj__VideoMedia_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "VideoMediaVector_begin" "', argument " "1"" of type '" "std::vector< pj::VideoMedia > *""'"); 
  }
  arg1 = reinterpret_cast< std::vector< pj::VideoMedia > * >(argp1);
  result = (arg1)->begin();
  resultobj = SWIG_NewPointerObj(swig::make_output_iterator(static_cast< const std::vector< pj::VideoMedia >::iterator & >(result)),
    swig::SwigPyIterator::descriptor(),SWIG_POINTER_OWN);
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_VideoMediaVector_end(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  std::vector< pj::VideoMedia > *arg1 = (std::vector< pj::VideoMedia > *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  std::vector< pj::VideoMedia >::iterator result;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__vectorT_pj__VideoMedia_std__allocatorT_pj__VideoMedia_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "VideoMediaVector_end" "', argument " "1"" of type '" "std::vector< pj::VideoMedia > *""'"); 
  }
  arg1 = reinterpret_cast< std::vector< pj::VideoMedia > * >(argp1);
  result = (arg1)->end();
  resultobj = SWIG_NewPointerObj(swig::make_output_iterator(static_cast< const std::vector< pj::VideoMedia >::iterator & >(result)),
    swig::SwigPyIterator::descriptor(),SWIG_POINTER_OWN);
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_VideoMediaVector_rbegin(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  std::vector< pj::VideoMedia > *arg1 = (std::vector< pj::VideoMedia > *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  std::vector< pj::VideoMedia >::reverse_iterator result;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__vectorT_pj__VideoMedia_std__allocatorT_pj__VideoMedia_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "VideoMediaVector_rbegin" "', argument " "1"" of type '" "std::vector< pj::VideoMedia > *""'"); 
  }
  arg1 = reinterpret_cast< std::vector< pj::VideoMedia > * >(argp1);
  result = (arg1)->rbegin();
  resultobj = SWIG_NewPointerObj(swig::make_output_iterator(static_cast< const std::vector< pj::VideoMedia >::reverse_iterator & >(result)),
    swig::SwigPyIterator::descriptor(),SWIG_POINTER_OWN);
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_VideoMediaVector_rend(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  std::vector< pj::VideoMedia > *arg1 = (std::vector< pj::VideoMedia > *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  std::vector< pj::VideoMedia >::reverse_iterator result;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__vectorT_pj__VideoMedia_std__allocatorT_pj__VideoMedia_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "VideoMediaVector_rend" "', argument " "1"" of type '" "std::vector< pj::VideoMedia > *""'"); 
  }
  arg1 = reinterpret_cast< std::vector< pj::VideoMedia > * >(argp1);
  result = (arg1)->rend();
  resultobj = SWIG_NewPointerObj(swig::make_output_iterator(static_cast< const std::vector< pj::VideoMedia >::reverse_iterator & >(result)),
    swig::SwigPyIterator::descriptor(),SWIG_POINTER_OWN);
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_VideoMediaVector_clear(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  std::vector< pj::VideoMedia > *arg1 = (std::vector< pj::VideoMedia > *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__vectorT_pj__VideoMedia_std__allocatorT_pj__VideoMedia_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "VideoMediaVector_clear" "', argument " "1"" of type '" "std::vector< pj::VideoMedia > *""'"); 
  }
  arg1 = reinterpret_cast< std::vector< pj::VideoMedia > * >(argp1);
  (arg1)->clear();
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_VideoMediaVector_get_allocator(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  std::vector< pj::VideoMedia > *arg1 = (std::vector< pj::VideoMedia > *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  SwigValueWrapper< std::allocator< pj::VideoMedia > > result;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__vectorT_pj__VideoMedia_std__allocatorT_pj__VideoMedia_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "VideoMediaVector_get_allocator" "', argument " "1"" of type '" "std::vector< pj::VideoMedia > const *""'"); 
  }
  arg1 = reinterpret_cast< std::vector< pj::VideoMedia > * >(argp1);
  result = ((std::vector< pj::VideoMedia > const *)arg1)->get_allocator();
  resultobj = SWIG_NewPointerObj((new std::vector< pj::VideoMedia >::allocator_type(static_cast< const std::vector< pj::VideoMedia >::allocator_type& >(result))), SWIGTYPE_p_std__allocatorT_pj__VideoMedia_t, SWIG_POINTER_OWN |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_new_VideoMediaVector__SWIG_2(PyObject *SWIGUNUSEDPARM(self), Py_ssize_t nobjs, PyObject **swig_obj) {
  PyObject *resultobj = 0;
  std::vector< pj::VideoMedia >::size_type arg1 ;
  size_t val1 ;
  int ecode1 = 0 ;
  std::vector< pj::VideoMedia > *result = 0 ;
  
  if ((nobjs < 1) || (nobjs > 1)) SWIG_fail;
  ecode1 = SWIG_AsVal_size_t(swig_obj[0], &val1);
  if (!SWIG_IsOK(ecode1)) {
    SWIG_exception_fail(SWIG_ArgError(ecode1), "in method '" "new_VideoMediaVector" "', argument " "1"" of type '" "std::vector< pj::VideoMedia >::size_type""'");
  } 
  arg1 = static_cast< std::vector< pj::VideoMedia >::size_type >(val1);
  result = (std::vector< pj::VideoMedia > *)new std::vector< pj::VideoMedia >(arg1);
  resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(result), SWIGTYPE_p_std__vectorT_pj__VideoMedia_std__allocatorT_pj__VideoMedia_t_t, SWIG_POINTER_NEW |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_VideoMediaVector_pop_back(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  std::vector< pj::VideoMedia > *arg1 = (std::vector< pj::VideoMedia > *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__vectorT_pj__VideoMedia_std__allocatorT_pj__VideoMedia_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "VideoMediaVector_pop_back" "', argument " "1"" of type '" "std::vector< pj::VideoMedia > *""'"); 
  }
  arg1 = reinterpret_cast< std::vector< pj::VideoMedia > * >(argp1);
  (arg1)->pop_back();
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_VideoMediaVector_resize__SWIG_0(PyObject *SWIGUNUSEDPARM(self), Py_ssize_t nobjs, PyObject **swig_obj) {
  PyObject *resultobj = 0;
  std::vector< pj::VideoMedia > *arg1 = (std::vector< pj::VideoMedia > *) 0 ;
  std::vector< pj::VideoMedia >::size_type arg2 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  size_t val2 ;
  int ecode2 = 0 ;
  
  if ((nobjs < 2) || (nobjs > 2)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__vectorT_pj__VideoMedia_std__allocatorT_pj__VideoMedia_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "VideoMediaVector_resize" "', argument " "1"" of type '" "std::vector< pj::VideoMedia > *""'"); 
  }
  arg1 = reinterpret_cast< std::vector< pj::VideoMedia > * >(argp1);
  ecode2 = SWIG_AsVal_size_t(swig_obj[1], &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "VideoMediaVector_resize" "', argument " "2"" of type '" "std::vector< pj::VideoMedia >::size_type""'");
  } 
  arg2 = static_cast< std::vector< pj::VideoMedia >::size_type >(val2);
  (arg1)->resize(arg2);
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_VideoMediaVector_erase__SWIG_0(PyObject *SWIGUNUSEDPARM(self), Py_ssize_t nobjs, PyObject **swig_obj) {
  PyObject *resultobj = 0;
  std::vector< pj::VideoMedia > *arg1 = (std::vector< pj::VideoMedia > *) 0 ;
  std::vector< pj::VideoMedia >::iterator arg2 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  swig::SwigPyIterator *iter2 = 0 ;
  int res2 ;
  std::vector< pj::VideoMedia >::iterator result;
  
  if ((nobjs < 2) || (nobjs > 2)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__vectorT_pj__VideoMedia_std__allocatorT_pj__VideoMedia_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "VideoMediaVector_erase" "', argument " "1"" of type '" "std::vector< pj::VideoMedia > *""'"); 
  }
  arg1 = reinterpret_cast< std::vector< pj::VideoMedia > * >(argp1);
  res2 = SWIG_ConvertPtr(swig_obj[1], SWIG_as_voidptrptr(&iter2), swig::SwigPyIterator::descriptor(), 0);
  if (!SWIG_IsOK(res2) || !iter2) {
    SWIG_exception_fail(SWIG_ArgError(SWIG_TypeError), "in method '" "VideoMediaVector_erase" "', argument " "2"" of type '" "std::vector< pj::VideoMedia >::iterator""'");
  } else {
    swig::SwigPyIterator_T<std::vector< pj::VideoMedia >::iterator > *iter_t = dynamic_cast<swig::SwigPyIterator_T<std::vector< pj::VideoMedia >::iterator > *>(iter2);
    if (iter_t) {
      arg2 = iter_t->get_current();
    } else {
      SWIG_exception_fail(SWIG_ArgError(SWIG_TypeError), "in method '" "VideoMediaVector_erase" "', argument " "2"" of type '" "std::vector< pj::VideoMedia >::iterator""'");
    }
  }
  result = std_vector_Sl_pj_VideoMedia_Sg__erase__SWIG_0(arg1,arg2);
  resultobj = SWIG_NewPointerObj(swig::make_output_iterator(static_cast< const std::vector< pj::VideoMedia >::iterator & >(result)),
    swig::SwigPyIterator::descriptor(),SWIG_POINTER_OWN);
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_VideoMediaVector_erase__SWIG_1(PyObject *SWIGUNUSEDPARM(self), Py_ssize_t nobjs, PyObject **swig_obj) {
  PyObject *resultobj = 0;
  std::vector< pj::VideoMedia > *arg1 = (std::vector< pj::VideoMedia > *) 0 ;
  std::vector< pj::VideoMedia >::iterator arg2 ;
  std::vector< pj::VideoMedia >::iterator arg3 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  swig::SwigPyIterator *iter2 = 0 ;
  int res2 ;
  swig::SwigPyIterator *iter3 = 0 ;
  int res3 ;
  std::vector< pj::VideoMedia >::iterator result;
  
  if ((nobjs < 3) || (nobjs > 3)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__vectorT_pj__VideoMedia_std__allocatorT_pj__VideoMedia_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "VideoMediaVector_erase" "', argument " "1"" of type '" "std::vector< pj::VideoMedia > *""'"); 
  }
  arg1 = reinterpret_cast< std::vector< pj::VideoMedia > * >(argp1);
  res2 = SWIG_ConvertPtr(swig_obj[1], SWIG_as_voidptrptr(&iter2), swig::SwigPyIterator::descriptor(), 0);
  if (!SWIG_IsOK(res2) || !iter2) {
    SWIG_exception_fail(SWIG_ArgError(SWIG_TypeError), "in method '" "VideoMediaVector_erase" "', argument " "2"" of type '" "std::vector< pj::VideoMedia >::iterator""'");
  } else {
    swig::SwigPyIterator_T<std::vector< pj::VideoMedia >::iterator > *iter_t = dynamic_cast<swig::SwigPyIterator_T<std::vector< pj::VideoMedia >::iterator > *>(iter2);
    if (iter_t) {
      arg2 = iter_t->get_current();
    } else {
      SWIG_exception_fail(SWIG_ArgError(SWIG_TypeError), "in method '" "VideoMediaVector_erase" "', argument " "2"" of type '" "std::vector< pj::VideoMedia >::iterator""'");
    }
  }
  res3 = SWIG_ConvertPtr(swig_obj[2], SWIG_as_voidptrptr(&iter3), swig::SwigPyIterator::descriptor(), 0);
  if (!SWIG_IsOK(res3) || !iter3) {
    SWIG_exception_fail(SWIG_ArgError(SWIG_TypeError), "in method '" "VideoMediaVector_erase" "', argument " "3"" of type '" "std::vector< pj::VideoMedia >::iterator""'");
  } else {
    swig::SwigPyIterator_T<std::vector< pj::VideoMedia >::iterator > *iter_t = dynamic_cast<swig::SwigPyIterator_T<std::vector< pj::VideoMedia >::iterator > *>(iter3);
    if (iter_t) {
      arg3 = iter_t->get_current();
    } else {
      SWIG_exception_fail(SWIG_ArgError(SWIG_TypeError), "in method '" "VideoMediaVector_erase" "', argument " "3"" of type '" "std::vector< pj::VideoMedia >::iterator""'");
    }
  }
  result = std_vector_Sl_pj_VideoMedia_Sg__erase__SWIG_1(arg1,arg2,arg3);
  resultobj = SWIG_NewPointerObj(swig::make_output_iterator(static_cast< const std::vector< pj::VideoMedia >::iterator & >(result)),
    swig::SwigPyIterator::descriptor(),SWIG_POINTER_OWN);
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_VideoMediaVector_erase(PyObject *self, PyObject *args) {
  Py_ssize_t argc;
  PyObject *argv[4] = {
    0
  };
  
  if (!(argc = SWIG_Python_UnpackTuple(args, "VideoMediaVector_erase", 0, 3, argv))) SWIG_fail;
  --argc;
  if (argc == 2) {
    int _v;
    int res = swig::asptr(argv[0], (std::vector< pj::VideoMedia,std::allocator< pj::VideoMedia > >**)(0));
    _v = SWIG_CheckState(res);
    if (_v) {
      swig::SwigPyIterator *iter = 0;
      int res = SWIG_ConvertPtr(argv[1], SWIG_as_voidptrptr(&iter), swig::SwigPyIterator::descriptor(), 0);
      _v = (SWIG_IsOK(res) && iter && (dynamic_cast<swig::SwigPyIterator_T<std::vector< pj::VideoMedia >::iterator > *>(iter) != 0));
      if (_v) {
        return _wrap_VideoMediaVector_erase__SWIG_0(self, argc, argv);
      }
    }
  }
  if (argc == 3) {
    int _v;
    int res = swig::asptr(argv[0], (std::vector< pj::VideoMedia,std::allocator< pj::VideoMedia > >**)(0));
    _v = SWIG_CheckState(res);
    if (_v) {
      swig::SwigPyIterator *iter = 0;
      int res = SWIG_ConvertPtr(argv[1], SWIG_as_voidptrptr(&iter), swig::SwigPyIterator::descriptor(), 0);
      _v = (SWIG_IsOK(res) && iter && (dynamic_cast<swig::SwigPyIterator_T<std::vector< pj::VideoMedia >::iterator > *>(iter) != 0));
      if (_v) {
        swig::SwigPyIterator *iter = 0;
        int res = SWIG_ConvertPtr(argv[2], SWIG_as_voidptrptr(&iter), swig::SwigPyIterator::descriptor(), 0);
        _v = (SWIG_IsOK(res) && iter && (dynamic_cast<swig::SwigPyIterator_T<std::vector< pj::VideoMedia >::iterator > *>(iter) != 0));
        if (_v) {
          return _wrap_VideoMediaVector_erase__SWIG_1(self, argc, argv);
        }
      }
    }
  }
  
fail:
  SWIG_Python_RaiseOrModifyTypeError("Wrong number or type of arguments for overloaded function 'VideoMediaVector_erase'.\n"
    "  Possible C/C++ prototypes are:\n"
    "    std::vector< pj::VideoMedia >::erase(std::vector< pj::VideoMedia >::iterator)\n"
    "    std::vector< pj::VideoMedia >::erase(std::vector< pj::VideoMedia >::iterator,std::vector< pj::VideoMedia >::iterator)\n");
  return 0;
}


SWIGINTERN PyObject *_wrap_new_VideoMediaVector__SWIG_3(PyObject *SWIGUNUSEDPARM(self), Py_ssize_t nobjs, PyObject **swig_obj) {
  PyObject *resultobj = 0;
  std::vector< pj::VideoMedia >::size_type arg1 ;
  std::vector< pj::VideoMedia >::value_type *arg2 = 0 ;
  size_t val1 ;
  int ecode1 = 0 ;
  void *argp2 = 0 ;
  int res2 = 0 ;
  std::vector< pj::VideoMedia > *result = 0 ;
  
  if ((nobjs < 2) || (nobjs > 2)) SWIG_fail;
  ecode1 = SWIG_AsVal_size_t(swig_obj[0], &val1);
  if (!SWIG_IsOK(ecode1)) {
    SWIG_exception_fail(SWIG_ArgError(ecode1), "in method '" "new_VideoMediaVector" "', argument " "1"" of type '" "std::vector< pj::VideoMedia >::size_type""'");
  } 
  arg1 = static_cast< std::vector< pj::VideoMedia >::size_type >(val1);
  res2 = SWIG_ConvertPtr(swig_obj[1], &argp2, SWIGTYPE_p_pj__VideoMedia,  0  | 0);
  if (!SWIG_IsOK(res2)) {
    SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "new_VideoMediaVector" "', argument " "2"" of type '" "std::vector< pj::VideoMedia >::value_type const &""'"); 
  }
  if (!argp2) {
    SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "new_VideoMediaVector" "', argument " "2"" of type '" "std::vector< pj::VideoMedia >::value_type const &""'"); 
  }
  arg2 = reinterpret_cast< std::vector< pj::VideoMedia >::value_type * >(argp2);
  result = (std::vector< pj::VideoMedia > *)new std::vector< pj::VideoMedia >(arg1,(std::vector< pj::VideoMedia >::value_type const &)*arg2);
  resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(result), SWIGTYPE_p_std__vectorT_pj__VideoMedia_std__allocatorT_pj__VideoMedia_t_t, SWIG_POINTER_NEW |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_new_VideoMediaVector(PyObject *self, PyObject *args) {
  Py_ssize_t argc;
  PyObject *argv[3] = {
    0
  };
  
  if (!(argc = SWIG_Python_UnpackTuple(args, "new_VideoMediaVector", 0, 2, argv))) SWIG_fail;
  --argc;
  if (argc == 0) {
    return _wrap_new_VideoMediaVector__SWIG_0(self, argc, argv);
  }
  if (argc == 1) {
    int _v;
    {
      int res = SWIG_AsVal_size_t(argv[0], NULL);
      _v = SWIG_CheckState(res);
    }
    if (_v) {
      return _wrap_new_VideoMediaVector__SWIG_2(self, argc, argv);
    }
  }
  if (argc == 1) {
    int _v;
    int res = swig::asptr(argv[0], (std::vector< pj::VideoMedia,std::allocator< pj::VideoMedia > >**)(0));
    _v = SWIG_CheckState(res);
    if (_v) {
      return _wrap_new_VideoMediaVector__SWIG_1(self, argc, argv);
    }
  }
  if (argc == 2) {
    int _v;
    {
      int res = SWIG_AsVal_size_t(argv[0], NULL);
      _v = SWIG_CheckState(res);
    }
    if (_v) {
      int res = SWIG_ConvertPtr(argv[1], 0, SWIGTYPE_p_pj__VideoMedia, SWIG_POINTER_NO_NULL | 0);
      _v = SWIG_CheckState(res);
      if (_v) {
        return _wrap_new_VideoMediaVector__SWIG_3(self, argc, argv);
      }
    }
  }
  
fail:
  SWIG_Python_RaiseOrModifyTypeError("Wrong number or type of arguments for overloaded function 'new_VideoMediaVector'.\n"
    "  Possible C/C++ prototypes are:\n"
    "    std::vector< pj::VideoMedia >::vector()\n"
    "    std::vector< pj::VideoMedia >::vector(std::vector< pj::VideoMedia > const &)\n"
    "    std::vector< pj::VideoMedia >::vector(std::vector< pj::VideoMedia >::size_type)\n"
    "    std::vector< pj::VideoMedia >::vector(std::vector< pj::VideoMedia >::size_type,std::vector< pj::VideoMedia >::value_type const &)\n");
  return 0;
}


SWIGINTERN PyObject *_wrap_VideoMediaVector_push_back(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  std::vector< pj::VideoMedia > *arg1 = (std::vector< pj::VideoMedia > *) 0 ;
  std::vector< pj::VideoMedia >::value_type *arg2 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  void *argp2 = 0 ;
  int res2 = 0 ;
  PyObject *swig_obj[2] ;
  
  if (!SWIG_Python_UnpackTuple(args, "VideoMediaVector_push_back", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__vectorT_pj__VideoMedia_std__allocatorT_pj__VideoMedia_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "VideoMediaVector_push_back" "', argument " "1"" of type '" "std::vector< pj::VideoMedia > *""'"); 
  }
  arg1 = reinterpret_cast< std::vector< pj::VideoMedia > * >(argp1);
  res2 = SWIG_ConvertPtr(swig_obj[1], &argp2, SWIGTYPE_p_pj__VideoMedia,  0  | 0);
  if (!SWIG_IsOK(res2)) {
    SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "VideoMediaVector_push_back" "', argument " "2"" of type '" "std::vector< pj::VideoMedia >::value_type const &""'"); 
  }
  if (!argp2) {
    SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "VideoMediaVector_push_back" "', argument " "2"" of type '" "std::vector< pj::VideoMedia >::value_type const &""'"); 
  }
  arg2 = reinterpret_cast< std::vector< pj::VideoMedia >::value_type * >(argp2);
  (arg1)->push_back((std::vector< pj::VideoMedia >::value_type const &)*arg2);
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_VideoMediaVector_front(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  std::vector< pj::VideoMedia > *arg1 = (std::vector< pj::VideoMedia > *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  std::vector< pj::VideoMedia >::value_type *result = 0 ;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__vectorT_pj__VideoMedia_std__allocatorT_pj__VideoMedia_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "VideoMediaVector_front" "', argument " "1"" of type '" "std::vector< pj::VideoMedia > const *""'"); 
  }
  arg1 = reinterpret_cast< std::vector< pj::VideoMedia > * >(argp1);
  result = (std::vector< pj::VideoMedia >::value_type *) &((std::vector< pj::VideoMedia > const *)arg1)->front();
  resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(result), SWIGTYPE_p_pj__VideoMedia, 0 |  0 );
  (void)swig::container_owner<swig::traits<std::vector< pj::VideoMedia >::value_type>::category>::back_reference(resultobj, swig_obj[0]);
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_VideoMediaVector_back(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  std::vector< pj::VideoMedia > *arg1 = (std::vector< pj::VideoMedia > *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  std::vector< pj::VideoMedia >::value_type *result = 0 ;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__vectorT_pj__VideoMedia_std__allocatorT_pj__VideoMedia_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "VideoMediaVector_back" "', argument " "1"" of type '" "std::vector< pj::VideoMedia > const *""'"); 
  }
  arg1 = reinterpret_cast< std::vector< pj::VideoMedia > * >(argp1);
  result = (std::vector< pj::VideoMedia >::value_type *) &((std::vector< pj::VideoMedia > const *)arg1)->back();
  resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(result), SWIGTYPE_p_pj__VideoMedia, 0 |  0 );
  (void)swig::container_owner<swig::traits<std::vector< pj::VideoMedia >::value_type>::category>::back_reference(resultobj, swig_obj[0]);
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_VideoMediaVector_assign(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  std::vector< pj::VideoMedia > *arg1 = (std::vector< pj::VideoMedia > *) 0 ;
  std::vector< pj::VideoMedia >::size_type arg2 ;
  std::vector< pj::VideoMedia >::value_type *arg3 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  size_t val2 ;
  int ecode2 = 0 ;
  void *argp3 = 0 ;
  int res3 = 0 ;
  PyObject *swig_obj[3] ;
  
  if (!SWIG_Python_UnpackTuple(args, "VideoMediaVector_assign", 3, 3, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__vectorT_pj__VideoMedia_std__allocatorT_pj__VideoMedia_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "VideoMediaVector_assign" "', argument " "1"" of type '" "std::vector< pj::VideoMedia > *""'"); 
  }
  arg1 = reinterpret_cast< std::vector< pj::VideoMedia > * >(argp1);
  ecode2 = SWIG_AsVal_size_t(swig_obj[1], &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "VideoMediaVector_assign" "', argument " "2"" of type '" "std::vector< pj::VideoMedia >::size_type""'");
  } 
  arg2 = static_cast< std::vector< pj::VideoMedia >::size_type >(val2);
  res3 = SWIG_ConvertPtr(swig_obj[2], &argp3, SWIGTYPE_p_pj__VideoMedia,  0  | 0);
  if (!SWIG_IsOK(res3)) {
    SWIG_exception_fail(SWIG_ArgError(res3), "in method '" "VideoMediaVector_assign" "', argument " "3"" of type '" "std::vector< pj::VideoMedia >::value_type const &""'"); 
  }
  if (!argp3) {
    SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "VideoMediaVector_assign" "', argument " "3"" of type '" "std::vector< pj::VideoMedia >::value_type const &""'"); 
  }
  arg3 = reinterpret_cast< std::vector< pj::VideoMedia >::value_type * >(argp3);
  (arg1)->assign(arg2,(std::vector< pj::VideoMedia >::value_type const &)*arg3);
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_VideoMediaVector_resize__SWIG_1(PyObject *SWIGUNUSEDPARM(self), Py_ssize_t nobjs, PyObject **swig_obj) {
  PyObject *resultobj = 0;
  std::vector< pj::VideoMedia > *arg1 = (std::vector< pj::VideoMedia > *) 0 ;
  std::vector< pj::VideoMedia >::size_type arg2 ;
  std::vector< pj::VideoMedia >::value_type *arg3 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  size_t val2 ;
  int ecode2 = 0 ;
  void *argp3 = 0 ;
  int res3 = 0 ;
  
  if ((nobjs < 3) || (nobjs > 3)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__vectorT_pj__VideoMedia_std__allocatorT_pj__VideoMedia_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "VideoMediaVector_resize" "', argument " "1"" of type '" "std::vector< pj::VideoMedia > *""'"); 
  }
  arg1 = reinterpret_cast< std::vector< pj::VideoMedia > * >(argp1);
  ecode2 = SWIG_AsVal_size_t(swig_obj[1], &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "VideoMediaVector_resize" "', argument " "2"" of type '" "std::vector< pj::VideoMedia >::size_type""'");
  } 
  arg2 = static_cast< std::vector< pj::VideoMedia >::size_type >(val2);
  res3 = SWIG_ConvertPtr(swig_obj[2], &argp3, SWIGTYPE_p_pj__VideoMedia,  0  | 0);
  if (!SWIG_IsOK(res3)) {
    SWIG_exception_fail(SWIG_ArgError(res3), "in method '" "VideoMediaVector_resize" "', argument " "3"" of type '" "std::vector< pj::VideoMedia >::value_type const &""'"); 
  }
  if (!argp3) {
    SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "VideoMediaVector_resize" "', argument " "3"" of type '" "std::vector< pj::VideoMedia >::value_type const &""'"); 
  }
  arg3 = reinterpret_cast< std::vector< pj::VideoMedia >::value_type * >(argp3);
  (arg1)->resize(arg2,(std::vector< pj::VideoMedia >::value_type const &)*arg3);
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_VideoMediaVector_resize(PyObject *self, PyObject *args) {
  Py_ssize_t argc;
  PyObject *argv[4] = {
    0
  };
  
  if (!(argc = SWIG_Python_UnpackTuple(args, "VideoMediaVector_resize", 0, 3, argv))) SWIG_fail;
  --argc;
  if (argc == 2) {
    int _v;
    int res = swig::asptr(argv[0], (std::vector< pj::VideoMedia,std::allocator< pj::VideoMedia > >**)(0));
    _v = SWIG_CheckState(res);
    if (_v) {
      {
        int res = SWIG_AsVal_size_t(argv[1], NULL);
        _v = SWIG_CheckState(res);
      }
      if (_v) {
        return _wrap_VideoMediaVector_resize__SWIG_0(self, argc, argv);
      }
    }
  }
  if (argc == 3) {
    int _v;
    int res = swig::asptr(argv[0], (std::vector< pj::VideoMedia,std::allocator< pj::VideoMedia > >**)(0));
    _v = SWIG_CheckState(res);
    if (_v) {
      {
        int res = SWIG_AsVal_size_t(argv[1], NULL);
        _v = SWIG_CheckState(res);
      }
      if (_v) {
        int res = SWIG_ConvertPtr(argv[2], 0, SWIGTYPE_p_pj__VideoMedia, SWIG_POINTER_NO_NULL | 0);
        _v = SWIG_CheckState(res);
        if (_v) {
          return _wrap_VideoMediaVector_resize__SWIG_1(self, argc, argv);
        }
      }
    }
  }
  
fail:
  SWIG_Python_RaiseOrModifyTypeError("Wrong number or type of arguments for overloaded function 'VideoMediaVector_resize'.\n"
    "  Possible C/C++ prototypes are:\n"
    "    std::vector< pj::VideoMedia >::resize(std::vector< pj::VideoMedia >::size_type)\n"
    "    std::vector< pj::VideoMedia >::resize(std::vector< pj::VideoMedia >::size_type,std::vector< pj::VideoMedia >::value_type const &)\n");
  return 0;
}


SWIGINTERN PyObject *_wrap_VideoMediaVector_insert__SWIG_0(PyObject *SWIGUNUSEDPARM(self), Py_ssize_t nobjs, PyObject **swig_obj) {
  PyObject *resultobj = 0;
  std::vector< pj::VideoMedia > *arg1 = (std::vector< pj::VideoMedia > *) 0 ;
  std::vector< pj::VideoMedia >::iterator arg2 ;
  std::vector< pj::VideoMedia >::value_type *arg3 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  swig::SwigPyIterator *iter2 = 0 ;
  int res2 ;
  void *argp3 = 0 ;
  int res3 = 0 ;
  std::vector< pj::VideoMedia >::iterator result;
  
  if ((nobjs < 3) || (nobjs > 3)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__vectorT_pj__VideoMedia_std__allocatorT_pj__VideoMedia_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "VideoMediaVector_insert" "', argument " "1"" of type '" "std::vector< pj::VideoMedia > *""'"); 
  }
  arg1 = reinterpret_cast< std::vector< pj::VideoMedia > * >(argp1);
  res2 = SWIG_ConvertPtr(swig_obj[1], SWIG_as_voidptrptr(&iter2), swig::SwigPyIterator::descriptor(), 0);
  if (!SWIG_IsOK(res2) || !iter2) {
    SWIG_exception_fail(SWIG_ArgError(SWIG_TypeError), "in method '" "VideoMediaVector_insert" "', argument " "2"" of type '" "std::vector< pj::VideoMedia >::iterator""'");
  } else {
    swig::SwigPyIterator_T<std::vector< pj::VideoMedia >::iterator > *iter_t = dynamic_cast<swig::SwigPyIterator_T<std::vector< pj::VideoMedia >::iterator > *>(iter2);
    if (iter_t) {
      arg2 = iter_t->get_current();
    } else {
      SWIG_exception_fail(SWIG_ArgError(SWIG_TypeError), "in method '" "VideoMediaVector_insert" "', argument " "2"" of type '" "std::vector< pj::VideoMedia >::iterator""'");
    }
  }
  res3 = SWIG_ConvertPtr(swig_obj[2], &argp3, SWIGTYPE_p_pj__VideoMedia,  0  | 0);
  if (!SWIG_IsOK(res3)) {
    SWIG_exception_fail(SWIG_ArgError(res3), "in method '" "VideoMediaVector_insert" "', argument " "3"" of type '" "std::vector< pj::VideoMedia >::value_type const &""'"); 
  }
  if (!argp3) {
    SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "VideoMediaVector_insert" "', argument " "3"" of type '" "std::vector< pj::VideoMedia >::value_type const &""'"); 
  }
  arg3 = reinterpret_cast< std::vector< pj::VideoMedia >::value_type * >(argp3);
  result = std_vector_Sl_pj_VideoMedia_Sg__insert__SWIG_0(arg1,arg2,(pj::VideoMedia const &)*arg3);
  resultobj = SWIG_NewPointerObj(swig::make_output_iterator(static_cast< const std::vector< pj::VideoMedia >::iterator & >(result)),
    swig::SwigPyIterator::descriptor(),SWIG_POINTER_OWN);
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_VideoMediaVector_insert__SWIG_1(PyObject *SWIGUNUSEDPARM(self), Py_ssize_t nobjs, PyObject **swig_obj) {
  PyObject *resultobj = 0;
  std::vector< pj::VideoMedia > *arg1 = (std::vector< pj::VideoMedia > *) 0 ;
  std::vector< pj::VideoMedia >::iterator arg2 ;
  std::vector< pj::VideoMedia >::size_type arg3 ;
  std::vector< pj::VideoMedia >::value_type *arg4 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  swig::SwigPyIterator *iter2 = 0 ;
  int res2 ;
  size_t val3 ;
  int ecode3 = 0 ;
  void *argp4 = 0 ;
  int res4 = 0 ;
  
  if ((nobjs < 4) || (nobjs > 4)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__vectorT_pj__VideoMedia_std__allocatorT_pj__VideoMedia_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "VideoMediaVector_insert" "', argument " "1"" of type '" "std::vector< pj::VideoMedia > *""'"); 
  }
  arg1 = reinterpret_cast< std::vector< pj::VideoMedia > * >(argp1);
  res2 = SWIG_ConvertPtr(swig_obj[1], SWIG_as_voidptrptr(&iter2), swig::SwigPyIterator::descriptor(), 0);
  if (!SWIG_IsOK(res2) || !iter2) {
    SWIG_exception_fail(SWIG_ArgError(SWIG_TypeError), "in method '" "VideoMediaVector_insert" "', argument " "2"" of type '" "std::vector< pj::VideoMedia >::iterator""'");
  } else {
    swig::SwigPyIterator_T<std::vector< pj::VideoMedia >::iterator > *iter_t = dynamic_cast<swig::SwigPyIterator_T<std::vector< pj::VideoMedia >::iterator > *>(iter2);
    if (iter_t) {
      arg2 = iter_t->get_current();
    } else {
      SWIG_exception_fail(SWIG_ArgError(SWIG_TypeError), "in method '" "VideoMediaVector_insert" "', argument " "2"" of type '" "std::vector< pj::VideoMedia >::iterator""'");
    }
  }
  ecode3 = SWIG_AsVal_size_t(swig_obj[2], &val3);
  if (!SWIG_IsOK(ecode3)) {
    SWIG_exception_fail(SWIG_ArgError(ecode3), "in method '" "VideoMediaVector_insert" "', argument " "3"" of type '" "std::vector< pj::VideoMedia >::size_type""'");
  } 
  arg3 = static_cast< std::vector< pj::VideoMedia >::size_type >(val3);
  res4 = SWIG_ConvertPtr(swig_obj[3], &argp4, SWIGTYPE_p_pj__VideoMedia,  0  | 0);
  if (!SWIG_IsOK(res4)) {
    SWIG_exception_fail(SWIG_ArgError(res4), "in method '" "VideoMediaVector_insert" "', argument " "4"" of type '" "std::vector< pj::VideoMedia >::value_type const &""'"); 
  }
  if (!argp4) {
    SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "VideoMediaVector_insert" "', argument " "4"" of type '" "std::vector< pj::VideoMedia >::value_type const &""'"); 
  }
  arg4 = reinterpret_cast< std::vector< pj::VideoMedia >::value_type * >(argp4);
  std_vector_Sl_pj_VideoMedia_Sg__insert__SWIG_1(arg1,arg2,arg3,(pj::VideoMedia const &)*arg4);
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_VideoMediaVector_insert(PyObject *self, PyObject *args) {
  Py_ssize_t argc;
  PyObject *argv[5] = {
    0
  };
  
  if (!(argc = SWIG_Python_UnpackTuple(args, "VideoMediaVector_insert", 0, 4, argv))) SWIG_fail;
  --argc;
  if (argc == 3) {
    int _v;
    int res = swig::asptr(argv[0], (std::vector< pj::VideoMedia,std::allocator< pj::VideoMedia > >**)(0));
    _v = SWIG_CheckState(res);
    if (_v) {
      swig::SwigPyIterator *iter = 0;
      int res = SWIG_ConvertPtr(argv[1], SWIG_as_voidptrptr(&iter), swig::SwigPyIterator::descriptor(), 0);
      _v = (SWIG_IsOK(res) && iter && (dynamic_cast<swig::SwigPyIterator_T<std::vector< pj::VideoMedia >::iterator > *>(iter) != 0));
      if (_v) {
        int res = SWIG_ConvertPtr(argv[2], 0, SWIGTYPE_p_pj__VideoMedia, SWIG_POINTER_NO_NULL | 0);
        _v = SWIG_CheckState(res);
        if (_v) {
          return _wrap_VideoMediaVector_insert__SWIG_0(self, argc, argv);
        }
      }
    }
  }
  if (argc == 4) {
    int _v;
    int res = swig::asptr(argv[0], (std::vector< pj::VideoMedia,std::allocator< pj::VideoMedia > >**)(0));
    _v = SWIG_CheckState(res);
    if (_v) {
      swig::SwigPyIterator *iter = 0;
      int res = SWIG_ConvertPtr(argv[1], SWIG_as_voidptrptr(&iter), swig::SwigPyIterator::descriptor(), 0);
      _v = (SWIG_IsOK(res) && iter && (dynamic_cast<swig::SwigPyIterator_T<std::vector< pj::VideoMedia >::iterator > *>(iter) != 0));
      if (_v) {
        {
          int res = SWIG_AsVal_size_t(argv[2], NULL);
          _v = SWIG_CheckState(res);
        }
        if (_v) {
          int res = SWIG_ConvertPtr(argv[3], 0, SWIGTYPE_p_pj__VideoMedia, SWIG_POINTER_NO_NULL | 0);
          _v = SWIG_CheckState(res);
          if (_v) {
            return _wrap_VideoMediaVector_insert__SWIG_1(self, argc, argv);
          }
        }
      }
    }
  }
  
fail:
  SWIG_Python_RaiseOrModifyTypeError("Wrong number or type of arguments for overloaded function 'VideoMediaVector_insert'.\n"
    "  Possible C/C++ prototypes are:\n"
    "    std::vector< pj::VideoMedia >::insert(std::vector< pj::VideoMedia >::iterator,std::vector< pj::VideoMedia >::value_type const &)\n"
    "    std::vector< pj::VideoMedia >::insert(std::vector< pj::VideoMedia >::iterator,std::vector< pj::VideoMedia >::size_type,std::vector< pj::VideoMedia >::value_type const &)\n");
  return 0;
}


SWIGINTERN PyObject *_wrap_VideoMediaVector_reserve(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  std::vector< pj::VideoMedia > *arg1 = (std::vector< pj::VideoMedia > *) 0 ;
  std::vector< pj::VideoMedia >::size_type arg2 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  size_t val2 ;
  int ecode2 = 0 ;
  PyObject *swig_obj[2] ;
  
  if (!SWIG_Python_UnpackTuple(args, "VideoMediaVector_reserve", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__vectorT_pj__VideoMedia_std__allocatorT_pj__VideoMedia_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "VideoMediaVector_reserve" "', argument " "1"" of type '" "std::vector< pj::VideoMedia > *""'"); 
  }
  arg1 = reinterpret_cast< std::vector< pj::VideoMedia > * >(argp1);
  ecode2 = SWIG_AsVal_size_t(swig_obj[1], &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "VideoMediaVector_reserve" "', argument " "2"" of type '" "std::vector< pj::VideoMedia >::size_type""'");
  } 
  arg2 = static_cast< std::vector< pj::VideoMedia >::size_type >(val2);
  (arg1)->reserve(arg2);
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_VideoMediaVector_capacity(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  std::vector< pj::VideoMedia > *arg1 = (std::vector< pj::VideoMedia > *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  std::vector< pj::VideoMedia >::size_type result;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__vectorT_pj__VideoMedia_std__allocatorT_pj__VideoMedia_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "VideoMediaVector_capacity" "', argument " "1"" of type '" "std::vector< pj::VideoMedia > const *""'"); 
  }
  arg1 = reinterpret_cast< std::vector< pj::VideoMedia > * >(argp1);
  result = ((std::vector< pj::VideoMedia > const *)arg1)->capacity();
  resultobj = SWIG_From_size_t(static_cast< size_t >(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_delete_VideoMediaVector(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  std::vector< pj::VideoMedia > *arg1 = (std::vector< pj::VideoMedia > *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__vectorT_pj__VideoMedia_std__allocatorT_pj__VideoMedia_t_t, SWIG_POINTER_DISOWN |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "delete_VideoMediaVector" "', argument " "1"" of type '" "std::vector< pj::VideoMedia > *""'"); 
  }
  arg1 = reinterpret_cast< std::vector< pj::VideoMedia > * >(argp1);
  delete arg1;
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *VideoMediaVector_swigregister(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *obj;
  if (!SWIG_Python_UnpackTuple(args, "swigregister", 1, 1, &obj)) return NULL;
  SWIG_TypeNewClientData(SWIGTYPE_p_std__vectorT_pj__VideoMedia_std__allocatorT_pj__VideoMedia_t_t, SWIG_NewClientData(obj));
  return SWIG_Py_Void();
}

SWIGINTERN PyObject *VideoMediaVector_swiginit(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  return SWIG_Python_InitShadowInstance(args);
}

SWIGINTERN PyObject *_wrap_ToneDescVector_iterator(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  std::vector< pj::ToneDesc > *arg1 = (std::vector< pj::ToneDesc > *) 0 ;
  PyObject **arg2 = (PyObject **) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  swig::SwigPyIterator *result = 0 ;
  
  arg2 = &swig_obj[0];
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__vectorT_pj__ToneDesc_std__allocatorT_pj__ToneDesc_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "ToneDescVector_iterator" "', argument " "1"" of type '" "std::vector< pj::ToneDesc > *""'"); 
  }
  arg1 = reinterpret_cast< std::vector< pj::ToneDesc > * >(argp1);
  result = (swig::SwigPyIterator *)std_vector_Sl_pj_ToneDesc_Sg__iterator(arg1,arg2);
  resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(result), SWIGTYPE_p_swig__SwigPyIterator, SWIG_POINTER_OWN |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_ToneDescVector___nonzero__(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  std::vector< pj::ToneDesc > *arg1 = (std::vector< pj::ToneDesc > *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  bool result;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__vectorT_pj__ToneDesc_std__allocatorT_pj__ToneDesc_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "ToneDescVector___nonzero__" "', argument " "1"" of type '" "std::vector< pj::ToneDesc > const *""'"); 
  }
  arg1 = reinterpret_cast< std::vector< pj::ToneDesc > * >(argp1);
  result = (bool)std_vector_Sl_pj_ToneDesc_Sg____nonzero__((std::vector< pj::ToneDesc > const *)arg1);
  resultobj = SWIG_From_bool(static_cast< bool >(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_ToneDescVector___bool__(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  std::vector< pj::ToneDesc > *arg1 = (std::vector< pj::ToneDesc > *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  bool result;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__vectorT_pj__ToneDesc_std__allocatorT_pj__ToneDesc_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "ToneDescVector___bool__" "', argument " "1"" of type '" "std::vector< pj::ToneDesc > const *""'"); 
  }
  arg1 = reinterpret_cast< std::vector< pj::ToneDesc > * >(argp1);
  result = (bool)std_vector_Sl_pj_ToneDesc_Sg____bool__((std::vector< pj::ToneDesc > const *)arg1);
  resultobj = SWIG_From_bool(static_cast< bool >(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_ToneDescVector___len__(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  std::vector< pj::ToneDesc > *arg1 = (std::vector< pj::ToneDesc > *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  std::vector< pj::ToneDesc >::size_type result;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__vectorT_pj__ToneDesc_std__allocatorT_pj__ToneDesc_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "ToneDescVector___len__" "', argument " "1"" of type '" "std::vector< pj::ToneDesc > const *""'"); 
  }
  arg1 = reinterpret_cast< std::vector< pj::ToneDesc > * >(argp1);
  result = std_vector_Sl_pj_ToneDesc_Sg____len__((std::vector< pj::ToneDesc > const *)arg1);
  resultobj = SWIG_From_size_t(static_cast< size_t >(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_ToneDescVector___getslice__(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  std::vector< pj::ToneDesc > *arg1 = (std::vector< pj::ToneDesc > *) 0 ;
  std::vector< pj::ToneDesc >::difference_type arg2 ;
  std::vector< pj::ToneDesc >::difference_type arg3 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  ptrdiff_t val2 ;
  int ecode2 = 0 ;
  ptrdiff_t val3 ;
  int ecode3 = 0 ;
  PyObject *swig_obj[3] ;
  std::vector< pj::ToneDesc,std::allocator< pj::ToneDesc > > *result = 0 ;
  
  if (!SWIG_Python_UnpackTuple(args, "ToneDescVector___getslice__", 3, 3, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__vectorT_pj__ToneDesc_std__allocatorT_pj__ToneDesc_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "ToneDescVector___getslice__" "', argument " "1"" of type '" "std::vector< pj::ToneDesc > *""'"); 
  }
  arg1 = reinterpret_cast< std::vector< pj::ToneDesc > * >(argp1);
  ecode2 = SWIG_AsVal_ptrdiff_t(swig_obj[1], &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "ToneDescVector___getslice__" "', argument " "2"" of type '" "std::vector< pj::ToneDesc >::difference_type""'");
  } 
  arg2 = static_cast< std::vector< pj::ToneDesc >::difference_type >(val2);
  ecode3 = SWIG_AsVal_ptrdiff_t(swig_obj[2], &val3);
  if (!SWIG_IsOK(ecode3)) {
    SWIG_exception_fail(SWIG_ArgError(ecode3), "in method '" "ToneDescVector___getslice__" "', argument " "3"" of type '" "std::vector< pj::ToneDesc >::difference_type""'");
  } 
  arg3 = static_cast< std::vector< pj::ToneDesc >::difference_type >(val3);
  try {
    result = (std::vector< pj::ToneDesc,std::allocator< pj::ToneDesc > > *)std_vector_Sl_pj_ToneDesc_Sg____getslice__(arg1,arg2,arg3);
  } catch(std::out_of_range &_e) {
    SWIG_exception_fail(SWIG_IndexError, (&_e)->what());
  } catch(std::invalid_argument &_e) {
    SWIG_exception_fail(SWIG_ValueError, (&_e)->what());
  }
  resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(result), SWIGTYPE_p_std__vectorT_pj__ToneDesc_std__allocatorT_pj__ToneDesc_t_t, SWIG_POINTER_OWN |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_ToneDescVector___setslice____SWIG_0(PyObject *SWIGUNUSEDPARM(self), Py_ssize_t nobjs, PyObject **swig_obj) {
  PyObject *resultobj = 0;
  std::vector< pj::ToneDesc > *arg1 = (std::vector< pj::ToneDesc > *) 0 ;
  std::vector< pj::ToneDesc >::difference_type arg2 ;
  std::vector< pj::ToneDesc >::difference_type arg3 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  ptrdiff_t val2 ;
  int ecode2 = 0 ;
  ptrdiff_t val3 ;
  int ecode3 = 0 ;
  
  if ((nobjs < 3) || (nobjs > 3)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__vectorT_pj__ToneDesc_std__allocatorT_pj__ToneDesc_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "ToneDescVector___setslice__" "', argument " "1"" of type '" "std::vector< pj::ToneDesc > *""'"); 
  }
  arg1 = reinterpret_cast< std::vector< pj::ToneDesc > * >(argp1);
  ecode2 = SWIG_AsVal_ptrdiff_t(swig_obj[1], &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "ToneDescVector___setslice__" "', argument " "2"" of type '" "std::vector< pj::ToneDesc >::difference_type""'");
  } 
  arg2 = static_cast< std::vector< pj::ToneDesc >::difference_type >(val2);
  ecode3 = SWIG_AsVal_ptrdiff_t(swig_obj[2], &val3);
  if (!SWIG_IsOK(ecode3)) {
    SWIG_exception_fail(SWIG_ArgError(ecode3), "in method '" "ToneDescVector___setslice__" "', argument " "3"" of type '" "std::vector< pj::ToneDesc >::difference_type""'");
  } 
  arg3 = static_cast< std::vector< pj::ToneDesc >::difference_type >(val3);
  try {
    std_vector_Sl_pj_ToneDesc_Sg____setslice____SWIG_0(arg1,arg2,arg3);
  } catch(std::out_of_range &_e) {
    SWIG_exception_fail(SWIG_IndexError, (&_e)->what());
  } catch(std::invalid_argument &_e) {
    SWIG_exception_fail(SWIG_ValueError, (&_e)->what());
  }
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_ToneDescVector___setslice____SWIG_1(PyObject *SWIGUNUSEDPARM(self), Py_ssize_t nobjs, PyObject **swig_obj) {
  PyObject *resultobj = 0;
  std::vector< pj::ToneDesc > *arg1 = (std::vector< pj::ToneDesc > *) 0 ;
  std::vector< pj::ToneDesc >::difference_type arg2 ;
  std::vector< pj::ToneDesc >::difference_type arg3 ;
  std::vector< pj::ToneDesc,std::allocator< pj::ToneDesc > > *arg4 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  ptrdiff_t val2 ;
  int ecode2 = 0 ;
  ptrdiff_t val3 ;
  int ecode3 = 0 ;
  int res4 = SWIG_OLDOBJ ;
  
  if ((nobjs < 4) || (nobjs > 4)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__vectorT_pj__ToneDesc_std__allocatorT_pj__ToneDesc_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "ToneDescVector___setslice__" "', argument " "1"" of type '" "std::vector< pj::ToneDesc > *""'"); 
  }
  arg1 = reinterpret_cast< std::vector< pj::ToneDesc > * >(argp1);
  ecode2 = SWIG_AsVal_ptrdiff_t(swig_obj[1], &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "ToneDescVector___setslice__" "', argument " "2"" of type '" "std::vector< pj::ToneDesc >::difference_type""'");
  } 
  arg2 = static_cast< std::vector< pj::ToneDesc >::difference_type >(val2);
  ecode3 = SWIG_AsVal_ptrdiff_t(swig_obj[2], &val3);
  if (!SWIG_IsOK(ecode3)) {
    SWIG_exception_fail(SWIG_ArgError(ecode3), "in method '" "ToneDescVector___setslice__" "', argument " "3"" of type '" "std::vector< pj::ToneDesc >::difference_type""'");
  } 
  arg3 = static_cast< std::vector< pj::ToneDesc >::difference_type >(val3);
  {
    std::vector< pj::ToneDesc,std::allocator< pj::ToneDesc > > *ptr = (std::vector< pj::ToneDesc,std::allocator< pj::ToneDesc > > *)0;
    res4 = swig::asptr(swig_obj[3], &ptr);
    if (!SWIG_IsOK(res4)) {
      SWIG_exception_fail(SWIG_ArgError(res4), "in method '" "ToneDescVector___setslice__" "', argument " "4"" of type '" "std::vector< pj::ToneDesc,std::allocator< pj::ToneDesc > > const &""'"); 
    }
    if (!ptr) {
      SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "ToneDescVector___setslice__" "', argument " "4"" of type '" "std::vector< pj::ToneDesc,std::allocator< pj::ToneDesc > > const &""'"); 
    }
    arg4 = ptr;
  }
  try {
    std_vector_Sl_pj_ToneDesc_Sg____setslice____SWIG_1(arg1,arg2,arg3,(std::vector< pj::ToneDesc,std::allocator< pj::ToneDesc > > const &)*arg4);
  } catch(std::out_of_range &_e) {
    SWIG_exception_fail(SWIG_IndexError, (&_e)->what());
  } catch(std::invalid_argument &_e) {
    SWIG_exception_fail(SWIG_ValueError, (&_e)->what());
  }
  resultobj = SWIG_Py_Void();
  if (SWIG_IsNewObj(res4)) delete arg4;
  return resultobj;
fail:
  if (SWIG_IsNewObj(res4)) delete arg4;
  return NULL;
}


SWIGINTERN PyObject *_wrap_ToneDescVector___setslice__(PyObject *self, PyObject *args) {
  Py_ssize_t argc;
  PyObject *argv[5] = {
    0
  };
  
  if (!(argc = SWIG_Python_UnpackTuple(args, "ToneDescVector___setslice__", 0, 4, argv))) SWIG_fail;
  --argc;
  if (argc == 3) {
    int _v;
    int res = swig::asptr(argv[0], (std::vector< pj::ToneDesc,std::allocator< pj::ToneDesc > >**)(0));
    _v = SWIG_CheckState(res);
    if (_v) {
      {
        int res = SWIG_AsVal_ptrdiff_t(argv[1], NULL);
        _v = SWIG_CheckState(res);
      }
      if (_v) {
        {
          int res = SWIG_AsVal_ptrdiff_t(argv[2], NULL);
          _v = SWIG_CheckState(res);
        }
        if (_v) {
          return _wrap_ToneDescVector___setslice____SWIG_0(self, argc, argv);
        }
      }
    }
  }
  if (argc == 4) {
    int _v;
    int res = swig::asptr(argv[0], (std::vector< pj::ToneDesc,std::allocator< pj::ToneDesc > >**)(0));
    _v = SWIG_CheckState(res);
    if (_v) {
      {
        int res = SWIG_AsVal_ptrdiff_t(argv[1], NULL);
        _v = SWIG_CheckState(res);
      }
      if (_v) {
        {
          int res = SWIG_AsVal_ptrdiff_t(argv[2], NULL);
          _v = SWIG_CheckState(res);
        }
        if (_v) {
          int res = swig::asptr(argv[3], (std::vector< pj::ToneDesc,std::allocator< pj::ToneDesc > >**)(0));
          _v = SWIG_CheckState(res);
          if (_v) {
            return _wrap_ToneDescVector___setslice____SWIG_1(self, argc, argv);
          }
        }
      }
    }
  }
  
fail:
  SWIG_Python_RaiseOrModifyTypeError("Wrong number or type of arguments for overloaded function 'ToneDescVector___setslice__'.\n"
    "  Possible C/C++ prototypes are:\n"
    "    std::vector< pj::ToneDesc >::__setslice__(std::vector< pj::ToneDesc >::difference_type,std::vector< pj::ToneDesc >::difference_type)\n"
    "    std::vector< pj::ToneDesc >::__setslice__(std::vector< pj::ToneDesc >::difference_type,std::vector< pj::ToneDesc >::difference_type,std::vector< pj::ToneDesc,std::allocator< pj::ToneDesc > > const &)\n");
  return 0;
}


SWIGINTERN PyObject *_wrap_ToneDescVector___delslice__(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  std::vector< pj::ToneDesc > *arg1 = (std::vector< pj::ToneDesc > *) 0 ;
  std::vector< pj::ToneDesc >::difference_type arg2 ;
  std::vector< pj::ToneDesc >::difference_type arg3 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  ptrdiff_t val2 ;
  int ecode2 = 0 ;
  ptrdiff_t val3 ;
  int ecode3 = 0 ;
  PyObject *swig_obj[3] ;
  
  if (!SWIG_Python_UnpackTuple(args, "ToneDescVector___delslice__", 3, 3, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__vectorT_pj__ToneDesc_std__allocatorT_pj__ToneDesc_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "ToneDescVector___delslice__" "', argument " "1"" of type '" "std::vector< pj::ToneDesc > *""'"); 
  }
  arg1 = reinterpret_cast< std::vector< pj::ToneDesc > * >(argp1);
  ecode2 = SWIG_AsVal_ptrdiff_t(swig_obj[1], &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "ToneDescVector___delslice__" "', argument " "2"" of type '" "std::vector< pj::ToneDesc >::difference_type""'");
  } 
  arg2 = static_cast< std::vector< pj::ToneDesc >::difference_type >(val2);
  ecode3 = SWIG_AsVal_ptrdiff_t(swig_obj[2], &val3);
  if (!SWIG_IsOK(ecode3)) {
    SWIG_exception_fail(SWIG_ArgError(ecode3), "in method '" "ToneDescVector___delslice__" "', argument " "3"" of type '" "std::vector< pj::ToneDesc >::difference_type""'");
  } 
  arg3 = static_cast< std::vector< pj::ToneDesc >::difference_type >(val3);
  try {
    std_vector_Sl_pj_ToneDesc_Sg____delslice__(arg1,arg2,arg3);
  } catch(std::out_of_range &_e) {
    SWIG_exception_fail(SWIG_IndexError, (&_e)->what());
  } catch(std::invalid_argument &_e) {
    SWIG_exception_fail(SWIG_ValueError, (&_e)->what());
  }
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_ToneDescVector___delitem____SWIG_0(PyObject *SWIGUNUSEDPARM(self), Py_ssize_t nobjs, PyObject **swig_obj) {
  PyObject *resultobj = 0;
  std::vector< pj::ToneDesc > *arg1 = (std::vector< pj::ToneDesc > *) 0 ;
  std::vector< pj::ToneDesc >::difference_type arg2 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  ptrdiff_t val2 ;
  int ecode2 = 0 ;
  
  if ((nobjs < 2) || (nobjs > 2)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__vectorT_pj__ToneDesc_std__allocatorT_pj__ToneDesc_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "ToneDescVector___delitem__" "', argument " "1"" of type '" "std::vector< pj::ToneDesc > *""'"); 
  }
  arg1 = reinterpret_cast< std::vector< pj::ToneDesc > * >(argp1);
  ecode2 = SWIG_AsVal_ptrdiff_t(swig_obj[1], &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "ToneDescVector___delitem__" "', argument " "2"" of type '" "std::vector< pj::ToneDesc >::difference_type""'");
  } 
  arg2 = static_cast< std::vector< pj::ToneDesc >::difference_type >(val2);
  try {
    std_vector_Sl_pj_ToneDesc_Sg____delitem____SWIG_0(arg1,arg2);
  } catch(std::out_of_range &_e) {
    SWIG_exception_fail(SWIG_IndexError, (&_e)->what());
  } catch(std::invalid_argument &_e) {
    SWIG_exception_fail(SWIG_ValueError, (&_e)->what());
  }
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_ToneDescVector___getitem____SWIG_0(PyObject *SWIGUNUSEDPARM(self), Py_ssize_t nobjs, PyObject **swig_obj) {
  PyObject *resultobj = 0;
  std::vector< pj::ToneDesc > *arg1 = (std::vector< pj::ToneDesc > *) 0 ;
  PySliceObject *arg2 = (PySliceObject *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  std::vector< pj::ToneDesc,std::allocator< pj::ToneDesc > > *result = 0 ;
  
  if ((nobjs < 2) || (nobjs > 2)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__vectorT_pj__ToneDesc_std__allocatorT_pj__ToneDesc_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "ToneDescVector___getitem__" "', argument " "1"" of type '" "std::vector< pj::ToneDesc > *""'"); 
  }
  arg1 = reinterpret_cast< std::vector< pj::ToneDesc > * >(argp1);
  {
    if (!PySlice_Check(swig_obj[1])) {
      SWIG_exception_fail(SWIG_ArgError(SWIG_TypeError), "in method '" "ToneDescVector___getitem__" "', argument " "2"" of type '" "PySliceObject *""'");
    }
    arg2 = (PySliceObject *) swig_obj[1];
  }
  try {
    result = (std::vector< pj::ToneDesc,std::allocator< pj::ToneDesc > > *)std_vector_Sl_pj_ToneDesc_Sg____getitem____SWIG_0(arg1,arg2);
  } catch(std::out_of_range &_e) {
    SWIG_exception_fail(SWIG_IndexError, (&_e)->what());
  } catch(std::invalid_argument &_e) {
    SWIG_exception_fail(SWIG_ValueError, (&_e)->what());
  }
  resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(result), SWIGTYPE_p_std__vectorT_pj__ToneDesc_std__allocatorT_pj__ToneDesc_t_t, SWIG_POINTER_OWN |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_ToneDescVector___setitem____SWIG_0(PyObject *SWIGUNUSEDPARM(self), Py_ssize_t nobjs, PyObject **swig_obj) {
  PyObject *resultobj = 0;
  std::vector< pj::ToneDesc > *arg1 = (std::vector< pj::ToneDesc > *) 0 ;
  PySliceObject *arg2 = (PySliceObject *) 0 ;
  std::vector< pj::ToneDesc,std::allocator< pj::ToneDesc > > *arg3 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  int res3 = SWIG_OLDOBJ ;
  
  if ((nobjs < 3) || (nobjs > 3)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__vectorT_pj__ToneDesc_std__allocatorT_pj__ToneDesc_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "ToneDescVector___setitem__" "', argument " "1"" of type '" "std::vector< pj::ToneDesc > *""'"); 
  }
  arg1 = reinterpret_cast< std::vector< pj::ToneDesc > * >(argp1);
  {
    if (!PySlice_Check(swig_obj[1])) {
      SWIG_exception_fail(SWIG_ArgError(SWIG_TypeError), "in method '" "ToneDescVector___setitem__" "', argument " "2"" of type '" "PySliceObject *""'");
    }
    arg2 = (PySliceObject *) swig_obj[1];
  }
  {
    std::vector< pj::ToneDesc,std::allocator< pj::ToneDesc > > *ptr = (std::vector< pj::ToneDesc,std::allocator< pj::ToneDesc > > *)0;
    res3 = swig::asptr(swig_obj[2], &ptr);
    if (!SWIG_IsOK(res3)) {
      SWIG_exception_fail(SWIG_ArgError(res3), "in method '" "ToneDescVector___setitem__" "', argument " "3"" of type '" "std::vector< pj::ToneDesc,std::allocator< pj::ToneDesc > > const &""'"); 
    }
    if (!ptr) {
      SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "ToneDescVector___setitem__" "', argument " "3"" of type '" "std::vector< pj::ToneDesc,std::allocator< pj::ToneDesc > > const &""'"); 
    }
    arg3 = ptr;
  }
  try {
    std_vector_Sl_pj_ToneDesc_Sg____setitem____SWIG_0(arg1,arg2,(std::vector< pj::ToneDesc,std::allocator< pj::ToneDesc > > const &)*arg3);
  } catch(std::out_of_range &_e) {
    SWIG_exception_fail(SWIG_IndexError, (&_e)->what());
  } catch(std::invalid_argument &_e) {
    SWIG_exception_fail(SWIG_ValueError, (&_e)->what());
  }
  resultobj = SWIG_Py_Void();
  if (SWIG_IsNewObj(res3)) delete arg3;
  return resultobj;
fail:
  if (SWIG_IsNewObj(res3)) delete arg3;
  return NULL;
}


SWIGINTERN PyObject *_wrap_ToneDescVector___setitem____SWIG_1(PyObject *SWIGUNUSEDPARM(self), Py_ssize_t nobjs, PyObject **swig_obj) {
  PyObject *resultobj = 0;
  std::vector< pj::ToneDesc > *arg1 = (std::vector< pj::ToneDesc > *) 0 ;
  PySliceObject *arg2 = (PySliceObject *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  
  if ((nobjs < 2) || (nobjs > 2)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__vectorT_pj__ToneDesc_std__allocatorT_pj__ToneDesc_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "ToneDescVector___setitem__" "', argument " "1"" of type '" "std::vector< pj::ToneDesc > *""'"); 
  }
  arg1 = reinterpret_cast< std::vector< pj::ToneDesc > * >(argp1);
  {
    if (!PySlice_Check(swig_obj[1])) {
      SWIG_exception_fail(SWIG_ArgError(SWIG_TypeError), "in method '" "ToneDescVector___setitem__" "', argument " "2"" of type '" "PySliceObject *""'");
    }
    arg2 = (PySliceObject *) swig_obj[1];
  }
  try {
    std_vector_Sl_pj_ToneDesc_Sg____setitem____SWIG_1(arg1,arg2);
  } catch(std::out_of_range &_e) {
    SWIG_exception_fail(SWIG_IndexError, (&_e)->what());
  } catch(std::invalid_argument &_e) {
    SWIG_exception_fail(SWIG_ValueError, (&_e)->what());
  }
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_ToneDescVector___delitem____SWIG_1(PyObject *SWIGUNUSEDPARM(self), Py_ssize_t nobjs, PyObject **swig_obj) {
  PyObject *resultobj = 0;
  std::vector< pj::ToneDesc > *arg1 = (std::vector< pj::ToneDesc > *) 0 ;
  PySliceObject *arg2 = (PySliceObject *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  
  if ((nobjs < 2) || (nobjs > 2)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__vectorT_pj__ToneDesc_std__allocatorT_pj__ToneDesc_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "ToneDescVector___delitem__" "', argument " "1"" of type '" "std::vector< pj::ToneDesc > *""'"); 
  }
  arg1 = reinterpret_cast< std::vector< pj::ToneDesc > * >(argp1);
  {
    if (!PySlice_Check(swig_obj[1])) {
      SWIG_exception_fail(SWIG_ArgError(SWIG_TypeError), "in method '" "ToneDescVector___delitem__" "', argument " "2"" of type '" "PySliceObject *""'");
    }
    arg2 = (PySliceObject *) swig_obj[1];
  }
  try {
    std_vector_Sl_pj_ToneDesc_Sg____delitem____SWIG_1(arg1,arg2);
  } catch(std::out_of_range &_e) {
    SWIG_exception_fail(SWIG_IndexError, (&_e)->what());
  } catch(std::invalid_argument &_e) {
    SWIG_exception_fail(SWIG_ValueError, (&_e)->what());
  }
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_ToneDescVector___delitem__(PyObject *self, PyObject *args) {
  Py_ssize_t argc;
  PyObject *argv[3] = {
    0
  };
  
  if (!(argc = SWIG_Python_UnpackTuple(args, "ToneDescVector___delitem__", 0, 2, argv))) SWIG_fail;
  --argc;
  if (argc == 2) {
    int _v;
    int res = swig::asptr(argv[0], (std::vector< pj::ToneDesc,std::allocator< pj::ToneDesc > >**)(0));
    _v = SWIG_CheckState(res);
    if (_v) {
      {
        _v = PySlice_Check(argv[1]);
      }
      if (_v) {
        return _wrap_ToneDescVector___delitem____SWIG_1(self, argc, argv);
      }
    }
  }
  if (argc == 2) {
    int _v;
    int res = swig::asptr(argv[0], (std::vector< pj::ToneDesc,std::allocator< pj::ToneDesc > >**)(0));
    _v = SWIG_CheckState(res);
    if (_v) {
      {
        int res = SWIG_AsVal_ptrdiff_t(argv[1], NULL);
        _v = SWIG_CheckState(res);
      }
      if (_v) {
        return _wrap_ToneDescVector___delitem____SWIG_0(self, argc, argv);
      }
    }
  }
  
fail:
  SWIG_Python_RaiseOrModifyTypeError("Wrong number or type of arguments for overloaded function 'ToneDescVector___delitem__'.\n"
    "  Possible C/C++ prototypes are:\n"
    "    std::vector< pj::ToneDesc >::__delitem__(std::vector< pj::ToneDesc >::difference_type)\n"
    "    std::vector< pj::ToneDesc >::__delitem__(PySliceObject *)\n");
  return 0;
}


SWIGINTERN PyObject *_wrap_ToneDescVector___getitem____SWIG_1(PyObject *SWIGUNUSEDPARM(self), Py_ssize_t nobjs, PyObject **swig_obj) {
  PyObject *resultobj = 0;
  std::vector< pj::ToneDesc > *arg1 = (std::vector< pj::ToneDesc > *) 0 ;
  std::vector< pj::ToneDesc >::difference_type arg2 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  ptrdiff_t val2 ;
  int ecode2 = 0 ;
  std::vector< pj::ToneDesc >::value_type *result = 0 ;
  
  if ((nobjs < 2) || (nobjs > 2)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__vectorT_pj__ToneDesc_std__allocatorT_pj__ToneDesc_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "ToneDescVector___getitem__" "', argument " "1"" of type '" "std::vector< pj::ToneDesc > const *""'"); 
  }
  arg1 = reinterpret_cast< std::vector< pj::ToneDesc > * >(argp1);
  ecode2 = SWIG_AsVal_ptrdiff_t(swig_obj[1], &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "ToneDescVector___getitem__" "', argument " "2"" of type '" "std::vector< pj::ToneDesc >::difference_type""'");
  } 
  arg2 = static_cast< std::vector< pj::ToneDesc >::difference_type >(val2);
  try {
    result = (std::vector< pj::ToneDesc >::value_type *) &std_vector_Sl_pj_ToneDesc_Sg____getitem____SWIG_1((std::vector< pj::ToneDesc > const *)arg1,arg2);
  } catch(std::out_of_range &_e) {
    SWIG_exception_fail(SWIG_IndexError, (&_e)->what());
  }
  resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(result), SWIGTYPE_p_pj__ToneDesc, 0 |  0 );
  (void)swig::container_owner<swig::traits<std::vector< pj::ToneDesc >::value_type>::category>::back_reference(resultobj, swig_obj[0]);
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_ToneDescVector___getitem__(PyObject *self, PyObject *args) {
  Py_ssize_t argc;
  PyObject *argv[3] = {
    0
  };
  
  if (!(argc = SWIG_Python_UnpackTuple(args, "ToneDescVector___getitem__", 0, 2, argv))) SWIG_fail;
  --argc;
  if (argc == 2) {
    int _v;
    int res = swig::asptr(argv[0], (std::vector< pj::ToneDesc,std::allocator< pj::ToneDesc > >**)(0));
    _v = SWIG_CheckState(res);
    if (_v) {
      {
        _v = PySlice_Check(argv[1]);
      }
      if (_v) {
        return _wrap_ToneDescVector___getitem____SWIG_0(self, argc, argv);
      }
    }
  }
  if (argc == 2) {
    int _v;
    int res = swig::asptr(argv[0], (std::vector< pj::ToneDesc,std::allocator< pj::ToneDesc > >**)(0));
    _v = SWIG_CheckState(res);
    if (_v) {
      {
        int res = SWIG_AsVal_ptrdiff_t(argv[1], NULL);
        _v = SWIG_CheckState(res);
      }
      if (_v) {
        return _wrap_ToneDescVector___getitem____SWIG_1(self, argc, argv);
      }
    }
  }
  
fail:
  SWIG_Python_RaiseOrModifyTypeError("Wrong number or type of arguments for overloaded function 'ToneDescVector___getitem__'.\n"
    "  Possible C/C++ prototypes are:\n"
    "    std::vector< pj::ToneDesc >::__getitem__(PySliceObject *)\n"
    "    std::vector< pj::ToneDesc >::__getitem__(std::vector< pj::ToneDesc >::difference_type) const\n");
  return 0;
}


SWIGINTERN PyObject *_wrap_ToneDescVector___setitem____SWIG_2(PyObject *SWIGUNUSEDPARM(self), Py_ssize_t nobjs, PyObject **swig_obj) {
  PyObject *resultobj = 0;
  std::vector< pj::ToneDesc > *arg1 = (std::vector< pj::ToneDesc > *) 0 ;
  std::vector< pj::ToneDesc >::difference_type arg2 ;
  std::vector< pj::ToneDesc >::value_type *arg3 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  ptrdiff_t val2 ;
  int ecode2 = 0 ;
  void *argp3 = 0 ;
  int res3 = 0 ;
  
  if ((nobjs < 3) || (nobjs > 3)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__vectorT_pj__ToneDesc_std__allocatorT_pj__ToneDesc_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "ToneDescVector___setitem__" "', argument " "1"" of type '" "std::vector< pj::ToneDesc > *""'"); 
  }
  arg1 = reinterpret_cast< std::vector< pj::ToneDesc > * >(argp1);
  ecode2 = SWIG_AsVal_ptrdiff_t(swig_obj[1], &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "ToneDescVector___setitem__" "', argument " "2"" of type '" "std::vector< pj::ToneDesc >::difference_type""'");
  } 
  arg2 = static_cast< std::vector< pj::ToneDesc >::difference_type >(val2);
  res3 = SWIG_ConvertPtr(swig_obj[2], &argp3, SWIGTYPE_p_pj__ToneDesc,  0  | 0);
  if (!SWIG_IsOK(res3)) {
    SWIG_exception_fail(SWIG_ArgError(res3), "in method '" "ToneDescVector___setitem__" "', argument " "3"" of type '" "std::vector< pj::ToneDesc >::value_type const &""'"); 
  }
  if (!argp3) {
    SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "ToneDescVector___setitem__" "', argument " "3"" of type '" "std::vector< pj::ToneDesc >::value_type const &""'"); 
  }
  arg3 = reinterpret_cast< std::vector< pj::ToneDesc >::value_type * >(argp3);
  try {
    std_vector_Sl_pj_ToneDesc_Sg____setitem____SWIG_2(arg1,arg2,(pj::ToneDesc const &)*arg3);
  } catch(std::out_of_range &_e) {
    SWIG_exception_fail(SWIG_IndexError, (&_e)->what());
  }
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_ToneDescVector___setitem__(PyObject *self, PyObject *args) {
  Py_ssize_t argc;
  PyObject *argv[4] = {
    0
  };
  
  if (!(argc = SWIG_Python_UnpackTuple(args, "ToneDescVector___setitem__", 0, 3, argv))) SWIG_fail;
  --argc;
  if (argc == 2) {
    int _v;
    int res = swig::asptr(argv[0], (std::vector< pj::ToneDesc,std::allocator< pj::ToneDesc > >**)(0));
    _v = SWIG_CheckState(res);
    if (_v) {
      {
        _v = PySlice_Check(argv[1]);
      }
      if (_v) {
        return _wrap_ToneDescVector___setitem____SWIG_1(self, argc, argv);
      }
    }
  }
  if (argc == 3) {
    int _v;
    int res = swig::asptr(argv[0], (std::vector< pj::ToneDesc,std::allocator< pj::ToneDesc > >**)(0));
    _v = SWIG_CheckState(res);
    if (_v) {
      {
        _v = PySlice_Check(argv[1]);
      }
      if (_v) {
        int res = swig::asptr(argv[2], (std::vector< pj::ToneDesc,std::allocator< pj::ToneDesc > >**)(0));
        _v = SWIG_CheckState(res);
        if (_v) {
          return _wrap_ToneDescVector___setitem____SWIG_0(self, argc, argv);
        }
      }
    }
  }
  if (argc == 3) {
    int _v;
    int res = swig::asptr(argv[0], (std::vector< pj::ToneDesc,std::allocator< pj::ToneDesc > >**)(0));
    _v = SWIG_CheckState(res);
    if (_v) {
      {
        int res = SWIG_AsVal_ptrdiff_t(argv[1], NULL);
        _v = SWIG_CheckState(res);
      }
      if (_v) {
        int res = SWIG_ConvertPtr(argv[2], 0, SWIGTYPE_p_pj__ToneDesc, SWIG_POINTER_NO_NULL | 0);
        _v = SWIG_CheckState(res);
        if (_v) {
          return _wrap_ToneDescVector___setitem____SWIG_2(self, argc, argv);
        }
      }
    }
  }
  
fail:
  SWIG_Python_RaiseOrModifyTypeError("Wrong number or type of arguments for overloaded function 'ToneDescVector___setitem__'.\n"
    "  Possible C/C++ prototypes are:\n"
    "    std::vector< pj::ToneDesc >::__setitem__(PySliceObject *,std::vector< pj::ToneDesc,std::allocator< pj::ToneDesc > > const &)\n"
    "    std::vector< pj::ToneDesc >::__setitem__(PySliceObject *)\n"
    "    std::vector< pj::ToneDesc >::__setitem__(std::vector< pj::ToneDesc >::difference_type,std::vector< pj::ToneDesc >::value_type const &)\n");
  return 0;
}


SWIGINTERN PyObject *_wrap_ToneDescVector_pop(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  std::vector< pj::ToneDesc > *arg1 = (std::vector< pj::ToneDesc > *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  std::vector< pj::ToneDesc >::value_type result;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__vectorT_pj__ToneDesc_std__allocatorT_pj__ToneDesc_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "ToneDescVector_pop" "', argument " "1"" of type '" "std::vector< pj::ToneDesc > *""'"); 
  }
  arg1 = reinterpret_cast< std::vector< pj::ToneDesc > * >(argp1);
  try {
    result = std_vector_Sl_pj_ToneDesc_Sg__pop(arg1);
  } catch(std::out_of_range &_e) {
    SWIG_exception_fail(SWIG_IndexError, (&_e)->what());
  }
  resultobj = SWIG_NewPointerObj((new std::vector< pj::ToneDesc >::value_type(static_cast< const std::vector< pj::ToneDesc >::value_type& >(result))), SWIGTYPE_p_pj__ToneDesc, SWIG_POINTER_OWN |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_ToneDescVector_append(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  std::vector< pj::ToneDesc > *arg1 = (std::vector< pj::ToneDesc > *) 0 ;
  std::vector< pj::ToneDesc >::value_type *arg2 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  void *argp2 = 0 ;
  int res2 = 0 ;
  PyObject *swig_obj[2] ;
  
  if (!SWIG_Python_UnpackTuple(args, "ToneDescVector_append", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__vectorT_pj__ToneDesc_std__allocatorT_pj__ToneDesc_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "ToneDescVector_append" "', argument " "1"" of type '" "std::vector< pj::ToneDesc > *""'"); 
  }
  arg1 = reinterpret_cast< std::vector< pj::ToneDesc > * >(argp1);
  res2 = SWIG_ConvertPtr(swig_obj[1], &argp2, SWIGTYPE_p_pj__ToneDesc,  0  | 0);
  if (!SWIG_IsOK(res2)) {
    SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "ToneDescVector_append" "', argument " "2"" of type '" "std::vector< pj::ToneDesc >::value_type const &""'"); 
  }
  if (!argp2) {
    SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "ToneDescVector_append" "', argument " "2"" of type '" "std::vector< pj::ToneDesc >::value_type const &""'"); 
  }
  arg2 = reinterpret_cast< std::vector< pj::ToneDesc >::value_type * >(argp2);
  std_vector_Sl_pj_ToneDesc_Sg__append(arg1,(pj::ToneDesc const &)*arg2);
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_new_ToneDescVector__SWIG_0(PyObject *SWIGUNUSEDPARM(self), Py_ssize_t nobjs, PyObject **SWIGUNUSEDPARM(swig_obj)) {
  PyObject *resultobj = 0;
  std::vector< pj::ToneDesc > *result = 0 ;
  
  if ((nobjs < 0) || (nobjs > 0)) SWIG_fail;
  result = (std::vector< pj::ToneDesc > *)new std::vector< pj::ToneDesc >();
  resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(result), SWIGTYPE_p_std__vectorT_pj__ToneDesc_std__allocatorT_pj__ToneDesc_t_t, SWIG_POINTER_NEW |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_new_ToneDescVector__SWIG_1(PyObject *SWIGUNUSEDPARM(self), Py_ssize_t nobjs, PyObject **swig_obj) {
  PyObject *resultobj = 0;
  std::vector< pj::ToneDesc > *arg1 = 0 ;
  int res1 = SWIG_OLDOBJ ;
  std::vector< pj::ToneDesc > *result = 0 ;
  
  if ((nobjs < 1) || (nobjs > 1)) SWIG_fail;
  {
    std::vector< pj::ToneDesc,std::allocator< pj::ToneDesc > > *ptr = (std::vector< pj::ToneDesc,std::allocator< pj::ToneDesc > > *)0;
    res1 = swig::asptr(swig_obj[0], &ptr);
    if (!SWIG_IsOK(res1)) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "new_ToneDescVector" "', argument " "1"" of type '" "std::vector< pj::ToneDesc > const &""'"); 
    }
    if (!ptr) {
      SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "new_ToneDescVector" "', argument " "1"" of type '" "std::vector< pj::ToneDesc > const &""'"); 
    }
    arg1 = ptr;
  }
  result = (std::vector< pj::ToneDesc > *)new std::vector< pj::ToneDesc >((std::vector< pj::ToneDesc > const &)*arg1);
  resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(result), SWIGTYPE_p_std__vectorT_pj__ToneDesc_std__allocatorT_pj__ToneDesc_t_t, SWIG_POINTER_NEW |  0 );
  if (SWIG_IsNewObj(res1)) delete arg1;
  return resultobj;
fail:
  if (SWIG_IsNewObj(res1)) delete arg1;
  return NULL;
}


SWIGINTERN PyObject *_wrap_ToneDescVector_empty(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  std::vector< pj::ToneDesc > *arg1 = (std::vector< pj::ToneDesc > *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  bool result;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__vectorT_pj__ToneDesc_std__allocatorT_pj__ToneDesc_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "ToneDescVector_empty" "', argument " "1"" of type '" "std::vector< pj::ToneDesc > const *""'"); 
  }
  arg1 = reinterpret_cast< std::vector< pj::ToneDesc > * >(argp1);
  result = (bool)((std::vector< pj::ToneDesc > const *)arg1)->empty();
  resultobj = SWIG_From_bool(static_cast< bool >(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_ToneDescVector_size(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  std::vector< pj::ToneDesc > *arg1 = (std::vector< pj::ToneDesc > *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  std::vector< pj::ToneDesc >::size_type result;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__vectorT_pj__ToneDesc_std__allocatorT_pj__ToneDesc_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "ToneDescVector_size" "', argument " "1"" of type '" "std::vector< pj::ToneDesc > const *""'"); 
  }
  arg1 = reinterpret_cast< std::vector< pj::ToneDesc > * >(argp1);
  result = ((std::vector< pj::ToneDesc > const *)arg1)->size();
  resultobj = SWIG_From_size_t(static_cast< size_t >(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_ToneDescVector_swap(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  std::vector< pj::ToneDesc > *arg1 = (std::vector< pj::ToneDesc > *) 0 ;
  std::vector< pj::ToneDesc > *arg2 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  void *argp2 = 0 ;
  int res2 = 0 ;
  PyObject *swig_obj[2] ;
  
  if (!SWIG_Python_UnpackTuple(args, "ToneDescVector_swap", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__vectorT_pj__ToneDesc_std__allocatorT_pj__ToneDesc_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "ToneDescVector_swap" "', argument " "1"" of type '" "std::vector< pj::ToneDesc > *""'"); 
  }
  arg1 = reinterpret_cast< std::vector< pj::ToneDesc > * >(argp1);
  res2 = SWIG_ConvertPtr(swig_obj[1], &argp2, SWIGTYPE_p_std__vectorT_pj__ToneDesc_std__allocatorT_pj__ToneDesc_t_t,  0 );
  if (!SWIG_IsOK(res2)) {
    SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "ToneDescVector_swap" "', argument " "2"" of type '" "std::vector< pj::ToneDesc > &""'"); 
  }
  if (!argp2) {
    SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "ToneDescVector_swap" "', argument " "2"" of type '" "std::vector< pj::ToneDesc > &""'"); 
  }
  arg2 = reinterpret_cast< std::vector< pj::ToneDesc > * >(argp2);
  (arg1)->swap(*arg2);
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_ToneDescVector_begin(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  std::vector< pj::ToneDesc > *arg1 = (std::vector< pj::ToneDesc > *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  std::vector< pj::ToneDesc >::iterator result;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__vectorT_pj__ToneDesc_std__allocatorT_pj__ToneDesc_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "ToneDescVector_begin" "', argument " "1"" of type '" "std::vector< pj::ToneDesc > *""'"); 
  }
  arg1 = reinterpret_cast< std::vector< pj::ToneDesc > * >(argp1);
  result = (arg1)->begin();
  resultobj = SWIG_NewPointerObj(swig::make_output_iterator(static_cast< const std::vector< pj::ToneDesc >::iterator & >(result)),
    swig::SwigPyIterator::descriptor(),SWIG_POINTER_OWN);
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_ToneDescVector_end(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  std::vector< pj::ToneDesc > *arg1 = (std::vector< pj::ToneDesc > *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  std::vector< pj::ToneDesc >::iterator result;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__vectorT_pj__ToneDesc_std__allocatorT_pj__ToneDesc_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "ToneDescVector_end" "', argument " "1"" of type '" "std::vector< pj::ToneDesc > *""'"); 
  }
  arg1 = reinterpret_cast< std::vector< pj::ToneDesc > * >(argp1);
  result = (arg1)->end();
  resultobj = SWIG_NewPointerObj(swig::make_output_iterator(static_cast< const std::vector< pj::ToneDesc >::iterator & >(result)),
    swig::SwigPyIterator::descriptor(),SWIG_POINTER_OWN);
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_ToneDescVector_rbegin(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  std::vector< pj::ToneDesc > *arg1 = (std::vector< pj::ToneDesc > *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  std::vector< pj::ToneDesc >::reverse_iterator result;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__vectorT_pj__ToneDesc_std__allocatorT_pj__ToneDesc_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "ToneDescVector_rbegin" "', argument " "1"" of type '" "std::vector< pj::ToneDesc > *""'"); 
  }
  arg1 = reinterpret_cast< std::vector< pj::ToneDesc > * >(argp1);
  result = (arg1)->rbegin();
  resultobj = SWIG_NewPointerObj(swig::make_output_iterator(static_cast< const std::vector< pj::ToneDesc >::reverse_iterator & >(result)),
    swig::SwigPyIterator::descriptor(),SWIG_POINTER_OWN);
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_ToneDescVector_rend(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  std::vector< pj::ToneDesc > *arg1 = (std::vector< pj::ToneDesc > *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  std::vector< pj::ToneDesc >::reverse_iterator result;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__vectorT_pj__ToneDesc_std__allocatorT_pj__ToneDesc_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "ToneDescVector_rend" "', argument " "1"" of type '" "std::vector< pj::ToneDesc > *""'"); 
  }
  arg1 = reinterpret_cast< std::vector< pj::ToneDesc > * >(argp1);
  result = (arg1)->rend();
  resultobj = SWIG_NewPointerObj(swig::make_output_iterator(static_cast< const std::vector< pj::ToneDesc >::reverse_iterator & >(result)),
    swig::SwigPyIterator::descriptor(),SWIG_POINTER_OWN);
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_ToneDescVector_clear(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  std::vector< pj::ToneDesc > *arg1 = (std::vector< pj::ToneDesc > *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__vectorT_pj__ToneDesc_std__allocatorT_pj__ToneDesc_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "ToneDescVector_clear" "', argument " "1"" of type '" "std::vector< pj::ToneDesc > *""'"); 
  }
  arg1 = reinterpret_cast< std::vector< pj::ToneDesc > * >(argp1);
  (arg1)->clear();
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_ToneDescVector_get_allocator(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  std::vector< pj::ToneDesc > *arg1 = (std::vector< pj::ToneDesc > *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  SwigValueWrapper< std::allocator< pj::ToneDesc > > result;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__vectorT_pj__ToneDesc_std__allocatorT_pj__ToneDesc_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "ToneDescVector_get_allocator" "', argument " "1"" of type '" "std::vector< pj::ToneDesc > const *""'"); 
  }
  arg1 = reinterpret_cast< std::vector< pj::ToneDesc > * >(argp1);
  result = ((std::vector< pj::ToneDesc > const *)arg1)->get_allocator();
  resultobj = SWIG_NewPointerObj((new std::vector< pj::ToneDesc >::allocator_type(static_cast< const std::vector< pj::ToneDesc >::allocator_type& >(result))), SWIGTYPE_p_std__allocatorT_pj__ToneDesc_t, SWIG_POINTER_OWN |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_new_ToneDescVector__SWIG_2(PyObject *SWIGUNUSEDPARM(self), Py_ssize_t nobjs, PyObject **swig_obj) {
  PyObject *resultobj = 0;
  std::vector< pj::ToneDesc >::size_type arg1 ;
  size_t val1 ;
  int ecode1 = 0 ;
  std::vector< pj::ToneDesc > *result = 0 ;
  
  if ((nobjs < 1) || (nobjs > 1)) SWIG_fail;
  ecode1 = SWIG_AsVal_size_t(swig_obj[0], &val1);
  if (!SWIG_IsOK(ecode1)) {
    SWIG_exception_fail(SWIG_ArgError(ecode1), "in method '" "new_ToneDescVector" "', argument " "1"" of type '" "std::vector< pj::ToneDesc >::size_type""'");
  } 
  arg1 = static_cast< std::vector< pj::ToneDesc >::size_type >(val1);
  result = (std::vector< pj::ToneDesc > *)new std::vector< pj::ToneDesc >(arg1);
  resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(result), SWIGTYPE_p_std__vectorT_pj__ToneDesc_std__allocatorT_pj__ToneDesc_t_t, SWIG_POINTER_NEW |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_ToneDescVector_pop_back(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  std::vector< pj::ToneDesc > *arg1 = (std::vector< pj::ToneDesc > *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__vectorT_pj__ToneDesc_std__allocatorT_pj__ToneDesc_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "ToneDescVector_pop_back" "', argument " "1"" of type '" "std::vector< pj::ToneDesc > *""'"); 
  }
  arg1 = reinterpret_cast< std::vector< pj::ToneDesc > * >(argp1);
  (arg1)->pop_back();
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_ToneDescVector_resize__SWIG_0(PyObject *SWIGUNUSEDPARM(self), Py_ssize_t nobjs, PyObject **swig_obj) {
  PyObject *resultobj = 0;
  std::vector< pj::ToneDesc > *arg1 = (std::vector< pj::ToneDesc > *) 0 ;
  std::vector< pj::ToneDesc >::size_type arg2 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  size_t val2 ;
  int ecode2 = 0 ;
  
  if ((nobjs < 2) || (nobjs > 2)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__vectorT_pj__ToneDesc_std__allocatorT_pj__ToneDesc_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "ToneDescVector_resize" "', argument " "1"" of type '" "std::vector< pj::ToneDesc > *""'"); 
  }
  arg1 = reinterpret_cast< std::vector< pj::ToneDesc > * >(argp1);
  ecode2 = SWIG_AsVal_size_t(swig_obj[1], &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "ToneDescVector_resize" "', argument " "2"" of type '" "std::vector< pj::ToneDesc >::size_type""'");
  } 
  arg2 = static_cast< std::vector< pj::ToneDesc >::size_type >(val2);
  (arg1)->resize(arg2);
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_ToneDescVector_erase__SWIG_0(PyObject *SWIGUNUSEDPARM(self), Py_ssize_t nobjs, PyObject **swig_obj) {
  PyObject *resultobj = 0;
  std::vector< pj::ToneDesc > *arg1 = (std::vector< pj::ToneDesc > *) 0 ;
  std::vector< pj::ToneDesc >::iterator arg2 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  swig::SwigPyIterator *iter2 = 0 ;
  int res2 ;
  std::vector< pj::ToneDesc >::iterator result;
  
  if ((nobjs < 2) || (nobjs > 2)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__vectorT_pj__ToneDesc_std__allocatorT_pj__ToneDesc_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "ToneDescVector_erase" "', argument " "1"" of type '" "std::vector< pj::ToneDesc > *""'"); 
  }
  arg1 = reinterpret_cast< std::vector< pj::ToneDesc > * >(argp1);
  res2 = SWIG_ConvertPtr(swig_obj[1], SWIG_as_voidptrptr(&iter2), swig::SwigPyIterator::descriptor(), 0);
  if (!SWIG_IsOK(res2) || !iter2) {
    SWIG_exception_fail(SWIG_ArgError(SWIG_TypeError), "in method '" "ToneDescVector_erase" "', argument " "2"" of type '" "std::vector< pj::ToneDesc >::iterator""'");
  } else {
    swig::SwigPyIterator_T<std::vector< pj::ToneDesc >::iterator > *iter_t = dynamic_cast<swig::SwigPyIterator_T<std::vector< pj::ToneDesc >::iterator > *>(iter2);
    if (iter_t) {
      arg2 = iter_t->get_current();
    } else {
      SWIG_exception_fail(SWIG_ArgError(SWIG_TypeError), "in method '" "ToneDescVector_erase" "', argument " "2"" of type '" "std::vector< pj::ToneDesc >::iterator""'");
    }
  }
  result = std_vector_Sl_pj_ToneDesc_Sg__erase__SWIG_0(arg1,arg2);
  resultobj = SWIG_NewPointerObj(swig::make_output_iterator(static_cast< const std::vector< pj::ToneDesc >::iterator & >(result)),
    swig::SwigPyIterator::descriptor(),SWIG_POINTER_OWN);
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_ToneDescVector_erase__SWIG_1(PyObject *SWIGUNUSEDPARM(self), Py_ssize_t nobjs, PyObject **swig_obj) {
  PyObject *resultobj = 0;
  std::vector< pj::ToneDesc > *arg1 = (std::vector< pj::ToneDesc > *) 0 ;
  std::vector< pj::ToneDesc >::iterator arg2 ;
  std::vector< pj::ToneDesc >::iterator arg3 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  swig::SwigPyIterator *iter2 = 0 ;
  int res2 ;
  swig::SwigPyIterator *iter3 = 0 ;
  int res3 ;
  std::vector< pj::ToneDesc >::iterator result;
  
  if ((nobjs < 3) || (nobjs > 3)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__vectorT_pj__ToneDesc_std__allocatorT_pj__ToneDesc_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "ToneDescVector_erase" "', argument " "1"" of type '" "std::vector< pj::ToneDesc > *""'"); 
  }
  arg1 = reinterpret_cast< std::vector< pj::ToneDesc > * >(argp1);
  res2 = SWIG_ConvertPtr(swig_obj[1], SWIG_as_voidptrptr(&iter2), swig::SwigPyIterator::descriptor(), 0);
  if (!SWIG_IsOK(res2) || !iter2) {
    SWIG_exception_fail(SWIG_ArgError(SWIG_TypeError), "in method '" "ToneDescVector_erase" "', argument " "2"" of type '" "std::vector< pj::ToneDesc >::iterator""'");
  } else {
    swig::SwigPyIterator_T<std::vector< pj::ToneDesc >::iterator > *iter_t = dynamic_cast<swig::SwigPyIterator_T<std::vector< pj::ToneDesc >::iterator > *>(iter2);
    if (iter_t) {
      arg2 = iter_t->get_current();
    } else {
      SWIG_exception_fail(SWIG_ArgError(SWIG_TypeError), "in method '" "ToneDescVector_erase" "', argument " "2"" of type '" "std::vector< pj::ToneDesc >::iterator""'");
    }
  }
  res3 = SWIG_ConvertPtr(swig_obj[2], SWIG_as_voidptrptr(&iter3), swig::SwigPyIterator::descriptor(), 0);
  if (!SWIG_IsOK(res3) || !iter3) {
    SWIG_exception_fail(SWIG_ArgError(SWIG_TypeError), "in method '" "ToneDescVector_erase" "', argument " "3"" of type '" "std::vector< pj::ToneDesc >::iterator""'");
  } else {
    swig::SwigPyIterator_T<std::vector< pj::ToneDesc >::iterator > *iter_t = dynamic_cast<swig::SwigPyIterator_T<std::vector< pj::ToneDesc >::iterator > *>(iter3);
    if (iter_t) {
      arg3 = iter_t->get_current();
    } else {
      SWIG_exception_fail(SWIG_ArgError(SWIG_TypeError), "in method '" "ToneDescVector_erase" "', argument " "3"" of type '" "std::vector< pj::ToneDesc >::iterator""'");
    }
  }
  result = std_vector_Sl_pj_ToneDesc_Sg__erase__SWIG_1(arg1,arg2,arg3);
  resultobj = SWIG_NewPointerObj(swig::make_output_iterator(static_cast< const std::vector< pj::ToneDesc >::iterator & >(result)),
    swig::SwigPyIterator::descriptor(),SWIG_POINTER_OWN);
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_ToneDescVector_erase(PyObject *self, PyObject *args) {
  Py_ssize_t argc;
  PyObject *argv[4] = {
    0
  };
  
  if (!(argc = SWIG_Python_UnpackTuple(args, "ToneDescVector_erase", 0, 3, argv))) SWIG_fail;
  --argc;
  if (argc == 2) {
    int _v;
    int res = swig::asptr(argv[0], (std::vector< pj::ToneDesc,std::allocator< pj::ToneDesc > >**)(0));
    _v = SWIG_CheckState(res);
    if (_v) {
      swig::SwigPyIterator *iter = 0;
      int res = SWIG_ConvertPtr(argv[1], SWIG_as_voidptrptr(&iter), swig::SwigPyIterator::descriptor(), 0);
      _v = (SWIG_IsOK(res) && iter && (dynamic_cast<swig::SwigPyIterator_T<std::vector< pj::ToneDesc >::iterator > *>(iter) != 0));
      if (_v) {
        return _wrap_ToneDescVector_erase__SWIG_0(self, argc, argv);
      }
    }
  }
  if (argc == 3) {
    int _v;
    int res = swig::asptr(argv[0], (std::vector< pj::ToneDesc,std::allocator< pj::ToneDesc > >**)(0));
    _v = SWIG_CheckState(res);
    if (_v) {
      swig::SwigPyIterator *iter = 0;
      int res = SWIG_ConvertPtr(argv[1], SWIG_as_voidptrptr(&iter), swig::SwigPyIterator::descriptor(), 0);
      _v = (SWIG_IsOK(res) && iter && (dynamic_cast<swig::SwigPyIterator_T<std::vector< pj::ToneDesc >::iterator > *>(iter) != 0));
      if (_v) {
        swig::SwigPyIterator *iter = 0;
        int res = SWIG_ConvertPtr(argv[2], SWIG_as_voidptrptr(&iter), swig::SwigPyIterator::descriptor(), 0);
        _v = (SWIG_IsOK(res) && iter && (dynamic_cast<swig::SwigPyIterator_T<std::vector< pj::ToneDesc >::iterator > *>(iter) != 0));
        if (_v) {
          return _wrap_ToneDescVector_erase__SWIG_1(self, argc, argv);
        }
      }
    }
  }
  
fail:
  SWIG_Python_RaiseOrModifyTypeError("Wrong number or type of arguments for overloaded function 'ToneDescVector_erase'.\n"
    "  Possible C/C++ prototypes are:\n"
    "    std::vector< pj::ToneDesc >::erase(std::vector< pj::ToneDesc >::iterator)\n"
    "    std::vector< pj::ToneDesc >::erase(std::vector< pj::ToneDesc >::iterator,std::vector< pj::ToneDesc >::iterator)\n");
  return 0;
}


SWIGINTERN PyObject *_wrap_new_ToneDescVector__SWIG_3(PyObject *SWIGUNUSEDPARM(self), Py_ssize_t nobjs, PyObject **swig_obj) {
  PyObject *resultobj = 0;
  std::vector< pj::ToneDesc >::size_type arg1 ;
  std::vector< pj::ToneDesc >::value_type *arg2 = 0 ;
  size_t val1 ;
  int ecode1 = 0 ;
  void *argp2 = 0 ;
  int res2 = 0 ;
  std::vector< pj::ToneDesc > *result = 0 ;
  
  if ((nobjs < 2) || (nobjs > 2)) SWIG_fail;
  ecode1 = SWIG_AsVal_size_t(swig_obj[0], &val1);
  if (!SWIG_IsOK(ecode1)) {
    SWIG_exception_fail(SWIG_ArgError(ecode1), "in method '" "new_ToneDescVector" "', argument " "1"" of type '" "std::vector< pj::ToneDesc >::size_type""'");
  } 
  arg1 = static_cast< std::vector< pj::ToneDesc >::size_type >(val1);
  res2 = SWIG_ConvertPtr(swig_obj[1], &argp2, SWIGTYPE_p_pj__ToneDesc,  0  | 0);
  if (!SWIG_IsOK(res2)) {
    SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "new_ToneDescVector" "', argument " "2"" of type '" "std::vector< pj::ToneDesc >::value_type const &""'"); 
  }
  if (!argp2) {
    SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "new_ToneDescVector" "', argument " "2"" of type '" "std::vector< pj::ToneDesc >::value_type const &""'"); 
  }
  arg2 = reinterpret_cast< std::vector< pj::ToneDesc >::value_type * >(argp2);
  result = (std::vector< pj::ToneDesc > *)new std::vector< pj::ToneDesc >(arg1,(std::vector< pj::ToneDesc >::value_type const &)*arg2);
  resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(result), SWIGTYPE_p_std__vectorT_pj__ToneDesc_std__allocatorT_pj__ToneDesc_t_t, SWIG_POINTER_NEW |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_new_ToneDescVector(PyObject *self, PyObject *args) {
  Py_ssize_t argc;
  PyObject *argv[3] = {
    0
  };
  
  if (!(argc = SWIG_Python_UnpackTuple(args, "new_ToneDescVector", 0, 2, argv))) SWIG_fail;
  --argc;
  if (argc == 0) {
    return _wrap_new_ToneDescVector__SWIG_0(self, argc, argv);
  }
  if (argc == 1) {
    int _v;
    {
      int res = SWIG_AsVal_size_t(argv[0], NULL);
      _v = SWIG_CheckState(res);
    }
    if (_v) {
      return _wrap_new_ToneDescVector__SWIG_2(self, argc, argv);
    }
  }
  if (argc == 1) {
    int _v;
    int res = swig::asptr(argv[0], (std::vector< pj::ToneDesc,std::allocator< pj::ToneDesc > >**)(0));
    _v = SWIG_CheckState(res);
    if (_v) {
      return _wrap_new_ToneDescVector__SWIG_1(self, argc, argv);
    }
  }
  if (argc == 2) {
    int _v;
    {
      int res = SWIG_AsVal_size_t(argv[0], NULL);
      _v = SWIG_CheckState(res);
    }
    if (_v) {
      int res = SWIG_ConvertPtr(argv[1], 0, SWIGTYPE_p_pj__ToneDesc, SWIG_POINTER_NO_NULL | 0);
      _v = SWIG_CheckState(res);
      if (_v) {
        return _wrap_new_ToneDescVector__SWIG_3(self, argc, argv);
      }
    }
  }
  
fail:
  SWIG_Python_RaiseOrModifyTypeError("Wrong number or type of arguments for overloaded function 'new_ToneDescVector'.\n"
    "  Possible C/C++ prototypes are:\n"
    "    std::vector< pj::ToneDesc >::vector()\n"
    "    std::vector< pj::ToneDesc >::vector(std::vector< pj::ToneDesc > const &)\n"
    "    std::vector< pj::ToneDesc >::vector(std::vector< pj::ToneDesc >::size_type)\n"
    "    std::vector< pj::ToneDesc >::vector(std::vector< pj::ToneDesc >::size_type,std::vector< pj::ToneDesc >::value_type const &)\n");
  return 0;
}


SWIGINTERN PyObject *_wrap_ToneDescVector_push_back(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  std::vector< pj::ToneDesc > *arg1 = (std::vector< pj::ToneDesc > *) 0 ;
  std::vector< pj::ToneDesc >::value_type *arg2 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  void *argp2 = 0 ;
  int res2 = 0 ;
  PyObject *swig_obj[2] ;
  
  if (!SWIG_Python_UnpackTuple(args, "ToneDescVector_push_back", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__vectorT_pj__ToneDesc_std__allocatorT_pj__ToneDesc_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "ToneDescVector_push_back" "', argument " "1"" of type '" "std::vector< pj::ToneDesc > *""'"); 
  }
  arg1 = reinterpret_cast< std::vector< pj::ToneDesc > * >(argp1);
  res2 = SWIG_ConvertPtr(swig_obj[1], &argp2, SWIGTYPE_p_pj__ToneDesc,  0  | 0);
  if (!SWIG_IsOK(res2)) {
    SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "ToneDescVector_push_back" "', argument " "2"" of type '" "std::vector< pj::ToneDesc >::value_type const &""'"); 
  }
  if (!argp2) {
    SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "ToneDescVector_push_back" "', argument " "2"" of type '" "std::vector< pj::ToneDesc >::value_type const &""'"); 
  }
  arg2 = reinterpret_cast< std::vector< pj::ToneDesc >::value_type * >(argp2);
  (arg1)->push_back((std::vector< pj::ToneDesc >::value_type const &)*arg2);
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_ToneDescVector_front(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  std::vector< pj::ToneDesc > *arg1 = (std::vector< pj::ToneDesc > *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  std::vector< pj::ToneDesc >::value_type *result = 0 ;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__vectorT_pj__ToneDesc_std__allocatorT_pj__ToneDesc_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "ToneDescVector_front" "', argument " "1"" of type '" "std::vector< pj::ToneDesc > const *""'"); 
  }
  arg1 = reinterpret_cast< std::vector< pj::ToneDesc > * >(argp1);
  result = (std::vector< pj::ToneDesc >::value_type *) &((std::vector< pj::ToneDesc > const *)arg1)->front();
  resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(result), SWIGTYPE_p_pj__ToneDesc, 0 |  0 );
  (void)swig::container_owner<swig::traits<std::vector< pj::ToneDesc >::value_type>::category>::back_reference(resultobj, swig_obj[0]);
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_ToneDescVector_back(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  std::vector< pj::ToneDesc > *arg1 = (std::vector< pj::ToneDesc > *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  std::vector< pj::ToneDesc >::value_type *result = 0 ;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__vectorT_pj__ToneDesc_std__allocatorT_pj__ToneDesc_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "ToneDescVector_back" "', argument " "1"" of type '" "std::vector< pj::ToneDesc > const *""'"); 
  }
  arg1 = reinterpret_cast< std::vector< pj::ToneDesc > * >(argp1);
  result = (std::vector< pj::ToneDesc >::value_type *) &((std::vector< pj::ToneDesc > const *)arg1)->back();
  resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(result), SWIGTYPE_p_pj__ToneDesc, 0 |  0 );
  (void)swig::container_owner<swig::traits<std::vector< pj::ToneDesc >::value_type>::category>::back_reference(resultobj, swig_obj[0]);
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_ToneDescVector_assign(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  std::vector< pj::ToneDesc > *arg1 = (std::vector< pj::ToneDesc > *) 0 ;
  std::vector< pj::ToneDesc >::size_type arg2 ;
  std::vector< pj::ToneDesc >::value_type *arg3 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  size_t val2 ;
  int ecode2 = 0 ;
  void *argp3 = 0 ;
  int res3 = 0 ;
  PyObject *swig_obj[3] ;
  
  if (!SWIG_Python_UnpackTuple(args, "ToneDescVector_assign", 3, 3, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__vectorT_pj__ToneDesc_std__allocatorT_pj__ToneDesc_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "ToneDescVector_assign" "', argument " "1"" of type '" "std::vector< pj::ToneDesc > *""'"); 
  }
  arg1 = reinterpret_cast< std::vector< pj::ToneDesc > * >(argp1);
  ecode2 = SWIG_AsVal_size_t(swig_obj[1], &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "ToneDescVector_assign" "', argument " "2"" of type '" "std::vector< pj::ToneDesc >::size_type""'");
  } 
  arg2 = static_cast< std::vector< pj::ToneDesc >::size_type >(val2);
  res3 = SWIG_ConvertPtr(swig_obj[2], &argp3, SWIGTYPE_p_pj__ToneDesc,  0  | 0);
  if (!SWIG_IsOK(res3)) {
    SWIG_exception_fail(SWIG_ArgError(res3), "in method '" "ToneDescVector_assign" "', argument " "3"" of type '" "std::vector< pj::ToneDesc >::value_type const &""'"); 
  }
  if (!argp3) {
    SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "ToneDescVector_assign" "', argument " "3"" of type '" "std::vector< pj::ToneDesc >::value_type const &""'"); 
  }
  arg3 = reinterpret_cast< std::vector< pj::ToneDesc >::value_type * >(argp3);
  (arg1)->assign(arg2,(std::vector< pj::ToneDesc >::value_type const &)*arg3);
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_ToneDescVector_resize__SWIG_1(PyObject *SWIGUNUSEDPARM(self), Py_ssize_t nobjs, PyObject **swig_obj) {
  PyObject *resultobj = 0;
  std::vector< pj::ToneDesc > *arg1 = (std::vector< pj::ToneDesc > *) 0 ;
  std::vector< pj::ToneDesc >::size_type arg2 ;
  std::vector< pj::ToneDesc >::value_type *arg3 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  size_t val2 ;
  int ecode2 = 0 ;
  void *argp3 = 0 ;
  int res3 = 0 ;
  
  if ((nobjs < 3) || (nobjs > 3)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__vectorT_pj__ToneDesc_std__allocatorT_pj__ToneDesc_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "ToneDescVector_resize" "', argument " "1"" of type '" "std::vector< pj::ToneDesc > *""'"); 
  }
  arg1 = reinterpret_cast< std::vector< pj::ToneDesc > * >(argp1);
  ecode2 = SWIG_AsVal_size_t(swig_obj[1], &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "ToneDescVector_resize" "', argument " "2"" of type '" "std::vector< pj::ToneDesc >::size_type""'");
  } 
  arg2 = static_cast< std::vector< pj::ToneDesc >::size_type >(val2);
  res3 = SWIG_ConvertPtr(swig_obj[2], &argp3, SWIGTYPE_p_pj__ToneDesc,  0  | 0);
  if (!SWIG_IsOK(res3)) {
    SWIG_exception_fail(SWIG_ArgError(res3), "in method '" "ToneDescVector_resize" "', argument " "3"" of type '" "std::vector< pj::ToneDesc >::value_type const &""'"); 
  }
  if (!argp3) {
    SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "ToneDescVector_resize" "', argument " "3"" of type '" "std::vector< pj::ToneDesc >::value_type const &""'"); 
  }
  arg3 = reinterpret_cast< std::vector< pj::ToneDesc >::value_type * >(argp3);
  (arg1)->resize(arg2,(std::vector< pj::ToneDesc >::value_type const &)*arg3);
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_ToneDescVector_resize(PyObject *self, PyObject *args) {
  Py_ssize_t argc;
  PyObject *argv[4] = {
    0
  };
  
  if (!(argc = SWIG_Python_UnpackTuple(args, "ToneDescVector_resize", 0, 3, argv))) SWIG_fail;
  --argc;
  if (argc == 2) {
    int _v;
    int res = swig::asptr(argv[0], (std::vector< pj::ToneDesc,std::allocator< pj::ToneDesc > >**)(0));
    _v = SWIG_CheckState(res);
    if (_v) {
      {
        int res = SWIG_AsVal_size_t(argv[1], NULL);
        _v = SWIG_CheckState(res);
      }
      if (_v) {
        return _wrap_ToneDescVector_resize__SWIG_0(self, argc, argv);
      }
    }
  }
  if (argc == 3) {
    int _v;
    int res = swig::asptr(argv[0], (std::vector< pj::ToneDesc,std::allocator< pj::ToneDesc > >**)(0));
    _v = SWIG_CheckState(res);
    if (_v) {
      {
        int res = SWIG_AsVal_size_t(argv[1], NULL);
        _v = SWIG_CheckState(res);
      }
      if (_v) {
        int res = SWIG_ConvertPtr(argv[2], 0, SWIGTYPE_p_pj__ToneDesc, SWIG_POINTER_NO_NULL | 0);
        _v = SWIG_CheckState(res);
        if (_v) {
          return _wrap_ToneDescVector_resize__SWIG_1(self, argc, argv);
        }
      }
    }
  }
  
fail:
  SWIG_Python_RaiseOrModifyTypeError("Wrong number or type of arguments for overloaded function 'ToneDescVector_resize'.\n"
    "  Possible C/C++ prototypes are:\n"
    "    std::vector< pj::ToneDesc >::resize(std::vector< pj::ToneDesc >::size_type)\n"
    "    std::vector< pj::ToneDesc >::resize(std::vector< pj::ToneDesc >::size_type,std::vector< pj::ToneDesc >::value_type const &)\n");
  return 0;
}


SWIGINTERN PyObject *_wrap_ToneDescVector_insert__SWIG_0(PyObject *SWIGUNUSEDPARM(self), Py_ssize_t nobjs, PyObject **swig_obj) {
  PyObject *resultobj = 0;
  std::vector< pj::ToneDesc > *arg1 = (std::vector< pj::ToneDesc > *) 0 ;
  std::vector< pj::ToneDesc >::iterator arg2 ;
  std::vector< pj::ToneDesc >::value_type *arg3 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  swig::SwigPyIterator *iter2 = 0 ;
  int res2 ;
  void *argp3 = 0 ;
  int res3 = 0 ;
  std::vector< pj::ToneDesc >::iterator result;
  
  if ((nobjs < 3) || (nobjs > 3)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__vectorT_pj__ToneDesc_std__allocatorT_pj__ToneDesc_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "ToneDescVector_insert" "', argument " "1"" of type '" "std::vector< pj::ToneDesc > *""'"); 
  }
  arg1 = reinterpret_cast< std::vector< pj::ToneDesc > * >(argp1);
  res2 = SWIG_ConvertPtr(swig_obj[1], SWIG_as_voidptrptr(&iter2), swig::SwigPyIterator::descriptor(), 0);
  if (!SWIG_IsOK(res2) || !iter2) {
    SWIG_exception_fail(SWIG_ArgError(SWIG_TypeError), "in method '" "ToneDescVector_insert" "', argument " "2"" of type '" "std::vector< pj::ToneDesc >::iterator""'");
  } else {
    swig::SwigPyIterator_T<std::vector< pj::ToneDesc >::iterator > *iter_t = dynamic_cast<swig::SwigPyIterator_T<std::vector< pj::ToneDesc >::iterator > *>(iter2);
    if (iter_t) {
      arg2 = iter_t->get_current();
    } else {
      SWIG_exception_fail(SWIG_ArgError(SWIG_TypeError), "in method '" "ToneDescVector_insert" "', argument " "2"" of type '" "std::vector< pj::ToneDesc >::iterator""'");
    }
  }
  res3 = SWIG_ConvertPtr(swig_obj[2], &argp3, SWIGTYPE_p_pj__ToneDesc,  0  | 0);
  if (!SWIG_IsOK(res3)) {
    SWIG_exception_fail(SWIG_ArgError(res3), "in method '" "ToneDescVector_insert" "', argument " "3"" of type '" "std::vector< pj::ToneDesc >::value_type const &""'"); 
  }
  if (!argp3) {
    SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "ToneDescVector_insert" "', argument " "3"" of type '" "std::vector< pj::ToneDesc >::value_type const &""'"); 
  }
  arg3 = reinterpret_cast< std::vector< pj::ToneDesc >::value_type * >(argp3);
  result = std_vector_Sl_pj_ToneDesc_Sg__insert__SWIG_0(arg1,arg2,(pj::ToneDesc const &)*arg3);
  resultobj = SWIG_NewPointerObj(swig::make_output_iterator(static_cast< const std::vector< pj::ToneDesc >::iterator & >(result)),
    swig::SwigPyIterator::descriptor(),SWIG_POINTER_OWN);
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_ToneDescVector_insert__SWIG_1(PyObject *SWIGUNUSEDPARM(self), Py_ssize_t nobjs, PyObject **swig_obj) {
  PyObject *resultobj = 0;
  std::vector< pj::ToneDesc > *arg1 = (std::vector< pj::ToneDesc > *) 0 ;
  std::vector< pj::ToneDesc >::iterator arg2 ;
  std::vector< pj::ToneDesc >::size_type arg3 ;
  std::vector< pj::ToneDesc >::value_type *arg4 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  swig::SwigPyIterator *iter2 = 0 ;
  int res2 ;
  size_t val3 ;
  int ecode3 = 0 ;
  void *argp4 = 0 ;
  int res4 = 0 ;
  
  if ((nobjs < 4) || (nobjs > 4)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__vectorT_pj__ToneDesc_std__allocatorT_pj__ToneDesc_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "ToneDescVector_insert" "', argument " "1"" of type '" "std::vector< pj::ToneDesc > *""'"); 
  }
  arg1 = reinterpret_cast< std::vector< pj::ToneDesc > * >(argp1);
  res2 = SWIG_ConvertPtr(swig_obj[1], SWIG_as_voidptrptr(&iter2), swig::SwigPyIterator::descriptor(), 0);
  if (!SWIG_IsOK(res2) || !iter2) {
    SWIG_exception_fail(SWIG_ArgError(SWIG_TypeError), "in method '" "ToneDescVector_insert" "', argument " "2"" of type '" "std::vector< pj::ToneDesc >::iterator""'");
  } else {
    swig::SwigPyIterator_T<std::vector< pj::ToneDesc >::iterator > *iter_t = dynamic_cast<swig::SwigPyIterator_T<std::vector< pj::ToneDesc >::iterator > *>(iter2);
    if (iter_t) {
      arg2 = iter_t->get_current();
    } else {
      SWIG_exception_fail(SWIG_ArgError(SWIG_TypeError), "in method '" "ToneDescVector_insert" "', argument " "2"" of type '" "std::vector< pj::ToneDesc >::iterator""'");
    }
  }
  ecode3 = SWIG_AsVal_size_t(swig_obj[2], &val3);
  if (!SWIG_IsOK(ecode3)) {
    SWIG_exception_fail(SWIG_ArgError(ecode3), "in method '" "ToneDescVector_insert" "', argument " "3"" of type '" "std::vector< pj::ToneDesc >::size_type""'");
  } 
  arg3 = static_cast< std::vector< pj::ToneDesc >::size_type >(val3);
  res4 = SWIG_ConvertPtr(swig_obj[3], &argp4, SWIGTYPE_p_pj__ToneDesc,  0  | 0);
  if (!SWIG_IsOK(res4)) {
    SWIG_exception_fail(SWIG_ArgError(res4), "in method '" "ToneDescVector_insert" "', argument " "4"" of type '" "std::vector< pj::ToneDesc >::value_type const &""'"); 
  }
  if (!argp4) {
    SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "ToneDescVector_insert" "', argument " "4"" of type '" "std::vector< pj::ToneDesc >::value_type const &""'"); 
  }
  arg4 = reinterpret_cast< std::vector< pj::ToneDesc >::value_type * >(argp4);
  std_vector_Sl_pj_ToneDesc_Sg__insert__SWIG_1(arg1,arg2,arg3,(pj::ToneDesc const &)*arg4);
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_ToneDescVector_insert(PyObject *self, PyObject *args) {
  Py_ssize_t argc;
  PyObject *argv[5] = {
    0
  };
  
  if (!(argc = SWIG_Python_UnpackTuple(args, "ToneDescVector_insert", 0, 4, argv))) SWIG_fail;
  --argc;
  if (argc == 3) {
    int _v;
    int res = swig::asptr(argv[0], (std::vector< pj::ToneDesc,std::allocator< pj::ToneDesc > >**)(0));
    _v = SWIG_CheckState(res);
    if (_v) {
      swig::SwigPyIterator *iter = 0;
      int res = SWIG_ConvertPtr(argv[1], SWIG_as_voidptrptr(&iter), swig::SwigPyIterator::descriptor(), 0);
      _v = (SWIG_IsOK(res) && iter && (dynamic_cast<swig::SwigPyIterator_T<std::vector< pj::ToneDesc >::iterator > *>(iter) != 0));
      if (_v) {
        int res = SWIG_ConvertPtr(argv[2], 0, SWIGTYPE_p_pj__ToneDesc, SWIG_POINTER_NO_NULL | 0);
        _v = SWIG_CheckState(res);
        if (_v) {
          return _wrap_ToneDescVector_insert__SWIG_0(self, argc, argv);
        }
      }
    }
  }
  if (argc == 4) {
    int _v;
    int res = swig::asptr(argv[0], (std::vector< pj::ToneDesc,std::allocator< pj::ToneDesc > >**)(0));
    _v = SWIG_CheckState(res);
    if (_v) {
      swig::SwigPyIterator *iter = 0;
      int res = SWIG_ConvertPtr(argv[1], SWIG_as_voidptrptr(&iter), swig::SwigPyIterator::descriptor(), 0);
      _v = (SWIG_IsOK(res) && iter && (dynamic_cast<swig::SwigPyIterator_T<std::vector< pj::ToneDesc >::iterator > *>(iter) != 0));
      if (_v) {
        {
          int res = SWIG_AsVal_size_t(argv[2], NULL);
          _v = SWIG_CheckState(res);
        }
        if (_v) {
          int res = SWIG_ConvertPtr(argv[3], 0, SWIGTYPE_p_pj__ToneDesc, SWIG_POINTER_NO_NULL | 0);
          _v = SWIG_CheckState(res);
          if (_v) {
            return _wrap_ToneDescVector_insert__SWIG_1(self, argc, argv);
          }
        }
      }
    }
  }
  
fail:
  SWIG_Python_RaiseOrModifyTypeError("Wrong number or type of arguments for overloaded function 'ToneDescVector_insert'.\n"
    "  Possible C/C++ prototypes are:\n"
    "    std::vector< pj::ToneDesc >::insert(std::vector< pj::ToneDesc >::iterator,std::vector< pj::ToneDesc >::value_type const &)\n"
    "    std::vector< pj::ToneDesc >::insert(std::vector< pj::ToneDesc >::iterator,std::vector< pj::ToneDesc >::size_type,std::vector< pj::ToneDesc >::value_type const &)\n");
  return 0;
}


SWIGINTERN PyObject *_wrap_ToneDescVector_reserve(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  std::vector< pj::ToneDesc > *arg1 = (std::vector< pj::ToneDesc > *) 0 ;
  std::vector< pj::ToneDesc >::size_type arg2 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  size_t val2 ;
  int ecode2 = 0 ;
  PyObject *swig_obj[2] ;
  
  if (!SWIG_Python_UnpackTuple(args, "ToneDescVector_reserve", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__vectorT_pj__ToneDesc_std__allocatorT_pj__ToneDesc_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "ToneDescVector_reserve" "', argument " "1"" of type '" "std::vector< pj::ToneDesc > *""'"); 
  }
  arg1 = reinterpret_cast< std::vector< pj::ToneDesc > * >(argp1);
  ecode2 = SWIG_AsVal_size_t(swig_obj[1], &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "ToneDescVector_reserve" "', argument " "2"" of type '" "std::vector< pj::ToneDesc >::size_type""'");
  } 
  arg2 = static_cast< std::vector< pj::ToneDesc >::size_type >(val2);
  (arg1)->reserve(arg2);
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_ToneDescVector_capacity(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  std::vector< pj::ToneDesc > *arg1 = (std::vector< pj::ToneDesc > *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  std::vector< pj::ToneDesc >::size_type result;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__vectorT_pj__ToneDesc_std__allocatorT_pj__ToneDesc_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "ToneDescVector_capacity" "', argument " "1"" of type '" "std::vector< pj::ToneDesc > const *""'"); 
  }
  arg1 = reinterpret_cast< std::vector< pj::ToneDesc > * >(argp1);
  result = ((std::vector< pj::ToneDesc > const *)arg1)->capacity();
  resultobj = SWIG_From_size_t(static_cast< size_t >(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_delete_ToneDescVector(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  std::vector< pj::ToneDesc > *arg1 = (std::vector< pj::ToneDesc > *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__vectorT_pj__ToneDesc_std__allocatorT_pj__ToneDesc_t_t, SWIG_POINTER_DISOWN |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "delete_ToneDescVector" "', argument " "1"" of type '" "std::vector< pj::ToneDesc > *""'"); 
  }
  arg1 = reinterpret_cast< std::vector< pj::ToneDesc > * >(argp1);
  delete arg1;
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *ToneDescVector_swigregister(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *obj;
  if (!SWIG_Python_UnpackTuple(args, "swigregister", 1, 1, &obj)) return NULL;
  SWIG_TypeNewClientData(SWIGTYPE_p_std__vectorT_pj__ToneDesc_std__allocatorT_pj__ToneDesc_t_t, SWIG_NewClientData(obj));
  return SWIG_Py_Void();
}

SWIGINTERN PyObject *ToneDescVector_swiginit(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  return SWIG_Python_InitShadowInstance(args);
}

SWIGINTERN PyObject *_wrap_ToneDigitVector_iterator(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  std::vector< pj::ToneDigit > *arg1 = (std::vector< pj::ToneDigit > *) 0 ;
  PyObject **arg2 = (PyObject **) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  swig::SwigPyIterator *result = 0 ;
  
  arg2 = &swig_obj[0];
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__vectorT_pj__ToneDigit_std__allocatorT_pj__ToneDigit_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "ToneDigitVector_iterator" "', argument " "1"" of type '" "std::vector< pj::ToneDigit > *""'"); 
  }
  arg1 = reinterpret_cast< std::vector< pj::ToneDigit > * >(argp1);
  result = (swig::SwigPyIterator *)std_vector_Sl_pj_ToneDigit_Sg__iterator(arg1,arg2);
  resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(result), SWIGTYPE_p_swig__SwigPyIterator, SWIG_POINTER_OWN |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_ToneDigitVector___nonzero__(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  std::vector< pj::ToneDigit > *arg1 = (std::vector< pj::ToneDigit > *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  bool result;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__vectorT_pj__ToneDigit_std__allocatorT_pj__ToneDigit_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "ToneDigitVector___nonzero__" "', argument " "1"" of type '" "std::vector< pj::ToneDigit > const *""'"); 
  }
  arg1 = reinterpret_cast< std::vector< pj::ToneDigit > * >(argp1);
  result = (bool)std_vector_Sl_pj_ToneDigit_Sg____nonzero__((std::vector< pj::ToneDigit > const *)arg1);
  resultobj = SWIG_From_bool(static_cast< bool >(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_ToneDigitVector___bool__(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  std::vector< pj::ToneDigit > *arg1 = (std::vector< pj::ToneDigit > *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  bool result;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__vectorT_pj__ToneDigit_std__allocatorT_pj__ToneDigit_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "ToneDigitVector___bool__" "', argument " "1"" of type '" "std::vector< pj::ToneDigit > const *""'"); 
  }
  arg1 = reinterpret_cast< std::vector< pj::ToneDigit > * >(argp1);
  result = (bool)std_vector_Sl_pj_ToneDigit_Sg____bool__((std::vector< pj::ToneDigit > const *)arg1);
  resultobj = SWIG_From_bool(static_cast< bool >(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_ToneDigitVector___len__(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  std::vector< pj::ToneDigit > *arg1 = (std::vector< pj::ToneDigit > *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  std::vector< pj::ToneDigit >::size_type result;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__vectorT_pj__ToneDigit_std__allocatorT_pj__ToneDigit_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "ToneDigitVector___len__" "', argument " "1"" of type '" "std::vector< pj::ToneDigit > const *""'"); 
  }
  arg1 = reinterpret_cast< std::vector< pj::ToneDigit > * >(argp1);
  result = std_vector_Sl_pj_ToneDigit_Sg____len__((std::vector< pj::ToneDigit > const *)arg1);
  resultobj = SWIG_From_size_t(static_cast< size_t >(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_ToneDigitVector___getslice__(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  std::vector< pj::ToneDigit > *arg1 = (std::vector< pj::ToneDigit > *) 0 ;
  std::vector< pj::ToneDigit >::difference_type arg2 ;
  std::vector< pj::ToneDigit >::difference_type arg3 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  ptrdiff_t val2 ;
  int ecode2 = 0 ;
  ptrdiff_t val3 ;
  int ecode3 = 0 ;
  PyObject *swig_obj[3] ;
  std::vector< pj::ToneDigit,std::allocator< pj::ToneDigit > > *result = 0 ;
  
  if (!SWIG_Python_UnpackTuple(args, "ToneDigitVector___getslice__", 3, 3, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__vectorT_pj__ToneDigit_std__allocatorT_pj__ToneDigit_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "ToneDigitVector___getslice__" "', argument " "1"" of type '" "std::vector< pj::ToneDigit > *""'"); 
  }
  arg1 = reinterpret_cast< std::vector< pj::ToneDigit > * >(argp1);
  ecode2 = SWIG_AsVal_ptrdiff_t(swig_obj[1], &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "ToneDigitVector___getslice__" "', argument " "2"" of type '" "std::vector< pj::ToneDigit >::difference_type""'");
  } 
  arg2 = static_cast< std::vector< pj::ToneDigit >::difference_type >(val2);
  ecode3 = SWIG_AsVal_ptrdiff_t(swig_obj[2], &val3);
  if (!SWIG_IsOK(ecode3)) {
    SWIG_exception_fail(SWIG_ArgError(ecode3), "in method '" "ToneDigitVector___getslice__" "', argument " "3"" of type '" "std::vector< pj::ToneDigit >::difference_type""'");
  } 
  arg3 = static_cast< std::vector< pj::ToneDigit >::difference_type >(val3);
  try {
    result = (std::vector< pj::ToneDigit,std::allocator< pj::ToneDigit > > *)std_vector_Sl_pj_ToneDigit_Sg____getslice__(arg1,arg2,arg3);
  } catch(std::out_of_range &_e) {
    SWIG_exception_fail(SWIG_IndexError, (&_e)->what());
  } catch(std::invalid_argument &_e) {
    SWIG_exception_fail(SWIG_ValueError, (&_e)->what());
  }
  resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(result), SWIGTYPE_p_std__vectorT_pj__ToneDigit_std__allocatorT_pj__ToneDigit_t_t, SWIG_POINTER_OWN |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_ToneDigitVector___setslice____SWIG_0(PyObject *SWIGUNUSEDPARM(self), Py_ssize_t nobjs, PyObject **swig_obj) {
  PyObject *resultobj = 0;
  std::vector< pj::ToneDigit > *arg1 = (std::vector< pj::ToneDigit > *) 0 ;
  std::vector< pj::ToneDigit >::difference_type arg2 ;
  std::vector< pj::ToneDigit >::difference_type arg3 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  ptrdiff_t val2 ;
  int ecode2 = 0 ;
  ptrdiff_t val3 ;
  int ecode3 = 0 ;
  
  if ((nobjs < 3) || (nobjs > 3)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__vectorT_pj__ToneDigit_std__allocatorT_pj__ToneDigit_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "ToneDigitVector___setslice__" "', argument " "1"" of type '" "std::vector< pj::ToneDigit > *""'"); 
  }
  arg1 = reinterpret_cast< std::vector< pj::ToneDigit > * >(argp1);
  ecode2 = SWIG_AsVal_ptrdiff_t(swig_obj[1], &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "ToneDigitVector___setslice__" "', argument " "2"" of type '" "std::vector< pj::ToneDigit >::difference_type""'");
  } 
  arg2 = static_cast< std::vector< pj::ToneDigit >::difference_type >(val2);
  ecode3 = SWIG_AsVal_ptrdiff_t(swig_obj[2], &val3);
  if (!SWIG_IsOK(ecode3)) {
    SWIG_exception_fail(SWIG_ArgError(ecode3), "in method '" "ToneDigitVector___setslice__" "', argument " "3"" of type '" "std::vector< pj::ToneDigit >::difference_type""'");
  } 
  arg3 = static_cast< std::vector< pj::ToneDigit >::difference_type >(val3);
  try {
    std_vector_Sl_pj_ToneDigit_Sg____setslice____SWIG_0(arg1,arg2,arg3);
  } catch(std::out_of_range &_e) {
    SWIG_exception_fail(SWIG_IndexError, (&_e)->what());
  } catch(std::invalid_argument &_e) {
    SWIG_exception_fail(SWIG_ValueError, (&_e)->what());
  }
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_ToneDigitVector___setslice____SWIG_1(PyObject *SWIGUNUSEDPARM(self), Py_ssize_t nobjs, PyObject **swig_obj) {
  PyObject *resultobj = 0;
  std::vector< pj::ToneDigit > *arg1 = (std::vector< pj::ToneDigit > *) 0 ;
  std::vector< pj::ToneDigit >::difference_type arg2 ;
  std::vector< pj::ToneDigit >::difference_type arg3 ;
  std::vector< pj::ToneDigit,std::allocator< pj::ToneDigit > > *arg4 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  ptrdiff_t val2 ;
  int ecode2 = 0 ;
  ptrdiff_t val3 ;
  int ecode3 = 0 ;
  int res4 = SWIG_OLDOBJ ;
  
  if ((nobjs < 4) || (nobjs > 4)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__vectorT_pj__ToneDigit_std__allocatorT_pj__ToneDigit_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "ToneDigitVector___setslice__" "', argument " "1"" of type '" "std::vector< pj::ToneDigit > *""'"); 
  }
  arg1 = reinterpret_cast< std::vector< pj::ToneDigit > * >(argp1);
  ecode2 = SWIG_AsVal_ptrdiff_t(swig_obj[1], &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "ToneDigitVector___setslice__" "', argument " "2"" of type '" "std::vector< pj::ToneDigit >::difference_type""'");
  } 
  arg2 = static_cast< std::vector< pj::ToneDigit >::difference_type >(val2);
  ecode3 = SWIG_AsVal_ptrdiff_t(swig_obj[2], &val3);
  if (!SWIG_IsOK(ecode3)) {
    SWIG_exception_fail(SWIG_ArgError(ecode3), "in method '" "ToneDigitVector___setslice__" "', argument " "3"" of type '" "std::vector< pj::ToneDigit >::difference_type""'");
  } 
  arg3 = static_cast< std::vector< pj::ToneDigit >::difference_type >(val3);
  {
    std::vector< pj::ToneDigit,std::allocator< pj::ToneDigit > > *ptr = (std::vector< pj::ToneDigit,std::allocator< pj::ToneDigit > > *)0;
    res4 = swig::asptr(swig_obj[3], &ptr);
    if (!SWIG_IsOK(res4)) {
      SWIG_exception_fail(SWIG_ArgError(res4), "in method '" "ToneDigitVector___setslice__" "', argument " "4"" of type '" "std::vector< pj::ToneDigit,std::allocator< pj::ToneDigit > > const &""'"); 
    }
    if (!ptr) {
      SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "ToneDigitVector___setslice__" "', argument " "4"" of type '" "std::vector< pj::ToneDigit,std::allocator< pj::ToneDigit > > const &""'"); 
    }
    arg4 = ptr;
  }
  try {
    std_vector_Sl_pj_ToneDigit_Sg____setslice____SWIG_1(arg1,arg2,arg3,(std::vector< pj::ToneDigit,std::allocator< pj::ToneDigit > > const &)*arg4);
  } catch(std::out_of_range &_e) {
    SWIG_exception_fail(SWIG_IndexError, (&_e)->what());
  } catch(std::invalid_argument &_e) {
    SWIG_exception_fail(SWIG_ValueError, (&_e)->what());
  }
  resultobj = SWIG_Py_Void();
  if (SWIG_IsNewObj(res4)) delete arg4;
  return resultobj;
fail:
  if (SWIG_IsNewObj(res4)) delete arg4;
  return NULL;
}


SWIGINTERN PyObject *_wrap_ToneDigitVector___setslice__(PyObject *self, PyObject *args) {
  Py_ssize_t argc;
  PyObject *argv[5] = {
    0
  };
  
  if (!(argc = SWIG_Python_UnpackTuple(args, "ToneDigitVector___setslice__", 0, 4, argv))) SWIG_fail;
  --argc;
  if (argc == 3) {
    int _v;
    int res = swig::asptr(argv[0], (std::vector< pj::ToneDigit,std::allocator< pj::ToneDigit > >**)(0));
    _v = SWIG_CheckState(res);
    if (_v) {
      {
        int res = SWIG_AsVal_ptrdiff_t(argv[1], NULL);
        _v = SWIG_CheckState(res);
      }
      if (_v) {
        {
          int res = SWIG_AsVal_ptrdiff_t(argv[2], NULL);
          _v = SWIG_CheckState(res);
        }
        if (_v) {
          return _wrap_ToneDigitVector___setslice____SWIG_0(self, argc, argv);
        }
      }
    }
  }
  if (argc == 4) {
    int _v;
    int res = swig::asptr(argv[0], (std::vector< pj::ToneDigit,std::allocator< pj::ToneDigit > >**)(0));
    _v = SWIG_CheckState(res);
    if (_v) {
      {
        int res = SWIG_AsVal_ptrdiff_t(argv[1], NULL);
        _v = SWIG_CheckState(res);
      }
      if (_v) {
        {
          int res = SWIG_AsVal_ptrdiff_t(argv[2], NULL);
          _v = SWIG_CheckState(res);
        }
        if (_v) {
          int res = swig::asptr(argv[3], (std::vector< pj::ToneDigit,std::allocator< pj::ToneDigit > >**)(0));
          _v = SWIG_CheckState(res);
          if (_v) {
            return _wrap_ToneDigitVector___setslice____SWIG_1(self, argc, argv);
          }
        }
      }
    }
  }
  
fail:
  SWIG_Python_RaiseOrModifyTypeError("Wrong number or type of arguments for overloaded function 'ToneDigitVector___setslice__'.\n"
    "  Possible C/C++ prototypes are:\n"
    "    std::vector< pj::ToneDigit >::__setslice__(std::vector< pj::ToneDigit >::difference_type,std::vector< pj::ToneDigit >::difference_type)\n"
    "    std::vector< pj::ToneDigit >::__setslice__(std::vector< pj::ToneDigit >::difference_type,std::vector< pj::ToneDigit >::difference_type,std::vector< pj::ToneDigit,std::allocator< pj::ToneDigit > > const &)\n");
  return 0;
}


SWIGINTERN PyObject *_wrap_ToneDigitVector___delslice__(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  std::vector< pj::ToneDigit > *arg1 = (std::vector< pj::ToneDigit > *) 0 ;
  std::vector< pj::ToneDigit >::difference_type arg2 ;
  std::vector< pj::ToneDigit >::difference_type arg3 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  ptrdiff_t val2 ;
  int ecode2 = 0 ;
  ptrdiff_t val3 ;
  int ecode3 = 0 ;
  PyObject *swig_obj[3] ;
  
  if (!SWIG_Python_UnpackTuple(args, "ToneDigitVector___delslice__", 3, 3, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__vectorT_pj__ToneDigit_std__allocatorT_pj__ToneDigit_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "ToneDigitVector___delslice__" "', argument " "1"" of type '" "std::vector< pj::ToneDigit > *""'"); 
  }
  arg1 = reinterpret_cast< std::vector< pj::ToneDigit > * >(argp1);
  ecode2 = SWIG_AsVal_ptrdiff_t(swig_obj[1], &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "ToneDigitVector___delslice__" "', argument " "2"" of type '" "std::vector< pj::ToneDigit >::difference_type""'");
  } 
  arg2 = static_cast< std::vector< pj::ToneDigit >::difference_type >(val2);
  ecode3 = SWIG_AsVal_ptrdiff_t(swig_obj[2], &val3);
  if (!SWIG_IsOK(ecode3)) {
    SWIG_exception_fail(SWIG_ArgError(ecode3), "in method '" "ToneDigitVector___delslice__" "', argument " "3"" of type '" "std::vector< pj::ToneDigit >::difference_type""'");
  } 
  arg3 = static_cast< std::vector< pj::ToneDigit >::difference_type >(val3);
  try {
    std_vector_Sl_pj_ToneDigit_Sg____delslice__(arg1,arg2,arg3);
  } catch(std::out_of_range &_e) {
    SWIG_exception_fail(SWIG_IndexError, (&_e)->what());
  } catch(std::invalid_argument &_e) {
    SWIG_exception_fail(SWIG_ValueError, (&_e)->what());
  }
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_ToneDigitVector___delitem____SWIG_0(PyObject *SWIGUNUSEDPARM(self), Py_ssize_t nobjs, PyObject **swig_obj) {
  PyObject *resultobj = 0;
  std::vector< pj::ToneDigit > *arg1 = (std::vector< pj::ToneDigit > *) 0 ;
  std::vector< pj::ToneDigit >::difference_type arg2 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  ptrdiff_t val2 ;
  int ecode2 = 0 ;
  
  if ((nobjs < 2) || (nobjs > 2)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__vectorT_pj__ToneDigit_std__allocatorT_pj__ToneDigit_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "ToneDigitVector___delitem__" "', argument " "1"" of type '" "std::vector< pj::ToneDigit > *""'"); 
  }
  arg1 = reinterpret_cast< std::vector< pj::ToneDigit > * >(argp1);
  ecode2 = SWIG_AsVal_ptrdiff_t(swig_obj[1], &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "ToneDigitVector___delitem__" "', argument " "2"" of type '" "std::vector< pj::ToneDigit >::difference_type""'");
  } 
  arg2 = static_cast< std::vector< pj::ToneDigit >::difference_type >(val2);
  try {
    std_vector_Sl_pj_ToneDigit_Sg____delitem____SWIG_0(arg1,arg2);
  } catch(std::out_of_range &_e) {
    SWIG_exception_fail(SWIG_IndexError, (&_e)->what());
  } catch(std::invalid_argument &_e) {
    SWIG_exception_fail(SWIG_ValueError, (&_e)->what());
  }
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_ToneDigitVector___getitem____SWIG_0(PyObject *SWIGUNUSEDPARM(self), Py_ssize_t nobjs, PyObject **swig_obj) {
  PyObject *resultobj = 0;
  std::vector< pj::ToneDigit > *arg1 = (std::vector< pj::ToneDigit > *) 0 ;
  PySliceObject *arg2 = (PySliceObject *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  std::vector< pj::ToneDigit,std::allocator< pj::ToneDigit > > *result = 0 ;
  
  if ((nobjs < 2) || (nobjs > 2)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__vectorT_pj__ToneDigit_std__allocatorT_pj__ToneDigit_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "ToneDigitVector___getitem__" "', argument " "1"" of type '" "std::vector< pj::ToneDigit > *""'"); 
  }
  arg1 = reinterpret_cast< std::vector< pj::ToneDigit > * >(argp1);
  {
    if (!PySlice_Check(swig_obj[1])) {
      SWIG_exception_fail(SWIG_ArgError(SWIG_TypeError), "in method '" "ToneDigitVector___getitem__" "', argument " "2"" of type '" "PySliceObject *""'");
    }
    arg2 = (PySliceObject *) swig_obj[1];
  }
  try {
    result = (std::vector< pj::ToneDigit,std::allocator< pj::ToneDigit > > *)std_vector_Sl_pj_ToneDigit_Sg____getitem____SWIG_0(arg1,arg2);
  } catch(std::out_of_range &_e) {
    SWIG_exception_fail(SWIG_IndexError, (&_e)->what());
  } catch(std::invalid_argument &_e) {
    SWIG_exception_fail(SWIG_ValueError, (&_e)->what());
  }
  resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(result), SWIGTYPE_p_std__vectorT_pj__ToneDigit_std__allocatorT_pj__ToneDigit_t_t, SWIG_POINTER_OWN |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_ToneDigitVector___setitem____SWIG_0(PyObject *SWIGUNUSEDPARM(self), Py_ssize_t nobjs, PyObject **swig_obj) {
  PyObject *resultobj = 0;
  std::vector< pj::ToneDigit > *arg1 = (std::vector< pj::ToneDigit > *) 0 ;
  PySliceObject *arg2 = (PySliceObject *) 0 ;
  std::vector< pj::ToneDigit,std::allocator< pj::ToneDigit > > *arg3 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  int res3 = SWIG_OLDOBJ ;
  
  if ((nobjs < 3) || (nobjs > 3)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__vectorT_pj__ToneDigit_std__allocatorT_pj__ToneDigit_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "ToneDigitVector___setitem__" "', argument " "1"" of type '" "std::vector< pj::ToneDigit > *""'"); 
  }
  arg1 = reinterpret_cast< std::vector< pj::ToneDigit > * >(argp1);
  {
    if (!PySlice_Check(swig_obj[1])) {
      SWIG_exception_fail(SWIG_ArgError(SWIG_TypeError), "in method '" "ToneDigitVector___setitem__" "', argument " "2"" of type '" "PySliceObject *""'");
    }
    arg2 = (PySliceObject *) swig_obj[1];
  }
  {
    std::vector< pj::ToneDigit,std::allocator< pj::ToneDigit > > *ptr = (std::vector< pj::ToneDigit,std::allocator< pj::ToneDigit > > *)0;
    res3 = swig::asptr(swig_obj[2], &ptr);
    if (!SWIG_IsOK(res3)) {
      SWIG_exception_fail(SWIG_ArgError(res3), "in method '" "ToneDigitVector___setitem__" "', argument " "3"" of type '" "std::vector< pj::ToneDigit,std::allocator< pj::ToneDigit > > const &""'"); 
    }
    if (!ptr) {
      SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "ToneDigitVector___setitem__" "', argument " "3"" of type '" "std::vector< pj::ToneDigit,std::allocator< pj::ToneDigit > > const &""'"); 
    }
    arg3 = ptr;
  }
  try {
    std_vector_Sl_pj_ToneDigit_Sg____setitem____SWIG_0(arg1,arg2,(std::vector< pj::ToneDigit,std::allocator< pj::ToneDigit > > const &)*arg3);
  } catch(std::out_of_range &_e) {
    SWIG_exception_fail(SWIG_IndexError, (&_e)->what());
  } catch(std::invalid_argument &_e) {
    SWIG_exception_fail(SWIG_ValueError, (&_e)->what());
  }
  resultobj = SWIG_Py_Void();
  if (SWIG_IsNewObj(res3)) delete arg3;
  return resultobj;
fail:
  if (SWIG_IsNewObj(res3)) delete arg3;
  return NULL;
}


SWIGINTERN PyObject *_wrap_ToneDigitVector___setitem____SWIG_1(PyObject *SWIGUNUSEDPARM(self), Py_ssize_t nobjs, PyObject **swig_obj) {
  PyObject *resultobj = 0;
  std::vector< pj::ToneDigit > *arg1 = (std::vector< pj::ToneDigit > *) 0 ;
  PySliceObject *arg2 = (PySliceObject *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  
  if ((nobjs < 2) || (nobjs > 2)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__vectorT_pj__ToneDigit_std__allocatorT_pj__ToneDigit_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "ToneDigitVector___setitem__" "', argument " "1"" of type '" "std::vector< pj::ToneDigit > *""'"); 
  }
  arg1 = reinterpret_cast< std::vector< pj::ToneDigit > * >(argp1);
  {
    if (!PySlice_Check(swig_obj[1])) {
      SWIG_exception_fail(SWIG_ArgError(SWIG_TypeError), "in method '" "ToneDigitVector___setitem__" "', argument " "2"" of type '" "PySliceObject *""'");
    }
    arg2 = (PySliceObject *) swig_obj[1];
  }
  try {
    std_vector_Sl_pj_ToneDigit_Sg____setitem____SWIG_1(arg1,arg2);
  } catch(std::out_of_range &_e) {
    SWIG_exception_fail(SWIG_IndexError, (&_e)->what());
  } catch(std::invalid_argument &_e) {
    SWIG_exception_fail(SWIG_ValueError, (&_e)->what());
  }
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_ToneDigitVector___delitem____SWIG_1(PyObject *SWIGUNUSEDPARM(self), Py_ssize_t nobjs, PyObject **swig_obj) {
  PyObject *resultobj = 0;
  std::vector< pj::ToneDigit > *arg1 = (std::vector< pj::ToneDigit > *) 0 ;
  PySliceObject *arg2 = (PySliceObject *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  
  if ((nobjs < 2) || (nobjs > 2)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__vectorT_pj__ToneDigit_std__allocatorT_pj__ToneDigit_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "ToneDigitVector___delitem__" "', argument " "1"" of type '" "std::vector< pj::ToneDigit > *""'"); 
  }
  arg1 = reinterpret_cast< std::vector< pj::ToneDigit > * >(argp1);
  {
    if (!PySlice_Check(swig_obj[1])) {
      SWIG_exception_fail(SWIG_ArgError(SWIG_TypeError), "in method '" "ToneDigitVector___delitem__" "', argument " "2"" of type '" "PySliceObject *""'");
    }
    arg2 = (PySliceObject *) swig_obj[1];
  }
  try {
    std_vector_Sl_pj_ToneDigit_Sg____delitem____SWIG_1(arg1,arg2);
  } catch(std::out_of_range &_e) {
    SWIG_exception_fail(SWIG_IndexError, (&_e)->what());
  } catch(std::invalid_argument &_e) {
    SWIG_exception_fail(SWIG_ValueError, (&_e)->what());
  }
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_ToneDigitVector___delitem__(PyObject *self, PyObject *args) {
  Py_ssize_t argc;
  PyObject *argv[3] = {
    0
  };
  
  if (!(argc = SWIG_Python_UnpackTuple(args, "ToneDigitVector___delitem__", 0, 2, argv))) SWIG_fail;
  --argc;
  if (argc == 2) {
    int _v;
    int res = swig::asptr(argv[0], (std::vector< pj::ToneDigit,std::allocator< pj::ToneDigit > >**)(0));
    _v = SWIG_CheckState(res);
    if (_v) {
      {
        _v = PySlice_Check(argv[1]);
      }
      if (_v) {
        return _wrap_ToneDigitVector___delitem____SWIG_1(self, argc, argv);
      }
    }
  }
  if (argc == 2) {
    int _v;
    int res = swig::asptr(argv[0], (std::vector< pj::ToneDigit,std::allocator< pj::ToneDigit > >**)(0));
    _v = SWIG_CheckState(res);
    if (_v) {
      {
        int res = SWIG_AsVal_ptrdiff_t(argv[1], NULL);
        _v = SWIG_CheckState(res);
      }
      if (_v) {
        return _wrap_ToneDigitVector___delitem____SWIG_0(self, argc, argv);
      }
    }
  }
  
fail:
  SWIG_Python_RaiseOrModifyTypeError("Wrong number or type of arguments for overloaded function 'ToneDigitVector___delitem__'.\n"
    "  Possible C/C++ prototypes are:\n"
    "    std::vector< pj::ToneDigit >::__delitem__(std::vector< pj::ToneDigit >::difference_type)\n"
    "    std::vector< pj::ToneDigit >::__delitem__(PySliceObject *)\n");
  return 0;
}


SWIGINTERN PyObject *_wrap_ToneDigitVector___getitem____SWIG_1(PyObject *SWIGUNUSEDPARM(self), Py_ssize_t nobjs, PyObject **swig_obj) {
  PyObject *resultobj = 0;
  std::vector< pj::ToneDigit > *arg1 = (std::vector< pj::ToneDigit > *) 0 ;
  std::vector< pj::ToneDigit >::difference_type arg2 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  ptrdiff_t val2 ;
  int ecode2 = 0 ;
  std::vector< pj::ToneDigit >::value_type *result = 0 ;
  
  if ((nobjs < 2) || (nobjs > 2)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__vectorT_pj__ToneDigit_std__allocatorT_pj__ToneDigit_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "ToneDigitVector___getitem__" "', argument " "1"" of type '" "std::vector< pj::ToneDigit > const *""'"); 
  }
  arg1 = reinterpret_cast< std::vector< pj::ToneDigit > * >(argp1);
  ecode2 = SWIG_AsVal_ptrdiff_t(swig_obj[1], &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "ToneDigitVector___getitem__" "', argument " "2"" of type '" "std::vector< pj::ToneDigit >::difference_type""'");
  } 
  arg2 = static_cast< std::vector< pj::ToneDigit >::difference_type >(val2);
  try {
    result = (std::vector< pj::ToneDigit >::value_type *) &std_vector_Sl_pj_ToneDigit_Sg____getitem____SWIG_1((std::vector< pj::ToneDigit > const *)arg1,arg2);
  } catch(std::out_of_range &_e) {
    SWIG_exception_fail(SWIG_IndexError, (&_e)->what());
  }
  resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(result), SWIGTYPE_p_pj__ToneDigit, 0 |  0 );
  (void)swig::container_owner<swig::traits<std::vector< pj::ToneDigit >::value_type>::category>::back_reference(resultobj, swig_obj[0]);
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_ToneDigitVector___getitem__(PyObject *self, PyObject *args) {
  Py_ssize_t argc;
  PyObject *argv[3] = {
    0
  };
  
  if (!(argc = SWIG_Python_UnpackTuple(args, "ToneDigitVector___getitem__", 0, 2, argv))) SWIG_fail;
  --argc;
  if (argc == 2) {
    int _v;
    int res = swig::asptr(argv[0], (std::vector< pj::ToneDigit,std::allocator< pj::ToneDigit > >**)(0));
    _v = SWIG_CheckState(res);
    if (_v) {
      {
        _v = PySlice_Check(argv[1]);
      }
      if (_v) {
        return _wrap_ToneDigitVector___getitem____SWIG_0(self, argc, argv);
      }
    }
  }
  if (argc == 2) {
    int _v;
    int res = swig::asptr(argv[0], (std::vector< pj::ToneDigit,std::allocator< pj::ToneDigit > >**)(0));
    _v = SWIG_CheckState(res);
    if (_v) {
      {
        int res = SWIG_AsVal_ptrdiff_t(argv[1], NULL);
        _v = SWIG_CheckState(res);
      }
      if (_v) {
        return _wrap_ToneDigitVector___getitem____SWIG_1(self, argc, argv);
      }
    }
  }
  
fail:
  SWIG_Python_RaiseOrModifyTypeError("Wrong number or type of arguments for overloaded function 'ToneDigitVector___getitem__'.\n"
    "  Possible C/C++ prototypes are:\n"
    "    std::vector< pj::ToneDigit >::__getitem__(PySliceObject *)\n"
    "    std::vector< pj::ToneDigit >::__getitem__(std::vector< pj::ToneDigit >::difference_type) const\n");
  return 0;
}


SWIGINTERN PyObject *_wrap_ToneDigitVector___setitem____SWIG_2(PyObject *SWIGUNUSEDPARM(self), Py_ssize_t nobjs, PyObject **swig_obj) {
  PyObject *resultobj = 0;
  std::vector< pj::ToneDigit > *arg1 = (std::vector< pj::ToneDigit > *) 0 ;
  std::vector< pj::ToneDigit >::difference_type arg2 ;
  std::vector< pj::ToneDigit >::value_type *arg3 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  ptrdiff_t val2 ;
  int ecode2 = 0 ;
  void *argp3 = 0 ;
  int res3 = 0 ;
  
  if ((nobjs < 3) || (nobjs > 3)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__vectorT_pj__ToneDigit_std__allocatorT_pj__ToneDigit_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "ToneDigitVector___setitem__" "', argument " "1"" of type '" "std::vector< pj::ToneDigit > *""'"); 
  }
  arg1 = reinterpret_cast< std::vector< pj::ToneDigit > * >(argp1);
  ecode2 = SWIG_AsVal_ptrdiff_t(swig_obj[1], &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "ToneDigitVector___setitem__" "', argument " "2"" of type '" "std::vector< pj::ToneDigit >::difference_type""'");
  } 
  arg2 = static_cast< std::vector< pj::ToneDigit >::difference_type >(val2);
  res3 = SWIG_ConvertPtr(swig_obj[2], &argp3, SWIGTYPE_p_pj__ToneDigit,  0  | 0);
  if (!SWIG_IsOK(res3)) {
    SWIG_exception_fail(SWIG_ArgError(res3), "in method '" "ToneDigitVector___setitem__" "', argument " "3"" of type '" "std::vector< pj::ToneDigit >::value_type const &""'"); 
  }
  if (!argp3) {
    SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "ToneDigitVector___setitem__" "', argument " "3"" of type '" "std::vector< pj::ToneDigit >::value_type const &""'"); 
  }
  arg3 = reinterpret_cast< std::vector< pj::ToneDigit >::value_type * >(argp3);
  try {
    std_vector_Sl_pj_ToneDigit_Sg____setitem____SWIG_2(arg1,arg2,(pj::ToneDigit const &)*arg3);
  } catch(std::out_of_range &_e) {
    SWIG_exception_fail(SWIG_IndexError, (&_e)->what());
  }
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_ToneDigitVector___setitem__(PyObject *self, PyObject *args) {
  Py_ssize_t argc;
  PyObject *argv[4] = {
    0
  };
  
  if (!(argc = SWIG_Python_UnpackTuple(args, "ToneDigitVector___setitem__", 0, 3, argv))) SWIG_fail;
  --argc;
  if (argc == 2) {
    int _v;
    int res = swig::asptr(argv[0], (std::vector< pj::ToneDigit,std::allocator< pj::ToneDigit > >**)(0));
    _v = SWIG_CheckState(res);
    if (_v) {
      {
        _v = PySlice_Check(argv[1]);
      }
      if (_v) {
        return _wrap_ToneDigitVector___setitem____SWIG_1(self, argc, argv);
      }
    }
  }
  if (argc == 3) {
    int _v;
    int res = swig::asptr(argv[0], (std::vector< pj::ToneDigit,std::allocator< pj::ToneDigit > >**)(0));
    _v = SWIG_CheckState(res);
    if (_v) {
      {
        _v = PySlice_Check(argv[1]);
      }
      if (_v) {
        int res = swig::asptr(argv[2], (std::vector< pj::ToneDigit,std::allocator< pj::ToneDigit > >**)(0));
        _v = SWIG_CheckState(res);
        if (_v) {
          return _wrap_ToneDigitVector___setitem____SWIG_0(self, argc, argv);
        }
      }
    }
  }
  if (argc == 3) {
    int _v;
    int res = swig::asptr(argv[0], (std::vector< pj::ToneDigit,std::allocator< pj::ToneDigit > >**)(0));
    _v = SWIG_CheckState(res);
    if (_v) {
      {
        int res = SWIG_AsVal_ptrdiff_t(argv[1], NULL);
        _v = SWIG_CheckState(res);
      }
      if (_v) {
        int res = SWIG_ConvertPtr(argv[2], 0, SWIGTYPE_p_pj__ToneDigit, SWIG_POINTER_NO_NULL | 0);
        _v = SWIG_CheckState(res);
        if (_v) {
          return _wrap_ToneDigitVector___setitem____SWIG_2(self, argc, argv);
        }
      }
    }
  }
  
fail:
  SWIG_Python_RaiseOrModifyTypeError("Wrong number or type of arguments for overloaded function 'ToneDigitVector___setitem__'.\n"
    "  Possible C/C++ prototypes are:\n"
    "    std::vector< pj::ToneDigit >::__setitem__(PySliceObject *,std::vector< pj::ToneDigit,std::allocator< pj::ToneDigit > > const &)\n"
    "    std::vector< pj::ToneDigit >::__setitem__(PySliceObject *)\n"
    "    std::vector< pj::ToneDigit >::__setitem__(std::vector< pj::ToneDigit >::difference_type,std::vector< pj::ToneDigit >::value_type const &)\n");
  return 0;
}


SWIGINTERN PyObject *_wrap_ToneDigitVector_pop(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  std::vector< pj::ToneDigit > *arg1 = (std::vector< pj::ToneDigit > *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  std::vector< pj::ToneDigit >::value_type result;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__vectorT_pj__ToneDigit_std__allocatorT_pj__ToneDigit_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "ToneDigitVector_pop" "', argument " "1"" of type '" "std::vector< pj::ToneDigit > *""'"); 
  }
  arg1 = reinterpret_cast< std::vector< pj::ToneDigit > * >(argp1);
  try {
    result = std_vector_Sl_pj_ToneDigit_Sg__pop(arg1);
  } catch(std::out_of_range &_e) {
    SWIG_exception_fail(SWIG_IndexError, (&_e)->what());
  }
  resultobj = SWIG_NewPointerObj((new std::vector< pj::ToneDigit >::value_type(static_cast< const std::vector< pj::ToneDigit >::value_type& >(result))), SWIGTYPE_p_pj__ToneDigit, SWIG_POINTER_OWN |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_ToneDigitVector_append(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  std::vector< pj::ToneDigit > *arg1 = (std::vector< pj::ToneDigit > *) 0 ;
  std::vector< pj::ToneDigit >::value_type *arg2 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  void *argp2 = 0 ;
  int res2 = 0 ;
  PyObject *swig_obj[2] ;
  
  if (!SWIG_Python_UnpackTuple(args, "ToneDigitVector_append", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__vectorT_pj__ToneDigit_std__allocatorT_pj__ToneDigit_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "ToneDigitVector_append" "', argument " "1"" of type '" "std::vector< pj::ToneDigit > *""'"); 
  }
  arg1 = reinterpret_cast< std::vector< pj::ToneDigit > * >(argp1);
  res2 = SWIG_ConvertPtr(swig_obj[1], &argp2, SWIGTYPE_p_pj__ToneDigit,  0  | 0);
  if (!SWIG_IsOK(res2)) {
    SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "ToneDigitVector_append" "', argument " "2"" of type '" "std::vector< pj::ToneDigit >::value_type const &""'"); 
  }
  if (!argp2) {
    SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "ToneDigitVector_append" "', argument " "2"" of type '" "std::vector< pj::ToneDigit >::value_type const &""'"); 
  }
  arg2 = reinterpret_cast< std::vector< pj::ToneDigit >::value_type * >(argp2);
  std_vector_Sl_pj_ToneDigit_Sg__append(arg1,(pj::ToneDigit const &)*arg2);
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_new_ToneDigitVector__SWIG_0(PyObject *SWIGUNUSEDPARM(self), Py_ssize_t nobjs, PyObject **SWIGUNUSEDPARM(swig_obj)) {
  PyObject *resultobj = 0;
  std::vector< pj::ToneDigit > *result = 0 ;
  
  if ((nobjs < 0) || (nobjs > 0)) SWIG_fail;
  result = (std::vector< pj::ToneDigit > *)new std::vector< pj::ToneDigit >();
  resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(result), SWIGTYPE_p_std__vectorT_pj__ToneDigit_std__allocatorT_pj__ToneDigit_t_t, SWIG_POINTER_NEW |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_new_ToneDigitVector__SWIG_1(PyObject *SWIGUNUSEDPARM(self), Py_ssize_t nobjs, PyObject **swig_obj) {
  PyObject *resultobj = 0;
  std::vector< pj::ToneDigit > *arg1 = 0 ;
  int res1 = SWIG_OLDOBJ ;
  std::vector< pj::ToneDigit > *result = 0 ;
  
  if ((nobjs < 1) || (nobjs > 1)) SWIG_fail;
  {
    std::vector< pj::ToneDigit,std::allocator< pj::ToneDigit > > *ptr = (std::vector< pj::ToneDigit,std::allocator< pj::ToneDigit > > *)0;
    res1 = swig::asptr(swig_obj[0], &ptr);
    if (!SWIG_IsOK(res1)) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "new_ToneDigitVector" "', argument " "1"" of type '" "std::vector< pj::ToneDigit > const &""'"); 
    }
    if (!ptr) {
      SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "new_ToneDigitVector" "', argument " "1"" of type '" "std::vector< pj::ToneDigit > const &""'"); 
    }
    arg1 = ptr;
  }
  result = (std::vector< pj::ToneDigit > *)new std::vector< pj::ToneDigit >((std::vector< pj::ToneDigit > const &)*arg1);
  resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(result), SWIGTYPE_p_std__vectorT_pj__ToneDigit_std__allocatorT_pj__ToneDigit_t_t, SWIG_POINTER_NEW |  0 );
  if (SWIG_IsNewObj(res1)) delete arg1;
  return resultobj;
fail:
  if (SWIG_IsNewObj(res1)) delete arg1;
  return NULL;
}


SWIGINTERN PyObject *_wrap_ToneDigitVector_empty(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  std::vector< pj::ToneDigit > *arg1 = (std::vector< pj::ToneDigit > *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  bool result;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__vectorT_pj__ToneDigit_std__allocatorT_pj__ToneDigit_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "ToneDigitVector_empty" "', argument " "1"" of type '" "std::vector< pj::ToneDigit > const *""'"); 
  }
  arg1 = reinterpret_cast< std::vector< pj::ToneDigit > * >(argp1);
  result = (bool)((std::vector< pj::ToneDigit > const *)arg1)->empty();
  resultobj = SWIG_From_bool(static_cast< bool >(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_ToneDigitVector_size(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  std::vector< pj::ToneDigit > *arg1 = (std::vector< pj::ToneDigit > *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  std::vector< pj::ToneDigit >::size_type result;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__vectorT_pj__ToneDigit_std__allocatorT_pj__ToneDigit_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "ToneDigitVector_size" "', argument " "1"" of type '" "std::vector< pj::ToneDigit > const *""'"); 
  }
  arg1 = reinterpret_cast< std::vector< pj::ToneDigit > * >(argp1);
  result = ((std::vector< pj::ToneDigit > const *)arg1)->size();
  resultobj = SWIG_From_size_t(static_cast< size_t >(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_ToneDigitVector_swap(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  std::vector< pj::ToneDigit > *arg1 = (std::vector< pj::ToneDigit > *) 0 ;
  std::vector< pj::ToneDigit > *arg2 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  void *argp2 = 0 ;
  int res2 = 0 ;
  PyObject *swig_obj[2] ;
  
  if (!SWIG_Python_UnpackTuple(args, "ToneDigitVector_swap", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__vectorT_pj__ToneDigit_std__allocatorT_pj__ToneDigit_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "ToneDigitVector_swap" "', argument " "1"" of type '" "std::vector< pj::ToneDigit > *""'"); 
  }
  arg1 = reinterpret_cast< std::vector< pj::ToneDigit > * >(argp1);
  res2 = SWIG_ConvertPtr(swig_obj[1], &argp2, SWIGTYPE_p_std__vectorT_pj__ToneDigit_std__allocatorT_pj__ToneDigit_t_t,  0 );
  if (!SWIG_IsOK(res2)) {
    SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "ToneDigitVector_swap" "', argument " "2"" of type '" "std::vector< pj::ToneDigit > &""'"); 
  }
  if (!argp2) {
    SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "ToneDigitVector_swap" "', argument " "2"" of type '" "std::vector< pj::ToneDigit > &""'"); 
  }
  arg2 = reinterpret_cast< std::vector< pj::ToneDigit > * >(argp2);
  (arg1)->swap(*arg2);
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_ToneDigitVector_begin(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  std::vector< pj::ToneDigit > *arg1 = (std::vector< pj::ToneDigit > *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  std::vector< pj::ToneDigit >::iterator result;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__vectorT_pj__ToneDigit_std__allocatorT_pj__ToneDigit_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "ToneDigitVector_begin" "', argument " "1"" of type '" "std::vector< pj::ToneDigit > *""'"); 
  }
  arg1 = reinterpret_cast< std::vector< pj::ToneDigit > * >(argp1);
  result = (arg1)->begin();
  resultobj = SWIG_NewPointerObj(swig::make_output_iterator(static_cast< const std::vector< pj::ToneDigit >::iterator & >(result)),
    swig::SwigPyIterator::descriptor(),SWIG_POINTER_OWN);
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_ToneDigitVector_end(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  std::vector< pj::ToneDigit > *arg1 = (std::vector< pj::ToneDigit > *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  std::vector< pj::ToneDigit >::iterator result;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__vectorT_pj__ToneDigit_std__allocatorT_pj__ToneDigit_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "ToneDigitVector_end" "', argument " "1"" of type '" "std::vector< pj::ToneDigit > *""'"); 
  }
  arg1 = reinterpret_cast< std::vector< pj::ToneDigit > * >(argp1);
  result = (arg1)->end();
  resultobj = SWIG_NewPointerObj(swig::make_output_iterator(static_cast< const std::vector< pj::ToneDigit >::iterator & >(result)),
    swig::SwigPyIterator::descriptor(),SWIG_POINTER_OWN);
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_ToneDigitVector_rbegin(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  std::vector< pj::ToneDigit > *arg1 = (std::vector< pj::ToneDigit > *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  std::vector< pj::ToneDigit >::reverse_iterator result;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__vectorT_pj__ToneDigit_std__allocatorT_pj__ToneDigit_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "ToneDigitVector_rbegin" "', argument " "1"" of type '" "std::vector< pj::ToneDigit > *""'"); 
  }
  arg1 = reinterpret_cast< std::vector< pj::ToneDigit > * >(argp1);
  result = (arg1)->rbegin();
  resultobj = SWIG_NewPointerObj(swig::make_output_iterator(static_cast< const std::vector< pj::ToneDigit >::reverse_iterator & >(result)),
    swig::SwigPyIterator::descriptor(),SWIG_POINTER_OWN);
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_ToneDigitVector_rend(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  std::vector< pj::ToneDigit > *arg1 = (std::vector< pj::ToneDigit > *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  std::vector< pj::ToneDigit >::reverse_iterator result;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__vectorT_pj__ToneDigit_std__allocatorT_pj__ToneDigit_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "ToneDigitVector_rend" "', argument " "1"" of type '" "std::vector< pj::ToneDigit > *""'"); 
  }
  arg1 = reinterpret_cast< std::vector< pj::ToneDigit > * >(argp1);
  result = (arg1)->rend();
  resultobj = SWIG_NewPointerObj(swig::make_output_iterator(static_cast< const std::vector< pj::ToneDigit >::reverse_iterator & >(result)),
    swig::SwigPyIterator::descriptor(),SWIG_POINTER_OWN);
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_ToneDigitVector_clear(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  std::vector< pj::ToneDigit > *arg1 = (std::vector< pj::ToneDigit > *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__vectorT_pj__ToneDigit_std__allocatorT_pj__ToneDigit_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "ToneDigitVector_clear" "', argument " "1"" of type '" "std::vector< pj::ToneDigit > *""'"); 
  }
  arg1 = reinterpret_cast< std::vector< pj::ToneDigit > * >(argp1);
  (arg1)->clear();
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_ToneDigitVector_get_allocator(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  std::vector< pj::ToneDigit > *arg1 = (std::vector< pj::ToneDigit > *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  SwigValueWrapper< std::allocator< pj::ToneDigit > > result;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__vectorT_pj__ToneDigit_std__allocatorT_pj__ToneDigit_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "ToneDigitVector_get_allocator" "', argument " "1"" of type '" "std::vector< pj::ToneDigit > const *""'"); 
  }
  arg1 = reinterpret_cast< std::vector< pj::ToneDigit > * >(argp1);
  result = ((std::vector< pj::ToneDigit > const *)arg1)->get_allocator();
  resultobj = SWIG_NewPointerObj((new std::vector< pj::ToneDigit >::allocator_type(static_cast< const std::vector< pj::ToneDigit >::allocator_type& >(result))), SWIGTYPE_p_std__allocatorT_pj__ToneDigit_t, SWIG_POINTER_OWN |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_new_ToneDigitVector__SWIG_2(PyObject *SWIGUNUSEDPARM(self), Py_ssize_t nobjs, PyObject **swig_obj) {
  PyObject *resultobj = 0;
  std::vector< pj::ToneDigit >::size_type arg1 ;
  size_t val1 ;
  int ecode1 = 0 ;
  std::vector< pj::ToneDigit > *result = 0 ;
  
  if ((nobjs < 1) || (nobjs > 1)) SWIG_fail;
  ecode1 = SWIG_AsVal_size_t(swig_obj[0], &val1);
  if (!SWIG_IsOK(ecode1)) {
    SWIG_exception_fail(SWIG_ArgError(ecode1), "in method '" "new_ToneDigitVector" "', argument " "1"" of type '" "std::vector< pj::ToneDigit >::size_type""'");
  } 
  arg1 = static_cast< std::vector< pj::ToneDigit >::size_type >(val1);
  result = (std::vector< pj::ToneDigit > *)new std::vector< pj::ToneDigit >(arg1);
  resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(result), SWIGTYPE_p_std__vectorT_pj__ToneDigit_std__allocatorT_pj__ToneDigit_t_t, SWIG_POINTER_NEW |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_ToneDigitVector_pop_back(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  std::vector< pj::ToneDigit > *arg1 = (std::vector< pj::ToneDigit > *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__vectorT_pj__ToneDigit_std__allocatorT_pj__ToneDigit_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "ToneDigitVector_pop_back" "', argument " "1"" of type '" "std::vector< pj::ToneDigit > *""'"); 
  }
  arg1 = reinterpret_cast< std::vector< pj::ToneDigit > * >(argp1);
  (arg1)->pop_back();
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_ToneDigitVector_resize__SWIG_0(PyObject *SWIGUNUSEDPARM(self), Py_ssize_t nobjs, PyObject **swig_obj) {
  PyObject *resultobj = 0;
  std::vector< pj::ToneDigit > *arg1 = (std::vector< pj::ToneDigit > *) 0 ;
  std::vector< pj::ToneDigit >::size_type arg2 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  size_t val2 ;
  int ecode2 = 0 ;
  
  if ((nobjs < 2) || (nobjs > 2)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__vectorT_pj__ToneDigit_std__allocatorT_pj__ToneDigit_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "ToneDigitVector_resize" "', argument " "1"" of type '" "std::vector< pj::ToneDigit > *""'"); 
  }
  arg1 = reinterpret_cast< std::vector< pj::ToneDigit > * >(argp1);
  ecode2 = SWIG_AsVal_size_t(swig_obj[1], &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "ToneDigitVector_resize" "', argument " "2"" of type '" "std::vector< pj::ToneDigit >::size_type""'");
  } 
  arg2 = static_cast< std::vector< pj::ToneDigit >::size_type >(val2);
  (arg1)->resize(arg2);
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_ToneDigitVector_erase__SWIG_0(PyObject *SWIGUNUSEDPARM(self), Py_ssize_t nobjs, PyObject **swig_obj) {
  PyObject *resultobj = 0;
  std::vector< pj::ToneDigit > *arg1 = (std::vector< pj::ToneDigit > *) 0 ;
  std::vector< pj::ToneDigit >::iterator arg2 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  swig::SwigPyIterator *iter2 = 0 ;
  int res2 ;
  std::vector< pj::ToneDigit >::iterator result;
  
  if ((nobjs < 2) || (nobjs > 2)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__vectorT_pj__ToneDigit_std__allocatorT_pj__ToneDigit_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "ToneDigitVector_erase" "', argument " "1"" of type '" "std::vector< pj::ToneDigit > *""'"); 
  }
  arg1 = reinterpret_cast< std::vector< pj::ToneDigit > * >(argp1);
  res2 = SWIG_ConvertPtr(swig_obj[1], SWIG_as_voidptrptr(&iter2), swig::SwigPyIterator::descriptor(), 0);
  if (!SWIG_IsOK(res2) || !iter2) {
    SWIG_exception_fail(SWIG_ArgError(SWIG_TypeError), "in method '" "ToneDigitVector_erase" "', argument " "2"" of type '" "std::vector< pj::ToneDigit >::iterator""'");
  } else {
    swig::SwigPyIterator_T<std::vector< pj::ToneDigit >::iterator > *iter_t = dynamic_cast<swig::SwigPyIterator_T<std::vector< pj::ToneDigit >::iterator > *>(iter2);
    if (iter_t) {
      arg2 = iter_t->get_current();
    } else {
      SWIG_exception_fail(SWIG_ArgError(SWIG_TypeError), "in method '" "ToneDigitVector_erase" "', argument " "2"" of type '" "std::vector< pj::ToneDigit >::iterator""'");
    }
  }
  result = std_vector_Sl_pj_ToneDigit_Sg__erase__SWIG_0(arg1,arg2);
  resultobj = SWIG_NewPointerObj(swig::make_output_iterator(static_cast< const std::vector< pj::ToneDigit >::iterator & >(result)),
    swig::SwigPyIterator::descriptor(),SWIG_POINTER_OWN);
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_ToneDigitVector_erase__SWIG_1(PyObject *SWIGUNUSEDPARM(self), Py_ssize_t nobjs, PyObject **swig_obj) {
  PyObject *resultobj = 0;
  std::vector< pj::ToneDigit > *arg1 = (std::vector< pj::ToneDigit > *) 0 ;
  std::vector< pj::ToneDigit >::iterator arg2 ;
  std::vector< pj::ToneDigit >::iterator arg3 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  swig::SwigPyIterator *iter2 = 0 ;
  int res2 ;
  swig::SwigPyIterator *iter3 = 0 ;
  int res3 ;
  std::vector< pj::ToneDigit >::iterator result;
  
  if ((nobjs < 3) || (nobjs > 3)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__vectorT_pj__ToneDigit_std__allocatorT_pj__ToneDigit_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "ToneDigitVector_erase" "', argument " "1"" of type '" "std::vector< pj::ToneDigit > *""'"); 
  }
  arg1 = reinterpret_cast< std::vector< pj::ToneDigit > * >(argp1);
  res2 = SWIG_ConvertPtr(swig_obj[1], SWIG_as_voidptrptr(&iter2), swig::SwigPyIterator::descriptor(), 0);
  if (!SWIG_IsOK(res2) || !iter2) {
    SWIG_exception_fail(SWIG_ArgError(SWIG_TypeError), "in method '" "ToneDigitVector_erase" "', argument " "2"" of type '" "std::vector< pj::ToneDigit >::iterator""'");
  } else {
    swig::SwigPyIterator_T<std::vector< pj::ToneDigit >::iterator > *iter_t = dynamic_cast<swig::SwigPyIterator_T<std::vector< pj::ToneDigit >::iterator > *>(iter2);
    if (iter_t) {
      arg2 = iter_t->get_current();
    } else {
      SWIG_exception_fail(SWIG_ArgError(SWIG_TypeError), "in method '" "ToneDigitVector_erase" "', argument " "2"" of type '" "std::vector< pj::ToneDigit >::iterator""'");
    }
  }
  res3 = SWIG_ConvertPtr(swig_obj[2], SWIG_as_voidptrptr(&iter3), swig::SwigPyIterator::descriptor(), 0);
  if (!SWIG_IsOK(res3) || !iter3) {
    SWIG_exception_fail(SWIG_ArgError(SWIG_TypeError), "in method '" "ToneDigitVector_erase" "', argument " "3"" of type '" "std::vector< pj::ToneDigit >::iterator""'");
  } else {
    swig::SwigPyIterator_T<std::vector< pj::ToneDigit >::iterator > *iter_t = dynamic_cast<swig::SwigPyIterator_T<std::vector< pj::ToneDigit >::iterator > *>(iter3);
    if (iter_t) {
      arg3 = iter_t->get_current();
    } else {
      SWIG_exception_fail(SWIG_ArgError(SWIG_TypeError), "in method '" "ToneDigitVector_erase" "', argument " "3"" of type '" "std::vector< pj::ToneDigit >::iterator""'");
    }
  }
  result = std_vector_Sl_pj_ToneDigit_Sg__erase__SWIG_1(arg1,arg2,arg3);
  resultobj = SWIG_NewPointerObj(swig::make_output_iterator(static_cast< const std::vector< pj::ToneDigit >::iterator & >(result)),
    swig::SwigPyIterator::descriptor(),SWIG_POINTER_OWN);
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_ToneDigitVector_erase(PyObject *self, PyObject *args) {
  Py_ssize_t argc;
  PyObject *argv[4] = {
    0
  };
  
  if (!(argc = SWIG_Python_UnpackTuple(args, "ToneDigitVector_erase", 0, 3, argv))) SWIG_fail;
  --argc;
  if (argc == 2) {
    int _v;
    int res = swig::asptr(argv[0], (std::vector< pj::ToneDigit,std::allocator< pj::ToneDigit > >**)(0));
    _v = SWIG_CheckState(res);
    if (_v) {
      swig::SwigPyIterator *iter = 0;
      int res = SWIG_ConvertPtr(argv[1], SWIG_as_voidptrptr(&iter), swig::SwigPyIterator::descriptor(), 0);
      _v = (SWIG_IsOK(res) && iter && (dynamic_cast<swig::SwigPyIterator_T<std::vector< pj::ToneDigit >::iterator > *>(iter) != 0));
      if (_v) {
        return _wrap_ToneDigitVector_erase__SWIG_0(self, argc, argv);
      }
    }
  }
  if (argc == 3) {
    int _v;
    int res = swig::asptr(argv[0], (std::vector< pj::ToneDigit,std::allocator< pj::ToneDigit > >**)(0));
    _v = SWIG_CheckState(res);
    if (_v) {
      swig::SwigPyIterator *iter = 0;
      int res = SWIG_ConvertPtr(argv[1], SWIG_as_voidptrptr(&iter), swig::SwigPyIterator::descriptor(), 0);
      _v = (SWIG_IsOK(res) && iter && (dynamic_cast<swig::SwigPyIterator_T<std::vector< pj::ToneDigit >::iterator > *>(iter) != 0));
      if (_v) {
        swig::SwigPyIterator *iter = 0;
        int res = SWIG_ConvertPtr(argv[2], SWIG_as_voidptrptr(&iter), swig::SwigPyIterator::descriptor(), 0);
        _v = (SWIG_IsOK(res) && iter && (dynamic_cast<swig::SwigPyIterator_T<std::vector< pj::ToneDigit >::iterator > *>(iter) != 0));
        if (_v) {
          return _wrap_ToneDigitVector_erase__SWIG_1(self, argc, argv);
        }
      }
    }
  }
  
fail:
  SWIG_Python_RaiseOrModifyTypeError("Wrong number or type of arguments for overloaded function 'ToneDigitVector_erase'.\n"
    "  Possible C/C++ prototypes are:\n"
    "    std::vector< pj::ToneDigit >::erase(std::vector< pj::ToneDigit >::iterator)\n"
    "    std::vector< pj::ToneDigit >::erase(std::vector< pj::ToneDigit >::iterator,std::vector< pj::ToneDigit >::iterator)\n");
  return 0;
}


SWIGINTERN PyObject *_wrap_new_ToneDigitVector__SWIG_3(PyObject *SWIGUNUSEDPARM(self), Py_ssize_t nobjs, PyObject **swig_obj) {
  PyObject *resultobj = 0;
  std::vector< pj::ToneDigit >::size_type arg1 ;
  std::vector< pj::ToneDigit >::value_type *arg2 = 0 ;
  size_t val1 ;
  int ecode1 = 0 ;
  void *argp2 = 0 ;
  int res2 = 0 ;
  std::vector< pj::ToneDigit > *result = 0 ;
  
  if ((nobjs < 2) || (nobjs > 2)) SWIG_fail;
  ecode1 = SWIG_AsVal_size_t(swig_obj[0], &val1);
  if (!SWIG_IsOK(ecode1)) {
    SWIG_exception_fail(SWIG_ArgError(ecode1), "in method '" "new_ToneDigitVector" "', argument " "1"" of type '" "std::vector< pj::ToneDigit >::size_type""'");
  } 
  arg1 = static_cast< std::vector< pj::ToneDigit >::size_type >(val1);
  res2 = SWIG_ConvertPtr(swig_obj[1], &argp2, SWIGTYPE_p_pj__ToneDigit,  0  | 0);
  if (!SWIG_IsOK(res2)) {
    SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "new_ToneDigitVector" "', argument " "2"" of type '" "std::vector< pj::ToneDigit >::value_type const &""'"); 
  }
  if (!argp2) {
    SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "new_ToneDigitVector" "', argument " "2"" of type '" "std::vector< pj::ToneDigit >::value_type const &""'"); 
  }
  arg2 = reinterpret_cast< std::vector< pj::ToneDigit >::value_type * >(argp2);
  result = (std::vector< pj::ToneDigit > *)new std::vector< pj::ToneDigit >(arg1,(std::vector< pj::ToneDigit >::value_type const &)*arg2);
  resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(result), SWIGTYPE_p_std__vectorT_pj__ToneDigit_std__allocatorT_pj__ToneDigit_t_t, SWIG_POINTER_NEW |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_new_ToneDigitVector(PyObject *self, PyObject *args) {
  Py_ssize_t argc;
  PyObject *argv[3] = {
    0
  };
  
  if (!(argc = SWIG_Python_UnpackTuple(args, "new_ToneDigitVector", 0, 2, argv))) SWIG_fail;
  --argc;
  if (argc == 0) {
    return _wrap_new_ToneDigitVector__SWIG_0(self, argc, argv);
  }
  if (argc == 1) {
    int _v;
    {
      int res = SWIG_AsVal_size_t(argv[0], NULL);
      _v = SWIG_CheckState(res);
    }
    if (_v) {
      return _wrap_new_ToneDigitVector__SWIG_2(self, argc, argv);
    }
  }
  if (argc == 1) {
    int _v;
    int res = swig::asptr(argv[0], (std::vector< pj::ToneDigit,std::allocator< pj::ToneDigit > >**)(0));
    _v = SWIG_CheckState(res);
    if (_v) {
      return _wrap_new_ToneDigitVector__SWIG_1(self, argc, argv);
    }
  }
  if (argc == 2) {
    int _v;
    {
      int res = SWIG_AsVal_size_t(argv[0], NULL);
      _v = SWIG_CheckState(res);
    }
    if (_v) {
      int res = SWIG_ConvertPtr(argv[1], 0, SWIGTYPE_p_pj__ToneDigit, SWIG_POINTER_NO_NULL | 0);
      _v = SWIG_CheckState(res);
      if (_v) {
        return _wrap_new_ToneDigitVector__SWIG_3(self, argc, argv);
      }
    }
  }
  
fail:
  SWIG_Python_RaiseOrModifyTypeError("Wrong number or type of arguments for overloaded function 'new_ToneDigitVector'.\n"
    "  Possible C/C++ prototypes are:\n"
    "    std::vector< pj::ToneDigit >::vector()\n"
    "    std::vector< pj::ToneDigit >::vector(std::vector< pj::ToneDigit > const &)\n"
    "    std::vector< pj::ToneDigit >::vector(std::vector< pj::ToneDigit >::size_type)\n"
    "    std::vector< pj::ToneDigit >::vector(std::vector< pj::ToneDigit >::size_type,std::vector< pj::ToneDigit >::value_type const &)\n");
  return 0;
}


SWIGINTERN PyObject *_wrap_ToneDigitVector_push_back(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  std::vector< pj::ToneDigit > *arg1 = (std::vector< pj::ToneDigit > *) 0 ;
  std::vector< pj::ToneDigit >::value_type *arg2 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  void *argp2 = 0 ;
  int res2 = 0 ;
  PyObject *swig_obj[2] ;
  
  if (!SWIG_Python_UnpackTuple(args, "ToneDigitVector_push_back", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__vectorT_pj__ToneDigit_std__allocatorT_pj__ToneDigit_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "ToneDigitVector_push_back" "', argument " "1"" of type '" "std::vector< pj::ToneDigit > *""'"); 
  }
  arg1 = reinterpret_cast< std::vector< pj::ToneDigit > * >(argp1);
  res2 = SWIG_ConvertPtr(swig_obj[1], &argp2, SWIGTYPE_p_pj__ToneDigit,  0  | 0);
  if (!SWIG_IsOK(res2)) {
    SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "ToneDigitVector_push_back" "', argument " "2"" of type '" "std::vector< pj::ToneDigit >::value_type const &""'"); 
  }
  if (!argp2) {
    SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "ToneDigitVector_push_back" "', argument " "2"" of type '" "std::vector< pj::ToneDigit >::value_type const &""'"); 
  }
  arg2 = reinterpret_cast< std::vector< pj::ToneDigit >::value_type * >(argp2);
  (arg1)->push_back((std::vector< pj::ToneDigit >::value_type const &)*arg2);
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_ToneDigitVector_front(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  std::vector< pj::ToneDigit > *arg1 = (std::vector< pj::ToneDigit > *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  std::vector< pj::ToneDigit >::value_type *result = 0 ;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__vectorT_pj__ToneDigit_std__allocatorT_pj__ToneDigit_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "ToneDigitVector_front" "', argument " "1"" of type '" "std::vector< pj::ToneDigit > const *""'"); 
  }
  arg1 = reinterpret_cast< std::vector< pj::ToneDigit > * >(argp1);
  result = (std::vector< pj::ToneDigit >::value_type *) &((std::vector< pj::ToneDigit > const *)arg1)->front();
  resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(result), SWIGTYPE_p_pj__ToneDigit, 0 |  0 );
  (void)swig::container_owner<swig::traits<std::vector< pj::ToneDigit >::value_type>::category>::back_reference(resultobj, swig_obj[0]);
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_ToneDigitVector_back(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  std::vector< pj::ToneDigit > *arg1 = (std::vector< pj::ToneDigit > *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  std::vector< pj::ToneDigit >::value_type *result = 0 ;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__vectorT_pj__ToneDigit_std__allocatorT_pj__ToneDigit_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "ToneDigitVector_back" "', argument " "1"" of type '" "std::vector< pj::ToneDigit > const *""'"); 
  }
  arg1 = reinterpret_cast< std::vector< pj::ToneDigit > * >(argp1);
  result = (std::vector< pj::ToneDigit >::value_type *) &((std::vector< pj::ToneDigit > const *)arg1)->back();
  resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(result), SWIGTYPE_p_pj__ToneDigit, 0 |  0 );
  (void)swig::container_owner<swig::traits<std::vector< pj::ToneDigit >::value_type>::category>::back_reference(resultobj, swig_obj[0]);
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_ToneDigitVector_assign(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  std::vector< pj::ToneDigit > *arg1 = (std::vector< pj::ToneDigit > *) 0 ;
  std::vector< pj::ToneDigit >::size_type arg2 ;
  std::vector< pj::ToneDigit >::value_type *arg3 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  size_t val2 ;
  int ecode2 = 0 ;
  void *argp3 = 0 ;
  int res3 = 0 ;
  PyObject *swig_obj[3] ;
  
  if (!SWIG_Python_UnpackTuple(args, "ToneDigitVector_assign", 3, 3, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__vectorT_pj__ToneDigit_std__allocatorT_pj__ToneDigit_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "ToneDigitVector_assign" "', argument " "1"" of type '" "std::vector< pj::ToneDigit > *""'"); 
  }
  arg1 = reinterpret_cast< std::vector< pj::ToneDigit > * >(argp1);
  ecode2 = SWIG_AsVal_size_t(swig_obj[1], &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "ToneDigitVector_assign" "', argument " "2"" of type '" "std::vector< pj::ToneDigit >::size_type""'");
  } 
  arg2 = static_cast< std::vector< pj::ToneDigit >::size_type >(val2);
  res3 = SWIG_ConvertPtr(swig_obj[2], &argp3, SWIGTYPE_p_pj__ToneDigit,  0  | 0);
  if (!SWIG_IsOK(res3)) {
    SWIG_exception_fail(SWIG_ArgError(res3), "in method '" "ToneDigitVector_assign" "', argument " "3"" of type '" "std::vector< pj::ToneDigit >::value_type const &""'"); 
  }
  if (!argp3) {
    SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "ToneDigitVector_assign" "', argument " "3"" of type '" "std::vector< pj::ToneDigit >::value_type const &""'"); 
  }
  arg3 = reinterpret_cast< std::vector< pj::ToneDigit >::value_type * >(argp3);
  (arg1)->assign(arg2,(std::vector< pj::ToneDigit >::value_type const &)*arg3);
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_ToneDigitVector_resize__SWIG_1(PyObject *SWIGUNUSEDPARM(self), Py_ssize_t nobjs, PyObject **swig_obj) {
  PyObject *resultobj = 0;
  std::vector< pj::ToneDigit > *arg1 = (std::vector< pj::ToneDigit > *) 0 ;
  std::vector< pj::ToneDigit >::size_type arg2 ;
  std::vector< pj::ToneDigit >::value_type *arg3 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  size_t val2 ;
  int ecode2 = 0 ;
  void *argp3 = 0 ;
  int res3 = 0 ;
  
  if ((nobjs < 3) || (nobjs > 3)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__vectorT_pj__ToneDigit_std__allocatorT_pj__ToneDigit_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "ToneDigitVector_resize" "', argument " "1"" of type '" "std::vector< pj::ToneDigit > *""'"); 
  }
  arg1 = reinterpret_cast< std::vector< pj::ToneDigit > * >(argp1);
  ecode2 = SWIG_AsVal_size_t(swig_obj[1], &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "ToneDigitVector_resize" "', argument " "2"" of type '" "std::vector< pj::ToneDigit >::size_type""'");
  } 
  arg2 = static_cast< std::vector< pj::ToneDigit >::size_type >(val2);
  res3 = SWIG_ConvertPtr(swig_obj[2], &argp3, SWIGTYPE_p_pj__ToneDigit,  0  | 0);
  if (!SWIG_IsOK(res3)) {
    SWIG_exception_fail(SWIG_ArgError(res3), "in method '" "ToneDigitVector_resize" "', argument " "3"" of type '" "std::vector< pj::ToneDigit >::value_type const &""'"); 
  }
  if (!argp3) {
    SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "ToneDigitVector_resize" "', argument " "3"" of type '" "std::vector< pj::ToneDigit >::value_type const &""'"); 
  }
  arg3 = reinterpret_cast< std::vector< pj::ToneDigit >::value_type * >(argp3);
  (arg1)->resize(arg2,(std::vector< pj::ToneDigit >::value_type const &)*arg3);
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_ToneDigitVector_resize(PyObject *self, PyObject *args) {
  Py_ssize_t argc;
  PyObject *argv[4] = {
    0
  };
  
  if (!(argc = SWIG_Python_UnpackTuple(args, "ToneDigitVector_resize", 0, 3, argv))) SWIG_fail;
  --argc;
  if (argc == 2) {
    int _v;
    int res = swig::asptr(argv[0], (std::vector< pj::ToneDigit,std::allocator< pj::ToneDigit > >**)(0));
    _v = SWIG_CheckState(res);
    if (_v) {
      {
        int res = SWIG_AsVal_size_t(argv[1], NULL);
        _v = SWIG_CheckState(res);
      }
      if (_v) {
        return _wrap_ToneDigitVector_resize__SWIG_0(self, argc, argv);
      }
    }
  }
  if (argc == 3) {
    int _v;
    int res = swig::asptr(argv[0], (std::vector< pj::ToneDigit,std::allocator< pj::ToneDigit > >**)(0));
    _v = SWIG_CheckState(res);
    if (_v) {
      {
        int res = SWIG_AsVal_size_t(argv[1], NULL);
        _v = SWIG_CheckState(res);
      }
      if (_v) {
        int res = SWIG_ConvertPtr(argv[2], 0, SWIGTYPE_p_pj__ToneDigit, SWIG_POINTER_NO_NULL | 0);
        _v = SWIG_CheckState(res);
        if (_v) {
          return _wrap_ToneDigitVector_resize__SWIG_1(self, argc, argv);
        }
      }
    }
  }
  
fail:
  SWIG_Python_RaiseOrModifyTypeError("Wrong number or type of arguments for overloaded function 'ToneDigitVector_resize'.\n"
    "  Possible C/C++ prototypes are:\n"
    "    std::vector< pj::ToneDigit >::resize(std::vector< pj::ToneDigit >::size_type)\n"
    "    std::vector< pj::ToneDigit >::resize(std::vector< pj::ToneDigit >::size_type,std::vector< pj::ToneDigit >::value_type const &)\n");
  return 0;
}


SWIGINTERN PyObject *_wrap_ToneDigitVector_insert__SWIG_0(PyObject *SWIGUNUSEDPARM(self), Py_ssize_t nobjs, PyObject **swig_obj) {
  PyObject *resultobj = 0;
  std::vector< pj::ToneDigit > *arg1 = (std::vector< pj::ToneDigit > *) 0 ;
  std::vector< pj::ToneDigit >::iterator arg2 ;
  std::vector< pj::ToneDigit >::value_type *arg3 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  swig::SwigPyIterator *iter2 = 0 ;
  int res2 ;
  void *argp3 = 0 ;
  int res3 = 0 ;
  std::vector< pj::ToneDigit >::iterator result;
  
  if ((nobjs < 3) || (nobjs > 3)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__vectorT_pj__ToneDigit_std__allocatorT_pj__ToneDigit_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "ToneDigitVector_insert" "', argument " "1"" of type '" "std::vector< pj::ToneDigit > *""'"); 
  }
  arg1 = reinterpret_cast< std::vector< pj::ToneDigit > * >(argp1);
  res2 = SWIG_ConvertPtr(swig_obj[1], SWIG_as_voidptrptr(&iter2), swig::SwigPyIterator::descriptor(), 0);
  if (!SWIG_IsOK(res2) || !iter2) {
    SWIG_exception_fail(SWIG_ArgError(SWIG_TypeError), "in method '" "ToneDigitVector_insert" "', argument " "2"" of type '" "std::vector< pj::ToneDigit >::iterator""'");
  } else {
    swig::SwigPyIterator_T<std::vector< pj::ToneDigit >::iterator > *iter_t = dynamic_cast<swig::SwigPyIterator_T<std::vector< pj::ToneDigit >::iterator > *>(iter2);
    if (iter_t) {
      arg2 = iter_t->get_current();
    } else {
      SWIG_exception_fail(SWIG_ArgError(SWIG_TypeError), "in method '" "ToneDigitVector_insert" "', argument " "2"" of type '" "std::vector< pj::ToneDigit >::iterator""'");
    }
  }
  res3 = SWIG_ConvertPtr(swig_obj[2], &argp3, SWIGTYPE_p_pj__ToneDigit,  0  | 0);
  if (!SWIG_IsOK(res3)) {
    SWIG_exception_fail(SWIG_ArgError(res3), "in method '" "ToneDigitVector_insert" "', argument " "3"" of type '" "std::vector< pj::ToneDigit >::value_type const &""'"); 
  }
  if (!argp3) {
    SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "ToneDigitVector_insert" "', argument " "3"" of type '" "std::vector< pj::ToneDigit >::value_type const &""'"); 
  }
  arg3 = reinterpret_cast< std::vector< pj::ToneDigit >::value_type * >(argp3);
  result = std_vector_Sl_pj_ToneDigit_Sg__insert__SWIG_0(arg1,arg2,(pj::ToneDigit const &)*arg3);
  resultobj = SWIG_NewPointerObj(swig::make_output_iterator(static_cast< const std::vector< pj::ToneDigit >::iterator & >(result)),
    swig::SwigPyIterator::descriptor(),SWIG_POINTER_OWN);
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_ToneDigitVector_insert__SWIG_1(PyObject *SWIGUNUSEDPARM(self), Py_ssize_t nobjs, PyObject **swig_obj) {
  PyObject *resultobj = 0;
  std::vector< pj::ToneDigit > *arg1 = (std::vector< pj::ToneDigit > *) 0 ;
  std::vector< pj::ToneDigit >::iterator arg2 ;
  std::vector< pj::ToneDigit >::size_type arg3 ;
  std::vector< pj::ToneDigit >::value_type *arg4 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  swig::SwigPyIterator *iter2 = 0 ;
  int res2 ;
  size_t val3 ;
  int ecode3 = 0 ;
  void *argp4 = 0 ;
  int res4 = 0 ;
  
  if ((nobjs < 4) || (nobjs > 4)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__vectorT_pj__ToneDigit_std__allocatorT_pj__ToneDigit_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "ToneDigitVector_insert" "', argument " "1"" of type '" "std::vector< pj::ToneDigit > *""'"); 
  }
  arg1 = reinterpret_cast< std::vector< pj::ToneDigit > * >(argp1);
  res2 = SWIG_ConvertPtr(swig_obj[1], SWIG_as_voidptrptr(&iter2), swig::SwigPyIterator::descriptor(), 0);
  if (!SWIG_IsOK(res2) || !iter2) {
    SWIG_exception_fail(SWIG_ArgError(SWIG_TypeError), "in method '" "ToneDigitVector_insert" "', argument " "2"" of type '" "std::vector< pj::ToneDigit >::iterator""'");
  } else {
    swig::SwigPyIterator_T<std::vector< pj::ToneDigit >::iterator > *iter_t = dynamic_cast<swig::SwigPyIterator_T<std::vector< pj::ToneDigit >::iterator > *>(iter2);
    if (iter_t) {
      arg2 = iter_t->get_current();
    } else {
      SWIG_exception_fail(SWIG_ArgError(SWIG_TypeError), "in method '" "ToneDigitVector_insert" "', argument " "2"" of type '" "std::vector< pj::ToneDigit >::iterator""'");
    }
  }
  ecode3 = SWIG_AsVal_size_t(swig_obj[2], &val3);
  if (!SWIG_IsOK(ecode3)) {
    SWIG_exception_fail(SWIG_ArgError(ecode3), "in method '" "ToneDigitVector_insert" "', argument " "3"" of type '" "std::vector< pj::ToneDigit >::size_type""'");
  } 
  arg3 = static_cast< std::vector< pj::ToneDigit >::size_type >(val3);
  res4 = SWIG_ConvertPtr(swig_obj[3], &argp4, SWIGTYPE_p_pj__ToneDigit,  0  | 0);
  if (!SWIG_IsOK(res4)) {
    SWIG_exception_fail(SWIG_ArgError(res4), "in method '" "ToneDigitVector_insert" "', argument " "4"" of type '" "std::vector< pj::ToneDigit >::value_type const &""'"); 
  }
  if (!argp4) {
    SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "ToneDigitVector_insert" "', argument " "4"" of type '" "std::vector< pj::ToneDigit >::value_type const &""'"); 
  }
  arg4 = reinterpret_cast< std::vector< pj::ToneDigit >::value_type * >(argp4);
  std_vector_Sl_pj_ToneDigit_Sg__insert__SWIG_1(arg1,arg2,arg3,(pj::ToneDigit const &)*arg4);
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_ToneDigitVector_insert(PyObject *self, PyObject *args) {
  Py_ssize_t argc;
  PyObject *argv[5] = {
    0
  };
  
  if (!(argc = SWIG_Python_UnpackTuple(args, "ToneDigitVector_insert", 0, 4, argv))) SWIG_fail;
  --argc;
  if (argc == 3) {
    int _v;
    int res = swig::asptr(argv[0], (std::vector< pj::ToneDigit,std::allocator< pj::ToneDigit > >**)(0));
    _v = SWIG_CheckState(res);
    if (_v) {
      swig::SwigPyIterator *iter = 0;
      int res = SWIG_ConvertPtr(argv[1], SWIG_as_voidptrptr(&iter), swig::SwigPyIterator::descriptor(), 0);
      _v = (SWIG_IsOK(res) && iter && (dynamic_cast<swig::SwigPyIterator_T<std::vector< pj::ToneDigit >::iterator > *>(iter) != 0));
      if (_v) {
        int res = SWIG_ConvertPtr(argv[2], 0, SWIGTYPE_p_pj__ToneDigit, SWIG_POINTER_NO_NULL | 0);
        _v = SWIG_CheckState(res);
        if (_v) {
          return _wrap_ToneDigitVector_insert__SWIG_0(self, argc, argv);
        }
      }
    }
  }
  if (argc == 4) {
    int _v;
    int res = swig::asptr(argv[0], (std::vector< pj::ToneDigit,std::allocator< pj::ToneDigit > >**)(0));
    _v = SWIG_CheckState(res);
    if (_v) {
      swig::SwigPyIterator *iter = 0;
      int res = SWIG_ConvertPtr(argv[1], SWIG_as_voidptrptr(&iter), swig::SwigPyIterator::descriptor(), 0);
      _v = (SWIG_IsOK(res) && iter && (dynamic_cast<swig::SwigPyIterator_T<std::vector< pj::ToneDigit >::iterator > *>(iter) != 0));
      if (_v) {
        {
          int res = SWIG_AsVal_size_t(argv[2], NULL);
          _v = SWIG_CheckState(res);
        }
        if (_v) {
          int res = SWIG_ConvertPtr(argv[3], 0, SWIGTYPE_p_pj__ToneDigit, SWIG_POINTER_NO_NULL | 0);
          _v = SWIG_CheckState(res);
          if (_v) {
            return _wrap_ToneDigitVector_insert__SWIG_1(self, argc, argv);
          }
        }
      }
    }
  }
  
fail:
  SWIG_Python_RaiseOrModifyTypeError("Wrong number or type of arguments for overloaded function 'ToneDigitVector_insert'.\n"
    "  Possible C/C++ prototypes are:\n"
    "    std::vector< pj::ToneDigit >::insert(std::vector< pj::ToneDigit >::iterator,std::vector< pj::ToneDigit >::value_type const &)\n"
    "    std::vector< pj::ToneDigit >::insert(std::vector< pj::ToneDigit >::iterator,std::vector< pj::ToneDigit >::size_type,std::vector< pj::ToneDigit >::value_type const &)\n");
  return 0;
}


SWIGINTERN PyObject *_wrap_ToneDigitVector_reserve(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  std::vector< pj::ToneDigit > *arg1 = (std::vector< pj::ToneDigit > *) 0 ;
  std::vector< pj::ToneDigit >::size_type arg2 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  size_t val2 ;
  int ecode2 = 0 ;
  PyObject *swig_obj[2] ;
  
  if (!SWIG_Python_UnpackTuple(args, "ToneDigitVector_reserve", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__vectorT_pj__ToneDigit_std__allocatorT_pj__ToneDigit_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "ToneDigitVector_reserve" "', argument " "1"" of type '" "std::vector< pj::ToneDigit > *""'"); 
  }
  arg1 = reinterpret_cast< std::vector< pj::ToneDigit > * >(argp1);
  ecode2 = SWIG_AsVal_size_t(swig_obj[1], &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "ToneDigitVector_reserve" "', argument " "2"" of type '" "std::vector< pj::ToneDigit >::size_type""'");
  } 
  arg2 = static_cast< std::vector< pj::ToneDigit >::size_type >(val2);
  (arg1)->reserve(arg2);
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_ToneDigitVector_capacity(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  std::vector< pj::ToneDigit > *arg1 = (std::vector< pj::ToneDigit > *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  std::vector< pj::ToneDigit >::size_type result;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__vectorT_pj__ToneDigit_std__allocatorT_pj__ToneDigit_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "ToneDigitVector_capacity" "', argument " "1"" of type '" "std::vector< pj::ToneDigit > const *""'"); 
  }
  arg1 = reinterpret_cast< std::vector< pj::ToneDigit > * >(argp1);
  result = ((std::vector< pj::ToneDigit > const *)arg1)->capacity();
  resultobj = SWIG_From_size_t(static_cast< size_t >(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_delete_ToneDigitVector(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  std::vector< pj::ToneDigit > *arg1 = (std::vector< pj::ToneDigit > *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__vectorT_pj__ToneDigit_std__allocatorT_pj__ToneDigit_t_t, SWIG_POINTER_DISOWN |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "delete_ToneDigitVector" "', argument " "1"" of type '" "std::vector< pj::ToneDigit > *""'"); 
  }
  arg1 = reinterpret_cast< std::vector< pj::ToneDigit > * >(argp1);
  delete arg1;
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *ToneDigitVector_swigregister(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *obj;
  if (!SWIG_Python_UnpackTuple(args, "swigregister", 1, 1, &obj)) return NULL;
  SWIG_TypeNewClientData(SWIGTYPE_p_std__vectorT_pj__ToneDigit_std__allocatorT_pj__ToneDigit_t_t, SWIG_NewClientData(obj));
  return SWIG_Py_Void();
}

SWIGINTERN PyObject *ToneDigitVector_swiginit(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  return SWIG_Python_InitShadowInstance(args);
}

SWIGINTERN PyObject *_wrap_ToneDigitMapVector_iterator(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  std::vector< pj::ToneDigitMapDigit > *arg1 = (std::vector< pj::ToneDigitMapDigit > *) 0 ;
  PyObject **arg2 = (PyObject **) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  swig::SwigPyIterator *result = 0 ;
  
  arg2 = &swig_obj[0];
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__vectorT_pj__ToneDigitMapDigit_std__allocatorT_pj__ToneDigitMapDigit_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "ToneDigitMapVector_iterator" "', argument " "1"" of type '" "std::vector< pj::ToneDigitMapDigit > *""'"); 
  }
  arg1 = reinterpret_cast< std::vector< pj::ToneDigitMapDigit > * >(argp1);
  result = (swig::SwigPyIterator *)std_vector_Sl_pj_ToneDigitMapDigit_Sg__iterator(arg1,arg2);
  resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(result), SWIGTYPE_p_swig__SwigPyIterator, SWIG_POINTER_OWN |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_ToneDigitMapVector___nonzero__(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  std::vector< pj::ToneDigitMapDigit > *arg1 = (std::vector< pj::ToneDigitMapDigit > *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  bool result;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__vectorT_pj__ToneDigitMapDigit_std__allocatorT_pj__ToneDigitMapDigit_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "ToneDigitMapVector___nonzero__" "', argument " "1"" of type '" "std::vector< pj::ToneDigitMapDigit > const *""'"); 
  }
  arg1 = reinterpret_cast< std::vector< pj::ToneDigitMapDigit > * >(argp1);
  result = (bool)std_vector_Sl_pj_ToneDigitMapDigit_Sg____nonzero__((std::vector< pj::ToneDigitMapDigit > const *)arg1);
  resultobj = SWIG_From_bool(static_cast< bool >(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_ToneDigitMapVector___bool__(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  std::vector< pj::ToneDigitMapDigit > *arg1 = (std::vector< pj::ToneDigitMapDigit > *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  bool result;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__vectorT_pj__ToneDigitMapDigit_std__allocatorT_pj__ToneDigitMapDigit_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "ToneDigitMapVector___bool__" "', argument " "1"" of type '" "std::vector< pj::ToneDigitMapDigit > const *""'"); 
  }
  arg1 = reinterpret_cast< std::vector< pj::ToneDigitMapDigit > * >(argp1);
  result = (bool)std_vector_Sl_pj_ToneDigitMapDigit_Sg____bool__((std::vector< pj::ToneDigitMapDigit > const *)arg1);
  resultobj = SWIG_From_bool(static_cast< bool >(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_ToneDigitMapVector___len__(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  std::vector< pj::ToneDigitMapDigit > *arg1 = (std::vector< pj::ToneDigitMapDigit > *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  std::vector< pj::ToneDigitMapDigit >::size_type result;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__vectorT_pj__ToneDigitMapDigit_std__allocatorT_pj__ToneDigitMapDigit_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "ToneDigitMapVector___len__" "', argument " "1"" of type '" "std::vector< pj::ToneDigitMapDigit > const *""'"); 
  }
  arg1 = reinterpret_cast< std::vector< pj::ToneDigitMapDigit > * >(argp1);
  result = std_vector_Sl_pj_ToneDigitMapDigit_Sg____len__((std::vector< pj::ToneDigitMapDigit > const *)arg1);
  resultobj = SWIG_From_size_t(static_cast< size_t >(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_ToneDigitMapVector___getslice__(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  std::vector< pj::ToneDigitMapDigit > *arg1 = (std::vector< pj::ToneDigitMapDigit > *) 0 ;
  std::vector< pj::ToneDigitMapDigit >::difference_type arg2 ;
  std::vector< pj::ToneDigitMapDigit >::difference_type arg3 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  ptrdiff_t val2 ;
  int ecode2 = 0 ;
  ptrdiff_t val3 ;
  int ecode3 = 0 ;
  PyObject *swig_obj[3] ;
  std::vector< pj::ToneDigitMapDigit,std::allocator< pj::ToneDigitMapDigit > > *result = 0 ;
  
  if (!SWIG_Python_UnpackTuple(args, "ToneDigitMapVector___getslice__", 3, 3, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__vectorT_pj__ToneDigitMapDigit_std__allocatorT_pj__ToneDigitMapDigit_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "ToneDigitMapVector___getslice__" "', argument " "1"" of type '" "std::vector< pj::ToneDigitMapDigit > *""'"); 
  }
  arg1 = reinterpret_cast< std::vector< pj::ToneDigitMapDigit > * >(argp1);
  ecode2 = SWIG_AsVal_ptrdiff_t(swig_obj[1], &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "ToneDigitMapVector___getslice__" "', argument " "2"" of type '" "std::vector< pj::ToneDigitMapDigit >::difference_type""'");
  } 
  arg2 = static_cast< std::vector< pj::ToneDigitMapDigit >::difference_type >(val2);
  ecode3 = SWIG_AsVal_ptrdiff_t(swig_obj[2], &val3);
  if (!SWIG_IsOK(ecode3)) {
    SWIG_exception_fail(SWIG_ArgError(ecode3), "in method '" "ToneDigitMapVector___getslice__" "', argument " "3"" of type '" "std::vector< pj::ToneDigitMapDigit >::difference_type""'");
  } 
  arg3 = static_cast< std::vector< pj::ToneDigitMapDigit >::difference_type >(val3);
  try {
    result = (std::vector< pj::ToneDigitMapDigit,std::allocator< pj::ToneDigitMapDigit > > *)std_vector_Sl_pj_ToneDigitMapDigit_Sg____getslice__(arg1,arg2,arg3);
  } catch(std::out_of_range &_e) {
    SWIG_exception_fail(SWIG_IndexError, (&_e)->what());
  } catch(std::invalid_argument &_e) {
    SWIG_exception_fail(SWIG_ValueError, (&_e)->what());
  }
  resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(result), SWIGTYPE_p_std__vectorT_pj__ToneDigitMapDigit_std__allocatorT_pj__ToneDigitMapDigit_t_t, SWIG_POINTER_OWN |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_ToneDigitMapVector___setslice____SWIG_0(PyObject *SWIGUNUSEDPARM(self), Py_ssize_t nobjs, PyObject **swig_obj) {
  PyObject *resultobj = 0;
  std::vector< pj::ToneDigitMapDigit > *arg1 = (std::vector< pj::ToneDigitMapDigit > *) 0 ;
  std::vector< pj::ToneDigitMapDigit >::difference_type arg2 ;
  std::vector< pj::ToneDigitMapDigit >::difference_type arg3 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  ptrdiff_t val2 ;
  int ecode2 = 0 ;
  ptrdiff_t val3 ;
  int ecode3 = 0 ;
  
  if ((nobjs < 3) || (nobjs > 3)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__vectorT_pj__ToneDigitMapDigit_std__allocatorT_pj__ToneDigitMapDigit_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "ToneDigitMapVector___setslice__" "', argument " "1"" of type '" "std::vector< pj::ToneDigitMapDigit > *""'"); 
  }
  arg1 = reinterpret_cast< std::vector< pj::ToneDigitMapDigit > * >(argp1);
  ecode2 = SWIG_AsVal_ptrdiff_t(swig_obj[1], &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "ToneDigitMapVector___setslice__" "', argument " "2"" of type '" "std::vector< pj::ToneDigitMapDigit >::difference_type""'");
  } 
  arg2 = static_cast< std::vector< pj::ToneDigitMapDigit >::difference_type >(val2);
  ecode3 = SWIG_AsVal_ptrdiff_t(swig_obj[2], &val3);
  if (!SWIG_IsOK(ecode3)) {
    SWIG_exception_fail(SWIG_ArgError(ecode3), "in method '" "ToneDigitMapVector___setslice__" "', argument " "3"" of type '" "std::vector< pj::ToneDigitMapDigit >::difference_type""'");
  } 
  arg3 = static_cast< std::vector< pj::ToneDigitMapDigit >::difference_type >(val3);
  try {
    std_vector_Sl_pj_ToneDigitMapDigit_Sg____setslice____SWIG_0(arg1,arg2,arg3);
  } catch(std::out_of_range &_e) {
    SWIG_exception_fail(SWIG_IndexError, (&_e)->what());
  } catch(std::invalid_argument &_e) {
    SWIG_exception_fail(SWIG_ValueError, (&_e)->what());
  }
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_ToneDigitMapVector___setslice____SWIG_1(PyObject *SWIGUNUSEDPARM(self), Py_ssize_t nobjs, PyObject **swig_obj) {
  PyObject *resultobj = 0;
  std::vector< pj::ToneDigitMapDigit > *arg1 = (std::vector< pj::ToneDigitMapDigit > *) 0 ;
  std::vector< pj::ToneDigitMapDigit >::difference_type arg2 ;
  std::vector< pj::ToneDigitMapDigit >::difference_type arg3 ;
  std::vector< pj::ToneDigitMapDigit,std::allocator< pj::ToneDigitMapDigit > > *arg4 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  ptrdiff_t val2 ;
  int ecode2 = 0 ;
  ptrdiff_t val3 ;
  int ecode3 = 0 ;
  int res4 = SWIG_OLDOBJ ;
  
  if ((nobjs < 4) || (nobjs > 4)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__vectorT_pj__ToneDigitMapDigit_std__allocatorT_pj__ToneDigitMapDigit_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "ToneDigitMapVector___setslice__" "', argument " "1"" of type '" "std::vector< pj::ToneDigitMapDigit > *""'"); 
  }
  arg1 = reinterpret_cast< std::vector< pj::ToneDigitMapDigit > * >(argp1);
  ecode2 = SWIG_AsVal_ptrdiff_t(swig_obj[1], &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "ToneDigitMapVector___setslice__" "', argument " "2"" of type '" "std::vector< pj::ToneDigitMapDigit >::difference_type""'");
  } 
  arg2 = static_cast< std::vector< pj::ToneDigitMapDigit >::difference_type >(val2);
  ecode3 = SWIG_AsVal_ptrdiff_t(swig_obj[2], &val3);
  if (!SWIG_IsOK(ecode3)) {
    SWIG_exception_fail(SWIG_ArgError(ecode3), "in method '" "ToneDigitMapVector___setslice__" "', argument " "3"" of type '" "std::vector< pj::ToneDigitMapDigit >::difference_type""'");
  } 
  arg3 = static_cast< std::vector< pj::ToneDigitMapDigit >::difference_type >(val3);
  {
    std::vector< pj::ToneDigitMapDigit,std::allocator< pj::ToneDigitMapDigit > > *ptr = (std::vector< pj::ToneDigitMapDigit,std::allocator< pj::ToneDigitMapDigit > > *)0;
    res4 = swig::asptr(swig_obj[3], &ptr);
    if (!SWIG_IsOK(res4)) {
      SWIG_exception_fail(SWIG_ArgError(res4), "in method '" "ToneDigitMapVector___setslice__" "', argument " "4"" of type '" "std::vector< pj::ToneDigitMapDigit,std::allocator< pj::ToneDigitMapDigit > > const &""'"); 
    }
    if (!ptr) {
      SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "ToneDigitMapVector___setslice__" "', argument " "4"" of type '" "std::vector< pj::ToneDigitMapDigit,std::allocator< pj::ToneDigitMapDigit > > const &""'"); 
    }
    arg4 = ptr;
  }
  try {
    std_vector_Sl_pj_ToneDigitMapDigit_Sg____setslice____SWIG_1(arg1,arg2,arg3,(std::vector< pj::ToneDigitMapDigit,std::allocator< pj::ToneDigitMapDigit > > const &)*arg4);
  } catch(std::out_of_range &_e) {
    SWIG_exception_fail(SWIG_IndexError, (&_e)->what());
  } catch(std::invalid_argument &_e) {
    SWIG_exception_fail(SWIG_ValueError, (&_e)->what());
  }
  resultobj = SWIG_Py_Void();
  if (SWIG_IsNewObj(res4)) delete arg4;
  return resultobj;
fail:
  if (SWIG_IsNewObj(res4)) delete arg4;
  return NULL;
}


SWIGINTERN PyObject *_wrap_ToneDigitMapVector___setslice__(PyObject *self, PyObject *args) {
  Py_ssize_t argc;
  PyObject *argv[5] = {
    0
  };
  
  if (!(argc = SWIG_Python_UnpackTuple(args, "ToneDigitMapVector___setslice__", 0, 4, argv))) SWIG_fail;
  --argc;
  if (argc == 3) {
    int _v;
    int res = swig::asptr(argv[0], (std::vector< pj::ToneDigitMapDigit,std::allocator< pj::ToneDigitMapDigit > >**)(0));
    _v = SWIG_CheckState(res);
    if (_v) {
      {
        int res = SWIG_AsVal_ptrdiff_t(argv[1], NULL);
        _v = SWIG_CheckState(res);
      }
      if (_v) {
        {
          int res = SWIG_AsVal_ptrdiff_t(argv[2], NULL);
          _v = SWIG_CheckState(res);
        }
        if (_v) {
          return _wrap_ToneDigitMapVector___setslice____SWIG_0(self, argc, argv);
        }
      }
    }
  }
  if (argc == 4) {
    int _v;
    int res = swig::asptr(argv[0], (std::vector< pj::ToneDigitMapDigit,std::allocator< pj::ToneDigitMapDigit > >**)(0));
    _v = SWIG_CheckState(res);
    if (_v) {
      {
        int res = SWIG_AsVal_ptrdiff_t(argv[1], NULL);
        _v = SWIG_CheckState(res);
      }
      if (_v) {
        {
          int res = SWIG_AsVal_ptrdiff_t(argv[2], NULL);
          _v = SWIG_CheckState(res);
        }
        if (_v) {
          int res = swig::asptr(argv[3], (std::vector< pj::ToneDigitMapDigit,std::allocator< pj::ToneDigitMapDigit > >**)(0));
          _v = SWIG_CheckState(res);
          if (_v) {
            return _wrap_ToneDigitMapVector___setslice____SWIG_1(self, argc, argv);
          }
        }
      }
    }
  }
  
fail:
  SWIG_Python_RaiseOrModifyTypeError("Wrong number or type of arguments for overloaded function 'ToneDigitMapVector___setslice__'.\n"
    "  Possible C/C++ prototypes are:\n"
    "    std::vector< pj::ToneDigitMapDigit >::__setslice__(std::vector< pj::ToneDigitMapDigit >::difference_type,std::vector< pj::ToneDigitMapDigit >::difference_type)\n"
    "    std::vector< pj::ToneDigitMapDigit >::__setslice__(std::vector< pj::ToneDigitMapDigit >::difference_type,std::vector< pj::ToneDigitMapDigit >::difference_type,std::vector< pj::ToneDigitMapDigit,std::allocator< pj::ToneDigitMapDigit > > const &)\n");
  return 0;
}


SWIGINTERN PyObject *_wrap_ToneDigitMapVector___delslice__(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  std::vector< pj::ToneDigitMapDigit > *arg1 = (std::vector< pj::ToneDigitMapDigit > *) 0 ;
  std::vector< pj::ToneDigitMapDigit >::difference_type arg2 ;
  std::vector< pj::ToneDigitMapDigit >::difference_type arg3 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  ptrdiff_t val2 ;
  int ecode2 = 0 ;
  ptrdiff_t val3 ;
  int ecode3 = 0 ;
  PyObject *swig_obj[3] ;
  
  if (!SWIG_Python_UnpackTuple(args, "ToneDigitMapVector___delslice__", 3, 3, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__vectorT_pj__ToneDigitMapDigit_std__allocatorT_pj__ToneDigitMapDigit_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "ToneDigitMapVector___delslice__" "', argument " "1"" of type '" "std::vector< pj::ToneDigitMapDigit > *""'"); 
  }
  arg1 = reinterpret_cast< std::vector< pj::ToneDigitMapDigit > * >(argp1);
  ecode2 = SWIG_AsVal_ptrdiff_t(swig_obj[1], &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "ToneDigitMapVector___delslice__" "', argument " "2"" of type '" "std::vector< pj::ToneDigitMapDigit >::difference_type""'");
  } 
  arg2 = static_cast< std::vector< pj::ToneDigitMapDigit >::difference_type >(val2);
  ecode3 = SWIG_AsVal_ptrdiff_t(swig_obj[2], &val3);
  if (!SWIG_IsOK(ecode3)) {
    SWIG_exception_fail(SWIG_ArgError(ecode3), "in method '" "ToneDigitMapVector___delslice__" "', argument " "3"" of type '" "std::vector< pj::ToneDigitMapDigit >::difference_type""'");
  } 
  arg3 = static_cast< std::vector< pj::ToneDigitMapDigit >::difference_type >(val3);
  try {
    std_vector_Sl_pj_ToneDigitMapDigit_Sg____delslice__(arg1,arg2,arg3);
  } catch(std::out_of_range &_e) {
    SWIG_exception_fail(SWIG_IndexError, (&_e)->what());
  } catch(std::invalid_argument &_e) {
    SWIG_exception_fail(SWIG_ValueError, (&_e)->what());
  }
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_ToneDigitMapVector___delitem____SWIG_0(PyObject *SWIGUNUSEDPARM(self), Py_ssize_t nobjs, PyObject **swig_obj) {
  PyObject *resultobj = 0;
  std::vector< pj::ToneDigitMapDigit > *arg1 = (std::vector< pj::ToneDigitMapDigit > *) 0 ;
  std::vector< pj::ToneDigitMapDigit >::difference_type arg2 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  ptrdiff_t val2 ;
  int ecode2 = 0 ;
  
  if ((nobjs < 2) || (nobjs > 2)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__vectorT_pj__ToneDigitMapDigit_std__allocatorT_pj__ToneDigitMapDigit_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "ToneDigitMapVector___delitem__" "', argument " "1"" of type '" "std::vector< pj::ToneDigitMapDigit > *""'"); 
  }
  arg1 = reinterpret_cast< std::vector< pj::ToneDigitMapDigit > * >(argp1);
  ecode2 = SWIG_AsVal_ptrdiff_t(swig_obj[1], &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "ToneDigitMapVector___delitem__" "', argument " "2"" of type '" "std::vector< pj::ToneDigitMapDigit >::difference_type""'");
  } 
  arg2 = static_cast< std::vector< pj::ToneDigitMapDigit >::difference_type >(val2);
  try {
    std_vector_Sl_pj_ToneDigitMapDigit_Sg____delitem____SWIG_0(arg1,arg2);
  } catch(std::out_of_range &_e) {
    SWIG_exception_fail(SWIG_IndexError, (&_e)->what());
  } catch(std::invalid_argument &_e) {
    SWIG_exception_fail(SWIG_ValueError, (&_e)->what());
  }
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_ToneDigitMapVector___getitem____SWIG_0(PyObject *SWIGUNUSEDPARM(self), Py_ssize_t nobjs, PyObject **swig_obj) {
  PyObject *resultobj = 0;
  std::vector< pj::ToneDigitMapDigit > *arg1 = (std::vector< pj::ToneDigitMapDigit > *) 0 ;
  PySliceObject *arg2 = (PySliceObject *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  std::vector< pj::ToneDigitMapDigit,std::allocator< pj::ToneDigitMapDigit > > *result = 0 ;
  
  if ((nobjs < 2) || (nobjs > 2)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__vectorT_pj__ToneDigitMapDigit_std__allocatorT_pj__ToneDigitMapDigit_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "ToneDigitMapVector___getitem__" "', argument " "1"" of type '" "std::vector< pj::ToneDigitMapDigit > *""'"); 
  }
  arg1 = reinterpret_cast< std::vector< pj::ToneDigitMapDigit > * >(argp1);
  {
    if (!PySlice_Check(swig_obj[1])) {
      SWIG_exception_fail(SWIG_ArgError(SWIG_TypeError), "in method '" "ToneDigitMapVector___getitem__" "', argument " "2"" of type '" "PySliceObject *""'");
    }
    arg2 = (PySliceObject *) swig_obj[1];
  }
  try {
    result = (std::vector< pj::ToneDigitMapDigit,std::allocator< pj::ToneDigitMapDigit > > *)std_vector_Sl_pj_ToneDigitMapDigit_Sg____getitem____SWIG_0(arg1,arg2);
  } catch(std::out_of_range &_e) {
    SWIG_exception_fail(SWIG_IndexError, (&_e)->what());
  } catch(std::invalid_argument &_e) {
    SWIG_exception_fail(SWIG_ValueError, (&_e)->what());
  }
  resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(result), SWIGTYPE_p_std__vectorT_pj__ToneDigitMapDigit_std__allocatorT_pj__ToneDigitMapDigit_t_t, SWIG_POINTER_OWN |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_ToneDigitMapVector___setitem____SWIG_0(PyObject *SWIGUNUSEDPARM(self), Py_ssize_t nobjs, PyObject **swig_obj) {
  PyObject *resultobj = 0;
  std::vector< pj::ToneDigitMapDigit > *arg1 = (std::vector< pj::ToneDigitMapDigit > *) 0 ;
  PySliceObject *arg2 = (PySliceObject *) 0 ;
  std::vector< pj::ToneDigitMapDigit,std::allocator< pj::ToneDigitMapDigit > > *arg3 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  int res3 = SWIG_OLDOBJ ;
  
  if ((nobjs < 3) || (nobjs > 3)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__vectorT_pj__ToneDigitMapDigit_std__allocatorT_pj__ToneDigitMapDigit_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "ToneDigitMapVector___setitem__" "', argument " "1"" of type '" "std::vector< pj::ToneDigitMapDigit > *""'"); 
  }
  arg1 = reinterpret_cast< std::vector< pj::ToneDigitMapDigit > * >(argp1);
  {
    if (!PySlice_Check(swig_obj[1])) {
      SWIG_exception_fail(SWIG_ArgError(SWIG_TypeError), "in method '" "ToneDigitMapVector___setitem__" "', argument " "2"" of type '" "PySliceObject *""'");
    }
    arg2 = (PySliceObject *) swig_obj[1];
  }
  {
    std::vector< pj::ToneDigitMapDigit,std::allocator< pj::ToneDigitMapDigit > > *ptr = (std::vector< pj::ToneDigitMapDigit,std::allocator< pj::ToneDigitMapDigit > > *)0;
    res3 = swig::asptr(swig_obj[2], &ptr);
    if (!SWIG_IsOK(res3)) {
      SWIG_exception_fail(SWIG_ArgError(res3), "in method '" "ToneDigitMapVector___setitem__" "', argument " "3"" of type '" "std::vector< pj::ToneDigitMapDigit,std::allocator< pj::ToneDigitMapDigit > > const &""'"); 
    }
    if (!ptr) {
      SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "ToneDigitMapVector___setitem__" "', argument " "3"" of type '" "std::vector< pj::ToneDigitMapDigit,std::allocator< pj::ToneDigitMapDigit > > const &""'"); 
    }
    arg3 = ptr;
  }
  try {
    std_vector_Sl_pj_ToneDigitMapDigit_Sg____setitem____SWIG_0(arg1,arg2,(std::vector< pj::ToneDigitMapDigit,std::allocator< pj::ToneDigitMapDigit > > const &)*arg3);
  } catch(std::out_of_range &_e) {
    SWIG_exception_fail(SWIG_IndexError, (&_e)->what());
  } catch(std::invalid_argument &_e) {
    SWIG_exception_fail(SWIG_ValueError, (&_e)->what());
  }
  resultobj = SWIG_Py_Void();
  if (SWIG_IsNewObj(res3)) delete arg3;
  return resultobj;
fail:
  if (SWIG_IsNewObj(res3)) delete arg3;
  return NULL;
}


SWIGINTERN PyObject *_wrap_ToneDigitMapVector___setitem____SWIG_1(PyObject *SWIGUNUSEDPARM(self), Py_ssize_t nobjs, PyObject **swig_obj) {
  PyObject *resultobj = 0;
  std::vector< pj::ToneDigitMapDigit > *arg1 = (std::vector< pj::ToneDigitMapDigit > *) 0 ;
  PySliceObject *arg2 = (PySliceObject *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  
  if ((nobjs < 2) || (nobjs > 2)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__vectorT_pj__ToneDigitMapDigit_std__allocatorT_pj__ToneDigitMapDigit_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "ToneDigitMapVector___setitem__" "', argument " "1"" of type '" "std::vector< pj::ToneDigitMapDigit > *""'"); 
  }
  arg1 = reinterpret_cast< std::vector< pj::ToneDigitMapDigit > * >(argp1);
  {
    if (!PySlice_Check(swig_obj[1])) {
      SWIG_exception_fail(SWIG_ArgError(SWIG_TypeError), "in method '" "ToneDigitMapVector___setitem__" "', argument " "2"" of type '" "PySliceObject *""'");
    }
    arg2 = (PySliceObject *) swig_obj[1];
  }
  try {
    std_vector_Sl_pj_ToneDigitMapDigit_Sg____setitem____SWIG_1(arg1,arg2);
  } catch(std::out_of_range &_e) {
    SWIG_exception_fail(SWIG_IndexError, (&_e)->what());
  } catch(std::invalid_argument &_e) {
    SWIG_exception_fail(SWIG_ValueError, (&_e)->what());
  }
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_ToneDigitMapVector___delitem____SWIG_1(PyObject *SWIGUNUSEDPARM(self), Py_ssize_t nobjs, PyObject **swig_obj) {
  PyObject *resultobj = 0;
  std::vector< pj::ToneDigitMapDigit > *arg1 = (std::vector< pj::ToneDigitMapDigit > *) 0 ;
  PySliceObject *arg2 = (PySliceObject *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  
  if ((nobjs < 2) || (nobjs > 2)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__vectorT_pj__ToneDigitMapDigit_std__allocatorT_pj__ToneDigitMapDigit_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "ToneDigitMapVector___delitem__" "', argument " "1"" of type '" "std::vector< pj::ToneDigitMapDigit > *""'"); 
  }
  arg1 = reinterpret_cast< std::vector< pj::ToneDigitMapDigit > * >(argp1);
  {
    if (!PySlice_Check(swig_obj[1])) {
      SWIG_exception_fail(SWIG_ArgError(SWIG_TypeError), "in method '" "ToneDigitMapVector___delitem__" "', argument " "2"" of type '" "PySliceObject *""'");
    }
    arg2 = (PySliceObject *) swig_obj[1];
  }
  try {
    std_vector_Sl_pj_ToneDigitMapDigit_Sg____delitem____SWIG_1(arg1,arg2);
  } catch(std::out_of_range &_e) {
    SWIG_exception_fail(SWIG_IndexError, (&_e)->what());
  } catch(std::invalid_argument &_e) {
    SWIG_exception_fail(SWIG_ValueError, (&_e)->what());
  }
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_ToneDigitMapVector___delitem__(PyObject *self, PyObject *args) {
  Py_ssize_t argc;
  PyObject *argv[3] = {
    0
  };
  
  if (!(argc = SWIG_Python_UnpackTuple(args, "ToneDigitMapVector___delitem__", 0, 2, argv))) SWIG_fail;
  --argc;
  if (argc == 2) {
    int _v;
    int res = swig::asptr(argv[0], (std::vector< pj::ToneDigitMapDigit,std::allocator< pj::ToneDigitMapDigit > >**)(0));
    _v = SWIG_CheckState(res);
    if (_v) {
      {
        _v = PySlice_Check(argv[1]);
      }
      if (_v) {
        return _wrap_ToneDigitMapVector___delitem____SWIG_1(self, argc, argv);
      }
    }
  }
  if (argc == 2) {
    int _v;
    int res = swig::asptr(argv[0], (std::vector< pj::ToneDigitMapDigit,std::allocator< pj::ToneDigitMapDigit > >**)(0));
    _v = SWIG_CheckState(res);
    if (_v) {
      {
        int res = SWIG_AsVal_ptrdiff_t(argv[1], NULL);
        _v = SWIG_CheckState(res);
      }
      if (_v) {
        return _wrap_ToneDigitMapVector___delitem____SWIG_0(self, argc, argv);
      }
    }
  }
  
fail:
  SWIG_Python_RaiseOrModifyTypeError("Wrong number or type of arguments for overloaded function 'ToneDigitMapVector___delitem__'.\n"
    "  Possible C/C++ prototypes are:\n"
    "    std::vector< pj::ToneDigitMapDigit >::__delitem__(std::vector< pj::ToneDigitMapDigit >::difference_type)\n"
    "    std::vector< pj::ToneDigitMapDigit >::__delitem__(PySliceObject *)\n");
  return 0;
}


SWIGINTERN PyObject *_wrap_ToneDigitMapVector___getitem____SWIG_1(PyObject *SWIGUNUSEDPARM(self), Py_ssize_t nobjs, PyObject **swig_obj) {
  PyObject *resultobj = 0;
  std::vector< pj::ToneDigitMapDigit > *arg1 = (std::vector< pj::ToneDigitMapDigit > *) 0 ;
  std::vector< pj::ToneDigitMapDigit >::difference_type arg2 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  ptrdiff_t val2 ;
  int ecode2 = 0 ;
  std::vector< pj::ToneDigitMapDigit >::value_type *result = 0 ;
  
  if ((nobjs < 2) || (nobjs > 2)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__vectorT_pj__ToneDigitMapDigit_std__allocatorT_pj__ToneDigitMapDigit_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "ToneDigitMapVector___getitem__" "', argument " "1"" of type '" "std::vector< pj::ToneDigitMapDigit > const *""'"); 
  }
  arg1 = reinterpret_cast< std::vector< pj::ToneDigitMapDigit > * >(argp1);
  ecode2 = SWIG_AsVal_ptrdiff_t(swig_obj[1], &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "ToneDigitMapVector___getitem__" "', argument " "2"" of type '" "std::vector< pj::ToneDigitMapDigit >::difference_type""'");
  } 
  arg2 = static_cast< std::vector< pj::ToneDigitMapDigit >::difference_type >(val2);
  try {
    result = (std::vector< pj::ToneDigitMapDigit >::value_type *) &std_vector_Sl_pj_ToneDigitMapDigit_Sg____getitem____SWIG_1((std::vector< pj::ToneDigitMapDigit > const *)arg1,arg2);
  } catch(std::out_of_range &_e) {
    SWIG_exception_fail(SWIG_IndexError, (&_e)->what());
  }
  resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(result), SWIGTYPE_p_pj__ToneDigitMapDigit, 0 |  0 );
  (void)swig::container_owner<swig::traits<std::vector< pj::ToneDigitMapDigit >::value_type>::category>::back_reference(resultobj, swig_obj[0]);
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_ToneDigitMapVector___getitem__(PyObject *self, PyObject *args) {
  Py_ssize_t argc;
  PyObject *argv[3] = {
    0
  };
  
  if (!(argc = SWIG_Python_UnpackTuple(args, "ToneDigitMapVector___getitem__", 0, 2, argv))) SWIG_fail;
  --argc;
  if (argc == 2) {
    int _v;
    int res = swig::asptr(argv[0], (std::vector< pj::ToneDigitMapDigit,std::allocator< pj::ToneDigitMapDigit > >**)(0));
    _v = SWIG_CheckState(res);
    if (_v) {
      {
        _v = PySlice_Check(argv[1]);
      }
      if (_v) {
        return _wrap_ToneDigitMapVector___getitem____SWIG_0(self, argc, argv);
      }
    }
  }
  if (argc == 2) {
    int _v;
    int res = swig::asptr(argv[0], (std::vector< pj::ToneDigitMapDigit,std::allocator< pj::ToneDigitMapDigit > >**)(0));
    _v = SWIG_CheckState(res);
    if (_v) {
      {
        int res = SWIG_AsVal_ptrdiff_t(argv[1], NULL);
        _v = SWIG_CheckState(res);
      }
      if (_v) {
        return _wrap_ToneDigitMapVector___getitem____SWIG_1(self, argc, argv);
      }
    }
  }
  
fail:
  SWIG_Python_RaiseOrModifyTypeError("Wrong number or type of arguments for overloaded function 'ToneDigitMapVector___getitem__'.\n"
    "  Possible C/C++ prototypes are:\n"
    "    std::vector< pj::ToneDigitMapDigit >::__getitem__(PySliceObject *)\n"
    "    std::vector< pj::ToneDigitMapDigit >::__getitem__(std::vector< pj::ToneDigitMapDigit >::difference_type) const\n");
  return 0;
}


SWIGINTERN PyObject *_wrap_ToneDigitMapVector___setitem____SWIG_2(PyObject *SWIGUNUSEDPARM(self), Py_ssize_t nobjs, PyObject **swig_obj) {
  PyObject *resultobj = 0;
  std::vector< pj::ToneDigitMapDigit > *arg1 = (std::vector< pj::ToneDigitMapDigit > *) 0 ;
  std::vector< pj::ToneDigitMapDigit >::difference_type arg2 ;
  std::vector< pj::ToneDigitMapDigit >::value_type *arg3 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  ptrdiff_t val2 ;
  int ecode2 = 0 ;
  void *argp3 = 0 ;
  int res3 = 0 ;
  
  if ((nobjs < 3) || (nobjs > 3)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__vectorT_pj__ToneDigitMapDigit_std__allocatorT_pj__ToneDigitMapDigit_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "ToneDigitMapVector___setitem__" "', argument " "1"" of type '" "std::vector< pj::ToneDigitMapDigit > *""'"); 
  }
  arg1 = reinterpret_cast< std::vector< pj::ToneDigitMapDigit > * >(argp1);
  ecode2 = SWIG_AsVal_ptrdiff_t(swig_obj[1], &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "ToneDigitMapVector___setitem__" "', argument " "2"" of type '" "std::vector< pj::ToneDigitMapDigit >::difference_type""'");
  } 
  arg2 = static_cast< std::vector< pj::ToneDigitMapDigit >::difference_type >(val2);
  res3 = SWIG_ConvertPtr(swig_obj[2], &argp3, SWIGTYPE_p_pj__ToneDigitMapDigit,  0  | 0);
  if (!SWIG_IsOK(res3)) {
    SWIG_exception_fail(SWIG_ArgError(res3), "in method '" "ToneDigitMapVector___setitem__" "', argument " "3"" of type '" "std::vector< pj::ToneDigitMapDigit >::value_type const &""'"); 
  }
  if (!argp3) {
    SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "ToneDigitMapVector___setitem__" "', argument " "3"" of type '" "std::vector< pj::ToneDigitMapDigit >::value_type const &""'"); 
  }
  arg3 = reinterpret_cast< std::vector< pj::ToneDigitMapDigit >::value_type * >(argp3);
  try {
    std_vector_Sl_pj_ToneDigitMapDigit_Sg____setitem____SWIG_2(arg1,arg2,(pj::ToneDigitMapDigit const &)*arg3);
  } catch(std::out_of_range &_e) {
    SWIG_exception_fail(SWIG_IndexError, (&_e)->what());
  }
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_ToneDigitMapVector___setitem__(PyObject *self, PyObject *args) {
  Py_ssize_t argc;
  PyObject *argv[4] = {
    0
  };
  
  if (!(argc = SWIG_Python_UnpackTuple(args, "ToneDigitMapVector___setitem__", 0, 3, argv))) SWIG_fail;
  --argc;
  if (argc == 2) {
    int _v;
    int res = swig::asptr(argv[0], (std::vector< pj::ToneDigitMapDigit,std::allocator< pj::ToneDigitMapDigit > >**)(0));
    _v = SWIG_CheckState(res);
    if (_v) {
      {
        _v = PySlice_Check(argv[1]);
      }
      if (_v) {
        return _wrap_ToneDigitMapVector___setitem____SWIG_1(self, argc, argv);
      }
    }
  }
  if (argc == 3) {
    int _v;
    int res = swig::asptr(argv[0], (std::vector< pj::ToneDigitMapDigit,std::allocator< pj::ToneDigitMapDigit > >**)(0));
    _v = SWIG_CheckState(res);
    if (_v) {
      {
        _v = PySlice_Check(argv[1]);
      }
      if (_v) {
        int res = swig::asptr(argv[2], (std::vector< pj::ToneDigitMapDigit,std::allocator< pj::ToneDigitMapDigit > >**)(0));
        _v = SWIG_CheckState(res);
        if (_v) {
          return _wrap_ToneDigitMapVector___setitem____SWIG_0(self, argc, argv);
        }
      }
    }
  }
  if (argc == 3) {
    int _v;
    int res = swig::asptr(argv[0], (std::vector< pj::ToneDigitMapDigit,std::allocator< pj::ToneDigitMapDigit > >**)(0));
    _v = SWIG_CheckState(res);
    if (_v) {
      {
        int res = SWIG_AsVal_ptrdiff_t(argv[1], NULL);
        _v = SWIG_CheckState(res);
      }
      if (_v) {
        int res = SWIG_ConvertPtr(argv[2], 0, SWIGTYPE_p_pj__ToneDigitMapDigit, SWIG_POINTER_NO_NULL | 0);
        _v = SWIG_CheckState(res);
        if (_v) {
          return _wrap_ToneDigitMapVector___setitem____SWIG_2(self, argc, argv);
        }
      }
    }
  }
  
fail:
  SWIG_Python_RaiseOrModifyTypeError("Wrong number or type of arguments for overloaded function 'ToneDigitMapVector___setitem__'.\n"
    "  Possible C/C++ prototypes are:\n"
    "    std::vector< pj::ToneDigitMapDigit >::__setitem__(PySliceObject *,std::vector< pj::ToneDigitMapDigit,std::allocator< pj::ToneDigitMapDigit > > const &)\n"
    "    std::vector< pj::ToneDigitMapDigit >::__setitem__(PySliceObject *)\n"
    "    std::vector< pj::ToneDigitMapDigit >::__setitem__(std::vector< pj::ToneDigitMapDigit >::difference_type,std::vector< pj::ToneDigitMapDigit >::value_type const &)\n");
  return 0;
}


SWIGINTERN PyObject *_wrap_ToneDigitMapVector_pop(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  std::vector< pj::ToneDigitMapDigit > *arg1 = (std::vector< pj::ToneDigitMapDigit > *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  std::vector< pj::ToneDigitMapDigit >::value_type result;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__vectorT_pj__ToneDigitMapDigit_std__allocatorT_pj__ToneDigitMapDigit_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "ToneDigitMapVector_pop" "', argument " "1"" of type '" "std::vector< pj::ToneDigitMapDigit > *""'"); 
  }
  arg1 = reinterpret_cast< std::vector< pj::ToneDigitMapDigit > * >(argp1);
  try {
    result = std_vector_Sl_pj_ToneDigitMapDigit_Sg__pop(arg1);
  } catch(std::out_of_range &_e) {
    SWIG_exception_fail(SWIG_IndexError, (&_e)->what());
  }
  resultobj = SWIG_NewPointerObj((new std::vector< pj::ToneDigitMapDigit >::value_type(static_cast< const std::vector< pj::ToneDigitMapDigit >::value_type& >(result))), SWIGTYPE_p_pj__ToneDigitMapDigit, SWIG_POINTER_OWN |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_ToneDigitMapVector_append(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  std::vector< pj::ToneDigitMapDigit > *arg1 = (std::vector< pj::ToneDigitMapDigit > *) 0 ;
  std::vector< pj::ToneDigitMapDigit >::value_type *arg2 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  void *argp2 = 0 ;
  int res2 = 0 ;
  PyObject *swig_obj[2] ;
  
  if (!SWIG_Python_UnpackTuple(args, "ToneDigitMapVector_append", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__vectorT_pj__ToneDigitMapDigit_std__allocatorT_pj__ToneDigitMapDigit_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "ToneDigitMapVector_append" "', argument " "1"" of type '" "std::vector< pj::ToneDigitMapDigit > *""'"); 
  }
  arg1 = reinterpret_cast< std::vector< pj::ToneDigitMapDigit > * >(argp1);
  res2 = SWIG_ConvertPtr(swig_obj[1], &argp2, SWIGTYPE_p_pj__ToneDigitMapDigit,  0  | 0);
  if (!SWIG_IsOK(res2)) {
    SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "ToneDigitMapVector_append" "', argument " "2"" of type '" "std::vector< pj::ToneDigitMapDigit >::value_type const &""'"); 
  }
  if (!argp2) {
    SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "ToneDigitMapVector_append" "', argument " "2"" of type '" "std::vector< pj::ToneDigitMapDigit >::value_type const &""'"); 
  }
  arg2 = reinterpret_cast< std::vector< pj::ToneDigitMapDigit >::value_type * >(argp2);
  std_vector_Sl_pj_ToneDigitMapDigit_Sg__append(arg1,(pj::ToneDigitMapDigit const &)*arg2);
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_new_ToneDigitMapVector__SWIG_0(PyObject *SWIGUNUSEDPARM(self), Py_ssize_t nobjs, PyObject **SWIGUNUSEDPARM(swig_obj)) {
  PyObject *resultobj = 0;
  std::vector< pj::ToneDigitMapDigit > *result = 0 ;
  
  if ((nobjs < 0) || (nobjs > 0)) SWIG_fail;
  result = (std::vector< pj::ToneDigitMapDigit > *)new std::vector< pj::ToneDigitMapDigit >();
  resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(result), SWIGTYPE_p_std__vectorT_pj__ToneDigitMapDigit_std__allocatorT_pj__ToneDigitMapDigit_t_t, SWIG_POINTER_NEW |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_new_ToneDigitMapVector__SWIG_1(PyObject *SWIGUNUSEDPARM(self), Py_ssize_t nobjs, PyObject **swig_obj) {
  PyObject *resultobj = 0;
  std::vector< pj::ToneDigitMapDigit > *arg1 = 0 ;
  int res1 = SWIG_OLDOBJ ;
  std::vector< pj::ToneDigitMapDigit > *result = 0 ;
  
  if ((nobjs < 1) || (nobjs > 1)) SWIG_fail;
  {
    std::vector< pj::ToneDigitMapDigit,std::allocator< pj::ToneDigitMapDigit > > *ptr = (std::vector< pj::ToneDigitMapDigit,std::allocator< pj::ToneDigitMapDigit > > *)0;
    res1 = swig::asptr(swig_obj[0], &ptr);
    if (!SWIG_IsOK(res1)) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "new_ToneDigitMapVector" "', argument " "1"" of type '" "std::vector< pj::ToneDigitMapDigit > const &""'"); 
    }
    if (!ptr) {
      SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "new_ToneDigitMapVector" "', argument " "1"" of type '" "std::vector< pj::ToneDigitMapDigit > const &""'"); 
    }
    arg1 = ptr;
  }
  result = (std::vector< pj::ToneDigitMapDigit > *)new std::vector< pj::ToneDigitMapDigit >((std::vector< pj::ToneDigitMapDigit > const &)*arg1);
  resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(result), SWIGTYPE_p_std__vectorT_pj__ToneDigitMapDigit_std__allocatorT_pj__ToneDigitMapDigit_t_t, SWIG_POINTER_NEW |  0 );
  if (SWIG_IsNewObj(res1)) delete arg1;
  return resultobj;
fail:
  if (SWIG_IsNewObj(res1)) delete arg1;
  return NULL;
}


SWIGINTERN PyObject *_wrap_ToneDigitMapVector_empty(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  std::vector< pj::ToneDigitMapDigit > *arg1 = (std::vector< pj::ToneDigitMapDigit > *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  bool result;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__vectorT_pj__ToneDigitMapDigit_std__allocatorT_pj__ToneDigitMapDigit_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "ToneDigitMapVector_empty" "', argument " "1"" of type '" "std::vector< pj::ToneDigitMapDigit > const *""'"); 
  }
  arg1 = reinterpret_cast< std::vector< pj::ToneDigitMapDigit > * >(argp1);
  result = (bool)((std::vector< pj::ToneDigitMapDigit > const *)arg1)->empty();
  resultobj = SWIG_From_bool(static_cast< bool >(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_ToneDigitMapVector_size(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  std::vector< pj::ToneDigitMapDigit > *arg1 = (std::vector< pj::ToneDigitMapDigit > *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  std::vector< pj::ToneDigitMapDigit >::size_type result;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__vectorT_pj__ToneDigitMapDigit_std__allocatorT_pj__ToneDigitMapDigit_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "ToneDigitMapVector_size" "', argument " "1"" of type '" "std::vector< pj::ToneDigitMapDigit > const *""'"); 
  }
  arg1 = reinterpret_cast< std::vector< pj::ToneDigitMapDigit > * >(argp1);
  result = ((std::vector< pj::ToneDigitMapDigit > const *)arg1)->size();
  resultobj = SWIG_From_size_t(static_cast< size_t >(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_ToneDigitMapVector_swap(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  std::vector< pj::ToneDigitMapDigit > *arg1 = (std::vector< pj::ToneDigitMapDigit > *) 0 ;
  std::vector< pj::ToneDigitMapDigit > *arg2 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  void *argp2 = 0 ;
  int res2 = 0 ;
  PyObject *swig_obj[2] ;
  
  if (!SWIG_Python_UnpackTuple(args, "ToneDigitMapVector_swap", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__vectorT_pj__ToneDigitMapDigit_std__allocatorT_pj__ToneDigitMapDigit_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "ToneDigitMapVector_swap" "', argument " "1"" of type '" "std::vector< pj::ToneDigitMapDigit > *""'"); 
  }
  arg1 = reinterpret_cast< std::vector< pj::ToneDigitMapDigit > * >(argp1);
  res2 = SWIG_ConvertPtr(swig_obj[1], &argp2, SWIGTYPE_p_std__vectorT_pj__ToneDigitMapDigit_std__allocatorT_pj__ToneDigitMapDigit_t_t,  0 );
  if (!SWIG_IsOK(res2)) {
    SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "ToneDigitMapVector_swap" "', argument " "2"" of type '" "std::vector< pj::ToneDigitMapDigit > &""'"); 
  }
  if (!argp2) {
    SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "ToneDigitMapVector_swap" "', argument " "2"" of type '" "std::vector< pj::ToneDigitMapDigit > &""'"); 
  }
  arg2 = reinterpret_cast< std::vector< pj::ToneDigitMapDigit > * >(argp2);
  (arg1)->swap(*arg2);
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_ToneDigitMapVector_begin(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  std::vector< pj::ToneDigitMapDigit > *arg1 = (std::vector< pj::ToneDigitMapDigit > *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  std::vector< pj::ToneDigitMapDigit >::iterator result;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__vectorT_pj__ToneDigitMapDigit_std__allocatorT_pj__ToneDigitMapDigit_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "ToneDigitMapVector_begin" "', argument " "1"" of type '" "std::vector< pj::ToneDigitMapDigit > *""'"); 
  }
  arg1 = reinterpret_cast< std::vector< pj::ToneDigitMapDigit > * >(argp1);
  result = (arg1)->begin();
  resultobj = SWIG_NewPointerObj(swig::make_output_iterator(static_cast< const std::vector< pj::ToneDigitMapDigit >::iterator & >(result)),
    swig::SwigPyIterator::descriptor(),SWIG_POINTER_OWN);
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_ToneDigitMapVector_end(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  std::vector< pj::ToneDigitMapDigit > *arg1 = (std::vector< pj::ToneDigitMapDigit > *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  std::vector< pj::ToneDigitMapDigit >::iterator result;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__vectorT_pj__ToneDigitMapDigit_std__allocatorT_pj__ToneDigitMapDigit_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "ToneDigitMapVector_end" "', argument " "1"" of type '" "std::vector< pj::ToneDigitMapDigit > *""'"); 
  }
  arg1 = reinterpret_cast< std::vector< pj::ToneDigitMapDigit > * >(argp1);
  result = (arg1)->end();
  resultobj = SWIG_NewPointerObj(swig::make_output_iterator(static_cast< const std::vector< pj::ToneDigitMapDigit >::iterator & >(result)),
    swig::SwigPyIterator::descriptor(),SWIG_POINTER_OWN);
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_ToneDigitMapVector_rbegin(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  std::vector< pj::ToneDigitMapDigit > *arg1 = (std::vector< pj::ToneDigitMapDigit > *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  std::vector< pj::ToneDigitMapDigit >::reverse_iterator result;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__vectorT_pj__ToneDigitMapDigit_std__allocatorT_pj__ToneDigitMapDigit_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "ToneDigitMapVector_rbegin" "', argument " "1"" of type '" "std::vector< pj::ToneDigitMapDigit > *""'"); 
  }
  arg1 = reinterpret_cast< std::vector< pj::ToneDigitMapDigit > * >(argp1);
  result = (arg1)->rbegin();
  resultobj = SWIG_NewPointerObj(swig::make_output_iterator(static_cast< const std::vector< pj::ToneDigitMapDigit >::reverse_iterator & >(result)),
    swig::SwigPyIterator::descriptor(),SWIG_POINTER_OWN);
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_ToneDigitMapVector_rend(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  std::vector< pj::ToneDigitMapDigit > *arg1 = (std::vector< pj::ToneDigitMapDigit > *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  std::vector< pj::ToneDigitMapDigit >::reverse_iterator result;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__vectorT_pj__ToneDigitMapDigit_std__allocatorT_pj__ToneDigitMapDigit_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "ToneDigitMapVector_rend" "', argument " "1"" of type '" "std::vector< pj::ToneDigitMapDigit > *""'"); 
  }
  arg1 = reinterpret_cast< std::vector< pj::ToneDigitMapDigit > * >(argp1);
  result = (arg1)->rend();
  resultobj = SWIG_NewPointerObj(swig::make_output_iterator(static_cast< const std::vector< pj::ToneDigitMapDigit >::reverse_iterator & >(result)),
    swig::SwigPyIterator::descriptor(),SWIG_POINTER_OWN);
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_ToneDigitMapVector_clear(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  std::vector< pj::ToneDigitMapDigit > *arg1 = (std::vector< pj::ToneDigitMapDigit > *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__vectorT_pj__ToneDigitMapDigit_std__allocatorT_pj__ToneDigitMapDigit_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "ToneDigitMapVector_clear" "', argument " "1"" of type '" "std::vector< pj::ToneDigitMapDigit > *""'"); 
  }
  arg1 = reinterpret_cast< std::vector< pj::ToneDigitMapDigit > * >(argp1);
  (arg1)->clear();
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_ToneDigitMapVector_get_allocator(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  std::vector< pj::ToneDigitMapDigit > *arg1 = (std::vector< pj::ToneDigitMapDigit > *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  SwigValueWrapper< std::allocator< pj::ToneDigitMapDigit > > result;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__vectorT_pj__ToneDigitMapDigit_std__allocatorT_pj__ToneDigitMapDigit_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "ToneDigitMapVector_get_allocator" "', argument " "1"" of type '" "std::vector< pj::ToneDigitMapDigit > const *""'"); 
  }
  arg1 = reinterpret_cast< std::vector< pj::ToneDigitMapDigit > * >(argp1);
  result = ((std::vector< pj::ToneDigitMapDigit > const *)arg1)->get_allocator();
  resultobj = SWIG_NewPointerObj((new std::vector< pj::ToneDigitMapDigit >::allocator_type(static_cast< const std::vector< pj::ToneDigitMapDigit >::allocator_type& >(result))), SWIGTYPE_p_std__allocatorT_pj__ToneDigitMapDigit_t, SWIG_POINTER_OWN |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_new_ToneDigitMapVector__SWIG_2(PyObject *SWIGUNUSEDPARM(self), Py_ssize_t nobjs, PyObject **swig_obj) {
  PyObject *resultobj = 0;
  std::vector< pj::ToneDigitMapDigit >::size_type arg1 ;
  size_t val1 ;
  int ecode1 = 0 ;
  std::vector< pj::ToneDigitMapDigit > *result = 0 ;
  
  if ((nobjs < 1) || (nobjs > 1)) SWIG_fail;
  ecode1 = SWIG_AsVal_size_t(swig_obj[0], &val1);
  if (!SWIG_IsOK(ecode1)) {
    SWIG_exception_fail(SWIG_ArgError(ecode1), "in method '" "new_ToneDigitMapVector" "', argument " "1"" of type '" "std::vector< pj::ToneDigitMapDigit >::size_type""'");
  } 
  arg1 = static_cast< std::vector< pj::ToneDigitMapDigit >::size_type >(val1);
  result = (std::vector< pj::ToneDigitMapDigit > *)new std::vector< pj::ToneDigitMapDigit >(arg1);
  resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(result), SWIGTYPE_p_std__vectorT_pj__ToneDigitMapDigit_std__allocatorT_pj__ToneDigitMapDigit_t_t, SWIG_POINTER_NEW |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_ToneDigitMapVector_pop_back(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  std::vector< pj::ToneDigitMapDigit > *arg1 = (std::vector< pj::ToneDigitMapDigit > *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__vectorT_pj__ToneDigitMapDigit_std__allocatorT_pj__ToneDigitMapDigit_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "ToneDigitMapVector_pop_back" "', argument " "1"" of type '" "std::vector< pj::ToneDigitMapDigit > *""'"); 
  }
  arg1 = reinterpret_cast< std::vector< pj::ToneDigitMapDigit > * >(argp1);
  (arg1)->pop_back();
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_ToneDigitMapVector_resize__SWIG_0(PyObject *SWIGUNUSEDPARM(self), Py_ssize_t nobjs, PyObject **swig_obj) {
  PyObject *resultobj = 0;
  std::vector< pj::ToneDigitMapDigit > *arg1 = (std::vector< pj::ToneDigitMapDigit > *) 0 ;
  std::vector< pj::ToneDigitMapDigit >::size_type arg2 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  size_t val2 ;
  int ecode2 = 0 ;
  
  if ((nobjs < 2) || (nobjs > 2)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__vectorT_pj__ToneDigitMapDigit_std__allocatorT_pj__ToneDigitMapDigit_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "ToneDigitMapVector_resize" "', argument " "1"" of type '" "std::vector< pj::ToneDigitMapDigit > *""'"); 
  }
  arg1 = reinterpret_cast< std::vector< pj::ToneDigitMapDigit > * >(argp1);
  ecode2 = SWIG_AsVal_size_t(swig_obj[1], &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "ToneDigitMapVector_resize" "', argument " "2"" of type '" "std::vector< pj::ToneDigitMapDigit >::size_type""'");
  } 
  arg2 = static_cast< std::vector< pj::ToneDigitMapDigit >::size_type >(val2);
  (arg1)->resize(arg2);
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_ToneDigitMapVector_erase__SWIG_0(PyObject *SWIGUNUSEDPARM(self), Py_ssize_t nobjs, PyObject **swig_obj) {
  PyObject *resultobj = 0;
  std::vector< pj::ToneDigitMapDigit > *arg1 = (std::vector< pj::ToneDigitMapDigit > *) 0 ;
  std::vector< pj::ToneDigitMapDigit >::iterator arg2 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  swig::SwigPyIterator *iter2 = 0 ;
  int res2 ;
  std::vector< pj::ToneDigitMapDigit >::iterator result;
  
  if ((nobjs < 2) || (nobjs > 2)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__vectorT_pj__ToneDigitMapDigit_std__allocatorT_pj__ToneDigitMapDigit_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "ToneDigitMapVector_erase" "', argument " "1"" of type '" "std::vector< pj::ToneDigitMapDigit > *""'"); 
  }
  arg1 = reinterpret_cast< std::vector< pj::ToneDigitMapDigit > * >(argp1);
  res2 = SWIG_ConvertPtr(swig_obj[1], SWIG_as_voidptrptr(&iter2), swig::SwigPyIterator::descriptor(), 0);
  if (!SWIG_IsOK(res2) || !iter2) {
    SWIG_exception_fail(SWIG_ArgError(SWIG_TypeError), "in method '" "ToneDigitMapVector_erase" "', argument " "2"" of type '" "std::vector< pj::ToneDigitMapDigit >::iterator""'");
  } else {
    swig::SwigPyIterator_T<std::vector< pj::ToneDigitMapDigit >::iterator > *iter_t = dynamic_cast<swig::SwigPyIterator_T<std::vector< pj::ToneDigitMapDigit >::iterator > *>(iter2);
    if (iter_t) {
      arg2 = iter_t->get_current();
    } else {
      SWIG_exception_fail(SWIG_ArgError(SWIG_TypeError), "in method '" "ToneDigitMapVector_erase" "', argument " "2"" of type '" "std::vector< pj::ToneDigitMapDigit >::iterator""'");
    }
  }
  result = std_vector_Sl_pj_ToneDigitMapDigit_Sg__erase__SWIG_0(arg1,arg2);
  resultobj = SWIG_NewPointerObj(swig::make_output_iterator(static_cast< const std::vector< pj::ToneDigitMapDigit >::iterator & >(result)),
    swig::SwigPyIterator::descriptor(),SWIG_POINTER_OWN);
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_ToneDigitMapVector_erase__SWIG_1(PyObject *SWIGUNUSEDPARM(self), Py_ssize_t nobjs, PyObject **swig_obj) {
  PyObject *resultobj = 0;
  std::vector< pj::ToneDigitMapDigit > *arg1 = (std::vector< pj::ToneDigitMapDigit > *) 0 ;
  std::vector< pj::ToneDigitMapDigit >::iterator arg2 ;
  std::vector< pj::ToneDigitMapDigit >::iterator arg3 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  swig::SwigPyIterator *iter2 = 0 ;
  int res2 ;
  swig::SwigPyIterator *iter3 = 0 ;
  int res3 ;
  std::vector< pj::ToneDigitMapDigit >::iterator result;
  
  if ((nobjs < 3) || (nobjs > 3)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__vectorT_pj__ToneDigitMapDigit_std__allocatorT_pj__ToneDigitMapDigit_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "ToneDigitMapVector_erase" "', argument " "1"" of type '" "std::vector< pj::ToneDigitMapDigit > *""'"); 
  }
  arg1 = reinterpret_cast< std::vector< pj::ToneDigitMapDigit > * >(argp1);
  res2 = SWIG_ConvertPtr(swig_obj[1], SWIG_as_voidptrptr(&iter2), swig::SwigPyIterator::descriptor(), 0);
  if (!SWIG_IsOK(res2) || !iter2) {
    SWIG_exception_fail(SWIG_ArgError(SWIG_TypeError), "in method '" "ToneDigitMapVector_erase" "', argument " "2"" of type '" "std::vector< pj::ToneDigitMapDigit >::iterator""'");
  } else {
    swig::SwigPyIterator_T<std::vector< pj::ToneDigitMapDigit >::iterator > *iter_t = dynamic_cast<swig::SwigPyIterator_T<std::vector< pj::ToneDigitMapDigit >::iterator > *>(iter2);
    if (iter_t) {
      arg2 = iter_t->get_current();
    } else {
      SWIG_exception_fail(SWIG_ArgError(SWIG_TypeError), "in method '" "ToneDigitMapVector_erase" "', argument " "2"" of type '" "std::vector< pj::ToneDigitMapDigit >::iterator""'");
    }
  }
  res3 = SWIG_ConvertPtr(swig_obj[2], SWIG_as_voidptrptr(&iter3), swig::SwigPyIterator::descriptor(), 0);
  if (!SWIG_IsOK(res3) || !iter3) {
    SWIG_exception_fail(SWIG_ArgError(SWIG_TypeError), "in method '" "ToneDigitMapVector_erase" "', argument " "3"" of type '" "std::vector< pj::ToneDigitMapDigit >::iterator""'");
  } else {
    swig::SwigPyIterator_T<std::vector< pj::ToneDigitMapDigit >::iterator > *iter_t = dynamic_cast<swig::SwigPyIterator_T<std::vector< pj::ToneDigitMapDigit >::iterator > *>(iter3);
    if (iter_t) {
      arg3 = iter_t->get_current();
    } else {
      SWIG_exception_fail(SWIG_ArgError(SWIG_TypeError), "in method '" "ToneDigitMapVector_erase" "', argument " "3"" of type '" "std::vector< pj::ToneDigitMapDigit >::iterator""'");
    }
  }
  result = std_vector_Sl_pj_ToneDigitMapDigit_Sg__erase__SWIG_1(arg1,arg2,arg3);
  resultobj = SWIG_NewPointerObj(swig::make_output_iterator(static_cast< const std::vector< pj::ToneDigitMapDigit >::iterator & >(result)),
    swig::SwigPyIterator::descriptor(),SWIG_POINTER_OWN);
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_ToneDigitMapVector_erase(PyObject *self, PyObject *args) {
  Py_ssize_t argc;
  PyObject *argv[4] = {
    0
  };
  
  if (!(argc = SWIG_Python_UnpackTuple(args, "ToneDigitMapVector_erase", 0, 3, argv))) SWIG_fail;
  --argc;
  if (argc == 2) {
    int _v;
    int res = swig::asptr(argv[0], (std::vector< pj::ToneDigitMapDigit,std::allocator< pj::ToneDigitMapDigit > >**)(0));
    _v = SWIG_CheckState(res);
    if (_v) {
      swig::SwigPyIterator *iter = 0;
      int res = SWIG_ConvertPtr(argv[1], SWIG_as_voidptrptr(&iter), swig::SwigPyIterator::descriptor(), 0);
      _v = (SWIG_IsOK(res) && iter && (dynamic_cast<swig::SwigPyIterator_T<std::vector< pj::ToneDigitMapDigit >::iterator > *>(iter) != 0));
      if (_v) {
        return _wrap_ToneDigitMapVector_erase__SWIG_0(self, argc, argv);
      }
    }
  }
  if (argc == 3) {
    int _v;
    int res = swig::asptr(argv[0], (std::vector< pj::ToneDigitMapDigit,std::allocator< pj::ToneDigitMapDigit > >**)(0));
    _v = SWIG_CheckState(res);
    if (_v) {
      swig::SwigPyIterator *iter = 0;
      int res = SWIG_ConvertPtr(argv[1], SWIG_as_voidptrptr(&iter), swig::SwigPyIterator::descriptor(), 0);
      _v = (SWIG_IsOK(res) && iter && (dynamic_cast<swig::SwigPyIterator_T<std::vector< pj::ToneDigitMapDigit >::iterator > *>(iter) != 0));
      if (_v) {
        swig::SwigPyIterator *iter = 0;
        int res = SWIG_ConvertPtr(argv[2], SWIG_as_voidptrptr(&iter), swig::SwigPyIterator::descriptor(), 0);
        _v = (SWIG_IsOK(res) && iter && (dynamic_cast<swig::SwigPyIterator_T<std::vector< pj::ToneDigitMapDigit >::iterator > *>(iter) != 0));
        if (_v) {
          return _wrap_ToneDigitMapVector_erase__SWIG_1(self, argc, argv);
        }
      }
    }
  }
  
fail:
  SWIG_Python_RaiseOrModifyTypeError("Wrong number or type of arguments for overloaded function 'ToneDigitMapVector_erase'.\n"
    "  Possible C/C++ prototypes are:\n"
    "    std::vector< pj::ToneDigitMapDigit >::erase(std::vector< pj::ToneDigitMapDigit >::iterator)\n"
    "    std::vector< pj::ToneDigitMapDigit >::erase(std::vector< pj::ToneDigitMapDigit >::iterator,std::vector< pj::ToneDigitMapDigit >::iterator)\n");
  return 0;
}


SWIGINTERN PyObject *_wrap_new_ToneDigitMapVector__SWIG_3(PyObject *SWIGUNUSEDPARM(self), Py_ssize_t nobjs, PyObject **swig_obj) {
  PyObject *resultobj = 0;
  std::vector< pj::ToneDigitMapDigit >::size_type arg1 ;
  std::vector< pj::ToneDigitMapDigit >::value_type *arg2 = 0 ;
  size_t val1 ;
  int ecode1 = 0 ;
  void *argp2 = 0 ;
  int res2 = 0 ;
  std::vector< pj::ToneDigitMapDigit > *result = 0 ;
  
  if ((nobjs < 2) || (nobjs > 2)) SWIG_fail;
  ecode1 = SWIG_AsVal_size_t(swig_obj[0], &val1);
  if (!SWIG_IsOK(ecode1)) {
    SWIG_exception_fail(SWIG_ArgError(ecode1), "in method '" "new_ToneDigitMapVector" "', argument " "1"" of type '" "std::vector< pj::ToneDigitMapDigit >::size_type""'");
  } 
  arg1 = static_cast< std::vector< pj::ToneDigitMapDigit >::size_type >(val1);
  res2 = SWIG_ConvertPtr(swig_obj[1], &argp2, SWIGTYPE_p_pj__ToneDigitMapDigit,  0  | 0);
  if (!SWIG_IsOK(res2)) {
    SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "new_ToneDigitMapVector" "', argument " "2"" of type '" "std::vector< pj::ToneDigitMapDigit >::value_type const &""'"); 
  }
  if (!argp2) {
    SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "new_ToneDigitMapVector" "', argument " "2"" of type '" "std::vector< pj::ToneDigitMapDigit >::value_type const &""'"); 
  }
  arg2 = reinterpret_cast< std::vector< pj::ToneDigitMapDigit >::value_type * >(argp2);
  result = (std::vector< pj::ToneDigitMapDigit > *)new std::vector< pj::ToneDigitMapDigit >(arg1,(std::vector< pj::ToneDigitMapDigit >::value_type const &)*arg2);
  resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(result), SWIGTYPE_p_std__vectorT_pj__ToneDigitMapDigit_std__allocatorT_pj__ToneDigitMapDigit_t_t, SWIG_POINTER_NEW |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_new_ToneDigitMapVector(PyObject *self, PyObject *args) {
  Py_ssize_t argc;
  PyObject *argv[3] = {
    0
  };
  
  if (!(argc = SWIG_Python_UnpackTuple(args, "new_ToneDigitMapVector", 0, 2, argv))) SWIG_fail;
  --argc;
  if (argc == 0) {
    return _wrap_new_ToneDigitMapVector__SWIG_0(self, argc, argv);
  }
  if (argc == 1) {
    int _v;
    {
      int res = SWIG_AsVal_size_t(argv[0], NULL);
      _v = SWIG_CheckState(res);
    }
    if (_v) {
      return _wrap_new_ToneDigitMapVector__SWIG_2(self, argc, argv);
    }
  }
  if (argc == 1) {
    int _v;
    int res = swig::asptr(argv[0], (std::vector< pj::ToneDigitMapDigit,std::allocator< pj::ToneDigitMapDigit > >**)(0));
    _v = SWIG_CheckState(res);
    if (_v) {
      return _wrap_new_ToneDigitMapVector__SWIG_1(self, argc, argv);
    }
  }
  if (argc == 2) {
    int _v;
    {
      int res = SWIG_AsVal_size_t(argv[0], NULL);
      _v = SWIG_CheckState(res);
    }
    if (_v) {
      int res = SWIG_ConvertPtr(argv[1], 0, SWIGTYPE_p_pj__ToneDigitMapDigit, SWIG_POINTER_NO_NULL | 0);
      _v = SWIG_CheckState(res);
      if (_v) {
        return _wrap_new_ToneDigitMapVector__SWIG_3(self, argc, argv);
      }
    }
  }
  
fail:
  SWIG_Python_RaiseOrModifyTypeError("Wrong number or type of arguments for overloaded function 'new_ToneDigitMapVector'.\n"
    "  Possible C/C++ prototypes are:\n"
    "    std::vector< pj::ToneDigitMapDigit >::vector()\n"
    "    std::vector< pj::ToneDigitMapDigit >::vector(std::vector< pj::ToneDigitMapDigit > const &)\n"
    "    std::vector< pj::ToneDigitMapDigit >::vector(std::vector< pj::ToneDigitMapDigit >::size_type)\n"
    "    std::vector< pj::ToneDigitMapDigit >::vector(std::vector< pj::ToneDigitMapDigit >::size_type,std::vector< pj::ToneDigitMapDigit >::value_type const &)\n");
  return 0;
}


SWIGINTERN PyObject *_wrap_ToneDigitMapVector_push_back(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  std::vector< pj::ToneDigitMapDigit > *arg1 = (std::vector< pj::ToneDigitMapDigit > *) 0 ;
  std::vector< pj::ToneDigitMapDigit >::value_type *arg2 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  void *argp2 = 0 ;
  int res2 = 0 ;
  PyObject *swig_obj[2] ;
  
  if (!SWIG_Python_UnpackTuple(args, "ToneDigitMapVector_push_back", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__vectorT_pj__ToneDigitMapDigit_std__allocatorT_pj__ToneDigitMapDigit_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "ToneDigitMapVector_push_back" "', argument " "1"" of type '" "std::vector< pj::ToneDigitMapDigit > *""'"); 
  }
  arg1 = reinterpret_cast< std::vector< pj::ToneDigitMapDigit > * >(argp1);
  res2 = SWIG_ConvertPtr(swig_obj[1], &argp2, SWIGTYPE_p_pj__ToneDigitMapDigit,  0  | 0);
  if (!SWIG_IsOK(res2)) {
    SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "ToneDigitMapVector_push_back" "', argument " "2"" of type '" "std::vector< pj::ToneDigitMapDigit >::value_type const &""'"); 
  }
  if (!argp2) {
    SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "ToneDigitMapVector_push_back" "', argument " "2"" of type '" "std::vector< pj::ToneDigitMapDigit >::value_type const &""'"); 
  }
  arg2 = reinterpret_cast< std::vector< pj::ToneDigitMapDigit >::value_type * >(argp2);
  (arg1)->push_back((std::vector< pj::ToneDigitMapDigit >::value_type const &)*arg2);
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_ToneDigitMapVector_front(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  std::vector< pj::ToneDigitMapDigit > *arg1 = (std::vector< pj::ToneDigitMapDigit > *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  std::vector< pj::ToneDigitMapDigit >::value_type *result = 0 ;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__vectorT_pj__ToneDigitMapDigit_std__allocatorT_pj__ToneDigitMapDigit_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "ToneDigitMapVector_front" "', argument " "1"" of type '" "std::vector< pj::ToneDigitMapDigit > const *""'"); 
  }
  arg1 = reinterpret_cast< std::vector< pj::ToneDigitMapDigit > * >(argp1);
  result = (std::vector< pj::ToneDigitMapDigit >::value_type *) &((std::vector< pj::ToneDigitMapDigit > const *)arg1)->front();
  resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(result), SWIGTYPE_p_pj__ToneDigitMapDigit, 0 |  0 );
  (void)swig::container_owner<swig::traits<std::vector< pj::ToneDigitMapDigit >::value_type>::category>::back_reference(resultobj, swig_obj[0]);
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_ToneDigitMapVector_back(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  std::vector< pj::ToneDigitMapDigit > *arg1 = (std::vector< pj::ToneDigitMapDigit > *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  std::vector< pj::ToneDigitMapDigit >::value_type *result = 0 ;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__vectorT_pj__ToneDigitMapDigit_std__allocatorT_pj__ToneDigitMapDigit_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "ToneDigitMapVector_back" "', argument " "1"" of type '" "std::vector< pj::ToneDigitMapDigit > const *""'"); 
  }
  arg1 = reinterpret_cast< std::vector< pj::ToneDigitMapDigit > * >(argp1);
  result = (std::vector< pj::ToneDigitMapDigit >::value_type *) &((std::vector< pj::ToneDigitMapDigit > const *)arg1)->back();
  resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(result), SWIGTYPE_p_pj__ToneDigitMapDigit, 0 |  0 );
  (void)swig::container_owner<swig::traits<std::vector< pj::ToneDigitMapDigit >::value_type>::category>::back_reference(resultobj, swig_obj[0]);
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_ToneDigitMapVector_assign(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  std::vector< pj::ToneDigitMapDigit > *arg1 = (std::vector< pj::ToneDigitMapDigit > *) 0 ;
  std::vector< pj::ToneDigitMapDigit >::size_type arg2 ;
  std::vector< pj::ToneDigitMapDigit >::value_type *arg3 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  size_t val2 ;
  int ecode2 = 0 ;
  void *argp3 = 0 ;
  int res3 = 0 ;
  PyObject *swig_obj[3] ;
  
  if (!SWIG_Python_UnpackTuple(args, "ToneDigitMapVector_assign", 3, 3, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__vectorT_pj__ToneDigitMapDigit_std__allocatorT_pj__ToneDigitMapDigit_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "ToneDigitMapVector_assign" "', argument " "1"" of type '" "std::vector< pj::ToneDigitMapDigit > *""'"); 
  }
  arg1 = reinterpret_cast< std::vector< pj::ToneDigitMapDigit > * >(argp1);
  ecode2 = SWIG_AsVal_size_t(swig_obj[1], &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "ToneDigitMapVector_assign" "', argument " "2"" of type '" "std::vector< pj::ToneDigitMapDigit >::size_type""'");
  } 
  arg2 = static_cast< std::vector< pj::ToneDigitMapDigit >::size_type >(val2);
  res3 = SWIG_ConvertPtr(swig_obj[2], &argp3, SWIGTYPE_p_pj__ToneDigitMapDigit,  0  | 0);
  if (!SWIG_IsOK(res3)) {
    SWIG_exception_fail(SWIG_ArgError(res3), "in method '" "ToneDigitMapVector_assign" "', argument " "3"" of type '" "std::vector< pj::ToneDigitMapDigit >::value_type const &""'"); 
  }
  if (!argp3) {
    SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "ToneDigitMapVector_assign" "', argument " "3"" of type '" "std::vector< pj::ToneDigitMapDigit >::value_type const &""'"); 
  }
  arg3 = reinterpret_cast< std::vector< pj::ToneDigitMapDigit >::value_type * >(argp3);
  (arg1)->assign(arg2,(std::vector< pj::ToneDigitMapDigit >::value_type const &)*arg3);
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_ToneDigitMapVector_resize__SWIG_1(PyObject *SWIGUNUSEDPARM(self), Py_ssize_t nobjs, PyObject **swig_obj) {
  PyObject *resultobj = 0;
  std::vector< pj::ToneDigitMapDigit > *arg1 = (std::vector< pj::ToneDigitMapDigit > *) 0 ;
  std::vector< pj::ToneDigitMapDigit >::size_type arg2 ;
  std::vector< pj::ToneDigitMapDigit >::value_type *arg3 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  size_t val2 ;
  int ecode2 = 0 ;
  void *argp3 = 0 ;
  int res3 = 0 ;
  
  if ((nobjs < 3) || (nobjs > 3)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__vectorT_pj__ToneDigitMapDigit_std__allocatorT_pj__ToneDigitMapDigit_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "ToneDigitMapVector_resize" "', argument " "1"" of type '" "std::vector< pj::ToneDigitMapDigit > *""'"); 
  }
  arg1 = reinterpret_cast< std::vector< pj::ToneDigitMapDigit > * >(argp1);
  ecode2 = SWIG_AsVal_size_t(swig_obj[1], &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "ToneDigitMapVector_resize" "', argument " "2"" of type '" "std::vector< pj::ToneDigitMapDigit >::size_type""'");
  } 
  arg2 = static_cast< std::vector< pj::ToneDigitMapDigit >::size_type >(val2);
  res3 = SWIG_ConvertPtr(swig_obj[2], &argp3, SWIGTYPE_p_pj__ToneDigitMapDigit,  0  | 0);
  if (!SWIG_IsOK(res3)) {
    SWIG_exception_fail(SWIG_ArgError(res3), "in method '" "ToneDigitMapVector_resize" "', argument " "3"" of type '" "std::vector< pj::ToneDigitMapDigit >::value_type const &""'"); 
  }
  if (!argp3) {
    SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "ToneDigitMapVector_resize" "', argument " "3"" of type '" "std::vector< pj::ToneDigitMapDigit >::value_type const &""'"); 
  }
  arg3 = reinterpret_cast< std::vector< pj::ToneDigitMapDigit >::value_type * >(argp3);
  (arg1)->resize(arg2,(std::vector< pj::ToneDigitMapDigit >::value_type const &)*arg3);
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_ToneDigitMapVector_resize(PyObject *self, PyObject *args) {
  Py_ssize_t argc;
  PyObject *argv[4] = {
    0
  };
  
  if (!(argc = SWIG_Python_UnpackTuple(args, "ToneDigitMapVector_resize", 0, 3, argv))) SWIG_fail;
  --argc;
  if (argc == 2) {
    int _v;
    int res = swig::asptr(argv[0], (std::vector< pj::ToneDigitMapDigit,std::allocator< pj::ToneDigitMapDigit > >**)(0));
    _v = SWIG_CheckState(res);
    if (_v) {
      {
        int res = SWIG_AsVal_size_t(argv[1], NULL);
        _v = SWIG_CheckState(res);
      }
      if (_v) {
        return _wrap_ToneDigitMapVector_resize__SWIG_0(self, argc, argv);
      }
    }
  }
  if (argc == 3) {
    int _v;
    int res = swig::asptr(argv[0], (std::vector< pj::ToneDigitMapDigit,std::allocator< pj::ToneDigitMapDigit > >**)(0));
    _v = SWIG_CheckState(res);
    if (_v) {
      {
        int res = SWIG_AsVal_size_t(argv[1], NULL);
        _v = SWIG_CheckState(res);
      }
      if (_v) {
        int res = SWIG_ConvertPtr(argv[2], 0, SWIGTYPE_p_pj__ToneDigitMapDigit, SWIG_POINTER_NO_NULL | 0);
        _v = SWIG_CheckState(res);
        if (_v) {
          return _wrap_ToneDigitMapVector_resize__SWIG_1(self, argc, argv);
        }
      }
    }
  }
  
fail:
  SWIG_Python_RaiseOrModifyTypeError("Wrong number or type of arguments for overloaded function 'ToneDigitMapVector_resize'.\n"
    "  Possible C/C++ prototypes are:\n"
    "    std::vector< pj::ToneDigitMapDigit >::resize(std::vector< pj::ToneDigitMapDigit >::size_type)\n"
    "    std::vector< pj::ToneDigitMapDigit >::resize(std::vector< pj::ToneDigitMapDigit >::size_type,std::vector< pj::ToneDigitMapDigit >::value_type const &)\n");
  return 0;
}


SWIGINTERN PyObject *_wrap_ToneDigitMapVector_insert__SWIG_0(PyObject *SWIGUNUSEDPARM(self), Py_ssize_t nobjs, PyObject **swig_obj) {
  PyObject *resultobj = 0;
  std::vector< pj::ToneDigitMapDigit > *arg1 = (std::vector< pj::ToneDigitMapDigit > *) 0 ;
  std::vector< pj::ToneDigitMapDigit >::iterator arg2 ;
  std::vector< pj::ToneDigitMapDigit >::value_type *arg3 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  swig::SwigPyIterator *iter2 = 0 ;
  int res2 ;
  void *argp3 = 0 ;
  int res3 = 0 ;
  std::vector< pj::ToneDigitMapDigit >::iterator result;
  
  if ((nobjs < 3) || (nobjs > 3)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__vectorT_pj__ToneDigitMapDigit_std__allocatorT_pj__ToneDigitMapDigit_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "ToneDigitMapVector_insert" "', argument " "1"" of type '" "std::vector< pj::ToneDigitMapDigit > *""'"); 
  }
  arg1 = reinterpret_cast< std::vector< pj::ToneDigitMapDigit > * >(argp1);
  res2 = SWIG_ConvertPtr(swig_obj[1], SWIG_as_voidptrptr(&iter2), swig::SwigPyIterator::descriptor(), 0);
  if (!SWIG_IsOK(res2) || !iter2) {
    SWIG_exception_fail(SWIG_ArgError(SWIG_TypeError), "in method '" "ToneDigitMapVector_insert" "', argument " "2"" of type '" "std::vector< pj::ToneDigitMapDigit >::iterator""'");
  } else {
    swig::SwigPyIterator_T<std::vector< pj::ToneDigitMapDigit >::iterator > *iter_t = dynamic_cast<swig::SwigPyIterator_T<std::vector< pj::ToneDigitMapDigit >::iterator > *>(iter2);
    if (iter_t) {
      arg2 = iter_t->get_current();
    } else {
      SWIG_exception_fail(SWIG_ArgError(SWIG_TypeError), "in method '" "ToneDigitMapVector_insert" "', argument " "2"" of type '" "std::vector< pj::ToneDigitMapDigit >::iterator""'");
    }
  }
  res3 = SWIG_ConvertPtr(swig_obj[2], &argp3, SWIGTYPE_p_pj__ToneDigitMapDigit,  0  | 0);
  if (!SWIG_IsOK(res3)) {
    SWIG_exception_fail(SWIG_ArgError(res3), "in method '" "ToneDigitMapVector_insert" "', argument " "3"" of type '" "std::vector< pj::ToneDigitMapDigit >::value_type const &""'"); 
  }
  if (!argp3) {
    SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "ToneDigitMapVector_insert" "', argument " "3"" of type '" "std::vector< pj::ToneDigitMapDigit >::value_type const &""'"); 
  }
  arg3 = reinterpret_cast< std::vector< pj::ToneDigitMapDigit >::value_type * >(argp3);
  result = std_vector_Sl_pj_ToneDigitMapDigit_Sg__insert__SWIG_0(arg1,arg2,(pj::ToneDigitMapDigit const &)*arg3);
  resultobj = SWIG_NewPointerObj(swig::make_output_iterator(static_cast< const std::vector< pj::ToneDigitMapDigit >::iterator & >(result)),
    swig::SwigPyIterator::descriptor(),SWIG_POINTER_OWN);
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_ToneDigitMapVector_insert__SWIG_1(PyObject *SWIGUNUSEDPARM(self), Py_ssize_t nobjs, PyObject **swig_obj) {
  PyObject *resultobj = 0;
  std::vector< pj::ToneDigitMapDigit > *arg1 = (std::vector< pj::ToneDigitMapDigit > *) 0 ;
  std::vector< pj::ToneDigitMapDigit >::iterator arg2 ;
  std::vector< pj::ToneDigitMapDigit >::size_type arg3 ;
  std::vector< pj::ToneDigitMapDigit >::value_type *arg4 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  swig::SwigPyIterator *iter2 = 0 ;
  int res2 ;
  size_t val3 ;
  int ecode3 = 0 ;
  void *argp4 = 0 ;
  int res4 = 0 ;
  
  if ((nobjs < 4) || (nobjs > 4)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__vectorT_pj__ToneDigitMapDigit_std__allocatorT_pj__ToneDigitMapDigit_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "ToneDigitMapVector_insert" "', argument " "1"" of type '" "std::vector< pj::ToneDigitMapDigit > *""'"); 
  }
  arg1 = reinterpret_cast< std::vector< pj::ToneDigitMapDigit > * >(argp1);
  res2 = SWIG_ConvertPtr(swig_obj[1], SWIG_as_voidptrptr(&iter2), swig::SwigPyIterator::descriptor(), 0);
  if (!SWIG_IsOK(res2) || !iter2) {
    SWIG_exception_fail(SWIG_ArgError(SWIG_TypeError), "in method '" "ToneDigitMapVector_insert" "', argument " "2"" of type '" "std::vector< pj::ToneDigitMapDigit >::iterator""'");
  } else {
    swig::SwigPyIterator_T<std::vector< pj::ToneDigitMapDigit >::iterator > *iter_t = dynamic_cast<swig::SwigPyIterator_T<std::vector< pj::ToneDigitMapDigit >::iterator > *>(iter2);
    if (iter_t) {
      arg2 = iter_t->get_current();
    } else {
      SWIG_exception_fail(SWIG_ArgError(SWIG_TypeError), "in method '" "ToneDigitMapVector_insert" "', argument " "2"" of type '" "std::vector< pj::ToneDigitMapDigit >::iterator""'");
    }
  }
  ecode3 = SWIG_AsVal_size_t(swig_obj[2], &val3);
  if (!SWIG_IsOK(ecode3)) {
    SWIG_exception_fail(SWIG_ArgError(ecode3), "in method '" "ToneDigitMapVector_insert" "', argument " "3"" of type '" "std::vector< pj::ToneDigitMapDigit >::size_type""'");
  } 
  arg3 = static_cast< std::vector< pj::ToneDigitMapDigit >::size_type >(val3);
  res4 = SWIG_ConvertPtr(swig_obj[3], &argp4, SWIGTYPE_p_pj__ToneDigitMapDigit,  0  | 0);
  if (!SWIG_IsOK(res4)) {
    SWIG_exception_fail(SWIG_ArgError(res4), "in method '" "ToneDigitMapVector_insert" "', argument " "4"" of type '" "std::vector< pj::ToneDigitMapDigit >::value_type const &""'"); 
  }
  if (!argp4) {
    SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "ToneDigitMapVector_insert" "', argument " "4"" of type '" "std::vector< pj::ToneDigitMapDigit >::value_type const &""'"); 
  }
  arg4 = reinterpret_cast< std::vector< pj::ToneDigitMapDigit >::value_type * >(argp4);
  std_vector_Sl_pj_ToneDigitMapDigit_Sg__insert__SWIG_1(arg1,arg2,arg3,(pj::ToneDigitMapDigit const &)*arg4);
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_ToneDigitMapVector_insert(PyObject *self, PyObject *args) {
  Py_ssize_t argc;
  PyObject *argv[5] = {
    0
  };
  
  if (!(argc = SWIG_Python_UnpackTuple(args, "ToneDigitMapVector_insert", 0, 4, argv))) SWIG_fail;
  --argc;
  if (argc == 3) {
    int _v;
    int res = swig::asptr(argv[0], (std::vector< pj::ToneDigitMapDigit,std::allocator< pj::ToneDigitMapDigit > >**)(0));
    _v = SWIG_CheckState(res);
    if (_v) {
      swig::SwigPyIterator *iter = 0;
      int res = SWIG_ConvertPtr(argv[1], SWIG_as_voidptrptr(&iter), swig::SwigPyIterator::descriptor(), 0);
      _v = (SWIG_IsOK(res) && iter && (dynamic_cast<swig::SwigPyIterator_T<std::vector< pj::ToneDigitMapDigit >::iterator > *>(iter) != 0));
      if (_v) {
        int res = SWIG_ConvertPtr(argv[2], 0, SWIGTYPE_p_pj__ToneDigitMapDigit, SWIG_POINTER_NO_NULL | 0);
        _v = SWIG_CheckState(res);
        if (_v) {
          return _wrap_ToneDigitMapVector_insert__SWIG_0(self, argc, argv);
        }
      }
    }
  }
  if (argc == 4) {
    int _v;
    int res = swig::asptr(argv[0], (std::vector< pj::ToneDigitMapDigit,std::allocator< pj::ToneDigitMapDigit > >**)(0));
    _v = SWIG_CheckState(res);
    if (_v) {
      swig::SwigPyIterator *iter = 0;
      int res = SWIG_ConvertPtr(argv[1], SWIG_as_voidptrptr(&iter), swig::SwigPyIterator::descriptor(), 0);
      _v = (SWIG_IsOK(res) && iter && (dynamic_cast<swig::SwigPyIterator_T<std::vector< pj::ToneDigitMapDigit >::iterator > *>(iter) != 0));
      if (_v) {
        {
          int res = SWIG_AsVal_size_t(argv[2], NULL);
          _v = SWIG_CheckState(res);
        }
        if (_v) {
          int res = SWIG_ConvertPtr(argv[3], 0, SWIGTYPE_p_pj__ToneDigitMapDigit, SWIG_POINTER_NO_NULL | 0);
          _v = SWIG_CheckState(res);
          if (_v) {
            return _wrap_ToneDigitMapVector_insert__SWIG_1(self, argc, argv);
          }
        }
      }
    }
  }
  
fail:
  SWIG_Python_RaiseOrModifyTypeError("Wrong number or type of arguments for overloaded function 'ToneDigitMapVector_insert'.\n"
    "  Possible C/C++ prototypes are:\n"
    "    std::vector< pj::ToneDigitMapDigit >::insert(std::vector< pj::ToneDigitMapDigit >::iterator,std::vector< pj::ToneDigitMapDigit >::value_type const &)\n"
    "    std::vector< pj::ToneDigitMapDigit >::insert(std::vector< pj::ToneDigitMapDigit >::iterator,std::vector< pj::ToneDigitMapDigit >::size_type,std::vector< pj::ToneDigitMapDigit >::value_type const &)\n");
  return 0;
}


SWIGINTERN PyObject *_wrap_ToneDigitMapVector_reserve(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  std::vector< pj::ToneDigitMapDigit > *arg1 = (std::vector< pj::ToneDigitMapDigit > *) 0 ;
  std::vector< pj::ToneDigitMapDigit >::size_type arg2 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  size_t val2 ;
  int ecode2 = 0 ;
  PyObject *swig_obj[2] ;
  
  if (!SWIG_Python_UnpackTuple(args, "ToneDigitMapVector_reserve", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__vectorT_pj__ToneDigitMapDigit_std__allocatorT_pj__ToneDigitMapDigit_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "ToneDigitMapVector_reserve" "', argument " "1"" of type '" "std::vector< pj::ToneDigitMapDigit > *""'"); 
  }
  arg1 = reinterpret_cast< std::vector< pj::ToneDigitMapDigit > * >(argp1);
  ecode2 = SWIG_AsVal_size_t(swig_obj[1], &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "ToneDigitMapVector_reserve" "', argument " "2"" of type '" "std::vector< pj::ToneDigitMapDigit >::size_type""'");
  } 
  arg2 = static_cast< std::vector< pj::ToneDigitMapDigit >::size_type >(val2);
  (arg1)->reserve(arg2);
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_ToneDigitMapVector_capacity(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  std::vector< pj::ToneDigitMapDigit > *arg1 = (std::vector< pj::ToneDigitMapDigit > *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  std::vector< pj::ToneDigitMapDigit >::size_type result;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__vectorT_pj__ToneDigitMapDigit_std__allocatorT_pj__ToneDigitMapDigit_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "ToneDigitMapVector_capacity" "', argument " "1"" of type '" "std::vector< pj::ToneDigitMapDigit > const *""'"); 
  }
  arg1 = reinterpret_cast< std::vector< pj::ToneDigitMapDigit > * >(argp1);
  result = ((std::vector< pj::ToneDigitMapDigit > const *)arg1)->capacity();
  resultobj = SWIG_From_size_t(static_cast< size_t >(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_delete_ToneDigitMapVector(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  std::vector< pj::ToneDigitMapDigit > *arg1 = (std::vector< pj::ToneDigitMapDigit > *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__vectorT_pj__ToneDigitMapDigit_std__allocatorT_pj__ToneDigitMapDigit_t_t, SWIG_POINTER_DISOWN |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "delete_ToneDigitMapVector" "', argument " "1"" of type '" "std::vector< pj::ToneDigitMapDigit > *""'"); 
  }
  arg1 = reinterpret_cast< std::vector< pj::ToneDigitMapDigit > * >(argp1);
  delete arg1;
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *ToneDigitMapVector_swigregister(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *obj;
  if (!SWIG_Python_UnpackTuple(args, "swigregister", 1, 1, &obj)) return NULL;
  SWIG_TypeNewClientData(SWIGTYPE_p_std__vectorT_pj__ToneDigitMapDigit_std__allocatorT_pj__ToneDigitMapDigit_t_t, SWIG_NewClientData(obj));
  return SWIG_Py_Void();
}

SWIGINTERN PyObject *ToneDigitMapVector_swiginit(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  return SWIG_Python_InitShadowInstance(args);
}

SWIGINTERN PyObject *_wrap_AudioDevInfoVector_iterator(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  std::vector< pj::AudioDevInfo * > *arg1 = (std::vector< pj::AudioDevInfo * > *) 0 ;
  PyObject **arg2 = (PyObject **) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  swig::SwigPyIterator *result = 0 ;
  
  arg2 = &swig_obj[0];
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__vectorT_pj__AudioDevInfo_p_std__allocatorT_pj__AudioDevInfo_p_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "AudioDevInfoVector_iterator" "', argument " "1"" of type '" "std::vector< pj::AudioDevInfo * > *""'"); 
  }
  arg1 = reinterpret_cast< std::vector< pj::AudioDevInfo * > * >(argp1);
  result = (swig::SwigPyIterator *)std_vector_Sl_pj_AudioDevInfo_Sm__Sg__iterator(arg1,arg2);
  resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(result), SWIGTYPE_p_swig__SwigPyIterator, SWIG_POINTER_OWN |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_AudioDevInfoVector___nonzero__(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  std::vector< pj::AudioDevInfo * > *arg1 = (std::vector< pj::AudioDevInfo * > *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  bool result;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__vectorT_pj__AudioDevInfo_p_std__allocatorT_pj__AudioDevInfo_p_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "AudioDevInfoVector___nonzero__" "', argument " "1"" of type '" "std::vector< pj::AudioDevInfo * > const *""'"); 
  }
  arg1 = reinterpret_cast< std::vector< pj::AudioDevInfo * > * >(argp1);
  result = (bool)std_vector_Sl_pj_AudioDevInfo_Sm__Sg____nonzero__((std::vector< pj::AudioDevInfo * > const *)arg1);
  resultobj = SWIG_From_bool(static_cast< bool >(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_AudioDevInfoVector___bool__(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  std::vector< pj::AudioDevInfo * > *arg1 = (std::vector< pj::AudioDevInfo * > *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  bool result;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__vectorT_pj__AudioDevInfo_p_std__allocatorT_pj__AudioDevInfo_p_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "AudioDevInfoVector___bool__" "', argument " "1"" of type '" "std::vector< pj::AudioDevInfo * > const *""'"); 
  }
  arg1 = reinterpret_cast< std::vector< pj::AudioDevInfo * > * >(argp1);
  result = (bool)std_vector_Sl_pj_AudioDevInfo_Sm__Sg____bool__((std::vector< pj::AudioDevInfo * > const *)arg1);
  resultobj = SWIG_From_bool(static_cast< bool >(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_AudioDevInfoVector___len__(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  std::vector< pj::AudioDevInfo * > *arg1 = (std::vector< pj::AudioDevInfo * > *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  std::vector< pj::AudioDevInfo * >::size_type result;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__vectorT_pj__AudioDevInfo_p_std__allocatorT_pj__AudioDevInfo_p_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "AudioDevInfoVector___len__" "', argument " "1"" of type '" "std::vector< pj::AudioDevInfo * > const *""'"); 
  }
  arg1 = reinterpret_cast< std::vector< pj::AudioDevInfo * > * >(argp1);
  result = std_vector_Sl_pj_AudioDevInfo_Sm__Sg____len__((std::vector< pj::AudioDevInfo * > const *)arg1);
  resultobj = SWIG_From_size_t(static_cast< size_t >(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_AudioDevInfoVector___getslice__(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  std::vector< pj::AudioDevInfo * > *arg1 = (std::vector< pj::AudioDevInfo * > *) 0 ;
  std::vector< pj::AudioDevInfo * >::difference_type arg2 ;
  std::vector< pj::AudioDevInfo * >::difference_type arg3 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  ptrdiff_t val2 ;
  int ecode2 = 0 ;
  ptrdiff_t val3 ;
  int ecode3 = 0 ;
  PyObject *swig_obj[3] ;
  std::vector< pj::AudioDevInfo *,std::allocator< pj::AudioDevInfo * > > *result = 0 ;
  
  if (!SWIG_Python_UnpackTuple(args, "AudioDevInfoVector___getslice__", 3, 3, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__vectorT_pj__AudioDevInfo_p_std__allocatorT_pj__AudioDevInfo_p_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "AudioDevInfoVector___getslice__" "', argument " "1"" of type '" "std::vector< pj::AudioDevInfo * > *""'"); 
  }
  arg1 = reinterpret_cast< std::vector< pj::AudioDevInfo * > * >(argp1);
  ecode2 = SWIG_AsVal_ptrdiff_t(swig_obj[1], &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "AudioDevInfoVector___getslice__" "', argument " "2"" of type '" "std::vector< pj::AudioDevInfo * >::difference_type""'");
  } 
  arg2 = static_cast< std::vector< pj::AudioDevInfo * >::difference_type >(val2);
  ecode3 = SWIG_AsVal_ptrdiff_t(swig_obj[2], &val3);
  if (!SWIG_IsOK(ecode3)) {
    SWIG_exception_fail(SWIG_ArgError(ecode3), "in method '" "AudioDevInfoVector___getslice__" "', argument " "3"" of type '" "std::vector< pj::AudioDevInfo * >::difference_type""'");
  } 
  arg3 = static_cast< std::vector< pj::AudioDevInfo * >::difference_type >(val3);
  try {
    result = (std::vector< pj::AudioDevInfo *,std::allocator< pj::AudioDevInfo * > > *)std_vector_Sl_pj_AudioDevInfo_Sm__Sg____getslice__(arg1,arg2,arg3);
  } catch(std::out_of_range &_e) {
    SWIG_exception_fail(SWIG_IndexError, (&_e)->what());
  } catch(std::invalid_argument &_e) {
    SWIG_exception_fail(SWIG_ValueError, (&_e)->what());
  }
  resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(result), SWIGTYPE_p_std__vectorT_pj__AudioDevInfo_p_std__allocatorT_pj__AudioDevInfo_p_t_t, SWIG_POINTER_OWN |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_AudioDevInfoVector___setslice____SWIG_0(PyObject *SWIGUNUSEDPARM(self), Py_ssize_t nobjs, PyObject **swig_obj) {
  PyObject *resultobj = 0;
  std::vector< pj::AudioDevInfo * > *arg1 = (std::vector< pj::AudioDevInfo * > *) 0 ;
  std::vector< pj::AudioDevInfo * >::difference_type arg2 ;
  std::vector< pj::AudioDevInfo * >::difference_type arg3 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  ptrdiff_t val2 ;
  int ecode2 = 0 ;
  ptrdiff_t val3 ;
  int ecode3 = 0 ;
  
  if ((nobjs < 3) || (nobjs > 3)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__vectorT_pj__AudioDevInfo_p_std__allocatorT_pj__AudioDevInfo_p_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "AudioDevInfoVector___setslice__" "', argument " "1"" of type '" "std::vector< pj::AudioDevInfo * > *""'"); 
  }
  arg1 = reinterpret_cast< std::vector< pj::AudioDevInfo * > * >(argp1);
  ecode2 = SWIG_AsVal_ptrdiff_t(swig_obj[1], &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "AudioDevInfoVector___setslice__" "', argument " "2"" of type '" "std::vector< pj::AudioDevInfo * >::difference_type""'");
  } 
  arg2 = static_cast< std::vector< pj::AudioDevInfo * >::difference_type >(val2);
  ecode3 = SWIG_AsVal_ptrdiff_t(swig_obj[2], &val3);
  if (!SWIG_IsOK(ecode3)) {
    SWIG_exception_fail(SWIG_ArgError(ecode3), "in method '" "AudioDevInfoVector___setslice__" "', argument " "3"" of type '" "std::vector< pj::AudioDevInfo * >::difference_type""'");
  } 
  arg3 = static_cast< std::vector< pj::AudioDevInfo * >::difference_type >(val3);
  try {
    std_vector_Sl_pj_AudioDevInfo_Sm__Sg____setslice____SWIG_0(arg1,arg2,arg3);
  } catch(std::out_of_range &_e) {
    SWIG_exception_fail(SWIG_IndexError, (&_e)->what());
  } catch(std::invalid_argument &_e) {
    SWIG_exception_fail(SWIG_ValueError, (&_e)->what());
  }
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_AudioDevInfoVector___setslice____SWIG_1(PyObject *SWIGUNUSEDPARM(self), Py_ssize_t nobjs, PyObject **swig_obj) {
  PyObject *resultobj = 0;
  std::vector< pj::AudioDevInfo * > *arg1 = (std::vector< pj::AudioDevInfo * > *) 0 ;
  std::vector< pj::AudioDevInfo * >::difference_type arg2 ;
  std::vector< pj::AudioDevInfo * >::difference_type arg3 ;
  std::vector< pj::AudioDevInfo *,std::allocator< pj::AudioDevInfo * > > *arg4 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  ptrdiff_t val2 ;
  int ecode2 = 0 ;
  ptrdiff_t val3 ;
  int ecode3 = 0 ;
  int res4 = SWIG_OLDOBJ ;
  
  if ((nobjs < 4) || (nobjs > 4)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__vectorT_pj__AudioDevInfo_p_std__allocatorT_pj__AudioDevInfo_p_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "AudioDevInfoVector___setslice__" "', argument " "1"" of type '" "std::vector< pj::AudioDevInfo * > *""'"); 
  }
  arg1 = reinterpret_cast< std::vector< pj::AudioDevInfo * > * >(argp1);
  ecode2 = SWIG_AsVal_ptrdiff_t(swig_obj[1], &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "AudioDevInfoVector___setslice__" "', argument " "2"" of type '" "std::vector< pj::AudioDevInfo * >::difference_type""'");
  } 
  arg2 = static_cast< std::vector< pj::AudioDevInfo * >::difference_type >(val2);
  ecode3 = SWIG_AsVal_ptrdiff_t(swig_obj[2], &val3);
  if (!SWIG_IsOK(ecode3)) {
    SWIG_exception_fail(SWIG_ArgError(ecode3), "in method '" "AudioDevInfoVector___setslice__" "', argument " "3"" of type '" "std::vector< pj::AudioDevInfo * >::difference_type""'");
  } 
  arg3 = static_cast< std::vector< pj::AudioDevInfo * >::difference_type >(val3);
  {
    std::vector< pj::AudioDevInfo*,std::allocator< pj::AudioDevInfo * > > *ptr = (std::vector< pj::AudioDevInfo*,std::allocator< pj::AudioDevInfo * > > *)0;
    res4 = swig::asptr(swig_obj[3], &ptr);
    if (!SWIG_IsOK(res4)) {
      SWIG_exception_fail(SWIG_ArgError(res4), "in method '" "AudioDevInfoVector___setslice__" "', argument " "4"" of type '" "std::vector< pj::AudioDevInfo *,std::allocator< pj::AudioDevInfo * > > const &""'"); 
    }
    if (!ptr) {
      SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "AudioDevInfoVector___setslice__" "', argument " "4"" of type '" "std::vector< pj::AudioDevInfo *,std::allocator< pj::AudioDevInfo * > > const &""'"); 
    }
    arg4 = ptr;
  }
  try {
    std_vector_Sl_pj_AudioDevInfo_Sm__Sg____setslice____SWIG_1(arg1,arg2,arg3,(std::vector< pj::AudioDevInfo *,std::allocator< pj::AudioDevInfo * > > const &)*arg4);
  } catch(std::out_of_range &_e) {
    SWIG_exception_fail(SWIG_IndexError, (&_e)->what());
  } catch(std::invalid_argument &_e) {
    SWIG_exception_fail(SWIG_ValueError, (&_e)->what());
  }
  resultobj = SWIG_Py_Void();
  if (SWIG_IsNewObj(res4)) delete arg4;
  return resultobj;
fail:
  if (SWIG_IsNewObj(res4)) delete arg4;
  return NULL;
}


SWIGINTERN PyObject *_wrap_AudioDevInfoVector___setslice__(PyObject *self, PyObject *args) {
  Py_ssize_t argc;
  PyObject *argv[5] = {
    0
  };
  
  if (!(argc = SWIG_Python_UnpackTuple(args, "AudioDevInfoVector___setslice__", 0, 4, argv))) SWIG_fail;
  --argc;
  if (argc == 3) {
    int _v;
    int res = swig::asptr(argv[0], (std::vector< pj::AudioDevInfo*,std::allocator< pj::AudioDevInfo * > >**)(0));
    _v = SWIG_CheckState(res);
    if (_v) {
      {
        int res = SWIG_AsVal_ptrdiff_t(argv[1], NULL);
        _v = SWIG_CheckState(res);
      }
      if (_v) {
        {
          int res = SWIG_AsVal_ptrdiff_t(argv[2], NULL);
          _v = SWIG_CheckState(res);
        }
        if (_v) {
          return _wrap_AudioDevInfoVector___setslice____SWIG_0(self, argc, argv);
        }
      }
    }
  }
  if (argc == 4) {
    int _v;
    int res = swig::asptr(argv[0], (std::vector< pj::AudioDevInfo*,std::allocator< pj::AudioDevInfo * > >**)(0));
    _v = SWIG_CheckState(res);
    if (_v) {
      {
        int res = SWIG_AsVal_ptrdiff_t(argv[1], NULL);
        _v = SWIG_CheckState(res);
      }
      if (_v) {
        {
          int res = SWIG_AsVal_ptrdiff_t(argv[2], NULL);
          _v = SWIG_CheckState(res);
        }
        if (_v) {
          int res = swig::asptr(argv[3], (std::vector< pj::AudioDevInfo*,std::allocator< pj::AudioDevInfo * > >**)(0));
          _v = SWIG_CheckState(res);
          if (_v) {
            return _wrap_AudioDevInfoVector___setslice____SWIG_1(self, argc, argv);
          }
        }
      }
    }
  }
  
fail:
  SWIG_Python_RaiseOrModifyTypeError("Wrong number or type of arguments for overloaded function 'AudioDevInfoVector___setslice__'.\n"
    "  Possible C/C++ prototypes are:\n"
    "    std::vector< pj::AudioDevInfo * >::__setslice__(std::vector< pj::AudioDevInfo * >::difference_type,std::vector< pj::AudioDevInfo * >::difference_type)\n"
    "    std::vector< pj::AudioDevInfo * >::__setslice__(std::vector< pj::AudioDevInfo * >::difference_type,std::vector< pj::AudioDevInfo * >::difference_type,std::vector< pj::AudioDevInfo *,std::allocator< pj::AudioDevInfo * > > const &)\n");
  return 0;
}


SWIGINTERN PyObject *_wrap_AudioDevInfoVector___delslice__(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  std::vector< pj::AudioDevInfo * > *arg1 = (std::vector< pj::AudioDevInfo * > *) 0 ;
  std::vector< pj::AudioDevInfo * >::difference_type arg2 ;
  std::vector< pj::AudioDevInfo * >::difference_type arg3 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  ptrdiff_t val2 ;
  int ecode2 = 0 ;
  ptrdiff_t val3 ;
  int ecode3 = 0 ;
  PyObject *swig_obj[3] ;
  
  if (!SWIG_Python_UnpackTuple(args, "AudioDevInfoVector___delslice__", 3, 3, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__vectorT_pj__AudioDevInfo_p_std__allocatorT_pj__AudioDevInfo_p_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "AudioDevInfoVector___delslice__" "', argument " "1"" of type '" "std::vector< pj::AudioDevInfo * > *""'"); 
  }
  arg1 = reinterpret_cast< std::vector< pj::AudioDevInfo * > * >(argp1);
  ecode2 = SWIG_AsVal_ptrdiff_t(swig_obj[1], &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "AudioDevInfoVector___delslice__" "', argument " "2"" of type '" "std::vector< pj::AudioDevInfo * >::difference_type""'");
  } 
  arg2 = static_cast< std::vector< pj::AudioDevInfo * >::difference_type >(val2);
  ecode3 = SWIG_AsVal_ptrdiff_t(swig_obj[2], &val3);
  if (!SWIG_IsOK(ecode3)) {
    SWIG_exception_fail(SWIG_ArgError(ecode3), "in method '" "AudioDevInfoVector___delslice__" "', argument " "3"" of type '" "std::vector< pj::AudioDevInfo * >::difference_type""'");
  } 
  arg3 = static_cast< std::vector< pj::AudioDevInfo * >::difference_type >(val3);
  try {
    std_vector_Sl_pj_AudioDevInfo_Sm__Sg____delslice__(arg1,arg2,arg3);
  } catch(std::out_of_range &_e) {
    SWIG_exception_fail(SWIG_IndexError, (&_e)->what());
  } catch(std::invalid_argument &_e) {
    SWIG_exception_fail(SWIG_ValueError, (&_e)->what());
  }
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_AudioDevInfoVector___delitem____SWIG_0(PyObject *SWIGUNUSEDPARM(self), Py_ssize_t nobjs, PyObject **swig_obj) {
  PyObject *resultobj = 0;
  std::vector< pj::AudioDevInfo * > *arg1 = (std::vector< pj::AudioDevInfo * > *) 0 ;
  std::vector< pj::AudioDevInfo * >::difference_type arg2 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  ptrdiff_t val2 ;
  int ecode2 = 0 ;
  
  if ((nobjs < 2) || (nobjs > 2)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__vectorT_pj__AudioDevInfo_p_std__allocatorT_pj__AudioDevInfo_p_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "AudioDevInfoVector___delitem__" "', argument " "1"" of type '" "std::vector< pj::AudioDevInfo * > *""'"); 
  }
  arg1 = reinterpret_cast< std::vector< pj::AudioDevInfo * > * >(argp1);
  ecode2 = SWIG_AsVal_ptrdiff_t(swig_obj[1], &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "AudioDevInfoVector___delitem__" "', argument " "2"" of type '" "std::vector< pj::AudioDevInfo * >::difference_type""'");
  } 
  arg2 = static_cast< std::vector< pj::AudioDevInfo * >::difference_type >(val2);
  try {
    std_vector_Sl_pj_AudioDevInfo_Sm__Sg____delitem____SWIG_0(arg1,arg2);
  } catch(std::out_of_range &_e) {
    SWIG_exception_fail(SWIG_IndexError, (&_e)->what());
  } catch(std::invalid_argument &_e) {
    SWIG_exception_fail(SWIG_ValueError, (&_e)->what());
  }
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_AudioDevInfoVector___getitem____SWIG_0(PyObject *SWIGUNUSEDPARM(self), Py_ssize_t nobjs, PyObject **swig_obj) {
  PyObject *resultobj = 0;
  std::vector< pj::AudioDevInfo * > *arg1 = (std::vector< pj::AudioDevInfo * > *) 0 ;
  PySliceObject *arg2 = (PySliceObject *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  std::vector< pj::AudioDevInfo *,std::allocator< pj::AudioDevInfo * > > *result = 0 ;
  
  if ((nobjs < 2) || (nobjs > 2)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__vectorT_pj__AudioDevInfo_p_std__allocatorT_pj__AudioDevInfo_p_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "AudioDevInfoVector___getitem__" "', argument " "1"" of type '" "std::vector< pj::AudioDevInfo * > *""'"); 
  }
  arg1 = reinterpret_cast< std::vector< pj::AudioDevInfo * > * >(argp1);
  {
    if (!PySlice_Check(swig_obj[1])) {
      SWIG_exception_fail(SWIG_ArgError(SWIG_TypeError), "in method '" "AudioDevInfoVector___getitem__" "', argument " "2"" of type '" "PySliceObject *""'");
    }
    arg2 = (PySliceObject *) swig_obj[1];
  }
  try {
    result = (std::vector< pj::AudioDevInfo *,std::allocator< pj::AudioDevInfo * > > *)std_vector_Sl_pj_AudioDevInfo_Sm__Sg____getitem____SWIG_0(arg1,arg2);
  } catch(std::out_of_range &_e) {
    SWIG_exception_fail(SWIG_IndexError, (&_e)->what());
  } catch(std::invalid_argument &_e) {
    SWIG_exception_fail(SWIG_ValueError, (&_e)->what());
  }
  resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(result), SWIGTYPE_p_std__vectorT_pj__AudioDevInfo_p_std__allocatorT_pj__AudioDevInfo_p_t_t, SWIG_POINTER_OWN |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_AudioDevInfoVector___setitem____SWIG_0(PyObject *SWIGUNUSEDPARM(self), Py_ssize_t nobjs, PyObject **swig_obj) {
  PyObject *resultobj = 0;
  std::vector< pj::AudioDevInfo * > *arg1 = (std::vector< pj::AudioDevInfo * > *) 0 ;
  PySliceObject *arg2 = (PySliceObject *) 0 ;
  std::vector< pj::AudioDevInfo *,std::allocator< pj::AudioDevInfo * > > *arg3 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  int res3 = SWIG_OLDOBJ ;
  
  if ((nobjs < 3) || (nobjs > 3)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__vectorT_pj__AudioDevInfo_p_std__allocatorT_pj__AudioDevInfo_p_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "AudioDevInfoVector___setitem__" "', argument " "1"" of type '" "std::vector< pj::AudioDevInfo * > *""'"); 
  }
  arg1 = reinterpret_cast< std::vector< pj::AudioDevInfo * > * >(argp1);
  {
    if (!PySlice_Check(swig_obj[1])) {
      SWIG_exception_fail(SWIG_ArgError(SWIG_TypeError), "in method '" "AudioDevInfoVector___setitem__" "', argument " "2"" of type '" "PySliceObject *""'");
    }
    arg2 = (PySliceObject *) swig_obj[1];
  }
  {
    std::vector< pj::AudioDevInfo*,std::allocator< pj::AudioDevInfo * > > *ptr = (std::vector< pj::AudioDevInfo*,std::allocator< pj::AudioDevInfo * > > *)0;
    res3 = swig::asptr(swig_obj[2], &ptr);
    if (!SWIG_IsOK(res3)) {
      SWIG_exception_fail(SWIG_ArgError(res3), "in method '" "AudioDevInfoVector___setitem__" "', argument " "3"" of type '" "std::vector< pj::AudioDevInfo *,std::allocator< pj::AudioDevInfo * > > const &""'"); 
    }
    if (!ptr) {
      SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "AudioDevInfoVector___setitem__" "', argument " "3"" of type '" "std::vector< pj::AudioDevInfo *,std::allocator< pj::AudioDevInfo * > > const &""'"); 
    }
    arg3 = ptr;
  }
  try {
    std_vector_Sl_pj_AudioDevInfo_Sm__Sg____setitem____SWIG_0(arg1,arg2,(std::vector< pj::AudioDevInfo *,std::allocator< pj::AudioDevInfo * > > const &)*arg3);
  } catch(std::out_of_range &_e) {
    SWIG_exception_fail(SWIG_IndexError, (&_e)->what());
  } catch(std::invalid_argument &_e) {
    SWIG_exception_fail(SWIG_ValueError, (&_e)->what());
  }
  resultobj = SWIG_Py_Void();
  if (SWIG_IsNewObj(res3)) delete arg3;
  return resultobj;
fail:
  if (SWIG_IsNewObj(res3)) delete arg3;
  return NULL;
}


SWIGINTERN PyObject *_wrap_AudioDevInfoVector___setitem____SWIG_1(PyObject *SWIGUNUSEDPARM(self), Py_ssize_t nobjs, PyObject **swig_obj) {
  PyObject *resultobj = 0;
  std::vector< pj::AudioDevInfo * > *arg1 = (std::vector< pj::AudioDevInfo * > *) 0 ;
  PySliceObject *arg2 = (PySliceObject *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  
  if ((nobjs < 2) || (nobjs > 2)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__vectorT_pj__AudioDevInfo_p_std__allocatorT_pj__AudioDevInfo_p_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "AudioDevInfoVector___setitem__" "', argument " "1"" of type '" "std::vector< pj::AudioDevInfo * > *""'"); 
  }
  arg1 = reinterpret_cast< std::vector< pj::AudioDevInfo * > * >(argp1);
  {
    if (!PySlice_Check(swig_obj[1])) {
      SWIG_exception_fail(SWIG_ArgError(SWIG_TypeError), "in method '" "AudioDevInfoVector___setitem__" "', argument " "2"" of type '" "PySliceObject *""'");
    }
    arg2 = (PySliceObject *) swig_obj[1];
  }
  try {
    std_vector_Sl_pj_AudioDevInfo_Sm__Sg____setitem____SWIG_1(arg1,arg2);
  } catch(std::out_of_range &_e) {
    SWIG_exception_fail(SWIG_IndexError, (&_e)->what());
  } catch(std::invalid_argument &_e) {
    SWIG_exception_fail(SWIG_ValueError, (&_e)->what());
  }
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_AudioDevInfoVector___delitem____SWIG_1(PyObject *SWIGUNUSEDPARM(self), Py_ssize_t nobjs, PyObject **swig_obj) {
  PyObject *resultobj = 0;
  std::vector< pj::AudioDevInfo * > *arg1 = (std::vector< pj::AudioDevInfo * > *) 0 ;
  PySliceObject *arg2 = (PySliceObject *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  
  if ((nobjs < 2) || (nobjs > 2)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__vectorT_pj__AudioDevInfo_p_std__allocatorT_pj__AudioDevInfo_p_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "AudioDevInfoVector___delitem__" "', argument " "1"" of type '" "std::vector< pj::AudioDevInfo * > *""'"); 
  }
  arg1 = reinterpret_cast< std::vector< pj::AudioDevInfo * > * >(argp1);
  {
    if (!PySlice_Check(swig_obj[1])) {
      SWIG_exception_fail(SWIG_ArgError(SWIG_TypeError), "in method '" "AudioDevInfoVector___delitem__" "', argument " "2"" of type '" "PySliceObject *""'");
    }
    arg2 = (PySliceObject *) swig_obj[1];
  }
  try {
    std_vector_Sl_pj_AudioDevInfo_Sm__Sg____delitem____SWIG_1(arg1,arg2);
  } catch(std::out_of_range &_e) {
    SWIG_exception_fail(SWIG_IndexError, (&_e)->what());
  } catch(std::invalid_argument &_e) {
    SWIG_exception_fail(SWIG_ValueError, (&_e)->what());
  }
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_AudioDevInfoVector___delitem__(PyObject *self, PyObject *args) {
  Py_ssize_t argc;
  PyObject *argv[3] = {
    0
  };
  
  if (!(argc = SWIG_Python_UnpackTuple(args, "AudioDevInfoVector___delitem__", 0, 2, argv))) SWIG_fail;
  --argc;
  if (argc == 2) {
    int _v;
    int res = swig::asptr(argv[0], (std::vector< pj::AudioDevInfo*,std::allocator< pj::AudioDevInfo * > >**)(0));
    _v = SWIG_CheckState(res);
    if (_v) {
      {
        _v = PySlice_Check(argv[1]);
      }
      if (_v) {
        return _wrap_AudioDevInfoVector___delitem____SWIG_1(self, argc, argv);
      }
    }
  }
  if (argc == 2) {
    int _v;
    int res = swig::asptr(argv[0], (std::vector< pj::AudioDevInfo*,std::allocator< pj::AudioDevInfo * > >**)(0));
    _v = SWIG_CheckState(res);
    if (_v) {
      {
        int res = SWIG_AsVal_ptrdiff_t(argv[1], NULL);
        _v = SWIG_CheckState(res);
      }
      if (_v) {
        return _wrap_AudioDevInfoVector___delitem____SWIG_0(self, argc, argv);
      }
    }
  }
  
fail:
  SWIG_Python_RaiseOrModifyTypeError("Wrong number or type of arguments for overloaded function 'AudioDevInfoVector___delitem__'.\n"
    "  Possible C/C++ prototypes are:\n"
    "    std::vector< pj::AudioDevInfo * >::__delitem__(std::vector< pj::AudioDevInfo * >::difference_type)\n"
    "    std::vector< pj::AudioDevInfo * >::__delitem__(PySliceObject *)\n");
  return 0;
}


SWIGINTERN PyObject *_wrap_AudioDevInfoVector___getitem____SWIG_1(PyObject *SWIGUNUSEDPARM(self), Py_ssize_t nobjs, PyObject **swig_obj) {
  PyObject *resultobj = 0;
  std::vector< pj::AudioDevInfo * > *arg1 = (std::vector< pj::AudioDevInfo * > *) 0 ;
  std::vector< pj::AudioDevInfo * >::difference_type arg2 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  ptrdiff_t val2 ;
  int ecode2 = 0 ;
  std::vector< pj::AudioDevInfo * >::value_type result;
  
  if ((nobjs < 2) || (nobjs > 2)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__vectorT_pj__AudioDevInfo_p_std__allocatorT_pj__AudioDevInfo_p_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "AudioDevInfoVector___getitem__" "', argument " "1"" of type '" "std::vector< pj::AudioDevInfo * > *""'"); 
  }
  arg1 = reinterpret_cast< std::vector< pj::AudioDevInfo * > * >(argp1);
  ecode2 = SWIG_AsVal_ptrdiff_t(swig_obj[1], &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "AudioDevInfoVector___getitem__" "', argument " "2"" of type '" "std::vector< pj::AudioDevInfo * >::difference_type""'");
  } 
  arg2 = static_cast< std::vector< pj::AudioDevInfo * >::difference_type >(val2);
  try {
    result = (std::vector< pj::AudioDevInfo * >::value_type)std_vector_Sl_pj_AudioDevInfo_Sm__Sg____getitem____SWIG_1(arg1,arg2);
  } catch(std::out_of_range &_e) {
    SWIG_exception_fail(SWIG_IndexError, (&_e)->what());
  }
  resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(result), SWIGTYPE_p_pj__AudioDevInfo, 0 |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_AudioDevInfoVector___getitem__(PyObject *self, PyObject *args) {
  Py_ssize_t argc;
  PyObject *argv[3] = {
    0
  };
  
  if (!(argc = SWIG_Python_UnpackTuple(args, "AudioDevInfoVector___getitem__", 0, 2, argv))) SWIG_fail;
  --argc;
  if (argc == 2) {
    int _v;
    int res = swig::asptr(argv[0], (std::vector< pj::AudioDevInfo*,std::allocator< pj::AudioDevInfo * > >**)(0));
    _v = SWIG_CheckState(res);
    if (_v) {
      {
        _v = PySlice_Check(argv[1]);
      }
      if (_v) {
        return _wrap_AudioDevInfoVector___getitem____SWIG_0(self, argc, argv);
      }
    }
  }
  if (argc == 2) {
    int _v;
    int res = swig::asptr(argv[0], (std::vector< pj::AudioDevInfo*,std::allocator< pj::AudioDevInfo * > >**)(0));
    _v = SWIG_CheckState(res);
    if (_v) {
      {
        int res = SWIG_AsVal_ptrdiff_t(argv[1], NULL);
        _v = SWIG_CheckState(res);
      }
      if (_v) {
        return _wrap_AudioDevInfoVector___getitem____SWIG_1(self, argc, argv);
      }
    }
  }
  
fail:
  SWIG_Python_RaiseOrModifyTypeError("Wrong number or type of arguments for overloaded function 'AudioDevInfoVector___getitem__'.\n"
    "  Possible C/C++ prototypes are:\n"
    "    std::vector< pj::AudioDevInfo * >::__getitem__(PySliceObject *)\n"
    "    std::vector< pj::AudioDevInfo * >::__getitem__(std::vector< pj::AudioDevInfo * >::difference_type)\n");
  return 0;
}


SWIGINTERN PyObject *_wrap_AudioDevInfoVector___setitem____SWIG_2(PyObject *SWIGUNUSEDPARM(self), Py_ssize_t nobjs, PyObject **swig_obj) {
  PyObject *resultobj = 0;
  std::vector< pj::AudioDevInfo * > *arg1 = (std::vector< pj::AudioDevInfo * > *) 0 ;
  std::vector< pj::AudioDevInfo * >::difference_type arg2 ;
  std::vector< pj::AudioDevInfo * >::value_type arg3 = (std::vector< pj::AudioDevInfo * >::value_type) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  ptrdiff_t val2 ;
  int ecode2 = 0 ;
  void *argp3 = 0 ;
  int res3 = 0 ;
  
  if ((nobjs < 3) || (nobjs > 3)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__vectorT_pj__AudioDevInfo_p_std__allocatorT_pj__AudioDevInfo_p_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "AudioDevInfoVector___setitem__" "', argument " "1"" of type '" "std::vector< pj::AudioDevInfo * > *""'"); 
  }
  arg1 = reinterpret_cast< std::vector< pj::AudioDevInfo * > * >(argp1);
  ecode2 = SWIG_AsVal_ptrdiff_t(swig_obj[1], &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "AudioDevInfoVector___setitem__" "', argument " "2"" of type '" "std::vector< pj::AudioDevInfo * >::difference_type""'");
  } 
  arg2 = static_cast< std::vector< pj::AudioDevInfo * >::difference_type >(val2);
  res3 = SWIG_ConvertPtr(swig_obj[2], &argp3,SWIGTYPE_p_pj__AudioDevInfo, 0 |  0 );
  if (!SWIG_IsOK(res3)) {
    SWIG_exception_fail(SWIG_ArgError(res3), "in method '" "AudioDevInfoVector___setitem__" "', argument " "3"" of type '" "std::vector< pj::AudioDevInfo * >::value_type""'"); 
  }
  arg3 = reinterpret_cast< std::vector< pj::AudioDevInfo * >::value_type >(argp3);
  try {
    std_vector_Sl_pj_AudioDevInfo_Sm__Sg____setitem____SWIG_2(arg1,arg2,arg3);
  } catch(std::out_of_range &_e) {
    SWIG_exception_fail(SWIG_IndexError, (&_e)->what());
  }
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_AudioDevInfoVector___setitem__(PyObject *self, PyObject *args) {
  Py_ssize_t argc;
  PyObject *argv[4] = {
    0
  };
  
  if (!(argc = SWIG_Python_UnpackTuple(args, "AudioDevInfoVector___setitem__", 0, 3, argv))) SWIG_fail;
  --argc;
  if (argc == 2) {
    int _v;
    int res = swig::asptr(argv[0], (std::vector< pj::AudioDevInfo*,std::allocator< pj::AudioDevInfo * > >**)(0));
    _v = SWIG_CheckState(res);
    if (_v) {
      {
        _v = PySlice_Check(argv[1]);
      }
      if (_v) {
        return _wrap_AudioDevInfoVector___setitem____SWIG_1(self, argc, argv);
      }
    }
  }
  if (argc == 3) {
    int _v;
    int res = swig::asptr(argv[0], (std::vector< pj::AudioDevInfo*,std::allocator< pj::AudioDevInfo * > >**)(0));
    _v = SWIG_CheckState(res);
    if (_v) {
      {
        _v = PySlice_Check(argv[1]);
      }
      if (_v) {
        int res = swig::asptr(argv[2], (std::vector< pj::AudioDevInfo*,std::allocator< pj::AudioDevInfo * > >**)(0));
        _v = SWIG_CheckState(res);
        if (_v) {
          return _wrap_AudioDevInfoVector___setitem____SWIG_0(self, argc, argv);
        }
      }
    }
  }
  if (argc == 3) {
    int _v;
    int res = swig::asptr(argv[0], (std::vector< pj::AudioDevInfo*,std::allocator< pj::AudioDevInfo * > >**)(0));
    _v = SWIG_CheckState(res);
    if (_v) {
      {
        int res = SWIG_AsVal_ptrdiff_t(argv[1], NULL);
        _v = SWIG_CheckState(res);
      }
      if (_v) {
        void *vptr = 0;
        int res = SWIG_ConvertPtr(argv[2], &vptr, SWIGTYPE_p_pj__AudioDevInfo, 0);
        _v = SWIG_CheckState(res);
        if (_v) {
          return _wrap_AudioDevInfoVector___setitem____SWIG_2(self, argc, argv);
        }
      }
    }
  }
  
fail:
  SWIG_Python_RaiseOrModifyTypeError("Wrong number or type of arguments for overloaded function 'AudioDevInfoVector___setitem__'.\n"
    "  Possible C/C++ prototypes are:\n"
    "    std::vector< pj::AudioDevInfo * >::__setitem__(PySliceObject *,std::vector< pj::AudioDevInfo *,std::allocator< pj::AudioDevInfo * > > const &)\n"
    "    std::vector< pj::AudioDevInfo * >::__setitem__(PySliceObject *)\n"
    "    std::vector< pj::AudioDevInfo * >::__setitem__(std::vector< pj::AudioDevInfo * >::difference_type,std::vector< pj::AudioDevInfo * >::value_type)\n");
  return 0;
}


SWIGINTERN PyObject *_wrap_AudioDevInfoVector_pop(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  std::vector< pj::AudioDevInfo * > *arg1 = (std::vector< pj::AudioDevInfo * > *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  std::vector< pj::AudioDevInfo * >::value_type result;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__vectorT_pj__AudioDevInfo_p_std__allocatorT_pj__AudioDevInfo_p_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "AudioDevInfoVector_pop" "', argument " "1"" of type '" "std::vector< pj::AudioDevInfo * > *""'"); 
  }
  arg1 = reinterpret_cast< std::vector< pj::AudioDevInfo * > * >(argp1);
  try {
    result = (std::vector< pj::AudioDevInfo * >::value_type)std_vector_Sl_pj_AudioDevInfo_Sm__Sg__pop(arg1);
  } catch(std::out_of_range &_e) {
    SWIG_exception_fail(SWIG_IndexError, (&_e)->what());
  }
  resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(result), SWIGTYPE_p_pj__AudioDevInfo, 0 |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_AudioDevInfoVector_append(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  std::vector< pj::AudioDevInfo * > *arg1 = (std::vector< pj::AudioDevInfo * > *) 0 ;
  std::vector< pj::AudioDevInfo * >::value_type arg2 = (std::vector< pj::AudioDevInfo * >::value_type) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  void *argp2 = 0 ;
  int res2 = 0 ;
  PyObject *swig_obj[2] ;
  
  if (!SWIG_Python_UnpackTuple(args, "AudioDevInfoVector_append", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__vectorT_pj__AudioDevInfo_p_std__allocatorT_pj__AudioDevInfo_p_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "AudioDevInfoVector_append" "', argument " "1"" of type '" "std::vector< pj::AudioDevInfo * > *""'"); 
  }
  arg1 = reinterpret_cast< std::vector< pj::AudioDevInfo * > * >(argp1);
  res2 = SWIG_ConvertPtr(swig_obj[1], &argp2,SWIGTYPE_p_pj__AudioDevInfo, 0 |  0 );
  if (!SWIG_IsOK(res2)) {
    SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "AudioDevInfoVector_append" "', argument " "2"" of type '" "std::vector< pj::AudioDevInfo * >::value_type""'"); 
  }
  arg2 = reinterpret_cast< std::vector< pj::AudioDevInfo * >::value_type >(argp2);
  std_vector_Sl_pj_AudioDevInfo_Sm__Sg__append(arg1,arg2);
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_new_AudioDevInfoVector__SWIG_0(PyObject *SWIGUNUSEDPARM(self), Py_ssize_t nobjs, PyObject **SWIGUNUSEDPARM(swig_obj)) {
  PyObject *resultobj = 0;
  std::vector< pj::AudioDevInfo * > *result = 0 ;
  
  if ((nobjs < 0) || (nobjs > 0)) SWIG_fail;
  result = (std::vector< pj::AudioDevInfo * > *)new std::vector< pj::AudioDevInfo * >();
  resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(result), SWIGTYPE_p_std__vectorT_pj__AudioDevInfo_p_std__allocatorT_pj__AudioDevInfo_p_t_t, SWIG_POINTER_NEW |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_new_AudioDevInfoVector__SWIG_1(PyObject *SWIGUNUSEDPARM(self), Py_ssize_t nobjs, PyObject **swig_obj) {
  PyObject *resultobj = 0;
  std::vector< pj::AudioDevInfo * > *arg1 = 0 ;
  int res1 = SWIG_OLDOBJ ;
  std::vector< pj::AudioDevInfo * > *result = 0 ;
  
  if ((nobjs < 1) || (nobjs > 1)) SWIG_fail;
  {
    std::vector< pj::AudioDevInfo*,std::allocator< pj::AudioDevInfo * > > *ptr = (std::vector< pj::AudioDevInfo*,std::allocator< pj::AudioDevInfo * > > *)0;
    res1 = swig::asptr(swig_obj[0], &ptr);
    if (!SWIG_IsOK(res1)) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "new_AudioDevInfoVector" "', argument " "1"" of type '" "std::vector< pj::AudioDevInfo * > const &""'"); 
    }
    if (!ptr) {
      SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "new_AudioDevInfoVector" "', argument " "1"" of type '" "std::vector< pj::AudioDevInfo * > const &""'"); 
    }
    arg1 = ptr;
  }
  result = (std::vector< pj::AudioDevInfo * > *)new std::vector< pj::AudioDevInfo * >((std::vector< pj::AudioDevInfo * > const &)*arg1);
  resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(result), SWIGTYPE_p_std__vectorT_pj__AudioDevInfo_p_std__allocatorT_pj__AudioDevInfo_p_t_t, SWIG_POINTER_NEW |  0 );
  if (SWIG_IsNewObj(res1)) delete arg1;
  return resultobj;
fail:
  if (SWIG_IsNewObj(res1)) delete arg1;
  return NULL;
}


SWIGINTERN PyObject *_wrap_AudioDevInfoVector_empty(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  std::vector< pj::AudioDevInfo * > *arg1 = (std::vector< pj::AudioDevInfo * > *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  bool result;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__vectorT_pj__AudioDevInfo_p_std__allocatorT_pj__AudioDevInfo_p_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "AudioDevInfoVector_empty" "', argument " "1"" of type '" "std::vector< pj::AudioDevInfo * > const *""'"); 
  }
  arg1 = reinterpret_cast< std::vector< pj::AudioDevInfo * > * >(argp1);
  result = (bool)((std::vector< pj::AudioDevInfo * > const *)arg1)->empty();
  resultobj = SWIG_From_bool(static_cast< bool >(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_AudioDevInfoVector_size(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  std::vector< pj::AudioDevInfo * > *arg1 = (std::vector< pj::AudioDevInfo * > *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  std::vector< pj::AudioDevInfo * >::size_type result;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__vectorT_pj__AudioDevInfo_p_std__allocatorT_pj__AudioDevInfo_p_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "AudioDevInfoVector_size" "', argument " "1"" of type '" "std::vector< pj::AudioDevInfo * > const *""'"); 
  }
  arg1 = reinterpret_cast< std::vector< pj::AudioDevInfo * > * >(argp1);
  result = ((std::vector< pj::AudioDevInfo * > const *)arg1)->size();
  resultobj = SWIG_From_size_t(static_cast< size_t >(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_AudioDevInfoVector_swap(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  std::vector< pj::AudioDevInfo * > *arg1 = (std::vector< pj::AudioDevInfo * > *) 0 ;
  std::vector< pj::AudioDevInfo * > *arg2 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  void *argp2 = 0 ;
  int res2 = 0 ;
  PyObject *swig_obj[2] ;
  
  if (!SWIG_Python_UnpackTuple(args, "AudioDevInfoVector_swap", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__vectorT_pj__AudioDevInfo_p_std__allocatorT_pj__AudioDevInfo_p_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "AudioDevInfoVector_swap" "', argument " "1"" of type '" "std::vector< pj::AudioDevInfo * > *""'"); 
  }
  arg1 = reinterpret_cast< std::vector< pj::AudioDevInfo * > * >(argp1);
  res2 = SWIG_ConvertPtr(swig_obj[1], &argp2, SWIGTYPE_p_std__vectorT_pj__AudioDevInfo_p_std__allocatorT_pj__AudioDevInfo_p_t_t,  0 );
  if (!SWIG_IsOK(res2)) {
    SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "AudioDevInfoVector_swap" "', argument " "2"" of type '" "std::vector< pj::AudioDevInfo * > &""'"); 
  }
  if (!argp2) {
    SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "AudioDevInfoVector_swap" "', argument " "2"" of type '" "std::vector< pj::AudioDevInfo * > &""'"); 
  }
  arg2 = reinterpret_cast< std::vector< pj::AudioDevInfo * > * >(argp2);
  (arg1)->swap(*arg2);
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_AudioDevInfoVector_begin(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  std::vector< pj::AudioDevInfo * > *arg1 = (std::vector< pj::AudioDevInfo * > *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  std::vector< pj::AudioDevInfo * >::iterator result;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__vectorT_pj__AudioDevInfo_p_std__allocatorT_pj__AudioDevInfo_p_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "AudioDevInfoVector_begin" "', argument " "1"" of type '" "std::vector< pj::AudioDevInfo * > *""'"); 
  }
  arg1 = reinterpret_cast< std::vector< pj::AudioDevInfo * > * >(argp1);
  result = (arg1)->begin();
  resultobj = SWIG_NewPointerObj(swig::make_output_iterator(static_cast< const std::vector< pj::AudioDevInfo * >::iterator & >(result)),
    swig::SwigPyIterator::descriptor(),SWIG_POINTER_OWN);
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_AudioDevInfoVector_end(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  std::vector< pj::AudioDevInfo * > *arg1 = (std::vector< pj::AudioDevInfo * > *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  std::vector< pj::AudioDevInfo * >::iterator result;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__vectorT_pj__AudioDevInfo_p_std__allocatorT_pj__AudioDevInfo_p_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "AudioDevInfoVector_end" "', argument " "1"" of type '" "std::vector< pj::AudioDevInfo * > *""'"); 
  }
  arg1 = reinterpret_cast< std::vector< pj::AudioDevInfo * > * >(argp1);
  result = (arg1)->end();
  resultobj = SWIG_NewPointerObj(swig::make_output_iterator(static_cast< const std::vector< pj::AudioDevInfo * >::iterator & >(result)),
    swig::SwigPyIterator::descriptor(),SWIG_POINTER_OWN);
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_AudioDevInfoVector_rbegin(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  std::vector< pj::AudioDevInfo * > *arg1 = (std::vector< pj::AudioDevInfo * > *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  std::vector< pj::AudioDevInfo * >::reverse_iterator result;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__vectorT_pj__AudioDevInfo_p_std__allocatorT_pj__AudioDevInfo_p_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "AudioDevInfoVector_rbegin" "', argument " "1"" of type '" "std::vector< pj::AudioDevInfo * > *""'"); 
  }
  arg1 = reinterpret_cast< std::vector< pj::AudioDevInfo * > * >(argp1);
  result = (arg1)->rbegin();
  resultobj = SWIG_NewPointerObj(swig::make_output_iterator(static_cast< const std::vector< pj::AudioDevInfo * >::reverse_iterator & >(result)),
    swig::SwigPyIterator::descriptor(),SWIG_POINTER_OWN);
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_AudioDevInfoVector_rend(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  std::vector< pj::AudioDevInfo * > *arg1 = (std::vector< pj::AudioDevInfo * > *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  std::vector< pj::AudioDevInfo * >::reverse_iterator result;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__vectorT_pj__AudioDevInfo_p_std__allocatorT_pj__AudioDevInfo_p_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "AudioDevInfoVector_rend" "', argument " "1"" of type '" "std::vector< pj::AudioDevInfo * > *""'"); 
  }
  arg1 = reinterpret_cast< std::vector< pj::AudioDevInfo * > * >(argp1);
  result = (arg1)->rend();
  resultobj = SWIG_NewPointerObj(swig::make_output_iterator(static_cast< const std::vector< pj::AudioDevInfo * >::reverse_iterator & >(result)),
    swig::SwigPyIterator::descriptor(),SWIG_POINTER_OWN);
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_AudioDevInfoVector_clear(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  std::vector< pj::AudioDevInfo * > *arg1 = (std::vector< pj::AudioDevInfo * > *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__vectorT_pj__AudioDevInfo_p_std__allocatorT_pj__AudioDevInfo_p_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "AudioDevInfoVector_clear" "', argument " "1"" of type '" "std::vector< pj::AudioDevInfo * > *""'"); 
  }
  arg1 = reinterpret_cast< std::vector< pj::AudioDevInfo * > * >(argp1);
  (arg1)->clear();
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_AudioDevInfoVector_get_allocator(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  std::vector< pj::AudioDevInfo * > *arg1 = (std::vector< pj::AudioDevInfo * > *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  SwigValueWrapper< std::allocator< pj::AudioDevInfo * > > result;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__vectorT_pj__AudioDevInfo_p_std__allocatorT_pj__AudioDevInfo_p_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "AudioDevInfoVector_get_allocator" "', argument " "1"" of type '" "std::vector< pj::AudioDevInfo * > const *""'"); 
  }
  arg1 = reinterpret_cast< std::vector< pj::AudioDevInfo * > * >(argp1);
  result = ((std::vector< pj::AudioDevInfo * > const *)arg1)->get_allocator();
  resultobj = SWIG_NewPointerObj((new std::vector< pj::AudioDevInfo * >::allocator_type(static_cast< const std::vector< pj::AudioDevInfo * >::allocator_type& >(result))), SWIGTYPE_p_std__allocatorT_pj__AudioDevInfo_p_t, SWIG_POINTER_OWN |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_new_AudioDevInfoVector__SWIG_2(PyObject *SWIGUNUSEDPARM(self), Py_ssize_t nobjs, PyObject **swig_obj) {
  PyObject *resultobj = 0;
  std::vector< pj::AudioDevInfo * >::size_type arg1 ;
  size_t val1 ;
  int ecode1 = 0 ;
  std::vector< pj::AudioDevInfo * > *result = 0 ;
  
  if ((nobjs < 1) || (nobjs > 1)) SWIG_fail;
  ecode1 = SWIG_AsVal_size_t(swig_obj[0], &val1);
  if (!SWIG_IsOK(ecode1)) {
    SWIG_exception_fail(SWIG_ArgError(ecode1), "in method '" "new_AudioDevInfoVector" "', argument " "1"" of type '" "std::vector< pj::AudioDevInfo * >::size_type""'");
  } 
  arg1 = static_cast< std::vector< pj::AudioDevInfo * >::size_type >(val1);
  result = (std::vector< pj::AudioDevInfo * > *)new std::vector< pj::AudioDevInfo * >(arg1);
  resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(result), SWIGTYPE_p_std__vectorT_pj__AudioDevInfo_p_std__allocatorT_pj__AudioDevInfo_p_t_t, SWIG_POINTER_NEW |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_AudioDevInfoVector_pop_back(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  std::vector< pj::AudioDevInfo * > *arg1 = (std::vector< pj::AudioDevInfo * > *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__vectorT_pj__AudioDevInfo_p_std__allocatorT_pj__AudioDevInfo_p_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "AudioDevInfoVector_pop_back" "', argument " "1"" of type '" "std::vector< pj::AudioDevInfo * > *""'"); 
  }
  arg1 = reinterpret_cast< std::vector< pj::AudioDevInfo * > * >(argp1);
  (arg1)->pop_back();
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_AudioDevInfoVector_resize__SWIG_0(PyObject *SWIGUNUSEDPARM(self), Py_ssize_t nobjs, PyObject **swig_obj) {
  PyObject *resultobj = 0;
  std::vector< pj::AudioDevInfo * > *arg1 = (std::vector< pj::AudioDevInfo * > *) 0 ;
  std::vector< pj::AudioDevInfo * >::size_type arg2 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  size_t val2 ;
  int ecode2 = 0 ;
  
  if ((nobjs < 2) || (nobjs > 2)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__vectorT_pj__AudioDevInfo_p_std__allocatorT_pj__AudioDevInfo_p_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "AudioDevInfoVector_resize" "', argument " "1"" of type '" "std::vector< pj::AudioDevInfo * > *""'"); 
  }
  arg1 = reinterpret_cast< std::vector< pj::AudioDevInfo * > * >(argp1);
  ecode2 = SWIG_AsVal_size_t(swig_obj[1], &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "AudioDevInfoVector_resize" "', argument " "2"" of type '" "std::vector< pj::AudioDevInfo * >::size_type""'");
  } 
  arg2 = static_cast< std::vector< pj::AudioDevInfo * >::size_type >(val2);
  (arg1)->resize(arg2);
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_AudioDevInfoVector_erase__SWIG_0(PyObject *SWIGUNUSEDPARM(self), Py_ssize_t nobjs, PyObject **swig_obj) {
  PyObject *resultobj = 0;
  std::vector< pj::AudioDevInfo * > *arg1 = (std::vector< pj::AudioDevInfo * > *) 0 ;
  std::vector< pj::AudioDevInfo * >::iterator arg2 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  swig::SwigPyIterator *iter2 = 0 ;
  int res2 ;
  std::vector< pj::AudioDevInfo * >::iterator result;
  
  if ((nobjs < 2) || (nobjs > 2)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__vectorT_pj__AudioDevInfo_p_std__allocatorT_pj__AudioDevInfo_p_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "AudioDevInfoVector_erase" "', argument " "1"" of type '" "std::vector< pj::AudioDevInfo * > *""'"); 
  }
  arg1 = reinterpret_cast< std::vector< pj::AudioDevInfo * > * >(argp1);
  res2 = SWIG_ConvertPtr(swig_obj[1], SWIG_as_voidptrptr(&iter2), swig::SwigPyIterator::descriptor(), 0);
  if (!SWIG_IsOK(res2) || !iter2) {
    SWIG_exception_fail(SWIG_ArgError(SWIG_TypeError), "in method '" "AudioDevInfoVector_erase" "', argument " "2"" of type '" "std::vector< pj::AudioDevInfo * >::iterator""'");
  } else {
    swig::SwigPyIterator_T<std::vector< pj::AudioDevInfo * >::iterator > *iter_t = dynamic_cast<swig::SwigPyIterator_T<std::vector< pj::AudioDevInfo * >::iterator > *>(iter2);
    if (iter_t) {
      arg2 = iter_t->get_current();
    } else {
      SWIG_exception_fail(SWIG_ArgError(SWIG_TypeError), "in method '" "AudioDevInfoVector_erase" "', argument " "2"" of type '" "std::vector< pj::AudioDevInfo * >::iterator""'");
    }
  }
  result = std_vector_Sl_pj_AudioDevInfo_Sm__Sg__erase__SWIG_0(arg1,arg2);
  resultobj = SWIG_NewPointerObj(swig::make_output_iterator(static_cast< const std::vector< pj::AudioDevInfo * >::iterator & >(result)),
    swig::SwigPyIterator::descriptor(),SWIG_POINTER_OWN);
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_AudioDevInfoVector_erase__SWIG_1(PyObject *SWIGUNUSEDPARM(self), Py_ssize_t nobjs, PyObject **swig_obj) {
  PyObject *resultobj = 0;
  std::vector< pj::AudioDevInfo * > *arg1 = (std::vector< pj::AudioDevInfo * > *) 0 ;
  std::vector< pj::AudioDevInfo * >::iterator arg2 ;
  std::vector< pj::AudioDevInfo * >::iterator arg3 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  swig::SwigPyIterator *iter2 = 0 ;
  int res2 ;
  swig::SwigPyIterator *iter3 = 0 ;
  int res3 ;
  std::vector< pj::AudioDevInfo * >::iterator result;
  
  if ((nobjs < 3) || (nobjs > 3)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__vectorT_pj__AudioDevInfo_p_std__allocatorT_pj__AudioDevInfo_p_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "AudioDevInfoVector_erase" "', argument " "1"" of type '" "std::vector< pj::AudioDevInfo * > *""'"); 
  }
  arg1 = reinterpret_cast< std::vector< pj::AudioDevInfo * > * >(argp1);
  res2 = SWIG_ConvertPtr(swig_obj[1], SWIG_as_voidptrptr(&iter2), swig::SwigPyIterator::descriptor(), 0);
  if (!SWIG_IsOK(res2) || !iter2) {
    SWIG_exception_fail(SWIG_ArgError(SWIG_TypeError), "in method '" "AudioDevInfoVector_erase" "', argument " "2"" of type '" "std::vector< pj::AudioDevInfo * >::iterator""'");
  } else {
    swig::SwigPyIterator_T<std::vector< pj::AudioDevInfo * >::iterator > *iter_t = dynamic_cast<swig::SwigPyIterator_T<std::vector< pj::AudioDevInfo * >::iterator > *>(iter2);
    if (iter_t) {
      arg2 = iter_t->get_current();
    } else {
      SWIG_exception_fail(SWIG_ArgError(SWIG_TypeError), "in method '" "AudioDevInfoVector_erase" "', argument " "2"" of type '" "std::vector< pj::AudioDevInfo * >::iterator""'");
    }
  }
  res3 = SWIG_ConvertPtr(swig_obj[2], SWIG_as_voidptrptr(&iter3), swig::SwigPyIterator::descriptor(), 0);
  if (!SWIG_IsOK(res3) || !iter3) {
    SWIG_exception_fail(SWIG_ArgError(SWIG_TypeError), "in method '" "AudioDevInfoVector_erase" "', argument " "3"" of type '" "std::vector< pj::AudioDevInfo * >::iterator""'");
  } else {
    swig::SwigPyIterator_T<std::vector< pj::AudioDevInfo * >::iterator > *iter_t = dynamic_cast<swig::SwigPyIterator_T<std::vector< pj::AudioDevInfo * >::iterator > *>(iter3);
    if (iter_t) {
      arg3 = iter_t->get_current();
    } else {
      SWIG_exception_fail(SWIG_ArgError(SWIG_TypeError), "in method '" "AudioDevInfoVector_erase" "', argument " "3"" of type '" "std::vector< pj::AudioDevInfo * >::iterator""'");
    }
  }
  result = std_vector_Sl_pj_AudioDevInfo_Sm__Sg__erase__SWIG_1(arg1,arg2,arg3);
  resultobj = SWIG_NewPointerObj(swig::make_output_iterator(static_cast< const std::vector< pj::AudioDevInfo * >::iterator & >(result)),
    swig::SwigPyIterator::descriptor(),SWIG_POINTER_OWN);
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_AudioDevInfoVector_erase(PyObject *self, PyObject *args) {
  Py_ssize_t argc;
  PyObject *argv[4] = {
    0
  };
  
  if (!(argc = SWIG_Python_UnpackTuple(args, "AudioDevInfoVector_erase", 0, 3, argv))) SWIG_fail;
  --argc;
  if (argc == 2) {
    int _v;
    int res = swig::asptr(argv[0], (std::vector< pj::AudioDevInfo*,std::allocator< pj::AudioDevInfo * > >**)(0));
    _v = SWIG_CheckState(res);
    if (_v) {
      swig::SwigPyIterator *iter = 0;
      int res = SWIG_ConvertPtr(argv[1], SWIG_as_voidptrptr(&iter), swig::SwigPyIterator::descriptor(), 0);
      _v = (SWIG_IsOK(res) && iter && (dynamic_cast<swig::SwigPyIterator_T<std::vector< pj::AudioDevInfo * >::iterator > *>(iter) != 0));
      if (_v) {
        return _wrap_AudioDevInfoVector_erase__SWIG_0(self, argc, argv);
      }
    }
  }
  if (argc == 3) {
    int _v;
    int res = swig::asptr(argv[0], (std::vector< pj::AudioDevInfo*,std::allocator< pj::AudioDevInfo * > >**)(0));
    _v = SWIG_CheckState(res);
    if (_v) {
      swig::SwigPyIterator *iter = 0;
      int res = SWIG_ConvertPtr(argv[1], SWIG_as_voidptrptr(&iter), swig::SwigPyIterator::descriptor(), 0);
      _v = (SWIG_IsOK(res) && iter && (dynamic_cast<swig::SwigPyIterator_T<std::vector< pj::AudioDevInfo * >::iterator > *>(iter) != 0));
      if (_v) {
        swig::SwigPyIterator *iter = 0;
        int res = SWIG_ConvertPtr(argv[2], SWIG_as_voidptrptr(&iter), swig::SwigPyIterator::descriptor(), 0);
        _v = (SWIG_IsOK(res) && iter && (dynamic_cast<swig::SwigPyIterator_T<std::vector< pj::AudioDevInfo * >::iterator > *>(iter) != 0));
        if (_v) {
          return _wrap_AudioDevInfoVector_erase__SWIG_1(self, argc, argv);
        }
      }
    }
  }
  
fail:
  SWIG_Python_RaiseOrModifyTypeError("Wrong number or type of arguments for overloaded function 'AudioDevInfoVector_erase'.\n"
    "  Possible C/C++ prototypes are:\n"
    "    std::vector< pj::AudioDevInfo * >::erase(std::vector< pj::AudioDevInfo * >::iterator)\n"
    "    std::vector< pj::AudioDevInfo * >::erase(std::vector< pj::AudioDevInfo * >::iterator,std::vector< pj::AudioDevInfo * >::iterator)\n");
  return 0;
}


SWIGINTERN PyObject *_wrap_new_AudioDevInfoVector__SWIG_3(PyObject *SWIGUNUSEDPARM(self), Py_ssize_t nobjs, PyObject **swig_obj) {
  PyObject *resultobj = 0;
  std::vector< pj::AudioDevInfo * >::size_type arg1 ;
  std::vector< pj::AudioDevInfo * >::value_type arg2 = (std::vector< pj::AudioDevInfo * >::value_type) 0 ;
  size_t val1 ;
  int ecode1 = 0 ;
  void *argp2 = 0 ;
  int res2 = 0 ;
  std::vector< pj::AudioDevInfo * > *result = 0 ;
  
  if ((nobjs < 2) || (nobjs > 2)) SWIG_fail;
  ecode1 = SWIG_AsVal_size_t(swig_obj[0], &val1);
  if (!SWIG_IsOK(ecode1)) {
    SWIG_exception_fail(SWIG_ArgError(ecode1), "in method '" "new_AudioDevInfoVector" "', argument " "1"" of type '" "std::vector< pj::AudioDevInfo * >::size_type""'");
  } 
  arg1 = static_cast< std::vector< pj::AudioDevInfo * >::size_type >(val1);
  res2 = SWIG_ConvertPtr(swig_obj[1], &argp2,SWIGTYPE_p_pj__AudioDevInfo, 0 |  0 );
  if (!SWIG_IsOK(res2)) {
    SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "new_AudioDevInfoVector" "', argument " "2"" of type '" "std::vector< pj::AudioDevInfo * >::value_type""'"); 
  }
  arg2 = reinterpret_cast< std::vector< pj::AudioDevInfo * >::value_type >(argp2);
  result = (std::vector< pj::AudioDevInfo * > *)new std::vector< pj::AudioDevInfo * >(arg1,arg2);
  resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(result), SWIGTYPE_p_std__vectorT_pj__AudioDevInfo_p_std__allocatorT_pj__AudioDevInfo_p_t_t, SWIG_POINTER_NEW |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_new_AudioDevInfoVector(PyObject *self, PyObject *args) {
  Py_ssize_t argc;
  PyObject *argv[3] = {
    0
  };
  
  if (!(argc = SWIG_Python_UnpackTuple(args, "new_AudioDevInfoVector", 0, 2, argv))) SWIG_fail;
  --argc;
  if (argc == 0) {
    return _wrap_new_AudioDevInfoVector__SWIG_0(self, argc, argv);
  }
  if (argc == 1) {
    int _v;
    {
      int res = SWIG_AsVal_size_t(argv[0], NULL);
      _v = SWIG_CheckState(res);
    }
    if (_v) {
      return _wrap_new_AudioDevInfoVector__SWIG_2(self, argc, argv);
    }
  }
  if (argc == 1) {
    int _v;
    int res = swig::asptr(argv[0], (std::vector< pj::AudioDevInfo*,std::allocator< pj::AudioDevInfo * > >**)(0));
    _v = SWIG_CheckState(res);
    if (_v) {
      return _wrap_new_AudioDevInfoVector__SWIG_1(self, argc, argv);
    }
  }
  if (argc == 2) {
    int _v;
    {
      int res = SWIG_AsVal_size_t(argv[0], NULL);
      _v = SWIG_CheckState(res);
    }
    if (_v) {
      void *vptr = 0;
      int res = SWIG_ConvertPtr(argv[1], &vptr, SWIGTYPE_p_pj__AudioDevInfo, 0);
      _v = SWIG_CheckState(res);
      if (_v) {
        return _wrap_new_AudioDevInfoVector__SWIG_3(self, argc, argv);
      }
    }
  }
  
fail:
  SWIG_Python_RaiseOrModifyTypeError("Wrong number or type of arguments for overloaded function 'new_AudioDevInfoVector'.\n"
    "  Possible C/C++ prototypes are:\n"
    "    std::vector< pj::AudioDevInfo * >::vector()\n"
    "    std::vector< pj::AudioDevInfo * >::vector(std::vector< pj::AudioDevInfo * > const &)\n"
    "    std::vector< pj::AudioDevInfo * >::vector(std::vector< pj::AudioDevInfo * >::size_type)\n"
    "    std::vector< pj::AudioDevInfo * >::vector(std::vector< pj::AudioDevInfo * >::size_type,std::vector< pj::AudioDevInfo * >::value_type)\n");
  return 0;
}


SWIGINTERN PyObject *_wrap_AudioDevInfoVector_push_back(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  std::vector< pj::AudioDevInfo * > *arg1 = (std::vector< pj::AudioDevInfo * > *) 0 ;
  std::vector< pj::AudioDevInfo * >::value_type arg2 = (std::vector< pj::AudioDevInfo * >::value_type) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  void *argp2 = 0 ;
  int res2 = 0 ;
  PyObject *swig_obj[2] ;
  
  if (!SWIG_Python_UnpackTuple(args, "AudioDevInfoVector_push_back", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__vectorT_pj__AudioDevInfo_p_std__allocatorT_pj__AudioDevInfo_p_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "AudioDevInfoVector_push_back" "', argument " "1"" of type '" "std::vector< pj::AudioDevInfo * > *""'"); 
  }
  arg1 = reinterpret_cast< std::vector< pj::AudioDevInfo * > * >(argp1);
  res2 = SWIG_ConvertPtr(swig_obj[1], &argp2,SWIGTYPE_p_pj__AudioDevInfo, 0 |  0 );
  if (!SWIG_IsOK(res2)) {
    SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "AudioDevInfoVector_push_back" "', argument " "2"" of type '" "std::vector< pj::AudioDevInfo * >::value_type""'"); 
  }
  arg2 = reinterpret_cast< std::vector< pj::AudioDevInfo * >::value_type >(argp2);
  (arg1)->push_back(arg2);
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_AudioDevInfoVector_front(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  std::vector< pj::AudioDevInfo * > *arg1 = (std::vector< pj::AudioDevInfo * > *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  std::vector< pj::AudioDevInfo * >::value_type result;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__vectorT_pj__AudioDevInfo_p_std__allocatorT_pj__AudioDevInfo_p_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "AudioDevInfoVector_front" "', argument " "1"" of type '" "std::vector< pj::AudioDevInfo * > const *""'"); 
  }
  arg1 = reinterpret_cast< std::vector< pj::AudioDevInfo * > * >(argp1);
  result = (std::vector< pj::AudioDevInfo * >::value_type)((std::vector< pj::AudioDevInfo * > const *)arg1)->front();
  resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(result), SWIGTYPE_p_pj__AudioDevInfo, 0 |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_AudioDevInfoVector_back(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  std::vector< pj::AudioDevInfo * > *arg1 = (std::vector< pj::AudioDevInfo * > *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  std::vector< pj::AudioDevInfo * >::value_type result;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__vectorT_pj__AudioDevInfo_p_std__allocatorT_pj__AudioDevInfo_p_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "AudioDevInfoVector_back" "', argument " "1"" of type '" "std::vector< pj::AudioDevInfo * > const *""'"); 
  }
  arg1 = reinterpret_cast< std::vector< pj::AudioDevInfo * > * >(argp1);
  result = (std::vector< pj::AudioDevInfo * >::value_type)((std::vector< pj::AudioDevInfo * > const *)arg1)->back();
  resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(result), SWIGTYPE_p_pj__AudioDevInfo, 0 |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_AudioDevInfoVector_assign(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  std::vector< pj::AudioDevInfo * > *arg1 = (std::vector< pj::AudioDevInfo * > *) 0 ;
  std::vector< pj::AudioDevInfo * >::size_type arg2 ;
  std::vector< pj::AudioDevInfo * >::value_type arg3 = (std::vector< pj::AudioDevInfo * >::value_type) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  size_t val2 ;
  int ecode2 = 0 ;
  void *argp3 = 0 ;
  int res3 = 0 ;
  PyObject *swig_obj[3] ;
  
  if (!SWIG_Python_UnpackTuple(args, "AudioDevInfoVector_assign", 3, 3, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__vectorT_pj__AudioDevInfo_p_std__allocatorT_pj__AudioDevInfo_p_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "AudioDevInfoVector_assign" "', argument " "1"" of type '" "std::vector< pj::AudioDevInfo * > *""'"); 
  }
  arg1 = reinterpret_cast< std::vector< pj::AudioDevInfo * > * >(argp1);
  ecode2 = SWIG_AsVal_size_t(swig_obj[1], &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "AudioDevInfoVector_assign" "', argument " "2"" of type '" "std::vector< pj::AudioDevInfo * >::size_type""'");
  } 
  arg2 = static_cast< std::vector< pj::AudioDevInfo * >::size_type >(val2);
  res3 = SWIG_ConvertPtr(swig_obj[2], &argp3,SWIGTYPE_p_pj__AudioDevInfo, 0 |  0 );
  if (!SWIG_IsOK(res3)) {
    SWIG_exception_fail(SWIG_ArgError(res3), "in method '" "AudioDevInfoVector_assign" "', argument " "3"" of type '" "std::vector< pj::AudioDevInfo * >::value_type""'"); 
  }
  arg3 = reinterpret_cast< std::vector< pj::AudioDevInfo * >::value_type >(argp3);
  (arg1)->assign(arg2,arg3);
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_AudioDevInfoVector_resize__SWIG_1(PyObject *SWIGUNUSEDPARM(self), Py_ssize_t nobjs, PyObject **swig_obj) {
  PyObject *resultobj = 0;
  std::vector< pj::AudioDevInfo * > *arg1 = (std::vector< pj::AudioDevInfo * > *) 0 ;
  std::vector< pj::AudioDevInfo * >::size_type arg2 ;
  std::vector< pj::AudioDevInfo * >::value_type arg3 = (std::vector< pj::AudioDevInfo * >::value_type) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  size_t val2 ;
  int ecode2 = 0 ;
  void *argp3 = 0 ;
  int res3 = 0 ;
  
  if ((nobjs < 3) || (nobjs > 3)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__vectorT_pj__AudioDevInfo_p_std__allocatorT_pj__AudioDevInfo_p_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "AudioDevInfoVector_resize" "', argument " "1"" of type '" "std::vector< pj::AudioDevInfo * > *""'"); 
  }
  arg1 = reinterpret_cast< std::vector< pj::AudioDevInfo * > * >(argp1);
  ecode2 = SWIG_AsVal_size_t(swig_obj[1], &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "AudioDevInfoVector_resize" "', argument " "2"" of type '" "std::vector< pj::AudioDevInfo * >::size_type""'");
  } 
  arg2 = static_cast< std::vector< pj::AudioDevInfo * >::size_type >(val2);
  res3 = SWIG_ConvertPtr(swig_obj[2], &argp3,SWIGTYPE_p_pj__AudioDevInfo, 0 |  0 );
  if (!SWIG_IsOK(res3)) {
    SWIG_exception_fail(SWIG_ArgError(res3), "in method '" "AudioDevInfoVector_resize" "', argument " "3"" of type '" "std::vector< pj::AudioDevInfo * >::value_type""'"); 
  }
  arg3 = reinterpret_cast< std::vector< pj::AudioDevInfo * >::value_type >(argp3);
  (arg1)->resize(arg2,arg3);
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_AudioDevInfoVector_resize(PyObject *self, PyObject *args) {
  Py_ssize_t argc;
  PyObject *argv[4] = {
    0
  };
  
  if (!(argc = SWIG_Python_UnpackTuple(args, "AudioDevInfoVector_resize", 0, 3, argv))) SWIG_fail;
  --argc;
  if (argc == 2) {
    int _v;
    int res = swig::asptr(argv[0], (std::vector< pj::AudioDevInfo*,std::allocator< pj::AudioDevInfo * > >**)(0));
    _v = SWIG_CheckState(res);
    if (_v) {
      {
        int res = SWIG_AsVal_size_t(argv[1], NULL);
        _v = SWIG_CheckState(res);
      }
      if (_v) {
        return _wrap_AudioDevInfoVector_resize__SWIG_0(self, argc, argv);
      }
    }
  }
  if (argc == 3) {
    int _v;
    int res = swig::asptr(argv[0], (std::vector< pj::AudioDevInfo*,std::allocator< pj::AudioDevInfo * > >**)(0));
    _v = SWIG_CheckState(res);
    if (_v) {
      {
        int res = SWIG_AsVal_size_t(argv[1], NULL);
        _v = SWIG_CheckState(res);
      }
      if (_v) {
        void *vptr = 0;
        int res = SWIG_ConvertPtr(argv[2], &vptr, SWIGTYPE_p_pj__AudioDevInfo, 0);
        _v = SWIG_CheckState(res);
        if (_v) {
          return _wrap_AudioDevInfoVector_resize__SWIG_1(self, argc, argv);
        }
      }
    }
  }
  
fail:
  SWIG_Python_RaiseOrModifyTypeError("Wrong number or type of arguments for overloaded function 'AudioDevInfoVector_resize'.\n"
    "  Possible C/C++ prototypes are:\n"
    "    std::vector< pj::AudioDevInfo * >::resize(std::vector< pj::AudioDevInfo * >::size_type)\n"
    "    std::vector< pj::AudioDevInfo * >::resize(std::vector< pj::AudioDevInfo * >::size_type,std::vector< pj::AudioDevInfo * >::value_type)\n");
  return 0;
}


SWIGINTERN PyObject *_wrap_AudioDevInfoVector_insert__SWIG_0(PyObject *SWIGUNUSEDPARM(self), Py_ssize_t nobjs, PyObject **swig_obj) {
  PyObject *resultobj = 0;
  std::vector< pj::AudioDevInfo * > *arg1 = (std::vector< pj::AudioDevInfo * > *) 0 ;
  std::vector< pj::AudioDevInfo * >::iterator arg2 ;
  std::vector< pj::AudioDevInfo * >::value_type arg3 = (std::vector< pj::AudioDevInfo * >::value_type) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  swig::SwigPyIterator *iter2 = 0 ;
  int res2 ;
  void *argp3 = 0 ;
  int res3 = 0 ;
  std::vector< pj::AudioDevInfo * >::iterator result;
  
  if ((nobjs < 3) || (nobjs > 3)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__vectorT_pj__AudioDevInfo_p_std__allocatorT_pj__AudioDevInfo_p_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "AudioDevInfoVector_insert" "', argument " "1"" of type '" "std::vector< pj::AudioDevInfo * > *""'"); 
  }
  arg1 = reinterpret_cast< std::vector< pj::AudioDevInfo * > * >(argp1);
  res2 = SWIG_ConvertPtr(swig_obj[1], SWIG_as_voidptrptr(&iter2), swig::SwigPyIterator::descriptor(), 0);
  if (!SWIG_IsOK(res2) || !iter2) {
    SWIG_exception_fail(SWIG_ArgError(SWIG_TypeError), "in method '" "AudioDevInfoVector_insert" "', argument " "2"" of type '" "std::vector< pj::AudioDevInfo * >::iterator""'");
  } else {
    swig::SwigPyIterator_T<std::vector< pj::AudioDevInfo * >::iterator > *iter_t = dynamic_cast<swig::SwigPyIterator_T<std::vector< pj::AudioDevInfo * >::iterator > *>(iter2);
    if (iter_t) {
      arg2 = iter_t->get_current();
    } else {
      SWIG_exception_fail(SWIG_ArgError(SWIG_TypeError), "in method '" "AudioDevInfoVector_insert" "', argument " "2"" of type '" "std::vector< pj::AudioDevInfo * >::iterator""'");
    }
  }
  res3 = SWIG_ConvertPtr(swig_obj[2], &argp3,SWIGTYPE_p_pj__AudioDevInfo, 0 |  0 );
  if (!SWIG_IsOK(res3)) {
    SWIG_exception_fail(SWIG_ArgError(res3), "in method '" "AudioDevInfoVector_insert" "', argument " "3"" of type '" "std::vector< pj::AudioDevInfo * >::value_type""'"); 
  }
  arg3 = reinterpret_cast< std::vector< pj::AudioDevInfo * >::value_type >(argp3);
  result = std_vector_Sl_pj_AudioDevInfo_Sm__Sg__insert__SWIG_0(arg1,arg2,arg3);
  resultobj = SWIG_NewPointerObj(swig::make_output_iterator(static_cast< const std::vector< pj::AudioDevInfo * >::iterator & >(result)),
    swig::SwigPyIterator::descriptor(),SWIG_POINTER_OWN);
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_AudioDevInfoVector_insert__SWIG_1(PyObject *SWIGUNUSEDPARM(self), Py_ssize_t nobjs, PyObject **swig_obj) {
  PyObject *resultobj = 0;
  std::vector< pj::AudioDevInfo * > *arg1 = (std::vector< pj::AudioDevInfo * > *) 0 ;
  std::vector< pj::AudioDevInfo * >::iterator arg2 ;
  std::vector< pj::AudioDevInfo * >::size_type arg3 ;
  std::vector< pj::AudioDevInfo * >::value_type arg4 = (std::vector< pj::AudioDevInfo * >::value_type) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  swig::SwigPyIterator *iter2 = 0 ;
  int res2 ;
  size_t val3 ;
  int ecode3 = 0 ;
  void *argp4 = 0 ;
  int res4 = 0 ;
  
  if ((nobjs < 4) || (nobjs > 4)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__vectorT_pj__AudioDevInfo_p_std__allocatorT_pj__AudioDevInfo_p_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "AudioDevInfoVector_insert" "', argument " "1"" of type '" "std::vector< pj::AudioDevInfo * > *""'"); 
  }
  arg1 = reinterpret_cast< std::vector< pj::AudioDevInfo * > * >(argp1);
  res2 = SWIG_ConvertPtr(swig_obj[1], SWIG_as_voidptrptr(&iter2), swig::SwigPyIterator::descriptor(), 0);
  if (!SWIG_IsOK(res2) || !iter2) {
    SWIG_exception_fail(SWIG_ArgError(SWIG_TypeError), "in method '" "AudioDevInfoVector_insert" "', argument " "2"" of type '" "std::vector< pj::AudioDevInfo * >::iterator""'");
  } else {
    swig::SwigPyIterator_T<std::vector< pj::AudioDevInfo * >::iterator > *iter_t = dynamic_cast<swig::SwigPyIterator_T<std::vector< pj::AudioDevInfo * >::iterator > *>(iter2);
    if (iter_t) {
      arg2 = iter_t->get_current();
    } else {
      SWIG_exception_fail(SWIG_ArgError(SWIG_TypeError), "in method '" "AudioDevInfoVector_insert" "', argument " "2"" of type '" "std::vector< pj::AudioDevInfo * >::iterator""'");
    }
  }
  ecode3 = SWIG_AsVal_size_t(swig_obj[2], &val3);
  if (!SWIG_IsOK(ecode3)) {
    SWIG_exception_fail(SWIG_ArgError(ecode3), "in method '" "AudioDevInfoVector_insert" "', argument " "3"" of type '" "std::vector< pj::AudioDevInfo * >::size_type""'");
  } 
  arg3 = static_cast< std::vector< pj::AudioDevInfo * >::size_type >(val3);
  res4 = SWIG_ConvertPtr(swig_obj[3], &argp4,SWIGTYPE_p_pj__AudioDevInfo, 0 |  0 );
  if (!SWIG_IsOK(res4)) {
    SWIG_exception_fail(SWIG_ArgError(res4), "in method '" "AudioDevInfoVector_insert" "', argument " "4"" of type '" "std::vector< pj::AudioDevInfo * >::value_type""'"); 
  }
  arg4 = reinterpret_cast< std::vector< pj::AudioDevInfo * >::value_type >(argp4);
  std_vector_Sl_pj_AudioDevInfo_Sm__Sg__insert__SWIG_1(arg1,arg2,arg3,arg4);
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_AudioDevInfoVector_insert(PyObject *self, PyObject *args) {
  Py_ssize_t argc;
  PyObject *argv[5] = {
    0
  };
  
  if (!(argc = SWIG_Python_UnpackTuple(args, "AudioDevInfoVector_insert", 0, 4, argv))) SWIG_fail;
  --argc;
  if (argc == 3) {
    int _v;
    int res = swig::asptr(argv[0], (std::vector< pj::AudioDevInfo*,std::allocator< pj::AudioDevInfo * > >**)(0));
    _v = SWIG_CheckState(res);
    if (_v) {
      swig::SwigPyIterator *iter = 0;
      int res = SWIG_ConvertPtr(argv[1], SWIG_as_voidptrptr(&iter), swig::SwigPyIterator::descriptor(), 0);
      _v = (SWIG_IsOK(res) && iter && (dynamic_cast<swig::SwigPyIterator_T<std::vector< pj::AudioDevInfo * >::iterator > *>(iter) != 0));
      if (_v) {
        void *vptr = 0;
        int res = SWIG_ConvertPtr(argv[2], &vptr, SWIGTYPE_p_pj__AudioDevInfo, 0);
        _v = SWIG_CheckState(res);
        if (_v) {
          return _wrap_AudioDevInfoVector_insert__SWIG_0(self, argc, argv);
        }
      }
    }
  }
  if (argc == 4) {
    int _v;
    int res = swig::asptr(argv[0], (std::vector< pj::AudioDevInfo*,std::allocator< pj::AudioDevInfo * > >**)(0));
    _v = SWIG_CheckState(res);
    if (_v) {
      swig::SwigPyIterator *iter = 0;
      int res = SWIG_ConvertPtr(argv[1], SWIG_as_voidptrptr(&iter), swig::SwigPyIterator::descriptor(), 0);
      _v = (SWIG_IsOK(res) && iter && (dynamic_cast<swig::SwigPyIterator_T<std::vector< pj::AudioDevInfo * >::iterator > *>(iter) != 0));
      if (_v) {
        {
          int res = SWIG_AsVal_size_t(argv[2], NULL);
          _v = SWIG_CheckState(res);
        }
        if (_v) {
          void *vptr = 0;
          int res = SWIG_ConvertPtr(argv[3], &vptr, SWIGTYPE_p_pj__AudioDevInfo, 0);
          _v = SWIG_CheckState(res);
          if (_v) {
            return _wrap_AudioDevInfoVector_insert__SWIG_1(self, argc, argv);
          }
        }
      }
    }
  }
  
fail:
  SWIG_Python_RaiseOrModifyTypeError("Wrong number or type of arguments for overloaded function 'AudioDevInfoVector_insert'.\n"
    "  Possible C/C++ prototypes are:\n"
    "    std::vector< pj::AudioDevInfo * >::insert(std::vector< pj::AudioDevInfo * >::iterator,std::vector< pj::AudioDevInfo * >::value_type)\n"
    "    std::vector< pj::AudioDevInfo * >::insert(std::vector< pj::AudioDevInfo * >::iterator,std::vector< pj::AudioDevInfo * >::size_type,std::vector< pj::AudioDevInfo * >::value_type)\n");
  return 0;
}


SWIGINTERN PyObject *_wrap_AudioDevInfoVector_reserve(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  std::vector< pj::AudioDevInfo * > *arg1 = (std::vector< pj::AudioDevInfo * > *) 0 ;
  std::vector< pj::AudioDevInfo * >::size_type arg2 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  size_t val2 ;
  int ecode2 = 0 ;
  PyObject *swig_obj[2] ;
  
  if (!SWIG_Python_UnpackTuple(args, "AudioDevInfoVector_reserve", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__vectorT_pj__AudioDevInfo_p_std__allocatorT_pj__AudioDevInfo_p_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "AudioDevInfoVector_reserve" "', argument " "1"" of type '" "std::vector< pj::AudioDevInfo * > *""'"); 
  }
  arg1 = reinterpret_cast< std::vector< pj::AudioDevInfo * > * >(argp1);
  ecode2 = SWIG_AsVal_size_t(swig_obj[1], &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "AudioDevInfoVector_reserve" "', argument " "2"" of type '" "std::vector< pj::AudioDevInfo * >::size_type""'");
  } 
  arg2 = static_cast< std::vector< pj::AudioDevInfo * >::size_type >(val2);
  (arg1)->reserve(arg2);
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_AudioDevInfoVector_capacity(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  std::vector< pj::AudioDevInfo * > *arg1 = (std::vector< pj::AudioDevInfo * > *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  std::vector< pj::AudioDevInfo * >::size_type result;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__vectorT_pj__AudioDevInfo_p_std__allocatorT_pj__AudioDevInfo_p_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "AudioDevInfoVector_capacity" "', argument " "1"" of type '" "std::vector< pj::AudioDevInfo * > const *""'"); 
  }
  arg1 = reinterpret_cast< std::vector< pj::AudioDevInfo * > * >(argp1);
  result = ((std::vector< pj::AudioDevInfo * > const *)arg1)->capacity();
  resultobj = SWIG_From_size_t(static_cast< size_t >(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_delete_AudioDevInfoVector(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  std::vector< pj::AudioDevInfo * > *arg1 = (std::vector< pj::AudioDevInfo * > *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__vectorT_pj__AudioDevInfo_p_std__allocatorT_pj__AudioDevInfo_p_t_t, SWIG_POINTER_DISOWN |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "delete_AudioDevInfoVector" "', argument " "1"" of type '" "std::vector< pj::AudioDevInfo * > *""'"); 
  }
  arg1 = reinterpret_cast< std::vector< pj::AudioDevInfo * > * >(argp1);
  delete arg1;
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *AudioDevInfoVector_swigregister(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *obj;
  if (!SWIG_Python_UnpackTuple(args, "swigregister", 1, 1, &obj)) return NULL;
  SWIG_TypeNewClientData(SWIGTYPE_p_std__vectorT_pj__AudioDevInfo_p_std__allocatorT_pj__AudioDevInfo_p_t_t, SWIG_NewClientData(obj));
  return SWIG_Py_Void();
}

SWIGINTERN PyObject *AudioDevInfoVector_swiginit(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  return SWIG_Python_InitShadowInstance(args);
}

SWIGINTERN PyObject *_wrap_AudioDevInfoVector2_iterator(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  std::vector< pj::AudioDevInfo > *arg1 = (std::vector< pj::AudioDevInfo > *) 0 ;
  PyObject **arg2 = (PyObject **) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  swig::SwigPyIterator *result = 0 ;
  
  arg2 = &swig_obj[0];
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__vectorT_pj__AudioDevInfo_std__allocatorT_pj__AudioDevInfo_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "AudioDevInfoVector2_iterator" "', argument " "1"" of type '" "std::vector< pj::AudioDevInfo > *""'"); 
  }
  arg1 = reinterpret_cast< std::vector< pj::AudioDevInfo > * >(argp1);
  result = (swig::SwigPyIterator *)std_vector_Sl_pj_AudioDevInfo_Sg__iterator(arg1,arg2);
  resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(result), SWIGTYPE_p_swig__SwigPyIterator, SWIG_POINTER_OWN |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_AudioDevInfoVector2___nonzero__(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  std::vector< pj::AudioDevInfo > *arg1 = (std::vector< pj::AudioDevInfo > *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  bool result;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__vectorT_pj__AudioDevInfo_std__allocatorT_pj__AudioDevInfo_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "AudioDevInfoVector2___nonzero__" "', argument " "1"" of type '" "std::vector< pj::AudioDevInfo > const *""'"); 
  }
  arg1 = reinterpret_cast< std::vector< pj::AudioDevInfo > * >(argp1);
  result = (bool)std_vector_Sl_pj_AudioDevInfo_Sg____nonzero__((std::vector< pj::AudioDevInfo > const *)arg1);
  resultobj = SWIG_From_bool(static_cast< bool >(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_AudioDevInfoVector2___bool__(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  std::vector< pj::AudioDevInfo > *arg1 = (std::vector< pj::AudioDevInfo > *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  bool result;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__vectorT_pj__AudioDevInfo_std__allocatorT_pj__AudioDevInfo_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "AudioDevInfoVector2___bool__" "', argument " "1"" of type '" "std::vector< pj::AudioDevInfo > const *""'"); 
  }
  arg1 = reinterpret_cast< std::vector< pj::AudioDevInfo > * >(argp1);
  result = (bool)std_vector_Sl_pj_AudioDevInfo_Sg____bool__((std::vector< pj::AudioDevInfo > const *)arg1);
  resultobj = SWIG_From_bool(static_cast< bool >(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_AudioDevInfoVector2___len__(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  std::vector< pj::AudioDevInfo > *arg1 = (std::vector< pj::AudioDevInfo > *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  std::vector< pj::AudioDevInfo >::size_type result;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__vectorT_pj__AudioDevInfo_std__allocatorT_pj__AudioDevInfo_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "AudioDevInfoVector2___len__" "', argument " "1"" of type '" "std::vector< pj::AudioDevInfo > const *""'"); 
  }
  arg1 = reinterpret_cast< std::vector< pj::AudioDevInfo > * >(argp1);
  result = std_vector_Sl_pj_AudioDevInfo_Sg____len__((std::vector< pj::AudioDevInfo > const *)arg1);
  resultobj = SWIG_From_size_t(static_cast< size_t >(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_AudioDevInfoVector2___getslice__(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  std::vector< pj::AudioDevInfo > *arg1 = (std::vector< pj::AudioDevInfo > *) 0 ;
  std::vector< pj::AudioDevInfo >::difference_type arg2 ;
  std::vector< pj::AudioDevInfo >::difference_type arg3 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  ptrdiff_t val2 ;
  int ecode2 = 0 ;
  ptrdiff_t val3 ;
  int ecode3 = 0 ;
  PyObject *swig_obj[3] ;
  std::vector< pj::AudioDevInfo,std::allocator< pj::AudioDevInfo > > *result = 0 ;
  
  if (!SWIG_Python_UnpackTuple(args, "AudioDevInfoVector2___getslice__", 3, 3, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__vectorT_pj__AudioDevInfo_std__allocatorT_pj__AudioDevInfo_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "AudioDevInfoVector2___getslice__" "', argument " "1"" of type '" "std::vector< pj::AudioDevInfo > *""'"); 
  }
  arg1 = reinterpret_cast< std::vector< pj::AudioDevInfo > * >(argp1);
  ecode2 = SWIG_AsVal_ptrdiff_t(swig_obj[1], &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "AudioDevInfoVector2___getslice__" "', argument " "2"" of type '" "std::vector< pj::AudioDevInfo >::difference_type""'");
  } 
  arg2 = static_cast< std::vector< pj::AudioDevInfo >::difference_type >(val2);
  ecode3 = SWIG_AsVal_ptrdiff_t(swig_obj[2], &val3);
  if (!SWIG_IsOK(ecode3)) {
    SWIG_exception_fail(SWIG_ArgError(ecode3), "in method '" "AudioDevInfoVector2___getslice__" "', argument " "3"" of type '" "std::vector< pj::AudioDevInfo >::difference_type""'");
  } 
  arg3 = static_cast< std::vector< pj::AudioDevInfo >::difference_type >(val3);
  try {
    result = (std::vector< pj::AudioDevInfo,std::allocator< pj::AudioDevInfo > > *)std_vector_Sl_pj_AudioDevInfo_Sg____getslice__(arg1,arg2,arg3);
  } catch(std::out_of_range &_e) {
    SWIG_exception_fail(SWIG_IndexError, (&_e)->what());
  } catch(std::invalid_argument &_e) {
    SWIG_exception_fail(SWIG_ValueError, (&_e)->what());
  }
  resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(result), SWIGTYPE_p_std__vectorT_pj__AudioDevInfo_std__allocatorT_pj__AudioDevInfo_t_t, SWIG_POINTER_OWN |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_AudioDevInfoVector2___setslice____SWIG_0(PyObject *SWIGUNUSEDPARM(self), Py_ssize_t nobjs, PyObject **swig_obj) {
  PyObject *resultobj = 0;
  std::vector< pj::AudioDevInfo > *arg1 = (std::vector< pj::AudioDevInfo > *) 0 ;
  std::vector< pj::AudioDevInfo >::difference_type arg2 ;
  std::vector< pj::AudioDevInfo >::difference_type arg3 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  ptrdiff_t val2 ;
  int ecode2 = 0 ;
  ptrdiff_t val3 ;
  int ecode3 = 0 ;
  
  if ((nobjs < 3) || (nobjs > 3)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__vectorT_pj__AudioDevInfo_std__allocatorT_pj__AudioDevInfo_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "AudioDevInfoVector2___setslice__" "', argument " "1"" of type '" "std::vector< pj::AudioDevInfo > *""'"); 
  }
  arg1 = reinterpret_cast< std::vector< pj::AudioDevInfo > * >(argp1);
  ecode2 = SWIG_AsVal_ptrdiff_t(swig_obj[1], &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "AudioDevInfoVector2___setslice__" "', argument " "2"" of type '" "std::vector< pj::AudioDevInfo >::difference_type""'");
  } 
  arg2 = static_cast< std::vector< pj::AudioDevInfo >::difference_type >(val2);
  ecode3 = SWIG_AsVal_ptrdiff_t(swig_obj[2], &val3);
  if (!SWIG_IsOK(ecode3)) {
    SWIG_exception_fail(SWIG_ArgError(ecode3), "in method '" "AudioDevInfoVector2___setslice__" "', argument " "3"" of type '" "std::vector< pj::AudioDevInfo >::difference_type""'");
  } 
  arg3 = static_cast< std::vector< pj::AudioDevInfo >::difference_type >(val3);
  try {
    std_vector_Sl_pj_AudioDevInfo_Sg____setslice____SWIG_0(arg1,arg2,arg3);
  } catch(std::out_of_range &_e) {
    SWIG_exception_fail(SWIG_IndexError, (&_e)->what());
  } catch(std::invalid_argument &_e) {
    SWIG_exception_fail(SWIG_ValueError, (&_e)->what());
  }
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_AudioDevInfoVector2___setslice____SWIG_1(PyObject *SWIGUNUSEDPARM(self), Py_ssize_t nobjs, PyObject **swig_obj) {
  PyObject *resultobj = 0;
  std::vector< pj::AudioDevInfo > *arg1 = (std::vector< pj::AudioDevInfo > *) 0 ;
  std::vector< pj::AudioDevInfo >::difference_type arg2 ;
  std::vector< pj::AudioDevInfo >::difference_type arg3 ;
  std::vector< pj::AudioDevInfo,std::allocator< pj::AudioDevInfo > > *arg4 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  ptrdiff_t val2 ;
  int ecode2 = 0 ;
  ptrdiff_t val3 ;
  int ecode3 = 0 ;
  int res4 = SWIG_OLDOBJ ;
  
  if ((nobjs < 4) || (nobjs > 4)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__vectorT_pj__AudioDevInfo_std__allocatorT_pj__AudioDevInfo_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "AudioDevInfoVector2___setslice__" "', argument " "1"" of type '" "std::vector< pj::AudioDevInfo > *""'"); 
  }
  arg1 = reinterpret_cast< std::vector< pj::AudioDevInfo > * >(argp1);
  ecode2 = SWIG_AsVal_ptrdiff_t(swig_obj[1], &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "AudioDevInfoVector2___setslice__" "', argument " "2"" of type '" "std::vector< pj::AudioDevInfo >::difference_type""'");
  } 
  arg2 = static_cast< std::vector< pj::AudioDevInfo >::difference_type >(val2);
  ecode3 = SWIG_AsVal_ptrdiff_t(swig_obj[2], &val3);
  if (!SWIG_IsOK(ecode3)) {
    SWIG_exception_fail(SWIG_ArgError(ecode3), "in method '" "AudioDevInfoVector2___setslice__" "', argument " "3"" of type '" "std::vector< pj::AudioDevInfo >::difference_type""'");
  } 
  arg3 = static_cast< std::vector< pj::AudioDevInfo >::difference_type >(val3);
  {
    std::vector< pj::AudioDevInfo,std::allocator< pj::AudioDevInfo > > *ptr = (std::vector< pj::AudioDevInfo,std::allocator< pj::AudioDevInfo > > *)0;
    res4 = swig::asptr(swig_obj[3], &ptr);
    if (!SWIG_IsOK(res4)) {
      SWIG_exception_fail(SWIG_ArgError(res4), "in method '" "AudioDevInfoVector2___setslice__" "', argument " "4"" of type '" "std::vector< pj::AudioDevInfo,std::allocator< pj::AudioDevInfo > > const &""'"); 
    }
    if (!ptr) {
      SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "AudioDevInfoVector2___setslice__" "', argument " "4"" of type '" "std::vector< pj::AudioDevInfo,std::allocator< pj::AudioDevInfo > > const &""'"); 
    }
    arg4 = ptr;
  }
  try {
    std_vector_Sl_pj_AudioDevInfo_Sg____setslice____SWIG_1(arg1,arg2,arg3,(std::vector< pj::AudioDevInfo,std::allocator< pj::AudioDevInfo > > const &)*arg4);
  } catch(std::out_of_range &_e) {
    SWIG_exception_fail(SWIG_IndexError, (&_e)->what());
  } catch(std::invalid_argument &_e) {
    SWIG_exception_fail(SWIG_ValueError, (&_e)->what());
  }
  resultobj = SWIG_Py_Void();
  if (SWIG_IsNewObj(res4)) delete arg4;
  return resultobj;
fail:
  if (SWIG_IsNewObj(res4)) delete arg4;
  return NULL;
}


SWIGINTERN PyObject *_wrap_AudioDevInfoVector2___setslice__(PyObject *self, PyObject *args) {
  Py_ssize_t argc;
  PyObject *argv[5] = {
    0
  };
  
  if (!(argc = SWIG_Python_UnpackTuple(args, "AudioDevInfoVector2___setslice__", 0, 4, argv))) SWIG_fail;
  --argc;
  if (argc == 3) {
    int _v;
    int res = swig::asptr(argv[0], (std::vector< pj::AudioDevInfo,std::allocator< pj::AudioDevInfo > >**)(0));
    _v = SWIG_CheckState(res);
    if (_v) {
      {
        int res = SWIG_AsVal_ptrdiff_t(argv[1], NULL);
        _v = SWIG_CheckState(res);
      }
      if (_v) {
        {
          int res = SWIG_AsVal_ptrdiff_t(argv[2], NULL);
          _v = SWIG_CheckState(res);
        }
        if (_v) {
          return _wrap_AudioDevInfoVector2___setslice____SWIG_0(self, argc, argv);
        }
      }
    }
  }
  if (argc == 4) {
    int _v;
    int res = swig::asptr(argv[0], (std::vector< pj::AudioDevInfo,std::allocator< pj::AudioDevInfo > >**)(0));
    _v = SWIG_CheckState(res);
    if (_v) {
      {
        int res = SWIG_AsVal_ptrdiff_t(argv[1], NULL);
        _v = SWIG_CheckState(res);
      }
      if (_v) {
        {
          int res = SWIG_AsVal_ptrdiff_t(argv[2], NULL);
          _v = SWIG_CheckState(res);
        }
        if (_v) {
          int res = swig::asptr(argv[3], (std::vector< pj::AudioDevInfo,std::allocator< pj::AudioDevInfo > >**)(0));
          _v = SWIG_CheckState(res);
          if (_v) {
            return _wrap_AudioDevInfoVector2___setslice____SWIG_1(self, argc, argv);
          }
        }
      }
    }
  }
  
fail:
  SWIG_Python_RaiseOrModifyTypeError("Wrong number or type of arguments for overloaded function 'AudioDevInfoVector2___setslice__'.\n"
    "  Possible C/C++ prototypes are:\n"
    "    std::vector< pj::AudioDevInfo >::__setslice__(std::vector< pj::AudioDevInfo >::difference_type,std::vector< pj::AudioDevInfo >::difference_type)\n"
    "    std::vector< pj::AudioDevInfo >::__setslice__(std::vector< pj::AudioDevInfo >::difference_type,std::vector< pj::AudioDevInfo >::difference_type,std::vector< pj::AudioDevInfo,std::allocator< pj::AudioDevInfo > > const &)\n");
  return 0;
}


SWIGINTERN PyObject *_wrap_AudioDevInfoVector2___delslice__(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  std::vector< pj::AudioDevInfo > *arg1 = (std::vector< pj::AudioDevInfo > *) 0 ;
  std::vector< pj::AudioDevInfo >::difference_type arg2 ;
  std::vector< pj::AudioDevInfo >::difference_type arg3 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  ptrdiff_t val2 ;
  int ecode2 = 0 ;
  ptrdiff_t val3 ;
  int ecode3 = 0 ;
  PyObject *swig_obj[3] ;
  
  if (!SWIG_Python_UnpackTuple(args, "AudioDevInfoVector2___delslice__", 3, 3, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__vectorT_pj__AudioDevInfo_std__allocatorT_pj__AudioDevInfo_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "AudioDevInfoVector2___delslice__" "', argument " "1"" of type '" "std::vector< pj::AudioDevInfo > *""'"); 
  }
  arg1 = reinterpret_cast< std::vector< pj::AudioDevInfo > * >(argp1);
  ecode2 = SWIG_AsVal_ptrdiff_t(swig_obj[1], &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "AudioDevInfoVector2___delslice__" "', argument " "2"" of type '" "std::vector< pj::AudioDevInfo >::difference_type""'");
  } 
  arg2 = static_cast< std::vector< pj::AudioDevInfo >::difference_type >(val2);
  ecode3 = SWIG_AsVal_ptrdiff_t(swig_obj[2], &val3);
  if (!SWIG_IsOK(ecode3)) {
    SWIG_exception_fail(SWIG_ArgError(ecode3), "in method '" "AudioDevInfoVector2___delslice__" "', argument " "3"" of type '" "std::vector< pj::AudioDevInfo >::difference_type""'");
  } 
  arg3 = static_cast< std::vector< pj::AudioDevInfo >::difference_type >(val3);
  try {
    std_vector_Sl_pj_AudioDevInfo_Sg____delslice__(arg1,arg2,arg3);
  } catch(std::out_of_range &_e) {
    SWIG_exception_fail(SWIG_IndexError, (&_e)->what());
  } catch(std::invalid_argument &_e) {
    SWIG_exception_fail(SWIG_ValueError, (&_e)->what());
  }
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_AudioDevInfoVector2___delitem____SWIG_0(PyObject *SWIGUNUSEDPARM(self), Py_ssize_t nobjs, PyObject **swig_obj) {
  PyObject *resultobj = 0;
  std::vector< pj::AudioDevInfo > *arg1 = (std::vector< pj::AudioDevInfo > *) 0 ;
  std::vector< pj::AudioDevInfo >::difference_type arg2 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  ptrdiff_t val2 ;
  int ecode2 = 0 ;
  
  if ((nobjs < 2) || (nobjs > 2)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__vectorT_pj__AudioDevInfo_std__allocatorT_pj__AudioDevInfo_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "AudioDevInfoVector2___delitem__" "', argument " "1"" of type '" "std::vector< pj::AudioDevInfo > *""'"); 
  }
  arg1 = reinterpret_cast< std::vector< pj::AudioDevInfo > * >(argp1);
  ecode2 = SWIG_AsVal_ptrdiff_t(swig_obj[1], &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "AudioDevInfoVector2___delitem__" "', argument " "2"" of type '" "std::vector< pj::AudioDevInfo >::difference_type""'");
  } 
  arg2 = static_cast< std::vector< pj::AudioDevInfo >::difference_type >(val2);
  try {
    std_vector_Sl_pj_AudioDevInfo_Sg____delitem____SWIG_0(arg1,arg2);
  } catch(std::out_of_range &_e) {
    SWIG_exception_fail(SWIG_IndexError, (&_e)->what());
  } catch(std::invalid_argument &_e) {
    SWIG_exception_fail(SWIG_ValueError, (&_e)->what());
  }
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_AudioDevInfoVector2___getitem____SWIG_0(PyObject *SWIGUNUSEDPARM(self), Py_ssize_t nobjs, PyObject **swig_obj) {
  PyObject *resultobj = 0;
  std::vector< pj::AudioDevInfo > *arg1 = (std::vector< pj::AudioDevInfo > *) 0 ;
  PySliceObject *arg2 = (PySliceObject *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  std::vector< pj::AudioDevInfo,std::allocator< pj::AudioDevInfo > > *result = 0 ;
  
  if ((nobjs < 2) || (nobjs > 2)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__vectorT_pj__AudioDevInfo_std__allocatorT_pj__AudioDevInfo_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "AudioDevInfoVector2___getitem__" "', argument " "1"" of type '" "std::vector< pj::AudioDevInfo > *""'"); 
  }
  arg1 = reinterpret_cast< std::vector< pj::AudioDevInfo > * >(argp1);
  {
    if (!PySlice_Check(swig_obj[1])) {
      SWIG_exception_fail(SWIG_ArgError(SWIG_TypeError), "in method '" "AudioDevInfoVector2___getitem__" "', argument " "2"" of type '" "PySliceObject *""'");
    }
    arg2 = (PySliceObject *) swig_obj[1];
  }
  try {
    result = (std::vector< pj::AudioDevInfo,std::allocator< pj::AudioDevInfo > > *)std_vector_Sl_pj_AudioDevInfo_Sg____getitem____SWIG_0(arg1,arg2);
  } catch(std::out_of_range &_e) {
    SWIG_exception_fail(SWIG_IndexError, (&_e)->what());
  } catch(std::invalid_argument &_e) {
    SWIG_exception_fail(SWIG_ValueError, (&_e)->what());
  }
  resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(result), SWIGTYPE_p_std__vectorT_pj__AudioDevInfo_std__allocatorT_pj__AudioDevInfo_t_t, SWIG_POINTER_OWN |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_AudioDevInfoVector2___setitem____SWIG_0(PyObject *SWIGUNUSEDPARM(self), Py_ssize_t nobjs, PyObject **swig_obj) {
  PyObject *resultobj = 0;
  std::vector< pj::AudioDevInfo > *arg1 = (std::vector< pj::AudioDevInfo > *) 0 ;
  PySliceObject *arg2 = (PySliceObject *) 0 ;
  std::vector< pj::AudioDevInfo,std::allocator< pj::AudioDevInfo > > *arg3 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  int res3 = SWIG_OLDOBJ ;
  
  if ((nobjs < 3) || (nobjs > 3)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__vectorT_pj__AudioDevInfo_std__allocatorT_pj__AudioDevInfo_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "AudioDevInfoVector2___setitem__" "', argument " "1"" of type '" "std::vector< pj::AudioDevInfo > *""'"); 
  }
  arg1 = reinterpret_cast< std::vector< pj::AudioDevInfo > * >(argp1);
  {
    if (!PySlice_Check(swig_obj[1])) {
      SWIG_exception_fail(SWIG_ArgError(SWIG_TypeError), "in method '" "AudioDevInfoVector2___setitem__" "', argument " "2"" of type '" "PySliceObject *""'");
    }
    arg2 = (PySliceObject *) swig_obj[1];
  }
  {
    std::vector< pj::AudioDevInfo,std::allocator< pj::AudioDevInfo > > *ptr = (std::vector< pj::AudioDevInfo,std::allocator< pj::AudioDevInfo > > *)0;
    res3 = swig::asptr(swig_obj[2], &ptr);
    if (!SWIG_IsOK(res3)) {
      SWIG_exception_fail(SWIG_ArgError(res3), "in method '" "AudioDevInfoVector2___setitem__" "', argument " "3"" of type '" "std::vector< pj::AudioDevInfo,std::allocator< pj::AudioDevInfo > > const &""'"); 
    }
    if (!ptr) {
      SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "AudioDevInfoVector2___setitem__" "', argument " "3"" of type '" "std::vector< pj::AudioDevInfo,std::allocator< pj::AudioDevInfo > > const &""'"); 
    }
    arg3 = ptr;
  }
  try {
    std_vector_Sl_pj_AudioDevInfo_Sg____setitem____SWIG_0(arg1,arg2,(std::vector< pj::AudioDevInfo,std::allocator< pj::AudioDevInfo > > const &)*arg3);
  } catch(std::out_of_range &_e) {
    SWIG_exception_fail(SWIG_IndexError, (&_e)->what());
  } catch(std::invalid_argument &_e) {
    SWIG_exception_fail(SWIG_ValueError, (&_e)->what());
  }
  resultobj = SWIG_Py_Void();
  if (SWIG_IsNewObj(res3)) delete arg3;
  return resultobj;
fail:
  if (SWIG_IsNewObj(res3)) delete arg3;
  return NULL;
}


SWIGINTERN PyObject *_wrap_AudioDevInfoVector2___setitem____SWIG_1(PyObject *SWIGUNUSEDPARM(self), Py_ssize_t nobjs, PyObject **swig_obj) {
  PyObject *resultobj = 0;
  std::vector< pj::AudioDevInfo > *arg1 = (std::vector< pj::AudioDevInfo > *) 0 ;
  PySliceObject *arg2 = (PySliceObject *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  
  if ((nobjs < 2) || (nobjs > 2)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__vectorT_pj__AudioDevInfo_std__allocatorT_pj__AudioDevInfo_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "AudioDevInfoVector2___setitem__" "', argument " "1"" of type '" "std::vector< pj::AudioDevInfo > *""'"); 
  }
  arg1 = reinterpret_cast< std::vector< pj::AudioDevInfo > * >(argp1);
  {
    if (!PySlice_Check(swig_obj[1])) {
      SWIG_exception_fail(SWIG_ArgError(SWIG_TypeError), "in method '" "AudioDevInfoVector2___setitem__" "', argument " "2"" of type '" "PySliceObject *""'");
    }
    arg2 = (PySliceObject *) swig_obj[1];
  }
  try {
    std_vector_Sl_pj_AudioDevInfo_Sg____setitem____SWIG_1(arg1,arg2);
  } catch(std::out_of_range &_e) {
    SWIG_exception_fail(SWIG_IndexError, (&_e)->what());
  } catch(std::invalid_argument &_e) {
    SWIG_exception_fail(SWIG_ValueError, (&_e)->what());
  }
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_AudioDevInfoVector2___delitem____SWIG_1(PyObject *SWIGUNUSEDPARM(self), Py_ssize_t nobjs, PyObject **swig_obj) {
  PyObject *resultobj = 0;
  std::vector< pj::AudioDevInfo > *arg1 = (std::vector< pj::AudioDevInfo > *) 0 ;
  PySliceObject *arg2 = (PySliceObject *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  
  if ((nobjs < 2) || (nobjs > 2)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__vectorT_pj__AudioDevInfo_std__allocatorT_pj__AudioDevInfo_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "AudioDevInfoVector2___delitem__" "', argument " "1"" of type '" "std::vector< pj::AudioDevInfo > *""'"); 
  }
  arg1 = reinterpret_cast< std::vector< pj::AudioDevInfo > * >(argp1);
  {
    if (!PySlice_Check(swig_obj[1])) {
      SWIG_exception_fail(SWIG_ArgError(SWIG_TypeError), "in method '" "AudioDevInfoVector2___delitem__" "', argument " "2"" of type '" "PySliceObject *""'");
    }
    arg2 = (PySliceObject *) swig_obj[1];
  }
  try {
    std_vector_Sl_pj_AudioDevInfo_Sg____delitem____SWIG_1(arg1,arg2);
  } catch(std::out_of_range &_e) {
    SWIG_exception_fail(SWIG_IndexError, (&_e)->what());
  } catch(std::invalid_argument &_e) {
    SWIG_exception_fail(SWIG_ValueError, (&_e)->what());
  }
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_AudioDevInfoVector2___delitem__(PyObject *self, PyObject *args) {
  Py_ssize_t argc;
  PyObject *argv[3] = {
    0
  };
  
  if (!(argc = SWIG_Python_UnpackTuple(args, "AudioDevInfoVector2___delitem__", 0, 2, argv))) SWIG_fail;
  --argc;
  if (argc == 2) {
    int _v;
    int res = swig::asptr(argv[0], (std::vector< pj::AudioDevInfo,std::allocator< pj::AudioDevInfo > >**)(0));
    _v = SWIG_CheckState(res);
    if (_v) {
      {
        _v = PySlice_Check(argv[1]);
      }
      if (_v) {
        return _wrap_AudioDevInfoVector2___delitem____SWIG_1(self, argc, argv);
      }
    }
  }
  if (argc == 2) {
    int _v;
    int res = swig::asptr(argv[0], (std::vector< pj::AudioDevInfo,std::allocator< pj::AudioDevInfo > >**)(0));
    _v = SWIG_CheckState(res);
    if (_v) {
      {
        int res = SWIG_AsVal_ptrdiff_t(argv[1], NULL);
        _v = SWIG_CheckState(res);
      }
      if (_v) {
        return _wrap_AudioDevInfoVector2___delitem____SWIG_0(self, argc, argv);
      }
    }
  }
  
fail:
  SWIG_Python_RaiseOrModifyTypeError("Wrong number or type of arguments for overloaded function 'AudioDevInfoVector2___delitem__'.\n"
    "  Possible C/C++ prototypes are:\n"
    "    std::vector< pj::AudioDevInfo >::__delitem__(std::vector< pj::AudioDevInfo >::difference_type)\n"
    "    std::vector< pj::AudioDevInfo >::__delitem__(PySliceObject *)\n");
  return 0;
}


SWIGINTERN PyObject *_wrap_AudioDevInfoVector2___getitem____SWIG_1(PyObject *SWIGUNUSEDPARM(self), Py_ssize_t nobjs, PyObject **swig_obj) {
  PyObject *resultobj = 0;
  std::vector< pj::AudioDevInfo > *arg1 = (std::vector< pj::AudioDevInfo > *) 0 ;
  std::vector< pj::AudioDevInfo >::difference_type arg2 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  ptrdiff_t val2 ;
  int ecode2 = 0 ;
  std::vector< pj::AudioDevInfo >::value_type *result = 0 ;
  
  if ((nobjs < 2) || (nobjs > 2)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__vectorT_pj__AudioDevInfo_std__allocatorT_pj__AudioDevInfo_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "AudioDevInfoVector2___getitem__" "', argument " "1"" of type '" "std::vector< pj::AudioDevInfo > const *""'"); 
  }
  arg1 = reinterpret_cast< std::vector< pj::AudioDevInfo > * >(argp1);
  ecode2 = SWIG_AsVal_ptrdiff_t(swig_obj[1], &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "AudioDevInfoVector2___getitem__" "', argument " "2"" of type '" "std::vector< pj::AudioDevInfo >::difference_type""'");
  } 
  arg2 = static_cast< std::vector< pj::AudioDevInfo >::difference_type >(val2);
  try {
    result = (std::vector< pj::AudioDevInfo >::value_type *) &std_vector_Sl_pj_AudioDevInfo_Sg____getitem____SWIG_1((std::vector< pj::AudioDevInfo > const *)arg1,arg2);
  } catch(std::out_of_range &_e) {
    SWIG_exception_fail(SWIG_IndexError, (&_e)->what());
  }
  resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(result), SWIGTYPE_p_pj__AudioDevInfo, 0 |  0 );
  (void)swig::container_owner<swig::traits<std::vector< pj::AudioDevInfo >::value_type>::category>::back_reference(resultobj, swig_obj[0]);
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_AudioDevInfoVector2___getitem__(PyObject *self, PyObject *args) {
  Py_ssize_t argc;
  PyObject *argv[3] = {
    0
  };
  
  if (!(argc = SWIG_Python_UnpackTuple(args, "AudioDevInfoVector2___getitem__", 0, 2, argv))) SWIG_fail;
  --argc;
  if (argc == 2) {
    int _v;
    int res = swig::asptr(argv[0], (std::vector< pj::AudioDevInfo,std::allocator< pj::AudioDevInfo > >**)(0));
    _v = SWIG_CheckState(res);
    if (_v) {
      {
        _v = PySlice_Check(argv[1]);
      }
      if (_v) {
        return _wrap_AudioDevInfoVector2___getitem____SWIG_0(self, argc, argv);
      }
    }
  }
  if (argc == 2) {
    int _v;
    int res = swig::asptr(argv[0], (std::vector< pj::AudioDevInfo,std::allocator< pj::AudioDevInfo > >**)(0));
    _v = SWIG_CheckState(res);
    if (_v) {
      {
        int res = SWIG_AsVal_ptrdiff_t(argv[1], NULL);
        _v = SWIG_CheckState(res);
      }
      if (_v) {
        return _wrap_AudioDevInfoVector2___getitem____SWIG_1(self, argc, argv);
      }
    }
  }
  
fail:
  SWIG_Python_RaiseOrModifyTypeError("Wrong number or type of arguments for overloaded function 'AudioDevInfoVector2___getitem__'.\n"
    "  Possible C/C++ prototypes are:\n"
    "    std::vector< pj::AudioDevInfo >::__getitem__(PySliceObject *)\n"
    "    std::vector< pj::AudioDevInfo >::__getitem__(std::vector< pj::AudioDevInfo >::difference_type) const\n");
  return 0;
}


SWIGINTERN PyObject *_wrap_AudioDevInfoVector2___setitem____SWIG_2(PyObject *SWIGUNUSEDPARM(self), Py_ssize_t nobjs, PyObject **swig_obj) {
  PyObject *resultobj = 0;
  std::vector< pj::AudioDevInfo > *arg1 = (std::vector< pj::AudioDevInfo > *) 0 ;
  std::vector< pj::AudioDevInfo >::difference_type arg2 ;
  std::vector< pj::AudioDevInfo >::value_type *arg3 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  ptrdiff_t val2 ;
  int ecode2 = 0 ;
  void *argp3 = 0 ;
  int res3 = 0 ;
  
  if ((nobjs < 3) || (nobjs > 3)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__vectorT_pj__AudioDevInfo_std__allocatorT_pj__AudioDevInfo_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "AudioDevInfoVector2___setitem__" "', argument " "1"" of type '" "std::vector< pj::AudioDevInfo > *""'"); 
  }
  arg1 = reinterpret_cast< std::vector< pj::AudioDevInfo > * >(argp1);
  ecode2 = SWIG_AsVal_ptrdiff_t(swig_obj[1], &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "AudioDevInfoVector2___setitem__" "', argument " "2"" of type '" "std::vector< pj::AudioDevInfo >::difference_type""'");
  } 
  arg2 = static_cast< std::vector< pj::AudioDevInfo >::difference_type >(val2);
  res3 = SWIG_ConvertPtr(swig_obj[2], &argp3, SWIGTYPE_p_pj__AudioDevInfo,  0  | 0);
  if (!SWIG_IsOK(res3)) {
    SWIG_exception_fail(SWIG_ArgError(res3), "in method '" "AudioDevInfoVector2___setitem__" "', argument " "3"" of type '" "std::vector< pj::AudioDevInfo >::value_type const &""'"); 
  }
  if (!argp3) {
    SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "AudioDevInfoVector2___setitem__" "', argument " "3"" of type '" "std::vector< pj::AudioDevInfo >::value_type const &""'"); 
  }
  arg3 = reinterpret_cast< std::vector< pj::AudioDevInfo >::value_type * >(argp3);
  try {
    std_vector_Sl_pj_AudioDevInfo_Sg____setitem____SWIG_2(arg1,arg2,(pj::AudioDevInfo const &)*arg3);
  } catch(std::out_of_range &_e) {
    SWIG_exception_fail(SWIG_IndexError, (&_e)->what());
  }
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_AudioDevInfoVector2___setitem__(PyObject *self, PyObject *args) {
  Py_ssize_t argc;
  PyObject *argv[4] = {
    0
  };
  
  if (!(argc = SWIG_Python_UnpackTuple(args, "AudioDevInfoVector2___setitem__", 0, 3, argv))) SWIG_fail;
  --argc;
  if (argc == 2) {
    int _v;
    int res = swig::asptr(argv[0], (std::vector< pj::AudioDevInfo,std::allocator< pj::AudioDevInfo > >**)(0));
    _v = SWIG_CheckState(res);
    if (_v) {
      {
        _v = PySlice_Check(argv[1]);
      }
      if (_v) {
        return _wrap_AudioDevInfoVector2___setitem____SWIG_1(self, argc, argv);
      }
    }
  }
  if (argc == 3) {
    int _v;
    int res = swig::asptr(argv[0], (std::vector< pj::AudioDevInfo,std::allocator< pj::AudioDevInfo > >**)(0));
    _v = SWIG_CheckState(res);
    if (_v) {
      {
        _v = PySlice_Check(argv[1]);
      }
      if (_v) {
        int res = swig::asptr(argv[2], (std::vector< pj::AudioDevInfo,std::allocator< pj::AudioDevInfo > >**)(0));
        _v = SWIG_CheckState(res);
        if (_v) {
          return _wrap_AudioDevInfoVector2___setitem____SWIG_0(self, argc, argv);
        }
      }
    }
  }
  if (argc == 3) {
    int _v;
    int res = swig::asptr(argv[0], (std::vector< pj::AudioDevInfo,std::allocator< pj::AudioDevInfo > >**)(0));
    _v = SWIG_CheckState(res);
    if (_v) {
      {
        int res = SWIG_AsVal_ptrdiff_t(argv[1], NULL);
        _v = SWIG_CheckState(res);
      }
      if (_v) {
        int res = SWIG_ConvertPtr(argv[2], 0, SWIGTYPE_p_pj__AudioDevInfo, SWIG_POINTER_NO_NULL | 0);
        _v = SWIG_CheckState(res);
        if (_v) {
          return _wrap_AudioDevInfoVector2___setitem____SWIG_2(self, argc, argv);
        }
      }
    }
  }
  
fail:
  SWIG_Python_RaiseOrModifyTypeError("Wrong number or type of arguments for overloaded function 'AudioDevInfoVector2___setitem__'.\n"
    "  Possible C/C++ prototypes are:\n"
    "    std::vector< pj::AudioDevInfo >::__setitem__(PySliceObject *,std::vector< pj::AudioDevInfo,std::allocator< pj::AudioDevInfo > > const &)\n"
    "    std::vector< pj::AudioDevInfo >::__setitem__(PySliceObject *)\n"
    "    std::vector< pj::AudioDevInfo >::__setitem__(std::vector< pj::AudioDevInfo >::difference_type,std::vector< pj::AudioDevInfo >::value_type const &)\n");
  return 0;
}


SWIGINTERN PyObject *_wrap_AudioDevInfoVector2_pop(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  std::vector< pj::AudioDevInfo > *arg1 = (std::vector< pj::AudioDevInfo > *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  std::vector< pj::AudioDevInfo >::value_type result;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__vectorT_pj__AudioDevInfo_std__allocatorT_pj__AudioDevInfo_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "AudioDevInfoVector2_pop" "', argument " "1"" of type '" "std::vector< pj::AudioDevInfo > *""'"); 
  }
  arg1 = reinterpret_cast< std::vector< pj::AudioDevInfo > * >(argp1);
  try {
    result = std_vector_Sl_pj_AudioDevInfo_Sg__pop(arg1);
  } catch(std::out_of_range &_e) {
    SWIG_exception_fail(SWIG_IndexError, (&_e)->what());
  }
  resultobj = SWIG_NewPointerObj((new std::vector< pj::AudioDevInfo >::value_type(static_cast< const std::vector< pj::AudioDevInfo >::value_type& >(result))), SWIGTYPE_p_pj__AudioDevInfo, SWIG_POINTER_OWN |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_AudioDevInfoVector2_append(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  std::vector< pj::AudioDevInfo > *arg1 = (std::vector< pj::AudioDevInfo > *) 0 ;
  std::vector< pj::AudioDevInfo >::value_type *arg2 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  void *argp2 = 0 ;
  int res2 = 0 ;
  PyObject *swig_obj[2] ;
  
  if (!SWIG_Python_UnpackTuple(args, "AudioDevInfoVector2_append", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__vectorT_pj__AudioDevInfo_std__allocatorT_pj__AudioDevInfo_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "AudioDevInfoVector2_append" "', argument " "1"" of type '" "std::vector< pj::AudioDevInfo > *""'"); 
  }
  arg1 = reinterpret_cast< std::vector< pj::AudioDevInfo > * >(argp1);
  res2 = SWIG_ConvertPtr(swig_obj[1], &argp2, SWIGTYPE_p_pj__AudioDevInfo,  0  | 0);
  if (!SWIG_IsOK(res2)) {
    SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "AudioDevInfoVector2_append" "', argument " "2"" of type '" "std::vector< pj::AudioDevInfo >::value_type const &""'"); 
  }
  if (!argp2) {
    SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "AudioDevInfoVector2_append" "', argument " "2"" of type '" "std::vector< pj::AudioDevInfo >::value_type const &""'"); 
  }
  arg2 = reinterpret_cast< std::vector< pj::AudioDevInfo >::value_type * >(argp2);
  std_vector_Sl_pj_AudioDevInfo_Sg__append(arg1,(pj::AudioDevInfo const &)*arg2);
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_new_AudioDevInfoVector2__SWIG_0(PyObject *SWIGUNUSEDPARM(self), Py_ssize_t nobjs, PyObject **SWIGUNUSEDPARM(swig_obj)) {
  PyObject *resultobj = 0;
  std::vector< pj::AudioDevInfo > *result = 0 ;
  
  if ((nobjs < 0) || (nobjs > 0)) SWIG_fail;
  result = (std::vector< pj::AudioDevInfo > *)new std::vector< pj::AudioDevInfo >();
  resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(result), SWIGTYPE_p_std__vectorT_pj__AudioDevInfo_std__allocatorT_pj__AudioDevInfo_t_t, SWIG_POINTER_NEW |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_new_AudioDevInfoVector2__SWIG_1(PyObject *SWIGUNUSEDPARM(self), Py_ssize_t nobjs, PyObject **swig_obj) {
  PyObject *resultobj = 0;
  std::vector< pj::AudioDevInfo > *arg1 = 0 ;
  int res1 = SWIG_OLDOBJ ;
  std::vector< pj::AudioDevInfo > *result = 0 ;
  
  if ((nobjs < 1) || (nobjs > 1)) SWIG_fail;
  {
    std::vector< pj::AudioDevInfo,std::allocator< pj::AudioDevInfo > > *ptr = (std::vector< pj::AudioDevInfo,std::allocator< pj::AudioDevInfo > > *)0;
    res1 = swig::asptr(swig_obj[0], &ptr);
    if (!SWIG_IsOK(res1)) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "new_AudioDevInfoVector2" "', argument " "1"" of type '" "std::vector< pj::AudioDevInfo > const &""'"); 
    }
    if (!ptr) {
      SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "new_AudioDevInfoVector2" "', argument " "1"" of type '" "std::vector< pj::AudioDevInfo > const &""'"); 
    }
    arg1 = ptr;
  }
  result = (std::vector< pj::AudioDevInfo > *)new std::vector< pj::AudioDevInfo >((std::vector< pj::AudioDevInfo > const &)*arg1);
  resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(result), SWIGTYPE_p_std__vectorT_pj__AudioDevInfo_std__allocatorT_pj__AudioDevInfo_t_t, SWIG_POINTER_NEW |  0 );
  if (SWIG_IsNewObj(res1)) delete arg1;
  return resultobj;
fail:
  if (SWIG_IsNewObj(res1)) delete arg1;
  return NULL;
}


SWIGINTERN PyObject *_wrap_AudioDevInfoVector2_empty(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  std::vector< pj::AudioDevInfo > *arg1 = (std::vector< pj::AudioDevInfo > *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  bool result;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__vectorT_pj__AudioDevInfo_std__allocatorT_pj__AudioDevInfo_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "AudioDevInfoVector2_empty" "', argument " "1"" of type '" "std::vector< pj::AudioDevInfo > const *""'"); 
  }
  arg1 = reinterpret_cast< std::vector< pj::AudioDevInfo > * >(argp1);
  result = (bool)((std::vector< pj::AudioDevInfo > const *)arg1)->empty();
  resultobj = SWIG_From_bool(static_cast< bool >(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_AudioDevInfoVector2_size(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  std::vector< pj::AudioDevInfo > *arg1 = (std::vector< pj::AudioDevInfo > *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  std::vector< pj::AudioDevInfo >::size_type result;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__vectorT_pj__AudioDevInfo_std__allocatorT_pj__AudioDevInfo_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "AudioDevInfoVector2_size" "', argument " "1"" of type '" "std::vector< pj::AudioDevInfo > const *""'"); 
  }
  arg1 = reinterpret_cast< std::vector< pj::AudioDevInfo > * >(argp1);
  result = ((std::vector< pj::AudioDevInfo > const *)arg1)->size();
  resultobj = SWIG_From_size_t(static_cast< size_t >(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_AudioDevInfoVector2_swap(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  std::vector< pj::AudioDevInfo > *arg1 = (std::vector< pj::AudioDevInfo > *) 0 ;
  std::vector< pj::AudioDevInfo > *arg2 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  void *argp2 = 0 ;
  int res2 = 0 ;
  PyObject *swig_obj[2] ;
  
  if (!SWIG_Python_UnpackTuple(args, "AudioDevInfoVector2_swap", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__vectorT_pj__AudioDevInfo_std__allocatorT_pj__AudioDevInfo_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "AudioDevInfoVector2_swap" "', argument " "1"" of type '" "std::vector< pj::AudioDevInfo > *""'"); 
  }
  arg1 = reinterpret_cast< std::vector< pj::AudioDevInfo > * >(argp1);
  res2 = SWIG_ConvertPtr(swig_obj[1], &argp2, SWIGTYPE_p_std__vectorT_pj__AudioDevInfo_std__allocatorT_pj__AudioDevInfo_t_t,  0 );
  if (!SWIG_IsOK(res2)) {
    SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "AudioDevInfoVector2_swap" "', argument " "2"" of type '" "std::vector< pj::AudioDevInfo > &""'"); 
  }
  if (!argp2) {
    SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "AudioDevInfoVector2_swap" "', argument " "2"" of type '" "std::vector< pj::AudioDevInfo > &""'"); 
  }
  arg2 = reinterpret_cast< std::vector< pj::AudioDevInfo > * >(argp2);
  (arg1)->swap(*arg2);
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_AudioDevInfoVector2_begin(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  std::vector< pj::AudioDevInfo > *arg1 = (std::vector< pj::AudioDevInfo > *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  std::vector< pj::AudioDevInfo >::iterator result;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__vectorT_pj__AudioDevInfo_std__allocatorT_pj__AudioDevInfo_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "AudioDevInfoVector2_begin" "', argument " "1"" of type '" "std::vector< pj::AudioDevInfo > *""'"); 
  }
  arg1 = reinterpret_cast< std::vector< pj::AudioDevInfo > * >(argp1);
  result = (arg1)->begin();
  resultobj = SWIG_NewPointerObj(swig::make_output_iterator(static_cast< const std::vector< pj::AudioDevInfo >::iterator & >(result)),
    swig::SwigPyIterator::descriptor(),SWIG_POINTER_OWN);
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_AudioDevInfoVector2_end(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  std::vector< pj::AudioDevInfo > *arg1 = (std::vector< pj::AudioDevInfo > *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  std::vector< pj::AudioDevInfo >::iterator result;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__vectorT_pj__AudioDevInfo_std__allocatorT_pj__AudioDevInfo_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "AudioDevInfoVector2_end" "', argument " "1"" of type '" "std::vector< pj::AudioDevInfo > *""'"); 
  }
  arg1 = reinterpret_cast< std::vector< pj::AudioDevInfo > * >(argp1);
  result = (arg1)->end();
  resultobj = SWIG_NewPointerObj(swig::make_output_iterator(static_cast< const std::vector< pj::AudioDevInfo >::iterator & >(result)),
    swig::SwigPyIterator::descriptor(),SWIG_POINTER_OWN);
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_AudioDevInfoVector2_rbegin(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  std::vector< pj::AudioDevInfo > *arg1 = (std::vector< pj::AudioDevInfo > *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  std::vector< pj::AudioDevInfo >::reverse_iterator result;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__vectorT_pj__AudioDevInfo_std__allocatorT_pj__AudioDevInfo_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "AudioDevInfoVector2_rbegin" "', argument " "1"" of type '" "std::vector< pj::AudioDevInfo > *""'"); 
  }
  arg1 = reinterpret_cast< std::vector< pj::AudioDevInfo > * >(argp1);
  result = (arg1)->rbegin();
  resultobj = SWIG_NewPointerObj(swig::make_output_iterator(static_cast< const std::vector< pj::AudioDevInfo >::reverse_iterator & >(result)),
    swig::SwigPyIterator::descriptor(),SWIG_POINTER_OWN);
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_AudioDevInfoVector2_rend(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  std::vector< pj::AudioDevInfo > *arg1 = (std::vector< pj::AudioDevInfo > *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  std::vector< pj::AudioDevInfo >::reverse_iterator result;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__vectorT_pj__AudioDevInfo_std__allocatorT_pj__AudioDevInfo_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "AudioDevInfoVector2_rend" "', argument " "1"" of type '" "std::vector< pj::AudioDevInfo > *""'"); 
  }
  arg1 = reinterpret_cast< std::vector< pj::AudioDevInfo > * >(argp1);
  result = (arg1)->rend();
  resultobj = SWIG_NewPointerObj(swig::make_output_iterator(static_cast< const std::vector< pj::AudioDevInfo >::reverse_iterator & >(result)),
    swig::SwigPyIterator::descriptor(),SWIG_POINTER_OWN);
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_AudioDevInfoVector2_clear(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  std::vector< pj::AudioDevInfo > *arg1 = (std::vector< pj::AudioDevInfo > *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__vectorT_pj__AudioDevInfo_std__allocatorT_pj__AudioDevInfo_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "AudioDevInfoVector2_clear" "', argument " "1"" of type '" "std::vector< pj::AudioDevInfo > *""'"); 
  }
  arg1 = reinterpret_cast< std::vector< pj::AudioDevInfo > * >(argp1);
  (arg1)->clear();
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_AudioDevInfoVector2_get_allocator(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  std::vector< pj::AudioDevInfo > *arg1 = (std::vector< pj::AudioDevInfo > *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  SwigValueWrapper< std::allocator< pj::AudioDevInfo > > result;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__vectorT_pj__AudioDevInfo_std__allocatorT_pj__AudioDevInfo_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "AudioDevInfoVector2_get_allocator" "', argument " "1"" of type '" "std::vector< pj::AudioDevInfo > const *""'"); 
  }
  arg1 = reinterpret_cast< std::vector< pj::AudioDevInfo > * >(argp1);
  result = ((std::vector< pj::AudioDevInfo > const *)arg1)->get_allocator();
  resultobj = SWIG_NewPointerObj((new std::vector< pj::AudioDevInfo >::allocator_type(static_cast< const std::vector< pj::AudioDevInfo >::allocator_type& >(result))), SWIGTYPE_p_std__allocatorT_pj__AudioDevInfo_t, SWIG_POINTER_OWN |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_new_AudioDevInfoVector2__SWIG_2(PyObject *SWIGUNUSEDPARM(self), Py_ssize_t nobjs, PyObject **swig_obj) {
  PyObject *resultobj = 0;
  std::vector< pj::AudioDevInfo >::size_type arg1 ;
  size_t val1 ;
  int ecode1 = 0 ;
  std::vector< pj::AudioDevInfo > *result = 0 ;
  
  if ((nobjs < 1) || (nobjs > 1)) SWIG_fail;
  ecode1 = SWIG_AsVal_size_t(swig_obj[0], &val1);
  if (!SWIG_IsOK(ecode1)) {
    SWIG_exception_fail(SWIG_ArgError(ecode1), "in method '" "new_AudioDevInfoVector2" "', argument " "1"" of type '" "std::vector< pj::AudioDevInfo >::size_type""'");
  } 
  arg1 = static_cast< std::vector< pj::AudioDevInfo >::size_type >(val1);
  result = (std::vector< pj::AudioDevInfo > *)new std::vector< pj::AudioDevInfo >(arg1);
  resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(result), SWIGTYPE_p_std__vectorT_pj__AudioDevInfo_std__allocatorT_pj__AudioDevInfo_t_t, SWIG_POINTER_NEW |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_AudioDevInfoVector2_pop_back(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  std::vector< pj::AudioDevInfo > *arg1 = (std::vector< pj::AudioDevInfo > *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__vectorT_pj__AudioDevInfo_std__allocatorT_pj__AudioDevInfo_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "AudioDevInfoVector2_pop_back" "', argument " "1"" of type '" "std::vector< pj::AudioDevInfo > *""'"); 
  }
  arg1 = reinterpret_cast< std::vector< pj::AudioDevInfo > * >(argp1);
  (arg1)->pop_back();
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_AudioDevInfoVector2_resize__SWIG_0(PyObject *SWIGUNUSEDPARM(self), Py_ssize_t nobjs, PyObject **swig_obj) {
  PyObject *resultobj = 0;
  std::vector< pj::AudioDevInfo > *arg1 = (std::vector< pj::AudioDevInfo > *) 0 ;
  std::vector< pj::AudioDevInfo >::size_type arg2 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  size_t val2 ;
  int ecode2 = 0 ;
  
  if ((nobjs < 2) || (nobjs > 2)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__vectorT_pj__AudioDevInfo_std__allocatorT_pj__AudioDevInfo_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "AudioDevInfoVector2_resize" "', argument " "1"" of type '" "std::vector< pj::AudioDevInfo > *""'"); 
  }
  arg1 = reinterpret_cast< std::vector< pj::AudioDevInfo > * >(argp1);
  ecode2 = SWIG_AsVal_size_t(swig_obj[1], &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "AudioDevInfoVector2_resize" "', argument " "2"" of type '" "std::vector< pj::AudioDevInfo >::size_type""'");
  } 
  arg2 = static_cast< std::vector< pj::AudioDevInfo >::size_type >(val2);
  (arg1)->resize(arg2);
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_AudioDevInfoVector2_erase__SWIG_0(PyObject *SWIGUNUSEDPARM(self), Py_ssize_t nobjs, PyObject **swig_obj) {
  PyObject *resultobj = 0;
  std::vector< pj::AudioDevInfo > *arg1 = (std::vector< pj::AudioDevInfo > *) 0 ;
  std::vector< pj::AudioDevInfo >::iterator arg2 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  swig::SwigPyIterator *iter2 = 0 ;
  int res2 ;
  std::vector< pj::AudioDevInfo >::iterator result;
  
  if ((nobjs < 2) || (nobjs > 2)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__vectorT_pj__AudioDevInfo_std__allocatorT_pj__AudioDevInfo_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "AudioDevInfoVector2_erase" "', argument " "1"" of type '" "std::vector< pj::AudioDevInfo > *""'"); 
  }
  arg1 = reinterpret_cast< std::vector< pj::AudioDevInfo > * >(argp1);
  res2 = SWIG_ConvertPtr(swig_obj[1], SWIG_as_voidptrptr(&iter2), swig::SwigPyIterator::descriptor(), 0);
  if (!SWIG_IsOK(res2) || !iter2) {
    SWIG_exception_fail(SWIG_ArgError(SWIG_TypeError), "in method '" "AudioDevInfoVector2_erase" "', argument " "2"" of type '" "std::vector< pj::AudioDevInfo >::iterator""'");
  } else {
    swig::SwigPyIterator_T<std::vector< pj::AudioDevInfo >::iterator > *iter_t = dynamic_cast<swig::SwigPyIterator_T<std::vector< pj::AudioDevInfo >::iterator > *>(iter2);
    if (iter_t) {
      arg2 = iter_t->get_current();
    } else {
      SWIG_exception_fail(SWIG_ArgError(SWIG_TypeError), "in method '" "AudioDevInfoVector2_erase" "', argument " "2"" of type '" "std::vector< pj::AudioDevInfo >::iterator""'");
    }
  }
  result = std_vector_Sl_pj_AudioDevInfo_Sg__erase__SWIG_0(arg1,arg2);
  resultobj = SWIG_NewPointerObj(swig::make_output_iterator(static_cast< const std::vector< pj::AudioDevInfo >::iterator & >(result)),
    swig::SwigPyIterator::descriptor(),SWIG_POINTER_OWN);
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_AudioDevInfoVector2_erase__SWIG_1(PyObject *SWIGUNUSEDPARM(self), Py_ssize_t nobjs, PyObject **swig_obj) {
  PyObject *resultobj = 0;
  std::vector< pj::AudioDevInfo > *arg1 = (std::vector< pj::AudioDevInfo > *) 0 ;
  std::vector< pj::AudioDevInfo >::iterator arg2 ;
  std::vector< pj::AudioDevInfo >::iterator arg3 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  swig::SwigPyIterator *iter2 = 0 ;
  int res2 ;
  swig::SwigPyIterator *iter3 = 0 ;
  int res3 ;
  std::vector< pj::AudioDevInfo >::iterator result;
  
  if ((nobjs < 3) || (nobjs > 3)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__vectorT_pj__AudioDevInfo_std__allocatorT_pj__AudioDevInfo_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "AudioDevInfoVector2_erase" "', argument " "1"" of type '" "std::vector< pj::AudioDevInfo > *""'"); 
  }
  arg1 = reinterpret_cast< std::vector< pj::AudioDevInfo > * >(argp1);
  res2 = SWIG_ConvertPtr(swig_obj[1], SWIG_as_voidptrptr(&iter2), swig::SwigPyIterator::descriptor(), 0);
  if (!SWIG_IsOK(res2) || !iter2) {
    SWIG_exception_fail(SWIG_ArgError(SWIG_TypeError), "in method '" "AudioDevInfoVector2_erase" "', argument " "2"" of type '" "std::vector< pj::AudioDevInfo >::iterator""'");
  } else {
    swig::SwigPyIterator_T<std::vector< pj::AudioDevInfo >::iterator > *iter_t = dynamic_cast<swig::SwigPyIterator_T<std::vector< pj::AudioDevInfo >::iterator > *>(iter2);
    if (iter_t) {
      arg2 = iter_t->get_current();
    } else {
      SWIG_exception_fail(SWIG_ArgError(SWIG_TypeError), "in method '" "AudioDevInfoVector2_erase" "', argument " "2"" of type '" "std::vector< pj::AudioDevInfo >::iterator""'");
    }
  }
  res3 = SWIG_ConvertPtr(swig_obj[2], SWIG_as_voidptrptr(&iter3), swig::SwigPyIterator::descriptor(), 0);
  if (!SWIG_IsOK(res3) || !iter3) {
    SWIG_exception_fail(SWIG_ArgError(SWIG_TypeError), "in method '" "AudioDevInfoVector2_erase" "', argument " "3"" of type '" "std::vector< pj::AudioDevInfo >::iterator""'");
  } else {
    swig::SwigPyIterator_T<std::vector< pj::AudioDevInfo >::iterator > *iter_t = dynamic_cast<swig::SwigPyIterator_T<std::vector< pj::AudioDevInfo >::iterator > *>(iter3);
    if (iter_t) {
      arg3 = iter_t->get_current();
    } else {
      SWIG_exception_fail(SWIG_ArgError(SWIG_TypeError), "in method '" "AudioDevInfoVector2_erase" "', argument " "3"" of type '" "std::vector< pj::AudioDevInfo >::iterator""'");
    }
  }
  result = std_vector_Sl_pj_AudioDevInfo_Sg__erase__SWIG_1(arg1,arg2,arg3);
  resultobj = SWIG_NewPointerObj(swig::make_output_iterator(static_cast< const std::vector< pj::AudioDevInfo >::iterator & >(result)),
    swig::SwigPyIterator::descriptor(),SWIG_POINTER_OWN);
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_AudioDevInfoVector2_erase(PyObject *self, PyObject *args) {
  Py_ssize_t argc;
  PyObject *argv[4] = {
    0
  };
  
  if (!(argc = SWIG_Python_UnpackTuple(args, "AudioDevInfoVector2_erase", 0, 3, argv))) SWIG_fail;
  --argc;
  if (argc == 2) {
    int _v;
    int res = swig::asptr(argv[0], (std::vector< pj::AudioDevInfo,std::allocator< pj::AudioDevInfo > >**)(0));
    _v = SWIG_CheckState(res);
    if (_v) {
      swig::SwigPyIterator *iter = 0;
      int res = SWIG_ConvertPtr(argv[1], SWIG_as_voidptrptr(&iter), swig::SwigPyIterator::descriptor(), 0);
      _v = (SWIG_IsOK(res) && iter && (dynamic_cast<swig::SwigPyIterator_T<std::vector< pj::AudioDevInfo >::iterator > *>(iter) != 0));
      if (_v) {
        return _wrap_AudioDevInfoVector2_erase__SWIG_0(self, argc, argv);
      }
    }
  }
  if (argc == 3) {
    int _v;
    int res = swig::asptr(argv[0], (std::vector< pj::AudioDevInfo,std::allocator< pj::AudioDevInfo > >**)(0));
    _v = SWIG_CheckState(res);
    if (_v) {
      swig::SwigPyIterator *iter = 0;
      int res = SWIG_ConvertPtr(argv[1], SWIG_as_voidptrptr(&iter), swig::SwigPyIterator::descriptor(), 0);
      _v = (SWIG_IsOK(res) && iter && (dynamic_cast<swig::SwigPyIterator_T<std::vector< pj::AudioDevInfo >::iterator > *>(iter) != 0));
      if (_v) {
        swig::SwigPyIterator *iter = 0;
        int res = SWIG_ConvertPtr(argv[2], SWIG_as_voidptrptr(&iter), swig::SwigPyIterator::descriptor(), 0);
        _v = (SWIG_IsOK(res) && iter && (dynamic_cast<swig::SwigPyIterator_T<std::vector< pj::AudioDevInfo >::iterator > *>(iter) != 0));
        if (_v) {
          return _wrap_AudioDevInfoVector2_erase__SWIG_1(self, argc, argv);
        }
      }
    }
  }
  
fail:
  SWIG_Python_RaiseOrModifyTypeError("Wrong number or type of arguments for overloaded function 'AudioDevInfoVector2_erase'.\n"
    "  Possible C/C++ prototypes are:\n"
    "    std::vector< pj::AudioDevInfo >::erase(std::vector< pj::AudioDevInfo >::iterator)\n"
    "    std::vector< pj::AudioDevInfo >::erase(std::vector< pj::AudioDevInfo >::iterator,std::vector< pj::AudioDevInfo >::iterator)\n");
  return 0;
}


SWIGINTERN PyObject *_wrap_new_AudioDevInfoVector2__SWIG_3(PyObject *SWIGUNUSEDPARM(self), Py_ssize_t nobjs, PyObject **swig_obj) {
  PyObject *resultobj = 0;
  std::vector< pj::AudioDevInfo >::size_type arg1 ;
  std::vector< pj::AudioDevInfo >::value_type *arg2 = 0 ;
  size_t val1 ;
  int ecode1 = 0 ;
  void *argp2 = 0 ;
  int res2 = 0 ;
  std::vector< pj::AudioDevInfo > *result = 0 ;
  
  if ((nobjs < 2) || (nobjs > 2)) SWIG_fail;
  ecode1 = SWIG_AsVal_size_t(swig_obj[0], &val1);
  if (!SWIG_IsOK(ecode1)) {
    SWIG_exception_fail(SWIG_ArgError(ecode1), "in method '" "new_AudioDevInfoVector2" "', argument " "1"" of type '" "std::vector< pj::AudioDevInfo >::size_type""'");
  } 
  arg1 = static_cast< std::vector< pj::AudioDevInfo >::size_type >(val1);
  res2 = SWIG_ConvertPtr(swig_obj[1], &argp2, SWIGTYPE_p_pj__AudioDevInfo,  0  | 0);
  if (!SWIG_IsOK(res2)) {
    SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "new_AudioDevInfoVector2" "', argument " "2"" of type '" "std::vector< pj::AudioDevInfo >::value_type const &""'"); 
  }
  if (!argp2) {
    SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "new_AudioDevInfoVector2" "', argument " "2"" of type '" "std::vector< pj::AudioDevInfo >::value_type const &""'"); 
  }
  arg2 = reinterpret_cast< std::vector< pj::AudioDevInfo >::value_type * >(argp2);
  result = (std::vector< pj::AudioDevInfo > *)new std::vector< pj::AudioDevInfo >(arg1,(std::vector< pj::AudioDevInfo >::value_type const &)*arg2);
  resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(result), SWIGTYPE_p_std__vectorT_pj__AudioDevInfo_std__allocatorT_pj__AudioDevInfo_t_t, SWIG_POINTER_NEW |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_new_AudioDevInfoVector2(PyObject *self, PyObject *args) {
  Py_ssize_t argc;
  PyObject *argv[3] = {
    0
  };
  
  if (!(argc = SWIG_Python_UnpackTuple(args, "new_AudioDevInfoVector2", 0, 2, argv))) SWIG_fail;
  --argc;
  if (argc == 0) {
    return _wrap_new_AudioDevInfoVector2__SWIG_0(self, argc, argv);
  }
  if (argc == 1) {
    int _v;
    {
      int res = SWIG_AsVal_size_t(argv[0], NULL);
      _v = SWIG_CheckState(res);
    }
    if (_v) {
      return _wrap_new_AudioDevInfoVector2__SWIG_2(self, argc, argv);
    }
  }
  if (argc == 1) {
    int _v;
    int res = swig::asptr(argv[0], (std::vector< pj::AudioDevInfo,std::allocator< pj::AudioDevInfo > >**)(0));
    _v = SWIG_CheckState(res);
    if (_v) {
      return _wrap_new_AudioDevInfoVector2__SWIG_1(self, argc, argv);
    }
  }
  if (argc == 2) {
    int _v;
    {
      int res = SWIG_AsVal_size_t(argv[0], NULL);
      _v = SWIG_CheckState(res);
    }
    if (_v) {
      int res = SWIG_ConvertPtr(argv[1], 0, SWIGTYPE_p_pj__AudioDevInfo, SWIG_POINTER_NO_NULL | 0);
      _v = SWIG_CheckState(res);
      if (_v) {
        return _wrap_new_AudioDevInfoVector2__SWIG_3(self, argc, argv);
      }
    }
  }
  
fail:
  SWIG_Python_RaiseOrModifyTypeError("Wrong number or type of arguments for overloaded function 'new_AudioDevInfoVector2'.\n"
    "  Possible C/C++ prototypes are:\n"
    "    std::vector< pj::AudioDevInfo >::vector()\n"
    "    std::vector< pj::AudioDevInfo >::vector(std::vector< pj::AudioDevInfo > const &)\n"
    "    std::vector< pj::AudioDevInfo >::vector(std::vector< pj::AudioDevInfo >::size_type)\n"
    "    std::vector< pj::AudioDevInfo >::vector(std::vector< pj::AudioDevInfo >::size_type,std::vector< pj::AudioDevInfo >::value_type const &)\n");
  return 0;
}


SWIGINTERN PyObject *_wrap_AudioDevInfoVector2_push_back(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  std::vector< pj::AudioDevInfo > *arg1 = (std::vector< pj::AudioDevInfo > *) 0 ;
  std::vector< pj::AudioDevInfo >::value_type *arg2 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  void *argp2 = 0 ;
  int res2 = 0 ;
  PyObject *swig_obj[2] ;
  
  if (!SWIG_Python_UnpackTuple(args, "AudioDevInfoVector2_push_back", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__vectorT_pj__AudioDevInfo_std__allocatorT_pj__AudioDevInfo_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "AudioDevInfoVector2_push_back" "', argument " "1"" of type '" "std::vector< pj::AudioDevInfo > *""'"); 
  }
  arg1 = reinterpret_cast< std::vector< pj::AudioDevInfo > * >(argp1);
  res2 = SWIG_ConvertPtr(swig_obj[1], &argp2, SWIGTYPE_p_pj__AudioDevInfo,  0  | 0);
  if (!SWIG_IsOK(res2)) {
    SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "AudioDevInfoVector2_push_back" "', argument " "2"" of type '" "std::vector< pj::AudioDevInfo >::value_type const &""'"); 
  }
  if (!argp2) {
    SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "AudioDevInfoVector2_push_back" "', argument " "2"" of type '" "std::vector< pj::AudioDevInfo >::value_type const &""'"); 
  }
  arg2 = reinterpret_cast< std::vector< pj::AudioDevInfo >::value_type * >(argp2);
  (arg1)->push_back((std::vector< pj::AudioDevInfo >::value_type const &)*arg2);
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_AudioDevInfoVector2_front(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  std::vector< pj::AudioDevInfo > *arg1 = (std::vector< pj::AudioDevInfo > *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  std::vector< pj::AudioDevInfo >::value_type *result = 0 ;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__vectorT_pj__AudioDevInfo_std__allocatorT_pj__AudioDevInfo_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "AudioDevInfoVector2_front" "', argument " "1"" of type '" "std::vector< pj::AudioDevInfo > const *""'"); 
  }
  arg1 = reinterpret_cast< std::vector< pj::AudioDevInfo > * >(argp1);
  result = (std::vector< pj::AudioDevInfo >::value_type *) &((std::vector< pj::AudioDevInfo > const *)arg1)->front();
  resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(result), SWIGTYPE_p_pj__AudioDevInfo, 0 |  0 );
  (void)swig::container_owner<swig::traits<std::vector< pj::AudioDevInfo >::value_type>::category>::back_reference(resultobj, swig_obj[0]);
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_AudioDevInfoVector2_back(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  std::vector< pj::AudioDevInfo > *arg1 = (std::vector< pj::AudioDevInfo > *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  std::vector< pj::AudioDevInfo >::value_type *result = 0 ;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__vectorT_pj__AudioDevInfo_std__allocatorT_pj__AudioDevInfo_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "AudioDevInfoVector2_back" "', argument " "1"" of type '" "std::vector< pj::AudioDevInfo > const *""'"); 
  }
  arg1 = reinterpret_cast< std::vector< pj::AudioDevInfo > * >(argp1);
  result = (std::vector< pj::AudioDevInfo >::value_type *) &((std::vector< pj::AudioDevInfo > const *)arg1)->back();
  resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(result), SWIGTYPE_p_pj__AudioDevInfo, 0 |  0 );
  (void)swig::container_owner<swig::traits<std::vector< pj::AudioDevInfo >::value_type>::category>::back_reference(resultobj, swig_obj[0]);
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_AudioDevInfoVector2_assign(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  std::vector< pj::AudioDevInfo > *arg1 = (std::vector< pj::AudioDevInfo > *) 0 ;
  std::vector< pj::AudioDevInfo >::size_type arg2 ;
  std::vector< pj::AudioDevInfo >::value_type *arg3 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  size_t val2 ;
  int ecode2 = 0 ;
  void *argp3 = 0 ;
  int res3 = 0 ;
  PyObject *swig_obj[3] ;
  
  if (!SWIG_Python_UnpackTuple(args, "AudioDevInfoVector2_assign", 3, 3, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__vectorT_pj__AudioDevInfo_std__allocatorT_pj__AudioDevInfo_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "AudioDevInfoVector2_assign" "', argument " "1"" of type '" "std::vector< pj::AudioDevInfo > *""'"); 
  }
  arg1 = reinterpret_cast< std::vector< pj::AudioDevInfo > * >(argp1);
  ecode2 = SWIG_AsVal_size_t(swig_obj[1], &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "AudioDevInfoVector2_assign" "', argument " "2"" of type '" "std::vector< pj::AudioDevInfo >::size_type""'");
  } 
  arg2 = static_cast< std::vector< pj::AudioDevInfo >::size_type >(val2);
  res3 = SWIG_ConvertPtr(swig_obj[2], &argp3, SWIGTYPE_p_pj__AudioDevInfo,  0  | 0);
  if (!SWIG_IsOK(res3)) {
    SWIG_exception_fail(SWIG_ArgError(res3), "in method '" "AudioDevInfoVector2_assign" "', argument " "3"" of type '" "std::vector< pj::AudioDevInfo >::value_type const &""'"); 
  }
  if (!argp3) {
    SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "AudioDevInfoVector2_assign" "', argument " "3"" of type '" "std::vector< pj::AudioDevInfo >::value_type const &""'"); 
  }
  arg3 = reinterpret_cast< std::vector< pj::AudioDevInfo >::value_type * >(argp3);
  (arg1)->assign(arg2,(std::vector< pj::AudioDevInfo >::value_type const &)*arg3);
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_AudioDevInfoVector2_resize__SWIG_1(PyObject *SWIGUNUSEDPARM(self), Py_ssize_t nobjs, PyObject **swig_obj) {
  PyObject *resultobj = 0;
  std::vector< pj::AudioDevInfo > *arg1 = (std::vector< pj::AudioDevInfo > *) 0 ;
  std::vector< pj::AudioDevInfo >::size_type arg2 ;
  std::vector< pj::AudioDevInfo >::value_type *arg3 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  size_t val2 ;
  int ecode2 = 0 ;
  void *argp3 = 0 ;
  int res3 = 0 ;
  
  if ((nobjs < 3) || (nobjs > 3)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__vectorT_pj__AudioDevInfo_std__allocatorT_pj__AudioDevInfo_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "AudioDevInfoVector2_resize" "', argument " "1"" of type '" "std::vector< pj::AudioDevInfo > *""'"); 
  }
  arg1 = reinterpret_cast< std::vector< pj::AudioDevInfo > * >(argp1);
  ecode2 = SWIG_AsVal_size_t(swig_obj[1], &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "AudioDevInfoVector2_resize" "', argument " "2"" of type '" "std::vector< pj::AudioDevInfo >::size_type""'");
  } 
  arg2 = static_cast< std::vector< pj::AudioDevInfo >::size_type >(val2);
  res3 = SWIG_ConvertPtr(swig_obj[2], &argp3, SWIGTYPE_p_pj__AudioDevInfo,  0  | 0);
  if (!SWIG_IsOK(res3)) {
    SWIG_exception_fail(SWIG_ArgError(res3), "in method '" "AudioDevInfoVector2_resize" "', argument " "3"" of type '" "std::vector< pj::AudioDevInfo >::value_type const &""'"); 
  }
  if (!argp3) {
    SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "AudioDevInfoVector2_resize" "', argument " "3"" of type '" "std::vector< pj::AudioDevInfo >::value_type const &""'"); 
  }
  arg3 = reinterpret_cast< std::vector< pj::AudioDevInfo >::value_type * >(argp3);
  (arg1)->resize(arg2,(std::vector< pj::AudioDevInfo >::value_type const &)*arg3);
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_AudioDevInfoVector2_resize(PyObject *self, PyObject *args) {
  Py_ssize_t argc;
  PyObject *argv[4] = {
    0
  };
  
  if (!(argc = SWIG_Python_UnpackTuple(args, "AudioDevInfoVector2_resize", 0, 3, argv))) SWIG_fail;
  --argc;
  if (argc == 2) {
    int _v;
    int res = swig::asptr(argv[0], (std::vector< pj::AudioDevInfo,std::allocator< pj::AudioDevInfo > >**)(0));
    _v = SWIG_CheckState(res);
    if (_v) {
      {
        int res = SWIG_AsVal_size_t(argv[1], NULL);
        _v = SWIG_CheckState(res);
      }
      if (_v) {
        return _wrap_AudioDevInfoVector2_resize__SWIG_0(self, argc, argv);
      }
    }
  }
  if (argc == 3) {
    int _v;
    int res = swig::asptr(argv[0], (std::vector< pj::AudioDevInfo,std::allocator< pj::AudioDevInfo > >**)(0));
    _v = SWIG_CheckState(res);
    if (_v) {
      {
        int res = SWIG_AsVal_size_t(argv[1], NULL);
        _v = SWIG_CheckState(res);
      }
      if (_v) {
        int res = SWIG_ConvertPtr(argv[2], 0, SWIGTYPE_p_pj__AudioDevInfo, SWIG_POINTER_NO_NULL | 0);
        _v = SWIG_CheckState(res);
        if (_v) {
          return _wrap_AudioDevInfoVector2_resize__SWIG_1(self, argc, argv);
        }
      }
    }
  }
  
fail:
  SWIG_Python_RaiseOrModifyTypeError("Wrong number or type of arguments for overloaded function 'AudioDevInfoVector2_resize'.\n"
    "  Possible C/C++ prototypes are:\n"
    "    std::vector< pj::AudioDevInfo >::resize(std::vector< pj::AudioDevInfo >::size_type)\n"
    "    std::vector< pj::AudioDevInfo >::resize(std::vector< pj::AudioDevInfo >::size_type,std::vector< pj::AudioDevInfo >::value_type const &)\n");
  return 0;
}


SWIGINTERN PyObject *_wrap_AudioDevInfoVector2_insert__SWIG_0(PyObject *SWIGUNUSEDPARM(self), Py_ssize_t nobjs, PyObject **swig_obj) {
  PyObject *resultobj = 0;
  std::vector< pj::AudioDevInfo > *arg1 = (std::vector< pj::AudioDevInfo > *) 0 ;
  std::vector< pj::AudioDevInfo >::iterator arg2 ;
  std::vector< pj::AudioDevInfo >::value_type *arg3 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  swig::SwigPyIterator *iter2 = 0 ;
  int res2 ;
  void *argp3 = 0 ;
  int res3 = 0 ;
  std::vector< pj::AudioDevInfo >::iterator result;
  
  if ((nobjs < 3) || (nobjs > 3)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__vectorT_pj__AudioDevInfo_std__allocatorT_pj__AudioDevInfo_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "AudioDevInfoVector2_insert" "', argument " "1"" of type '" "std::vector< pj::AudioDevInfo > *""'"); 
  }
  arg1 = reinterpret_cast< std::vector< pj::AudioDevInfo > * >(argp1);
  res2 = SWIG_ConvertPtr(swig_obj[1], SWIG_as_voidptrptr(&iter2), swig::SwigPyIterator::descriptor(), 0);
  if (!SWIG_IsOK(res2) || !iter2) {
    SWIG_exception_fail(SWIG_ArgError(SWIG_TypeError), "in method '" "AudioDevInfoVector2_insert" "', argument " "2"" of type '" "std::vector< pj::AudioDevInfo >::iterator""'");
  } else {
    swig::SwigPyIterator_T<std::vector< pj::AudioDevInfo >::iterator > *iter_t = dynamic_cast<swig::SwigPyIterator_T<std::vector< pj::AudioDevInfo >::iterator > *>(iter2);
    if (iter_t) {
      arg2 = iter_t->get_current();
    } else {
      SWIG_exception_fail(SWIG_ArgError(SWIG_TypeError), "in method '" "AudioDevInfoVector2_insert" "', argument " "2"" of type '" "std::vector< pj::AudioDevInfo >::iterator""'");
    }
  }
  res3 = SWIG_ConvertPtr(swig_obj[2], &argp3, SWIGTYPE_p_pj__AudioDevInfo,  0  | 0);
  if (!SWIG_IsOK(res3)) {
    SWIG_exception_fail(SWIG_ArgError(res3), "in method '" "AudioDevInfoVector2_insert" "', argument " "3"" of type '" "std::vector< pj::AudioDevInfo >::value_type const &""'"); 
  }
  if (!argp3) {
    SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "AudioDevInfoVector2_insert" "', argument " "3"" of type '" "std::vector< pj::AudioDevInfo >::value_type const &""'"); 
  }
  arg3 = reinterpret_cast< std::vector< pj::AudioDevInfo >::value_type * >(argp3);
  result = std_vector_Sl_pj_AudioDevInfo_Sg__insert__SWIG_0(arg1,arg2,(pj::AudioDevInfo const &)*arg3);
  resultobj = SWIG_NewPointerObj(swig::make_output_iterator(static_cast< const std::vector< pj::AudioDevInfo >::iterator & >(result)),
    swig::SwigPyIterator::descriptor(),SWIG_POINTER_OWN);
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_AudioDevInfoVector2_insert__SWIG_1(PyObject *SWIGUNUSEDPARM(self), Py_ssize_t nobjs, PyObject **swig_obj) {
  PyObject *resultobj = 0;
  std::vector< pj::AudioDevInfo > *arg1 = (std::vector< pj::AudioDevInfo > *) 0 ;
  std::vector< pj::AudioDevInfo >::iterator arg2 ;
  std::vector< pj::AudioDevInfo >::size_type arg3 ;
  std::vector< pj::AudioDevInfo >::value_type *arg4 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  swig::SwigPyIterator *iter2 = 0 ;
  int res2 ;
  size_t val3 ;
  int ecode3 = 0 ;
  void *argp4 = 0 ;
  int res4 = 0 ;
  
  if ((nobjs < 4) || (nobjs > 4)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__vectorT_pj__AudioDevInfo_std__allocatorT_pj__AudioDevInfo_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "AudioDevInfoVector2_insert" "', argument " "1"" of type '" "std::vector< pj::AudioDevInfo > *""'"); 
  }
  arg1 = reinterpret_cast< std::vector< pj::AudioDevInfo > * >(argp1);
  res2 = SWIG_ConvertPtr(swig_obj[1], SWIG_as_voidptrptr(&iter2), swig::SwigPyIterator::descriptor(), 0);
  if (!SWIG_IsOK(res2) || !iter2) {
    SWIG_exception_fail(SWIG_ArgError(SWIG_TypeError), "in method '" "AudioDevInfoVector2_insert" "', argument " "2"" of type '" "std::vector< pj::AudioDevInfo >::iterator""'");
  } else {
    swig::SwigPyIterator_T<std::vector< pj::AudioDevInfo >::iterator > *iter_t = dynamic_cast<swig::SwigPyIterator_T<std::vector< pj::AudioDevInfo >::iterator > *>(iter2);
    if (iter_t) {
      arg2 = iter_t->get_current();
    } else {
      SWIG_exception_fail(SWIG_ArgError(SWIG_TypeError), "in method '" "AudioDevInfoVector2_insert" "', argument " "2"" of type '" "std::vector< pj::AudioDevInfo >::iterator""'");
    }
  }
  ecode3 = SWIG_AsVal_size_t(swig_obj[2], &val3);
  if (!SWIG_IsOK(ecode3)) {
    SWIG_exception_fail(SWIG_ArgError(ecode3), "in method '" "AudioDevInfoVector2_insert" "', argument " "3"" of type '" "std::vector< pj::AudioDevInfo >::size_type""'");
  } 
  arg3 = static_cast< std::vector< pj::AudioDevInfo >::size_type >(val3);
  res4 = SWIG_ConvertPtr(swig_obj[3], &argp4, SWIGTYPE_p_pj__AudioDevInfo,  0  | 0);
  if (!SWIG_IsOK(res4)) {
    SWIG_exception_fail(SWIG_ArgError(res4), "in method '" "AudioDevInfoVector2_insert" "', argument " "4"" of type '" "std::vector< pj::AudioDevInfo >::value_type const &""'"); 
  }
  if (!argp4) {
    SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "AudioDevInfoVector2_insert" "', argument " "4"" of type '" "std::vector< pj::AudioDevInfo >::value_type const &""'"); 
  }
  arg4 = reinterpret_cast< std::vector< pj::AudioDevInfo >::value_type * >(argp4);
  std_vector_Sl_pj_AudioDevInfo_Sg__insert__SWIG_1(arg1,arg2,arg3,(pj::AudioDevInfo const &)*arg4);
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_AudioDevInfoVector2_insert(PyObject *self, PyObject *args) {
  Py_ssize_t argc;
  PyObject *argv[5] = {
    0
  };
  
  if (!(argc = SWIG_Python_UnpackTuple(args, "AudioDevInfoVector2_insert", 0, 4, argv))) SWIG_fail;
  --argc;
  if (argc == 3) {
    int _v;
    int res = swig::asptr(argv[0], (std::vector< pj::AudioDevInfo,std::allocator< pj::AudioDevInfo > >**)(0));
    _v = SWIG_CheckState(res);
    if (_v) {
      swig::SwigPyIterator *iter = 0;
      int res = SWIG_ConvertPtr(argv[1], SWIG_as_voidptrptr(&iter), swig::SwigPyIterator::descriptor(), 0);
      _v = (SWIG_IsOK(res) && iter && (dynamic_cast<swig::SwigPyIterator_T<std::vector< pj::AudioDevInfo >::iterator > *>(iter) != 0));
      if (_v) {
        int res = SWIG_ConvertPtr(argv[2], 0, SWIGTYPE_p_pj__AudioDevInfo, SWIG_POINTER_NO_NULL | 0);
        _v = SWIG_CheckState(res);
        if (_v) {
          return _wrap_AudioDevInfoVector2_insert__SWIG_0(self, argc, argv);
        }
      }
    }
  }
  if (argc == 4) {
    int _v;
    int res = swig::asptr(argv[0], (std::vector< pj::AudioDevInfo,std::allocator< pj::AudioDevInfo > >**)(0));
    _v = SWIG_CheckState(res);
    if (_v) {
      swig::SwigPyIterator *iter = 0;
      int res = SWIG_ConvertPtr(argv[1], SWIG_as_voidptrptr(&iter), swig::SwigPyIterator::descriptor(), 0);
      _v = (SWIG_IsOK(res) && iter && (dynamic_cast<swig::SwigPyIterator_T<std::vector< pj::AudioDevInfo >::iterator > *>(iter) != 0));
      if (_v) {
        {
          int res = SWIG_AsVal_size_t(argv[2], NULL);
          _v = SWIG_CheckState(res);
        }
        if (_v) {
          int res = SWIG_ConvertPtr(argv[3], 0, SWIGTYPE_p_pj__AudioDevInfo, SWIG_POINTER_NO_NULL | 0);
          _v = SWIG_CheckState(res);
          if (_v) {
            return _wrap_AudioDevInfoVector2_insert__SWIG_1(self, argc, argv);
          }
        }
      }
    }
  }
  
fail:
  SWIG_Python_RaiseOrModifyTypeError("Wrong number or type of arguments for overloaded function 'AudioDevInfoVector2_insert'.\n"
    "  Possible C/C++ prototypes are:\n"
    "    std::vector< pj::AudioDevInfo >::insert(std::vector< pj::AudioDevInfo >::iterator,std::vector< pj::AudioDevInfo >::value_type const &)\n"
    "    std::vector< pj::AudioDevInfo >::insert(std::vector< pj::AudioDevInfo >::iterator,std::vector< pj::AudioDevInfo >::size_type,std::vector< pj::AudioDevInfo >::value_type const &)\n");
  return 0;
}


SWIGINTERN PyObject *_wrap_AudioDevInfoVector2_reserve(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  std::vector< pj::AudioDevInfo > *arg1 = (std::vector< pj::AudioDevInfo > *) 0 ;
  std::vector< pj::AudioDevInfo >::size_type arg2 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  size_t val2 ;
  int ecode2 = 0 ;
  PyObject *swig_obj[2] ;
  
  if (!SWIG_Python_UnpackTuple(args, "AudioDevInfoVector2_reserve", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__vectorT_pj__AudioDevInfo_std__allocatorT_pj__AudioDevInfo_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "AudioDevInfoVector2_reserve" "', argument " "1"" of type '" "std::vector< pj::AudioDevInfo > *""'"); 
  }
  arg1 = reinterpret_cast< std::vector< pj::AudioDevInfo > * >(argp1);
  ecode2 = SWIG_AsVal_size_t(swig_obj[1], &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "AudioDevInfoVector2_reserve" "', argument " "2"" of type '" "std::vector< pj::AudioDevInfo >::size_type""'");
  } 
  arg2 = static_cast< std::vector< pj::AudioDevInfo >::size_type >(val2);
  (arg1)->reserve(arg2);
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_AudioDevInfoVector2_capacity(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  std::vector< pj::AudioDevInfo > *arg1 = (std::vector< pj::AudioDevInfo > *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  std::vector< pj::AudioDevInfo >::size_type result;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__vectorT_pj__AudioDevInfo_std__allocatorT_pj__AudioDevInfo_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "AudioDevInfoVector2_capacity" "', argument " "1"" of type '" "std::vector< pj::AudioDevInfo > const *""'"); 
  }
  arg1 = reinterpret_cast< std::vector< pj::AudioDevInfo > * >(argp1);
  result = ((std::vector< pj::AudioDevInfo > const *)arg1)->capacity();
  resultobj = SWIG_From_size_t(static_cast< size_t >(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_delete_AudioDevInfoVector2(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  std::vector< pj::AudioDevInfo > *arg1 = (std::vector< pj::AudioDevInfo > *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__vectorT_pj__AudioDevInfo_std__allocatorT_pj__AudioDevInfo_t_t, SWIG_POINTER_DISOWN |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "delete_AudioDevInfoVector2" "', argument " "1"" of type '" "std::vector< pj::AudioDevInfo > *""'"); 
  }
  arg1 = reinterpret_cast< std::vector< pj::AudioDevInfo > * >(argp1);
  delete arg1;
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *AudioDevInfoVector2_swigregister(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *obj;
  if (!SWIG_Python_UnpackTuple(args, "swigregister", 1, 1, &obj)) return NULL;
  SWIG_TypeNewClientData(SWIGTYPE_p_std__vectorT_pj__AudioDevInfo_std__allocatorT_pj__AudioDevInfo_t_t, SWIG_NewClientData(obj));
  return SWIG_Py_Void();
}

SWIGINTERN PyObject *AudioDevInfoVector2_swiginit(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  return SWIG_Python_InitShadowInstance(args);
}

SWIGINTERN PyObject *_wrap_CodecInfoVector_iterator(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  std::vector< pj::CodecInfo * > *arg1 = (std::vector< pj::CodecInfo * > *) 0 ;
  PyObject **arg2 = (PyObject **) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  swig::SwigPyIterator *result = 0 ;
  
  arg2 = &swig_obj[0];
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__vectorT_pj__CodecInfo_p_std__allocatorT_pj__CodecInfo_p_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "CodecInfoVector_iterator" "', argument " "1"" of type '" "std::vector< pj::CodecInfo * > *""'"); 
  }
  arg1 = reinterpret_cast< std::vector< pj::CodecInfo * > * >(argp1);
  result = (swig::SwigPyIterator *)std_vector_Sl_pj_CodecInfo_Sm__Sg__iterator(arg1,arg2);
  resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(result), SWIGTYPE_p_swig__SwigPyIterator, SWIG_POINTER_OWN |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_CodecInfoVector___nonzero__(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  std::vector< pj::CodecInfo * > *arg1 = (std::vector< pj::CodecInfo * > *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  bool result;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__vectorT_pj__CodecInfo_p_std__allocatorT_pj__CodecInfo_p_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "CodecInfoVector___nonzero__" "', argument " "1"" of type '" "std::vector< pj::CodecInfo * > const *""'"); 
  }
  arg1 = reinterpret_cast< std::vector< pj::CodecInfo * > * >(argp1);
  result = (bool)std_vector_Sl_pj_CodecInfo_Sm__Sg____nonzero__((std::vector< pj::CodecInfo * > const *)arg1);
  resultobj = SWIG_From_bool(static_cast< bool >(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_CodecInfoVector___bool__(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  std::vector< pj::CodecInfo * > *arg1 = (std::vector< pj::CodecInfo * > *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  bool result;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__vectorT_pj__CodecInfo_p_std__allocatorT_pj__CodecInfo_p_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "CodecInfoVector___bool__" "', argument " "1"" of type '" "std::vector< pj::CodecInfo * > const *""'"); 
  }
  arg1 = reinterpret_cast< std::vector< pj::CodecInfo * > * >(argp1);
  result = (bool)std_vector_Sl_pj_CodecInfo_Sm__Sg____bool__((std::vector< pj::CodecInfo * > const *)arg1);
  resultobj = SWIG_From_bool(static_cast< bool >(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_CodecInfoVector___len__(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  std::vector< pj::CodecInfo * > *arg1 = (std::vector< pj::CodecInfo * > *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  std::vector< pj::CodecInfo * >::size_type result;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__vectorT_pj__CodecInfo_p_std__allocatorT_pj__CodecInfo_p_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "CodecInfoVector___len__" "', argument " "1"" of type '" "std::vector< pj::CodecInfo * > const *""'"); 
  }
  arg1 = reinterpret_cast< std::vector< pj::CodecInfo * > * >(argp1);
  result = std_vector_Sl_pj_CodecInfo_Sm__Sg____len__((std::vector< pj::CodecInfo * > const *)arg1);
  resultobj = SWIG_From_size_t(static_cast< size_t >(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_CodecInfoVector___getslice__(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  std::vector< pj::CodecInfo * > *arg1 = (std::vector< pj::CodecInfo * > *) 0 ;
  std::vector< pj::CodecInfo * >::difference_type arg2 ;
  std::vector< pj::CodecInfo * >::difference_type arg3 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  ptrdiff_t val2 ;
  int ecode2 = 0 ;
  ptrdiff_t val3 ;
  int ecode3 = 0 ;
  PyObject *swig_obj[3] ;
  std::vector< pj::CodecInfo *,std::allocator< pj::CodecInfo * > > *result = 0 ;
  
  if (!SWIG_Python_UnpackTuple(args, "CodecInfoVector___getslice__", 3, 3, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__vectorT_pj__CodecInfo_p_std__allocatorT_pj__CodecInfo_p_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "CodecInfoVector___getslice__" "', argument " "1"" of type '" "std::vector< pj::CodecInfo * > *""'"); 
  }
  arg1 = reinterpret_cast< std::vector< pj::CodecInfo * > * >(argp1);
  ecode2 = SWIG_AsVal_ptrdiff_t(swig_obj[1], &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "CodecInfoVector___getslice__" "', argument " "2"" of type '" "std::vector< pj::CodecInfo * >::difference_type""'");
  } 
  arg2 = static_cast< std::vector< pj::CodecInfo * >::difference_type >(val2);
  ecode3 = SWIG_AsVal_ptrdiff_t(swig_obj[2], &val3);
  if (!SWIG_IsOK(ecode3)) {
    SWIG_exception_fail(SWIG_ArgError(ecode3), "in method '" "CodecInfoVector___getslice__" "', argument " "3"" of type '" "std::vector< pj::CodecInfo * >::difference_type""'");
  } 
  arg3 = static_cast< std::vector< pj::CodecInfo * >::difference_type >(val3);
  try {
    result = (std::vector< pj::CodecInfo *,std::allocator< pj::CodecInfo * > > *)std_vector_Sl_pj_CodecInfo_Sm__Sg____getslice__(arg1,arg2,arg3);
  } catch(std::out_of_range &_e) {
    SWIG_exception_fail(SWIG_IndexError, (&_e)->what());
  } catch(std::invalid_argument &_e) {
    SWIG_exception_fail(SWIG_ValueError, (&_e)->what());
  }
  resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(result), SWIGTYPE_p_std__vectorT_pj__CodecInfo_p_std__allocatorT_pj__CodecInfo_p_t_t, SWIG_POINTER_OWN |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_CodecInfoVector___setslice____SWIG_0(PyObject *SWIGUNUSEDPARM(self), Py_ssize_t nobjs, PyObject **swig_obj) {
  PyObject *resultobj = 0;
  std::vector< pj::CodecInfo * > *arg1 = (std::vector< pj::CodecInfo * > *) 0 ;
  std::vector< pj::CodecInfo * >::difference_type arg2 ;
  std::vector< pj::CodecInfo * >::difference_type arg3 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  ptrdiff_t val2 ;
  int ecode2 = 0 ;
  ptrdiff_t val3 ;
  int ecode3 = 0 ;
  
  if ((nobjs < 3) || (nobjs > 3)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__vectorT_pj__CodecInfo_p_std__allocatorT_pj__CodecInfo_p_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "CodecInfoVector___setslice__" "', argument " "1"" of type '" "std::vector< pj::CodecInfo * > *""'"); 
  }
  arg1 = reinterpret_cast< std::vector< pj::CodecInfo * > * >(argp1);
  ecode2 = SWIG_AsVal_ptrdiff_t(swig_obj[1], &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "CodecInfoVector___setslice__" "', argument " "2"" of type '" "std::vector< pj::CodecInfo * >::difference_type""'");
  } 
  arg2 = static_cast< std::vector< pj::CodecInfo * >::difference_type >(val2);
  ecode3 = SWIG_AsVal_ptrdiff_t(swig_obj[2], &val3);
  if (!SWIG_IsOK(ecode3)) {
    SWIG_exception_fail(SWIG_ArgError(ecode3), "in method '" "CodecInfoVector___setslice__" "', argument " "3"" of type '" "std::vector< pj::CodecInfo * >::difference_type""'");
  } 
  arg3 = static_cast< std::vector< pj::CodecInfo * >::difference_type >(val3);
  try {
    std_vector_Sl_pj_CodecInfo_Sm__Sg____setslice____SWIG_0(arg1,arg2,arg3);
  } catch(std::out_of_range &_e) {
    SWIG_exception_fail(SWIG_IndexError, (&_e)->what());
  } catch(std::invalid_argument &_e) {
    SWIG_exception_fail(SWIG_ValueError, (&_e)->what());
  }
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_CodecInfoVector___setslice____SWIG_1(PyObject *SWIGUNUSEDPARM(self), Py_ssize_t nobjs, PyObject **swig_obj) {
  PyObject *resultobj = 0;
  std::vector< pj::CodecInfo * > *arg1 = (std::vector< pj::CodecInfo * > *) 0 ;
  std::vector< pj::CodecInfo * >::difference_type arg2 ;
  std::vector< pj::CodecInfo * >::difference_type arg3 ;
  std::vector< pj::CodecInfo *,std::allocator< pj::CodecInfo * > > *arg4 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  ptrdiff_t val2 ;
  int ecode2 = 0 ;
  ptrdiff_t val3 ;
  int ecode3 = 0 ;
  int res4 = SWIG_OLDOBJ ;
  
  if ((nobjs < 4) || (nobjs > 4)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__vectorT_pj__CodecInfo_p_std__allocatorT_pj__CodecInfo_p_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "CodecInfoVector___setslice__" "', argument " "1"" of type '" "std::vector< pj::CodecInfo * > *""'"); 
  }
  arg1 = reinterpret_cast< std::vector< pj::CodecInfo * > * >(argp1);
  ecode2 = SWIG_AsVal_ptrdiff_t(swig_obj[1], &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "CodecInfoVector___setslice__" "', argument " "2"" of type '" "std::vector< pj::CodecInfo * >::difference_type""'");
  } 
  arg2 = static_cast< std::vector< pj::CodecInfo * >::difference_type >(val2);
  ecode3 = SWIG_AsVal_ptrdiff_t(swig_obj[2], &val3);
  if (!SWIG_IsOK(ecode3)) {
    SWIG_exception_fail(SWIG_ArgError(ecode3), "in method '" "CodecInfoVector___setslice__" "', argument " "3"" of type '" "std::vector< pj::CodecInfo * >::difference_type""'");
  } 
  arg3 = static_cast< std::vector< pj::CodecInfo * >::difference_type >(val3);
  {
    std::vector< pj::CodecInfo*,std::allocator< pj::CodecInfo * > > *ptr = (std::vector< pj::CodecInfo*,std::allocator< pj::CodecInfo * > > *)0;
    res4 = swig::asptr(swig_obj[3], &ptr);
    if (!SWIG_IsOK(res4)) {
      SWIG_exception_fail(SWIG_ArgError(res4), "in method '" "CodecInfoVector___setslice__" "', argument " "4"" of type '" "std::vector< pj::CodecInfo *,std::allocator< pj::CodecInfo * > > const &""'"); 
    }
    if (!ptr) {
      SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "CodecInfoVector___setslice__" "', argument " "4"" of type '" "std::vector< pj::CodecInfo *,std::allocator< pj::CodecInfo * > > const &""'"); 
    }
    arg4 = ptr;
  }
  try {
    std_vector_Sl_pj_CodecInfo_Sm__Sg____setslice____SWIG_1(arg1,arg2,arg3,(std::vector< pj::CodecInfo *,std::allocator< pj::CodecInfo * > > const &)*arg4);
  } catch(std::out_of_range &_e) {
    SWIG_exception_fail(SWIG_IndexError, (&_e)->what());
  } catch(std::invalid_argument &_e) {
    SWIG_exception_fail(SWIG_ValueError, (&_e)->what());
  }
  resultobj = SWIG_Py_Void();
  if (SWIG_IsNewObj(res4)) delete arg4;
  return resultobj;
fail:
  if (SWIG_IsNewObj(res4)) delete arg4;
  return NULL;
}


SWIGINTERN PyObject *_wrap_CodecInfoVector___setslice__(PyObject *self, PyObject *args) {
  Py_ssize_t argc;
  PyObject *argv[5] = {
    0
  };
  
  if (!(argc = SWIG_Python_UnpackTuple(args, "CodecInfoVector___setslice__", 0, 4, argv))) SWIG_fail;
  --argc;
  if (argc == 3) {
    int _v;
    int res = swig::asptr(argv[0], (std::vector< pj::CodecInfo*,std::allocator< pj::CodecInfo * > >**)(0));
    _v = SWIG_CheckState(res);
    if (_v) {
      {
        int res = SWIG_AsVal_ptrdiff_t(argv[1], NULL);
        _v = SWIG_CheckState(res);
      }
      if (_v) {
        {
          int res = SWIG_AsVal_ptrdiff_t(argv[2], NULL);
          _v = SWIG_CheckState(res);
        }
        if (_v) {
          return _wrap_CodecInfoVector___setslice____SWIG_0(self, argc, argv);
        }
      }
    }
  }
  if (argc == 4) {
    int _v;
    int res = swig::asptr(argv[0], (std::vector< pj::CodecInfo*,std::allocator< pj::CodecInfo * > >**)(0));
    _v = SWIG_CheckState(res);
    if (_v) {
      {
        int res = SWIG_AsVal_ptrdiff_t(argv[1], NULL);
        _v = SWIG_CheckState(res);
      }
      if (_v) {
        {
          int res = SWIG_AsVal_ptrdiff_t(argv[2], NULL);
          _v = SWIG_CheckState(res);
        }
        if (_v) {
          int res = swig::asptr(argv[3], (std::vector< pj::CodecInfo*,std::allocator< pj::CodecInfo * > >**)(0));
          _v = SWIG_CheckState(res);
          if (_v) {
            return _wrap_CodecInfoVector___setslice____SWIG_1(self, argc, argv);
          }
        }
      }
    }
  }
  
fail:
  SWIG_Python_RaiseOrModifyTypeError("Wrong number or type of arguments for overloaded function 'CodecInfoVector___setslice__'.\n"
    "  Possible C/C++ prototypes are:\n"
    "    std::vector< pj::CodecInfo * >::__setslice__(std::vector< pj::CodecInfo * >::difference_type,std::vector< pj::CodecInfo * >::difference_type)\n"
    "    std::vector< pj::CodecInfo * >::__setslice__(std::vector< pj::CodecInfo * >::difference_type,std::vector< pj::CodecInfo * >::difference_type,std::vector< pj::CodecInfo *,std::allocator< pj::CodecInfo * > > const &)\n");
  return 0;
}


SWIGINTERN PyObject *_wrap_CodecInfoVector___delslice__(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  std::vector< pj::CodecInfo * > *arg1 = (std::vector< pj::CodecInfo * > *) 0 ;
  std::vector< pj::CodecInfo * >::difference_type arg2 ;
  std::vector< pj::CodecInfo * >::difference_type arg3 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  ptrdiff_t val2 ;
  int ecode2 = 0 ;
  ptrdiff_t val3 ;
  int ecode3 = 0 ;
  PyObject *swig_obj[3] ;
  
  if (!SWIG_Python_UnpackTuple(args, "CodecInfoVector___delslice__", 3, 3, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__vectorT_pj__CodecInfo_p_std__allocatorT_pj__CodecInfo_p_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "CodecInfoVector___delslice__" "', argument " "1"" of type '" "std::vector< pj::CodecInfo * > *""'"); 
  }
  arg1 = reinterpret_cast< std::vector< pj::CodecInfo * > * >(argp1);
  ecode2 = SWIG_AsVal_ptrdiff_t(swig_obj[1], &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "CodecInfoVector___delslice__" "', argument " "2"" of type '" "std::vector< pj::CodecInfo * >::difference_type""'");
  } 
  arg2 = static_cast< std::vector< pj::CodecInfo * >::difference_type >(val2);
  ecode3 = SWIG_AsVal_ptrdiff_t(swig_obj[2], &val3);
  if (!SWIG_IsOK(ecode3)) {
    SWIG_exception_fail(SWIG_ArgError(ecode3), "in method '" "CodecInfoVector___delslice__" "', argument " "3"" of type '" "std::vector< pj::CodecInfo * >::difference_type""'");
  } 
  arg3 = static_cast< std::vector< pj::CodecInfo * >::difference_type >(val3);
  try {
    std_vector_Sl_pj_CodecInfo_Sm__Sg____delslice__(arg1,arg2,arg3);
  } catch(std::out_of_range &_e) {
    SWIG_exception_fail(SWIG_IndexError, (&_e)->what());
  } catch(std::invalid_argument &_e) {
    SWIG_exception_fail(SWIG_ValueError, (&_e)->what());
  }
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_CodecInfoVector___delitem____SWIG_0(PyObject *SWIGUNUSEDPARM(self), Py_ssize_t nobjs, PyObject **swig_obj) {
  PyObject *resultobj = 0;
  std::vector< pj::CodecInfo * > *arg1 = (std::vector< pj::CodecInfo * > *) 0 ;
  std::vector< pj::CodecInfo * >::difference_type arg2 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  ptrdiff_t val2 ;
  int ecode2 = 0 ;
  
  if ((nobjs < 2) || (nobjs > 2)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__vectorT_pj__CodecInfo_p_std__allocatorT_pj__CodecInfo_p_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "CodecInfoVector___delitem__" "', argument " "1"" of type '" "std::vector< pj::CodecInfo * > *""'"); 
  }
  arg1 = reinterpret_cast< std::vector< pj::CodecInfo * > * >(argp1);
  ecode2 = SWIG_AsVal_ptrdiff_t(swig_obj[1], &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "CodecInfoVector___delitem__" "', argument " "2"" of type '" "std::vector< pj::CodecInfo * >::difference_type""'");
  } 
  arg2 = static_cast< std::vector< pj::CodecInfo * >::difference_type >(val2);
  try {
    std_vector_Sl_pj_CodecInfo_Sm__Sg____delitem____SWIG_0(arg1,arg2);
  } catch(std::out_of_range &_e) {
    SWIG_exception_fail(SWIG_IndexError, (&_e)->what());
  } catch(std::invalid_argument &_e) {
    SWIG_exception_fail(SWIG_ValueError, (&_e)->what());
  }
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_CodecInfoVector___getitem____SWIG_0(PyObject *SWIGUNUSEDPARM(self), Py_ssize_t nobjs, PyObject **swig_obj) {
  PyObject *resultobj = 0;
  std::vector< pj::CodecInfo * > *arg1 = (std::vector< pj::CodecInfo * > *) 0 ;
  PySliceObject *arg2 = (PySliceObject *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  std::vector< pj::CodecInfo *,std::allocator< pj::CodecInfo * > > *result = 0 ;
  
  if ((nobjs < 2) || (nobjs > 2)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__vectorT_pj__CodecInfo_p_std__allocatorT_pj__CodecInfo_p_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "CodecInfoVector___getitem__" "', argument " "1"" of type '" "std::vector< pj::CodecInfo * > *""'"); 
  }
  arg1 = reinterpret_cast< std::vector< pj::CodecInfo * > * >(argp1);
  {
    if (!PySlice_Check(swig_obj[1])) {
      SWIG_exception_fail(SWIG_ArgError(SWIG_TypeError), "in method '" "CodecInfoVector___getitem__" "', argument " "2"" of type '" "PySliceObject *""'");
    }
    arg2 = (PySliceObject *) swig_obj[1];
  }
  try {
    result = (std::vector< pj::CodecInfo *,std::allocator< pj::CodecInfo * > > *)std_vector_Sl_pj_CodecInfo_Sm__Sg____getitem____SWIG_0(arg1,arg2);
  } catch(std::out_of_range &_e) {
    SWIG_exception_fail(SWIG_IndexError, (&_e)->what());
  } catch(std::invalid_argument &_e) {
    SWIG_exception_fail(SWIG_ValueError, (&_e)->what());
  }
  resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(result), SWIGTYPE_p_std__vectorT_pj__CodecInfo_p_std__allocatorT_pj__CodecInfo_p_t_t, SWIG_POINTER_OWN |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_CodecInfoVector___setitem____SWIG_0(PyObject *SWIGUNUSEDPARM(self), Py_ssize_t nobjs, PyObject **swig_obj) {
  PyObject *resultobj = 0;
  std::vector< pj::CodecInfo * > *arg1 = (std::vector< pj::CodecInfo * > *) 0 ;
  PySliceObject *arg2 = (PySliceObject *) 0 ;
  std::vector< pj::CodecInfo *,std::allocator< pj::CodecInfo * > > *arg3 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  int res3 = SWIG_OLDOBJ ;
  
  if ((nobjs < 3) || (nobjs > 3)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__vectorT_pj__CodecInfo_p_std__allocatorT_pj__CodecInfo_p_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "CodecInfoVector___setitem__" "', argument " "1"" of type '" "std::vector< pj::CodecInfo * > *""'"); 
  }
  arg1 = reinterpret_cast< std::vector< pj::CodecInfo * > * >(argp1);
  {
    if (!PySlice_Check(swig_obj[1])) {
      SWIG_exception_fail(SWIG_ArgError(SWIG_TypeError), "in method '" "CodecInfoVector___setitem__" "', argument " "2"" of type '" "PySliceObject *""'");
    }
    arg2 = (PySliceObject *) swig_obj[1];
  }
  {
    std::vector< pj::CodecInfo*,std::allocator< pj::CodecInfo * > > *ptr = (std::vector< pj::CodecInfo*,std::allocator< pj::CodecInfo * > > *)0;
    res3 = swig::asptr(swig_obj[2], &ptr);
    if (!SWIG_IsOK(res3)) {
      SWIG_exception_fail(SWIG_ArgError(res3), "in method '" "CodecInfoVector___setitem__" "', argument " "3"" of type '" "std::vector< pj::CodecInfo *,std::allocator< pj::CodecInfo * > > const &""'"); 
    }
    if (!ptr) {
      SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "CodecInfoVector___setitem__" "', argument " "3"" of type '" "std::vector< pj::CodecInfo *,std::allocator< pj::CodecInfo * > > const &""'"); 
    }
    arg3 = ptr;
  }
  try {
    std_vector_Sl_pj_CodecInfo_Sm__Sg____setitem____SWIG_0(arg1,arg2,(std::vector< pj::CodecInfo *,std::allocator< pj::CodecInfo * > > const &)*arg3);
  } catch(std::out_of_range &_e) {
    SWIG_exception_fail(SWIG_IndexError, (&_e)->what());
  } catch(std::invalid_argument &_e) {
    SWIG_exception_fail(SWIG_ValueError, (&_e)->what());
  }
  resultobj = SWIG_Py_Void();
  if (SWIG_IsNewObj(res3)) delete arg3;
  return resultobj;
fail:
  if (SWIG_IsNewObj(res3)) delete arg3;
  return NULL;
}


SWIGINTERN PyObject *_wrap_CodecInfoVector___setitem____SWIG_1(PyObject *SWIGUNUSEDPARM(self), Py_ssize_t nobjs, PyObject **swig_obj) {
  PyObject *resultobj = 0;
  std::vector< pj::CodecInfo * > *arg1 = (std::vector< pj::CodecInfo * > *) 0 ;
  PySliceObject *arg2 = (PySliceObject *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  
  if ((nobjs < 2) || (nobjs > 2)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__vectorT_pj__CodecInfo_p_std__allocatorT_pj__CodecInfo_p_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "CodecInfoVector___setitem__" "', argument " "1"" of type '" "std::vector< pj::CodecInfo * > *""'"); 
  }
  arg1 = reinterpret_cast< std::vector< pj::CodecInfo * > * >(argp1);
  {
    if (!PySlice_Check(swig_obj[1])) {
      SWIG_exception_fail(SWIG_ArgError(SWIG_TypeError), "in method '" "CodecInfoVector___setitem__" "', argument " "2"" of type '" "PySliceObject *""'");
    }
    arg2 = (PySliceObject *) swig_obj[1];
  }
  try {
    std_vector_Sl_pj_CodecInfo_Sm__Sg____setitem____SWIG_1(arg1,arg2);
  } catch(std::out_of_range &_e) {
    SWIG_exception_fail(SWIG_IndexError, (&_e)->what());
  } catch(std::invalid_argument &_e) {
    SWIG_exception_fail(SWIG_ValueError, (&_e)->what());
  }
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_CodecInfoVector___delitem____SWIG_1(PyObject *SWIGUNUSEDPARM(self), Py_ssize_t nobjs, PyObject **swig_obj) {
  PyObject *resultobj = 0;
  std::vector< pj::CodecInfo * > *arg1 = (std::vector< pj::CodecInfo * > *) 0 ;
  PySliceObject *arg2 = (PySliceObject *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  
  if ((nobjs < 2) || (nobjs > 2)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__vectorT_pj__CodecInfo_p_std__allocatorT_pj__CodecInfo_p_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "CodecInfoVector___delitem__" "', argument " "1"" of type '" "std::vector< pj::CodecInfo * > *""'"); 
  }
  arg1 = reinterpret_cast< std::vector< pj::CodecInfo * > * >(argp1);
  {
    if (!PySlice_Check(swig_obj[1])) {
      SWIG_exception_fail(SWIG_ArgError(SWIG_TypeError), "in method '" "CodecInfoVector___delitem__" "', argument " "2"" of type '" "PySliceObject *""'");
    }
    arg2 = (PySliceObject *) swig_obj[1];
  }
  try {
    std_vector_Sl_pj_CodecInfo_Sm__Sg____delitem____SWIG_1(arg1,arg2);
  } catch(std::out_of_range &_e) {
    SWIG_exception_fail(SWIG_IndexError, (&_e)->what());
  } catch(std::invalid_argument &_e) {
    SWIG_exception_fail(SWIG_ValueError, (&_e)->what());
  }
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_CodecInfoVector___delitem__(PyObject *self, PyObject *args) {
  Py_ssize_t argc;
  PyObject *argv[3] = {
    0
  };
  
  if (!(argc = SWIG_Python_UnpackTuple(args, "CodecInfoVector___delitem__", 0, 2, argv))) SWIG_fail;
  --argc;
  if (argc == 2) {
    int _v;
    int res = swig::asptr(argv[0], (std::vector< pj::CodecInfo*,std::allocator< pj::CodecInfo * > >**)(0));
    _v = SWIG_CheckState(res);
    if (_v) {
      {
        _v = PySlice_Check(argv[1]);
      }
      if (_v) {
        return _wrap_CodecInfoVector___delitem____SWIG_1(self, argc, argv);
      }
    }
  }
  if (argc == 2) {
    int _v;
    int res = swig::asptr(argv[0], (std::vector< pj::CodecInfo*,std::allocator< pj::CodecInfo * > >**)(0));
    _v = SWIG_CheckState(res);
    if (_v) {
      {
        int res = SWIG_AsVal_ptrdiff_t(argv[1], NULL);
        _v = SWIG_CheckState(res);
      }
      if (_v) {
        return _wrap_CodecInfoVector___delitem____SWIG_0(self, argc, argv);
      }
    }
  }
  
fail:
  SWIG_Python_RaiseOrModifyTypeError("Wrong number or type of arguments for overloaded function 'CodecInfoVector___delitem__'.\n"
    "  Possible C/C++ prototypes are:\n"
    "    std::vector< pj::CodecInfo * >::__delitem__(std::vector< pj::CodecInfo * >::difference_type)\n"
    "    std::vector< pj::CodecInfo * >::__delitem__(PySliceObject *)\n");
  return 0;
}


SWIGINTERN PyObject *_wrap_CodecInfoVector___getitem____SWIG_1(PyObject *SWIGUNUSEDPARM(self), Py_ssize_t nobjs, PyObject **swig_obj) {
  PyObject *resultobj = 0;
  std::vector< pj::CodecInfo * > *arg1 = (std::vector< pj::CodecInfo * > *) 0 ;
  std::vector< pj::CodecInfo * >::difference_type arg2 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  ptrdiff_t val2 ;
  int ecode2 = 0 ;
  std::vector< pj::CodecInfo * >::value_type result;
  
  if ((nobjs < 2) || (nobjs > 2)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__vectorT_pj__CodecInfo_p_std__allocatorT_pj__CodecInfo_p_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "CodecInfoVector___getitem__" "', argument " "1"" of type '" "std::vector< pj::CodecInfo * > *""'"); 
  }
  arg1 = reinterpret_cast< std::vector< pj::CodecInfo * > * >(argp1);
  ecode2 = SWIG_AsVal_ptrdiff_t(swig_obj[1], &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "CodecInfoVector___getitem__" "', argument " "2"" of type '" "std::vector< pj::CodecInfo * >::difference_type""'");
  } 
  arg2 = static_cast< std::vector< pj::CodecInfo * >::difference_type >(val2);
  try {
    result = (std::vector< pj::CodecInfo * >::value_type)std_vector_Sl_pj_CodecInfo_Sm__Sg____getitem____SWIG_1(arg1,arg2);
  } catch(std::out_of_range &_e) {
    SWIG_exception_fail(SWIG_IndexError, (&_e)->what());
  }
  resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(result), SWIGTYPE_p_pj__CodecInfo, 0 |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_CodecInfoVector___getitem__(PyObject *self, PyObject *args) {
  Py_ssize_t argc;
  PyObject *argv[3] = {
    0
  };
  
  if (!(argc = SWIG_Python_UnpackTuple(args, "CodecInfoVector___getitem__", 0, 2, argv))) SWIG_fail;
  --argc;
  if (argc == 2) {
    int _v;
    int res = swig::asptr(argv[0], (std::vector< pj::CodecInfo*,std::allocator< pj::CodecInfo * > >**)(0));
    _v = SWIG_CheckState(res);
    if (_v) {
      {
        _v = PySlice_Check(argv[1]);
      }
      if (_v) {
        return _wrap_CodecInfoVector___getitem____SWIG_0(self, argc, argv);
      }
    }
  }
  if (argc == 2) {
    int _v;
    int res = swig::asptr(argv[0], (std::vector< pj::CodecInfo*,std::allocator< pj::CodecInfo * > >**)(0));
    _v = SWIG_CheckState(res);
    if (_v) {
      {
        int res = SWIG_AsVal_ptrdiff_t(argv[1], NULL);
        _v = SWIG_CheckState(res);
      }
      if (_v) {
        return _wrap_CodecInfoVector___getitem____SWIG_1(self, argc, argv);
      }
    }
  }
  
fail:
  SWIG_Python_RaiseOrModifyTypeError("Wrong number or type of arguments for overloaded function 'CodecInfoVector___getitem__'.\n"
    "  Possible C/C++ prototypes are:\n"
    "    std::vector< pj::CodecInfo * >::__getitem__(PySliceObject *)\n"
    "    std::vector< pj::CodecInfo * >::__getitem__(std::vector< pj::CodecInfo * >::difference_type)\n");
  return 0;
}


SWIGINTERN PyObject *_wrap_CodecInfoVector___setitem____SWIG_2(PyObject *SWIGUNUSEDPARM(self), Py_ssize_t nobjs, PyObject **swig_obj) {
  PyObject *resultobj = 0;
  std::vector< pj::CodecInfo * > *arg1 = (std::vector< pj::CodecInfo * > *) 0 ;
  std::vector< pj::CodecInfo * >::difference_type arg2 ;
  std::vector< pj::CodecInfo * >::value_type arg3 = (std::vector< pj::CodecInfo * >::value_type) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  ptrdiff_t val2 ;
  int ecode2 = 0 ;
  void *argp3 = 0 ;
  int res3 = 0 ;
  
  if ((nobjs < 3) || (nobjs > 3)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__vectorT_pj__CodecInfo_p_std__allocatorT_pj__CodecInfo_p_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "CodecInfoVector___setitem__" "', argument " "1"" of type '" "std::vector< pj::CodecInfo * > *""'"); 
  }
  arg1 = reinterpret_cast< std::vector< pj::CodecInfo * > * >(argp1);
  ecode2 = SWIG_AsVal_ptrdiff_t(swig_obj[1], &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "CodecInfoVector___setitem__" "', argument " "2"" of type '" "std::vector< pj::CodecInfo * >::difference_type""'");
  } 
  arg2 = static_cast< std::vector< pj::CodecInfo * >::difference_type >(val2);
  res3 = SWIG_ConvertPtr(swig_obj[2], &argp3,SWIGTYPE_p_pj__CodecInfo, 0 |  0 );
  if (!SWIG_IsOK(res3)) {
    SWIG_exception_fail(SWIG_ArgError(res3), "in method '" "CodecInfoVector___setitem__" "', argument " "3"" of type '" "std::vector< pj::CodecInfo * >::value_type""'"); 
  }
  arg3 = reinterpret_cast< std::vector< pj::CodecInfo * >::value_type >(argp3);
  try {
    std_vector_Sl_pj_CodecInfo_Sm__Sg____setitem____SWIG_2(arg1,arg2,arg3);
  } catch(std::out_of_range &_e) {
    SWIG_exception_fail(SWIG_IndexError, (&_e)->what());
  }
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_CodecInfoVector___setitem__(PyObject *self, PyObject *args) {
  Py_ssize_t argc;
  PyObject *argv[4] = {
    0
  };
  
  if (!(argc = SWIG_Python_UnpackTuple(args, "CodecInfoVector___setitem__", 0, 3, argv))) SWIG_fail;
  --argc;
  if (argc == 2) {
    int _v;
    int res = swig::asptr(argv[0], (std::vector< pj::CodecInfo*,std::allocator< pj::CodecInfo * > >**)(0));
    _v = SWIG_CheckState(res);
    if (_v) {
      {
        _v = PySlice_Check(argv[1]);
      }
      if (_v) {
        return _wrap_CodecInfoVector___setitem____SWIG_1(self, argc, argv);
      }
    }
  }
  if (argc == 3) {
    int _v;
    int res = swig::asptr(argv[0], (std::vector< pj::CodecInfo*,std::allocator< pj::CodecInfo * > >**)(0));
    _v = SWIG_CheckState(res);
    if (_v) {
      {
        _v = PySlice_Check(argv[1]);
      }
      if (_v) {
        int res = swig::asptr(argv[2], (std::vector< pj::CodecInfo*,std::allocator< pj::CodecInfo * > >**)(0));
        _v = SWIG_CheckState(res);
        if (_v) {
          return _wrap_CodecInfoVector___setitem____SWIG_0(self, argc, argv);
        }
      }
    }
  }
  if (argc == 3) {
    int _v;
    int res = swig::asptr(argv[0], (std::vector< pj::CodecInfo*,std::allocator< pj::CodecInfo * > >**)(0));
    _v = SWIG_CheckState(res);
    if (_v) {
      {
        int res = SWIG_AsVal_ptrdiff_t(argv[1], NULL);
        _v = SWIG_CheckState(res);
      }
      if (_v) {
        void *vptr = 0;
        int res = SWIG_ConvertPtr(argv[2], &vptr, SWIGTYPE_p_pj__CodecInfo, 0);
        _v = SWIG_CheckState(res);
        if (_v) {
          return _wrap_CodecInfoVector___setitem____SWIG_2(self, argc, argv);
        }
      }
    }
  }
  
fail:
  SWIG_Python_RaiseOrModifyTypeError("Wrong number or type of arguments for overloaded function 'CodecInfoVector___setitem__'.\n"
    "  Possible C/C++ prototypes are:\n"
    "    std::vector< pj::CodecInfo * >::__setitem__(PySliceObject *,std::vector< pj::CodecInfo *,std::allocator< pj::CodecInfo * > > const &)\n"
    "    std::vector< pj::CodecInfo * >::__setitem__(PySliceObject *)\n"
    "    std::vector< pj::CodecInfo * >::__setitem__(std::vector< pj::CodecInfo * >::difference_type,std::vector< pj::CodecInfo * >::value_type)\n");
  return 0;
}


SWIGINTERN PyObject *_wrap_CodecInfoVector_pop(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  std::vector< pj::CodecInfo * > *arg1 = (std::vector< pj::CodecInfo * > *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  std::vector< pj::CodecInfo * >::value_type result;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__vectorT_pj__CodecInfo_p_std__allocatorT_pj__CodecInfo_p_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "CodecInfoVector_pop" "', argument " "1"" of type '" "std::vector< pj::CodecInfo * > *""'"); 
  }
  arg1 = reinterpret_cast< std::vector< pj::CodecInfo * > * >(argp1);
  try {
    result = (std::vector< pj::CodecInfo * >::value_type)std_vector_Sl_pj_CodecInfo_Sm__Sg__pop(arg1);
  } catch(std::out_of_range &_e) {
    SWIG_exception_fail(SWIG_IndexError, (&_e)->what());
  }
  resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(result), SWIGTYPE_p_pj__CodecInfo, 0 |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_CodecInfoVector_append(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  std::vector< pj::CodecInfo * > *arg1 = (std::vector< pj::CodecInfo * > *) 0 ;
  std::vector< pj::CodecInfo * >::value_type arg2 = (std::vector< pj::CodecInfo * >::value_type) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  void *argp2 = 0 ;
  int res2 = 0 ;
  PyObject *swig_obj[2] ;
  
  if (!SWIG_Python_UnpackTuple(args, "CodecInfoVector_append", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__vectorT_pj__CodecInfo_p_std__allocatorT_pj__CodecInfo_p_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "CodecInfoVector_append" "', argument " "1"" of type '" "std::vector< pj::CodecInfo * > *""'"); 
  }
  arg1 = reinterpret_cast< std::vector< pj::CodecInfo * > * >(argp1);
  res2 = SWIG_ConvertPtr(swig_obj[1], &argp2,SWIGTYPE_p_pj__CodecInfo, 0 |  0 );
  if (!SWIG_IsOK(res2)) {
    SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "CodecInfoVector_append" "', argument " "2"" of type '" "std::vector< pj::CodecInfo * >::value_type""'"); 
  }
  arg2 = reinterpret_cast< std::vector< pj::CodecInfo * >::value_type >(argp2);
  std_vector_Sl_pj_CodecInfo_Sm__Sg__append(arg1,arg2);
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_new_CodecInfoVector__SWIG_0(PyObject *SWIGUNUSEDPARM(self), Py_ssize_t nobjs, PyObject **SWIGUNUSEDPARM(swig_obj)) {
  PyObject *resultobj = 0;
  std::vector< pj::CodecInfo * > *result = 0 ;
  
  if ((nobjs < 0) || (nobjs > 0)) SWIG_fail;
  result = (std::vector< pj::CodecInfo * > *)new std::vector< pj::CodecInfo * >();
  resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(result), SWIGTYPE_p_std__vectorT_pj__CodecInfo_p_std__allocatorT_pj__CodecInfo_p_t_t, SWIG_POINTER_NEW |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_new_CodecInfoVector__SWIG_1(PyObject *SWIGUNUSEDPARM(self), Py_ssize_t nobjs, PyObject **swig_obj) {
  PyObject *resultobj = 0;
  std::vector< pj::CodecInfo * > *arg1 = 0 ;
  int res1 = SWIG_OLDOBJ ;
  std::vector< pj::CodecInfo * > *result = 0 ;
  
  if ((nobjs < 1) || (nobjs > 1)) SWIG_fail;
  {
    std::vector< pj::CodecInfo*,std::allocator< pj::CodecInfo * > > *ptr = (std::vector< pj::CodecInfo*,std::allocator< pj::CodecInfo * > > *)0;
    res1 = swig::asptr(swig_obj[0], &ptr);
    if (!SWIG_IsOK(res1)) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "new_CodecInfoVector" "', argument " "1"" of type '" "std::vector< pj::CodecInfo * > const &""'"); 
    }
    if (!ptr) {
      SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "new_CodecInfoVector" "', argument " "1"" of type '" "std::vector< pj::CodecInfo * > const &""'"); 
    }
    arg1 = ptr;
  }
  result = (std::vector< pj::CodecInfo * > *)new std::vector< pj::CodecInfo * >((std::vector< pj::CodecInfo * > const &)*arg1);
  resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(result), SWIGTYPE_p_std__vectorT_pj__CodecInfo_p_std__allocatorT_pj__CodecInfo_p_t_t, SWIG_POINTER_NEW |  0 );
  if (SWIG_IsNewObj(res1)) delete arg1;
  return resultobj;
fail:
  if (SWIG_IsNewObj(res1)) delete arg1;
  return NULL;
}


SWIGINTERN PyObject *_wrap_CodecInfoVector_empty(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  std::vector< pj::CodecInfo * > *arg1 = (std::vector< pj::CodecInfo * > *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  bool result;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__vectorT_pj__CodecInfo_p_std__allocatorT_pj__CodecInfo_p_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "CodecInfoVector_empty" "', argument " "1"" of type '" "std::vector< pj::CodecInfo * > const *""'"); 
  }
  arg1 = reinterpret_cast< std::vector< pj::CodecInfo * > * >(argp1);
  result = (bool)((std::vector< pj::CodecInfo * > const *)arg1)->empty();
  resultobj = SWIG_From_bool(static_cast< bool >(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_CodecInfoVector_size(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  std::vector< pj::CodecInfo * > *arg1 = (std::vector< pj::CodecInfo * > *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  std::vector< pj::CodecInfo * >::size_type result;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__vectorT_pj__CodecInfo_p_std__allocatorT_pj__CodecInfo_p_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "CodecInfoVector_size" "', argument " "1"" of type '" "std::vector< pj::CodecInfo * > const *""'"); 
  }
  arg1 = reinterpret_cast< std::vector< pj::CodecInfo * > * >(argp1);
  result = ((std::vector< pj::CodecInfo * > const *)arg1)->size();
  resultobj = SWIG_From_size_t(static_cast< size_t >(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_CodecInfoVector_swap(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  std::vector< pj::CodecInfo * > *arg1 = (std::vector< pj::CodecInfo * > *) 0 ;
  std::vector< pj::CodecInfo * > *arg2 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  void *argp2 = 0 ;
  int res2 = 0 ;
  PyObject *swig_obj[2] ;
  
  if (!SWIG_Python_UnpackTuple(args, "CodecInfoVector_swap", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__vectorT_pj__CodecInfo_p_std__allocatorT_pj__CodecInfo_p_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "CodecInfoVector_swap" "', argument " "1"" of type '" "std::vector< pj::CodecInfo * > *""'"); 
  }
  arg1 = reinterpret_cast< std::vector< pj::CodecInfo * > * >(argp1);
  res2 = SWIG_ConvertPtr(swig_obj[1], &argp2, SWIGTYPE_p_std__vectorT_pj__CodecInfo_p_std__allocatorT_pj__CodecInfo_p_t_t,  0 );
  if (!SWIG_IsOK(res2)) {
    SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "CodecInfoVector_swap" "', argument " "2"" of type '" "std::vector< pj::CodecInfo * > &""'"); 
  }
  if (!argp2) {
    SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "CodecInfoVector_swap" "', argument " "2"" of type '" "std::vector< pj::CodecInfo * > &""'"); 
  }
  arg2 = reinterpret_cast< std::vector< pj::CodecInfo * > * >(argp2);
  (arg1)->swap(*arg2);
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_CodecInfoVector_begin(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  std::vector< pj::CodecInfo * > *arg1 = (std::vector< pj::CodecInfo * > *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  std::vector< pj::CodecInfo * >::iterator result;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__vectorT_pj__CodecInfo_p_std__allocatorT_pj__CodecInfo_p_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "CodecInfoVector_begin" "', argument " "1"" of type '" "std::vector< pj::CodecInfo * > *""'"); 
  }
  arg1 = reinterpret_cast< std::vector< pj::CodecInfo * > * >(argp1);
  result = (arg1)->begin();
  resultobj = SWIG_NewPointerObj(swig::make_output_iterator(static_cast< const std::vector< pj::CodecInfo * >::iterator & >(result)),
    swig::SwigPyIterator::descriptor(),SWIG_POINTER_OWN);
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_CodecInfoVector_end(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  std::vector< pj::CodecInfo * > *arg1 = (std::vector< pj::CodecInfo * > *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  std::vector< pj::CodecInfo * >::iterator result;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__vectorT_pj__CodecInfo_p_std__allocatorT_pj__CodecInfo_p_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "CodecInfoVector_end" "', argument " "1"" of type '" "std::vector< pj::CodecInfo * > *""'"); 
  }
  arg1 = reinterpret_cast< std::vector< pj::CodecInfo * > * >(argp1);
  result = (arg1)->end();
  resultobj = SWIG_NewPointerObj(swig::make_output_iterator(static_cast< const std::vector< pj::CodecInfo * >::iterator & >(result)),
    swig::SwigPyIterator::descriptor(),SWIG_POINTER_OWN);
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_CodecInfoVector_rbegin(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  std::vector< pj::CodecInfo * > *arg1 = (std::vector< pj::CodecInfo * > *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  std::vector< pj::CodecInfo * >::reverse_iterator result;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__vectorT_pj__CodecInfo_p_std__allocatorT_pj__CodecInfo_p_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "CodecInfoVector_rbegin" "', argument " "1"" of type '" "std::vector< pj::CodecInfo * > *""'"); 
  }
  arg1 = reinterpret_cast< std::vector< pj::CodecInfo * > * >(argp1);
  result = (arg1)->rbegin();
  resultobj = SWIG_NewPointerObj(swig::make_output_iterator(static_cast< const std::vector< pj::CodecInfo * >::reverse_iterator & >(result)),
    swig::SwigPyIterator::descriptor(),SWIG_POINTER_OWN);
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_CodecInfoVector_rend(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  std::vector< pj::CodecInfo * > *arg1 = (std::vector< pj::CodecInfo * > *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  std::vector< pj::CodecInfo * >::reverse_iterator result;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__vectorT_pj__CodecInfo_p_std__allocatorT_pj__CodecInfo_p_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "CodecInfoVector_rend" "', argument " "1"" of type '" "std::vector< pj::CodecInfo * > *""'"); 
  }
  arg1 = reinterpret_cast< std::vector< pj::CodecInfo * > * >(argp1);
  result = (arg1)->rend();
  resultobj = SWIG_NewPointerObj(swig::make_output_iterator(static_cast< const std::vector< pj::CodecInfo * >::reverse_iterator & >(result)),
    swig::SwigPyIterator::descriptor(),SWIG_POINTER_OWN);
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_CodecInfoVector_clear(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  std::vector< pj::CodecInfo * > *arg1 = (std::vector< pj::CodecInfo * > *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__vectorT_pj__CodecInfo_p_std__allocatorT_pj__CodecInfo_p_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "CodecInfoVector_clear" "', argument " "1"" of type '" "std::vector< pj::CodecInfo * > *""'"); 
  }
  arg1 = reinterpret_cast< std::vector< pj::CodecInfo * > * >(argp1);
  (arg1)->clear();
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_CodecInfoVector_get_allocator(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  std::vector< pj::CodecInfo * > *arg1 = (std::vector< pj::CodecInfo * > *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  SwigValueWrapper< std::allocator< pj::CodecInfo * > > result;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__vectorT_pj__CodecInfo_p_std__allocatorT_pj__CodecInfo_p_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "CodecInfoVector_get_allocator" "', argument " "1"" of type '" "std::vector< pj::CodecInfo * > const *""'"); 
  }
  arg1 = reinterpret_cast< std::vector< pj::CodecInfo * > * >(argp1);
  result = ((std::vector< pj::CodecInfo * > const *)arg1)->get_allocator();
  resultobj = SWIG_NewPointerObj((new std::vector< pj::CodecInfo * >::allocator_type(static_cast< const std::vector< pj::CodecInfo * >::allocator_type& >(result))), SWIGTYPE_p_std__allocatorT_pj__CodecInfo_p_t, SWIG_POINTER_OWN |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_new_CodecInfoVector__SWIG_2(PyObject *SWIGUNUSEDPARM(self), Py_ssize_t nobjs, PyObject **swig_obj) {
  PyObject *resultobj = 0;
  std::vector< pj::CodecInfo * >::size_type arg1 ;
  size_t val1 ;
  int ecode1 = 0 ;
  std::vector< pj::CodecInfo * > *result = 0 ;
  
  if ((nobjs < 1) || (nobjs > 1)) SWIG_fail;
  ecode1 = SWIG_AsVal_size_t(swig_obj[0], &val1);
  if (!SWIG_IsOK(ecode1)) {
    SWIG_exception_fail(SWIG_ArgError(ecode1), "in method '" "new_CodecInfoVector" "', argument " "1"" of type '" "std::vector< pj::CodecInfo * >::size_type""'");
  } 
  arg1 = static_cast< std::vector< pj::CodecInfo * >::size_type >(val1);
  result = (std::vector< pj::CodecInfo * > *)new std::vector< pj::CodecInfo * >(arg1);
  resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(result), SWIGTYPE_p_std__vectorT_pj__CodecInfo_p_std__allocatorT_pj__CodecInfo_p_t_t, SWIG_POINTER_NEW |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_CodecInfoVector_pop_back(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  std::vector< pj::CodecInfo * > *arg1 = (std::vector< pj::CodecInfo * > *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__vectorT_pj__CodecInfo_p_std__allocatorT_pj__CodecInfo_p_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "CodecInfoVector_pop_back" "', argument " "1"" of type '" "std::vector< pj::CodecInfo * > *""'"); 
  }
  arg1 = reinterpret_cast< std::vector< pj::CodecInfo * > * >(argp1);
  (arg1)->pop_back();
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_CodecInfoVector_resize__SWIG_0(PyObject *SWIGUNUSEDPARM(self), Py_ssize_t nobjs, PyObject **swig_obj) {
  PyObject *resultobj = 0;
  std::vector< pj::CodecInfo * > *arg1 = (std::vector< pj::CodecInfo * > *) 0 ;
  std::vector< pj::CodecInfo * >::size_type arg2 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  size_t val2 ;
  int ecode2 = 0 ;
  
  if ((nobjs < 2) || (nobjs > 2)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__vectorT_pj__CodecInfo_p_std__allocatorT_pj__CodecInfo_p_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "CodecInfoVector_resize" "', argument " "1"" of type '" "std::vector< pj::CodecInfo * > *""'"); 
  }
  arg1 = reinterpret_cast< std::vector< pj::CodecInfo * > * >(argp1);
  ecode2 = SWIG_AsVal_size_t(swig_obj[1], &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "CodecInfoVector_resize" "', argument " "2"" of type '" "std::vector< pj::CodecInfo * >::size_type""'");
  } 
  arg2 = static_cast< std::vector< pj::CodecInfo * >::size_type >(val2);
  (arg1)->resize(arg2);
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_CodecInfoVector_erase__SWIG_0(PyObject *SWIGUNUSEDPARM(self), Py_ssize_t nobjs, PyObject **swig_obj) {
  PyObject *resultobj = 0;
  std::vector< pj::CodecInfo * > *arg1 = (std::vector< pj::CodecInfo * > *) 0 ;
  std::vector< pj::CodecInfo * >::iterator arg2 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  swig::SwigPyIterator *iter2 = 0 ;
  int res2 ;
  std::vector< pj::CodecInfo * >::iterator result;
  
  if ((nobjs < 2) || (nobjs > 2)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__vectorT_pj__CodecInfo_p_std__allocatorT_pj__CodecInfo_p_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "CodecInfoVector_erase" "', argument " "1"" of type '" "std::vector< pj::CodecInfo * > *""'"); 
  }
  arg1 = reinterpret_cast< std::vector< pj::CodecInfo * > * >(argp1);
  res2 = SWIG_ConvertPtr(swig_obj[1], SWIG_as_voidptrptr(&iter2), swig::SwigPyIterator::descriptor(), 0);
  if (!SWIG_IsOK(res2) || !iter2) {
    SWIG_exception_fail(SWIG_ArgError(SWIG_TypeError), "in method '" "CodecInfoVector_erase" "', argument " "2"" of type '" "std::vector< pj::CodecInfo * >::iterator""'");
  } else {
    swig::SwigPyIterator_T<std::vector< pj::CodecInfo * >::iterator > *iter_t = dynamic_cast<swig::SwigPyIterator_T<std::vector< pj::CodecInfo * >::iterator > *>(iter2);
    if (iter_t) {
      arg2 = iter_t->get_current();
    } else {
      SWIG_exception_fail(SWIG_ArgError(SWIG_TypeError), "in method '" "CodecInfoVector_erase" "', argument " "2"" of type '" "std::vector< pj::CodecInfo * >::iterator""'");
    }
  }
  result = std_vector_Sl_pj_CodecInfo_Sm__Sg__erase__SWIG_0(arg1,arg2);
  resultobj = SWIG_NewPointerObj(swig::make_output_iterator(static_cast< const std::vector< pj::CodecInfo * >::iterator & >(result)),
    swig::SwigPyIterator::descriptor(),SWIG_POINTER_OWN);
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_CodecInfoVector_erase__SWIG_1(PyObject *SWIGUNUSEDPARM(self), Py_ssize_t nobjs, PyObject **swig_obj) {
  PyObject *resultobj = 0;
  std::vector< pj::CodecInfo * > *arg1 = (std::vector< pj::CodecInfo * > *) 0 ;
  std::vector< pj::CodecInfo * >::iterator arg2 ;
  std::vector< pj::CodecInfo * >::iterator arg3 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  swig::SwigPyIterator *iter2 = 0 ;
  int res2 ;
  swig::SwigPyIterator *iter3 = 0 ;
  int res3 ;
  std::vector< pj::CodecInfo * >::iterator result;
  
  if ((nobjs < 3) || (nobjs > 3)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__vectorT_pj__CodecInfo_p_std__allocatorT_pj__CodecInfo_p_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "CodecInfoVector_erase" "', argument " "1"" of type '" "std::vector< pj::CodecInfo * > *""'"); 
  }
  arg1 = reinterpret_cast< std::vector< pj::CodecInfo * > * >(argp1);
  res2 = SWIG_ConvertPtr(swig_obj[1], SWIG_as_voidptrptr(&iter2), swig::SwigPyIterator::descriptor(), 0);
  if (!SWIG_IsOK(res2) || !iter2) {
    SWIG_exception_fail(SWIG_ArgError(SWIG_TypeError), "in method '" "CodecInfoVector_erase" "', argument " "2"" of type '" "std::vector< pj::CodecInfo * >::iterator""'");
  } else {
    swig::SwigPyIterator_T<std::vector< pj::CodecInfo * >::iterator > *iter_t = dynamic_cast<swig::SwigPyIterator_T<std::vector< pj::CodecInfo * >::iterator > *>(iter2);
    if (iter_t) {
      arg2 = iter_t->get_current();
    } else {
      SWIG_exception_fail(SWIG_ArgError(SWIG_TypeError), "in method '" "CodecInfoVector_erase" "', argument " "2"" of type '" "std::vector< pj::CodecInfo * >::iterator""'");
    }
  }
  res3 = SWIG_ConvertPtr(swig_obj[2], SWIG_as_voidptrptr(&iter3), swig::SwigPyIterator::descriptor(), 0);
  if (!SWIG_IsOK(res3) || !iter3) {
    SWIG_exception_fail(SWIG_ArgError(SWIG_TypeError), "in method '" "CodecInfoVector_erase" "', argument " "3"" of type '" "std::vector< pj::CodecInfo * >::iterator""'");
  } else {
    swig::SwigPyIterator_T<std::vector< pj::CodecInfo * >::iterator > *iter_t = dynamic_cast<swig::SwigPyIterator_T<std::vector< pj::CodecInfo * >::iterator > *>(iter3);
    if (iter_t) {
      arg3 = iter_t->get_current();
    } else {
      SWIG_exception_fail(SWIG_ArgError(SWIG_TypeError), "in method '" "CodecInfoVector_erase" "', argument " "3"" of type '" "std::vector< pj::CodecInfo * >::iterator""'");
    }
  }
  result = std_vector_Sl_pj_CodecInfo_Sm__Sg__erase__SWIG_1(arg1,arg2,arg3);
  resultobj = SWIG_NewPointerObj(swig::make_output_iterator(static_cast< const std::vector< pj::CodecInfo * >::iterator & >(result)),
    swig::SwigPyIterator::descriptor(),SWIG_POINTER_OWN);
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_CodecInfoVector_erase(PyObject *self, PyObject *args) {
  Py_ssize_t argc;
  PyObject *argv[4] = {
    0
  };
  
  if (!(argc = SWIG_Python_UnpackTuple(args, "CodecInfoVector_erase", 0, 3, argv))) SWIG_fail;
  --argc;
  if (argc == 2) {
    int _v;
    int res = swig::asptr(argv[0], (std::vector< pj::CodecInfo*,std::allocator< pj::CodecInfo * > >**)(0));
    _v = SWIG_CheckState(res);
    if (_v) {
      swig::SwigPyIterator *iter = 0;
      int res = SWIG_ConvertPtr(argv[1], SWIG_as_voidptrptr(&iter), swig::SwigPyIterator::descriptor(), 0);
      _v = (SWIG_IsOK(res) && iter && (dynamic_cast<swig::SwigPyIterator_T<std::vector< pj::CodecInfo * >::iterator > *>(iter) != 0));
      if (_v) {
        return _wrap_CodecInfoVector_erase__SWIG_0(self, argc, argv);
      }
    }
  }
  if (argc == 3) {
    int _v;
    int res = swig::asptr(argv[0], (std::vector< pj::CodecInfo*,std::allocator< pj::CodecInfo * > >**)(0));
    _v = SWIG_CheckState(res);
    if (_v) {
      swig::SwigPyIterator *iter = 0;
      int res = SWIG_ConvertPtr(argv[1], SWIG_as_voidptrptr(&iter), swig::SwigPyIterator::descriptor(), 0);
      _v = (SWIG_IsOK(res) && iter && (dynamic_cast<swig::SwigPyIterator_T<std::vector< pj::CodecInfo * >::iterator > *>(iter) != 0));
      if (_v) {
        swig::SwigPyIterator *iter = 0;
        int res = SWIG_ConvertPtr(argv[2], SWIG_as_voidptrptr(&iter), swig::SwigPyIterator::descriptor(), 0);
        _v = (SWIG_IsOK(res) && iter && (dynamic_cast<swig::SwigPyIterator_T<std::vector< pj::CodecInfo * >::iterator > *>(iter) != 0));
        if (_v) {
          return _wrap_CodecInfoVector_erase__SWIG_1(self, argc, argv);
        }
      }
    }
  }
  
fail:
  SWIG_Python_RaiseOrModifyTypeError("Wrong number or type of arguments for overloaded function 'CodecInfoVector_erase'.\n"
    "  Possible C/C++ prototypes are:\n"
    "    std::vector< pj::CodecInfo * >::erase(std::vector< pj::CodecInfo * >::iterator)\n"
    "    std::vector< pj::CodecInfo * >::erase(std::vector< pj::CodecInfo * >::iterator,std::vector< pj::CodecInfo * >::iterator)\n");
  return 0;
}


SWIGINTERN PyObject *_wrap_new_CodecInfoVector__SWIG_3(PyObject *SWIGUNUSEDPARM(self), Py_ssize_t nobjs, PyObject **swig_obj) {
  PyObject *resultobj = 0;
  std::vector< pj::CodecInfo * >::size_type arg1 ;
  std::vector< pj::CodecInfo * >::value_type arg2 = (std::vector< pj::CodecInfo * >::value_type) 0 ;
  size_t val1 ;
  int ecode1 = 0 ;
  void *argp2 = 0 ;
  int res2 = 0 ;
  std::vector< pj::CodecInfo * > *result = 0 ;
  
  if ((nobjs < 2) || (nobjs > 2)) SWIG_fail;
  ecode1 = SWIG_AsVal_size_t(swig_obj[0], &val1);
  if (!SWIG_IsOK(ecode1)) {
    SWIG_exception_fail(SWIG_ArgError(ecode1), "in method '" "new_CodecInfoVector" "', argument " "1"" of type '" "std::vector< pj::CodecInfo * >::size_type""'");
  } 
  arg1 = static_cast< std::vector< pj::CodecInfo * >::size_type >(val1);
  res2 = SWIG_ConvertPtr(swig_obj[1], &argp2,SWIGTYPE_p_pj__CodecInfo, 0 |  0 );
  if (!SWIG_IsOK(res2)) {
    SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "new_CodecInfoVector" "', argument " "2"" of type '" "std::vector< pj::CodecInfo * >::value_type""'"); 
  }
  arg2 = reinterpret_cast< std::vector< pj::CodecInfo * >::value_type >(argp2);
  result = (std::vector< pj::CodecInfo * > *)new std::vector< pj::CodecInfo * >(arg1,arg2);
  resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(result), SWIGTYPE_p_std__vectorT_pj__CodecInfo_p_std__allocatorT_pj__CodecInfo_p_t_t, SWIG_POINTER_NEW |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_new_CodecInfoVector(PyObject *self, PyObject *args) {
  Py_ssize_t argc;
  PyObject *argv[3] = {
    0
  };
  
  if (!(argc = SWIG_Python_UnpackTuple(args, "new_CodecInfoVector", 0, 2, argv))) SWIG_fail;
  --argc;
  if (argc == 0) {
    return _wrap_new_CodecInfoVector__SWIG_0(self, argc, argv);
  }
  if (argc == 1) {
    int _v;
    {
      int res = SWIG_AsVal_size_t(argv[0], NULL);
      _v = SWIG_CheckState(res);
    }
    if (_v) {
      return _wrap_new_CodecInfoVector__SWIG_2(self, argc, argv);
    }
  }
  if (argc == 1) {
    int _v;
    int res = swig::asptr(argv[0], (std::vector< pj::CodecInfo*,std::allocator< pj::CodecInfo * > >**)(0));
    _v = SWIG_CheckState(res);
    if (_v) {
      return _wrap_new_CodecInfoVector__SWIG_1(self, argc, argv);
    }
  }
  if (argc == 2) {
    int _v;
    {
      int res = SWIG_AsVal_size_t(argv[0], NULL);
      _v = SWIG_CheckState(res);
    }
    if (_v) {
      void *vptr = 0;
      int res = SWIG_ConvertPtr(argv[1], &vptr, SWIGTYPE_p_pj__CodecInfo, 0);
      _v = SWIG_CheckState(res);
      if (_v) {
        return _wrap_new_CodecInfoVector__SWIG_3(self, argc, argv);
      }
    }
  }
  
fail:
  SWIG_Python_RaiseOrModifyTypeError("Wrong number or type of arguments for overloaded function 'new_CodecInfoVector'.\n"
    "  Possible C/C++ prototypes are:\n"
    "    std::vector< pj::CodecInfo * >::vector()\n"
    "    std::vector< pj::CodecInfo * >::vector(std::vector< pj::CodecInfo * > const &)\n"
    "    std::vector< pj::CodecInfo * >::vector(std::vector< pj::CodecInfo * >::size_type)\n"
    "    std::vector< pj::CodecInfo * >::vector(std::vector< pj::CodecInfo * >::size_type,std::vector< pj::CodecInfo * >::value_type)\n");
  return 0;
}


SWIGINTERN PyObject *_wrap_CodecInfoVector_push_back(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  std::vector< pj::CodecInfo * > *arg1 = (std::vector< pj::CodecInfo * > *) 0 ;
  std::vector< pj::CodecInfo * >::value_type arg2 = (std::vector< pj::CodecInfo * >::value_type) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  void *argp2 = 0 ;
  int res2 = 0 ;
  PyObject *swig_obj[2] ;
  
  if (!SWIG_Python_UnpackTuple(args, "CodecInfoVector_push_back", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__vectorT_pj__CodecInfo_p_std__allocatorT_pj__CodecInfo_p_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "CodecInfoVector_push_back" "', argument " "1"" of type '" "std::vector< pj::CodecInfo * > *""'"); 
  }
  arg1 = reinterpret_cast< std::vector< pj::CodecInfo * > * >(argp1);
  res2 = SWIG_ConvertPtr(swig_obj[1], &argp2,SWIGTYPE_p_pj__CodecInfo, 0 |  0 );
  if (!SWIG_IsOK(res2)) {
    SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "CodecInfoVector_push_back" "', argument " "2"" of type '" "std::vector< pj::CodecInfo * >::value_type""'"); 
  }
  arg2 = reinterpret_cast< std::vector< pj::CodecInfo * >::value_type >(argp2);
  (arg1)->push_back(arg2);
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_CodecInfoVector_front(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  std::vector< pj::CodecInfo * > *arg1 = (std::vector< pj::CodecInfo * > *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  std::vector< pj::CodecInfo * >::value_type result;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__vectorT_pj__CodecInfo_p_std__allocatorT_pj__CodecInfo_p_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "CodecInfoVector_front" "', argument " "1"" of type '" "std::vector< pj::CodecInfo * > const *""'"); 
  }
  arg1 = reinterpret_cast< std::vector< pj::CodecInfo * > * >(argp1);
  result = (std::vector< pj::CodecInfo * >::value_type)((std::vector< pj::CodecInfo * > const *)arg1)->front();
  resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(result), SWIGTYPE_p_pj__CodecInfo, 0 |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_CodecInfoVector_back(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  std::vector< pj::CodecInfo * > *arg1 = (std::vector< pj::CodecInfo * > *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  std::vector< pj::CodecInfo * >::value_type result;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__vectorT_pj__CodecInfo_p_std__allocatorT_pj__CodecInfo_p_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "CodecInfoVector_back" "', argument " "1"" of type '" "std::vector< pj::CodecInfo * > const *""'"); 
  }
  arg1 = reinterpret_cast< std::vector< pj::CodecInfo * > * >(argp1);
  result = (std::vector< pj::CodecInfo * >::value_type)((std::vector< pj::CodecInfo * > const *)arg1)->back();
  resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(result), SWIGTYPE_p_pj__CodecInfo, 0 |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_CodecInfoVector_assign(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  std::vector< pj::CodecInfo * > *arg1 = (std::vector< pj::CodecInfo * > *) 0 ;
  std::vector< pj::CodecInfo * >::size_type arg2 ;
  std::vector< pj::CodecInfo * >::value_type arg3 = (std::vector< pj::CodecInfo * >::value_type) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  size_t val2 ;
  int ecode2 = 0 ;
  void *argp3 = 0 ;
  int res3 = 0 ;
  PyObject *swig_obj[3] ;
  
  if (!SWIG_Python_UnpackTuple(args, "CodecInfoVector_assign", 3, 3, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__vectorT_pj__CodecInfo_p_std__allocatorT_pj__CodecInfo_p_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "CodecInfoVector_assign" "', argument " "1"" of type '" "std::vector< pj::CodecInfo * > *""'"); 
  }
  arg1 = reinterpret_cast< std::vector< pj::CodecInfo * > * >(argp1);
  ecode2 = SWIG_AsVal_size_t(swig_obj[1], &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "CodecInfoVector_assign" "', argument " "2"" of type '" "std::vector< pj::CodecInfo * >::size_type""'");
  } 
  arg2 = static_cast< std::vector< pj::CodecInfo * >::size_type >(val2);
  res3 = SWIG_ConvertPtr(swig_obj[2], &argp3,SWIGTYPE_p_pj__CodecInfo, 0 |  0 );
  if (!SWIG_IsOK(res3)) {
    SWIG_exception_fail(SWIG_ArgError(res3), "in method '" "CodecInfoVector_assign" "', argument " "3"" of type '" "std::vector< pj::CodecInfo * >::value_type""'"); 
  }
  arg3 = reinterpret_cast< std::vector< pj::CodecInfo * >::value_type >(argp3);
  (arg1)->assign(arg2,arg3);
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_CodecInfoVector_resize__SWIG_1(PyObject *SWIGUNUSEDPARM(self), Py_ssize_t nobjs, PyObject **swig_obj) {
  PyObject *resultobj = 0;
  std::vector< pj::CodecInfo * > *arg1 = (std::vector< pj::CodecInfo * > *) 0 ;
  std::vector< pj::CodecInfo * >::size_type arg2 ;
  std::vector< pj::CodecInfo * >::value_type arg3 = (std::vector< pj::CodecInfo * >::value_type) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  size_t val2 ;
  int ecode2 = 0 ;
  void *argp3 = 0 ;
  int res3 = 0 ;
  
  if ((nobjs < 3) || (nobjs > 3)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__vectorT_pj__CodecInfo_p_std__allocatorT_pj__CodecInfo_p_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "CodecInfoVector_resize" "', argument " "1"" of type '" "std::vector< pj::CodecInfo * > *""'"); 
  }
  arg1 = reinterpret_cast< std::vector< pj::CodecInfo * > * >(argp1);
  ecode2 = SWIG_AsVal_size_t(swig_obj[1], &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "CodecInfoVector_resize" "', argument " "2"" of type '" "std::vector< pj::CodecInfo * >::size_type""'");
  } 
  arg2 = static_cast< std::vector< pj::CodecInfo * >::size_type >(val2);
  res3 = SWIG_ConvertPtr(swig_obj[2], &argp3,SWIGTYPE_p_pj__CodecInfo, 0 |  0 );
  if (!SWIG_IsOK(res3)) {
    SWIG_exception_fail(SWIG_ArgError(res3), "in method '" "CodecInfoVector_resize" "', argument " "3"" of type '" "std::vector< pj::CodecInfo * >::value_type""'"); 
  }
  arg3 = reinterpret_cast< std::vector< pj::CodecInfo * >::value_type >(argp3);
  (arg1)->resize(arg2,arg3);
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_CodecInfoVector_resize(PyObject *self, PyObject *args) {
  Py_ssize_t argc;
  PyObject *argv[4] = {
    0
  };
  
  if (!(argc = SWIG_Python_UnpackTuple(args, "CodecInfoVector_resize", 0, 3, argv))) SWIG_fail;
  --argc;
  if (argc == 2) {
    int _v;
    int res = swig::asptr(argv[0], (std::vector< pj::CodecInfo*,std::allocator< pj::CodecInfo * > >**)(0));
    _v = SWIG_CheckState(res);
    if (_v) {
      {
        int res = SWIG_AsVal_size_t(argv[1], NULL);
        _v = SWIG_CheckState(res);
      }
      if (_v) {
        return _wrap_CodecInfoVector_resize__SWIG_0(self, argc, argv);
      }
    }
  }
  if (argc == 3) {
    int _v;
    int res = swig::asptr(argv[0], (std::vector< pj::CodecInfo*,std::allocator< pj::CodecInfo * > >**)(0));
    _v = SWIG_CheckState(res);
    if (_v) {
      {
        int res = SWIG_AsVal_size_t(argv[1], NULL);
        _v = SWIG_CheckState(res);
      }
      if (_v) {
        void *vptr = 0;
        int res = SWIG_ConvertPtr(argv[2], &vptr, SWIGTYPE_p_pj__CodecInfo, 0);
        _v = SWIG_CheckState(res);
        if (_v) {
          return _wrap_CodecInfoVector_resize__SWIG_1(self, argc, argv);
        }
      }
    }
  }
  
fail:
  SWIG_Python_RaiseOrModifyTypeError("Wrong number or type of arguments for overloaded function 'CodecInfoVector_resize'.\n"
    "  Possible C/C++ prototypes are:\n"
    "    std::vector< pj::CodecInfo * >::resize(std::vector< pj::CodecInfo * >::size_type)\n"
    "    std::vector< pj::CodecInfo * >::resize(std::vector< pj::CodecInfo * >::size_type,std::vector< pj::CodecInfo * >::value_type)\n");
  return 0;
}


SWIGINTERN PyObject *_wrap_CodecInfoVector_insert__SWIG_0(PyObject *SWIGUNUSEDPARM(self), Py_ssize_t nobjs, PyObject **swig_obj) {
  PyObject *resultobj = 0;
  std::vector< pj::CodecInfo * > *arg1 = (std::vector< pj::CodecInfo * > *) 0 ;
  std::vector< pj::CodecInfo * >::iterator arg2 ;
  std::vector< pj::CodecInfo * >::value_type arg3 = (std::vector< pj::CodecInfo * >::value_type) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  swig::SwigPyIterator *iter2 = 0 ;
  int res2 ;
  void *argp3 = 0 ;
  int res3 = 0 ;
  std::vector< pj::CodecInfo * >::iterator result;
  
  if ((nobjs < 3) || (nobjs > 3)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__vectorT_pj__CodecInfo_p_std__allocatorT_pj__CodecInfo_p_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "CodecInfoVector_insert" "', argument " "1"" of type '" "std::vector< pj::CodecInfo * > *""'"); 
  }
  arg1 = reinterpret_cast< std::vector< pj::CodecInfo * > * >(argp1);
  res2 = SWIG_ConvertPtr(swig_obj[1], SWIG_as_voidptrptr(&iter2), swig::SwigPyIterator::descriptor(), 0);
  if (!SWIG_IsOK(res2) || !iter2) {
    SWIG_exception_fail(SWIG_ArgError(SWIG_TypeError), "in method '" "CodecInfoVector_insert" "', argument " "2"" of type '" "std::vector< pj::CodecInfo * >::iterator""'");
  } else {
    swig::SwigPyIterator_T<std::vector< pj::CodecInfo * >::iterator > *iter_t = dynamic_cast<swig::SwigPyIterator_T<std::vector< pj::CodecInfo * >::iterator > *>(iter2);
    if (iter_t) {
      arg2 = iter_t->get_current();
    } else {
      SWIG_exception_fail(SWIG_ArgError(SWIG_TypeError), "in method '" "CodecInfoVector_insert" "', argument " "2"" of type '" "std::vector< pj::CodecInfo * >::iterator""'");
    }
  }
  res3 = SWIG_ConvertPtr(swig_obj[2], &argp3,SWIGTYPE_p_pj__CodecInfo, 0 |  0 );
  if (!SWIG_IsOK(res3)) {
    SWIG_exception_fail(SWIG_ArgError(res3), "in method '" "CodecInfoVector_insert" "', argument " "3"" of type '" "std::vector< pj::CodecInfo * >::value_type""'"); 
  }
  arg3 = reinterpret_cast< std::vector< pj::CodecInfo * >::value_type >(argp3);
  result = std_vector_Sl_pj_CodecInfo_Sm__Sg__insert__SWIG_0(arg1,arg2,arg3);
  resultobj = SWIG_NewPointerObj(swig::make_output_iterator(static_cast< const std::vector< pj::CodecInfo * >::iterator & >(result)),
    swig::SwigPyIterator::descriptor(),SWIG_POINTER_OWN);
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_CodecInfoVector_insert__SWIG_1(PyObject *SWIGUNUSEDPARM(self), Py_ssize_t nobjs, PyObject **swig_obj) {
  PyObject *resultobj = 0;
  std::vector< pj::CodecInfo * > *arg1 = (std::vector< pj::CodecInfo * > *) 0 ;
  std::vector< pj::CodecInfo * >::iterator arg2 ;
  std::vector< pj::CodecInfo * >::size_type arg3 ;
  std::vector< pj::CodecInfo * >::value_type arg4 = (std::vector< pj::CodecInfo * >::value_type) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  swig::SwigPyIterator *iter2 = 0 ;
  int res2 ;
  size_t val3 ;
  int ecode3 = 0 ;
  void *argp4 = 0 ;
  int res4 = 0 ;
  
  if ((nobjs < 4) || (nobjs > 4)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__vectorT_pj__CodecInfo_p_std__allocatorT_pj__CodecInfo_p_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "CodecInfoVector_insert" "', argument " "1"" of type '" "std::vector< pj::CodecInfo * > *""'"); 
  }
  arg1 = reinterpret_cast< std::vector< pj::CodecInfo * > * >(argp1);
  res2 = SWIG_ConvertPtr(swig_obj[1], SWIG_as_voidptrptr(&iter2), swig::SwigPyIterator::descriptor(), 0);
  if (!SWIG_IsOK(res2) || !iter2) {
    SWIG_exception_fail(SWIG_ArgError(SWIG_TypeError), "in method '" "CodecInfoVector_insert" "', argument " "2"" of type '" "std::vector< pj::CodecInfo * >::iterator""'");
  } else {
    swig::SwigPyIterator_T<std::vector< pj::CodecInfo * >::iterator > *iter_t = dynamic_cast<swig::SwigPyIterator_T<std::vector< pj::CodecInfo * >::iterator > *>(iter2);
    if (iter_t) {
      arg2 = iter_t->get_current();
    } else {
      SWIG_exception_fail(SWIG_ArgError(SWIG_TypeError), "in method '" "CodecInfoVector_insert" "', argument " "2"" of type '" "std::vector< pj::CodecInfo * >::iterator""'");
    }
  }
  ecode3 = SWIG_AsVal_size_t(swig_obj[2], &val3);
  if (!SWIG_IsOK(ecode3)) {
    SWIG_exception_fail(SWIG_ArgError(ecode3), "in method '" "CodecInfoVector_insert" "', argument " "3"" of type '" "std::vector< pj::CodecInfo * >::size_type""'");
  } 
  arg3 = static_cast< std::vector< pj::CodecInfo * >::size_type >(val3);
  res4 = SWIG_ConvertPtr(swig_obj[3], &argp4,SWIGTYPE_p_pj__CodecInfo, 0 |  0 );
  if (!SWIG_IsOK(res4)) {
    SWIG_exception_fail(SWIG_ArgError(res4), "in method '" "CodecInfoVector_insert" "', argument " "4"" of type '" "std::vector< pj::CodecInfo * >::value_type""'"); 
  }
  arg4 = reinterpret_cast< std::vector< pj::CodecInfo * >::value_type >(argp4);
  std_vector_Sl_pj_CodecInfo_Sm__Sg__insert__SWIG_1(arg1,arg2,arg3,arg4);
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_CodecInfoVector_insert(PyObject *self, PyObject *args) {
  Py_ssize_t argc;
  PyObject *argv[5] = {
    0
  };
  
  if (!(argc = SWIG_Python_UnpackTuple(args, "CodecInfoVector_insert", 0, 4, argv))) SWIG_fail;
  --argc;
  if (argc == 3) {
    int _v;
    int res = swig::asptr(argv[0], (std::vector< pj::CodecInfo*,std::allocator< pj::CodecInfo * > >**)(0));
    _v = SWIG_CheckState(res);
    if (_v) {
      swig::SwigPyIterator *iter = 0;
      int res = SWIG_ConvertPtr(argv[1], SWIG_as_voidptrptr(&iter), swig::SwigPyIterator::descriptor(), 0);
      _v = (SWIG_IsOK(res) && iter && (dynamic_cast<swig::SwigPyIterator_T<std::vector< pj::CodecInfo * >::iterator > *>(iter) != 0));
      if (_v) {
        void *vptr = 0;
        int res = SWIG_ConvertPtr(argv[2], &vptr, SWIGTYPE_p_pj__CodecInfo, 0);
        _v = SWIG_CheckState(res);
        if (_v) {
          return _wrap_CodecInfoVector_insert__SWIG_0(self, argc, argv);
        }
      }
    }
  }
  if (argc == 4) {
    int _v;
    int res = swig::asptr(argv[0], (std::vector< pj::CodecInfo*,std::allocator< pj::CodecInfo * > >**)(0));
    _v = SWIG_CheckState(res);
    if (_v) {
      swig::SwigPyIterator *iter = 0;
      int res = SWIG_ConvertPtr(argv[1], SWIG_as_voidptrptr(&iter), swig::SwigPyIterator::descriptor(), 0);
      _v = (SWIG_IsOK(res) && iter && (dynamic_cast<swig::SwigPyIterator_T<std::vector< pj::CodecInfo * >::iterator > *>(iter) != 0));
      if (_v) {
        {
          int res = SWIG_AsVal_size_t(argv[2], NULL);
          _v = SWIG_CheckState(res);
        }
        if (_v) {
          void *vptr = 0;
          int res = SWIG_ConvertPtr(argv[3], &vptr, SWIGTYPE_p_pj__CodecInfo, 0);
          _v = SWIG_CheckState(res);
          if (_v) {
            return _wrap_CodecInfoVector_insert__SWIG_1(self, argc, argv);
          }
        }
      }
    }
  }
  
fail:
  SWIG_Python_RaiseOrModifyTypeError("Wrong number or type of arguments for overloaded function 'CodecInfoVector_insert'.\n"
    "  Possible C/C++ prototypes are:\n"
    "    std::vector< pj::CodecInfo * >::insert(std::vector< pj::CodecInfo * >::iterator,std::vector< pj::CodecInfo * >::value_type)\n"
    "    std::vector< pj::CodecInfo * >::insert(std::vector< pj::CodecInfo * >::iterator,std::vector< pj::CodecInfo * >::size_type,std::vector< pj::CodecInfo * >::value_type)\n");
  return 0;
}


SWIGINTERN PyObject *_wrap_CodecInfoVector_reserve(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  std::vector< pj::CodecInfo * > *arg1 = (std::vector< pj::CodecInfo * > *) 0 ;
  std::vector< pj::CodecInfo * >::size_type arg2 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  size_t val2 ;
  int ecode2 = 0 ;
  PyObject *swig_obj[2] ;
  
  if (!SWIG_Python_UnpackTuple(args, "CodecInfoVector_reserve", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__vectorT_pj__CodecInfo_p_std__allocatorT_pj__CodecInfo_p_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "CodecInfoVector_reserve" "', argument " "1"" of type '" "std::vector< pj::CodecInfo * > *""'"); 
  }
  arg1 = reinterpret_cast< std::vector< pj::CodecInfo * > * >(argp1);
  ecode2 = SWIG_AsVal_size_t(swig_obj[1], &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "CodecInfoVector_reserve" "', argument " "2"" of type '" "std::vector< pj::CodecInfo * >::size_type""'");
  } 
  arg2 = static_cast< std::vector< pj::CodecInfo * >::size_type >(val2);
  (arg1)->reserve(arg2);
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_CodecInfoVector_capacity(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  std::vector< pj::CodecInfo * > *arg1 = (std::vector< pj::CodecInfo * > *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  std::vector< pj::CodecInfo * >::size_type result;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__vectorT_pj__CodecInfo_p_std__allocatorT_pj__CodecInfo_p_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "CodecInfoVector_capacity" "', argument " "1"" of type '" "std::vector< pj::CodecInfo * > const *""'"); 
  }
  arg1 = reinterpret_cast< std::vector< pj::CodecInfo * > * >(argp1);
  result = ((std::vector< pj::CodecInfo * > const *)arg1)->capacity();
  resultobj = SWIG_From_size_t(static_cast< size_t >(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_delete_CodecInfoVector(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  std::vector< pj::CodecInfo * > *arg1 = (std::vector< pj::CodecInfo * > *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__vectorT_pj__CodecInfo_p_std__allocatorT_pj__CodecInfo_p_t_t, SWIG_POINTER_DISOWN |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "delete_CodecInfoVector" "', argument " "1"" of type '" "std::vector< pj::CodecInfo * > *""'"); 
  }
  arg1 = reinterpret_cast< std::vector< pj::CodecInfo * > * >(argp1);
  delete arg1;
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *CodecInfoVector_swigregister(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *obj;
  if (!SWIG_Python_UnpackTuple(args, "swigregister", 1, 1, &obj)) return NULL;
  SWIG_TypeNewClientData(SWIGTYPE_p_std__vectorT_pj__CodecInfo_p_std__allocatorT_pj__CodecInfo_p_t_t, SWIG_NewClientData(obj));
  return SWIG_Py_Void();
}

SWIGINTERN PyObject *CodecInfoVector_swiginit(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  return SWIG_Python_InitShadowInstance(args);
}

SWIGINTERN PyObject *_wrap_CodecInfoVector2_iterator(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  std::vector< pj::CodecInfo > *arg1 = (std::vector< pj::CodecInfo > *) 0 ;
  PyObject **arg2 = (PyObject **) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  swig::SwigPyIterator *result = 0 ;
  
  arg2 = &swig_obj[0];
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__vectorT_pj__CodecInfo_std__allocatorT_pj__CodecInfo_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "CodecInfoVector2_iterator" "', argument " "1"" of type '" "std::vector< pj::CodecInfo > *""'"); 
  }
  arg1 = reinterpret_cast< std::vector< pj::CodecInfo > * >(argp1);
  result = (swig::SwigPyIterator *)std_vector_Sl_pj_CodecInfo_Sg__iterator(arg1,arg2);
  resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(result), SWIGTYPE_p_swig__SwigPyIterator, SWIG_POINTER_OWN |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_CodecInfoVector2___nonzero__(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  std::vector< pj::CodecInfo > *arg1 = (std::vector< pj::CodecInfo > *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  bool result;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__vectorT_pj__CodecInfo_std__allocatorT_pj__CodecInfo_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "CodecInfoVector2___nonzero__" "', argument " "1"" of type '" "std::vector< pj::CodecInfo > const *""'"); 
  }
  arg1 = reinterpret_cast< std::vector< pj::CodecInfo > * >(argp1);
  result = (bool)std_vector_Sl_pj_CodecInfo_Sg____nonzero__((std::vector< pj::CodecInfo > const *)arg1);
  resultobj = SWIG_From_bool(static_cast< bool >(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_CodecInfoVector2___bool__(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  std::vector< pj::CodecInfo > *arg1 = (std::vector< pj::CodecInfo > *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  bool result;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__vectorT_pj__CodecInfo_std__allocatorT_pj__CodecInfo_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "CodecInfoVector2___bool__" "', argument " "1"" of type '" "std::vector< pj::CodecInfo > const *""'"); 
  }
  arg1 = reinterpret_cast< std::vector< pj::CodecInfo > * >(argp1);
  result = (bool)std_vector_Sl_pj_CodecInfo_Sg____bool__((std::vector< pj::CodecInfo > const *)arg1);
  resultobj = SWIG_From_bool(static_cast< bool >(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_CodecInfoVector2___len__(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  std::vector< pj::CodecInfo > *arg1 = (std::vector< pj::CodecInfo > *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  std::vector< pj::CodecInfo >::size_type result;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__vectorT_pj__CodecInfo_std__allocatorT_pj__CodecInfo_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "CodecInfoVector2___len__" "', argument " "1"" of type '" "std::vector< pj::CodecInfo > const *""'"); 
  }
  arg1 = reinterpret_cast< std::vector< pj::CodecInfo > * >(argp1);
  result = std_vector_Sl_pj_CodecInfo_Sg____len__((std::vector< pj::CodecInfo > const *)arg1);
  resultobj = SWIG_From_size_t(static_cast< size_t >(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_CodecInfoVector2___getslice__(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  std::vector< pj::CodecInfo > *arg1 = (std::vector< pj::CodecInfo > *) 0 ;
  std::vector< pj::CodecInfo >::difference_type arg2 ;
  std::vector< pj::CodecInfo >::difference_type arg3 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  ptrdiff_t val2 ;
  int ecode2 = 0 ;
  ptrdiff_t val3 ;
  int ecode3 = 0 ;
  PyObject *swig_obj[3] ;
  std::vector< pj::CodecInfo,std::allocator< pj::CodecInfo > > *result = 0 ;
  
  if (!SWIG_Python_UnpackTuple(args, "CodecInfoVector2___getslice__", 3, 3, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__vectorT_pj__CodecInfo_std__allocatorT_pj__CodecInfo_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "CodecInfoVector2___getslice__" "', argument " "1"" of type '" "std::vector< pj::CodecInfo > *""'"); 
  }
  arg1 = reinterpret_cast< std::vector< pj::CodecInfo > * >(argp1);
  ecode2 = SWIG_AsVal_ptrdiff_t(swig_obj[1], &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "CodecInfoVector2___getslice__" "', argument " "2"" of type '" "std::vector< pj::CodecInfo >::difference_type""'");
  } 
  arg2 = static_cast< std::vector< pj::CodecInfo >::difference_type >(val2);
  ecode3 = SWIG_AsVal_ptrdiff_t(swig_obj[2], &val3);
  if (!SWIG_IsOK(ecode3)) {
    SWIG_exception_fail(SWIG_ArgError(ecode3), "in method '" "CodecInfoVector2___getslice__" "', argument " "3"" of type '" "std::vector< pj::CodecInfo >::difference_type""'");
  } 
  arg3 = static_cast< std::vector< pj::CodecInfo >::difference_type >(val3);
  try {
    result = (std::vector< pj::CodecInfo,std::allocator< pj::CodecInfo > > *)std_vector_Sl_pj_CodecInfo_Sg____getslice__(arg1,arg2,arg3);
  } catch(std::out_of_range &_e) {
    SWIG_exception_fail(SWIG_IndexError, (&_e)->what());
  } catch(std::invalid_argument &_e) {
    SWIG_exception_fail(SWIG_ValueError, (&_e)->what());
  }
  resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(result), SWIGTYPE_p_std__vectorT_pj__CodecInfo_std__allocatorT_pj__CodecInfo_t_t, SWIG_POINTER_OWN |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_CodecInfoVector2___setslice____SWIG_0(PyObject *SWIGUNUSEDPARM(self), Py_ssize_t nobjs, PyObject **swig_obj) {
  PyObject *resultobj = 0;
  std::vector< pj::CodecInfo > *arg1 = (std::vector< pj::CodecInfo > *) 0 ;
  std::vector< pj::CodecInfo >::difference_type arg2 ;
  std::vector< pj::CodecInfo >::difference_type arg3 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  ptrdiff_t val2 ;
  int ecode2 = 0 ;
  ptrdiff_t val3 ;
  int ecode3 = 0 ;
  
  if ((nobjs < 3) || (nobjs > 3)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__vectorT_pj__CodecInfo_std__allocatorT_pj__CodecInfo_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "CodecInfoVector2___setslice__" "', argument " "1"" of type '" "std::vector< pj::CodecInfo > *""'"); 
  }
  arg1 = reinterpret_cast< std::vector< pj::CodecInfo > * >(argp1);
  ecode2 = SWIG_AsVal_ptrdiff_t(swig_obj[1], &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "CodecInfoVector2___setslice__" "', argument " "2"" of type '" "std::vector< pj::CodecInfo >::difference_type""'");
  } 
  arg2 = static_cast< std::vector< pj::CodecInfo >::difference_type >(val2);
  ecode3 = SWIG_AsVal_ptrdiff_t(swig_obj[2], &val3);
  if (!SWIG_IsOK(ecode3)) {
    SWIG_exception_fail(SWIG_ArgError(ecode3), "in method '" "CodecInfoVector2___setslice__" "', argument " "3"" of type '" "std::vector< pj::CodecInfo >::difference_type""'");
  } 
  arg3 = static_cast< std::vector< pj::CodecInfo >::difference_type >(val3);
  try {
    std_vector_Sl_pj_CodecInfo_Sg____setslice____SWIG_0(arg1,arg2,arg3);
  } catch(std::out_of_range &_e) {
    SWIG_exception_fail(SWIG_IndexError, (&_e)->what());
  } catch(std::invalid_argument &_e) {
    SWIG_exception_fail(SWIG_ValueError, (&_e)->what());
  }
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_CodecInfoVector2___setslice____SWIG_1(PyObject *SWIGUNUSEDPARM(self), Py_ssize_t nobjs, PyObject **swig_obj) {
  PyObject *resultobj = 0;
  std::vector< pj::CodecInfo > *arg1 = (std::vector< pj::CodecInfo > *) 0 ;
  std::vector< pj::CodecInfo >::difference_type arg2 ;
  std::vector< pj::CodecInfo >::difference_type arg3 ;
  std::vector< pj::CodecInfo,std::allocator< pj::CodecInfo > > *arg4 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  ptrdiff_t val2 ;
  int ecode2 = 0 ;
  ptrdiff_t val3 ;
  int ecode3 = 0 ;
  int res4 = SWIG_OLDOBJ ;
  
  if ((nobjs < 4) || (nobjs > 4)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__vectorT_pj__CodecInfo_std__allocatorT_pj__CodecInfo_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "CodecInfoVector2___setslice__" "', argument " "1"" of type '" "std::vector< pj::CodecInfo > *""'"); 
  }
  arg1 = reinterpret_cast< std::vector< pj::CodecInfo > * >(argp1);
  ecode2 = SWIG_AsVal_ptrdiff_t(swig_obj[1], &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "CodecInfoVector2___setslice__" "', argument " "2"" of type '" "std::vector< pj::CodecInfo >::difference_type""'");
  } 
  arg2 = static_cast< std::vector< pj::CodecInfo >::difference_type >(val2);
  ecode3 = SWIG_AsVal_ptrdiff_t(swig_obj[2], &val3);
  if (!SWIG_IsOK(ecode3)) {
    SWIG_exception_fail(SWIG_ArgError(ecode3), "in method '" "CodecInfoVector2___setslice__" "', argument " "3"" of type '" "std::vector< pj::CodecInfo >::difference_type""'");
  } 
  arg3 = static_cast< std::vector< pj::CodecInfo >::difference_type >(val3);
  {
    std::vector< pj::CodecInfo,std::allocator< pj::CodecInfo > > *ptr = (std::vector< pj::CodecInfo,std::allocator< pj::CodecInfo > > *)0;
    res4 = swig::asptr(swig_obj[3], &ptr);
    if (!SWIG_IsOK(res4)) {
      SWIG_exception_fail(SWIG_ArgError(res4), "in method '" "CodecInfoVector2___setslice__" "', argument " "4"" of type '" "std::vector< pj::CodecInfo,std::allocator< pj::CodecInfo > > const &""'"); 
    }
    if (!ptr) {
      SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "CodecInfoVector2___setslice__" "', argument " "4"" of type '" "std::vector< pj::CodecInfo,std::allocator< pj::CodecInfo > > const &""'"); 
    }
    arg4 = ptr;
  }
  try {
    std_vector_Sl_pj_CodecInfo_Sg____setslice____SWIG_1(arg1,arg2,arg3,(std::vector< pj::CodecInfo,std::allocator< pj::CodecInfo > > const &)*arg4);
  } catch(std::out_of_range &_e) {
    SWIG_exception_fail(SWIG_IndexError, (&_e)->what());
  } catch(std::invalid_argument &_e) {
    SWIG_exception_fail(SWIG_ValueError, (&_e)->what());
  }
  resultobj = SWIG_Py_Void();
  if (SWIG_IsNewObj(res4)) delete arg4;
  return resultobj;
fail:
  if (SWIG_IsNewObj(res4)) delete arg4;
  return NULL;
}


SWIGINTERN PyObject *_wrap_CodecInfoVector2___setslice__(PyObject *self, PyObject *args) {
  Py_ssize_t argc;
  PyObject *argv[5] = {
    0
  };
  
  if (!(argc = SWIG_Python_UnpackTuple(args, "CodecInfoVector2___setslice__", 0, 4, argv))) SWIG_fail;
  --argc;
  if (argc == 3) {
    int _v;
    int res = swig::asptr(argv[0], (std::vector< pj::CodecInfo,std::allocator< pj::CodecInfo > >**)(0));
    _v = SWIG_CheckState(res);
    if (_v) {
      {
        int res = SWIG_AsVal_ptrdiff_t(argv[1], NULL);
        _v = SWIG_CheckState(res);
      }
      if (_v) {
        {
          int res = SWIG_AsVal_ptrdiff_t(argv[2], NULL);
          _v = SWIG_CheckState(res);
        }
        if (_v) {
          return _wrap_CodecInfoVector2___setslice____SWIG_0(self, argc, argv);
        }
      }
    }
  }
  if (argc == 4) {
    int _v;
    int res = swig::asptr(argv[0], (std::vector< pj::CodecInfo,std::allocator< pj::CodecInfo > >**)(0));
    _v = SWIG_CheckState(res);
    if (_v) {
      {
        int res = SWIG_AsVal_ptrdiff_t(argv[1], NULL);
        _v = SWIG_CheckState(res);
      }
      if (_v) {
        {
          int res = SWIG_AsVal_ptrdiff_t(argv[2], NULL);
          _v = SWIG_CheckState(res);
        }
        if (_v) {
          int res = swig::asptr(argv[3], (std::vector< pj::CodecInfo,std::allocator< pj::CodecInfo > >**)(0));
          _v = SWIG_CheckState(res);
          if (_v) {
            return _wrap_CodecInfoVector2___setslice____SWIG_1(self, argc, argv);
          }
        }
      }
    }
  }
  
fail:
  SWIG_Python_RaiseOrModifyTypeError("Wrong number or type of arguments for overloaded function 'CodecInfoVector2___setslice__'.\n"
    "  Possible C/C++ prototypes are:\n"
    "    std::vector< pj::CodecInfo >::__setslice__(std::vector< pj::CodecInfo >::difference_type,std::vector< pj::CodecInfo >::difference_type)\n"
    "    std::vector< pj::CodecInfo >::__setslice__(std::vector< pj::CodecInfo >::difference_type,std::vector< pj::CodecInfo >::difference_type,std::vector< pj::CodecInfo,std::allocator< pj::CodecInfo > > const &)\n");
  return 0;
}


SWIGINTERN PyObject *_wrap_CodecInfoVector2___delslice__(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  std::vector< pj::CodecInfo > *arg1 = (std::vector< pj::CodecInfo > *) 0 ;
  std::vector< pj::CodecInfo >::difference_type arg2 ;
  std::vector< pj::CodecInfo >::difference_type arg3 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  ptrdiff_t val2 ;
  int ecode2 = 0 ;
  ptrdiff_t val3 ;
  int ecode3 = 0 ;
  PyObject *swig_obj[3] ;
  
  if (!SWIG_Python_UnpackTuple(args, "CodecInfoVector2___delslice__", 3, 3, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__vectorT_pj__CodecInfo_std__allocatorT_pj__CodecInfo_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "CodecInfoVector2___delslice__" "', argument " "1"" of type '" "std::vector< pj::CodecInfo > *""'"); 
  }
  arg1 = reinterpret_cast< std::vector< pj::CodecInfo > * >(argp1);
  ecode2 = SWIG_AsVal_ptrdiff_t(swig_obj[1], &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "CodecInfoVector2___delslice__" "', argument " "2"" of type '" "std::vector< pj::CodecInfo >::difference_type""'");
  } 
  arg2 = static_cast< std::vector< pj::CodecInfo >::difference_type >(val2);
  ecode3 = SWIG_AsVal_ptrdiff_t(swig_obj[2], &val3);
  if (!SWIG_IsOK(ecode3)) {
    SWIG_exception_fail(SWIG_ArgError(ecode3), "in method '" "CodecInfoVector2___delslice__" "', argument " "3"" of type '" "std::vector< pj::CodecInfo >::difference_type""'");
  } 
  arg3 = static_cast< std::vector< pj::CodecInfo >::difference_type >(val3);
  try {
    std_vector_Sl_pj_CodecInfo_Sg____delslice__(arg1,arg2,arg3);
  } catch(std::out_of_range &_e) {
    SWIG_exception_fail(SWIG_IndexError, (&_e)->what());
  } catch(std::invalid_argument &_e) {
    SWIG_exception_fail(SWIG_ValueError, (&_e)->what());
  }
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_CodecInfoVector2___delitem____SWIG_0(PyObject *SWIGUNUSEDPARM(self), Py_ssize_t nobjs, PyObject **swig_obj) {
  PyObject *resultobj = 0;
  std::vector< pj::CodecInfo > *arg1 = (std::vector< pj::CodecInfo > *) 0 ;
  std::vector< pj::CodecInfo >::difference_type arg2 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  ptrdiff_t val2 ;
  int ecode2 = 0 ;
  
  if ((nobjs < 2) || (nobjs > 2)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__vectorT_pj__CodecInfo_std__allocatorT_pj__CodecInfo_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "CodecInfoVector2___delitem__" "', argument " "1"" of type '" "std::vector< pj::CodecInfo > *""'"); 
  }
  arg1 = reinterpret_cast< std::vector< pj::CodecInfo > * >(argp1);
  ecode2 = SWIG_AsVal_ptrdiff_t(swig_obj[1], &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "CodecInfoVector2___delitem__" "', argument " "2"" of type '" "std::vector< pj::CodecInfo >::difference_type""'");
  } 
  arg2 = static_cast< std::vector< pj::CodecInfo >::difference_type >(val2);
  try {
    std_vector_Sl_pj_CodecInfo_Sg____delitem____SWIG_0(arg1,arg2);
  } catch(std::out_of_range &_e) {
    SWIG_exception_fail(SWIG_IndexError, (&_e)->what());
  } catch(std::invalid_argument &_e) {
    SWIG_exception_fail(SWIG_ValueError, (&_e)->what());
  }
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_CodecInfoVector2___getitem____SWIG_0(PyObject *SWIGUNUSEDPARM(self), Py_ssize_t nobjs, PyObject **swig_obj) {
  PyObject *resultobj = 0;
  std::vector< pj::CodecInfo > *arg1 = (std::vector< pj::CodecInfo > *) 0 ;
  PySliceObject *arg2 = (PySliceObject *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  std::vector< pj::CodecInfo,std::allocator< pj::CodecInfo > > *result = 0 ;
  
  if ((nobjs < 2) || (nobjs > 2)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__vectorT_pj__CodecInfo_std__allocatorT_pj__CodecInfo_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "CodecInfoVector2___getitem__" "', argument " "1"" of type '" "std::vector< pj::CodecInfo > *""'"); 
  }
  arg1 = reinterpret_cast< std::vector< pj::CodecInfo > * >(argp1);
  {
    if (!PySlice_Check(swig_obj[1])) {
      SWIG_exception_fail(SWIG_ArgError(SWIG_TypeError), "in method '" "CodecInfoVector2___getitem__" "', argument " "2"" of type '" "PySliceObject *""'");
    }
    arg2 = (PySliceObject *) swig_obj[1];
  }
  try {
    result = (std::vector< pj::CodecInfo,std::allocator< pj::CodecInfo > > *)std_vector_Sl_pj_CodecInfo_Sg____getitem____SWIG_0(arg1,arg2);
  } catch(std::out_of_range &_e) {
    SWIG_exception_fail(SWIG_IndexError, (&_e)->what());
  } catch(std::invalid_argument &_e) {
    SWIG_exception_fail(SWIG_ValueError, (&_e)->what());
  }
  resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(result), SWIGTYPE_p_std__vectorT_pj__CodecInfo_std__allocatorT_pj__CodecInfo_t_t, SWIG_POINTER_OWN |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_CodecInfoVector2___setitem____SWIG_0(PyObject *SWIGUNUSEDPARM(self), Py_ssize_t nobjs, PyObject **swig_obj) {
  PyObject *resultobj = 0;
  std::vector< pj::CodecInfo > *arg1 = (std::vector< pj::CodecInfo > *) 0 ;
  PySliceObject *arg2 = (PySliceObject *) 0 ;
  std::vector< pj::CodecInfo,std::allocator< pj::CodecInfo > > *arg3 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  int res3 = SWIG_OLDOBJ ;
  
  if ((nobjs < 3) || (nobjs > 3)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__vectorT_pj__CodecInfo_std__allocatorT_pj__CodecInfo_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "CodecInfoVector2___setitem__" "', argument " "1"" of type '" "std::vector< pj::CodecInfo > *""'"); 
  }
  arg1 = reinterpret_cast< std::vector< pj::CodecInfo > * >(argp1);
  {
    if (!PySlice_Check(swig_obj[1])) {
      SWIG_exception_fail(SWIG_ArgError(SWIG_TypeError), "in method '" "CodecInfoVector2___setitem__" "', argument " "2"" of type '" "PySliceObject *""'");
    }
    arg2 = (PySliceObject *) swig_obj[1];
  }
  {
    std::vector< pj::CodecInfo,std::allocator< pj::CodecInfo > > *ptr = (std::vector< pj::CodecInfo,std::allocator< pj::CodecInfo > > *)0;
    res3 = swig::asptr(swig_obj[2], &ptr);
    if (!SWIG_IsOK(res3)) {
      SWIG_exception_fail(SWIG_ArgError(res3), "in method '" "CodecInfoVector2___setitem__" "', argument " "3"" of type '" "std::vector< pj::CodecInfo,std::allocator< pj::CodecInfo > > const &""'"); 
    }
    if (!ptr) {
      SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "CodecInfoVector2___setitem__" "', argument " "3"" of type '" "std::vector< pj::CodecInfo,std::allocator< pj::CodecInfo > > const &""'"); 
    }
    arg3 = ptr;
  }
  try {
    std_vector_Sl_pj_CodecInfo_Sg____setitem____SWIG_0(arg1,arg2,(std::vector< pj::CodecInfo,std::allocator< pj::CodecInfo > > const &)*arg3);
  } catch(std::out_of_range &_e) {
    SWIG_exception_fail(SWIG_IndexError, (&_e)->what());
  } catch(std::invalid_argument &_e) {
    SWIG_exception_fail(SWIG_ValueError, (&_e)->what());
  }
  resultobj = SWIG_Py_Void();
  if (SWIG_IsNewObj(res3)) delete arg3;
  return resultobj;
fail:
  if (SWIG_IsNewObj(res3)) delete arg3;
  return NULL;
}


SWIGINTERN PyObject *_wrap_CodecInfoVector2___setitem____SWIG_1(PyObject *SWIGUNUSEDPARM(self), Py_ssize_t nobjs, PyObject **swig_obj) {
  PyObject *resultobj = 0;
  std::vector< pj::CodecInfo > *arg1 = (std::vector< pj::CodecInfo > *) 0 ;
  PySliceObject *arg2 = (PySliceObject *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  
  if ((nobjs < 2) || (nobjs > 2)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__vectorT_pj__CodecInfo_std__allocatorT_pj__CodecInfo_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "CodecInfoVector2___setitem__" "', argument " "1"" of type '" "std::vector< pj::CodecInfo > *""'"); 
  }
  arg1 = reinterpret_cast< std::vector< pj::CodecInfo > * >(argp1);
  {
    if (!PySlice_Check(swig_obj[1])) {
      SWIG_exception_fail(SWIG_ArgError(SWIG_TypeError), "in method '" "CodecInfoVector2___setitem__" "', argument " "2"" of type '" "PySliceObject *""'");
    }
    arg2 = (PySliceObject *) swig_obj[1];
  }
  try {
    std_vector_Sl_pj_CodecInfo_Sg____setitem____SWIG_1(arg1,arg2);
  } catch(std::out_of_range &_e) {
    SWIG_exception_fail(SWIG_IndexError, (&_e)->what());
  } catch(std::invalid_argument &_e) {
    SWIG_exception_fail(SWIG_ValueError, (&_e)->what());
  }
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_CodecInfoVector2___delitem____SWIG_1(PyObject *SWIGUNUSEDPARM(self), Py_ssize_t nobjs, PyObject **swig_obj) {
  PyObject *resultobj = 0;
  std::vector< pj::CodecInfo > *arg1 = (std::vector< pj::CodecInfo > *) 0 ;
  PySliceObject *arg2 = (PySliceObject *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  
  if ((nobjs < 2) || (nobjs > 2)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__vectorT_pj__CodecInfo_std__allocatorT_pj__CodecInfo_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "CodecInfoVector2___delitem__" "', argument " "1"" of type '" "std::vector< pj::CodecInfo > *""'"); 
  }
  arg1 = reinterpret_cast< std::vector< pj::CodecInfo > * >(argp1);
  {
    if (!PySlice_Check(swig_obj[1])) {
      SWIG_exception_fail(SWIG_ArgError(SWIG_TypeError), "in method '" "CodecInfoVector2___delitem__" "', argument " "2"" of type '" "PySliceObject *""'");
    }
    arg2 = (PySliceObject *) swig_obj[1];
  }
  try {
    std_vector_Sl_pj_CodecInfo_Sg____delitem____SWIG_1(arg1,arg2);
  } catch(std::out_of_range &_e) {
    SWIG_exception_fail(SWIG_IndexError, (&_e)->what());
  } catch(std::invalid_argument &_e) {
    SWIG_exception_fail(SWIG_ValueError, (&_e)->what());
  }
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_CodecInfoVector2___delitem__(PyObject *self, PyObject *args) {
  Py_ssize_t argc;
  PyObject *argv[3] = {
    0
  };
  
  if (!(argc = SWIG_Python_UnpackTuple(args, "CodecInfoVector2___delitem__", 0, 2, argv))) SWIG_fail;
  --argc;
  if (argc == 2) {
    int _v;
    int res = swig::asptr(argv[0], (std::vector< pj::CodecInfo,std::allocator< pj::CodecInfo > >**)(0));
    _v = SWIG_CheckState(res);
    if (_v) {
      {
        _v = PySlice_Check(argv[1]);
      }
      if (_v) {
        return _wrap_CodecInfoVector2___delitem____SWIG_1(self, argc, argv);
      }
    }
  }
  if (argc == 2) {
    int _v;
    int res = swig::asptr(argv[0], (std::vector< pj::CodecInfo,std::allocator< pj::CodecInfo > >**)(0));
    _v = SWIG_CheckState(res);
    if (_v) {
      {
        int res = SWIG_AsVal_ptrdiff_t(argv[1], NULL);
        _v = SWIG_CheckState(res);
      }
      if (_v) {
        return _wrap_CodecInfoVector2___delitem____SWIG_0(self, argc, argv);
      }
    }
  }
  
fail:
  SWIG_Python_RaiseOrModifyTypeError("Wrong number or type of arguments for overloaded function 'CodecInfoVector2___delitem__'.\n"
    "  Possible C/C++ prototypes are:\n"
    "    std::vector< pj::CodecInfo >::__delitem__(std::vector< pj::CodecInfo >::difference_type)\n"
    "    std::vector< pj::CodecInfo >::__delitem__(PySliceObject *)\n");
  return 0;
}


SWIGINTERN PyObject *_wrap_CodecInfoVector2___getitem____SWIG_1(PyObject *SWIGUNUSEDPARM(self), Py_ssize_t nobjs, PyObject **swig_obj) {
  PyObject *resultobj = 0;
  std::vector< pj::CodecInfo > *arg1 = (std::vector< pj::CodecInfo > *) 0 ;
  std::vector< pj::CodecInfo >::difference_type arg2 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  ptrdiff_t val2 ;
  int ecode2 = 0 ;
  std::vector< pj::CodecInfo >::value_type *result = 0 ;
  
  if ((nobjs < 2) || (nobjs > 2)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__vectorT_pj__CodecInfo_std__allocatorT_pj__CodecInfo_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "CodecInfoVector2___getitem__" "', argument " "1"" of type '" "std::vector< pj::CodecInfo > const *""'"); 
  }
  arg1 = reinterpret_cast< std::vector< pj::CodecInfo > * >(argp1);
  ecode2 = SWIG_AsVal_ptrdiff_t(swig_obj[1], &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "CodecInfoVector2___getitem__" "', argument " "2"" of type '" "std::vector< pj::CodecInfo >::difference_type""'");
  } 
  arg2 = static_cast< std::vector< pj::CodecInfo >::difference_type >(val2);
  try {
    result = (std::vector< pj::CodecInfo >::value_type *) &std_vector_Sl_pj_CodecInfo_Sg____getitem____SWIG_1((std::vector< pj::CodecInfo > const *)arg1,arg2);
  } catch(std::out_of_range &_e) {
    SWIG_exception_fail(SWIG_IndexError, (&_e)->what());
  }
  resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(result), SWIGTYPE_p_pj__CodecInfo, 0 |  0 );
  (void)swig::container_owner<swig::traits<std::vector< pj::CodecInfo >::value_type>::category>::back_reference(resultobj, swig_obj[0]);
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_CodecInfoVector2___getitem__(PyObject *self, PyObject *args) {
  Py_ssize_t argc;
  PyObject *argv[3] = {
    0
  };
  
  if (!(argc = SWIG_Python_UnpackTuple(args, "CodecInfoVector2___getitem__", 0, 2, argv))) SWIG_fail;
  --argc;
  if (argc == 2) {
    int _v;
    int res = swig::asptr(argv[0], (std::vector< pj::CodecInfo,std::allocator< pj::CodecInfo > >**)(0));
    _v = SWIG_CheckState(res);
    if (_v) {
      {
        _v = PySlice_Check(argv[1]);
      }
      if (_v) {
        return _wrap_CodecInfoVector2___getitem____SWIG_0(self, argc, argv);
      }
    }
  }
  if (argc == 2) {
    int _v;
    int res = swig::asptr(argv[0], (std::vector< pj::CodecInfo,std::allocator< pj::CodecInfo > >**)(0));
    _v = SWIG_CheckState(res);
    if (_v) {
      {
        int res = SWIG_AsVal_ptrdiff_t(argv[1], NULL);
        _v = SWIG_CheckState(res);
      }
      if (_v) {
        return _wrap_CodecInfoVector2___getitem____SWIG_1(self, argc, argv);
      }
    }
  }
  
fail:
  SWIG_Python_RaiseOrModifyTypeError("Wrong number or type of arguments for overloaded function 'CodecInfoVector2___getitem__'.\n"
    "  Possible C/C++ prototypes are:\n"
    "    std::vector< pj::CodecInfo >::__getitem__(PySliceObject *)\n"
    "    std::vector< pj::CodecInfo >::__getitem__(std::vector< pj::CodecInfo >::difference_type) const\n");
  return 0;
}


SWIGINTERN PyObject *_wrap_CodecInfoVector2___setitem____SWIG_2(PyObject *SWIGUNUSEDPARM(self), Py_ssize_t nobjs, PyObject **swig_obj) {
  PyObject *resultobj = 0;
  std::vector< pj::CodecInfo > *arg1 = (std::vector< pj::CodecInfo > *) 0 ;
  std::vector< pj::CodecInfo >::difference_type arg2 ;
  std::vector< pj::CodecInfo >::value_type *arg3 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  ptrdiff_t val2 ;
  int ecode2 = 0 ;
  void *argp3 = 0 ;
  int res3 = 0 ;
  
  if ((nobjs < 3) || (nobjs > 3)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__vectorT_pj__CodecInfo_std__allocatorT_pj__CodecInfo_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "CodecInfoVector2___setitem__" "', argument " "1"" of type '" "std::vector< pj::CodecInfo > *""'"); 
  }
  arg1 = reinterpret_cast< std::vector< pj::CodecInfo > * >(argp1);
  ecode2 = SWIG_AsVal_ptrdiff_t(swig_obj[1], &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "CodecInfoVector2___setitem__" "', argument " "2"" of type '" "std::vector< pj::CodecInfo >::difference_type""'");
  } 
  arg2 = static_cast< std::vector< pj::CodecInfo >::difference_type >(val2);
  res3 = SWIG_ConvertPtr(swig_obj[2], &argp3, SWIGTYPE_p_pj__CodecInfo,  0  | 0);
  if (!SWIG_IsOK(res3)) {
    SWIG_exception_fail(SWIG_ArgError(res3), "in method '" "CodecInfoVector2___setitem__" "', argument " "3"" of type '" "std::vector< pj::CodecInfo >::value_type const &""'"); 
  }
  if (!argp3) {
    SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "CodecInfoVector2___setitem__" "', argument " "3"" of type '" "std::vector< pj::CodecInfo >::value_type const &""'"); 
  }
  arg3 = reinterpret_cast< std::vector< pj::CodecInfo >::value_type * >(argp3);
  try {
    std_vector_Sl_pj_CodecInfo_Sg____setitem____SWIG_2(arg1,arg2,(pj::CodecInfo const &)*arg3);
  } catch(std::out_of_range &_e) {
    SWIG_exception_fail(SWIG_IndexError, (&_e)->what());
  }
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_CodecInfoVector2___setitem__(PyObject *self, PyObject *args) {
  Py_ssize_t argc;
  PyObject *argv[4] = {
    0
  };
  
  if (!(argc = SWIG_Python_UnpackTuple(args, "CodecInfoVector2___setitem__", 0, 3, argv))) SWIG_fail;
  --argc;
  if (argc == 2) {
    int _v;
    int res = swig::asptr(argv[0], (std::vector< pj::CodecInfo,std::allocator< pj::CodecInfo > >**)(0));
    _v = SWIG_CheckState(res);
    if (_v) {
      {
        _v = PySlice_Check(argv[1]);
      }
      if (_v) {
        return _wrap_CodecInfoVector2___setitem____SWIG_1(self, argc, argv);
      }
    }
  }
  if (argc == 3) {
    int _v;
    int res = swig::asptr(argv[0], (std::vector< pj::CodecInfo,std::allocator< pj::CodecInfo > >**)(0));
    _v = SWIG_CheckState(res);
    if (_v) {
      {
        _v = PySlice_Check(argv[1]);
      }
      if (_v) {
        int res = swig::asptr(argv[2], (std::vector< pj::CodecInfo,std::allocator< pj::CodecInfo > >**)(0));
        _v = SWIG_CheckState(res);
        if (_v) {
          return _wrap_CodecInfoVector2___setitem____SWIG_0(self, argc, argv);
        }
      }
    }
  }
  if (argc == 3) {
    int _v;
    int res = swig::asptr(argv[0], (std::vector< pj::CodecInfo,std::allocator< pj::CodecInfo > >**)(0));
    _v = SWIG_CheckState(res);
    if (_v) {
      {
        int res = SWIG_AsVal_ptrdiff_t(argv[1], NULL);
        _v = SWIG_CheckState(res);
      }
      if (_v) {
        int res = SWIG_ConvertPtr(argv[2], 0, SWIGTYPE_p_pj__CodecInfo, SWIG_POINTER_NO_NULL | 0);
        _v = SWIG_CheckState(res);
        if (_v) {
          return _wrap_CodecInfoVector2___setitem____SWIG_2(self, argc, argv);
        }
      }
    }
  }
  
fail:
  SWIG_Python_RaiseOrModifyTypeError("Wrong number or type of arguments for overloaded function 'CodecInfoVector2___setitem__'.\n"
    "  Possible C/C++ prototypes are:\n"
    "    std::vector< pj::CodecInfo >::__setitem__(PySliceObject *,std::vector< pj::CodecInfo,std::allocator< pj::CodecInfo > > const &)\n"
    "    std::vector< pj::CodecInfo >::__setitem__(PySliceObject *)\n"
    "    std::vector< pj::CodecInfo >::__setitem__(std::vector< pj::CodecInfo >::difference_type,std::vector< pj::CodecInfo >::value_type const &)\n");
  return 0;
}


SWIGINTERN PyObject *_wrap_CodecInfoVector2_pop(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  std::vector< pj::CodecInfo > *arg1 = (std::vector< pj::CodecInfo > *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  std::vector< pj::CodecInfo >::value_type result;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__vectorT_pj__CodecInfo_std__allocatorT_pj__CodecInfo_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "CodecInfoVector2_pop" "', argument " "1"" of type '" "std::vector< pj::CodecInfo > *""'"); 
  }
  arg1 = reinterpret_cast< std::vector< pj::CodecInfo > * >(argp1);
  try {
    result = std_vector_Sl_pj_CodecInfo_Sg__pop(arg1);
  } catch(std::out_of_range &_e) {
    SWIG_exception_fail(SWIG_IndexError, (&_e)->what());
  }
  resultobj = SWIG_NewPointerObj((new std::vector< pj::CodecInfo >::value_type(static_cast< const std::vector< pj::CodecInfo >::value_type& >(result))), SWIGTYPE_p_pj__CodecInfo, SWIG_POINTER_OWN |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_CodecInfoVector2_append(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  std::vector< pj::CodecInfo > *arg1 = (std::vector< pj::CodecInfo > *) 0 ;
  std::vector< pj::CodecInfo >::value_type *arg2 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  void *argp2 = 0 ;
  int res2 = 0 ;
  PyObject *swig_obj[2] ;
  
  if (!SWIG_Python_UnpackTuple(args, "CodecInfoVector2_append", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__vectorT_pj__CodecInfo_std__allocatorT_pj__CodecInfo_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "CodecInfoVector2_append" "', argument " "1"" of type '" "std::vector< pj::CodecInfo > *""'"); 
  }
  arg1 = reinterpret_cast< std::vector< pj::CodecInfo > * >(argp1);
  res2 = SWIG_ConvertPtr(swig_obj[1], &argp2, SWIGTYPE_p_pj__CodecInfo,  0  | 0);
  if (!SWIG_IsOK(res2)) {
    SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "CodecInfoVector2_append" "', argument " "2"" of type '" "std::vector< pj::CodecInfo >::value_type const &""'"); 
  }
  if (!argp2) {
    SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "CodecInfoVector2_append" "', argument " "2"" of type '" "std::vector< pj::CodecInfo >::value_type const &""'"); 
  }
  arg2 = reinterpret_cast< std::vector< pj::CodecInfo >::value_type * >(argp2);
  std_vector_Sl_pj_CodecInfo_Sg__append(arg1,(pj::CodecInfo const &)*arg2);
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_new_CodecInfoVector2__SWIG_0(PyObject *SWIGUNUSEDPARM(self), Py_ssize_t nobjs, PyObject **SWIGUNUSEDPARM(swig_obj)) {
  PyObject *resultobj = 0;
  std::vector< pj::CodecInfo > *result = 0 ;
  
  if ((nobjs < 0) || (nobjs > 0)) SWIG_fail;
  result = (std::vector< pj::CodecInfo > *)new std::vector< pj::CodecInfo >();
  resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(result), SWIGTYPE_p_std__vectorT_pj__CodecInfo_std__allocatorT_pj__CodecInfo_t_t, SWIG_POINTER_NEW |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_new_CodecInfoVector2__SWIG_1(PyObject *SWIGUNUSEDPARM(self), Py_ssize_t nobjs, PyObject **swig_obj) {
  PyObject *resultobj = 0;
  std::vector< pj::CodecInfo > *arg1 = 0 ;
  int res1 = SWIG_OLDOBJ ;
  std::vector< pj::CodecInfo > *result = 0 ;
  
  if ((nobjs < 1) || (nobjs > 1)) SWIG_fail;
  {
    std::vector< pj::CodecInfo,std::allocator< pj::CodecInfo > > *ptr = (std::vector< pj::CodecInfo,std::allocator< pj::CodecInfo > > *)0;
    res1 = swig::asptr(swig_obj[0], &ptr);
    if (!SWIG_IsOK(res1)) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "new_CodecInfoVector2" "', argument " "1"" of type '" "std::vector< pj::CodecInfo > const &""'"); 
    }
    if (!ptr) {
      SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "new_CodecInfoVector2" "', argument " "1"" of type '" "std::vector< pj::CodecInfo > const &""'"); 
    }
    arg1 = ptr;
  }
  result = (std::vector< pj::CodecInfo > *)new std::vector< pj::CodecInfo >((std::vector< pj::CodecInfo > const &)*arg1);
  resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(result), SWIGTYPE_p_std__vectorT_pj__CodecInfo_std__allocatorT_pj__CodecInfo_t_t, SWIG_POINTER_NEW |  0 );
  if (SWIG_IsNewObj(res1)) delete arg1;
  return resultobj;
fail:
  if (SWIG_IsNewObj(res1)) delete arg1;
  return NULL;
}


SWIGINTERN PyObject *_wrap_CodecInfoVector2_empty(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  std::vector< pj::CodecInfo > *arg1 = (std::vector< pj::CodecInfo > *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  bool result;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__vectorT_pj__CodecInfo_std__allocatorT_pj__CodecInfo_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "CodecInfoVector2_empty" "', argument " "1"" of type '" "std::vector< pj::CodecInfo > const *""'"); 
  }
  arg1 = reinterpret_cast< std::vector< pj::CodecInfo > * >(argp1);
  result = (bool)((std::vector< pj::CodecInfo > const *)arg1)->empty();
  resultobj = SWIG_From_bool(static_cast< bool >(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_CodecInfoVector2_size(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  std::vector< pj::CodecInfo > *arg1 = (std::vector< pj::CodecInfo > *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  std::vector< pj::CodecInfo >::size_type result;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__vectorT_pj__CodecInfo_std__allocatorT_pj__CodecInfo_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "CodecInfoVector2_size" "', argument " "1"" of type '" "std::vector< pj::CodecInfo > const *""'"); 
  }
  arg1 = reinterpret_cast< std::vector< pj::CodecInfo > * >(argp1);
  result = ((std::vector< pj::CodecInfo > const *)arg1)->size();
  resultobj = SWIG_From_size_t(static_cast< size_t >(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_CodecInfoVector2_swap(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  std::vector< pj::CodecInfo > *arg1 = (std::vector< pj::CodecInfo > *) 0 ;
  std::vector< pj::CodecInfo > *arg2 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  void *argp2 = 0 ;
  int res2 = 0 ;
  PyObject *swig_obj[2] ;
  
  if (!SWIG_Python_UnpackTuple(args, "CodecInfoVector2_swap", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__vectorT_pj__CodecInfo_std__allocatorT_pj__CodecInfo_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "CodecInfoVector2_swap" "', argument " "1"" of type '" "std::vector< pj::CodecInfo > *""'"); 
  }
  arg1 = reinterpret_cast< std::vector< pj::CodecInfo > * >(argp1);
  res2 = SWIG_ConvertPtr(swig_obj[1], &argp2, SWIGTYPE_p_std__vectorT_pj__CodecInfo_std__allocatorT_pj__CodecInfo_t_t,  0 );
  if (!SWIG_IsOK(res2)) {
    SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "CodecInfoVector2_swap" "', argument " "2"" of type '" "std::vector< pj::CodecInfo > &""'"); 
  }
  if (!argp2) {
    SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "CodecInfoVector2_swap" "', argument " "2"" of type '" "std::vector< pj::CodecInfo > &""'"); 
  }
  arg2 = reinterpret_cast< std::vector< pj::CodecInfo > * >(argp2);
  (arg1)->swap(*arg2);
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_CodecInfoVector2_begin(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  std::vector< pj::CodecInfo > *arg1 = (std::vector< pj::CodecInfo > *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  std::vector< pj::CodecInfo >::iterator result;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__vectorT_pj__CodecInfo_std__allocatorT_pj__CodecInfo_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "CodecInfoVector2_begin" "', argument " "1"" of type '" "std::vector< pj::CodecInfo > *""'"); 
  }
  arg1 = reinterpret_cast< std::vector< pj::CodecInfo > * >(argp1);
  result = (arg1)->begin();
  resultobj = SWIG_NewPointerObj(swig::make_output_iterator(static_cast< const std::vector< pj::CodecInfo >::iterator & >(result)),
    swig::SwigPyIterator::descriptor(),SWIG_POINTER_OWN);
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_CodecInfoVector2_end(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  std::vector< pj::CodecInfo > *arg1 = (std::vector< pj::CodecInfo > *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  std::vector< pj::CodecInfo >::iterator result;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__vectorT_pj__CodecInfo_std__allocatorT_pj__CodecInfo_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "CodecInfoVector2_end" "', argument " "1"" of type '" "std::vector< pj::CodecInfo > *""'"); 
  }
  arg1 = reinterpret_cast< std::vector< pj::CodecInfo > * >(argp1);
  result = (arg1)->end();
  resultobj = SWIG_NewPointerObj(swig::make_output_iterator(static_cast< const std::vector< pj::CodecInfo >::iterator & >(result)),
    swig::SwigPyIterator::descriptor(),SWIG_POINTER_OWN);
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_CodecInfoVector2_rbegin(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  std::vector< pj::CodecInfo > *arg1 = (std::vector< pj::CodecInfo > *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  std::vector< pj::CodecInfo >::reverse_iterator result;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__vectorT_pj__CodecInfo_std__allocatorT_pj__CodecInfo_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "CodecInfoVector2_rbegin" "', argument " "1"" of type '" "std::vector< pj::CodecInfo > *""'"); 
  }
  arg1 = reinterpret_cast< std::vector< pj::CodecInfo > * >(argp1);
  result = (arg1)->rbegin();
  resultobj = SWIG_NewPointerObj(swig::make_output_iterator(static_cast< const std::vector< pj::CodecInfo >::reverse_iterator & >(result)),
    swig::SwigPyIterator::descriptor(),SWIG_POINTER_OWN);
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_CodecInfoVector2_rend(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  std::vector< pj::CodecInfo > *arg1 = (std::vector< pj::CodecInfo > *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  std::vector< pj::CodecInfo >::reverse_iterator result;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__vectorT_pj__CodecInfo_std__allocatorT_pj__CodecInfo_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "CodecInfoVector2_rend" "', argument " "1"" of type '" "std::vector< pj::CodecInfo > *""'"); 
  }
  arg1 = reinterpret_cast< std::vector< pj::CodecInfo > * >(argp1);
  result = (arg1)->rend();
  resultobj = SWIG_NewPointerObj(swig::make_output_iterator(static_cast< const std::vector< pj::CodecInfo >::reverse_iterator & >(result)),
    swig::SwigPyIterator::descriptor(),SWIG_POINTER_OWN);
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_CodecInfoVector2_clear(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  std::vector< pj::CodecInfo > *arg1 = (std::vector< pj::CodecInfo > *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__vectorT_pj__CodecInfo_std__allocatorT_pj__CodecInfo_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "CodecInfoVector2_clear" "', argument " "1"" of type '" "std::vector< pj::CodecInfo > *""'"); 
  }
  arg1 = reinterpret_cast< std::vector< pj::CodecInfo > * >(argp1);
  (arg1)->clear();
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_CodecInfoVector2_get_allocator(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  std::vector< pj::CodecInfo > *arg1 = (std::vector< pj::CodecInfo > *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  SwigValueWrapper< std::allocator< pj::CodecInfo > > result;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__vectorT_pj__CodecInfo_std__allocatorT_pj__CodecInfo_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "CodecInfoVector2_get_allocator" "', argument " "1"" of type '" "std::vector< pj::CodecInfo > const *""'"); 
  }
  arg1 = reinterpret_cast< std::vector< pj::CodecInfo > * >(argp1);
  result = ((std::vector< pj::CodecInfo > const *)arg1)->get_allocator();
  resultobj = SWIG_NewPointerObj((new std::vector< pj::CodecInfo >::allocator_type(static_cast< const std::vector< pj::CodecInfo >::allocator_type& >(result))), SWIGTYPE_p_std__allocatorT_pj__CodecInfo_t, SWIG_POINTER_OWN |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_new_CodecInfoVector2__SWIG_2(PyObject *SWIGUNUSEDPARM(self), Py_ssize_t nobjs, PyObject **swig_obj) {
  PyObject *resultobj = 0;
  std::vector< pj::CodecInfo >::size_type arg1 ;
  size_t val1 ;
  int ecode1 = 0 ;
  std::vector< pj::CodecInfo > *result = 0 ;
  
  if ((nobjs < 1) || (nobjs > 1)) SWIG_fail;
  ecode1 = SWIG_AsVal_size_t(swig_obj[0], &val1);
  if (!SWIG_IsOK(ecode1)) {
    SWIG_exception_fail(SWIG_ArgError(ecode1), "in method '" "new_CodecInfoVector2" "', argument " "1"" of type '" "std::vector< pj::CodecInfo >::size_type""'");
  } 
  arg1 = static_cast< std::vector< pj::CodecInfo >::size_type >(val1);
  result = (std::vector< pj::CodecInfo > *)new std::vector< pj::CodecInfo >(arg1);
  resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(result), SWIGTYPE_p_std__vectorT_pj__CodecInfo_std__allocatorT_pj__CodecInfo_t_t, SWIG_POINTER_NEW |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_CodecInfoVector2_pop_back(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  std::vector< pj::CodecInfo > *arg1 = (std::vector< pj::CodecInfo > *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__vectorT_pj__CodecInfo_std__allocatorT_pj__CodecInfo_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "CodecInfoVector2_pop_back" "', argument " "1"" of type '" "std::vector< pj::CodecInfo > *""'"); 
  }
  arg1 = reinterpret_cast< std::vector< pj::CodecInfo > * >(argp1);
  (arg1)->pop_back();
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_CodecInfoVector2_resize__SWIG_0(PyObject *SWIGUNUSEDPARM(self), Py_ssize_t nobjs, PyObject **swig_obj) {
  PyObject *resultobj = 0;
  std::vector< pj::CodecInfo > *arg1 = (std::vector< pj::CodecInfo > *) 0 ;
  std::vector< pj::CodecInfo >::size_type arg2 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  size_t val2 ;
  int ecode2 = 0 ;
  
  if ((nobjs < 2) || (nobjs > 2)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__vectorT_pj__CodecInfo_std__allocatorT_pj__CodecInfo_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "CodecInfoVector2_resize" "', argument " "1"" of type '" "std::vector< pj::CodecInfo > *""'"); 
  }
  arg1 = reinterpret_cast< std::vector< pj::CodecInfo > * >(argp1);
  ecode2 = SWIG_AsVal_size_t(swig_obj[1], &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "CodecInfoVector2_resize" "', argument " "2"" of type '" "std::vector< pj::CodecInfo >::size_type""'");
  } 
  arg2 = static_cast< std::vector< pj::CodecInfo >::size_type >(val2);
  (arg1)->resize(arg2);
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_CodecInfoVector2_erase__SWIG_0(PyObject *SWIGUNUSEDPARM(self), Py_ssize_t nobjs, PyObject **swig_obj) {
  PyObject *resultobj = 0;
  std::vector< pj::CodecInfo > *arg1 = (std::vector< pj::CodecInfo > *) 0 ;
  std::vector< pj::CodecInfo >::iterator arg2 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  swig::SwigPyIterator *iter2 = 0 ;
  int res2 ;
  std::vector< pj::CodecInfo >::iterator result;
  
  if ((nobjs < 2) || (nobjs > 2)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__vectorT_pj__CodecInfo_std__allocatorT_pj__CodecInfo_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "CodecInfoVector2_erase" "', argument " "1"" of type '" "std::vector< pj::CodecInfo > *""'"); 
  }
  arg1 = reinterpret_cast< std::vector< pj::CodecInfo > * >(argp1);
  res2 = SWIG_ConvertPtr(swig_obj[1], SWIG_as_voidptrptr(&iter2), swig::SwigPyIterator::descriptor(), 0);
  if (!SWIG_IsOK(res2) || !iter2) {
    SWIG_exception_fail(SWIG_ArgError(SWIG_TypeError), "in method '" "CodecInfoVector2_erase" "', argument " "2"" of type '" "std::vector< pj::CodecInfo >::iterator""'");
  } else {
    swig::SwigPyIterator_T<std::vector< pj::CodecInfo >::iterator > *iter_t = dynamic_cast<swig::SwigPyIterator_T<std::vector< pj::CodecInfo >::iterator > *>(iter2);
    if (iter_t) {
      arg2 = iter_t->get_current();
    } else {
      SWIG_exception_fail(SWIG_ArgError(SWIG_TypeError), "in method '" "CodecInfoVector2_erase" "', argument " "2"" of type '" "std::vector< pj::CodecInfo >::iterator""'");
    }
  }
  result = std_vector_Sl_pj_CodecInfo_Sg__erase__SWIG_0(arg1,arg2);
  resultobj = SWIG_NewPointerObj(swig::make_output_iterator(static_cast< const std::vector< pj::CodecInfo >::iterator & >(result)),
    swig::SwigPyIterator::descriptor(),SWIG_POINTER_OWN);
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_CodecInfoVector2_erase__SWIG_1(PyObject *SWIGUNUSEDPARM(self), Py_ssize_t nobjs, PyObject **swig_obj) {
  PyObject *resultobj = 0;
  std::vector< pj::CodecInfo > *arg1 = (std::vector< pj::CodecInfo > *) 0 ;
  std::vector< pj::CodecInfo >::iterator arg2 ;
  std::vector< pj::CodecInfo >::iterator arg3 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  swig::SwigPyIterator *iter2 = 0 ;
  int res2 ;
  swig::SwigPyIterator *iter3 = 0 ;
  int res3 ;
  std::vector< pj::CodecInfo >::iterator result;
  
  if ((nobjs < 3) || (nobjs > 3)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__vectorT_pj__CodecInfo_std__allocatorT_pj__CodecInfo_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "CodecInfoVector2_erase" "', argument " "1"" of type '" "std::vector< pj::CodecInfo > *""'"); 
  }
  arg1 = reinterpret_cast< std::vector< pj::CodecInfo > * >(argp1);
  res2 = SWIG_ConvertPtr(swig_obj[1], SWIG_as_voidptrptr(&iter2), swig::SwigPyIterator::descriptor(), 0);
  if (!SWIG_IsOK(res2) || !iter2) {
    SWIG_exception_fail(SWIG_ArgError(SWIG_TypeError), "in method '" "CodecInfoVector2_erase" "', argument " "2"" of type '" "std::vector< pj::CodecInfo >::iterator""'");
  } else {
    swig::SwigPyIterator_T<std::vector< pj::CodecInfo >::iterator > *iter_t = dynamic_cast<swig::SwigPyIterator_T<std::vector< pj::CodecInfo >::iterator > *>(iter2);
    if (iter_t) {
      arg2 = iter_t->get_current();
    } else {
      SWIG_exception_fail(SWIG_ArgError(SWIG_TypeError), "in method '" "CodecInfoVector2_erase" "', argument " "2"" of type '" "std::vector< pj::CodecInfo >::iterator""'");
    }
  }
  res3 = SWIG_ConvertPtr(swig_obj[2], SWIG_as_voidptrptr(&iter3), swig::SwigPyIterator::descriptor(), 0);
  if (!SWIG_IsOK(res3) || !iter3) {
    SWIG_exception_fail(SWIG_ArgError(SWIG_TypeError), "in method '" "CodecInfoVector2_erase" "', argument " "3"" of type '" "std::vector< pj::CodecInfo >::iterator""'");
  } else {
    swig::SwigPyIterator_T<std::vector< pj::CodecInfo >::iterator > *iter_t = dynamic_cast<swig::SwigPyIterator_T<std::vector< pj::CodecInfo >::iterator > *>(iter3);
    if (iter_t) {
      arg3 = iter_t->get_current();
    } else {
      SWIG_exception_fail(SWIG_ArgError(SWIG_TypeError), "in method '" "CodecInfoVector2_erase" "', argument " "3"" of type '" "std::vector< pj::CodecInfo >::iterator""'");
    }
  }
  result = std_vector_Sl_pj_CodecInfo_Sg__erase__SWIG_1(arg1,arg2,arg3);
  resultobj = SWIG_NewPointerObj(swig::make_output_iterator(static_cast< const std::vector< pj::CodecInfo >::iterator & >(result)),
    swig::SwigPyIterator::descriptor(),SWIG_POINTER_OWN);
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_CodecInfoVector2_erase(PyObject *self, PyObject *args) {
  Py_ssize_t argc;
  PyObject *argv[4] = {
    0
  };
  
  if (!(argc = SWIG_Python_UnpackTuple(args, "CodecInfoVector2_erase", 0, 3, argv))) SWIG_fail;
  --argc;
  if (argc == 2) {
    int _v;
    int res = swig::asptr(argv[0], (std::vector< pj::CodecInfo,std::allocator< pj::CodecInfo > >**)(0));
    _v = SWIG_CheckState(res);
    if (_v) {
      swig::SwigPyIterator *iter = 0;
      int res = SWIG_ConvertPtr(argv[1], SWIG_as_voidptrptr(&iter), swig::SwigPyIterator::descriptor(), 0);
      _v = (SWIG_IsOK(res) && iter && (dynamic_cast<swig::SwigPyIterator_T<std::vector< pj::CodecInfo >::iterator > *>(iter) != 0));
      if (_v) {
        return _wrap_CodecInfoVector2_erase__SWIG_0(self, argc, argv);
      }
    }
  }
  if (argc == 3) {
    int _v;
    int res = swig::asptr(argv[0], (std::vector< pj::CodecInfo,std::allocator< pj::CodecInfo > >**)(0));
    _v = SWIG_CheckState(res);
    if (_v) {
      swig::SwigPyIterator *iter = 0;
      int res = SWIG_ConvertPtr(argv[1], SWIG_as_voidptrptr(&iter), swig::SwigPyIterator::descriptor(), 0);
      _v = (SWIG_IsOK(res) && iter && (dynamic_cast<swig::SwigPyIterator_T<std::vector< pj::CodecInfo >::iterator > *>(iter) != 0));
      if (_v) {
        swig::SwigPyIterator *iter = 0;
        int res = SWIG_ConvertPtr(argv[2], SWIG_as_voidptrptr(&iter), swig::SwigPyIterator::descriptor(), 0);
        _v = (SWIG_IsOK(res) && iter && (dynamic_cast<swig::SwigPyIterator_T<std::vector< pj::CodecInfo >::iterator > *>(iter) != 0));
        if (_v) {
          return _wrap_CodecInfoVector2_erase__SWIG_1(self, argc, argv);
        }
      }
    }
  }
  
fail:
  SWIG_Python_RaiseOrModifyTypeError("Wrong number or type of arguments for overloaded function 'CodecInfoVector2_erase'.\n"
    "  Possible C/C++ prototypes are:\n"
    "    std::vector< pj::CodecInfo >::erase(std::vector< pj::CodecInfo >::iterator)\n"
    "    std::vector< pj::CodecInfo >::erase(std::vector< pj::CodecInfo >::iterator,std::vector< pj::CodecInfo >::iterator)\n");
  return 0;
}


SWIGINTERN PyObject *_wrap_new_CodecInfoVector2__SWIG_3(PyObject *SWIGUNUSEDPARM(self), Py_ssize_t nobjs, PyObject **swig_obj) {
  PyObject *resultobj = 0;
  std::vector< pj::CodecInfo >::size_type arg1 ;
  std::vector< pj::CodecInfo >::value_type *arg2 = 0 ;
  size_t val1 ;
  int ecode1 = 0 ;
  void *argp2 = 0 ;
  int res2 = 0 ;
  std::vector< pj::CodecInfo > *result = 0 ;
  
  if ((nobjs < 2) || (nobjs > 2)) SWIG_fail;
  ecode1 = SWIG_AsVal_size_t(swig_obj[0], &val1);
  if (!SWIG_IsOK(ecode1)) {
    SWIG_exception_fail(SWIG_ArgError(ecode1), "in method '" "new_CodecInfoVector2" "', argument " "1"" of type '" "std::vector< pj::CodecInfo >::size_type""'");
  } 
  arg1 = static_cast< std::vector< pj::CodecInfo >::size_type >(val1);
  res2 = SWIG_ConvertPtr(swig_obj[1], &argp2, SWIGTYPE_p_pj__CodecInfo,  0  | 0);
  if (!SWIG_IsOK(res2)) {
    SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "new_CodecInfoVector2" "', argument " "2"" of type '" "std::vector< pj::CodecInfo >::value_type const &""'"); 
  }
  if (!argp2) {
    SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "new_CodecInfoVector2" "', argument " "2"" of type '" "std::vector< pj::CodecInfo >::value_type const &""'"); 
  }
  arg2 = reinterpret_cast< std::vector< pj::CodecInfo >::value_type * >(argp2);
  result = (std::vector< pj::CodecInfo > *)new std::vector< pj::CodecInfo >(arg1,(std::vector< pj::CodecInfo >::value_type const &)*arg2);
  resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(result), SWIGTYPE_p_std__vectorT_pj__CodecInfo_std__allocatorT_pj__CodecInfo_t_t, SWIG_POINTER_NEW |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_new_CodecInfoVector2(PyObject *self, PyObject *args) {
  Py_ssize_t argc;
  PyObject *argv[3] = {
    0
  };
  
  if (!(argc = SWIG_Python_UnpackTuple(args, "new_CodecInfoVector2", 0, 2, argv))) SWIG_fail;
  --argc;
  if (argc == 0) {
    return _wrap_new_CodecInfoVector2__SWIG_0(self, argc, argv);
  }
  if (argc == 1) {
    int _v;
    {
      int res = SWIG_AsVal_size_t(argv[0], NULL);
      _v = SWIG_CheckState(res);
    }
    if (_v) {
      return _wrap_new_CodecInfoVector2__SWIG_2(self, argc, argv);
    }
  }
  if (argc == 1) {
    int _v;
    int res = swig::asptr(argv[0], (std::vector< pj::CodecInfo,std::allocator< pj::CodecInfo > >**)(0));
    _v = SWIG_CheckState(res);
    if (_v) {
      return _wrap_new_CodecInfoVector2__SWIG_1(self, argc, argv);
    }
  }
  if (argc == 2) {
    int _v;
    {
      int res = SWIG_AsVal_size_t(argv[0], NULL);
      _v = SWIG_CheckState(res);
    }
    if (_v) {
      int res = SWIG_ConvertPtr(argv[1], 0, SWIGTYPE_p_pj__CodecInfo, SWIG_POINTER_NO_NULL | 0);
      _v = SWIG_CheckState(res);
      if (_v) {
        return _wrap_new_CodecInfoVector2__SWIG_3(self, argc, argv);
      }
    }
  }
  
fail:
  SWIG_Python_RaiseOrModifyTypeError("Wrong number or type of arguments for overloaded function 'new_CodecInfoVector2'.\n"
    "  Possible C/C++ prototypes are:\n"
    "    std::vector< pj::CodecInfo >::vector()\n"
    "    std::vector< pj::CodecInfo >::vector(std::vector< pj::CodecInfo > const &)\n"
    "    std::vector< pj::CodecInfo >::vector(std::vector< pj::CodecInfo >::size_type)\n"
    "    std::vector< pj::CodecInfo >::vector(std::vector< pj::CodecInfo >::size_type,std::vector< pj::CodecInfo >::value_type const &)\n");
  return 0;
}


SWIGINTERN PyObject *_wrap_CodecInfoVector2_push_back(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  std::vector< pj::CodecInfo > *arg1 = (std::vector< pj::CodecInfo > *) 0 ;
  std::vector< pj::CodecInfo >::value_type *arg2 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  void *argp2 = 0 ;
  int res2 = 0 ;
  PyObject *swig_obj[2] ;
  
  if (!SWIG_Python_UnpackTuple(args, "CodecInfoVector2_push_back", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__vectorT_pj__CodecInfo_std__allocatorT_pj__CodecInfo_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "CodecInfoVector2_push_back" "', argument " "1"" of type '" "std::vector< pj::CodecInfo > *""'"); 
  }
  arg1 = reinterpret_cast< std::vector< pj::CodecInfo > * >(argp1);
  res2 = SWIG_ConvertPtr(swig_obj[1], &argp2, SWIGTYPE_p_pj__CodecInfo,  0  | 0);
  if (!SWIG_IsOK(res2)) {
    SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "CodecInfoVector2_push_back" "', argument " "2"" of type '" "std::vector< pj::CodecInfo >::value_type const &""'"); 
  }
  if (!argp2) {
    SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "CodecInfoVector2_push_back" "', argument " "2"" of type '" "std::vector< pj::CodecInfo >::value_type const &""'"); 
  }
  arg2 = reinterpret_cast< std::vector< pj::CodecInfo >::value_type * >(argp2);
  (arg1)->push_back((std::vector< pj::CodecInfo >::value_type const &)*arg2);
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_CodecInfoVector2_front(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  std::vector< pj::CodecInfo > *arg1 = (std::vector< pj::CodecInfo > *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  std::vector< pj::CodecInfo >::value_type *result = 0 ;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__vectorT_pj__CodecInfo_std__allocatorT_pj__CodecInfo_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "CodecInfoVector2_front" "', argument " "1"" of type '" "std::vector< pj::CodecInfo > const *""'"); 
  }
  arg1 = reinterpret_cast< std::vector< pj::CodecInfo > * >(argp1);
  result = (std::vector< pj::CodecInfo >::value_type *) &((std::vector< pj::CodecInfo > const *)arg1)->front();
  resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(result), SWIGTYPE_p_pj__CodecInfo, 0 |  0 );
  (void)swig::container_owner<swig::traits<std::vector< pj::CodecInfo >::value_type>::category>::back_reference(resultobj, swig_obj[0]);
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_CodecInfoVector2_back(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  std::vector< pj::CodecInfo > *arg1 = (std::vector< pj::CodecInfo > *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  std::vector< pj::CodecInfo >::value_type *result = 0 ;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__vectorT_pj__CodecInfo_std__allocatorT_pj__CodecInfo_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "CodecInfoVector2_back" "', argument " "1"" of type '" "std::vector< pj::CodecInfo > const *""'"); 
  }
  arg1 = reinterpret_cast< std::vector< pj::CodecInfo > * >(argp1);
  result = (std::vector< pj::CodecInfo >::value_type *) &((std::vector< pj::CodecInfo > const *)arg1)->back();
  resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(result), SWIGTYPE_p_pj__CodecInfo, 0 |  0 );
  (void)swig::container_owner<swig::traits<std::vector< pj::CodecInfo >::value_type>::category>::back_reference(resultobj, swig_obj[0]);
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_CodecInfoVector2_assign(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  std::vector< pj::CodecInfo > *arg1 = (std::vector< pj::CodecInfo > *) 0 ;
  std::vector< pj::CodecInfo >::size_type arg2 ;
  std::vector< pj::CodecInfo >::value_type *arg3 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  size_t val2 ;
  int ecode2 = 0 ;
  void *argp3 = 0 ;
  int res3 = 0 ;
  PyObject *swig_obj[3] ;
  
  if (!SWIG_Python_UnpackTuple(args, "CodecInfoVector2_assign", 3, 3, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__vectorT_pj__CodecInfo_std__allocatorT_pj__CodecInfo_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "CodecInfoVector2_assign" "', argument " "1"" of type '" "std::vector< pj::CodecInfo > *""'"); 
  }
  arg1 = reinterpret_cast< std::vector< pj::CodecInfo > * >(argp1);
  ecode2 = SWIG_AsVal_size_t(swig_obj[1], &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "CodecInfoVector2_assign" "', argument " "2"" of type '" "std::vector< pj::CodecInfo >::size_type""'");
  } 
  arg2 = static_cast< std::vector< pj::CodecInfo >::size_type >(val2);
  res3 = SWIG_ConvertPtr(swig_obj[2], &argp3, SWIGTYPE_p_pj__CodecInfo,  0  | 0);
  if (!SWIG_IsOK(res3)) {
    SWIG_exception_fail(SWIG_ArgError(res3), "in method '" "CodecInfoVector2_assign" "', argument " "3"" of type '" "std::vector< pj::CodecInfo >::value_type const &""'"); 
  }
  if (!argp3) {
    SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "CodecInfoVector2_assign" "', argument " "3"" of type '" "std::vector< pj::CodecInfo >::value_type const &""'"); 
  }
  arg3 = reinterpret_cast< std::vector< pj::CodecInfo >::value_type * >(argp3);
  (arg1)->assign(arg2,(std::vector< pj::CodecInfo >::value_type const &)*arg3);
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_CodecInfoVector2_resize__SWIG_1(PyObject *SWIGUNUSEDPARM(self), Py_ssize_t nobjs, PyObject **swig_obj) {
  PyObject *resultobj = 0;
  std::vector< pj::CodecInfo > *arg1 = (std::vector< pj::CodecInfo > *) 0 ;
  std::vector< pj::CodecInfo >::size_type arg2 ;
  std::vector< pj::CodecInfo >::value_type *arg3 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  size_t val2 ;
  int ecode2 = 0 ;
  void *argp3 = 0 ;
  int res3 = 0 ;
  
  if ((nobjs < 3) || (nobjs > 3)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__vectorT_pj__CodecInfo_std__allocatorT_pj__CodecInfo_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "CodecInfoVector2_resize" "', argument " "1"" of type '" "std::vector< pj::CodecInfo > *""'"); 
  }
  arg1 = reinterpret_cast< std::vector< pj::CodecInfo > * >(argp1);
  ecode2 = SWIG_AsVal_size_t(swig_obj[1], &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "CodecInfoVector2_resize" "', argument " "2"" of type '" "std::vector< pj::CodecInfo >::size_type""'");
  } 
  arg2 = static_cast< std::vector< pj::CodecInfo >::size_type >(val2);
  res3 = SWIG_ConvertPtr(swig_obj[2], &argp3, SWIGTYPE_p_pj__CodecInfo,  0  | 0);
  if (!SWIG_IsOK(res3)) {
    SWIG_exception_fail(SWIG_ArgError(res3), "in method '" "CodecInfoVector2_resize" "', argument " "3"" of type '" "std::vector< pj::CodecInfo >::value_type const &""'"); 
  }
  if (!argp3) {
    SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "CodecInfoVector2_resize" "', argument " "3"" of type '" "std::vector< pj::CodecInfo >::value_type const &""'"); 
  }
  arg3 = reinterpret_cast< std::vector< pj::CodecInfo >::value_type * >(argp3);
  (arg1)->resize(arg2,(std::vector< pj::CodecInfo >::value_type const &)*arg3);
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_CodecInfoVector2_resize(PyObject *self, PyObject *args) {
  Py_ssize_t argc;
  PyObject *argv[4] = {
    0
  };
  
  if (!(argc = SWIG_Python_UnpackTuple(args, "CodecInfoVector2_resize", 0, 3, argv))) SWIG_fail;
  --argc;
  if (argc == 2) {
    int _v;
    int res = swig::asptr(argv[0], (std::vector< pj::CodecInfo,std::allocator< pj::CodecInfo > >**)(0));
    _v = SWIG_CheckState(res);
    if (_v) {
      {
        int res = SWIG_AsVal_size_t(argv[1], NULL);
        _v = SWIG_CheckState(res);
      }
      if (_v) {
        return _wrap_CodecInfoVector2_resize__SWIG_0(self, argc, argv);
      }
    }
  }
  if (argc == 3) {
    int _v;
    int res = swig::asptr(argv[0], (std::vector< pj::CodecInfo,std::allocator< pj::CodecInfo > >**)(0));
    _v = SWIG_CheckState(res);
    if (_v) {
      {
        int res = SWIG_AsVal_size_t(argv[1], NULL);
        _v = SWIG_CheckState(res);
      }
      if (_v) {
        int res = SWIG_ConvertPtr(argv[2], 0, SWIGTYPE_p_pj__CodecInfo, SWIG_POINTER_NO_NULL | 0);
        _v = SWIG_CheckState(res);
        if (_v) {
          return _wrap_CodecInfoVector2_resize__SWIG_1(self, argc, argv);
        }
      }
    }
  }
  
fail:
  SWIG_Python_RaiseOrModifyTypeError("Wrong number or type of arguments for overloaded function 'CodecInfoVector2_resize'.\n"
    "  Possible C/C++ prototypes are:\n"
    "    std::vector< pj::CodecInfo >::resize(std::vector< pj::CodecInfo >::size_type)\n"
    "    std::vector< pj::CodecInfo >::resize(std::vector< pj::CodecInfo >::size_type,std::vector< pj::CodecInfo >::value_type const &)\n");
  return 0;
}


SWIGINTERN PyObject *_wrap_CodecInfoVector2_insert__SWIG_0(PyObject *SWIGUNUSEDPARM(self), Py_ssize_t nobjs, PyObject **swig_obj) {
  PyObject *resultobj = 0;
  std::vector< pj::CodecInfo > *arg1 = (std::vector< pj::CodecInfo > *) 0 ;
  std::vector< pj::CodecInfo >::iterator arg2 ;
  std::vector< pj::CodecInfo >::value_type *arg3 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  swig::SwigPyIterator *iter2 = 0 ;
  int res2 ;
  void *argp3 = 0 ;
  int res3 = 0 ;
  std::vector< pj::CodecInfo >::iterator result;
  
  if ((nobjs < 3) || (nobjs > 3)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__vectorT_pj__CodecInfo_std__allocatorT_pj__CodecInfo_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "CodecInfoVector2_insert" "', argument " "1"" of type '" "std::vector< pj::CodecInfo > *""'"); 
  }
  arg1 = reinterpret_cast< std::vector< pj::CodecInfo > * >(argp1);
  res2 = SWIG_ConvertPtr(swig_obj[1], SWIG_as_voidptrptr(&iter2), swig::SwigPyIterator::descriptor(), 0);
  if (!SWIG_IsOK(res2) || !iter2) {
    SWIG_exception_fail(SWIG_ArgError(SWIG_TypeError), "in method '" "CodecInfoVector2_insert" "', argument " "2"" of type '" "std::vector< pj::CodecInfo >::iterator""'");
  } else {
    swig::SwigPyIterator_T<std::vector< pj::CodecInfo >::iterator > *iter_t = dynamic_cast<swig::SwigPyIterator_T<std::vector< pj::CodecInfo >::iterator > *>(iter2);
    if (iter_t) {
      arg2 = iter_t->get_current();
    } else {
      SWIG_exception_fail(SWIG_ArgError(SWIG_TypeError), "in method '" "CodecInfoVector2_insert" "', argument " "2"" of type '" "std::vector< pj::CodecInfo >::iterator""'");
    }
  }
  res3 = SWIG_ConvertPtr(swig_obj[2], &argp3, SWIGTYPE_p_pj__CodecInfo,  0  | 0);
  if (!SWIG_IsOK(res3)) {
    SWIG_exception_fail(SWIG_ArgError(res3), "in method '" "CodecInfoVector2_insert" "', argument " "3"" of type '" "std::vector< pj::CodecInfo >::value_type const &""'"); 
  }
  if (!argp3) {
    SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "CodecInfoVector2_insert" "', argument " "3"" of type '" "std::vector< pj::CodecInfo >::value_type const &""'"); 
  }
  arg3 = reinterpret_cast< std::vector< pj::CodecInfo >::value_type * >(argp3);
  result = std_vector_Sl_pj_CodecInfo_Sg__insert__SWIG_0(arg1,arg2,(pj::CodecInfo const &)*arg3);
  resultobj = SWIG_NewPointerObj(swig::make_output_iterator(static_cast< const std::vector< pj::CodecInfo >::iterator & >(result)),
    swig::SwigPyIterator::descriptor(),SWIG_POINTER_OWN);
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_CodecInfoVector2_insert__SWIG_1(PyObject *SWIGUNUSEDPARM(self), Py_ssize_t nobjs, PyObject **swig_obj) {
  PyObject *resultobj = 0;
  std::vector< pj::CodecInfo > *arg1 = (std::vector< pj::CodecInfo > *) 0 ;
  std::vector< pj::CodecInfo >::iterator arg2 ;
  std::vector< pj::CodecInfo >::size_type arg3 ;
  std::vector< pj::CodecInfo >::value_type *arg4 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  swig::SwigPyIterator *iter2 = 0 ;
  int res2 ;
  size_t val3 ;
  int ecode3 = 0 ;
  void *argp4 = 0 ;
  int res4 = 0 ;
  
  if ((nobjs < 4) || (nobjs > 4)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__vectorT_pj__CodecInfo_std__allocatorT_pj__CodecInfo_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "CodecInfoVector2_insert" "', argument " "1"" of type '" "std::vector< pj::CodecInfo > *""'"); 
  }
  arg1 = reinterpret_cast< std::vector< pj::CodecInfo > * >(argp1);
  res2 = SWIG_ConvertPtr(swig_obj[1], SWIG_as_voidptrptr(&iter2), swig::SwigPyIterator::descriptor(), 0);
  if (!SWIG_IsOK(res2) || !iter2) {
    SWIG_exception_fail(SWIG_ArgError(SWIG_TypeError), "in method '" "CodecInfoVector2_insert" "', argument " "2"" of type '" "std::vector< pj::CodecInfo >::iterator""'");
  } else {
    swig::SwigPyIterator_T<std::vector< pj::CodecInfo >::iterator > *iter_t = dynamic_cast<swig::SwigPyIterator_T<std::vector< pj::CodecInfo >::iterator > *>(iter2);
    if (iter_t) {
      arg2 = iter_t->get_current();
    } else {
      SWIG_exception_fail(SWIG_ArgError(SWIG_TypeError), "in method '" "CodecInfoVector2_insert" "', argument " "2"" of type '" "std::vector< pj::CodecInfo >::iterator""'");
    }
  }
  ecode3 = SWIG_AsVal_size_t(swig_obj[2], &val3);
  if (!SWIG_IsOK(ecode3)) {
    SWIG_exception_fail(SWIG_ArgError(ecode3), "in method '" "CodecInfoVector2_insert" "', argument " "3"" of type '" "std::vector< pj::CodecInfo >::size_type""'");
  } 
  arg3 = static_cast< std::vector< pj::CodecInfo >::size_type >(val3);
  res4 = SWIG_ConvertPtr(swig_obj[3], &argp4, SWIGTYPE_p_pj__CodecInfo,  0  | 0);
  if (!SWIG_IsOK(res4)) {
    SWIG_exception_fail(SWIG_ArgError(res4), "in method '" "CodecInfoVector2_insert" "', argument " "4"" of type '" "std::vector< pj::CodecInfo >::value_type const &""'"); 
  }
  if (!argp4) {
    SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "CodecInfoVector2_insert" "', argument " "4"" of type '" "std::vector< pj::CodecInfo >::value_type const &""'"); 
  }
  arg4 = reinterpret_cast< std::vector< pj::CodecInfo >::value_type * >(argp4);
  std_vector_Sl_pj_CodecInfo_Sg__insert__SWIG_1(arg1,arg2,arg3,(pj::CodecInfo const &)*arg4);
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_CodecInfoVector2_insert(PyObject *self, PyObject *args) {
  Py_ssize_t argc;
  PyObject *argv[5] = {
    0
  };
  
  if (!(argc = SWIG_Python_UnpackTuple(args, "CodecInfoVector2_insert", 0, 4, argv))) SWIG_fail;
  --argc;
  if (argc == 3) {
    int _v;
    int res = swig::asptr(argv[0], (std::vector< pj::CodecInfo,std::allocator< pj::CodecInfo > >**)(0));
    _v = SWIG_CheckState(res);
    if (_v) {
      swig::SwigPyIterator *iter = 0;
      int res = SWIG_ConvertPtr(argv[1], SWIG_as_voidptrptr(&iter), swig::SwigPyIterator::descriptor(), 0);
      _v = (SWIG_IsOK(res) && iter && (dynamic_cast<swig::SwigPyIterator_T<std::vector< pj::CodecInfo >::iterator > *>(iter) != 0));
      if (_v) {
        int res = SWIG_ConvertPtr(argv[2], 0, SWIGTYPE_p_pj__CodecInfo, SWIG_POINTER_NO_NULL | 0);
        _v = SWIG_CheckState(res);
        if (_v) {
          return _wrap_CodecInfoVector2_insert__SWIG_0(self, argc, argv);
        }
      }
    }
  }
  if (argc == 4) {
    int _v;
    int res = swig::asptr(argv[0], (std::vector< pj::CodecInfo,std::allocator< pj::CodecInfo > >**)(0));
    _v = SWIG_CheckState(res);
    if (_v) {
      swig::SwigPyIterator *iter = 0;
      int res = SWIG_ConvertPtr(argv[1], SWIG_as_voidptrptr(&iter), swig::SwigPyIterator::descriptor(), 0);
      _v = (SWIG_IsOK(res) && iter && (dynamic_cast<swig::SwigPyIterator_T<std::vector< pj::CodecInfo >::iterator > *>(iter) != 0));
      if (_v) {
        {
          int res = SWIG_AsVal_size_t(argv[2], NULL);
          _v = SWIG_CheckState(res);
        }
        if (_v) {
          int res = SWIG_ConvertPtr(argv[3], 0, SWIGTYPE_p_pj__CodecInfo, SWIG_POINTER_NO_NULL | 0);
          _v = SWIG_CheckState(res);
          if (_v) {
            return _wrap_CodecInfoVector2_insert__SWIG_1(self, argc, argv);
          }
        }
      }
    }
  }
  
fail:
  SWIG_Python_RaiseOrModifyTypeError("Wrong number or type of arguments for overloaded function 'CodecInfoVector2_insert'.\n"
    "  Possible C/C++ prototypes are:\n"
    "    std::vector< pj::CodecInfo >::insert(std::vector< pj::CodecInfo >::iterator,std::vector< pj::CodecInfo >::value_type const &)\n"
    "    std::vector< pj::CodecInfo >::insert(std::vector< pj::CodecInfo >::iterator,std::vector< pj::CodecInfo >::size_type,std::vector< pj::CodecInfo >::value_type const &)\n");
  return 0;
}


SWIGINTERN PyObject *_wrap_CodecInfoVector2_reserve(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  std::vector< pj::CodecInfo > *arg1 = (std::vector< pj::CodecInfo > *) 0 ;
  std::vector< pj::CodecInfo >::size_type arg2 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  size_t val2 ;
  int ecode2 = 0 ;
  PyObject *swig_obj[2] ;
  
  if (!SWIG_Python_UnpackTuple(args, "CodecInfoVector2_reserve", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__vectorT_pj__CodecInfo_std__allocatorT_pj__CodecInfo_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "CodecInfoVector2_reserve" "', argument " "1"" of type '" "std::vector< pj::CodecInfo > *""'"); 
  }
  arg1 = reinterpret_cast< std::vector< pj::CodecInfo > * >(argp1);
  ecode2 = SWIG_AsVal_size_t(swig_obj[1], &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "CodecInfoVector2_reserve" "', argument " "2"" of type '" "std::vector< pj::CodecInfo >::size_type""'");
  } 
  arg2 = static_cast< std::vector< pj::CodecInfo >::size_type >(val2);
  (arg1)->reserve(arg2);
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_CodecInfoVector2_capacity(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  std::vector< pj::CodecInfo > *arg1 = (std::vector< pj::CodecInfo > *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  std::vector< pj::CodecInfo >::size_type result;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__vectorT_pj__CodecInfo_std__allocatorT_pj__CodecInfo_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "CodecInfoVector2_capacity" "', argument " "1"" of type '" "std::vector< pj::CodecInfo > const *""'"); 
  }
  arg1 = reinterpret_cast< std::vector< pj::CodecInfo > * >(argp1);
  result = ((std::vector< pj::CodecInfo > const *)arg1)->capacity();
  resultobj = SWIG_From_size_t(static_cast< size_t >(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_delete_CodecInfoVector2(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  std::vector< pj::CodecInfo > *arg1 = (std::vector< pj::CodecInfo > *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__vectorT_pj__CodecInfo_std__allocatorT_pj__CodecInfo_t_t, SWIG_POINTER_DISOWN |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "delete_CodecInfoVector2" "', argument " "1"" of type '" "std::vector< pj::CodecInfo > *""'"); 
  }
  arg1 = reinterpret_cast< std::vector< pj::CodecInfo > * >(argp1);
  delete arg1;
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *CodecInfoVector2_swigregister(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *obj;
  if (!SWIG_Python_UnpackTuple(args, "swigregister", 1, 1, &obj)) return NULL;
  SWIG_TypeNewClientData(SWIGTYPE_p_std__vectorT_pj__CodecInfo_std__allocatorT_pj__CodecInfo_t_t, SWIG_NewClientData(obj));
  return SWIG_Py_Void();
}

SWIGINTERN PyObject *CodecInfoVector2_swiginit(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  return SWIG_Python_InitShadowInstance(args);
}

SWIGINTERN PyObject *_wrap_VideoDevInfoVector_iterator(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  std::vector< pj::VideoDevInfo * > *arg1 = (std::vector< pj::VideoDevInfo * > *) 0 ;
  PyObject **arg2 = (PyObject **) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  swig::SwigPyIterator *result = 0 ;
  
  arg2 = &swig_obj[0];
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__vectorT_pj__VideoDevInfo_p_std__allocatorT_pj__VideoDevInfo_p_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "VideoDevInfoVector_iterator" "', argument " "1"" of type '" "std::vector< pj::VideoDevInfo * > *""'"); 
  }
  arg1 = reinterpret_cast< std::vector< pj::VideoDevInfo * > * >(argp1);
  result = (swig::SwigPyIterator *)std_vector_Sl_pj_VideoDevInfo_Sm__Sg__iterator(arg1,arg2);
  resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(result), SWIGTYPE_p_swig__SwigPyIterator, SWIG_POINTER_OWN |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_VideoDevInfoVector___nonzero__(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  std::vector< pj::VideoDevInfo * > *arg1 = (std::vector< pj::VideoDevInfo * > *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  bool result;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__vectorT_pj__VideoDevInfo_p_std__allocatorT_pj__VideoDevInfo_p_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "VideoDevInfoVector___nonzero__" "', argument " "1"" of type '" "std::vector< pj::VideoDevInfo * > const *""'"); 
  }
  arg1 = reinterpret_cast< std::vector< pj::VideoDevInfo * > * >(argp1);
  result = (bool)std_vector_Sl_pj_VideoDevInfo_Sm__Sg____nonzero__((std::vector< pj::VideoDevInfo * > const *)arg1);
  resultobj = SWIG_From_bool(static_cast< bool >(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_VideoDevInfoVector___bool__(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  std::vector< pj::VideoDevInfo * > *arg1 = (std::vector< pj::VideoDevInfo * > *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  bool result;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__vectorT_pj__VideoDevInfo_p_std__allocatorT_pj__VideoDevInfo_p_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "VideoDevInfoVector___bool__" "', argument " "1"" of type '" "std::vector< pj::VideoDevInfo * > const *""'"); 
  }
  arg1 = reinterpret_cast< std::vector< pj::VideoDevInfo * > * >(argp1);
  result = (bool)std_vector_Sl_pj_VideoDevInfo_Sm__Sg____bool__((std::vector< pj::VideoDevInfo * > const *)arg1);
  resultobj = SWIG_From_bool(static_cast< bool >(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_VideoDevInfoVector___len__(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  std::vector< pj::VideoDevInfo * > *arg1 = (std::vector< pj::VideoDevInfo * > *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  std::vector< pj::VideoDevInfo * >::size_type result;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__vectorT_pj__VideoDevInfo_p_std__allocatorT_pj__VideoDevInfo_p_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "VideoDevInfoVector___len__" "', argument " "1"" of type '" "std::vector< pj::VideoDevInfo * > const *""'"); 
  }
  arg1 = reinterpret_cast< std::vector< pj::VideoDevInfo * > * >(argp1);
  result = std_vector_Sl_pj_VideoDevInfo_Sm__Sg____len__((std::vector< pj::VideoDevInfo * > const *)arg1);
  resultobj = SWIG_From_size_t(static_cast< size_t >(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_VideoDevInfoVector___getslice__(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  std::vector< pj::VideoDevInfo * > *arg1 = (std::vector< pj::VideoDevInfo * > *) 0 ;
  std::vector< pj::VideoDevInfo * >::difference_type arg2 ;
  std::vector< pj::VideoDevInfo * >::difference_type arg3 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  ptrdiff_t val2 ;
  int ecode2 = 0 ;
  ptrdiff_t val3 ;
  int ecode3 = 0 ;
  PyObject *swig_obj[3] ;
  std::vector< pj::VideoDevInfo *,std::allocator< pj::VideoDevInfo * > > *result = 0 ;
  
  if (!SWIG_Python_UnpackTuple(args, "VideoDevInfoVector___getslice__", 3, 3, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__vectorT_pj__VideoDevInfo_p_std__allocatorT_pj__VideoDevInfo_p_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "VideoDevInfoVector___getslice__" "', argument " "1"" of type '" "std::vector< pj::VideoDevInfo * > *""'"); 
  }
  arg1 = reinterpret_cast< std::vector< pj::VideoDevInfo * > * >(argp1);
  ecode2 = SWIG_AsVal_ptrdiff_t(swig_obj[1], &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "VideoDevInfoVector___getslice__" "', argument " "2"" of type '" "std::vector< pj::VideoDevInfo * >::difference_type""'");
  } 
  arg2 = static_cast< std::vector< pj::VideoDevInfo * >::difference_type >(val2);
  ecode3 = SWIG_AsVal_ptrdiff_t(swig_obj[2], &val3);
  if (!SWIG_IsOK(ecode3)) {
    SWIG_exception_fail(SWIG_ArgError(ecode3), "in method '" "VideoDevInfoVector___getslice__" "', argument " "3"" of type '" "std::vector< pj::VideoDevInfo * >::difference_type""'");
  } 
  arg3 = static_cast< std::vector< pj::VideoDevInfo * >::difference_type >(val3);
  try {
    result = (std::vector< pj::VideoDevInfo *,std::allocator< pj::VideoDevInfo * > > *)std_vector_Sl_pj_VideoDevInfo_Sm__Sg____getslice__(arg1,arg2,arg3);
  } catch(std::out_of_range &_e) {
    SWIG_exception_fail(SWIG_IndexError, (&_e)->what());
  } catch(std::invalid_argument &_e) {
    SWIG_exception_fail(SWIG_ValueError, (&_e)->what());
  }
  resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(result), SWIGTYPE_p_std__vectorT_pj__VideoDevInfo_p_std__allocatorT_pj__VideoDevInfo_p_t_t, SWIG_POINTER_OWN |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_VideoDevInfoVector___setslice____SWIG_0(PyObject *SWIGUNUSEDPARM(self), Py_ssize_t nobjs, PyObject **swig_obj) {
  PyObject *resultobj = 0;
  std::vector< pj::VideoDevInfo * > *arg1 = (std::vector< pj::VideoDevInfo * > *) 0 ;
  std::vector< pj::VideoDevInfo * >::difference_type arg2 ;
  std::vector< pj::VideoDevInfo * >::difference_type arg3 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  ptrdiff_t val2 ;
  int ecode2 = 0 ;
  ptrdiff_t val3 ;
  int ecode3 = 0 ;
  
  if ((nobjs < 3) || (nobjs > 3)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__vectorT_pj__VideoDevInfo_p_std__allocatorT_pj__VideoDevInfo_p_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "VideoDevInfoVector___setslice__" "', argument " "1"" of type '" "std::vector< pj::VideoDevInfo * > *""'"); 
  }
  arg1 = reinterpret_cast< std::vector< pj::VideoDevInfo * > * >(argp1);
  ecode2 = SWIG_AsVal_ptrdiff_t(swig_obj[1], &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "VideoDevInfoVector___setslice__" "', argument " "2"" of type '" "std::vector< pj::VideoDevInfo * >::difference_type""'");
  } 
  arg2 = static_cast< std::vector< pj::VideoDevInfo * >::difference_type >(val2);
  ecode3 = SWIG_AsVal_ptrdiff_t(swig_obj[2], &val3);
  if (!SWIG_IsOK(ecode3)) {
    SWIG_exception_fail(SWIG_ArgError(ecode3), "in method '" "VideoDevInfoVector___setslice__" "', argument " "3"" of type '" "std::vector< pj::VideoDevInfo * >::difference_type""'");
  } 
  arg3 = static_cast< std::vector< pj::VideoDevInfo * >::difference_type >(val3);
  try {
    std_vector_Sl_pj_VideoDevInfo_Sm__Sg____setslice____SWIG_0(arg1,arg2,arg3);
  } catch(std::out_of_range &_e) {
    SWIG_exception_fail(SWIG_IndexError, (&_e)->what());
  } catch(std::invalid_argument &_e) {
    SWIG_exception_fail(SWIG_ValueError, (&_e)->what());
  }
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_VideoDevInfoVector___setslice____SWIG_1(PyObject *SWIGUNUSEDPARM(self), Py_ssize_t nobjs, PyObject **swig_obj) {
  PyObject *resultobj = 0;
  std::vector< pj::VideoDevInfo * > *arg1 = (std::vector< pj::VideoDevInfo * > *) 0 ;
  std::vector< pj::VideoDevInfo * >::difference_type arg2 ;
  std::vector< pj::VideoDevInfo * >::difference_type arg3 ;
  std::vector< pj::VideoDevInfo *,std::allocator< pj::VideoDevInfo * > > *arg4 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  ptrdiff_t val2 ;
  int ecode2 = 0 ;
  ptrdiff_t val3 ;
  int ecode3 = 0 ;
  int res4 = SWIG_OLDOBJ ;
  
  if ((nobjs < 4) || (nobjs > 4)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__vectorT_pj__VideoDevInfo_p_std__allocatorT_pj__VideoDevInfo_p_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "VideoDevInfoVector___setslice__" "', argument " "1"" of type '" "std::vector< pj::VideoDevInfo * > *""'"); 
  }
  arg1 = reinterpret_cast< std::vector< pj::VideoDevInfo * > * >(argp1);
  ecode2 = SWIG_AsVal_ptrdiff_t(swig_obj[1], &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "VideoDevInfoVector___setslice__" "', argument " "2"" of type '" "std::vector< pj::VideoDevInfo * >::difference_type""'");
  } 
  arg2 = static_cast< std::vector< pj::VideoDevInfo * >::difference_type >(val2);
  ecode3 = SWIG_AsVal_ptrdiff_t(swig_obj[2], &val3);
  if (!SWIG_IsOK(ecode3)) {
    SWIG_exception_fail(SWIG_ArgError(ecode3), "in method '" "VideoDevInfoVector___setslice__" "', argument " "3"" of type '" "std::vector< pj::VideoDevInfo * >::difference_type""'");
  } 
  arg3 = static_cast< std::vector< pj::VideoDevInfo * >::difference_type >(val3);
  {
    std::vector< pj::VideoDevInfo*,std::allocator< pj::VideoDevInfo * > > *ptr = (std::vector< pj::VideoDevInfo*,std::allocator< pj::VideoDevInfo * > > *)0;
    res4 = swig::asptr(swig_obj[3], &ptr);
    if (!SWIG_IsOK(res4)) {
      SWIG_exception_fail(SWIG_ArgError(res4), "in method '" "VideoDevInfoVector___setslice__" "', argument " "4"" of type '" "std::vector< pj::VideoDevInfo *,std::allocator< pj::VideoDevInfo * > > const &""'"); 
    }
    if (!ptr) {
      SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "VideoDevInfoVector___setslice__" "', argument " "4"" of type '" "std::vector< pj::VideoDevInfo *,std::allocator< pj::VideoDevInfo * > > const &""'"); 
    }
    arg4 = ptr;
  }
  try {
    std_vector_Sl_pj_VideoDevInfo_Sm__Sg____setslice____SWIG_1(arg1,arg2,arg3,(std::vector< pj::VideoDevInfo *,std::allocator< pj::VideoDevInfo * > > const &)*arg4);
  } catch(std::out_of_range &_e) {
    SWIG_exception_fail(SWIG_IndexError, (&_e)->what());
  } catch(std::invalid_argument &_e) {
    SWIG_exception_fail(SWIG_ValueError, (&_e)->what());
  }
  resultobj = SWIG_Py_Void();
  if (SWIG_IsNewObj(res4)) delete arg4;
  return resultobj;
fail:
  if (SWIG_IsNewObj(res4)) delete arg4;
  return NULL;
}


SWIGINTERN PyObject *_wrap_VideoDevInfoVector___setslice__(PyObject *self, PyObject *args) {
  Py_ssize_t argc;
  PyObject *argv[5] = {
    0
  };
  
  if (!(argc = SWIG_Python_UnpackTuple(args, "VideoDevInfoVector___setslice__", 0, 4, argv))) SWIG_fail;
  --argc;
  if (argc == 3) {
    int _v;
    int res = swig::asptr(argv[0], (std::vector< pj::VideoDevInfo*,std::allocator< pj::VideoDevInfo * > >**)(0));
    _v = SWIG_CheckState(res);
    if (_v) {
      {
        int res = SWIG_AsVal_ptrdiff_t(argv[1], NULL);
        _v = SWIG_CheckState(res);
      }
      if (_v) {
        {
          int res = SWIG_AsVal_ptrdiff_t(argv[2], NULL);
          _v = SWIG_CheckState(res);
        }
        if (_v) {
          return _wrap_VideoDevInfoVector___setslice____SWIG_0(self, argc, argv);
        }
      }
    }
  }
  if (argc == 4) {
    int _v;
    int res = swig::asptr(argv[0], (std::vector< pj::VideoDevInfo*,std::allocator< pj::VideoDevInfo * > >**)(0));
    _v = SWIG_CheckState(res);
    if (_v) {
      {
        int res = SWIG_AsVal_ptrdiff_t(argv[1], NULL);
        _v = SWIG_CheckState(res);
      }
      if (_v) {
        {
          int res = SWIG_AsVal_ptrdiff_t(argv[2], NULL);
          _v = SWIG_CheckState(res);
        }
        if (_v) {
          int res = swig::asptr(argv[3], (std::vector< pj::VideoDevInfo*,std::allocator< pj::VideoDevInfo * > >**)(0));
          _v = SWIG_CheckState(res);
          if (_v) {
            return _wrap_VideoDevInfoVector___setslice____SWIG_1(self, argc, argv);
          }
        }
      }
    }
  }
  
fail:
  SWIG_Python_RaiseOrModifyTypeError("Wrong number or type of arguments for overloaded function 'VideoDevInfoVector___setslice__'.\n"
    "  Possible C/C++ prototypes are:\n"
    "    std::vector< pj::VideoDevInfo * >::__setslice__(std::vector< pj::VideoDevInfo * >::difference_type,std::vector< pj::VideoDevInfo * >::difference_type)\n"
    "    std::vector< pj::VideoDevInfo * >::__setslice__(std::vector< pj::VideoDevInfo * >::difference_type,std::vector< pj::VideoDevInfo * >::difference_type,std::vector< pj::VideoDevInfo *,std::allocator< pj::VideoDevInfo * > > const &)\n");
  return 0;
}


SWIGINTERN PyObject *_wrap_VideoDevInfoVector___delslice__(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  std::vector< pj::VideoDevInfo * > *arg1 = (std::vector< pj::VideoDevInfo * > *) 0 ;
  std::vector< pj::VideoDevInfo * >::difference_type arg2 ;
  std::vector< pj::VideoDevInfo * >::difference_type arg3 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  ptrdiff_t val2 ;
  int ecode2 = 0 ;
  ptrdiff_t val3 ;
  int ecode3 = 0 ;
  PyObject *swig_obj[3] ;
  
  if (!SWIG_Python_UnpackTuple(args, "VideoDevInfoVector___delslice__", 3, 3, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__vectorT_pj__VideoDevInfo_p_std__allocatorT_pj__VideoDevInfo_p_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "VideoDevInfoVector___delslice__" "', argument " "1"" of type '" "std::vector< pj::VideoDevInfo * > *""'"); 
  }
  arg1 = reinterpret_cast< std::vector< pj::VideoDevInfo * > * >(argp1);
  ecode2 = SWIG_AsVal_ptrdiff_t(swig_obj[1], &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "VideoDevInfoVector___delslice__" "', argument " "2"" of type '" "std::vector< pj::VideoDevInfo * >::difference_type""'");
  } 
  arg2 = static_cast< std::vector< pj::VideoDevInfo * >::difference_type >(val2);
  ecode3 = SWIG_AsVal_ptrdiff_t(swig_obj[2], &val3);
  if (!SWIG_IsOK(ecode3)) {
    SWIG_exception_fail(SWIG_ArgError(ecode3), "in method '" "VideoDevInfoVector___delslice__" "', argument " "3"" of type '" "std::vector< pj::VideoDevInfo * >::difference_type""'");
  } 
  arg3 = static_cast< std::vector< pj::VideoDevInfo * >::difference_type >(val3);
  try {
    std_vector_Sl_pj_VideoDevInfo_Sm__Sg____delslice__(arg1,arg2,arg3);
  } catch(std::out_of_range &_e) {
    SWIG_exception_fail(SWIG_IndexError, (&_e)->what());
  } catch(std::invalid_argument &_e) {
    SWIG_exception_fail(SWIG_ValueError, (&_e)->what());
  }
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_VideoDevInfoVector___delitem____SWIG_0(PyObject *SWIGUNUSEDPARM(self), Py_ssize_t nobjs, PyObject **swig_obj) {
  PyObject *resultobj = 0;
  std::vector< pj::VideoDevInfo * > *arg1 = (std::vector< pj::VideoDevInfo * > *) 0 ;
  std::vector< pj::VideoDevInfo * >::difference_type arg2 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  ptrdiff_t val2 ;
  int ecode2 = 0 ;
  
  if ((nobjs < 2) || (nobjs > 2)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__vectorT_pj__VideoDevInfo_p_std__allocatorT_pj__VideoDevInfo_p_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "VideoDevInfoVector___delitem__" "', argument " "1"" of type '" "std::vector< pj::VideoDevInfo * > *""'"); 
  }
  arg1 = reinterpret_cast< std::vector< pj::VideoDevInfo * > * >(argp1);
  ecode2 = SWIG_AsVal_ptrdiff_t(swig_obj[1], &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "VideoDevInfoVector___delitem__" "', argument " "2"" of type '" "std::vector< pj::VideoDevInfo * >::difference_type""'");
  } 
  arg2 = static_cast< std::vector< pj::VideoDevInfo * >::difference_type >(val2);
  try {
    std_vector_Sl_pj_VideoDevInfo_Sm__Sg____delitem____SWIG_0(arg1,arg2);
  } catch(std::out_of_range &_e) {
    SWIG_exception_fail(SWIG_IndexError, (&_e)->what());
  } catch(std::invalid_argument &_e) {
    SWIG_exception_fail(SWIG_ValueError, (&_e)->what());
  }
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_VideoDevInfoVector___getitem____SWIG_0(PyObject *SWIGUNUSEDPARM(self), Py_ssize_t nobjs, PyObject **swig_obj) {
  PyObject *resultobj = 0;
  std::vector< pj::VideoDevInfo * > *arg1 = (std::vector< pj::VideoDevInfo * > *) 0 ;
  PySliceObject *arg2 = (PySliceObject *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  std::vector< pj::VideoDevInfo *,std::allocator< pj::VideoDevInfo * > > *result = 0 ;
  
  if ((nobjs < 2) || (nobjs > 2)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__vectorT_pj__VideoDevInfo_p_std__allocatorT_pj__VideoDevInfo_p_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "VideoDevInfoVector___getitem__" "', argument " "1"" of type '" "std::vector< pj::VideoDevInfo * > *""'"); 
  }
  arg1 = reinterpret_cast< std::vector< pj::VideoDevInfo * > * >(argp1);
  {
    if (!PySlice_Check(swig_obj[1])) {
      SWIG_exception_fail(SWIG_ArgError(SWIG_TypeError), "in method '" "VideoDevInfoVector___getitem__" "', argument " "2"" of type '" "PySliceObject *""'");
    }
    arg2 = (PySliceObject *) swig_obj[1];
  }
  try {
    result = (std::vector< pj::VideoDevInfo *,std::allocator< pj::VideoDevInfo * > > *)std_vector_Sl_pj_VideoDevInfo_Sm__Sg____getitem____SWIG_0(arg1,arg2);
  } catch(std::out_of_range &_e) {
    SWIG_exception_fail(SWIG_IndexError, (&_e)->what());
  } catch(std::invalid_argument &_e) {
    SWIG_exception_fail(SWIG_ValueError, (&_e)->what());
  }
  resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(result), SWIGTYPE_p_std__vectorT_pj__VideoDevInfo_p_std__allocatorT_pj__VideoDevInfo_p_t_t, SWIG_POINTER_OWN |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_VideoDevInfoVector___setitem____SWIG_0(PyObject *SWIGUNUSEDPARM(self), Py_ssize_t nobjs, PyObject **swig_obj) {
  PyObject *resultobj = 0;
  std::vector< pj::VideoDevInfo * > *arg1 = (std::vector< pj::VideoDevInfo * > *) 0 ;
  PySliceObject *arg2 = (PySliceObject *) 0 ;
  std::vector< pj::VideoDevInfo *,std::allocator< pj::VideoDevInfo * > > *arg3 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  int res3 = SWIG_OLDOBJ ;
  
  if ((nobjs < 3) || (nobjs > 3)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__vectorT_pj__VideoDevInfo_p_std__allocatorT_pj__VideoDevInfo_p_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "VideoDevInfoVector___setitem__" "', argument " "1"" of type '" "std::vector< pj::VideoDevInfo * > *""'"); 
  }
  arg1 = reinterpret_cast< std::vector< pj::VideoDevInfo * > * >(argp1);
  {
    if (!PySlice_Check(swig_obj[1])) {
      SWIG_exception_fail(SWIG_ArgError(SWIG_TypeError), "in method '" "VideoDevInfoVector___setitem__" "', argument " "2"" of type '" "PySliceObject *""'");
    }
    arg2 = (PySliceObject *) swig_obj[1];
  }
  {
    std::vector< pj::VideoDevInfo*,std::allocator< pj::VideoDevInfo * > > *ptr = (std::vector< pj::VideoDevInfo*,std::allocator< pj::VideoDevInfo * > > *)0;
    res3 = swig::asptr(swig_obj[2], &ptr);
    if (!SWIG_IsOK(res3)) {
      SWIG_exception_fail(SWIG_ArgError(res3), "in method '" "VideoDevInfoVector___setitem__" "', argument " "3"" of type '" "std::vector< pj::VideoDevInfo *,std::allocator< pj::VideoDevInfo * > > const &""'"); 
    }
    if (!ptr) {
      SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "VideoDevInfoVector___setitem__" "', argument " "3"" of type '" "std::vector< pj::VideoDevInfo *,std::allocator< pj::VideoDevInfo * > > const &""'"); 
    }
    arg3 = ptr;
  }
  try {
    std_vector_Sl_pj_VideoDevInfo_Sm__Sg____setitem____SWIG_0(arg1,arg2,(std::vector< pj::VideoDevInfo *,std::allocator< pj::VideoDevInfo * > > const &)*arg3);
  } catch(std::out_of_range &_e) {
    SWIG_exception_fail(SWIG_IndexError, (&_e)->what());
  } catch(std::invalid_argument &_e) {
    SWIG_exception_fail(SWIG_ValueError, (&_e)->what());
  }
  resultobj = SWIG_Py_Void();
  if (SWIG_IsNewObj(res3)) delete arg3;
  return resultobj;
fail:
  if (SWIG_IsNewObj(res3)) delete arg3;
  return NULL;
}


SWIGINTERN PyObject *_wrap_VideoDevInfoVector___setitem____SWIG_1(PyObject *SWIGUNUSEDPARM(self), Py_ssize_t nobjs, PyObject **swig_obj) {
  PyObject *resultobj = 0;
  std::vector< pj::VideoDevInfo * > *arg1 = (std::vector< pj::VideoDevInfo * > *) 0 ;
  PySliceObject *arg2 = (PySliceObject *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  
  if ((nobjs < 2) || (nobjs > 2)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__vectorT_pj__VideoDevInfo_p_std__allocatorT_pj__VideoDevInfo_p_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "VideoDevInfoVector___setitem__" "', argument " "1"" of type '" "std::vector< pj::VideoDevInfo * > *""'"); 
  }
  arg1 = reinterpret_cast< std::vector< pj::VideoDevInfo * > * >(argp1);
  {
    if (!PySlice_Check(swig_obj[1])) {
      SWIG_exception_fail(SWIG_ArgError(SWIG_TypeError), "in method '" "VideoDevInfoVector___setitem__" "', argument " "2"" of type '" "PySliceObject *""'");
    }
    arg2 = (PySliceObject *) swig_obj[1];
  }
  try {
    std_vector_Sl_pj_VideoDevInfo_Sm__Sg____setitem____SWIG_1(arg1,arg2);
  } catch(std::out_of_range &_e) {
    SWIG_exception_fail(SWIG_IndexError, (&_e)->what());
  } catch(std::invalid_argument &_e) {
    SWIG_exception_fail(SWIG_ValueError, (&_e)->what());
  }
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_VideoDevInfoVector___delitem____SWIG_1(PyObject *SWIGUNUSEDPARM(self), Py_ssize_t nobjs, PyObject **swig_obj) {
  PyObject *resultobj = 0;
  std::vector< pj::VideoDevInfo * > *arg1 = (std::vector< pj::VideoDevInfo * > *) 0 ;
  PySliceObject *arg2 = (PySliceObject *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  
  if ((nobjs < 2) || (nobjs > 2)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__vectorT_pj__VideoDevInfo_p_std__allocatorT_pj__VideoDevInfo_p_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "VideoDevInfoVector___delitem__" "', argument " "1"" of type '" "std::vector< pj::VideoDevInfo * > *""'"); 
  }
  arg1 = reinterpret_cast< std::vector< pj::VideoDevInfo * > * >(argp1);
  {
    if (!PySlice_Check(swig_obj[1])) {
      SWIG_exception_fail(SWIG_ArgError(SWIG_TypeError), "in method '" "VideoDevInfoVector___delitem__" "', argument " "2"" of type '" "PySliceObject *""'");
    }
    arg2 = (PySliceObject *) swig_obj[1];
  }
  try {
    std_vector_Sl_pj_VideoDevInfo_Sm__Sg____delitem____SWIG_1(arg1,arg2);
  } catch(std::out_of_range &_e) {
    SWIG_exception_fail(SWIG_IndexError, (&_e)->what());
  } catch(std::invalid_argument &_e) {
    SWIG_exception_fail(SWIG_ValueError, (&_e)->what());
  }
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_VideoDevInfoVector___delitem__(PyObject *self, PyObject *args) {
  Py_ssize_t argc;
  PyObject *argv[3] = {
    0
  };
  
  if (!(argc = SWIG_Python_UnpackTuple(args, "VideoDevInfoVector___delitem__", 0, 2, argv))) SWIG_fail;
  --argc;
  if (argc == 2) {
    int _v;
    int res = swig::asptr(argv[0], (std::vector< pj::VideoDevInfo*,std::allocator< pj::VideoDevInfo * > >**)(0));
    _v = SWIG_CheckState(res);
    if (_v) {
      {
        _v = PySlice_Check(argv[1]);
      }
      if (_v) {
        return _wrap_VideoDevInfoVector___delitem____SWIG_1(self, argc, argv);
      }
    }
  }
  if (argc == 2) {
    int _v;
    int res = swig::asptr(argv[0], (std::vector< pj::VideoDevInfo*,std::allocator< pj::VideoDevInfo * > >**)(0));
    _v = SWIG_CheckState(res);
    if (_v) {
      {
        int res = SWIG_AsVal_ptrdiff_t(argv[1], NULL);
        _v = SWIG_CheckState(res);
      }
      if (_v) {
        return _wrap_VideoDevInfoVector___delitem____SWIG_0(self, argc, argv);
      }
    }
  }
  
fail:
  SWIG_Python_RaiseOrModifyTypeError("Wrong number or type of arguments for overloaded function 'VideoDevInfoVector___delitem__'.\n"
    "  Possible C/C++ prototypes are:\n"
    "    std::vector< pj::VideoDevInfo * >::__delitem__(std::vector< pj::VideoDevInfo * >::difference_type)\n"
    "    std::vector< pj::VideoDevInfo * >::__delitem__(PySliceObject *)\n");
  return 0;
}


SWIGINTERN PyObject *_wrap_VideoDevInfoVector___getitem____SWIG_1(PyObject *SWIGUNUSEDPARM(self), Py_ssize_t nobjs, PyObject **swig_obj) {
  PyObject *resultobj = 0;
  std::vector< pj::VideoDevInfo * > *arg1 = (std::vector< pj::VideoDevInfo * > *) 0 ;
  std::vector< pj::VideoDevInfo * >::difference_type arg2 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  ptrdiff_t val2 ;
  int ecode2 = 0 ;
  std::vector< pj::VideoDevInfo * >::value_type result;
  
  if ((nobjs < 2) || (nobjs > 2)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__vectorT_pj__VideoDevInfo_p_std__allocatorT_pj__VideoDevInfo_p_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "VideoDevInfoVector___getitem__" "', argument " "1"" of type '" "std::vector< pj::VideoDevInfo * > *""'"); 
  }
  arg1 = reinterpret_cast< std::vector< pj::VideoDevInfo * > * >(argp1);
  ecode2 = SWIG_AsVal_ptrdiff_t(swig_obj[1], &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "VideoDevInfoVector___getitem__" "', argument " "2"" of type '" "std::vector< pj::VideoDevInfo * >::difference_type""'");
  } 
  arg2 = static_cast< std::vector< pj::VideoDevInfo * >::difference_type >(val2);
  try {
    result = (std::vector< pj::VideoDevInfo * >::value_type)std_vector_Sl_pj_VideoDevInfo_Sm__Sg____getitem____SWIG_1(arg1,arg2);
  } catch(std::out_of_range &_e) {
    SWIG_exception_fail(SWIG_IndexError, (&_e)->what());
  }
  resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(result), SWIGTYPE_p_pj__VideoDevInfo, 0 |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_VideoDevInfoVector___getitem__(PyObject *self, PyObject *args) {
  Py_ssize_t argc;
  PyObject *argv[3] = {
    0
  };
  
  if (!(argc = SWIG_Python_UnpackTuple(args, "VideoDevInfoVector___getitem__", 0, 2, argv))) SWIG_fail;
  --argc;
  if (argc == 2) {
    int _v;
    int res = swig::asptr(argv[0], (std::vector< pj::VideoDevInfo*,std::allocator< pj::VideoDevInfo * > >**)(0));
    _v = SWIG_CheckState(res);
    if (_v) {
      {
        _v = PySlice_Check(argv[1]);
      }
      if (_v) {
        return _wrap_VideoDevInfoVector___getitem____SWIG_0(self, argc, argv);
      }
    }
  }
  if (argc == 2) {
    int _v;
    int res = swig::asptr(argv[0], (std::vector< pj::VideoDevInfo*,std::allocator< pj::VideoDevInfo * > >**)(0));
    _v = SWIG_CheckState(res);
    if (_v) {
      {
        int res = SWIG_AsVal_ptrdiff_t(argv[1], NULL);
        _v = SWIG_CheckState(res);
      }
      if (_v) {
        return _wrap_VideoDevInfoVector___getitem____SWIG_1(self, argc, argv);
      }
    }
  }
  
fail:
  SWIG_Python_RaiseOrModifyTypeError("Wrong number or type of arguments for overloaded function 'VideoDevInfoVector___getitem__'.\n"
    "  Possible C/C++ prototypes are:\n"
    "    std::vector< pj::VideoDevInfo * >::__getitem__(PySliceObject *)\n"
    "    std::vector< pj::VideoDevInfo * >::__getitem__(std::vector< pj::VideoDevInfo * >::difference_type)\n");
  return 0;
}


SWIGINTERN PyObject *_wrap_VideoDevInfoVector___setitem____SWIG_2(PyObject *SWIGUNUSEDPARM(self), Py_ssize_t nobjs, PyObject **swig_obj) {
  PyObject *resultobj = 0;
  std::vector< pj::VideoDevInfo * > *arg1 = (std::vector< pj::VideoDevInfo * > *) 0 ;
  std::vector< pj::VideoDevInfo * >::difference_type arg2 ;
  std::vector< pj::VideoDevInfo * >::value_type arg3 = (std::vector< pj::VideoDevInfo * >::value_type) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  ptrdiff_t val2 ;
  int ecode2 = 0 ;
  void *argp3 = 0 ;
  int res3 = 0 ;
  
  if ((nobjs < 3) || (nobjs > 3)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__vectorT_pj__VideoDevInfo_p_std__allocatorT_pj__VideoDevInfo_p_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "VideoDevInfoVector___setitem__" "', argument " "1"" of type '" "std::vector< pj::VideoDevInfo * > *""'"); 
  }
  arg1 = reinterpret_cast< std::vector< pj::VideoDevInfo * > * >(argp1);
  ecode2 = SWIG_AsVal_ptrdiff_t(swig_obj[1], &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "VideoDevInfoVector___setitem__" "', argument " "2"" of type '" "std::vector< pj::VideoDevInfo * >::difference_type""'");
  } 
  arg2 = static_cast< std::vector< pj::VideoDevInfo * >::difference_type >(val2);
  res3 = SWIG_ConvertPtr(swig_obj[2], &argp3,SWIGTYPE_p_pj__VideoDevInfo, 0 |  0 );
  if (!SWIG_IsOK(res3)) {
    SWIG_exception_fail(SWIG_ArgError(res3), "in method '" "VideoDevInfoVector___setitem__" "', argument " "3"" of type '" "std::vector< pj::VideoDevInfo * >::value_type""'"); 
  }
  arg3 = reinterpret_cast< std::vector< pj::VideoDevInfo * >::value_type >(argp3);
  try {
    std_vector_Sl_pj_VideoDevInfo_Sm__Sg____setitem____SWIG_2(arg1,arg2,arg3);
  } catch(std::out_of_range &_e) {
    SWIG_exception_fail(SWIG_IndexError, (&_e)->what());
  }
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_VideoDevInfoVector___setitem__(PyObject *self, PyObject *args) {
  Py_ssize_t argc;
  PyObject *argv[4] = {
    0
  };
  
  if (!(argc = SWIG_Python_UnpackTuple(args, "VideoDevInfoVector___setitem__", 0, 3, argv))) SWIG_fail;
  --argc;
  if (argc == 2) {
    int _v;
    int res = swig::asptr(argv[0], (std::vector< pj::VideoDevInfo*,std::allocator< pj::VideoDevInfo * > >**)(0));
    _v = SWIG_CheckState(res);
    if (_v) {
      {
        _v = PySlice_Check(argv[1]);
      }
      if (_v) {
        return _wrap_VideoDevInfoVector___setitem____SWIG_1(self, argc, argv);
      }
    }
  }
  if (argc == 3) {
    int _v;
    int res = swig::asptr(argv[0], (std::vector< pj::VideoDevInfo*,std::allocator< pj::VideoDevInfo * > >**)(0));
    _v = SWIG_CheckState(res);
    if (_v) {
      {
        _v = PySlice_Check(argv[1]);
      }
      if (_v) {
        int res = swig::asptr(argv[2], (std::vector< pj::VideoDevInfo*,std::allocator< pj::VideoDevInfo * > >**)(0));
        _v = SWIG_CheckState(res);
        if (_v) {
          return _wrap_VideoDevInfoVector___setitem____SWIG_0(self, argc, argv);
        }
      }
    }
  }
  if (argc == 3) {
    int _v;
    int res = swig::asptr(argv[0], (std::vector< pj::VideoDevInfo*,std::allocator< pj::VideoDevInfo * > >**)(0));
    _v = SWIG_CheckState(res);
    if (_v) {
      {
        int res = SWIG_AsVal_ptrdiff_t(argv[1], NULL);
        _v = SWIG_CheckState(res);
      }
      if (_v) {
        void *vptr = 0;
        int res = SWIG_ConvertPtr(argv[2], &vptr, SWIGTYPE_p_pj__VideoDevInfo, 0);
        _v = SWIG_CheckState(res);
        if (_v) {
          return _wrap_VideoDevInfoVector___setitem____SWIG_2(self, argc, argv);
        }
      }
    }
  }
  
fail:
  SWIG_Python_RaiseOrModifyTypeError("Wrong number or type of arguments for overloaded function 'VideoDevInfoVector___setitem__'.\n"
    "  Possible C/C++ prototypes are:\n"
    "    std::vector< pj::VideoDevInfo * >::__setitem__(PySliceObject *,std::vector< pj::VideoDevInfo *,std::allocator< pj::VideoDevInfo * > > const &)\n"
    "    std::vector< pj::VideoDevInfo * >::__setitem__(PySliceObject *)\n"
    "    std::vector< pj::VideoDevInfo * >::__setitem__(std::vector< pj::VideoDevInfo * >::difference_type,std::vector< pj::VideoDevInfo * >::value_type)\n");
  return 0;
}


SWIGINTERN PyObject *_wrap_VideoDevInfoVector_pop(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  std::vector< pj::VideoDevInfo * > *arg1 = (std::vector< pj::VideoDevInfo * > *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  std::vector< pj::VideoDevInfo * >::value_type result;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__vectorT_pj__VideoDevInfo_p_std__allocatorT_pj__VideoDevInfo_p_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "VideoDevInfoVector_pop" "', argument " "1"" of type '" "std::vector< pj::VideoDevInfo * > *""'"); 
  }
  arg1 = reinterpret_cast< std::vector< pj::VideoDevInfo * > * >(argp1);
  try {
    result = (std::vector< pj::VideoDevInfo * >::value_type)std_vector_Sl_pj_VideoDevInfo_Sm__Sg__pop(arg1);
  } catch(std::out_of_range &_e) {
    SWIG_exception_fail(SWIG_IndexError, (&_e)->what());
  }
  resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(result), SWIGTYPE_p_pj__VideoDevInfo, 0 |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_VideoDevInfoVector_append(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  std::vector< pj::VideoDevInfo * > *arg1 = (std::vector< pj::VideoDevInfo * > *) 0 ;
  std::vector< pj::VideoDevInfo * >::value_type arg2 = (std::vector< pj::VideoDevInfo * >::value_type) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  void *argp2 = 0 ;
  int res2 = 0 ;
  PyObject *swig_obj[2] ;
  
  if (!SWIG_Python_UnpackTuple(args, "VideoDevInfoVector_append", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__vectorT_pj__VideoDevInfo_p_std__allocatorT_pj__VideoDevInfo_p_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "VideoDevInfoVector_append" "', argument " "1"" of type '" "std::vector< pj::VideoDevInfo * > *""'"); 
  }
  arg1 = reinterpret_cast< std::vector< pj::VideoDevInfo * > * >(argp1);
  res2 = SWIG_ConvertPtr(swig_obj[1], &argp2,SWIGTYPE_p_pj__VideoDevInfo, 0 |  0 );
  if (!SWIG_IsOK(res2)) {
    SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "VideoDevInfoVector_append" "', argument " "2"" of type '" "std::vector< pj::VideoDevInfo * >::value_type""'"); 
  }
  arg2 = reinterpret_cast< std::vector< pj::VideoDevInfo * >::value_type >(argp2);
  std_vector_Sl_pj_VideoDevInfo_Sm__Sg__append(arg1,arg2);
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_new_VideoDevInfoVector__SWIG_0(PyObject *SWIGUNUSEDPARM(self), Py_ssize_t nobjs, PyObject **SWIGUNUSEDPARM(swig_obj)) {
  PyObject *resultobj = 0;
  std::vector< pj::VideoDevInfo * > *result = 0 ;
  
  if ((nobjs < 0) || (nobjs > 0)) SWIG_fail;
  result = (std::vector< pj::VideoDevInfo * > *)new std::vector< pj::VideoDevInfo * >();
  resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(result), SWIGTYPE_p_std__vectorT_pj__VideoDevInfo_p_std__allocatorT_pj__VideoDevInfo_p_t_t, SWIG_POINTER_NEW |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_new_VideoDevInfoVector__SWIG_1(PyObject *SWIGUNUSEDPARM(self), Py_ssize_t nobjs, PyObject **swig_obj) {
  PyObject *resultobj = 0;
  std::vector< pj::VideoDevInfo * > *arg1 = 0 ;
  int res1 = SWIG_OLDOBJ ;
  std::vector< pj::VideoDevInfo * > *result = 0 ;
  
  if ((nobjs < 1) || (nobjs > 1)) SWIG_fail;
  {
    std::vector< pj::VideoDevInfo*,std::allocator< pj::VideoDevInfo * > > *ptr = (std::vector< pj::VideoDevInfo*,std::allocator< pj::VideoDevInfo * > > *)0;
    res1 = swig::asptr(swig_obj[0], &ptr);
    if (!SWIG_IsOK(res1)) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "new_VideoDevInfoVector" "', argument " "1"" of type '" "std::vector< pj::VideoDevInfo * > const &""'"); 
    }
    if (!ptr) {
      SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "new_VideoDevInfoVector" "', argument " "1"" of type '" "std::vector< pj::VideoDevInfo * > const &""'"); 
    }
    arg1 = ptr;
  }
  result = (std::vector< pj::VideoDevInfo * > *)new std::vector< pj::VideoDevInfo * >((std::vector< pj::VideoDevInfo * > const &)*arg1);
  resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(result), SWIGTYPE_p_std__vectorT_pj__VideoDevInfo_p_std__allocatorT_pj__VideoDevInfo_p_t_t, SWIG_POINTER_NEW |  0 );
  if (SWIG_IsNewObj(res1)) delete arg1;
  return resultobj;
fail:
  if (SWIG_IsNewObj(res1)) delete arg1;
  return NULL;
}


SWIGINTERN PyObject *_wrap_VideoDevInfoVector_empty(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  std::vector< pj::VideoDevInfo * > *arg1 = (std::vector< pj::VideoDevInfo * > *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  bool result;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__vectorT_pj__VideoDevInfo_p_std__allocatorT_pj__VideoDevInfo_p_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "VideoDevInfoVector_empty" "', argument " "1"" of type '" "std::vector< pj::VideoDevInfo * > const *""'"); 
  }
  arg1 = reinterpret_cast< std::vector< pj::VideoDevInfo * > * >(argp1);
  result = (bool)((std::vector< pj::VideoDevInfo * > const *)arg1)->empty();
  resultobj = SWIG_From_bool(static_cast< bool >(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_VideoDevInfoVector_size(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  std::vector< pj::VideoDevInfo * > *arg1 = (std::vector< pj::VideoDevInfo * > *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  std::vector< pj::VideoDevInfo * >::size_type result;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__vectorT_pj__VideoDevInfo_p_std__allocatorT_pj__VideoDevInfo_p_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "VideoDevInfoVector_size" "', argument " "1"" of type '" "std::vector< pj::VideoDevInfo * > const *""'"); 
  }
  arg1 = reinterpret_cast< std::vector< pj::VideoDevInfo * > * >(argp1);
  result = ((std::vector< pj::VideoDevInfo * > const *)arg1)->size();
  resultobj = SWIG_From_size_t(static_cast< size_t >(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_VideoDevInfoVector_swap(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  std::vector< pj::VideoDevInfo * > *arg1 = (std::vector< pj::VideoDevInfo * > *) 0 ;
  std::vector< pj::VideoDevInfo * > *arg2 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  void *argp2 = 0 ;
  int res2 = 0 ;
  PyObject *swig_obj[2] ;
  
  if (!SWIG_Python_UnpackTuple(args, "VideoDevInfoVector_swap", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__vectorT_pj__VideoDevInfo_p_std__allocatorT_pj__VideoDevInfo_p_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "VideoDevInfoVector_swap" "', argument " "1"" of type '" "std::vector< pj::VideoDevInfo * > *""'"); 
  }
  arg1 = reinterpret_cast< std::vector< pj::VideoDevInfo * > * >(argp1);
  res2 = SWIG_ConvertPtr(swig_obj[1], &argp2, SWIGTYPE_p_std__vectorT_pj__VideoDevInfo_p_std__allocatorT_pj__VideoDevInfo_p_t_t,  0 );
  if (!SWIG_IsOK(res2)) {
    SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "VideoDevInfoVector_swap" "', argument " "2"" of type '" "std::vector< pj::VideoDevInfo * > &""'"); 
  }
  if (!argp2) {
    SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "VideoDevInfoVector_swap" "', argument " "2"" of type '" "std::vector< pj::VideoDevInfo * > &""'"); 
  }
  arg2 = reinterpret_cast< std::vector< pj::VideoDevInfo * > * >(argp2);
  (arg1)->swap(*arg2);
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_VideoDevInfoVector_begin(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  std::vector< pj::VideoDevInfo * > *arg1 = (std::vector< pj::VideoDevInfo * > *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  std::vector< pj::VideoDevInfo * >::iterator result;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__vectorT_pj__VideoDevInfo_p_std__allocatorT_pj__VideoDevInfo_p_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "VideoDevInfoVector_begin" "', argument " "1"" of type '" "std::vector< pj::VideoDevInfo * > *""'"); 
  }
  arg1 = reinterpret_cast< std::vector< pj::VideoDevInfo * > * >(argp1);
  result = (arg1)->begin();
  resultobj = SWIG_NewPointerObj(swig::make_output_iterator(static_cast< const std::vector< pj::VideoDevInfo * >::iterator & >(result)),
    swig::SwigPyIterator::descriptor(),SWIG_POINTER_OWN);
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_VideoDevInfoVector_end(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  std::vector< pj::VideoDevInfo * > *arg1 = (std::vector< pj::VideoDevInfo * > *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  std::vector< pj::VideoDevInfo * >::iterator result;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__vectorT_pj__VideoDevInfo_p_std__allocatorT_pj__VideoDevInfo_p_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "VideoDevInfoVector_end" "', argument " "1"" of type '" "std::vector< pj::VideoDevInfo * > *""'"); 
  }
  arg1 = reinterpret_cast< std::vector< pj::VideoDevInfo * > * >(argp1);
  result = (arg1)->end();
  resultobj = SWIG_NewPointerObj(swig::make_output_iterator(static_cast< const std::vector< pj::VideoDevInfo * >::iterator & >(result)),
    swig::SwigPyIterator::descriptor(),SWIG_POINTER_OWN);
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_VideoDevInfoVector_rbegin(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  std::vector< pj::VideoDevInfo * > *arg1 = (std::vector< pj::VideoDevInfo * > *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  std::vector< pj::VideoDevInfo * >::reverse_iterator result;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__vectorT_pj__VideoDevInfo_p_std__allocatorT_pj__VideoDevInfo_p_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "VideoDevInfoVector_rbegin" "', argument " "1"" of type '" "std::vector< pj::VideoDevInfo * > *""'"); 
  }
  arg1 = reinterpret_cast< std::vector< pj::VideoDevInfo * > * >(argp1);
  result = (arg1)->rbegin();
  resultobj = SWIG_NewPointerObj(swig::make_output_iterator(static_cast< const std::vector< pj::VideoDevInfo * >::reverse_iterator & >(result)),
    swig::SwigPyIterator::descriptor(),SWIG_POINTER_OWN);
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_VideoDevInfoVector_rend(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  std::vector< pj::VideoDevInfo * > *arg1 = (std::vector< pj::VideoDevInfo * > *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  std::vector< pj::VideoDevInfo * >::reverse_iterator result;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__vectorT_pj__VideoDevInfo_p_std__allocatorT_pj__VideoDevInfo_p_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "VideoDevInfoVector_rend" "', argument " "1"" of type '" "std::vector< pj::VideoDevInfo * > *""'"); 
  }
  arg1 = reinterpret_cast< std::vector< pj::VideoDevInfo * > * >(argp1);
  result = (arg1)->rend();
  resultobj = SWIG_NewPointerObj(swig::make_output_iterator(static_cast< const std::vector< pj::VideoDevInfo * >::reverse_iterator & >(result)),
    swig::SwigPyIterator::descriptor(),SWIG_POINTER_OWN);
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_VideoDevInfoVector_clear(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  std::vector< pj::VideoDevInfo * > *arg1 = (std::vector< pj::VideoDevInfo * > *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__vectorT_pj__VideoDevInfo_p_std__allocatorT_pj__VideoDevInfo_p_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "VideoDevInfoVector_clear" "', argument " "1"" of type '" "std::vector< pj::VideoDevInfo * > *""'"); 
  }
  arg1 = reinterpret_cast< std::vector< pj::VideoDevInfo * > * >(argp1);
  (arg1)->clear();
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_VideoDevInfoVector_get_allocator(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  std::vector< pj::VideoDevInfo * > *arg1 = (std::vector< pj::VideoDevInfo * > *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  SwigValueWrapper< std::allocator< pj::VideoDevInfo * > > result;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__vectorT_pj__VideoDevInfo_p_std__allocatorT_pj__VideoDevInfo_p_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "VideoDevInfoVector_get_allocator" "', argument " "1"" of type '" "std::vector< pj::VideoDevInfo * > const *""'"); 
  }
  arg1 = reinterpret_cast< std::vector< pj::VideoDevInfo * > * >(argp1);
  result = ((std::vector< pj::VideoDevInfo * > const *)arg1)->get_allocator();
  resultobj = SWIG_NewPointerObj((new std::vector< pj::VideoDevInfo * >::allocator_type(static_cast< const std::vector< pj::VideoDevInfo * >::allocator_type& >(result))), SWIGTYPE_p_std__allocatorT_pj__VideoDevInfo_p_t, SWIG_POINTER_OWN |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_new_VideoDevInfoVector__SWIG_2(PyObject *SWIGUNUSEDPARM(self), Py_ssize_t nobjs, PyObject **swig_obj) {
  PyObject *resultobj = 0;
  std::vector< pj::VideoDevInfo * >::size_type arg1 ;
  size_t val1 ;
  int ecode1 = 0 ;
  std::vector< pj::VideoDevInfo * > *result = 0 ;
  
  if ((nobjs < 1) || (nobjs > 1)) SWIG_fail;
  ecode1 = SWIG_AsVal_size_t(swig_obj[0], &val1);
  if (!SWIG_IsOK(ecode1)) {
    SWIG_exception_fail(SWIG_ArgError(ecode1), "in method '" "new_VideoDevInfoVector" "', argument " "1"" of type '" "std::vector< pj::VideoDevInfo * >::size_type""'");
  } 
  arg1 = static_cast< std::vector< pj::VideoDevInfo * >::size_type >(val1);
  result = (std::vector< pj::VideoDevInfo * > *)new std::vector< pj::VideoDevInfo * >(arg1);
  resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(result), SWIGTYPE_p_std__vectorT_pj__VideoDevInfo_p_std__allocatorT_pj__VideoDevInfo_p_t_t, SWIG_POINTER_NEW |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_VideoDevInfoVector_pop_back(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  std::vector< pj::VideoDevInfo * > *arg1 = (std::vector< pj::VideoDevInfo * > *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__vectorT_pj__VideoDevInfo_p_std__allocatorT_pj__VideoDevInfo_p_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "VideoDevInfoVector_pop_back" "', argument " "1"" of type '" "std::vector< pj::VideoDevInfo * > *""'"); 
  }
  arg1 = reinterpret_cast< std::vector< pj::VideoDevInfo * > * >(argp1);
  (arg1)->pop_back();
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_VideoDevInfoVector_resize__SWIG_0(PyObject *SWIGUNUSEDPARM(self), Py_ssize_t nobjs, PyObject **swig_obj) {
  PyObject *resultobj = 0;
  std::vector< pj::VideoDevInfo * > *arg1 = (std::vector< pj::VideoDevInfo * > *) 0 ;
  std::vector< pj::VideoDevInfo * >::size_type arg2 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  size_t val2 ;
  int ecode2 = 0 ;
  
  if ((nobjs < 2) || (nobjs > 2)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__vectorT_pj__VideoDevInfo_p_std__allocatorT_pj__VideoDevInfo_p_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "VideoDevInfoVector_resize" "', argument " "1"" of type '" "std::vector< pj::VideoDevInfo * > *""'"); 
  }
  arg1 = reinterpret_cast< std::vector< pj::VideoDevInfo * > * >(argp1);
  ecode2 = SWIG_AsVal_size_t(swig_obj[1], &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "VideoDevInfoVector_resize" "', argument " "2"" of type '" "std::vector< pj::VideoDevInfo * >::size_type""'");
  } 
  arg2 = static_cast< std::vector< pj::VideoDevInfo * >::size_type >(val2);
  (arg1)->resize(arg2);
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_VideoDevInfoVector_erase__SWIG_0(PyObject *SWIGUNUSEDPARM(self), Py_ssize_t nobjs, PyObject **swig_obj) {
  PyObject *resultobj = 0;
  std::vector< pj::VideoDevInfo * > *arg1 = (std::vector< pj::VideoDevInfo * > *) 0 ;
  std::vector< pj::VideoDevInfo * >::iterator arg2 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  swig::SwigPyIterator *iter2 = 0 ;
  int res2 ;
  std::vector< pj::VideoDevInfo * >::iterator result;
  
  if ((nobjs < 2) || (nobjs > 2)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__vectorT_pj__VideoDevInfo_p_std__allocatorT_pj__VideoDevInfo_p_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "VideoDevInfoVector_erase" "', argument " "1"" of type '" "std::vector< pj::VideoDevInfo * > *""'"); 
  }
  arg1 = reinterpret_cast< std::vector< pj::VideoDevInfo * > * >(argp1);
  res2 = SWIG_ConvertPtr(swig_obj[1], SWIG_as_voidptrptr(&iter2), swig::SwigPyIterator::descriptor(), 0);
  if (!SWIG_IsOK(res2) || !iter2) {
    SWIG_exception_fail(SWIG_ArgError(SWIG_TypeError), "in method '" "VideoDevInfoVector_erase" "', argument " "2"" of type '" "std::vector< pj::VideoDevInfo * >::iterator""'");
  } else {
    swig::SwigPyIterator_T<std::vector< pj::VideoDevInfo * >::iterator > *iter_t = dynamic_cast<swig::SwigPyIterator_T<std::vector< pj::VideoDevInfo * >::iterator > *>(iter2);
    if (iter_t) {
      arg2 = iter_t->get_current();
    } else {
      SWIG_exception_fail(SWIG_ArgError(SWIG_TypeError), "in method '" "VideoDevInfoVector_erase" "', argument " "2"" of type '" "std::vector< pj::VideoDevInfo * >::iterator""'");
    }
  }
  result = std_vector_Sl_pj_VideoDevInfo_Sm__Sg__erase__SWIG_0(arg1,arg2);
  resultobj = SWIG_NewPointerObj(swig::make_output_iterator(static_cast< const std::vector< pj::VideoDevInfo * >::iterator & >(result)),
    swig::SwigPyIterator::descriptor(),SWIG_POINTER_OWN);
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_VideoDevInfoVector_erase__SWIG_1(PyObject *SWIGUNUSEDPARM(self), Py_ssize_t nobjs, PyObject **swig_obj) {
  PyObject *resultobj = 0;
  std::vector< pj::VideoDevInfo * > *arg1 = (std::vector< pj::VideoDevInfo * > *) 0 ;
  std::vector< pj::VideoDevInfo * >::iterator arg2 ;
  std::vector< pj::VideoDevInfo * >::iterator arg3 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  swig::SwigPyIterator *iter2 = 0 ;
  int res2 ;
  swig::SwigPyIterator *iter3 = 0 ;
  int res3 ;
  std::vector< pj::VideoDevInfo * >::iterator result;
  
  if ((nobjs < 3) || (nobjs > 3)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__vectorT_pj__VideoDevInfo_p_std__allocatorT_pj__VideoDevInfo_p_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "VideoDevInfoVector_erase" "', argument " "1"" of type '" "std::vector< pj::VideoDevInfo * > *""'"); 
  }
  arg1 = reinterpret_cast< std::vector< pj::VideoDevInfo * > * >(argp1);
  res2 = SWIG_ConvertPtr(swig_obj[1], SWIG_as_voidptrptr(&iter2), swig::SwigPyIterator::descriptor(), 0);
  if (!SWIG_IsOK(res2) || !iter2) {
    SWIG_exception_fail(SWIG_ArgError(SWIG_TypeError), "in method '" "VideoDevInfoVector_erase" "', argument " "2"" of type '" "std::vector< pj::VideoDevInfo * >::iterator""'");
  } else {
    swig::SwigPyIterator_T<std::vector< pj::VideoDevInfo * >::iterator > *iter_t = dynamic_cast<swig::SwigPyIterator_T<std::vector< pj::VideoDevInfo * >::iterator > *>(iter2);
    if (iter_t) {
      arg2 = iter_t->get_current();
    } else {
      SWIG_exception_fail(SWIG_ArgError(SWIG_TypeError), "in method '" "VideoDevInfoVector_erase" "', argument " "2"" of type '" "std::vector< pj::VideoDevInfo * >::iterator""'");
    }
  }
  res3 = SWIG_ConvertPtr(swig_obj[2], SWIG_as_voidptrptr(&iter3), swig::SwigPyIterator::descriptor(), 0);
  if (!SWIG_IsOK(res3) || !iter3) {
    SWIG_exception_fail(SWIG_ArgError(SWIG_TypeError), "in method '" "VideoDevInfoVector_erase" "', argument " "3"" of type '" "std::vector< pj::VideoDevInfo * >::iterator""'");
  } else {
    swig::SwigPyIterator_T<std::vector< pj::VideoDevInfo * >::iterator > *iter_t = dynamic_cast<swig::SwigPyIterator_T<std::vector< pj::VideoDevInfo * >::iterator > *>(iter3);
    if (iter_t) {
      arg3 = iter_t->get_current();
    } else {
      SWIG_exception_fail(SWIG_ArgError(SWIG_TypeError), "in method '" "VideoDevInfoVector_erase" "', argument " "3"" of type '" "std::vector< pj::VideoDevInfo * >::iterator""'");
    }
  }
  result = std_vector_Sl_pj_VideoDevInfo_Sm__Sg__erase__SWIG_1(arg1,arg2,arg3);
  resultobj = SWIG_NewPointerObj(swig::make_output_iterator(static_cast< const std::vector< pj::VideoDevInfo * >::iterator & >(result)),
    swig::SwigPyIterator::descriptor(),SWIG_POINTER_OWN);
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_VideoDevInfoVector_erase(PyObject *self, PyObject *args) {
  Py_ssize_t argc;
  PyObject *argv[4] = {
    0
  };
  
  if (!(argc = SWIG_Python_UnpackTuple(args, "VideoDevInfoVector_erase", 0, 3, argv))) SWIG_fail;
  --argc;
  if (argc == 2) {
    int _v;
    int res = swig::asptr(argv[0], (std::vector< pj::VideoDevInfo*,std::allocator< pj::VideoDevInfo * > >**)(0));
    _v = SWIG_CheckState(res);
    if (_v) {
      swig::SwigPyIterator *iter = 0;
      int res = SWIG_ConvertPtr(argv[1], SWIG_as_voidptrptr(&iter), swig::SwigPyIterator::descriptor(), 0);
      _v = (SWIG_IsOK(res) && iter && (dynamic_cast<swig::SwigPyIterator_T<std::vector< pj::VideoDevInfo * >::iterator > *>(iter) != 0));
      if (_v) {
        return _wrap_VideoDevInfoVector_erase__SWIG_0(self, argc, argv);
      }
    }
  }
  if (argc == 3) {
    int _v;
    int res = swig::asptr(argv[0], (std::vector< pj::VideoDevInfo*,std::allocator< pj::VideoDevInfo * > >**)(0));
    _v = SWIG_CheckState(res);
    if (_v) {
      swig::SwigPyIterator *iter = 0;
      int res = SWIG_ConvertPtr(argv[1], SWIG_as_voidptrptr(&iter), swig::SwigPyIterator::descriptor(), 0);
      _v = (SWIG_IsOK(res) && iter && (dynamic_cast<swig::SwigPyIterator_T<std::vector< pj::VideoDevInfo * >::iterator > *>(iter) != 0));
      if (_v) {
        swig::SwigPyIterator *iter = 0;
        int res = SWIG_ConvertPtr(argv[2], SWIG_as_voidptrptr(&iter), swig::SwigPyIterator::descriptor(), 0);
        _v = (SWIG_IsOK(res) && iter && (dynamic_cast<swig::SwigPyIterator_T<std::vector< pj::VideoDevInfo * >::iterator > *>(iter) != 0));
        if (_v) {
          return _wrap_VideoDevInfoVector_erase__SWIG_1(self, argc, argv);
        }
      }
    }
  }
  
fail:
  SWIG_Python_RaiseOrModifyTypeError("Wrong number or type of arguments for overloaded function 'VideoDevInfoVector_erase'.\n"
    "  Possible C/C++ prototypes are:\n"
    "    std::vector< pj::VideoDevInfo * >::erase(std::vector< pj::VideoDevInfo * >::iterator)\n"
    "    std::vector< pj::VideoDevInfo * >::erase(std::vector< pj::VideoDevInfo * >::iterator,std::vector< pj::VideoDevInfo * >::iterator)\n");
  return 0;
}


SWIGINTERN PyObject *_wrap_new_VideoDevInfoVector__SWIG_3(PyObject *SWIGUNUSEDPARM(self), Py_ssize_t nobjs, PyObject **swig_obj) {
  PyObject *resultobj = 0;
  std::vector< pj::VideoDevInfo * >::size_type arg1 ;
  std::vector< pj::VideoDevInfo * >::value_type arg2 = (std::vector< pj::VideoDevInfo * >::value_type) 0 ;
  size_t val1 ;
  int ecode1 = 0 ;
  void *argp2 = 0 ;
  int res2 = 0 ;
  std::vector< pj::VideoDevInfo * > *result = 0 ;
  
  if ((nobjs < 2) || (nobjs > 2)) SWIG_fail;
  ecode1 = SWIG_AsVal_size_t(swig_obj[0], &val1);
  if (!SWIG_IsOK(ecode1)) {
    SWIG_exception_fail(SWIG_ArgError(ecode1), "in method '" "new_VideoDevInfoVector" "', argument " "1"" of type '" "std::vector< pj::VideoDevInfo * >::size_type""'");
  } 
  arg1 = static_cast< std::vector< pj::VideoDevInfo * >::size_type >(val1);
  res2 = SWIG_ConvertPtr(swig_obj[1], &argp2,SWIGTYPE_p_pj__VideoDevInfo, 0 |  0 );
  if (!SWIG_IsOK(res2)) {
    SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "new_VideoDevInfoVector" "', argument " "2"" of type '" "std::vector< pj::VideoDevInfo * >::value_type""'"); 
  }
  arg2 = reinterpret_cast< std::vector< pj::VideoDevInfo * >::value_type >(argp2);
  result = (std::vector< pj::VideoDevInfo * > *)new std::vector< pj::VideoDevInfo * >(arg1,arg2);
  resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(result), SWIGTYPE_p_std__vectorT_pj__VideoDevInfo_p_std__allocatorT_pj__VideoDevInfo_p_t_t, SWIG_POINTER_NEW |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_new_VideoDevInfoVector(PyObject *self, PyObject *args) {
  Py_ssize_t argc;
  PyObject *argv[3] = {
    0
  };
  
  if (!(argc = SWIG_Python_UnpackTuple(args, "new_VideoDevInfoVector", 0, 2, argv))) SWIG_fail;
  --argc;
  if (argc == 0) {
    return _wrap_new_VideoDevInfoVector__SWIG_0(self, argc, argv);
  }
  if (argc == 1) {
    int _v;
    {
      int res = SWIG_AsVal_size_t(argv[0], NULL);
      _v = SWIG_CheckState(res);
    }
    if (_v) {
      return _wrap_new_VideoDevInfoVector__SWIG_2(self, argc, argv);
    }
  }
  if (argc == 1) {
    int _v;
    int res = swig::asptr(argv[0], (std::vector< pj::VideoDevInfo*,std::allocator< pj::VideoDevInfo * > >**)(0));
    _v = SWIG_CheckState(res);
    if (_v) {
      return _wrap_new_VideoDevInfoVector__SWIG_1(self, argc, argv);
    }
  }
  if (argc == 2) {
    int _v;
    {
      int res = SWIG_AsVal_size_t(argv[0], NULL);
      _v = SWIG_CheckState(res);
    }
    if (_v) {
      void *vptr = 0;
      int res = SWIG_ConvertPtr(argv[1], &vptr, SWIGTYPE_p_pj__VideoDevInfo, 0);
      _v = SWIG_CheckState(res);
      if (_v) {
        return _wrap_new_VideoDevInfoVector__SWIG_3(self, argc, argv);
      }
    }
  }
  
fail:
  SWIG_Python_RaiseOrModifyTypeError("Wrong number or type of arguments for overloaded function 'new_VideoDevInfoVector'.\n"
    "  Possible C/C++ prototypes are:\n"
    "    std::vector< pj::VideoDevInfo * >::vector()\n"
    "    std::vector< pj::VideoDevInfo * >::vector(std::vector< pj::VideoDevInfo * > const &)\n"
    "    std::vector< pj::VideoDevInfo * >::vector(std::vector< pj::VideoDevInfo * >::size_type)\n"
    "    std::vector< pj::VideoDevInfo * >::vector(std::vector< pj::VideoDevInfo * >::size_type,std::vector< pj::VideoDevInfo * >::value_type)\n");
  return 0;
}


SWIGINTERN PyObject *_wrap_VideoDevInfoVector_push_back(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  std::vector< pj::VideoDevInfo * > *arg1 = (std::vector< pj::VideoDevInfo * > *) 0 ;
  std::vector< pj::VideoDevInfo * >::value_type arg2 = (std::vector< pj::VideoDevInfo * >::value_type) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  void *argp2 = 0 ;
  int res2 = 0 ;
  PyObject *swig_obj[2] ;
  
  if (!SWIG_Python_UnpackTuple(args, "VideoDevInfoVector_push_back", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__vectorT_pj__VideoDevInfo_p_std__allocatorT_pj__VideoDevInfo_p_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "VideoDevInfoVector_push_back" "', argument " "1"" of type '" "std::vector< pj::VideoDevInfo * > *""'"); 
  }
  arg1 = reinterpret_cast< std::vector< pj::VideoDevInfo * > * >(argp1);
  res2 = SWIG_ConvertPtr(swig_obj[1], &argp2,SWIGTYPE_p_pj__VideoDevInfo, 0 |  0 );
  if (!SWIG_IsOK(res2)) {
    SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "VideoDevInfoVector_push_back" "', argument " "2"" of type '" "std::vector< pj::VideoDevInfo * >::value_type""'"); 
  }
  arg2 = reinterpret_cast< std::vector< pj::VideoDevInfo * >::value_type >(argp2);
  (arg1)->push_back(arg2);
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_VideoDevInfoVector_front(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  std::vector< pj::VideoDevInfo * > *arg1 = (std::vector< pj::VideoDevInfo * > *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  std::vector< pj::VideoDevInfo * >::value_type result;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__vectorT_pj__VideoDevInfo_p_std__allocatorT_pj__VideoDevInfo_p_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "VideoDevInfoVector_front" "', argument " "1"" of type '" "std::vector< pj::VideoDevInfo * > const *""'"); 
  }
  arg1 = reinterpret_cast< std::vector< pj::VideoDevInfo * > * >(argp1);
  result = (std::vector< pj::VideoDevInfo * >::value_type)((std::vector< pj::VideoDevInfo * > const *)arg1)->front();
  resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(result), SWIGTYPE_p_pj__VideoDevInfo, 0 |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_VideoDevInfoVector_back(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  std::vector< pj::VideoDevInfo * > *arg1 = (std::vector< pj::VideoDevInfo * > *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  std::vector< pj::VideoDevInfo * >::value_type result;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__vectorT_pj__VideoDevInfo_p_std__allocatorT_pj__VideoDevInfo_p_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "VideoDevInfoVector_back" "', argument " "1"" of type '" "std::vector< pj::VideoDevInfo * > const *""'"); 
  }
  arg1 = reinterpret_cast< std::vector< pj::VideoDevInfo * > * >(argp1);
  result = (std::vector< pj::VideoDevInfo * >::value_type)((std::vector< pj::VideoDevInfo * > const *)arg1)->back();
  resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(result), SWIGTYPE_p_pj__VideoDevInfo, 0 |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_VideoDevInfoVector_assign(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  std::vector< pj::VideoDevInfo * > *arg1 = (std::vector< pj::VideoDevInfo * > *) 0 ;
  std::vector< pj::VideoDevInfo * >::size_type arg2 ;
  std::vector< pj::VideoDevInfo * >::value_type arg3 = (std::vector< pj::VideoDevInfo * >::value_type) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  size_t val2 ;
  int ecode2 = 0 ;
  void *argp3 = 0 ;
  int res3 = 0 ;
  PyObject *swig_obj[3] ;
  
  if (!SWIG_Python_UnpackTuple(args, "VideoDevInfoVector_assign", 3, 3, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__vectorT_pj__VideoDevInfo_p_std__allocatorT_pj__VideoDevInfo_p_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "VideoDevInfoVector_assign" "', argument " "1"" of type '" "std::vector< pj::VideoDevInfo * > *""'"); 
  }
  arg1 = reinterpret_cast< std::vector< pj::VideoDevInfo * > * >(argp1);
  ecode2 = SWIG_AsVal_size_t(swig_obj[1], &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "VideoDevInfoVector_assign" "', argument " "2"" of type '" "std::vector< pj::VideoDevInfo * >::size_type""'");
  } 
  arg2 = static_cast< std::vector< pj::VideoDevInfo * >::size_type >(val2);
  res3 = SWIG_ConvertPtr(swig_obj[2], &argp3,SWIGTYPE_p_pj__VideoDevInfo, 0 |  0 );
  if (!SWIG_IsOK(res3)) {
    SWIG_exception_fail(SWIG_ArgError(res3), "in method '" "VideoDevInfoVector_assign" "', argument " "3"" of type '" "std::vector< pj::VideoDevInfo * >::value_type""'"); 
  }
  arg3 = reinterpret_cast< std::vector< pj::VideoDevInfo * >::value_type >(argp3);
  (arg1)->assign(arg2,arg3);
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_VideoDevInfoVector_resize__SWIG_1(PyObject *SWIGUNUSEDPARM(self), Py_ssize_t nobjs, PyObject **swig_obj) {
  PyObject *resultobj = 0;
  std::vector< pj::VideoDevInfo * > *arg1 = (std::vector< pj::VideoDevInfo * > *) 0 ;
  std::vector< pj::VideoDevInfo * >::size_type arg2 ;
  std::vector< pj::VideoDevInfo * >::value_type arg3 = (std::vector< pj::VideoDevInfo * >::value_type) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  size_t val2 ;
  int ecode2 = 0 ;
  void *argp3 = 0 ;
  int res3 = 0 ;
  
  if ((nobjs < 3) || (nobjs > 3)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__vectorT_pj__VideoDevInfo_p_std__allocatorT_pj__VideoDevInfo_p_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "VideoDevInfoVector_resize" "', argument " "1"" of type '" "std::vector< pj::VideoDevInfo * > *""'"); 
  }
  arg1 = reinterpret_cast< std::vector< pj::VideoDevInfo * > * >(argp1);
  ecode2 = SWIG_AsVal_size_t(swig_obj[1], &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "VideoDevInfoVector_resize" "', argument " "2"" of type '" "std::vector< pj::VideoDevInfo * >::size_type""'");
  } 
  arg2 = static_cast< std::vector< pj::VideoDevInfo * >::size_type >(val2);
  res3 = SWIG_ConvertPtr(swig_obj[2], &argp3,SWIGTYPE_p_pj__VideoDevInfo, 0 |  0 );
  if (!SWIG_IsOK(res3)) {
    SWIG_exception_fail(SWIG_ArgError(res3), "in method '" "VideoDevInfoVector_resize" "', argument " "3"" of type '" "std::vector< pj::VideoDevInfo * >::value_type""'"); 
  }
  arg3 = reinterpret_cast< std::vector< pj::VideoDevInfo * >::value_type >(argp3);
  (arg1)->resize(arg2,arg3);
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_VideoDevInfoVector_resize(PyObject *self, PyObject *args) {
  Py_ssize_t argc;
  PyObject *argv[4] = {
    0
  };
  
  if (!(argc = SWIG_Python_UnpackTuple(args, "VideoDevInfoVector_resize", 0, 3, argv))) SWIG_fail;
  --argc;
  if (argc == 2) {
    int _v;
    int res = swig::asptr(argv[0], (std::vector< pj::VideoDevInfo*,std::allocator< pj::VideoDevInfo * > >**)(0));
    _v = SWIG_CheckState(res);
    if (_v) {
      {
        int res = SWIG_AsVal_size_t(argv[1], NULL);
        _v = SWIG_CheckState(res);
      }
      if (_v) {
        return _wrap_VideoDevInfoVector_resize__SWIG_0(self, argc, argv);
      }
    }
  }
  if (argc == 3) {
    int _v;
    int res = swig::asptr(argv[0], (std::vector< pj::VideoDevInfo*,std::allocator< pj::VideoDevInfo * > >**)(0));
    _v = SWIG_CheckState(res);
    if (_v) {
      {
        int res = SWIG_AsVal_size_t(argv[1], NULL);
        _v = SWIG_CheckState(res);
      }
      if (_v) {
        void *vptr = 0;
        int res = SWIG_ConvertPtr(argv[2], &vptr, SWIGTYPE_p_pj__VideoDevInfo, 0);
        _v = SWIG_CheckState(res);
        if (_v) {
          return _wrap_VideoDevInfoVector_resize__SWIG_1(self, argc, argv);
        }
      }
    }
  }
  
fail:
  SWIG_Python_RaiseOrModifyTypeError("Wrong number or type of arguments for overloaded function 'VideoDevInfoVector_resize'.\n"
    "  Possible C/C++ prototypes are:\n"
    "    std::vector< pj::VideoDevInfo * >::resize(std::vector< pj::VideoDevInfo * >::size_type)\n"
    "    std::vector< pj::VideoDevInfo * >::resize(std::vector< pj::VideoDevInfo * >::size_type,std::vector< pj::VideoDevInfo * >::value_type)\n");
  return 0;
}


SWIGINTERN PyObject *_wrap_VideoDevInfoVector_insert__SWIG_0(PyObject *SWIGUNUSEDPARM(self), Py_ssize_t nobjs, PyObject **swig_obj) {
  PyObject *resultobj = 0;
  std::vector< pj::VideoDevInfo * > *arg1 = (std::vector< pj::VideoDevInfo * > *) 0 ;
  std::vector< pj::VideoDevInfo * >::iterator arg2 ;
  std::vector< pj::VideoDevInfo * >::value_type arg3 = (std::vector< pj::VideoDevInfo * >::value_type) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  swig::SwigPyIterator *iter2 = 0 ;
  int res2 ;
  void *argp3 = 0 ;
  int res3 = 0 ;
  std::vector< pj::VideoDevInfo * >::iterator result;
  
  if ((nobjs < 3) || (nobjs > 3)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__vectorT_pj__VideoDevInfo_p_std__allocatorT_pj__VideoDevInfo_p_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "VideoDevInfoVector_insert" "', argument " "1"" of type '" "std::vector< pj::VideoDevInfo * > *""'"); 
  }
  arg1 = reinterpret_cast< std::vector< pj::VideoDevInfo * > * >(argp1);
  res2 = SWIG_ConvertPtr(swig_obj[1], SWIG_as_voidptrptr(&iter2), swig::SwigPyIterator::descriptor(), 0);
  if (!SWIG_IsOK(res2) || !iter2) {
    SWIG_exception_fail(SWIG_ArgError(SWIG_TypeError), "in method '" "VideoDevInfoVector_insert" "', argument " "2"" of type '" "std::vector< pj::VideoDevInfo * >::iterator""'");
  } else {
    swig::SwigPyIterator_T<std::vector< pj::VideoDevInfo * >::iterator > *iter_t = dynamic_cast<swig::SwigPyIterator_T<std::vector< pj::VideoDevInfo * >::iterator > *>(iter2);
    if (iter_t) {
      arg2 = iter_t->get_current();
    } else {
      SWIG_exception_fail(SWIG_ArgError(SWIG_TypeError), "in method '" "VideoDevInfoVector_insert" "', argument " "2"" of type '" "std::vector< pj::VideoDevInfo * >::iterator""'");
    }
  }
  res3 = SWIG_ConvertPtr(swig_obj[2], &argp3,SWIGTYPE_p_pj__VideoDevInfo, 0 |  0 );
  if (!SWIG_IsOK(res3)) {
    SWIG_exception_fail(SWIG_ArgError(res3), "in method '" "VideoDevInfoVector_insert" "', argument " "3"" of type '" "std::vector< pj::VideoDevInfo * >::value_type""'"); 
  }
  arg3 = reinterpret_cast< std::vector< pj::VideoDevInfo * >::value_type >(argp3);
  result = std_vector_Sl_pj_VideoDevInfo_Sm__Sg__insert__SWIG_0(arg1,arg2,arg3);
  resultobj = SWIG_NewPointerObj(swig::make_output_iterator(static_cast< const std::vector< pj::VideoDevInfo * >::iterator & >(result)),
    swig::SwigPyIterator::descriptor(),SWIG_POINTER_OWN);
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_VideoDevInfoVector_insert__SWIG_1(PyObject *SWIGUNUSEDPARM(self), Py_ssize_t nobjs, PyObject **swig_obj) {
  PyObject *resultobj = 0;
  std::vector< pj::VideoDevInfo * > *arg1 = (std::vector< pj::VideoDevInfo * > *) 0 ;
  std::vector< pj::VideoDevInfo * >::iterator arg2 ;
  std::vector< pj::VideoDevInfo * >::size_type arg3 ;
  std::vector< pj::VideoDevInfo * >::value_type arg4 = (std::vector< pj::VideoDevInfo * >::value_type) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  swig::SwigPyIterator *iter2 = 0 ;
  int res2 ;
  size_t val3 ;
  int ecode3 = 0 ;
  void *argp4 = 0 ;
  int res4 = 0 ;
  
  if ((nobjs < 4) || (nobjs > 4)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__vectorT_pj__VideoDevInfo_p_std__allocatorT_pj__VideoDevInfo_p_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "VideoDevInfoVector_insert" "', argument " "1"" of type '" "std::vector< pj::VideoDevInfo * > *""'"); 
  }
  arg1 = reinterpret_cast< std::vector< pj::VideoDevInfo * > * >(argp1);
  res2 = SWIG_ConvertPtr(swig_obj[1], SWIG_as_voidptrptr(&iter2), swig::SwigPyIterator::descriptor(), 0);
  if (!SWIG_IsOK(res2) || !iter2) {
    SWIG_exception_fail(SWIG_ArgError(SWIG_TypeError), "in method '" "VideoDevInfoVector_insert" "', argument " "2"" of type '" "std::vector< pj::VideoDevInfo * >::iterator""'");
  } else {
    swig::SwigPyIterator_T<std::vector< pj::VideoDevInfo * >::iterator > *iter_t = dynamic_cast<swig::SwigPyIterator_T<std::vector< pj::VideoDevInfo * >::iterator > *>(iter2);
    if (iter_t) {
      arg2 = iter_t->get_current();
    } else {
      SWIG_exception_fail(SWIG_ArgError(SWIG_TypeError), "in method '" "VideoDevInfoVector_insert" "', argument " "2"" of type '" "std::vector< pj::VideoDevInfo * >::iterator""'");
    }
  }
  ecode3 = SWIG_AsVal_size_t(swig_obj[2], &val3);
  if (!SWIG_IsOK(ecode3)) {
    SWIG_exception_fail(SWIG_ArgError(ecode3), "in method '" "VideoDevInfoVector_insert" "', argument " "3"" of type '" "std::vector< pj::VideoDevInfo * >::size_type""'");
  } 
  arg3 = static_cast< std::vector< pj::VideoDevInfo * >::size_type >(val3);
  res4 = SWIG_ConvertPtr(swig_obj[3], &argp4,SWIGTYPE_p_pj__VideoDevInfo, 0 |  0 );
  if (!SWIG_IsOK(res4)) {
    SWIG_exception_fail(SWIG_ArgError(res4), "in method '" "VideoDevInfoVector_insert" "', argument " "4"" of type '" "std::vector< pj::VideoDevInfo * >::value_type""'"); 
  }
  arg4 = reinterpret_cast< std::vector< pj::VideoDevInfo * >::value_type >(argp4);
  std_vector_Sl_pj_VideoDevInfo_Sm__Sg__insert__SWIG_1(arg1,arg2,arg3,arg4);
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_VideoDevInfoVector_insert(PyObject *self, PyObject *args) {
  Py_ssize_t argc;
  PyObject *argv[5] = {
    0
  };
  
  if (!(argc = SWIG_Python_UnpackTuple(args, "VideoDevInfoVector_insert", 0, 4, argv))) SWIG_fail;
  --argc;
  if (argc == 3) {
    int _v;
    int res = swig::asptr(argv[0], (std::vector< pj::VideoDevInfo*,std::allocator< pj::VideoDevInfo * > >**)(0));
    _v = SWIG_CheckState(res);
    if (_v) {
      swig::SwigPyIterator *iter = 0;
      int res = SWIG_ConvertPtr(argv[1], SWIG_as_voidptrptr(&iter), swig::SwigPyIterator::descriptor(), 0);
      _v = (SWIG_IsOK(res) && iter && (dynamic_cast<swig::SwigPyIterator_T<std::vector< pj::VideoDevInfo * >::iterator > *>(iter) != 0));
      if (_v) {
        void *vptr = 0;
        int res = SWIG_ConvertPtr(argv[2], &vptr, SWIGTYPE_p_pj__VideoDevInfo, 0);
        _v = SWIG_CheckState(res);
        if (_v) {
          return _wrap_VideoDevInfoVector_insert__SWIG_0(self, argc, argv);
        }
      }
    }
  }
  if (argc == 4) {
    int _v;
    int res = swig::asptr(argv[0], (std::vector< pj::VideoDevInfo*,std::allocator< pj::VideoDevInfo * > >**)(0));
    _v = SWIG_CheckState(res);
    if (_v) {
      swig::SwigPyIterator *iter = 0;
      int res = SWIG_ConvertPtr(argv[1], SWIG_as_voidptrptr(&iter), swig::SwigPyIterator::descriptor(), 0);
      _v = (SWIG_IsOK(res) && iter && (dynamic_cast<swig::SwigPyIterator_T<std::vector< pj::VideoDevInfo * >::iterator > *>(iter) != 0));
      if (_v) {
        {
          int res = SWIG_AsVal_size_t(argv[2], NULL);
          _v = SWIG_CheckState(res);
        }
        if (_v) {
          void *vptr = 0;
          int res = SWIG_ConvertPtr(argv[3], &vptr, SWIGTYPE_p_pj__VideoDevInfo, 0);
          _v = SWIG_CheckState(res);
          if (_v) {
            return _wrap_VideoDevInfoVector_insert__SWIG_1(self, argc, argv);
          }
        }
      }
    }
  }
  
fail:
  SWIG_Python_RaiseOrModifyTypeError("Wrong number or type of arguments for overloaded function 'VideoDevInfoVector_insert'.\n"
    "  Possible C/C++ prototypes are:\n"
    "    std::vector< pj::VideoDevInfo * >::insert(std::vector< pj::VideoDevInfo * >::iterator,std::vector< pj::VideoDevInfo * >::value_type)\n"
    "    std::vector< pj::VideoDevInfo * >::insert(std::vector< pj::VideoDevInfo * >::iterator,std::vector< pj::VideoDevInfo * >::size_type,std::vector< pj::VideoDevInfo * >::value_type)\n");
  return 0;
}


SWIGINTERN PyObject *_wrap_VideoDevInfoVector_reserve(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  std::vector< pj::VideoDevInfo * > *arg1 = (std::vector< pj::VideoDevInfo * > *) 0 ;
  std::vector< pj::VideoDevInfo * >::size_type arg2 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  size_t val2 ;
  int ecode2 = 0 ;
  PyObject *swig_obj[2] ;
  
  if (!SWIG_Python_UnpackTuple(args, "VideoDevInfoVector_reserve", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__vectorT_pj__VideoDevInfo_p_std__allocatorT_pj__VideoDevInfo_p_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "VideoDevInfoVector_reserve" "', argument " "1"" of type '" "std::vector< pj::VideoDevInfo * > *""'"); 
  }
  arg1 = reinterpret_cast< std::vector< pj::VideoDevInfo * > * >(argp1);
  ecode2 = SWIG_AsVal_size_t(swig_obj[1], &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "VideoDevInfoVector_reserve" "', argument " "2"" of type '" "std::vector< pj::VideoDevInfo * >::size_type""'");
  } 
  arg2 = static_cast< std::vector< pj::VideoDevInfo * >::size_type >(val2);
  (arg1)->reserve(arg2);
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_VideoDevInfoVector_capacity(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  std::vector< pj::VideoDevInfo * > *arg1 = (std::vector< pj::VideoDevInfo * > *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  std::vector< pj::VideoDevInfo * >::size_type result;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__vectorT_pj__VideoDevInfo_p_std__allocatorT_pj__VideoDevInfo_p_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "VideoDevInfoVector_capacity" "', argument " "1"" of type '" "std::vector< pj::VideoDevInfo * > const *""'"); 
  }
  arg1 = reinterpret_cast< std::vector< pj::VideoDevInfo * > * >(argp1);
  result = ((std::vector< pj::VideoDevInfo * > const *)arg1)->capacity();
  resultobj = SWIG_From_size_t(static_cast< size_t >(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_delete_VideoDevInfoVector(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  std::vector< pj::VideoDevInfo * > *arg1 = (std::vector< pj::VideoDevInfo * > *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__vectorT_pj__VideoDevInfo_p_std__allocatorT_pj__VideoDevInfo_p_t_t, SWIG_POINTER_DISOWN |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "delete_VideoDevInfoVector" "', argument " "1"" of type '" "std::vector< pj::VideoDevInfo * > *""'"); 
  }
  arg1 = reinterpret_cast< std::vector< pj::VideoDevInfo * > * >(argp1);
  delete arg1;
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *VideoDevInfoVector_swigregister(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *obj;
  if (!SWIG_Python_UnpackTuple(args, "swigregister", 1, 1, &obj)) return NULL;
  SWIG_TypeNewClientData(SWIGTYPE_p_std__vectorT_pj__VideoDevInfo_p_std__allocatorT_pj__VideoDevInfo_p_t_t, SWIG_NewClientData(obj));
  return SWIG_Py_Void();
}

SWIGINTERN PyObject *VideoDevInfoVector_swiginit(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  return SWIG_Python_InitShadowInstance(args);
}

SWIGINTERN PyObject *_wrap_VideoDevInfoVector2_iterator(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  std::vector< pj::VideoDevInfo > *arg1 = (std::vector< pj::VideoDevInfo > *) 0 ;
  PyObject **arg2 = (PyObject **) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  swig::SwigPyIterator *result = 0 ;
  
  arg2 = &swig_obj[0];
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__vectorT_pj__VideoDevInfo_std__allocatorT_pj__VideoDevInfo_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "VideoDevInfoVector2_iterator" "', argument " "1"" of type '" "std::vector< pj::VideoDevInfo > *""'"); 
  }
  arg1 = reinterpret_cast< std::vector< pj::VideoDevInfo > * >(argp1);
  result = (swig::SwigPyIterator *)std_vector_Sl_pj_VideoDevInfo_Sg__iterator(arg1,arg2);
  resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(result), SWIGTYPE_p_swig__SwigPyIterator, SWIG_POINTER_OWN |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_VideoDevInfoVector2___nonzero__(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  std::vector< pj::VideoDevInfo > *arg1 = (std::vector< pj::VideoDevInfo > *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  bool result;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__vectorT_pj__VideoDevInfo_std__allocatorT_pj__VideoDevInfo_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "VideoDevInfoVector2___nonzero__" "', argument " "1"" of type '" "std::vector< pj::VideoDevInfo > const *""'"); 
  }
  arg1 = reinterpret_cast< std::vector< pj::VideoDevInfo > * >(argp1);
  result = (bool)std_vector_Sl_pj_VideoDevInfo_Sg____nonzero__((std::vector< pj::VideoDevInfo > const *)arg1);
  resultobj = SWIG_From_bool(static_cast< bool >(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_VideoDevInfoVector2___bool__(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  std::vector< pj::VideoDevInfo > *arg1 = (std::vector< pj::VideoDevInfo > *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  bool result;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__vectorT_pj__VideoDevInfo_std__allocatorT_pj__VideoDevInfo_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "VideoDevInfoVector2___bool__" "', argument " "1"" of type '" "std::vector< pj::VideoDevInfo > const *""'"); 
  }
  arg1 = reinterpret_cast< std::vector< pj::VideoDevInfo > * >(argp1);
  result = (bool)std_vector_Sl_pj_VideoDevInfo_Sg____bool__((std::vector< pj::VideoDevInfo > const *)arg1);
  resultobj = SWIG_From_bool(static_cast< bool >(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_VideoDevInfoVector2___len__(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  std::vector< pj::VideoDevInfo > *arg1 = (std::vector< pj::VideoDevInfo > *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  std::vector< pj::VideoDevInfo >::size_type result;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__vectorT_pj__VideoDevInfo_std__allocatorT_pj__VideoDevInfo_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "VideoDevInfoVector2___len__" "', argument " "1"" of type '" "std::vector< pj::VideoDevInfo > const *""'"); 
  }
  arg1 = reinterpret_cast< std::vector< pj::VideoDevInfo > * >(argp1);
  result = std_vector_Sl_pj_VideoDevInfo_Sg____len__((std::vector< pj::VideoDevInfo > const *)arg1);
  resultobj = SWIG_From_size_t(static_cast< size_t >(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_VideoDevInfoVector2___getslice__(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  std::vector< pj::VideoDevInfo > *arg1 = (std::vector< pj::VideoDevInfo > *) 0 ;
  std::vector< pj::VideoDevInfo >::difference_type arg2 ;
  std::vector< pj::VideoDevInfo >::difference_type arg3 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  ptrdiff_t val2 ;
  int ecode2 = 0 ;
  ptrdiff_t val3 ;
  int ecode3 = 0 ;
  PyObject *swig_obj[3] ;
  std::vector< pj::VideoDevInfo,std::allocator< pj::VideoDevInfo > > *result = 0 ;
  
  if (!SWIG_Python_UnpackTuple(args, "VideoDevInfoVector2___getslice__", 3, 3, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__vectorT_pj__VideoDevInfo_std__allocatorT_pj__VideoDevInfo_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "VideoDevInfoVector2___getslice__" "', argument " "1"" of type '" "std::vector< pj::VideoDevInfo > *""'"); 
  }
  arg1 = reinterpret_cast< std::vector< pj::VideoDevInfo > * >(argp1);
  ecode2 = SWIG_AsVal_ptrdiff_t(swig_obj[1], &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "VideoDevInfoVector2___getslice__" "', argument " "2"" of type '" "std::vector< pj::VideoDevInfo >::difference_type""'");
  } 
  arg2 = static_cast< std::vector< pj::VideoDevInfo >::difference_type >(val2);
  ecode3 = SWIG_AsVal_ptrdiff_t(swig_obj[2], &val3);
  if (!SWIG_IsOK(ecode3)) {
    SWIG_exception_fail(SWIG_ArgError(ecode3), "in method '" "VideoDevInfoVector2___getslice__" "', argument " "3"" of type '" "std::vector< pj::VideoDevInfo >::difference_type""'");
  } 
  arg3 = static_cast< std::vector< pj::VideoDevInfo >::difference_type >(val3);
  try {
    result = (std::vector< pj::VideoDevInfo,std::allocator< pj::VideoDevInfo > > *)std_vector_Sl_pj_VideoDevInfo_Sg____getslice__(arg1,arg2,arg3);
  } catch(std::out_of_range &_e) {
    SWIG_exception_fail(SWIG_IndexError, (&_e)->what());
  } catch(std::invalid_argument &_e) {
    SWIG_exception_fail(SWIG_ValueError, (&_e)->what());
  }
  resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(result), SWIGTYPE_p_std__vectorT_pj__VideoDevInfo_std__allocatorT_pj__VideoDevInfo_t_t, SWIG_POINTER_OWN |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_VideoDevInfoVector2___setslice____SWIG_0(PyObject *SWIGUNUSEDPARM(self), Py_ssize_t nobjs, PyObject **swig_obj) {
  PyObject *resultobj = 0;
  std::vector< pj::VideoDevInfo > *arg1 = (std::vector< pj::VideoDevInfo > *) 0 ;
  std::vector< pj::VideoDevInfo >::difference_type arg2 ;
  std::vector< pj::VideoDevInfo >::difference_type arg3 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  ptrdiff_t val2 ;
  int ecode2 = 0 ;
  ptrdiff_t val3 ;
  int ecode3 = 0 ;
  
  if ((nobjs < 3) || (nobjs > 3)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__vectorT_pj__VideoDevInfo_std__allocatorT_pj__VideoDevInfo_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "VideoDevInfoVector2___setslice__" "', argument " "1"" of type '" "std::vector< pj::VideoDevInfo > *""'"); 
  }
  arg1 = reinterpret_cast< std::vector< pj::VideoDevInfo > * >(argp1);
  ecode2 = SWIG_AsVal_ptrdiff_t(swig_obj[1], &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "VideoDevInfoVector2___setslice__" "', argument " "2"" of type '" "std::vector< pj::VideoDevInfo >::difference_type""'");
  } 
  arg2 = static_cast< std::vector< pj::VideoDevInfo >::difference_type >(val2);
  ecode3 = SWIG_AsVal_ptrdiff_t(swig_obj[2], &val3);
  if (!SWIG_IsOK(ecode3)) {
    SWIG_exception_fail(SWIG_ArgError(ecode3), "in method '" "VideoDevInfoVector2___setslice__" "', argument " "3"" of type '" "std::vector< pj::VideoDevInfo >::difference_type""'");
  } 
  arg3 = static_cast< std::vector< pj::VideoDevInfo >::difference_type >(val3);
  try {
    std_vector_Sl_pj_VideoDevInfo_Sg____setslice____SWIG_0(arg1,arg2,arg3);
  } catch(std::out_of_range &_e) {
    SWIG_exception_fail(SWIG_IndexError, (&_e)->what());
  } catch(std::invalid_argument &_e) {
    SWIG_exception_fail(SWIG_ValueError, (&_e)->what());
  }
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_VideoDevInfoVector2___setslice____SWIG_1(PyObject *SWIGUNUSEDPARM(self), Py_ssize_t nobjs, PyObject **swig_obj) {
  PyObject *resultobj = 0;
  std::vector< pj::VideoDevInfo > *arg1 = (std::vector< pj::VideoDevInfo > *) 0 ;
  std::vector< pj::VideoDevInfo >::difference_type arg2 ;
  std::vector< pj::VideoDevInfo >::difference_type arg3 ;
  std::vector< pj::VideoDevInfo,std::allocator< pj::VideoDevInfo > > *arg4 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  ptrdiff_t val2 ;
  int ecode2 = 0 ;
  ptrdiff_t val3 ;
  int ecode3 = 0 ;
  int res4 = SWIG_OLDOBJ ;
  
  if ((nobjs < 4) || (nobjs > 4)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__vectorT_pj__VideoDevInfo_std__allocatorT_pj__VideoDevInfo_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "VideoDevInfoVector2___setslice__" "', argument " "1"" of type '" "std::vector< pj::VideoDevInfo > *""'"); 
  }
  arg1 = reinterpret_cast< std::vector< pj::VideoDevInfo > * >(argp1);
  ecode2 = SWIG_AsVal_ptrdiff_t(swig_obj[1], &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "VideoDevInfoVector2___setslice__" "', argument " "2"" of type '" "std::vector< pj::VideoDevInfo >::difference_type""'");
  } 
  arg2 = static_cast< std::vector< pj::VideoDevInfo >::difference_type >(val2);
  ecode3 = SWIG_AsVal_ptrdiff_t(swig_obj[2], &val3);
  if (!SWIG_IsOK(ecode3)) {
    SWIG_exception_fail(SWIG_ArgError(ecode3), "in method '" "VideoDevInfoVector2___setslice__" "', argument " "3"" of type '" "std::vector< pj::VideoDevInfo >::difference_type""'");
  } 
  arg3 = static_cast< std::vector< pj::VideoDevInfo >::difference_type >(val3);
  {
    std::vector< pj::VideoDevInfo,std::allocator< pj::VideoDevInfo > > *ptr = (std::vector< pj::VideoDevInfo,std::allocator< pj::VideoDevInfo > > *)0;
    res4 = swig::asptr(swig_obj[3], &ptr);
    if (!SWIG_IsOK(res4)) {
      SWIG_exception_fail(SWIG_ArgError(res4), "in method '" "VideoDevInfoVector2___setslice__" "', argument " "4"" of type '" "std::vector< pj::VideoDevInfo,std::allocator< pj::VideoDevInfo > > const &""'"); 
    }
    if (!ptr) {
      SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "VideoDevInfoVector2___setslice__" "', argument " "4"" of type '" "std::vector< pj::VideoDevInfo,std::allocator< pj::VideoDevInfo > > const &""'"); 
    }
    arg4 = ptr;
  }
  try {
    std_vector_Sl_pj_VideoDevInfo_Sg____setslice____SWIG_1(arg1,arg2,arg3,(std::vector< pj::VideoDevInfo,std::allocator< pj::VideoDevInfo > > const &)*arg4);
  } catch(std::out_of_range &_e) {
    SWIG_exception_fail(SWIG_IndexError, (&_e)->what());
  } catch(std::invalid_argument &_e) {
    SWIG_exception_fail(SWIG_ValueError, (&_e)->what());
  }
  resultobj = SWIG_Py_Void();
  if (SWIG_IsNewObj(res4)) delete arg4;
  return resultobj;
fail:
  if (SWIG_IsNewObj(res4)) delete arg4;
  return NULL;
}


SWIGINTERN PyObject *_wrap_VideoDevInfoVector2___setslice__(PyObject *self, PyObject *args) {
  Py_ssize_t argc;
  PyObject *argv[5] = {
    0
  };
  
  if (!(argc = SWIG_Python_UnpackTuple(args, "VideoDevInfoVector2___setslice__", 0, 4, argv))) SWIG_fail;
  --argc;
  if (argc == 3) {
    int _v;
    int res = swig::asptr(argv[0], (std::vector< pj::VideoDevInfo,std::allocator< pj::VideoDevInfo > >**)(0));
    _v = SWIG_CheckState(res);
    if (_v) {
      {
        int res = SWIG_AsVal_ptrdiff_t(argv[1], NULL);
        _v = SWIG_CheckState(res);
      }
      if (_v) {
        {
          int res = SWIG_AsVal_ptrdiff_t(argv[2], NULL);
          _v = SWIG_CheckState(res);
        }
        if (_v) {
          return _wrap_VideoDevInfoVector2___setslice____SWIG_0(self, argc, argv);
        }
      }
    }
  }
  if (argc == 4) {
    int _v;
    int res = swig::asptr(argv[0], (std::vector< pj::VideoDevInfo,std::allocator< pj::VideoDevInfo > >**)(0));
    _v = SWIG_CheckState(res);
    if (_v) {
      {
        int res = SWIG_AsVal_ptrdiff_t(argv[1], NULL);
        _v = SWIG_CheckState(res);
      }
      if (_v) {
        {
          int res = SWIG_AsVal_ptrdiff_t(argv[2], NULL);
          _v = SWIG_CheckState(res);
        }
        if (_v) {
          int res = swig::asptr(argv[3], (std::vector< pj::VideoDevInfo,std::allocator< pj::VideoDevInfo > >**)(0));
          _v = SWIG_CheckState(res);
          if (_v) {
            return _wrap_VideoDevInfoVector2___setslice____SWIG_1(self, argc, argv);
          }
        }
      }
    }
  }
  
fail:
  SWIG_Python_RaiseOrModifyTypeError("Wrong number or type of arguments for overloaded function 'VideoDevInfoVector2___setslice__'.\n"
    "  Possible C/C++ prototypes are:\n"
    "    std::vector< pj::VideoDevInfo >::__setslice__(std::vector< pj::VideoDevInfo >::difference_type,std::vector< pj::VideoDevInfo >::difference_type)\n"
    "    std::vector< pj::VideoDevInfo >::__setslice__(std::vector< pj::VideoDevInfo >::difference_type,std::vector< pj::VideoDevInfo >::difference_type,std::vector< pj::VideoDevInfo,std::allocator< pj::VideoDevInfo > > const &)\n");
  return 0;
}


SWIGINTERN PyObject *_wrap_VideoDevInfoVector2___delslice__(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  std::vector< pj::VideoDevInfo > *arg1 = (std::vector< pj::VideoDevInfo > *) 0 ;
  std::vector< pj::VideoDevInfo >::difference_type arg2 ;
  std::vector< pj::VideoDevInfo >::difference_type arg3 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  ptrdiff_t val2 ;
  int ecode2 = 0 ;
  ptrdiff_t val3 ;
  int ecode3 = 0 ;
  PyObject *swig_obj[3] ;
  
  if (!SWIG_Python_UnpackTuple(args, "VideoDevInfoVector2___delslice__", 3, 3, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__vectorT_pj__VideoDevInfo_std__allocatorT_pj__VideoDevInfo_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "VideoDevInfoVector2___delslice__" "', argument " "1"" of type '" "std::vector< pj::VideoDevInfo > *""'"); 
  }
  arg1 = reinterpret_cast< std::vector< pj::VideoDevInfo > * >(argp1);
  ecode2 = SWIG_AsVal_ptrdiff_t(swig_obj[1], &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "VideoDevInfoVector2___delslice__" "', argument " "2"" of type '" "std::vector< pj::VideoDevInfo >::difference_type""'");
  } 
  arg2 = static_cast< std::vector< pj::VideoDevInfo >::difference_type >(val2);
  ecode3 = SWIG_AsVal_ptrdiff_t(swig_obj[2], &val3);
  if (!SWIG_IsOK(ecode3)) {
    SWIG_exception_fail(SWIG_ArgError(ecode3), "in method '" "VideoDevInfoVector2___delslice__" "', argument " "3"" of type '" "std::vector< pj::VideoDevInfo >::difference_type""'");
  } 
  arg3 = static_cast< std::vector< pj::VideoDevInfo >::difference_type >(val3);
  try {
    std_vector_Sl_pj_VideoDevInfo_Sg____delslice__(arg1,arg2,arg3);
  } catch(std::out_of_range &_e) {
    SWIG_exception_fail(SWIG_IndexError, (&_e)->what());
  } catch(std::invalid_argument &_e) {
    SWIG_exception_fail(SWIG_ValueError, (&_e)->what());
  }
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_VideoDevInfoVector2___delitem____SWIG_0(PyObject *SWIGUNUSEDPARM(self), Py_ssize_t nobjs, PyObject **swig_obj) {
  PyObject *resultobj = 0;
  std::vector< pj::VideoDevInfo > *arg1 = (std::vector< pj::VideoDevInfo > *) 0 ;
  std::vector< pj::VideoDevInfo >::difference_type arg2 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  ptrdiff_t val2 ;
  int ecode2 = 0 ;
  
  if ((nobjs < 2) || (nobjs > 2)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__vectorT_pj__VideoDevInfo_std__allocatorT_pj__VideoDevInfo_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "VideoDevInfoVector2___delitem__" "', argument " "1"" of type '" "std::vector< pj::VideoDevInfo > *""'"); 
  }
  arg1 = reinterpret_cast< std::vector< pj::VideoDevInfo > * >(argp1);
  ecode2 = SWIG_AsVal_ptrdiff_t(swig_obj[1], &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "VideoDevInfoVector2___delitem__" "', argument " "2"" of type '" "std::vector< pj::VideoDevInfo >::difference_type""'");
  } 
  arg2 = static_cast< std::vector< pj::VideoDevInfo >::difference_type >(val2);
  try {
    std_vector_Sl_pj_VideoDevInfo_Sg____delitem____SWIG_0(arg1,arg2);
  } catch(std::out_of_range &_e) {
    SWIG_exception_fail(SWIG_IndexError, (&_e)->what());
  } catch(std::invalid_argument &_e) {
    SWIG_exception_fail(SWIG_ValueError, (&_e)->what());
  }
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_VideoDevInfoVector2___getitem____SWIG_0(PyObject *SWIGUNUSEDPARM(self), Py_ssize_t nobjs, PyObject **swig_obj) {
  PyObject *resultobj = 0;
  std::vector< pj::VideoDevInfo > *arg1 = (std::vector< pj::VideoDevInfo > *) 0 ;
  PySliceObject *arg2 = (PySliceObject *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  std::vector< pj::VideoDevInfo,std::allocator< pj::VideoDevInfo > > *result = 0 ;
  
  if ((nobjs < 2) || (nobjs > 2)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__vectorT_pj__VideoDevInfo_std__allocatorT_pj__VideoDevInfo_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "VideoDevInfoVector2___getitem__" "', argument " "1"" of type '" "std::vector< pj::VideoDevInfo > *""'"); 
  }
  arg1 = reinterpret_cast< std::vector< pj::VideoDevInfo > * >(argp1);
  {
    if (!PySlice_Check(swig_obj[1])) {
      SWIG_exception_fail(SWIG_ArgError(SWIG_TypeError), "in method '" "VideoDevInfoVector2___getitem__" "', argument " "2"" of type '" "PySliceObject *""'");
    }
    arg2 = (PySliceObject *) swig_obj[1];
  }
  try {
    result = (std::vector< pj::VideoDevInfo,std::allocator< pj::VideoDevInfo > > *)std_vector_Sl_pj_VideoDevInfo_Sg____getitem____SWIG_0(arg1,arg2);
  } catch(std::out_of_range &_e) {
    SWIG_exception_fail(SWIG_IndexError, (&_e)->what());
  } catch(std::invalid_argument &_e) {
    SWIG_exception_fail(SWIG_ValueError, (&_e)->what());
  }
  resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(result), SWIGTYPE_p_std__vectorT_pj__VideoDevInfo_std__allocatorT_pj__VideoDevInfo_t_t, SWIG_POINTER_OWN |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_VideoDevInfoVector2___setitem____SWIG_0(PyObject *SWIGUNUSEDPARM(self), Py_ssize_t nobjs, PyObject **swig_obj) {
  PyObject *resultobj = 0;
  std::vector< pj::VideoDevInfo > *arg1 = (std::vector< pj::VideoDevInfo > *) 0 ;
  PySliceObject *arg2 = (PySliceObject *) 0 ;
  std::vector< pj::VideoDevInfo,std::allocator< pj::VideoDevInfo > > *arg3 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  int res3 = SWIG_OLDOBJ ;
  
  if ((nobjs < 3) || (nobjs > 3)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__vectorT_pj__VideoDevInfo_std__allocatorT_pj__VideoDevInfo_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "VideoDevInfoVector2___setitem__" "', argument " "1"" of type '" "std::vector< pj::VideoDevInfo > *""'"); 
  }
  arg1 = reinterpret_cast< std::vector< pj::VideoDevInfo > * >(argp1);
  {
    if (!PySlice_Check(swig_obj[1])) {
      SWIG_exception_fail(SWIG_ArgError(SWIG_TypeError), "in method '" "VideoDevInfoVector2___setitem__" "', argument " "2"" of type '" "PySliceObject *""'");
    }
    arg2 = (PySliceObject *) swig_obj[1];
  }
  {
    std::vector< pj::VideoDevInfo,std::allocator< pj::VideoDevInfo > > *ptr = (std::vector< pj::VideoDevInfo,std::allocator< pj::VideoDevInfo > > *)0;
    res3 = swig::asptr(swig_obj[2], &ptr);
    if (!SWIG_IsOK(res3)) {
      SWIG_exception_fail(SWIG_ArgError(res3), "in method '" "VideoDevInfoVector2___setitem__" "', argument " "3"" of type '" "std::vector< pj::VideoDevInfo,std::allocator< pj::VideoDevInfo > > const &""'"); 
    }
    if (!ptr) {
      SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "VideoDevInfoVector2___setitem__" "', argument " "3"" of type '" "std::vector< pj::VideoDevInfo,std::allocator< pj::VideoDevInfo > > const &""'"); 
    }
    arg3 = ptr;
  }
  try {
    std_vector_Sl_pj_VideoDevInfo_Sg____setitem____SWIG_0(arg1,arg2,(std::vector< pj::VideoDevInfo,std::allocator< pj::VideoDevInfo > > const &)*arg3);
  } catch(std::out_of_range &_e) {
    SWIG_exception_fail(SWIG_IndexError, (&_e)->what());
  } catch(std::invalid_argument &_e) {
    SWIG_exception_fail(SWIG_ValueError, (&_e)->what());
  }
  resultobj = SWIG_Py_Void();
  if (SWIG_IsNewObj(res3)) delete arg3;
  return resultobj;
fail:
  if (SWIG_IsNewObj(res3)) delete arg3;
  return NULL;
}


SWIGINTERN PyObject *_wrap_VideoDevInfoVector2___setitem____SWIG_1(PyObject *SWIGUNUSEDPARM(self), Py_ssize_t nobjs, PyObject **swig_obj) {
  PyObject *resultobj = 0;
  std::vector< pj::VideoDevInfo > *arg1 = (std::vector< pj::VideoDevInfo > *) 0 ;
  PySliceObject *arg2 = (PySliceObject *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  
  if ((nobjs < 2) || (nobjs > 2)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__vectorT_pj__VideoDevInfo_std__allocatorT_pj__VideoDevInfo_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "VideoDevInfoVector2___setitem__" "', argument " "1"" of type '" "std::vector< pj::VideoDevInfo > *""'"); 
  }
  arg1 = reinterpret_cast< std::vector< pj::VideoDevInfo > * >(argp1);
  {
    if (!PySlice_Check(swig_obj[1])) {
      SWIG_exception_fail(SWIG_ArgError(SWIG_TypeError), "in method '" "VideoDevInfoVector2___setitem__" "', argument " "2"" of type '" "PySliceObject *""'");
    }
    arg2 = (PySliceObject *) swig_obj[1];
  }
  try {
    std_vector_Sl_pj_VideoDevInfo_Sg____setitem____SWIG_1(arg1,arg2);
  } catch(std::out_of_range &_e) {
    SWIG_exception_fail(SWIG_IndexError, (&_e)->what());
  } catch(std::invalid_argument &_e) {
    SWIG_exception_fail(SWIG_ValueError, (&_e)->what());
  }
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_VideoDevInfoVector2___delitem____SWIG_1(PyObject *SWIGUNUSEDPARM(self), Py_ssize_t nobjs, PyObject **swig_obj) {
  PyObject *resultobj = 0;
  std::vector< pj::VideoDevInfo > *arg1 = (std::vector< pj::VideoDevInfo > *) 0 ;
  PySliceObject *arg2 = (PySliceObject *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  
  if ((nobjs < 2) || (nobjs > 2)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__vectorT_pj__VideoDevInfo_std__allocatorT_pj__VideoDevInfo_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "VideoDevInfoVector2___delitem__" "', argument " "1"" of type '" "std::vector< pj::VideoDevInfo > *""'"); 
  }
  arg1 = reinterpret_cast< std::vector< pj::VideoDevInfo > * >(argp1);
  {
    if (!PySlice_Check(swig_obj[1])) {
      SWIG_exception_fail(SWIG_ArgError(SWIG_TypeError), "in method '" "VideoDevInfoVector2___delitem__" "', argument " "2"" of type '" "PySliceObject *""'");
    }
    arg2 = (PySliceObject *) swig_obj[1];
  }
  try {
    std_vector_Sl_pj_VideoDevInfo_Sg____delitem____SWIG_1(arg1,arg2);
  } catch(std::out_of_range &_e) {
    SWIG_exception_fail(SWIG_IndexError, (&_e)->what());
  } catch(std::invalid_argument &_e) {
    SWIG_exception_fail(SWIG_ValueError, (&_e)->what());
  }
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_VideoDevInfoVector2___delitem__(PyObject *self, PyObject *args) {
  Py_ssize_t argc;
  PyObject *argv[3] = {
    0
  };
  
  if (!(argc = SWIG_Python_UnpackTuple(args, "VideoDevInfoVector2___delitem__", 0, 2, argv))) SWIG_fail;
  --argc;
  if (argc == 2) {
    int _v;
    int res = swig::asptr(argv[0], (std::vector< pj::VideoDevInfo,std::allocator< pj::VideoDevInfo > >**)(0));
    _v = SWIG_CheckState(res);
    if (_v) {
      {
        _v = PySlice_Check(argv[1]);
      }
      if (_v) {
        return _wrap_VideoDevInfoVector2___delitem____SWIG_1(self, argc, argv);
      }
    }
  }
  if (argc == 2) {
    int _v;
    int res = swig::asptr(argv[0], (std::vector< pj::VideoDevInfo,std::allocator< pj::VideoDevInfo > >**)(0));
    _v = SWIG_CheckState(res);
    if (_v) {
      {
        int res = SWIG_AsVal_ptrdiff_t(argv[1], NULL);
        _v = SWIG_CheckState(res);
      }
      if (_v) {
        return _wrap_VideoDevInfoVector2___delitem____SWIG_0(self, argc, argv);
      }
    }
  }
  
fail:
  SWIG_Python_RaiseOrModifyTypeError("Wrong number or type of arguments for overloaded function 'VideoDevInfoVector2___delitem__'.\n"
    "  Possible C/C++ prototypes are:\n"
    "    std::vector< pj::VideoDevInfo >::__delitem__(std::vector< pj::VideoDevInfo >::difference_type)\n"
    "    std::vector< pj::VideoDevInfo >::__delitem__(PySliceObject *)\n");
  return 0;
}


SWIGINTERN PyObject *_wrap_VideoDevInfoVector2___getitem____SWIG_1(PyObject *SWIGUNUSEDPARM(self), Py_ssize_t nobjs, PyObject **swig_obj) {
  PyObject *resultobj = 0;
  std::vector< pj::VideoDevInfo > *arg1 = (std::vector< pj::VideoDevInfo > *) 0 ;
  std::vector< pj::VideoDevInfo >::difference_type arg2 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  ptrdiff_t val2 ;
  int ecode2 = 0 ;
  std::vector< pj::VideoDevInfo >::value_type *result = 0 ;
  
  if ((nobjs < 2) || (nobjs > 2)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__vectorT_pj__VideoDevInfo_std__allocatorT_pj__VideoDevInfo_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "VideoDevInfoVector2___getitem__" "', argument " "1"" of type '" "std::vector< pj::VideoDevInfo > const *""'"); 
  }
  arg1 = reinterpret_cast< std::vector< pj::VideoDevInfo > * >(argp1);
  ecode2 = SWIG_AsVal_ptrdiff_t(swig_obj[1], &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "VideoDevInfoVector2___getitem__" "', argument " "2"" of type '" "std::vector< pj::VideoDevInfo >::difference_type""'");
  } 
  arg2 = static_cast< std::vector< pj::VideoDevInfo >::difference_type >(val2);
  try {
    result = (std::vector< pj::VideoDevInfo >::value_type *) &std_vector_Sl_pj_VideoDevInfo_Sg____getitem____SWIG_1((std::vector< pj::VideoDevInfo > const *)arg1,arg2);
  } catch(std::out_of_range &_e) {
    SWIG_exception_fail(SWIG_IndexError, (&_e)->what());
  }
  resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(result), SWIGTYPE_p_pj__VideoDevInfo, 0 |  0 );
  (void)swig::container_owner<swig::traits<std::vector< pj::VideoDevInfo >::value_type>::category>::back_reference(resultobj, swig_obj[0]);
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_VideoDevInfoVector2___getitem__(PyObject *self, PyObject *args) {
  Py_ssize_t argc;
  PyObject *argv[3] = {
    0
  };
  
  if (!(argc = SWIG_Python_UnpackTuple(args, "VideoDevInfoVector2___getitem__", 0, 2, argv))) SWIG_fail;
  --argc;
  if (argc == 2) {
    int _v;
    int res = swig::asptr(argv[0], (std::vector< pj::VideoDevInfo,std::allocator< pj::VideoDevInfo > >**)(0));
    _v = SWIG_CheckState(res);
    if (_v) {
      {
        _v = PySlice_Check(argv[1]);
      }
      if (_v) {
        return _wrap_VideoDevInfoVector2___getitem____SWIG_0(self, argc, argv);
      }
    }
  }
  if (argc == 2) {
    int _v;
    int res = swig::asptr(argv[0], (std::vector< pj::VideoDevInfo,std::allocator< pj::VideoDevInfo > >**)(0));
    _v = SWIG_CheckState(res);
    if (_v) {
      {
        int res = SWIG_AsVal_ptrdiff_t(argv[1], NULL);
        _v = SWIG_CheckState(res);
      }
      if (_v) {
        return _wrap_VideoDevInfoVector2___getitem____SWIG_1(self, argc, argv);
      }
    }
  }
  
fail:
  SWIG_Python_RaiseOrModifyTypeError("Wrong number or type of arguments for overloaded function 'VideoDevInfoVector2___getitem__'.\n"
    "  Possible C/C++ prototypes are:\n"
    "    std::vector< pj::VideoDevInfo >::__getitem__(PySliceObject *)\n"
    "    std::vector< pj::VideoDevInfo >::__getitem__(std::vector< pj::VideoDevInfo >::difference_type) const\n");
  return 0;
}


SWIGINTERN PyObject *_wrap_VideoDevInfoVector2___setitem____SWIG_2(PyObject *SWIGUNUSEDPARM(self), Py_ssize_t nobjs, PyObject **swig_obj) {
  PyObject *resultobj = 0;
  std::vector< pj::VideoDevInfo > *arg1 = (std::vector< pj::VideoDevInfo > *) 0 ;
  std::vector< pj::VideoDevInfo >::difference_type arg2 ;
  std::vector< pj::VideoDevInfo >::value_type *arg3 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  ptrdiff_t val2 ;
  int ecode2 = 0 ;
  void *argp3 = 0 ;
  int res3 = 0 ;
  
  if ((nobjs < 3) || (nobjs > 3)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__vectorT_pj__VideoDevInfo_std__allocatorT_pj__VideoDevInfo_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "VideoDevInfoVector2___setitem__" "', argument " "1"" of type '" "std::vector< pj::VideoDevInfo > *""'"); 
  }
  arg1 = reinterpret_cast< std::vector< pj::VideoDevInfo > * >(argp1);
  ecode2 = SWIG_AsVal_ptrdiff_t(swig_obj[1], &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "VideoDevInfoVector2___setitem__" "', argument " "2"" of type '" "std::vector< pj::VideoDevInfo >::difference_type""'");
  } 
  arg2 = static_cast< std::vector< pj::VideoDevInfo >::difference_type >(val2);
  res3 = SWIG_ConvertPtr(swig_obj[2], &argp3, SWIGTYPE_p_pj__VideoDevInfo,  0  | 0);
  if (!SWIG_IsOK(res3)) {
    SWIG_exception_fail(SWIG_ArgError(res3), "in method '" "VideoDevInfoVector2___setitem__" "', argument " "3"" of type '" "std::vector< pj::VideoDevInfo >::value_type const &""'"); 
  }
  if (!argp3) {
    SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "VideoDevInfoVector2___setitem__" "', argument " "3"" of type '" "std::vector< pj::VideoDevInfo >::value_type const &""'"); 
  }
  arg3 = reinterpret_cast< std::vector< pj::VideoDevInfo >::value_type * >(argp3);
  try {
    std_vector_Sl_pj_VideoDevInfo_Sg____setitem____SWIG_2(arg1,arg2,(pj::VideoDevInfo const &)*arg3);
  } catch(std::out_of_range &_e) {
    SWIG_exception_fail(SWIG_IndexError, (&_e)->what());
  }
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_VideoDevInfoVector2___setitem__(PyObject *self, PyObject *args) {
  Py_ssize_t argc;
  PyObject *argv[4] = {
    0
  };
  
  if (!(argc = SWIG_Python_UnpackTuple(args, "VideoDevInfoVector2___setitem__", 0, 3, argv))) SWIG_fail;
  --argc;
  if (argc == 2) {
    int _v;
    int res = swig::asptr(argv[0], (std::vector< pj::VideoDevInfo,std::allocator< pj::VideoDevInfo > >**)(0));
    _v = SWIG_CheckState(res);
    if (_v) {
      {
        _v = PySlice_Check(argv[1]);
      }
      if (_v) {
        return _wrap_VideoDevInfoVector2___setitem____SWIG_1(self, argc, argv);
      }
    }
  }
  if (argc == 3) {
    int _v;
    int res = swig::asptr(argv[0], (std::vector< pj::VideoDevInfo,std::allocator< pj::VideoDevInfo > >**)(0));
    _v = SWIG_CheckState(res);
    if (_v) {
      {
        _v = PySlice_Check(argv[1]);
      }
      if (_v) {
        int res = swig::asptr(argv[2], (std::vector< pj::VideoDevInfo,std::allocator< pj::VideoDevInfo > >**)(0));
        _v = SWIG_CheckState(res);
        if (_v) {
          return _wrap_VideoDevInfoVector2___setitem____SWIG_0(self, argc, argv);
        }
      }
    }
  }
  if (argc == 3) {
    int _v;
    int res = swig::asptr(argv[0], (std::vector< pj::VideoDevInfo,std::allocator< pj::VideoDevInfo > >**)(0));
    _v = SWIG_CheckState(res);
    if (_v) {
      {
        int res = SWIG_AsVal_ptrdiff_t(argv[1], NULL);
        _v = SWIG_CheckState(res);
      }
      if (_v) {
        int res = SWIG_ConvertPtr(argv[2], 0, SWIGTYPE_p_pj__VideoDevInfo, SWIG_POINTER_NO_NULL | 0);
        _v = SWIG_CheckState(res);
        if (_v) {
          return _wrap_VideoDevInfoVector2___setitem____SWIG_2(self, argc, argv);
        }
      }
    }
  }
  
fail:
  SWIG_Python_RaiseOrModifyTypeError("Wrong number or type of arguments for overloaded function 'VideoDevInfoVector2___setitem__'.\n"
    "  Possible C/C++ prototypes are:\n"
    "    std::vector< pj::VideoDevInfo >::__setitem__(PySliceObject *,std::vector< pj::VideoDevInfo,std::allocator< pj::VideoDevInfo > > const &)\n"
    "    std::vector< pj::VideoDevInfo >::__setitem__(PySliceObject *)\n"
    "    std::vector< pj::VideoDevInfo >::__setitem__(std::vector< pj::VideoDevInfo >::difference_type,std::vector< pj::VideoDevInfo >::value_type const &)\n");
  return 0;
}


SWIGINTERN PyObject *_wrap_VideoDevInfoVector2_pop(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  std::vector< pj::VideoDevInfo > *arg1 = (std::vector< pj::VideoDevInfo > *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  std::vector< pj::VideoDevInfo >::value_type result;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__vectorT_pj__VideoDevInfo_std__allocatorT_pj__VideoDevInfo_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "VideoDevInfoVector2_pop" "', argument " "1"" of type '" "std::vector< pj::VideoDevInfo > *""'"); 
  }
  arg1 = reinterpret_cast< std::vector< pj::VideoDevInfo > * >(argp1);
  try {
    result = std_vector_Sl_pj_VideoDevInfo_Sg__pop(arg1);
  } catch(std::out_of_range &_e) {
    SWIG_exception_fail(SWIG_IndexError, (&_e)->what());
  }
  resultobj = SWIG_NewPointerObj((new std::vector< pj::VideoDevInfo >::value_type(static_cast< const std::vector< pj::VideoDevInfo >::value_type& >(result))), SWIGTYPE_p_pj__VideoDevInfo, SWIG_POINTER_OWN |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_VideoDevInfoVector2_append(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  std::vector< pj::VideoDevInfo > *arg1 = (std::vector< pj::VideoDevInfo > *) 0 ;
  std::vector< pj::VideoDevInfo >::value_type *arg2 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  void *argp2 = 0 ;
  int res2 = 0 ;
  PyObject *swig_obj[2] ;
  
  if (!SWIG_Python_UnpackTuple(args, "VideoDevInfoVector2_append", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__vectorT_pj__VideoDevInfo_std__allocatorT_pj__VideoDevInfo_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "VideoDevInfoVector2_append" "', argument " "1"" of type '" "std::vector< pj::VideoDevInfo > *""'"); 
  }
  arg1 = reinterpret_cast< std::vector< pj::VideoDevInfo > * >(argp1);
  res2 = SWIG_ConvertPtr(swig_obj[1], &argp2, SWIGTYPE_p_pj__VideoDevInfo,  0  | 0);
  if (!SWIG_IsOK(res2)) {
    SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "VideoDevInfoVector2_append" "', argument " "2"" of type '" "std::vector< pj::VideoDevInfo >::value_type const &""'"); 
  }
  if (!argp2) {
    SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "VideoDevInfoVector2_append" "', argument " "2"" of type '" "std::vector< pj::VideoDevInfo >::value_type const &""'"); 
  }
  arg2 = reinterpret_cast< std::vector< pj::VideoDevInfo >::value_type * >(argp2);
  std_vector_Sl_pj_VideoDevInfo_Sg__append(arg1,(pj::VideoDevInfo const &)*arg2);
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_new_VideoDevInfoVector2__SWIG_0(PyObject *SWIGUNUSEDPARM(self), Py_ssize_t nobjs, PyObject **SWIGUNUSEDPARM(swig_obj)) {
  PyObject *resultobj = 0;
  std::vector< pj::VideoDevInfo > *result = 0 ;
  
  if ((nobjs < 0) || (nobjs > 0)) SWIG_fail;
  result = (std::vector< pj::VideoDevInfo > *)new std::vector< pj::VideoDevInfo >();
  resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(result), SWIGTYPE_p_std__vectorT_pj__VideoDevInfo_std__allocatorT_pj__VideoDevInfo_t_t, SWIG_POINTER_NEW |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_new_VideoDevInfoVector2__SWIG_1(PyObject *SWIGUNUSEDPARM(self), Py_ssize_t nobjs, PyObject **swig_obj) {
  PyObject *resultobj = 0;
  std::vector< pj::VideoDevInfo > *arg1 = 0 ;
  int res1 = SWIG_OLDOBJ ;
  std::vector< pj::VideoDevInfo > *result = 0 ;
  
  if ((nobjs < 1) || (nobjs > 1)) SWIG_fail;
  {
    std::vector< pj::VideoDevInfo,std::allocator< pj::VideoDevInfo > > *ptr = (std::vector< pj::VideoDevInfo,std::allocator< pj::VideoDevInfo > > *)0;
    res1 = swig::asptr(swig_obj[0], &ptr);
    if (!SWIG_IsOK(res1)) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "new_VideoDevInfoVector2" "', argument " "1"" of type '" "std::vector< pj::VideoDevInfo > const &""'"); 
    }
    if (!ptr) {
      SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "new_VideoDevInfoVector2" "', argument " "1"" of type '" "std::vector< pj::VideoDevInfo > const &""'"); 
    }
    arg1 = ptr;
  }
  result = (std::vector< pj::VideoDevInfo > *)new std::vector< pj::VideoDevInfo >((std::vector< pj::VideoDevInfo > const &)*arg1);
  resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(result), SWIGTYPE_p_std__vectorT_pj__VideoDevInfo_std__allocatorT_pj__VideoDevInfo_t_t, SWIG_POINTER_NEW |  0 );
  if (SWIG_IsNewObj(res1)) delete arg1;
  return resultobj;
fail:
  if (SWIG_IsNewObj(res1)) delete arg1;
  return NULL;
}


SWIGINTERN PyObject *_wrap_VideoDevInfoVector2_empty(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  std::vector< pj::VideoDevInfo > *arg1 = (std::vector< pj::VideoDevInfo > *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  bool result;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__vectorT_pj__VideoDevInfo_std__allocatorT_pj__VideoDevInfo_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "VideoDevInfoVector2_empty" "', argument " "1"" of type '" "std::vector< pj::VideoDevInfo > const *""'"); 
  }
  arg1 = reinterpret_cast< std::vector< pj::VideoDevInfo > * >(argp1);
  result = (bool)((std::vector< pj::VideoDevInfo > const *)arg1)->empty();
  resultobj = SWIG_From_bool(static_cast< bool >(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_VideoDevInfoVector2_size(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  std::vector< pj::VideoDevInfo > *arg1 = (std::vector< pj::VideoDevInfo > *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  std::vector< pj::VideoDevInfo >::size_type result;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__vectorT_pj__VideoDevInfo_std__allocatorT_pj__VideoDevInfo_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "VideoDevInfoVector2_size" "', argument " "1"" of type '" "std::vector< pj::VideoDevInfo > const *""'"); 
  }
  arg1 = reinterpret_cast< std::vector< pj::VideoDevInfo > * >(argp1);
  result = ((std::vector< pj::VideoDevInfo > const *)arg1)->size();
  resultobj = SWIG_From_size_t(static_cast< size_t >(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_VideoDevInfoVector2_swap(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  std::vector< pj::VideoDevInfo > *arg1 = (std::vector< pj::VideoDevInfo > *) 0 ;
  std::vector< pj::VideoDevInfo > *arg2 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  void *argp2 = 0 ;
  int res2 = 0 ;
  PyObject *swig_obj[2] ;
  
  if (!SWIG_Python_UnpackTuple(args, "VideoDevInfoVector2_swap", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__vectorT_pj__VideoDevInfo_std__allocatorT_pj__VideoDevInfo_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "VideoDevInfoVector2_swap" "', argument " "1"" of type '" "std::vector< pj::VideoDevInfo > *""'"); 
  }
  arg1 = reinterpret_cast< std::vector< pj::VideoDevInfo > * >(argp1);
  res2 = SWIG_ConvertPtr(swig_obj[1], &argp2, SWIGTYPE_p_std__vectorT_pj__VideoDevInfo_std__allocatorT_pj__VideoDevInfo_t_t,  0 );
  if (!SWIG_IsOK(res2)) {
    SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "VideoDevInfoVector2_swap" "', argument " "2"" of type '" "std::vector< pj::VideoDevInfo > &""'"); 
  }
  if (!argp2) {
    SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "VideoDevInfoVector2_swap" "', argument " "2"" of type '" "std::vector< pj::VideoDevInfo > &""'"); 
  }
  arg2 = reinterpret_cast< std::vector< pj::VideoDevInfo > * >(argp2);
  (arg1)->swap(*arg2);
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_VideoDevInfoVector2_begin(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  std::vector< pj::VideoDevInfo > *arg1 = (std::vector< pj::VideoDevInfo > *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  std::vector< pj::VideoDevInfo >::iterator result;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__vectorT_pj__VideoDevInfo_std__allocatorT_pj__VideoDevInfo_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "VideoDevInfoVector2_begin" "', argument " "1"" of type '" "std::vector< pj::VideoDevInfo > *""'"); 
  }
  arg1 = reinterpret_cast< std::vector< pj::VideoDevInfo > * >(argp1);
  result = (arg1)->begin();
  resultobj = SWIG_NewPointerObj(swig::make_output_iterator(static_cast< const std::vector< pj::VideoDevInfo >::iterator & >(result)),
    swig::SwigPyIterator::descriptor(),SWIG_POINTER_OWN);
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_VideoDevInfoVector2_end(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  std::vector< pj::VideoDevInfo > *arg1 = (std::vector< pj::VideoDevInfo > *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  std::vector< pj::VideoDevInfo >::iterator result;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__vectorT_pj__VideoDevInfo_std__allocatorT_pj__VideoDevInfo_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "VideoDevInfoVector2_end" "', argument " "1"" of type '" "std::vector< pj::VideoDevInfo > *""'"); 
  }
  arg1 = reinterpret_cast< std::vector< pj::VideoDevInfo > * >(argp1);
  result = (arg1)->end();
  resultobj = SWIG_NewPointerObj(swig::make_output_iterator(static_cast< const std::vector< pj::VideoDevInfo >::iterator & >(result)),
    swig::SwigPyIterator::descriptor(),SWIG_POINTER_OWN);
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_VideoDevInfoVector2_rbegin(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  std::vector< pj::VideoDevInfo > *arg1 = (std::vector< pj::VideoDevInfo > *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  std::vector< pj::VideoDevInfo >::reverse_iterator result;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__vectorT_pj__VideoDevInfo_std__allocatorT_pj__VideoDevInfo_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "VideoDevInfoVector2_rbegin" "', argument " "1"" of type '" "std::vector< pj::VideoDevInfo > *""'"); 
  }
  arg1 = reinterpret_cast< std::vector< pj::VideoDevInfo > * >(argp1);
  result = (arg1)->rbegin();
  resultobj = SWIG_NewPointerObj(swig::make_output_iterator(static_cast< const std::vector< pj::VideoDevInfo >::reverse_iterator & >(result)),
    swig::SwigPyIterator::descriptor(),SWIG_POINTER_OWN);
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_VideoDevInfoVector2_rend(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  std::vector< pj::VideoDevInfo > *arg1 = (std::vector< pj::VideoDevInfo > *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  std::vector< pj::VideoDevInfo >::reverse_iterator result;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__vectorT_pj__VideoDevInfo_std__allocatorT_pj__VideoDevInfo_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "VideoDevInfoVector2_rend" "', argument " "1"" of type '" "std::vector< pj::VideoDevInfo > *""'"); 
  }
  arg1 = reinterpret_cast< std::vector< pj::VideoDevInfo > * >(argp1);
  result = (arg1)->rend();
  resultobj = SWIG_NewPointerObj(swig::make_output_iterator(static_cast< const std::vector< pj::VideoDevInfo >::reverse_iterator & >(result)),
    swig::SwigPyIterator::descriptor(),SWIG_POINTER_OWN);
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_VideoDevInfoVector2_clear(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  std::vector< pj::VideoDevInfo > *arg1 = (std::vector< pj::VideoDevInfo > *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__vectorT_pj__VideoDevInfo_std__allocatorT_pj__VideoDevInfo_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "VideoDevInfoVector2_clear" "', argument " "1"" of type '" "std::vector< pj::VideoDevInfo > *""'"); 
  }
  arg1 = reinterpret_cast< std::vector< pj::VideoDevInfo > * >(argp1);
  (arg1)->clear();
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_VideoDevInfoVector2_get_allocator(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  std::vector< pj::VideoDevInfo > *arg1 = (std::vector< pj::VideoDevInfo > *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  SwigValueWrapper< std::allocator< pj::VideoDevInfo > > result;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__vectorT_pj__VideoDevInfo_std__allocatorT_pj__VideoDevInfo_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "VideoDevInfoVector2_get_allocator" "', argument " "1"" of type '" "std::vector< pj::VideoDevInfo > const *""'"); 
  }
  arg1 = reinterpret_cast< std::vector< pj::VideoDevInfo > * >(argp1);
  result = ((std::vector< pj::VideoDevInfo > const *)arg1)->get_allocator();
  resultobj = SWIG_NewPointerObj((new std::vector< pj::VideoDevInfo >::allocator_type(static_cast< const std::vector< pj::VideoDevInfo >::allocator_type& >(result))), SWIGTYPE_p_std__allocatorT_pj__VideoDevInfo_t, SWIG_POINTER_OWN |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_new_VideoDevInfoVector2__SWIG_2(PyObject *SWIGUNUSEDPARM(self), Py_ssize_t nobjs, PyObject **swig_obj) {
  PyObject *resultobj = 0;
  std::vector< pj::VideoDevInfo >::size_type arg1 ;
  size_t val1 ;
  int ecode1 = 0 ;
  std::vector< pj::VideoDevInfo > *result = 0 ;
  
  if ((nobjs < 1) || (nobjs > 1)) SWIG_fail;
  ecode1 = SWIG_AsVal_size_t(swig_obj[0], &val1);
  if (!SWIG_IsOK(ecode1)) {
    SWIG_exception_fail(SWIG_ArgError(ecode1), "in method '" "new_VideoDevInfoVector2" "', argument " "1"" of type '" "std::vector< pj::VideoDevInfo >::size_type""'");
  } 
  arg1 = static_cast< std::vector< pj::VideoDevInfo >::size_type >(val1);
  result = (std::vector< pj::VideoDevInfo > *)new std::vector< pj::VideoDevInfo >(arg1);
  resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(result), SWIGTYPE_p_std__vectorT_pj__VideoDevInfo_std__allocatorT_pj__VideoDevInfo_t_t, SWIG_POINTER_NEW |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_VideoDevInfoVector2_pop_back(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  std::vector< pj::VideoDevInfo > *arg1 = (std::vector< pj::VideoDevInfo > *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__vectorT_pj__VideoDevInfo_std__allocatorT_pj__VideoDevInfo_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "VideoDevInfoVector2_pop_back" "', argument " "1"" of type '" "std::vector< pj::VideoDevInfo > *""'"); 
  }
  arg1 = reinterpret_cast< std::vector< pj::VideoDevInfo > * >(argp1);
  (arg1)->pop_back();
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_VideoDevInfoVector2_resize__SWIG_0(PyObject *SWIGUNUSEDPARM(self), Py_ssize_t nobjs, PyObject **swig_obj) {
  PyObject *resultobj = 0;
  std::vector< pj::VideoDevInfo > *arg1 = (std::vector< pj::VideoDevInfo > *) 0 ;
  std::vector< pj::VideoDevInfo >::size_type arg2 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  size_t val2 ;
  int ecode2 = 0 ;
  
  if ((nobjs < 2) || (nobjs > 2)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__vectorT_pj__VideoDevInfo_std__allocatorT_pj__VideoDevInfo_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "VideoDevInfoVector2_resize" "', argument " "1"" of type '" "std::vector< pj::VideoDevInfo > *""'"); 
  }
  arg1 = reinterpret_cast< std::vector< pj::VideoDevInfo > * >(argp1);
  ecode2 = SWIG_AsVal_size_t(swig_obj[1], &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "VideoDevInfoVector2_resize" "', argument " "2"" of type '" "std::vector< pj::VideoDevInfo >::size_type""'");
  } 
  arg2 = static_cast< std::vector< pj::VideoDevInfo >::size_type >(val2);
  (arg1)->resize(arg2);
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_VideoDevInfoVector2_erase__SWIG_0(PyObject *SWIGUNUSEDPARM(self), Py_ssize_t nobjs, PyObject **swig_obj) {
  PyObject *resultobj = 0;
  std::vector< pj::VideoDevInfo > *arg1 = (std::vector< pj::VideoDevInfo > *) 0 ;
  std::vector< pj::VideoDevInfo >::iterator arg2 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  swig::SwigPyIterator *iter2 = 0 ;
  int res2 ;
  std::vector< pj::VideoDevInfo >::iterator result;
  
  if ((nobjs < 2) || (nobjs > 2)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__vectorT_pj__VideoDevInfo_std__allocatorT_pj__VideoDevInfo_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "VideoDevInfoVector2_erase" "', argument " "1"" of type '" "std::vector< pj::VideoDevInfo > *""'"); 
  }
  arg1 = reinterpret_cast< std::vector< pj::VideoDevInfo > * >(argp1);
  res2 = SWIG_ConvertPtr(swig_obj[1], SWIG_as_voidptrptr(&iter2), swig::SwigPyIterator::descriptor(), 0);
  if (!SWIG_IsOK(res2) || !iter2) {
    SWIG_exception_fail(SWIG_ArgError(SWIG_TypeError), "in method '" "VideoDevInfoVector2_erase" "', argument " "2"" of type '" "std::vector< pj::VideoDevInfo >::iterator""'");
  } else {
    swig::SwigPyIterator_T<std::vector< pj::VideoDevInfo >::iterator > *iter_t = dynamic_cast<swig::SwigPyIterator_T<std::vector< pj::VideoDevInfo >::iterator > *>(iter2);
    if (iter_t) {
      arg2 = iter_t->get_current();
    } else {
      SWIG_exception_fail(SWIG_ArgError(SWIG_TypeError), "in method '" "VideoDevInfoVector2_erase" "', argument " "2"" of type '" "std::vector< pj::VideoDevInfo >::iterator""'");
    }
  }
  result = std_vector_Sl_pj_VideoDevInfo_Sg__erase__SWIG_0(arg1,arg2);
  resultobj = SWIG_NewPointerObj(swig::make_output_iterator(static_cast< const std::vector< pj::VideoDevInfo >::iterator & >(result)),
    swig::SwigPyIterator::descriptor(),SWIG_POINTER_OWN);
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_VideoDevInfoVector2_erase__SWIG_1(PyObject *SWIGUNUSEDPARM(self), Py_ssize_t nobjs, PyObject **swig_obj) {
  PyObject *resultobj = 0;
  std::vector< pj::VideoDevInfo > *arg1 = (std::vector< pj::VideoDevInfo > *) 0 ;
  std::vector< pj::VideoDevInfo >::iterator arg2 ;
  std::vector< pj::VideoDevInfo >::iterator arg3 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  swig::SwigPyIterator *iter2 = 0 ;
  int res2 ;
  swig::SwigPyIterator *iter3 = 0 ;
  int res3 ;
  std::vector< pj::VideoDevInfo >::iterator result;
  
  if ((nobjs < 3) || (nobjs > 3)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__vectorT_pj__VideoDevInfo_std__allocatorT_pj__VideoDevInfo_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "VideoDevInfoVector2_erase" "', argument " "1"" of type '" "std::vector< pj::VideoDevInfo > *""'"); 
  }
  arg1 = reinterpret_cast< std::vector< pj::VideoDevInfo > * >(argp1);
  res2 = SWIG_ConvertPtr(swig_obj[1], SWIG_as_voidptrptr(&iter2), swig::SwigPyIterator::descriptor(), 0);
  if (!SWIG_IsOK(res2) || !iter2) {
    SWIG_exception_fail(SWIG_ArgError(SWIG_TypeError), "in method '" "VideoDevInfoVector2_erase" "', argument " "2"" of type '" "std::vector< pj::VideoDevInfo >::iterator""'");
  } else {
    swig::SwigPyIterator_T<std::vector< pj::VideoDevInfo >::iterator > *iter_t = dynamic_cast<swig::SwigPyIterator_T<std::vector< pj::VideoDevInfo >::iterator > *>(iter2);
    if (iter_t) {
      arg2 = iter_t->get_current();
    } else {
      SWIG_exception_fail(SWIG_ArgError(SWIG_TypeError), "in method '" "VideoDevInfoVector2_erase" "', argument " "2"" of type '" "std::vector< pj::VideoDevInfo >::iterator""'");
    }
  }
  res3 = SWIG_ConvertPtr(swig_obj[2], SWIG_as_voidptrptr(&iter3), swig::SwigPyIterator::descriptor(), 0);
  if (!SWIG_IsOK(res3) || !iter3) {
    SWIG_exception_fail(SWIG_ArgError(SWIG_TypeError), "in method '" "VideoDevInfoVector2_erase" "', argument " "3"" of type '" "std::vector< pj::VideoDevInfo >::iterator""'");
  } else {
    swig::SwigPyIterator_T<std::vector< pj::VideoDevInfo >::iterator > *iter_t = dynamic_cast<swig::SwigPyIterator_T<std::vector< pj::VideoDevInfo >::iterator > *>(iter3);
    if (iter_t) {
      arg3 = iter_t->get_current();
    } else {
      SWIG_exception_fail(SWIG_ArgError(SWIG_TypeError), "in method '" "VideoDevInfoVector2_erase" "', argument " "3"" of type '" "std::vector< pj::VideoDevInfo >::iterator""'");
    }
  }
  result = std_vector_Sl_pj_VideoDevInfo_Sg__erase__SWIG_1(arg1,arg2,arg3);
  resultobj = SWIG_NewPointerObj(swig::make_output_iterator(static_cast< const std::vector< pj::VideoDevInfo >::iterator & >(result)),
    swig::SwigPyIterator::descriptor(),SWIG_POINTER_OWN);
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_VideoDevInfoVector2_erase(PyObject *self, PyObject *args) {
  Py_ssize_t argc;
  PyObject *argv[4] = {
    0
  };
  
  if (!(argc = SWIG_Python_UnpackTuple(args, "VideoDevInfoVector2_erase", 0, 3, argv))) SWIG_fail;
  --argc;
  if (argc == 2) {
    int _v;
    int res = swig::asptr(argv[0], (std::vector< pj::VideoDevInfo,std::allocator< pj::VideoDevInfo > >**)(0));
    _v = SWIG_CheckState(res);
    if (_v) {
      swig::SwigPyIterator *iter = 0;
      int res = SWIG_ConvertPtr(argv[1], SWIG_as_voidptrptr(&iter), swig::SwigPyIterator::descriptor(), 0);
      _v = (SWIG_IsOK(res) && iter && (dynamic_cast<swig::SwigPyIterator_T<std::vector< pj::VideoDevInfo >::iterator > *>(iter) != 0));
      if (_v) {
        return _wrap_VideoDevInfoVector2_erase__SWIG_0(self, argc, argv);
      }
    }
  }
  if (argc == 3) {
    int _v;
    int res = swig::asptr(argv[0], (std::vector< pj::VideoDevInfo,std::allocator< pj::VideoDevInfo > >**)(0));
    _v = SWIG_CheckState(res);
    if (_v) {
      swig::SwigPyIterator *iter = 0;
      int res = SWIG_ConvertPtr(argv[1], SWIG_as_voidptrptr(&iter), swig::SwigPyIterator::descriptor(), 0);
      _v = (SWIG_IsOK(res) && iter && (dynamic_cast<swig::SwigPyIterator_T<std::vector< pj::VideoDevInfo >::iterator > *>(iter) != 0));
      if (_v) {
        swig::SwigPyIterator *iter = 0;
        int res = SWIG_ConvertPtr(argv[2], SWIG_as_voidptrptr(&iter), swig::SwigPyIterator::descriptor(), 0);
        _v = (SWIG_IsOK(res) && iter && (dynamic_cast<swig::SwigPyIterator_T<std::vector< pj::VideoDevInfo >::iterator > *>(iter) != 0));
        if (_v) {
          return _wrap_VideoDevInfoVector2_erase__SWIG_1(self, argc, argv);
        }
      }
    }
  }
  
fail:
  SWIG_Python_RaiseOrModifyTypeError("Wrong number or type of arguments for overloaded function 'VideoDevInfoVector2_erase'.\n"
    "  Possible C/C++ prototypes are:\n"
    "    std::vector< pj::VideoDevInfo >::erase(std::vector< pj::VideoDevInfo >::iterator)\n"
    "    std::vector< pj::VideoDevInfo >::erase(std::vector< pj::VideoDevInfo >::iterator,std::vector< pj::VideoDevInfo >::iterator)\n");
  return 0;
}


SWIGINTERN PyObject *_wrap_new_VideoDevInfoVector2__SWIG_3(PyObject *SWIGUNUSEDPARM(self), Py_ssize_t nobjs, PyObject **swig_obj) {
  PyObject *resultobj = 0;
  std::vector< pj::VideoDevInfo >::size_type arg1 ;
  std::vector< pj::VideoDevInfo >::value_type *arg2 = 0 ;
  size_t val1 ;
  int ecode1 = 0 ;
  void *argp2 = 0 ;
  int res2 = 0 ;
  std::vector< pj::VideoDevInfo > *result = 0 ;
  
  if ((nobjs < 2) || (nobjs > 2)) SWIG_fail;
  ecode1 = SWIG_AsVal_size_t(swig_obj[0], &val1);
  if (!SWIG_IsOK(ecode1)) {
    SWIG_exception_fail(SWIG_ArgError(ecode1), "in method '" "new_VideoDevInfoVector2" "', argument " "1"" of type '" "std::vector< pj::VideoDevInfo >::size_type""'");
  } 
  arg1 = static_cast< std::vector< pj::VideoDevInfo >::size_type >(val1);
  res2 = SWIG_ConvertPtr(swig_obj[1], &argp2, SWIGTYPE_p_pj__VideoDevInfo,  0  | 0);
  if (!SWIG_IsOK(res2)) {
    SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "new_VideoDevInfoVector2" "', argument " "2"" of type '" "std::vector< pj::VideoDevInfo >::value_type const &""'"); 
  }
  if (!argp2) {
    SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "new_VideoDevInfoVector2" "', argument " "2"" of type '" "std::vector< pj::VideoDevInfo >::value_type const &""'"); 
  }
  arg2 = reinterpret_cast< std::vector< pj::VideoDevInfo >::value_type * >(argp2);
  result = (std::vector< pj::VideoDevInfo > *)new std::vector< pj::VideoDevInfo >(arg1,(std::vector< pj::VideoDevInfo >::value_type const &)*arg2);
  resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(result), SWIGTYPE_p_std__vectorT_pj__VideoDevInfo_std__allocatorT_pj__VideoDevInfo_t_t, SWIG_POINTER_NEW |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_new_VideoDevInfoVector2(PyObject *self, PyObject *args) {
  Py_ssize_t argc;
  PyObject *argv[3] = {
    0
  };
  
  if (!(argc = SWIG_Python_UnpackTuple(args, "new_VideoDevInfoVector2", 0, 2, argv))) SWIG_fail;
  --argc;
  if (argc == 0) {
    return _wrap_new_VideoDevInfoVector2__SWIG_0(self, argc, argv);
  }
  if (argc == 1) {
    int _v;
    {
      int res = SWIG_AsVal_size_t(argv[0], NULL);
      _v = SWIG_CheckState(res);
    }
    if (_v) {
      return _wrap_new_VideoDevInfoVector2__SWIG_2(self, argc, argv);
    }
  }
  if (argc == 1) {
    int _v;
    int res = swig::asptr(argv[0], (std::vector< pj::VideoDevInfo,std::allocator< pj::VideoDevInfo > >**)(0));
    _v = SWIG_CheckState(res);
    if (_v) {
      return _wrap_new_VideoDevInfoVector2__SWIG_1(self, argc, argv);
    }
  }
  if (argc == 2) {
    int _v;
    {
      int res = SWIG_AsVal_size_t(argv[0], NULL);
      _v = SWIG_CheckState(res);
    }
    if (_v) {
      int res = SWIG_ConvertPtr(argv[1], 0, SWIGTYPE_p_pj__VideoDevInfo, SWIG_POINTER_NO_NULL | 0);
      _v = SWIG_CheckState(res);
      if (_v) {
        return _wrap_new_VideoDevInfoVector2__SWIG_3(self, argc, argv);
      }
    }
  }
  
fail:
  SWIG_Python_RaiseOrModifyTypeError("Wrong number or type of arguments for overloaded function 'new_VideoDevInfoVector2'.\n"
    "  Possible C/C++ prototypes are:\n"
    "    std::vector< pj::VideoDevInfo >::vector()\n"
    "    std::vector< pj::VideoDevInfo >::vector(std::vector< pj::VideoDevInfo > const &)\n"
    "    std::vector< pj::VideoDevInfo >::vector(std::vector< pj::VideoDevInfo >::size_type)\n"
    "    std::vector< pj::VideoDevInfo >::vector(std::vector< pj::VideoDevInfo >::size_type,std::vector< pj::VideoDevInfo >::value_type const &)\n");
  return 0;
}


SWIGINTERN PyObject *_wrap_VideoDevInfoVector2_push_back(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  std::vector< pj::VideoDevInfo > *arg1 = (std::vector< pj::VideoDevInfo > *) 0 ;
  std::vector< pj::VideoDevInfo >::value_type *arg2 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  void *argp2 = 0 ;
  int res2 = 0 ;
  PyObject *swig_obj[2] ;
  
  if (!SWIG_Python_UnpackTuple(args, "VideoDevInfoVector2_push_back", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__vectorT_pj__VideoDevInfo_std__allocatorT_pj__VideoDevInfo_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "VideoDevInfoVector2_push_back" "', argument " "1"" of type '" "std::vector< pj::VideoDevInfo > *""'"); 
  }
  arg1 = reinterpret_cast< std::vector< pj::VideoDevInfo > * >(argp1);
  res2 = SWIG_ConvertPtr(swig_obj[1], &argp2, SWIGTYPE_p_pj__VideoDevInfo,  0  | 0);
  if (!SWIG_IsOK(res2)) {
    SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "VideoDevInfoVector2_push_back" "', argument " "2"" of type '" "std::vector< pj::VideoDevInfo >::value_type const &""'"); 
  }
  if (!argp2) {
    SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "VideoDevInfoVector2_push_back" "', argument " "2"" of type '" "std::vector< pj::VideoDevInfo >::value_type const &""'"); 
  }
  arg2 = reinterpret_cast< std::vector< pj::VideoDevInfo >::value_type * >(argp2);
  (arg1)->push_back((std::vector< pj::VideoDevInfo >::value_type const &)*arg2);
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_VideoDevInfoVector2_front(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  std::vector< pj::VideoDevInfo > *arg1 = (std::vector< pj::VideoDevInfo > *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  std::vector< pj::VideoDevInfo >::value_type *result = 0 ;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__vectorT_pj__VideoDevInfo_std__allocatorT_pj__VideoDevInfo_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "VideoDevInfoVector2_front" "', argument " "1"" of type '" "std::vector< pj::VideoDevInfo > const *""'"); 
  }
  arg1 = reinterpret_cast< std::vector< pj::VideoDevInfo > * >(argp1);
  result = (std::vector< pj::VideoDevInfo >::value_type *) &((std::vector< pj::VideoDevInfo > const *)arg1)->front();
  resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(result), SWIGTYPE_p_pj__VideoDevInfo, 0 |  0 );
  (void)swig::container_owner<swig::traits<std::vector< pj::VideoDevInfo >::value_type>::category>::back_reference(resultobj, swig_obj[0]);
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_VideoDevInfoVector2_back(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  std::vector< pj::VideoDevInfo > *arg1 = (std::vector< pj::VideoDevInfo > *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  std::vector< pj::VideoDevInfo >::value_type *result = 0 ;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__vectorT_pj__VideoDevInfo_std__allocatorT_pj__VideoDevInfo_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "VideoDevInfoVector2_back" "', argument " "1"" of type '" "std::vector< pj::VideoDevInfo > const *""'"); 
  }
  arg1 = reinterpret_cast< std::vector< pj::VideoDevInfo > * >(argp1);
  result = (std::vector< pj::VideoDevInfo >::value_type *) &((std::vector< pj::VideoDevInfo > const *)arg1)->back();
  resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(result), SWIGTYPE_p_pj__VideoDevInfo, 0 |  0 );
  (void)swig::container_owner<swig::traits<std::vector< pj::VideoDevInfo >::value_type>::category>::back_reference(resultobj, swig_obj[0]);
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_VideoDevInfoVector2_assign(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  std::vector< pj::VideoDevInfo > *arg1 = (std::vector< pj::VideoDevInfo > *) 0 ;
  std::vector< pj::VideoDevInfo >::size_type arg2 ;
  std::vector< pj::VideoDevInfo >::value_type *arg3 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  size_t val2 ;
  int ecode2 = 0 ;
  void *argp3 = 0 ;
  int res3 = 0 ;
  PyObject *swig_obj[3] ;
  
  if (!SWIG_Python_UnpackTuple(args, "VideoDevInfoVector2_assign", 3, 3, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__vectorT_pj__VideoDevInfo_std__allocatorT_pj__VideoDevInfo_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "VideoDevInfoVector2_assign" "', argument " "1"" of type '" "std::vector< pj::VideoDevInfo > *""'"); 
  }
  arg1 = reinterpret_cast< std::vector< pj::VideoDevInfo > * >(argp1);
  ecode2 = SWIG_AsVal_size_t(swig_obj[1], &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "VideoDevInfoVector2_assign" "', argument " "2"" of type '" "std::vector< pj::VideoDevInfo >::size_type""'");
  } 
  arg2 = static_cast< std::vector< pj::VideoDevInfo >::size_type >(val2);
  res3 = SWIG_ConvertPtr(swig_obj[2], &argp3, SWIGTYPE_p_pj__VideoDevInfo,  0  | 0);
  if (!SWIG_IsOK(res3)) {
    SWIG_exception_fail(SWIG_ArgError(res3), "in method '" "VideoDevInfoVector2_assign" "', argument " "3"" of type '" "std::vector< pj::VideoDevInfo >::value_type const &""'"); 
  }
  if (!argp3) {
    SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "VideoDevInfoVector2_assign" "', argument " "3"" of type '" "std::vector< pj::VideoDevInfo >::value_type const &""'"); 
  }
  arg3 = reinterpret_cast< std::vector< pj::VideoDevInfo >::value_type * >(argp3);
  (arg1)->assign(arg2,(std::vector< pj::VideoDevInfo >::value_type const &)*arg3);
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_VideoDevInfoVector2_resize__SWIG_1(PyObject *SWIGUNUSEDPARM(self), Py_ssize_t nobjs, PyObject **swig_obj) {
  PyObject *resultobj = 0;
  std::vector< pj::VideoDevInfo > *arg1 = (std::vector< pj::VideoDevInfo > *) 0 ;
  std::vector< pj::VideoDevInfo >::size_type arg2 ;
  std::vector< pj::VideoDevInfo >::value_type *arg3 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  size_t val2 ;
  int ecode2 = 0 ;
  void *argp3 = 0 ;
  int res3 = 0 ;
  
  if ((nobjs < 3) || (nobjs > 3)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__vectorT_pj__VideoDevInfo_std__allocatorT_pj__VideoDevInfo_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "VideoDevInfoVector2_resize" "', argument " "1"" of type '" "std::vector< pj::VideoDevInfo > *""'"); 
  }
  arg1 = reinterpret_cast< std::vector< pj::VideoDevInfo > * >(argp1);
  ecode2 = SWIG_AsVal_size_t(swig_obj[1], &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "VideoDevInfoVector2_resize" "', argument " "2"" of type '" "std::vector< pj::VideoDevInfo >::size_type""'");
  } 
  arg2 = static_cast< std::vector< pj::VideoDevInfo >::size_type >(val2);
  res3 = SWIG_ConvertPtr(swig_obj[2], &argp3, SWIGTYPE_p_pj__VideoDevInfo,  0  | 0);
  if (!SWIG_IsOK(res3)) {
    SWIG_exception_fail(SWIG_ArgError(res3), "in method '" "VideoDevInfoVector2_resize" "', argument " "3"" of type '" "std::vector< pj::VideoDevInfo >::value_type const &""'"); 
  }
  if (!argp3) {
    SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "VideoDevInfoVector2_resize" "', argument " "3"" of type '" "std::vector< pj::VideoDevInfo >::value_type const &""'"); 
  }
  arg3 = reinterpret_cast< std::vector< pj::VideoDevInfo >::value_type * >(argp3);
  (arg1)->resize(arg2,(std::vector< pj::VideoDevInfo >::value_type const &)*arg3);
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_VideoDevInfoVector2_resize(PyObject *self, PyObject *args) {
  Py_ssize_t argc;
  PyObject *argv[4] = {
    0
  };
  
  if (!(argc = SWIG_Python_UnpackTuple(args, "VideoDevInfoVector2_resize", 0, 3, argv))) SWIG_fail;
  --argc;
  if (argc == 2) {
    int _v;
    int res = swig::asptr(argv[0], (std::vector< pj::VideoDevInfo,std::allocator< pj::VideoDevInfo > >**)(0));
    _v = SWIG_CheckState(res);
    if (_v) {
      {
        int res = SWIG_AsVal_size_t(argv[1], NULL);
        _v = SWIG_CheckState(res);
      }
      if (_v) {
        return _wrap_VideoDevInfoVector2_resize__SWIG_0(self, argc, argv);
      }
    }
  }
  if (argc == 3) {
    int _v;
    int res = swig::asptr(argv[0], (std::vector< pj::VideoDevInfo,std::allocator< pj::VideoDevInfo > >**)(0));
    _v = SWIG_CheckState(res);
    if (_v) {
      {
        int res = SWIG_AsVal_size_t(argv[1], NULL);
        _v = SWIG_CheckState(res);
      }
      if (_v) {
        int res = SWIG_ConvertPtr(argv[2], 0, SWIGTYPE_p_pj__VideoDevInfo, SWIG_POINTER_NO_NULL | 0);
        _v = SWIG_CheckState(res);
        if (_v) {
          return _wrap_VideoDevInfoVector2_resize__SWIG_1(self, argc, argv);
        }
      }
    }
  }
  
fail:
  SWIG_Python_RaiseOrModifyTypeError("Wrong number or type of arguments for overloaded function 'VideoDevInfoVector2_resize'.\n"
    "  Possible C/C++ prototypes are:\n"
    "    std::vector< pj::VideoDevInfo >::resize(std::vector< pj::VideoDevInfo >::size_type)\n"
    "    std::vector< pj::VideoDevInfo >::resize(std::vector< pj::VideoDevInfo >::size_type,std::vector< pj::VideoDevInfo >::value_type const &)\n");
  return 0;
}


SWIGINTERN PyObject *_wrap_VideoDevInfoVector2_insert__SWIG_0(PyObject *SWIGUNUSEDPARM(self), Py_ssize_t nobjs, PyObject **swig_obj) {
  PyObject *resultobj = 0;
  std::vector< pj::VideoDevInfo > *arg1 = (std::vector< pj::VideoDevInfo > *) 0 ;
  std::vector< pj::VideoDevInfo >::iterator arg2 ;
  std::vector< pj::VideoDevInfo >::value_type *arg3 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  swig::SwigPyIterator *iter2 = 0 ;
  int res2 ;
  void *argp3 = 0 ;
  int res3 = 0 ;
  std::vector< pj::VideoDevInfo >::iterator result;
  
  if ((nobjs < 3) || (nobjs > 3)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__vectorT_pj__VideoDevInfo_std__allocatorT_pj__VideoDevInfo_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "VideoDevInfoVector2_insert" "', argument " "1"" of type '" "std::vector< pj::VideoDevInfo > *""'"); 
  }
  arg1 = reinterpret_cast< std::vector< pj::VideoDevInfo > * >(argp1);
  res2 = SWIG_ConvertPtr(swig_obj[1], SWIG_as_voidptrptr(&iter2), swig::SwigPyIterator::descriptor(), 0);
  if (!SWIG_IsOK(res2) || !iter2) {
    SWIG_exception_fail(SWIG_ArgError(SWIG_TypeError), "in method '" "VideoDevInfoVector2_insert" "', argument " "2"" of type '" "std::vector< pj::VideoDevInfo >::iterator""'");
  } else {
    swig::SwigPyIterator_T<std::vector< pj::VideoDevInfo >::iterator > *iter_t = dynamic_cast<swig::SwigPyIterator_T<std::vector< pj::VideoDevInfo >::iterator > *>(iter2);
    if (iter_t) {
      arg2 = iter_t->get_current();
    } else {
      SWIG_exception_fail(SWIG_ArgError(SWIG_TypeError), "in method '" "VideoDevInfoVector2_insert" "', argument " "2"" of type '" "std::vector< pj::VideoDevInfo >::iterator""'");
    }
  }
  res3 = SWIG_ConvertPtr(swig_obj[2], &argp3, SWIGTYPE_p_pj__VideoDevInfo,  0  | 0);
  if (!SWIG_IsOK(res3)) {
    SWIG_exception_fail(SWIG_ArgError(res3), "in method '" "VideoDevInfoVector2_insert" "', argument " "3"" of type '" "std::vector< pj::VideoDevInfo >::value_type const &""'"); 
  }
  if (!argp3) {
    SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "VideoDevInfoVector2_insert" "', argument " "3"" of type '" "std::vector< pj::VideoDevInfo >::value_type const &""'"); 
  }
  arg3 = reinterpret_cast< std::vector< pj::VideoDevInfo >::value_type * >(argp3);
  result = std_vector_Sl_pj_VideoDevInfo_Sg__insert__SWIG_0(arg1,arg2,(pj::VideoDevInfo const &)*arg3);
  resultobj = SWIG_NewPointerObj(swig::make_output_iterator(static_cast< const std::vector< pj::VideoDevInfo >::iterator & >(result)),
    swig::SwigPyIterator::descriptor(),SWIG_POINTER_OWN);
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_VideoDevInfoVector2_insert__SWIG_1(PyObject *SWIGUNUSEDPARM(self), Py_ssize_t nobjs, PyObject **swig_obj) {
  PyObject *resultobj = 0;
  std::vector< pj::VideoDevInfo > *arg1 = (std::vector< pj::VideoDevInfo > *) 0 ;
  std::vector< pj::VideoDevInfo >::iterator arg2 ;
  std::vector< pj::VideoDevInfo >::size_type arg3 ;
  std::vector< pj::VideoDevInfo >::value_type *arg4 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  swig::SwigPyIterator *iter2 = 0 ;
  int res2 ;
  size_t val3 ;
  int ecode3 = 0 ;
  void *argp4 = 0 ;
  int res4 = 0 ;
  
  if ((nobjs < 4) || (nobjs > 4)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__vectorT_pj__VideoDevInfo_std__allocatorT_pj__VideoDevInfo_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "VideoDevInfoVector2_insert" "', argument " "1"" of type '" "std::vector< pj::VideoDevInfo > *""'"); 
  }
  arg1 = reinterpret_cast< std::vector< pj::VideoDevInfo > * >(argp1);
  res2 = SWIG_ConvertPtr(swig_obj[1], SWIG_as_voidptrptr(&iter2), swig::SwigPyIterator::descriptor(), 0);
  if (!SWIG_IsOK(res2) || !iter2) {
    SWIG_exception_fail(SWIG_ArgError(SWIG_TypeError), "in method '" "VideoDevInfoVector2_insert" "', argument " "2"" of type '" "std::vector< pj::VideoDevInfo >::iterator""'");
  } else {
    swig::SwigPyIterator_T<std::vector< pj::VideoDevInfo >::iterator > *iter_t = dynamic_cast<swig::SwigPyIterator_T<std::vector< pj::VideoDevInfo >::iterator > *>(iter2);
    if (iter_t) {
      arg2 = iter_t->get_current();
    } else {
      SWIG_exception_fail(SWIG_ArgError(SWIG_TypeError), "in method '" "VideoDevInfoVector2_insert" "', argument " "2"" of type '" "std::vector< pj::VideoDevInfo >::iterator""'");
    }
  }
  ecode3 = SWIG_AsVal_size_t(swig_obj[2], &val3);
  if (!SWIG_IsOK(ecode3)) {
    SWIG_exception_fail(SWIG_ArgError(ecode3), "in method '" "VideoDevInfoVector2_insert" "', argument " "3"" of type '" "std::vector< pj::VideoDevInfo >::size_type""'");
  } 
  arg3 = static_cast< std::vector< pj::VideoDevInfo >::size_type >(val3);
  res4 = SWIG_ConvertPtr(swig_obj[3], &argp4, SWIGTYPE_p_pj__VideoDevInfo,  0  | 0);
  if (!SWIG_IsOK(res4)) {
    SWIG_exception_fail(SWIG_ArgError(res4), "in method '" "VideoDevInfoVector2_insert" "', argument " "4"" of type '" "std::vector< pj::VideoDevInfo >::value_type const &""'"); 
  }
  if (!argp4) {
    SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "VideoDevInfoVector2_insert" "', argument " "4"" of type '" "std::vector< pj::VideoDevInfo >::value_type const &""'"); 
  }
  arg4 = reinterpret_cast< std::vector< pj::VideoDevInfo >::value_type * >(argp4);
  std_vector_Sl_pj_VideoDevInfo_Sg__insert__SWIG_1(arg1,arg2,arg3,(pj::VideoDevInfo const &)*arg4);
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_VideoDevInfoVector2_insert(PyObject *self, PyObject *args) {
  Py_ssize_t argc;
  PyObject *argv[5] = {
    0
  };
  
  if (!(argc = SWIG_Python_UnpackTuple(args, "VideoDevInfoVector2_insert", 0, 4, argv))) SWIG_fail;
  --argc;
  if (argc == 3) {
    int _v;
    int res = swig::asptr(argv[0], (std::vector< pj::VideoDevInfo,std::allocator< pj::VideoDevInfo > >**)(0));
    _v = SWIG_CheckState(res);
    if (_v) {
      swig::SwigPyIterator *iter = 0;
      int res = SWIG_ConvertPtr(argv[1], SWIG_as_voidptrptr(&iter), swig::SwigPyIterator::descriptor(), 0);
      _v = (SWIG_IsOK(res) && iter && (dynamic_cast<swig::SwigPyIterator_T<std::vector< pj::VideoDevInfo >::iterator > *>(iter) != 0));
      if (_v) {
        int res = SWIG_ConvertPtr(argv[2], 0, SWIGTYPE_p_pj__VideoDevInfo, SWIG_POINTER_NO_NULL | 0);
        _v = SWIG_CheckState(res);
        if (_v) {
          return _wrap_VideoDevInfoVector2_insert__SWIG_0(self, argc, argv);
        }
      }
    }
  }
  if (argc == 4) {
    int _v;
    int res = swig::asptr(argv[0], (std::vector< pj::VideoDevInfo,std::allocator< pj::VideoDevInfo > >**)(0));
    _v = SWIG_CheckState(res);
    if (_v) {
      swig::SwigPyIterator *iter = 0;
      int res = SWIG_ConvertPtr(argv[1], SWIG_as_voidptrptr(&iter), swig::SwigPyIterator::descriptor(), 0);
      _v = (SWIG_IsOK(res) && iter && (dynamic_cast<swig::SwigPyIterator_T<std::vector< pj::VideoDevInfo >::iterator > *>(iter) != 0));
      if (_v) {
        {
          int res = SWIG_AsVal_size_t(argv[2], NULL);
          _v = SWIG_CheckState(res);
        }
        if (_v) {
          int res = SWIG_ConvertPtr(argv[3], 0, SWIGTYPE_p_pj__VideoDevInfo, SWIG_POINTER_NO_NULL | 0);
          _v = SWIG_CheckState(res);
          if (_v) {
            return _wrap_VideoDevInfoVector2_insert__SWIG_1(self, argc, argv);
          }
        }
      }
    }
  }
  
fail:
  SWIG_Python_RaiseOrModifyTypeError("Wrong number or type of arguments for overloaded function 'VideoDevInfoVector2_insert'.\n"
    "  Possible C/C++ prototypes are:\n"
    "    std::vector< pj::VideoDevInfo >::insert(std::vector< pj::VideoDevInfo >::iterator,std::vector< pj::VideoDevInfo >::value_type const &)\n"
    "    std::vector< pj::VideoDevInfo >::insert(std::vector< pj::VideoDevInfo >::iterator,std::vector< pj::VideoDevInfo >::size_type,std::vector< pj::VideoDevInfo >::value_type const &)\n");
  return 0;
}


SWIGINTERN PyObject *_wrap_VideoDevInfoVector2_reserve(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  std::vector< pj::VideoDevInfo > *arg1 = (std::vector< pj::VideoDevInfo > *) 0 ;
  std::vector< pj::VideoDevInfo >::size_type arg2 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  size_t val2 ;
  int ecode2 = 0 ;
  PyObject *swig_obj[2] ;
  
  if (!SWIG_Python_UnpackTuple(args, "VideoDevInfoVector2_reserve", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__vectorT_pj__VideoDevInfo_std__allocatorT_pj__VideoDevInfo_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "VideoDevInfoVector2_reserve" "', argument " "1"" of type '" "std::vector< pj::VideoDevInfo > *""'"); 
  }
  arg1 = reinterpret_cast< std::vector< pj::VideoDevInfo > * >(argp1);
  ecode2 = SWIG_AsVal_size_t(swig_obj[1], &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "VideoDevInfoVector2_reserve" "', argument " "2"" of type '" "std::vector< pj::VideoDevInfo >::size_type""'");
  } 
  arg2 = static_cast< std::vector< pj::VideoDevInfo >::size_type >(val2);
  (arg1)->reserve(arg2);
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_VideoDevInfoVector2_capacity(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  std::vector< pj::VideoDevInfo > *arg1 = (std::vector< pj::VideoDevInfo > *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  std::vector< pj::VideoDevInfo >::size_type result;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__vectorT_pj__VideoDevInfo_std__allocatorT_pj__VideoDevInfo_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "VideoDevInfoVector2_capacity" "', argument " "1"" of type '" "std::vector< pj::VideoDevInfo > const *""'"); 
  }
  arg1 = reinterpret_cast< std::vector< pj::VideoDevInfo > * >(argp1);
  result = ((std::vector< pj::VideoDevInfo > const *)arg1)->capacity();
  resultobj = SWIG_From_size_t(static_cast< size_t >(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_delete_VideoDevInfoVector2(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  std::vector< pj::VideoDevInfo > *arg1 = (std::vector< pj::VideoDevInfo > *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__vectorT_pj__VideoDevInfo_std__allocatorT_pj__VideoDevInfo_t_t, SWIG_POINTER_DISOWN |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "delete_VideoDevInfoVector2" "', argument " "1"" of type '" "std::vector< pj::VideoDevInfo > *""'"); 
  }
  arg1 = reinterpret_cast< std::vector< pj::VideoDevInfo > * >(argp1);
  delete arg1;
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *VideoDevInfoVector2_swigregister(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *obj;
  if (!SWIG_Python_UnpackTuple(args, "swigregister", 1, 1, &obj)) return NULL;
  SWIG_TypeNewClientData(SWIGTYPE_p_std__vectorT_pj__VideoDevInfo_std__allocatorT_pj__VideoDevInfo_t_t, SWIG_NewClientData(obj));
  return SWIG_Py_Void();
}

SWIGINTERN PyObject *VideoDevInfoVector2_swiginit(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  return SWIG_Python_InitShadowInstance(args);
}

SWIGINTERN PyObject *_wrap_CodecFmtpVector_iterator(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  std::vector< pj::CodecFmtp > *arg1 = (std::vector< pj::CodecFmtp > *) 0 ;
  PyObject **arg2 = (PyObject **) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  swig::SwigPyIterator *result = 0 ;
  
  arg2 = &swig_obj[0];
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__vectorT_pj__CodecFmtp_std__allocatorT_pj__CodecFmtp_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "CodecFmtpVector_iterator" "', argument " "1"" of type '" "std::vector< pj::CodecFmtp > *""'"); 
  }
  arg1 = reinterpret_cast< std::vector< pj::CodecFmtp > * >(argp1);
  result = (swig::SwigPyIterator *)std_vector_Sl_pj_CodecFmtp_Sg__iterator(arg1,arg2);
  resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(result), SWIGTYPE_p_swig__SwigPyIterator, SWIG_POINTER_OWN |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_CodecFmtpVector___nonzero__(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  std::vector< pj::CodecFmtp > *arg1 = (std::vector< pj::CodecFmtp > *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  bool result;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__vectorT_pj__CodecFmtp_std__allocatorT_pj__CodecFmtp_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "CodecFmtpVector___nonzero__" "', argument " "1"" of type '" "std::vector< pj::CodecFmtp > const *""'"); 
  }
  arg1 = reinterpret_cast< std::vector< pj::CodecFmtp > * >(argp1);
  result = (bool)std_vector_Sl_pj_CodecFmtp_Sg____nonzero__((std::vector< pj::CodecFmtp > const *)arg1);
  resultobj = SWIG_From_bool(static_cast< bool >(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_CodecFmtpVector___bool__(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  std::vector< pj::CodecFmtp > *arg1 = (std::vector< pj::CodecFmtp > *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  bool result;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__vectorT_pj__CodecFmtp_std__allocatorT_pj__CodecFmtp_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "CodecFmtpVector___bool__" "', argument " "1"" of type '" "std::vector< pj::CodecFmtp > const *""'"); 
  }
  arg1 = reinterpret_cast< std::vector< pj::CodecFmtp > * >(argp1);
  result = (bool)std_vector_Sl_pj_CodecFmtp_Sg____bool__((std::vector< pj::CodecFmtp > const *)arg1);
  resultobj = SWIG_From_bool(static_cast< bool >(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_CodecFmtpVector___len__(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  std::vector< pj::CodecFmtp > *arg1 = (std::vector< pj::CodecFmtp > *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  std::vector< pj::CodecFmtp >::size_type result;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__vectorT_pj__CodecFmtp_std__allocatorT_pj__CodecFmtp_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "CodecFmtpVector___len__" "', argument " "1"" of type '" "std::vector< pj::CodecFmtp > const *""'"); 
  }
  arg1 = reinterpret_cast< std::vector< pj::CodecFmtp > * >(argp1);
  result = std_vector_Sl_pj_CodecFmtp_Sg____len__((std::vector< pj::CodecFmtp > const *)arg1);
  resultobj = SWIG_From_size_t(static_cast< size_t >(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_CodecFmtpVector___getslice__(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  std::vector< pj::CodecFmtp > *arg1 = (std::vector< pj::CodecFmtp > *) 0 ;
  std::vector< pj::CodecFmtp >::difference_type arg2 ;
  std::vector< pj::CodecFmtp >::difference_type arg3 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  ptrdiff_t val2 ;
  int ecode2 = 0 ;
  ptrdiff_t val3 ;
  int ecode3 = 0 ;
  PyObject *swig_obj[3] ;
  std::vector< pj::CodecFmtp,std::allocator< pj::CodecFmtp > > *result = 0 ;
  
  if (!SWIG_Python_UnpackTuple(args, "CodecFmtpVector___getslice__", 3, 3, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__vectorT_pj__CodecFmtp_std__allocatorT_pj__CodecFmtp_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "CodecFmtpVector___getslice__" "', argument " "1"" of type '" "std::vector< pj::CodecFmtp > *""'"); 
  }
  arg1 = reinterpret_cast< std::vector< pj::CodecFmtp > * >(argp1);
  ecode2 = SWIG_AsVal_ptrdiff_t(swig_obj[1], &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "CodecFmtpVector___getslice__" "', argument " "2"" of type '" "std::vector< pj::CodecFmtp >::difference_type""'");
  } 
  arg2 = static_cast< std::vector< pj::CodecFmtp >::difference_type >(val2);
  ecode3 = SWIG_AsVal_ptrdiff_t(swig_obj[2], &val3);
  if (!SWIG_IsOK(ecode3)) {
    SWIG_exception_fail(SWIG_ArgError(ecode3), "in method '" "CodecFmtpVector___getslice__" "', argument " "3"" of type '" "std::vector< pj::CodecFmtp >::difference_type""'");
  } 
  arg3 = static_cast< std::vector< pj::CodecFmtp >::difference_type >(val3);
  try {
    result = (std::vector< pj::CodecFmtp,std::allocator< pj::CodecFmtp > > *)std_vector_Sl_pj_CodecFmtp_Sg____getslice__(arg1,arg2,arg3);
  } catch(std::out_of_range &_e) {
    SWIG_exception_fail(SWIG_IndexError, (&_e)->what());
  } catch(std::invalid_argument &_e) {
    SWIG_exception_fail(SWIG_ValueError, (&_e)->what());
  }
  resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(result), SWIGTYPE_p_std__vectorT_pj__CodecFmtp_std__allocatorT_pj__CodecFmtp_t_t, SWIG_POINTER_OWN |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_CodecFmtpVector___setslice____SWIG_0(PyObject *SWIGUNUSEDPARM(self), Py_ssize_t nobjs, PyObject **swig_obj) {
  PyObject *resultobj = 0;
  std::vector< pj::CodecFmtp > *arg1 = (std::vector< pj::CodecFmtp > *) 0 ;
  std::vector< pj::CodecFmtp >::difference_type arg2 ;
  std::vector< pj::CodecFmtp >::difference_type arg3 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  ptrdiff_t val2 ;
  int ecode2 = 0 ;
  ptrdiff_t val3 ;
  int ecode3 = 0 ;
  
  if ((nobjs < 3) || (nobjs > 3)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__vectorT_pj__CodecFmtp_std__allocatorT_pj__CodecFmtp_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "CodecFmtpVector___setslice__" "', argument " "1"" of type '" "std::vector< pj::CodecFmtp > *""'"); 
  }
  arg1 = reinterpret_cast< std::vector< pj::CodecFmtp > * >(argp1);
  ecode2 = SWIG_AsVal_ptrdiff_t(swig_obj[1], &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "CodecFmtpVector___setslice__" "', argument " "2"" of type '" "std::vector< pj::CodecFmtp >::difference_type""'");
  } 
  arg2 = static_cast< std::vector< pj::CodecFmtp >::difference_type >(val2);
  ecode3 = SWIG_AsVal_ptrdiff_t(swig_obj[2], &val3);
  if (!SWIG_IsOK(ecode3)) {
    SWIG_exception_fail(SWIG_ArgError(ecode3), "in method '" "CodecFmtpVector___setslice__" "', argument " "3"" of type '" "std::vector< pj::CodecFmtp >::difference_type""'");
  } 
  arg3 = static_cast< std::vector< pj::CodecFmtp >::difference_type >(val3);
  try {
    std_vector_Sl_pj_CodecFmtp_Sg____setslice____SWIG_0(arg1,arg2,arg3);
  } catch(std::out_of_range &_e) {
    SWIG_exception_fail(SWIG_IndexError, (&_e)->what());
  } catch(std::invalid_argument &_e) {
    SWIG_exception_fail(SWIG_ValueError, (&_e)->what());
  }
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_CodecFmtpVector___setslice____SWIG_1(PyObject *SWIGUNUSEDPARM(self), Py_ssize_t nobjs, PyObject **swig_obj) {
  PyObject *resultobj = 0;
  std::vector< pj::CodecFmtp > *arg1 = (std::vector< pj::CodecFmtp > *) 0 ;
  std::vector< pj::CodecFmtp >::difference_type arg2 ;
  std::vector< pj::CodecFmtp >::difference_type arg3 ;
  std::vector< pj::CodecFmtp,std::allocator< pj::CodecFmtp > > *arg4 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  ptrdiff_t val2 ;
  int ecode2 = 0 ;
  ptrdiff_t val3 ;
  int ecode3 = 0 ;
  int res4 = SWIG_OLDOBJ ;
  
  if ((nobjs < 4) || (nobjs > 4)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__vectorT_pj__CodecFmtp_std__allocatorT_pj__CodecFmtp_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "CodecFmtpVector___setslice__" "', argument " "1"" of type '" "std::vector< pj::CodecFmtp > *""'"); 
  }
  arg1 = reinterpret_cast< std::vector< pj::CodecFmtp > * >(argp1);
  ecode2 = SWIG_AsVal_ptrdiff_t(swig_obj[1], &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "CodecFmtpVector___setslice__" "', argument " "2"" of type '" "std::vector< pj::CodecFmtp >::difference_type""'");
  } 
  arg2 = static_cast< std::vector< pj::CodecFmtp >::difference_type >(val2);
  ecode3 = SWIG_AsVal_ptrdiff_t(swig_obj[2], &val3);
  if (!SWIG_IsOK(ecode3)) {
    SWIG_exception_fail(SWIG_ArgError(ecode3), "in method '" "CodecFmtpVector___setslice__" "', argument " "3"" of type '" "std::vector< pj::CodecFmtp >::difference_type""'");
  } 
  arg3 = static_cast< std::vector< pj::CodecFmtp >::difference_type >(val3);
  {
    std::vector< pj::CodecFmtp,std::allocator< pj::CodecFmtp > > *ptr = (std::vector< pj::CodecFmtp,std::allocator< pj::CodecFmtp > > *)0;
    res4 = swig::asptr(swig_obj[3], &ptr);
    if (!SWIG_IsOK(res4)) {
      SWIG_exception_fail(SWIG_ArgError(res4), "in method '" "CodecFmtpVector___setslice__" "', argument " "4"" of type '" "std::vector< pj::CodecFmtp,std::allocator< pj::CodecFmtp > > const &""'"); 
    }
    if (!ptr) {
      SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "CodecFmtpVector___setslice__" "', argument " "4"" of type '" "std::vector< pj::CodecFmtp,std::allocator< pj::CodecFmtp > > const &""'"); 
    }
    arg4 = ptr;
  }
  try {
    std_vector_Sl_pj_CodecFmtp_Sg____setslice____SWIG_1(arg1,arg2,arg3,(std::vector< pj::CodecFmtp,std::allocator< pj::CodecFmtp > > const &)*arg4);
  } catch(std::out_of_range &_e) {
    SWIG_exception_fail(SWIG_IndexError, (&_e)->what());
  } catch(std::invalid_argument &_e) {
    SWIG_exception_fail(SWIG_ValueError, (&_e)->what());
  }
  resultobj = SWIG_Py_Void();
  if (SWIG_IsNewObj(res4)) delete arg4;
  return resultobj;
fail:
  if (SWIG_IsNewObj(res4)) delete arg4;
  return NULL;
}


SWIGINTERN PyObject *_wrap_CodecFmtpVector___setslice__(PyObject *self, PyObject *args) {
  Py_ssize_t argc;
  PyObject *argv[5] = {
    0
  };
  
  if (!(argc = SWIG_Python_UnpackTuple(args, "CodecFmtpVector___setslice__", 0, 4, argv))) SWIG_fail;
  --argc;
  if (argc == 3) {
    int _v;
    int res = swig::asptr(argv[0], (std::vector< pj::CodecFmtp,std::allocator< pj::CodecFmtp > >**)(0));
    _v = SWIG_CheckState(res);
    if (_v) {
      {
        int res = SWIG_AsVal_ptrdiff_t(argv[1], NULL);
        _v = SWIG_CheckState(res);
      }
      if (_v) {
        {
          int res = SWIG_AsVal_ptrdiff_t(argv[2], NULL);
          _v = SWIG_CheckState(res);
        }
        if (_v) {
          return _wrap_CodecFmtpVector___setslice____SWIG_0(self, argc, argv);
        }
      }
    }
  }
  if (argc == 4) {
    int _v;
    int res = swig::asptr(argv[0], (std::vector< pj::CodecFmtp,std::allocator< pj::CodecFmtp > >**)(0));
    _v = SWIG_CheckState(res);
    if (_v) {
      {
        int res = SWIG_AsVal_ptrdiff_t(argv[1], NULL);
        _v = SWIG_CheckState(res);
      }
      if (_v) {
        {
          int res = SWIG_AsVal_ptrdiff_t(argv[2], NULL);
          _v = SWIG_CheckState(res);
        }
        if (_v) {
          int res = swig::asptr(argv[3], (std::vector< pj::CodecFmtp,std::allocator< pj::CodecFmtp > >**)(0));
          _v = SWIG_CheckState(res);
          if (_v) {
            return _wrap_CodecFmtpVector___setslice____SWIG_1(self, argc, argv);
          }
        }
      }
    }
  }
  
fail:
  SWIG_Python_RaiseOrModifyTypeError("Wrong number or type of arguments for overloaded function 'CodecFmtpVector___setslice__'.\n"
    "  Possible C/C++ prototypes are:\n"
    "    std::vector< pj::CodecFmtp >::__setslice__(std::vector< pj::CodecFmtp >::difference_type,std::vector< pj::CodecFmtp >::difference_type)\n"
    "    std::vector< pj::CodecFmtp >::__setslice__(std::vector< pj::CodecFmtp >::difference_type,std::vector< pj::CodecFmtp >::difference_type,std::vector< pj::CodecFmtp,std::allocator< pj::CodecFmtp > > const &)\n");
  return 0;
}


SWIGINTERN PyObject *_wrap_CodecFmtpVector___delslice__(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  std::vector< pj::CodecFmtp > *arg1 = (std::vector< pj::CodecFmtp > *) 0 ;
  std::vector< pj::CodecFmtp >::difference_type arg2 ;
  std::vector< pj::CodecFmtp >::difference_type arg3 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  ptrdiff_t val2 ;
  int ecode2 = 0 ;
  ptrdiff_t val3 ;
  int ecode3 = 0 ;
  PyObject *swig_obj[3] ;
  
  if (!SWIG_Python_UnpackTuple(args, "CodecFmtpVector___delslice__", 3, 3, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__vectorT_pj__CodecFmtp_std__allocatorT_pj__CodecFmtp_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "CodecFmtpVector___delslice__" "', argument " "1"" of type '" "std::vector< pj::CodecFmtp > *""'"); 
  }
  arg1 = reinterpret_cast< std::vector< pj::CodecFmtp > * >(argp1);
  ecode2 = SWIG_AsVal_ptrdiff_t(swig_obj[1], &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "CodecFmtpVector___delslice__" "', argument " "2"" of type '" "std::vector< pj::CodecFmtp >::difference_type""'");
  } 
  arg2 = static_cast< std::vector< pj::CodecFmtp >::difference_type >(val2);
  ecode3 = SWIG_AsVal_ptrdiff_t(swig_obj[2], &val3);
  if (!SWIG_IsOK(ecode3)) {
    SWIG_exception_fail(SWIG_ArgError(ecode3), "in method '" "CodecFmtpVector___delslice__" "', argument " "3"" of type '" "std::vector< pj::CodecFmtp >::difference_type""'");
  } 
  arg3 = static_cast< std::vector< pj::CodecFmtp >::difference_type >(val3);
  try {
    std_vector_Sl_pj_CodecFmtp_Sg____delslice__(arg1,arg2,arg3);
  } catch(std::out_of_range &_e) {
    SWIG_exception_fail(SWIG_IndexError, (&_e)->what());
  } catch(std::invalid_argument &_e) {
    SWIG_exception_fail(SWIG_ValueError, (&_e)->what());
  }
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_CodecFmtpVector___delitem____SWIG_0(PyObject *SWIGUNUSEDPARM(self), Py_ssize_t nobjs, PyObject **swig_obj) {
  PyObject *resultobj = 0;
  std::vector< pj::CodecFmtp > *arg1 = (std::vector< pj::CodecFmtp > *) 0 ;
  std::vector< pj::CodecFmtp >::difference_type arg2 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  ptrdiff_t val2 ;
  int ecode2 = 0 ;
  
  if ((nobjs < 2) || (nobjs > 2)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__vectorT_pj__CodecFmtp_std__allocatorT_pj__CodecFmtp_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "CodecFmtpVector___delitem__" "', argument " "1"" of type '" "std::vector< pj::CodecFmtp > *""'"); 
  }
  arg1 = reinterpret_cast< std::vector< pj::CodecFmtp > * >(argp1);
  ecode2 = SWIG_AsVal_ptrdiff_t(swig_obj[1], &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "CodecFmtpVector___delitem__" "', argument " "2"" of type '" "std::vector< pj::CodecFmtp >::difference_type""'");
  } 
  arg2 = static_cast< std::vector< pj::CodecFmtp >::difference_type >(val2);
  try {
    std_vector_Sl_pj_CodecFmtp_Sg____delitem____SWIG_0(arg1,arg2);
  } catch(std::out_of_range &_e) {
    SWIG_exception_fail(SWIG_IndexError, (&_e)->what());
  } catch(std::invalid_argument &_e) {
    SWIG_exception_fail(SWIG_ValueError, (&_e)->what());
  }
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_CodecFmtpVector___getitem____SWIG_0(PyObject *SWIGUNUSEDPARM(self), Py_ssize_t nobjs, PyObject **swig_obj) {
  PyObject *resultobj = 0;
  std::vector< pj::CodecFmtp > *arg1 = (std::vector< pj::CodecFmtp > *) 0 ;
  PySliceObject *arg2 = (PySliceObject *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  std::vector< pj::CodecFmtp,std::allocator< pj::CodecFmtp > > *result = 0 ;
  
  if ((nobjs < 2) || (nobjs > 2)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__vectorT_pj__CodecFmtp_std__allocatorT_pj__CodecFmtp_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "CodecFmtpVector___getitem__" "', argument " "1"" of type '" "std::vector< pj::CodecFmtp > *""'"); 
  }
  arg1 = reinterpret_cast< std::vector< pj::CodecFmtp > * >(argp1);
  {
    if (!PySlice_Check(swig_obj[1])) {
      SWIG_exception_fail(SWIG_ArgError(SWIG_TypeError), "in method '" "CodecFmtpVector___getitem__" "', argument " "2"" of type '" "PySliceObject *""'");
    }
    arg2 = (PySliceObject *) swig_obj[1];
  }
  try {
    result = (std::vector< pj::CodecFmtp,std::allocator< pj::CodecFmtp > > *)std_vector_Sl_pj_CodecFmtp_Sg____getitem____SWIG_0(arg1,arg2);
  } catch(std::out_of_range &_e) {
    SWIG_exception_fail(SWIG_IndexError, (&_e)->what());
  } catch(std::invalid_argument &_e) {
    SWIG_exception_fail(SWIG_ValueError, (&_e)->what());
  }
  resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(result), SWIGTYPE_p_std__vectorT_pj__CodecFmtp_std__allocatorT_pj__CodecFmtp_t_t, SWIG_POINTER_OWN |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_CodecFmtpVector___setitem____SWIG_0(PyObject *SWIGUNUSEDPARM(self), Py_ssize_t nobjs, PyObject **swig_obj) {
  PyObject *resultobj = 0;
  std::vector< pj::CodecFmtp > *arg1 = (std::vector< pj::CodecFmtp > *) 0 ;
  PySliceObject *arg2 = (PySliceObject *) 0 ;
  std::vector< pj::CodecFmtp,std::allocator< pj::CodecFmtp > > *arg3 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  int res3 = SWIG_OLDOBJ ;
  
  if ((nobjs < 3) || (nobjs > 3)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__vectorT_pj__CodecFmtp_std__allocatorT_pj__CodecFmtp_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "CodecFmtpVector___setitem__" "', argument " "1"" of type '" "std::vector< pj::CodecFmtp > *""'"); 
  }
  arg1 = reinterpret_cast< std::vector< pj::CodecFmtp > * >(argp1);
  {
    if (!PySlice_Check(swig_obj[1])) {
      SWIG_exception_fail(SWIG_ArgError(SWIG_TypeError), "in method '" "CodecFmtpVector___setitem__" "', argument " "2"" of type '" "PySliceObject *""'");
    }
    arg2 = (PySliceObject *) swig_obj[1];
  }
  {
    std::vector< pj::CodecFmtp,std::allocator< pj::CodecFmtp > > *ptr = (std::vector< pj::CodecFmtp,std::allocator< pj::CodecFmtp > > *)0;
    res3 = swig::asptr(swig_obj[2], &ptr);
    if (!SWIG_IsOK(res3)) {
      SWIG_exception_fail(SWIG_ArgError(res3), "in method '" "CodecFmtpVector___setitem__" "', argument " "3"" of type '" "std::vector< pj::CodecFmtp,std::allocator< pj::CodecFmtp > > const &""'"); 
    }
    if (!ptr) {
      SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "CodecFmtpVector___setitem__" "', argument " "3"" of type '" "std::vector< pj::CodecFmtp,std::allocator< pj::CodecFmtp > > const &""'"); 
    }
    arg3 = ptr;
  }
  try {
    std_vector_Sl_pj_CodecFmtp_Sg____setitem____SWIG_0(arg1,arg2,(std::vector< pj::CodecFmtp,std::allocator< pj::CodecFmtp > > const &)*arg3);
  } catch(std::out_of_range &_e) {
    SWIG_exception_fail(SWIG_IndexError, (&_e)->what());
  } catch(std::invalid_argument &_e) {
    SWIG_exception_fail(SWIG_ValueError, (&_e)->what());
  }
  resultobj = SWIG_Py_Void();
  if (SWIG_IsNewObj(res3)) delete arg3;
  return resultobj;
fail:
  if (SWIG_IsNewObj(res3)) delete arg3;
  return NULL;
}


SWIGINTERN PyObject *_wrap_CodecFmtpVector___setitem____SWIG_1(PyObject *SWIGUNUSEDPARM(self), Py_ssize_t nobjs, PyObject **swig_obj) {
  PyObject *resultobj = 0;
  std::vector< pj::CodecFmtp > *arg1 = (std::vector< pj::CodecFmtp > *) 0 ;
  PySliceObject *arg2 = (PySliceObject *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  
  if ((nobjs < 2) || (nobjs > 2)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__vectorT_pj__CodecFmtp_std__allocatorT_pj__CodecFmtp_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "CodecFmtpVector___setitem__" "', argument " "1"" of type '" "std::vector< pj::CodecFmtp > *""'"); 
  }
  arg1 = reinterpret_cast< std::vector< pj::CodecFmtp > * >(argp1);
  {
    if (!PySlice_Check(swig_obj[1])) {
      SWIG_exception_fail(SWIG_ArgError(SWIG_TypeError), "in method '" "CodecFmtpVector___setitem__" "', argument " "2"" of type '" "PySliceObject *""'");
    }
    arg2 = (PySliceObject *) swig_obj[1];
  }
  try {
    std_vector_Sl_pj_CodecFmtp_Sg____setitem____SWIG_1(arg1,arg2);
  } catch(std::out_of_range &_e) {
    SWIG_exception_fail(SWIG_IndexError, (&_e)->what());
  } catch(std::invalid_argument &_e) {
    SWIG_exception_fail(SWIG_ValueError, (&_e)->what());
  }
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_CodecFmtpVector___delitem____SWIG_1(PyObject *SWIGUNUSEDPARM(self), Py_ssize_t nobjs, PyObject **swig_obj) {
  PyObject *resultobj = 0;
  std::vector< pj::CodecFmtp > *arg1 = (std::vector< pj::CodecFmtp > *) 0 ;
  PySliceObject *arg2 = (PySliceObject *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  
  if ((nobjs < 2) || (nobjs > 2)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__vectorT_pj__CodecFmtp_std__allocatorT_pj__CodecFmtp_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "CodecFmtpVector___delitem__" "', argument " "1"" of type '" "std::vector< pj::CodecFmtp > *""'"); 
  }
  arg1 = reinterpret_cast< std::vector< pj::CodecFmtp > * >(argp1);
  {
    if (!PySlice_Check(swig_obj[1])) {
      SWIG_exception_fail(SWIG_ArgError(SWIG_TypeError), "in method '" "CodecFmtpVector___delitem__" "', argument " "2"" of type '" "PySliceObject *""'");
    }
    arg2 = (PySliceObject *) swig_obj[1];
  }
  try {
    std_vector_Sl_pj_CodecFmtp_Sg____delitem____SWIG_1(arg1,arg2);
  } catch(std::out_of_range &_e) {
    SWIG_exception_fail(SWIG_IndexError, (&_e)->what());
  } catch(std::invalid_argument &_e) {
    SWIG_exception_fail(SWIG_ValueError, (&_e)->what());
  }
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_CodecFmtpVector___delitem__(PyObject *self, PyObject *args) {
  Py_ssize_t argc;
  PyObject *argv[3] = {
    0
  };
  
  if (!(argc = SWIG_Python_UnpackTuple(args, "CodecFmtpVector___delitem__", 0, 2, argv))) SWIG_fail;
  --argc;
  if (argc == 2) {
    int _v;
    int res = swig::asptr(argv[0], (std::vector< pj::CodecFmtp,std::allocator< pj::CodecFmtp > >**)(0));
    _v = SWIG_CheckState(res);
    if (_v) {
      {
        _v = PySlice_Check(argv[1]);
      }
      if (_v) {
        return _wrap_CodecFmtpVector___delitem____SWIG_1(self, argc, argv);
      }
    }
  }
  if (argc == 2) {
    int _v;
    int res = swig::asptr(argv[0], (std::vector< pj::CodecFmtp,std::allocator< pj::CodecFmtp > >**)(0));
    _v = SWIG_CheckState(res);
    if (_v) {
      {
        int res = SWIG_AsVal_ptrdiff_t(argv[1], NULL);
        _v = SWIG_CheckState(res);
      }
      if (_v) {
        return _wrap_CodecFmtpVector___delitem____SWIG_0(self, argc, argv);
      }
    }
  }
  
fail:
  SWIG_Python_RaiseOrModifyTypeError("Wrong number or type of arguments for overloaded function 'CodecFmtpVector___delitem__'.\n"
    "  Possible C/C++ prototypes are:\n"
    "    std::vector< pj::CodecFmtp >::__delitem__(std::vector< pj::CodecFmtp >::difference_type)\n"
    "    std::vector< pj::CodecFmtp >::__delitem__(PySliceObject *)\n");
  return 0;
}


SWIGINTERN PyObject *_wrap_CodecFmtpVector___getitem____SWIG_1(PyObject *SWIGUNUSEDPARM(self), Py_ssize_t nobjs, PyObject **swig_obj) {
  PyObject *resultobj = 0;
  std::vector< pj::CodecFmtp > *arg1 = (std::vector< pj::CodecFmtp > *) 0 ;
  std::vector< pj::CodecFmtp >::difference_type arg2 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  ptrdiff_t val2 ;
  int ecode2 = 0 ;
  std::vector< pj::CodecFmtp >::value_type *result = 0 ;
  
  if ((nobjs < 2) || (nobjs > 2)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__vectorT_pj__CodecFmtp_std__allocatorT_pj__CodecFmtp_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "CodecFmtpVector___getitem__" "', argument " "1"" of type '" "std::vector< pj::CodecFmtp > const *""'"); 
  }
  arg1 = reinterpret_cast< std::vector< pj::CodecFmtp > * >(argp1);
  ecode2 = SWIG_AsVal_ptrdiff_t(swig_obj[1], &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "CodecFmtpVector___getitem__" "', argument " "2"" of type '" "std::vector< pj::CodecFmtp >::difference_type""'");
  } 
  arg2 = static_cast< std::vector< pj::CodecFmtp >::difference_type >(val2);
  try {
    result = (std::vector< pj::CodecFmtp >::value_type *) &std_vector_Sl_pj_CodecFmtp_Sg____getitem____SWIG_1((std::vector< pj::CodecFmtp > const *)arg1,arg2);
  } catch(std::out_of_range &_e) {
    SWIG_exception_fail(SWIG_IndexError, (&_e)->what());
  }
  resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(result), SWIGTYPE_p_pj__CodecFmtp, 0 |  0 );
  (void)swig::container_owner<swig::traits<std::vector< pj::CodecFmtp >::value_type>::category>::back_reference(resultobj, swig_obj[0]);
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_CodecFmtpVector___getitem__(PyObject *self, PyObject *args) {
  Py_ssize_t argc;
  PyObject *argv[3] = {
    0
  };
  
  if (!(argc = SWIG_Python_UnpackTuple(args, "CodecFmtpVector___getitem__", 0, 2, argv))) SWIG_fail;
  --argc;
  if (argc == 2) {
    int _v;
    int res = swig::asptr(argv[0], (std::vector< pj::CodecFmtp,std::allocator< pj::CodecFmtp > >**)(0));
    _v = SWIG_CheckState(res);
    if (_v) {
      {
        _v = PySlice_Check(argv[1]);
      }
      if (_v) {
        return _wrap_CodecFmtpVector___getitem____SWIG_0(self, argc, argv);
      }
    }
  }
  if (argc == 2) {
    int _v;
    int res = swig::asptr(argv[0], (std::vector< pj::CodecFmtp,std::allocator< pj::CodecFmtp > >**)(0));
    _v = SWIG_CheckState(res);
    if (_v) {
      {
        int res = SWIG_AsVal_ptrdiff_t(argv[1], NULL);
        _v = SWIG_CheckState(res);
      }
      if (_v) {
        return _wrap_CodecFmtpVector___getitem____SWIG_1(self, argc, argv);
      }
    }
  }
  
fail:
  SWIG_Python_RaiseOrModifyTypeError("Wrong number or type of arguments for overloaded function 'CodecFmtpVector___getitem__'.\n"
    "  Possible C/C++ prototypes are:\n"
    "    std::vector< pj::CodecFmtp >::__getitem__(PySliceObject *)\n"
    "    std::vector< pj::CodecFmtp >::__getitem__(std::vector< pj::CodecFmtp >::difference_type) const\n");
  return 0;
}


SWIGINTERN PyObject *_wrap_CodecFmtpVector___setitem____SWIG_2(PyObject *SWIGUNUSEDPARM(self), Py_ssize_t nobjs, PyObject **swig_obj) {
  PyObject *resultobj = 0;
  std::vector< pj::CodecFmtp > *arg1 = (std::vector< pj::CodecFmtp > *) 0 ;
  std::vector< pj::CodecFmtp >::difference_type arg2 ;
  std::vector< pj::CodecFmtp >::value_type *arg3 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  ptrdiff_t val2 ;
  int ecode2 = 0 ;
  void *argp3 = 0 ;
  int res3 = 0 ;
  
  if ((nobjs < 3) || (nobjs > 3)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__vectorT_pj__CodecFmtp_std__allocatorT_pj__CodecFmtp_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "CodecFmtpVector___setitem__" "', argument " "1"" of type '" "std::vector< pj::CodecFmtp > *""'"); 
  }
  arg1 = reinterpret_cast< std::vector< pj::CodecFmtp > * >(argp1);
  ecode2 = SWIG_AsVal_ptrdiff_t(swig_obj[1], &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "CodecFmtpVector___setitem__" "', argument " "2"" of type '" "std::vector< pj::CodecFmtp >::difference_type""'");
  } 
  arg2 = static_cast< std::vector< pj::CodecFmtp >::difference_type >(val2);
  res3 = SWIG_ConvertPtr(swig_obj[2], &argp3, SWIGTYPE_p_pj__CodecFmtp,  0  | 0);
  if (!SWIG_IsOK(res3)) {
    SWIG_exception_fail(SWIG_ArgError(res3), "in method '" "CodecFmtpVector___setitem__" "', argument " "3"" of type '" "std::vector< pj::CodecFmtp >::value_type const &""'"); 
  }
  if (!argp3) {
    SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "CodecFmtpVector___setitem__" "', argument " "3"" of type '" "std::vector< pj::CodecFmtp >::value_type const &""'"); 
  }
  arg3 = reinterpret_cast< std::vector< pj::CodecFmtp >::value_type * >(argp3);
  try {
    std_vector_Sl_pj_CodecFmtp_Sg____setitem____SWIG_2(arg1,arg2,(pj::CodecFmtp const &)*arg3);
  } catch(std::out_of_range &_e) {
    SWIG_exception_fail(SWIG_IndexError, (&_e)->what());
  }
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_CodecFmtpVector___setitem__(PyObject *self, PyObject *args) {
  Py_ssize_t argc;
  PyObject *argv[4] = {
    0
  };
  
  if (!(argc = SWIG_Python_UnpackTuple(args, "CodecFmtpVector___setitem__", 0, 3, argv))) SWIG_fail;
  --argc;
  if (argc == 2) {
    int _v;
    int res = swig::asptr(argv[0], (std::vector< pj::CodecFmtp,std::allocator< pj::CodecFmtp > >**)(0));
    _v = SWIG_CheckState(res);
    if (_v) {
      {
        _v = PySlice_Check(argv[1]);
      }
      if (_v) {
        return _wrap_CodecFmtpVector___setitem____SWIG_1(self, argc, argv);
      }
    }
  }
  if (argc == 3) {
    int _v;
    int res = swig::asptr(argv[0], (std::vector< pj::CodecFmtp,std::allocator< pj::CodecFmtp > >**)(0));
    _v = SWIG_CheckState(res);
    if (_v) {
      {
        _v = PySlice_Check(argv[1]);
      }
      if (_v) {
        int res = swig::asptr(argv[2], (std::vector< pj::CodecFmtp,std::allocator< pj::CodecFmtp > >**)(0));
        _v = SWIG_CheckState(res);
        if (_v) {
          return _wrap_CodecFmtpVector___setitem____SWIG_0(self, argc, argv);
        }
      }
    }
  }
  if (argc == 3) {
    int _v;
    int res = swig::asptr(argv[0], (std::vector< pj::CodecFmtp,std::allocator< pj::CodecFmtp > >**)(0));
    _v = SWIG_CheckState(res);
    if (_v) {
      {
        int res = SWIG_AsVal_ptrdiff_t(argv[1], NULL);
        _v = SWIG_CheckState(res);
      }
      if (_v) {
        int res = SWIG_ConvertPtr(argv[2], 0, SWIGTYPE_p_pj__CodecFmtp, SWIG_POINTER_NO_NULL | 0);
        _v = SWIG_CheckState(res);
        if (_v) {
          return _wrap_CodecFmtpVector___setitem____SWIG_2(self, argc, argv);
        }
      }
    }
  }
  
fail:
  SWIG_Python_RaiseOrModifyTypeError("Wrong number or type of arguments for overloaded function 'CodecFmtpVector___setitem__'.\n"
    "  Possible C/C++ prototypes are:\n"
    "    std::vector< pj::CodecFmtp >::__setitem__(PySliceObject *,std::vector< pj::CodecFmtp,std::allocator< pj::CodecFmtp > > const &)\n"
    "    std::vector< pj::CodecFmtp >::__setitem__(PySliceObject *)\n"
    "    std::vector< pj::CodecFmtp >::__setitem__(std::vector< pj::CodecFmtp >::difference_type,std::vector< pj::CodecFmtp >::value_type const &)\n");
  return 0;
}


SWIGINTERN PyObject *_wrap_CodecFmtpVector_pop(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  std::vector< pj::CodecFmtp > *arg1 = (std::vector< pj::CodecFmtp > *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  std::vector< pj::CodecFmtp >::value_type result;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__vectorT_pj__CodecFmtp_std__allocatorT_pj__CodecFmtp_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "CodecFmtpVector_pop" "', argument " "1"" of type '" "std::vector< pj::CodecFmtp > *""'"); 
  }
  arg1 = reinterpret_cast< std::vector< pj::CodecFmtp > * >(argp1);
  try {
    result = std_vector_Sl_pj_CodecFmtp_Sg__pop(arg1);
  } catch(std::out_of_range &_e) {
    SWIG_exception_fail(SWIG_IndexError, (&_e)->what());
  }
  resultobj = SWIG_NewPointerObj((new std::vector< pj::CodecFmtp >::value_type(static_cast< const std::vector< pj::CodecFmtp >::value_type& >(result))), SWIGTYPE_p_pj__CodecFmtp, SWIG_POINTER_OWN |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_CodecFmtpVector_append(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  std::vector< pj::CodecFmtp > *arg1 = (std::vector< pj::CodecFmtp > *) 0 ;
  std::vector< pj::CodecFmtp >::value_type *arg2 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  void *argp2 = 0 ;
  int res2 = 0 ;
  PyObject *swig_obj[2] ;
  
  if (!SWIG_Python_UnpackTuple(args, "CodecFmtpVector_append", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__vectorT_pj__CodecFmtp_std__allocatorT_pj__CodecFmtp_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "CodecFmtpVector_append" "', argument " "1"" of type '" "std::vector< pj::CodecFmtp > *""'"); 
  }
  arg1 = reinterpret_cast< std::vector< pj::CodecFmtp > * >(argp1);
  res2 = SWIG_ConvertPtr(swig_obj[1], &argp2, SWIGTYPE_p_pj__CodecFmtp,  0  | 0);
  if (!SWIG_IsOK(res2)) {
    SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "CodecFmtpVector_append" "', argument " "2"" of type '" "std::vector< pj::CodecFmtp >::value_type const &""'"); 
  }
  if (!argp2) {
    SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "CodecFmtpVector_append" "', argument " "2"" of type '" "std::vector< pj::CodecFmtp >::value_type const &""'"); 
  }
  arg2 = reinterpret_cast< std::vector< pj::CodecFmtp >::value_type * >(argp2);
  std_vector_Sl_pj_CodecFmtp_Sg__append(arg1,(pj::CodecFmtp const &)*arg2);
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_new_CodecFmtpVector__SWIG_0(PyObject *SWIGUNUSEDPARM(self), Py_ssize_t nobjs, PyObject **SWIGUNUSEDPARM(swig_obj)) {
  PyObject *resultobj = 0;
  std::vector< pj::CodecFmtp > *result = 0 ;
  
  if ((nobjs < 0) || (nobjs > 0)) SWIG_fail;
  result = (std::vector< pj::CodecFmtp > *)new std::vector< pj::CodecFmtp >();
  resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(result), SWIGTYPE_p_std__vectorT_pj__CodecFmtp_std__allocatorT_pj__CodecFmtp_t_t, SWIG_POINTER_NEW |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_new_CodecFmtpVector__SWIG_1(PyObject *SWIGUNUSEDPARM(self), Py_ssize_t nobjs, PyObject **swig_obj) {
  PyObject *resultobj = 0;
  std::vector< pj::CodecFmtp > *arg1 = 0 ;
  int res1 = SWIG_OLDOBJ ;
  std::vector< pj::CodecFmtp > *result = 0 ;
  
  if ((nobjs < 1) || (nobjs > 1)) SWIG_fail;
  {
    std::vector< pj::CodecFmtp,std::allocator< pj::CodecFmtp > > *ptr = (std::vector< pj::CodecFmtp,std::allocator< pj::CodecFmtp > > *)0;
    res1 = swig::asptr(swig_obj[0], &ptr);
    if (!SWIG_IsOK(res1)) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "new_CodecFmtpVector" "', argument " "1"" of type '" "std::vector< pj::CodecFmtp > const &""'"); 
    }
    if (!ptr) {
      SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "new_CodecFmtpVector" "', argument " "1"" of type '" "std::vector< pj::CodecFmtp > const &""'"); 
    }
    arg1 = ptr;
  }
  result = (std::vector< pj::CodecFmtp > *)new std::vector< pj::CodecFmtp >((std::vector< pj::CodecFmtp > const &)*arg1);
  resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(result), SWIGTYPE_p_std__vectorT_pj__CodecFmtp_std__allocatorT_pj__CodecFmtp_t_t, SWIG_POINTER_NEW |  0 );
  if (SWIG_IsNewObj(res1)) delete arg1;
  return resultobj;
fail:
  if (SWIG_IsNewObj(res1)) delete arg1;
  return NULL;
}


SWIGINTERN PyObject *_wrap_CodecFmtpVector_empty(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  std::vector< pj::CodecFmtp > *arg1 = (std::vector< pj::CodecFmtp > *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  bool result;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__vectorT_pj__CodecFmtp_std__allocatorT_pj__CodecFmtp_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "CodecFmtpVector_empty" "', argument " "1"" of type '" "std::vector< pj::CodecFmtp > const *""'"); 
  }
  arg1 = reinterpret_cast< std::vector< pj::CodecFmtp > * >(argp1);
  result = (bool)((std::vector< pj::CodecFmtp > const *)arg1)->empty();
  resultobj = SWIG_From_bool(static_cast< bool >(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_CodecFmtpVector_size(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  std::vector< pj::CodecFmtp > *arg1 = (std::vector< pj::CodecFmtp > *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  std::vector< pj::CodecFmtp >::size_type result;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__vectorT_pj__CodecFmtp_std__allocatorT_pj__CodecFmtp_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "CodecFmtpVector_size" "', argument " "1"" of type '" "std::vector< pj::CodecFmtp > const *""'"); 
  }
  arg1 = reinterpret_cast< std::vector< pj::CodecFmtp > * >(argp1);
  result = ((std::vector< pj::CodecFmtp > const *)arg1)->size();
  resultobj = SWIG_From_size_t(static_cast< size_t >(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_CodecFmtpVector_swap(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  std::vector< pj::CodecFmtp > *arg1 = (std::vector< pj::CodecFmtp > *) 0 ;
  std::vector< pj::CodecFmtp > *arg2 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  void *argp2 = 0 ;
  int res2 = 0 ;
  PyObject *swig_obj[2] ;
  
  if (!SWIG_Python_UnpackTuple(args, "CodecFmtpVector_swap", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__vectorT_pj__CodecFmtp_std__allocatorT_pj__CodecFmtp_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "CodecFmtpVector_swap" "', argument " "1"" of type '" "std::vector< pj::CodecFmtp > *""'"); 
  }
  arg1 = reinterpret_cast< std::vector< pj::CodecFmtp > * >(argp1);
  res2 = SWIG_ConvertPtr(swig_obj[1], &argp2, SWIGTYPE_p_std__vectorT_pj__CodecFmtp_std__allocatorT_pj__CodecFmtp_t_t,  0 );
  if (!SWIG_IsOK(res2)) {
    SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "CodecFmtpVector_swap" "', argument " "2"" of type '" "std::vector< pj::CodecFmtp > &""'"); 
  }
  if (!argp2) {
    SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "CodecFmtpVector_swap" "', argument " "2"" of type '" "std::vector< pj::CodecFmtp > &""'"); 
  }
  arg2 = reinterpret_cast< std::vector< pj::CodecFmtp > * >(argp2);
  (arg1)->swap(*arg2);
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_CodecFmtpVector_begin(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  std::vector< pj::CodecFmtp > *arg1 = (std::vector< pj::CodecFmtp > *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  std::vector< pj::CodecFmtp >::iterator result;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__vectorT_pj__CodecFmtp_std__allocatorT_pj__CodecFmtp_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "CodecFmtpVector_begin" "', argument " "1"" of type '" "std::vector< pj::CodecFmtp > *""'"); 
  }
  arg1 = reinterpret_cast< std::vector< pj::CodecFmtp > * >(argp1);
  result = (arg1)->begin();
  resultobj = SWIG_NewPointerObj(swig::make_output_iterator(static_cast< const std::vector< pj::CodecFmtp >::iterator & >(result)),
    swig::SwigPyIterator::descriptor(),SWIG_POINTER_OWN);
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_CodecFmtpVector_end(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  std::vector< pj::CodecFmtp > *arg1 = (std::vector< pj::CodecFmtp > *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  std::vector< pj::CodecFmtp >::iterator result;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__vectorT_pj__CodecFmtp_std__allocatorT_pj__CodecFmtp_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "CodecFmtpVector_end" "', argument " "1"" of type '" "std::vector< pj::CodecFmtp > *""'"); 
  }
  arg1 = reinterpret_cast< std::vector< pj::CodecFmtp > * >(argp1);
  result = (arg1)->end();
  resultobj = SWIG_NewPointerObj(swig::make_output_iterator(static_cast< const std::vector< pj::CodecFmtp >::iterator & >(result)),
    swig::SwigPyIterator::descriptor(),SWIG_POINTER_OWN);
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_CodecFmtpVector_rbegin(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  std::vector< pj::CodecFmtp > *arg1 = (std::vector< pj::CodecFmtp > *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  std::vector< pj::CodecFmtp >::reverse_iterator result;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__vectorT_pj__CodecFmtp_std__allocatorT_pj__CodecFmtp_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "CodecFmtpVector_rbegin" "', argument " "1"" of type '" "std::vector< pj::CodecFmtp > *""'"); 
  }
  arg1 = reinterpret_cast< std::vector< pj::CodecFmtp > * >(argp1);
  result = (arg1)->rbegin();
  resultobj = SWIG_NewPointerObj(swig::make_output_iterator(static_cast< const std::vector< pj::CodecFmtp >::reverse_iterator & >(result)),
    swig::SwigPyIterator::descriptor(),SWIG_POINTER_OWN);
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_CodecFmtpVector_rend(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  std::vector< pj::CodecFmtp > *arg1 = (std::vector< pj::CodecFmtp > *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  std::vector< pj::CodecFmtp >::reverse_iterator result;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__vectorT_pj__CodecFmtp_std__allocatorT_pj__CodecFmtp_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "CodecFmtpVector_rend" "', argument " "1"" of type '" "std::vector< pj::CodecFmtp > *""'"); 
  }
  arg1 = reinterpret_cast< std::vector< pj::CodecFmtp > * >(argp1);
  result = (arg1)->rend();
  resultobj = SWIG_NewPointerObj(swig::make_output_iterator(static_cast< const std::vector< pj::CodecFmtp >::reverse_iterator & >(result)),
    swig::SwigPyIterator::descriptor(),SWIG_POINTER_OWN);
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_CodecFmtpVector_clear(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  std::vector< pj::CodecFmtp > *arg1 = (std::vector< pj::CodecFmtp > *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__vectorT_pj__CodecFmtp_std__allocatorT_pj__CodecFmtp_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "CodecFmtpVector_clear" "', argument " "1"" of type '" "std::vector< pj::CodecFmtp > *""'"); 
  }
  arg1 = reinterpret_cast< std::vector< pj::CodecFmtp > * >(argp1);
  (arg1)->clear();
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_CodecFmtpVector_get_allocator(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  std::vector< pj::CodecFmtp > *arg1 = (std::vector< pj::CodecFmtp > *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  SwigValueWrapper< std::allocator< pj::CodecFmtp > > result;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__vectorT_pj__CodecFmtp_std__allocatorT_pj__CodecFmtp_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "CodecFmtpVector_get_allocator" "', argument " "1"" of type '" "std::vector< pj::CodecFmtp > const *""'"); 
  }
  arg1 = reinterpret_cast< std::vector< pj::CodecFmtp > * >(argp1);
  result = ((std::vector< pj::CodecFmtp > const *)arg1)->get_allocator();
  resultobj = SWIG_NewPointerObj((new std::vector< pj::CodecFmtp >::allocator_type(static_cast< const std::vector< pj::CodecFmtp >::allocator_type& >(result))), SWIGTYPE_p_std__allocatorT_pj__CodecFmtp_t, SWIG_POINTER_OWN |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_new_CodecFmtpVector__SWIG_2(PyObject *SWIGUNUSEDPARM(self), Py_ssize_t nobjs, PyObject **swig_obj) {
  PyObject *resultobj = 0;
  std::vector< pj::CodecFmtp >::size_type arg1 ;
  size_t val1 ;
  int ecode1 = 0 ;
  std::vector< pj::CodecFmtp > *result = 0 ;
  
  if ((nobjs < 1) || (nobjs > 1)) SWIG_fail;
  ecode1 = SWIG_AsVal_size_t(swig_obj[0], &val1);
  if (!SWIG_IsOK(ecode1)) {
    SWIG_exception_fail(SWIG_ArgError(ecode1), "in method '" "new_CodecFmtpVector" "', argument " "1"" of type '" "std::vector< pj::CodecFmtp >::size_type""'");
  } 
  arg1 = static_cast< std::vector< pj::CodecFmtp >::size_type >(val1);
  result = (std::vector< pj::CodecFmtp > *)new std::vector< pj::CodecFmtp >(arg1);
  resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(result), SWIGTYPE_p_std__vectorT_pj__CodecFmtp_std__allocatorT_pj__CodecFmtp_t_t, SWIG_POINTER_NEW |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_CodecFmtpVector_pop_back(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  std::vector< pj::CodecFmtp > *arg1 = (std::vector< pj::CodecFmtp > *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__vectorT_pj__CodecFmtp_std__allocatorT_pj__CodecFmtp_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "CodecFmtpVector_pop_back" "', argument " "1"" of type '" "std::vector< pj::CodecFmtp > *""'"); 
  }
  arg1 = reinterpret_cast< std::vector< pj::CodecFmtp > * >(argp1);
  (arg1)->pop_back();
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_CodecFmtpVector_resize__SWIG_0(PyObject *SWIGUNUSEDPARM(self), Py_ssize_t nobjs, PyObject **swig_obj) {
  PyObject *resultobj = 0;
  std::vector< pj::CodecFmtp > *arg1 = (std::vector< pj::CodecFmtp > *) 0 ;
  std::vector< pj::CodecFmtp >::size_type arg2 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  size_t val2 ;
  int ecode2 = 0 ;
  
  if ((nobjs < 2) || (nobjs > 2)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__vectorT_pj__CodecFmtp_std__allocatorT_pj__CodecFmtp_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "CodecFmtpVector_resize" "', argument " "1"" of type '" "std::vector< pj::CodecFmtp > *""'"); 
  }
  arg1 = reinterpret_cast< std::vector< pj::CodecFmtp > * >(argp1);
  ecode2 = SWIG_AsVal_size_t(swig_obj[1], &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "CodecFmtpVector_resize" "', argument " "2"" of type '" "std::vector< pj::CodecFmtp >::size_type""'");
  } 
  arg2 = static_cast< std::vector< pj::CodecFmtp >::size_type >(val2);
  (arg1)->resize(arg2);
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_CodecFmtpVector_erase__SWIG_0(PyObject *SWIGUNUSEDPARM(self), Py_ssize_t nobjs, PyObject **swig_obj) {
  PyObject *resultobj = 0;
  std::vector< pj::CodecFmtp > *arg1 = (std::vector< pj::CodecFmtp > *) 0 ;
  std::vector< pj::CodecFmtp >::iterator arg2 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  swig::SwigPyIterator *iter2 = 0 ;
  int res2 ;
  std::vector< pj::CodecFmtp >::iterator result;
  
  if ((nobjs < 2) || (nobjs > 2)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__vectorT_pj__CodecFmtp_std__allocatorT_pj__CodecFmtp_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "CodecFmtpVector_erase" "', argument " "1"" of type '" "std::vector< pj::CodecFmtp > *""'"); 
  }
  arg1 = reinterpret_cast< std::vector< pj::CodecFmtp > * >(argp1);
  res2 = SWIG_ConvertPtr(swig_obj[1], SWIG_as_voidptrptr(&iter2), swig::SwigPyIterator::descriptor(), 0);
  if (!SWIG_IsOK(res2) || !iter2) {
    SWIG_exception_fail(SWIG_ArgError(SWIG_TypeError), "in method '" "CodecFmtpVector_erase" "', argument " "2"" of type '" "std::vector< pj::CodecFmtp >::iterator""'");
  } else {
    swig::SwigPyIterator_T<std::vector< pj::CodecFmtp >::iterator > *iter_t = dynamic_cast<swig::SwigPyIterator_T<std::vector< pj::CodecFmtp >::iterator > *>(iter2);
    if (iter_t) {
      arg2 = iter_t->get_current();
    } else {
      SWIG_exception_fail(SWIG_ArgError(SWIG_TypeError), "in method '" "CodecFmtpVector_erase" "', argument " "2"" of type '" "std::vector< pj::CodecFmtp >::iterator""'");
    }
  }
  result = std_vector_Sl_pj_CodecFmtp_Sg__erase__SWIG_0(arg1,arg2);
  resultobj = SWIG_NewPointerObj(swig::make_output_iterator(static_cast< const std::vector< pj::CodecFmtp >::iterator & >(result)),
    swig::SwigPyIterator::descriptor(),SWIG_POINTER_OWN);
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_CodecFmtpVector_erase__SWIG_1(PyObject *SWIGUNUSEDPARM(self), Py_ssize_t nobjs, PyObject **swig_obj) {
  PyObject *resultobj = 0;
  std::vector< pj::CodecFmtp > *arg1 = (std::vector< pj::CodecFmtp > *) 0 ;
  std::vector< pj::CodecFmtp >::iterator arg2 ;
  std::vector< pj::CodecFmtp >::iterator arg3 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  swig::SwigPyIterator *iter2 = 0 ;
  int res2 ;
  swig::SwigPyIterator *iter3 = 0 ;
  int res3 ;
  std::vector< pj::CodecFmtp >::iterator result;
  
  if ((nobjs < 3) || (nobjs > 3)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__vectorT_pj__CodecFmtp_std__allocatorT_pj__CodecFmtp_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "CodecFmtpVector_erase" "', argument " "1"" of type '" "std::vector< pj::CodecFmtp > *""'"); 
  }
  arg1 = reinterpret_cast< std::vector< pj::CodecFmtp > * >(argp1);
  res2 = SWIG_ConvertPtr(swig_obj[1], SWIG_as_voidptrptr(&iter2), swig::SwigPyIterator::descriptor(), 0);
  if (!SWIG_IsOK(res2) || !iter2) {
    SWIG_exception_fail(SWIG_ArgError(SWIG_TypeError), "in method '" "CodecFmtpVector_erase" "', argument " "2"" of type '" "std::vector< pj::CodecFmtp >::iterator""'");
  } else {
    swig::SwigPyIterator_T<std::vector< pj::CodecFmtp >::iterator > *iter_t = dynamic_cast<swig::SwigPyIterator_T<std::vector< pj::CodecFmtp >::iterator > *>(iter2);
    if (iter_t) {
      arg2 = iter_t->get_current();
    } else {
      SWIG_exception_fail(SWIG_ArgError(SWIG_TypeError), "in method '" "CodecFmtpVector_erase" "', argument " "2"" of type '" "std::vector< pj::CodecFmtp >::iterator""'");
    }
  }
  res3 = SWIG_ConvertPtr(swig_obj[2], SWIG_as_voidptrptr(&iter3), swig::SwigPyIterator::descriptor(), 0);
  if (!SWIG_IsOK(res3) || !iter3) {
    SWIG_exception_fail(SWIG_ArgError(SWIG_TypeError), "in method '" "CodecFmtpVector_erase" "', argument " "3"" of type '" "std::vector< pj::CodecFmtp >::iterator""'");
  } else {
    swig::SwigPyIterator_T<std::vector< pj::CodecFmtp >::iterator > *iter_t = dynamic_cast<swig::SwigPyIterator_T<std::vector< pj::CodecFmtp >::iterator > *>(iter3);
    if (iter_t) {
      arg3 = iter_t->get_current();
    } else {
      SWIG_exception_fail(SWIG_ArgError(SWIG_TypeError), "in method '" "CodecFmtpVector_erase" "', argument " "3"" of type '" "std::vector< pj::CodecFmtp >::iterator""'");
    }
  }
  result = std_vector_Sl_pj_CodecFmtp_Sg__erase__SWIG_1(arg1,arg2,arg3);
  resultobj = SWIG_NewPointerObj(swig::make_output_iterator(static_cast< const std::vector< pj::CodecFmtp >::iterator & >(result)),
    swig::SwigPyIterator::descriptor(),SWIG_POINTER_OWN);
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_CodecFmtpVector_erase(PyObject *self, PyObject *args) {
  Py_ssize_t argc;
  PyObject *argv[4] = {
    0
  };
  
  if (!(argc = SWIG_Python_UnpackTuple(args, "CodecFmtpVector_erase", 0, 3, argv))) SWIG_fail;
  --argc;
  if (argc == 2) {
    int _v;
    int res = swig::asptr(argv[0], (std::vector< pj::CodecFmtp,std::allocator< pj::CodecFmtp > >**)(0));
    _v = SWIG_CheckState(res);
    if (_v) {
      swig::SwigPyIterator *iter = 0;
      int res = SWIG_ConvertPtr(argv[1], SWIG_as_voidptrptr(&iter), swig::SwigPyIterator::descriptor(), 0);
      _v = (SWIG_IsOK(res) && iter && (dynamic_cast<swig::SwigPyIterator_T<std::vector< pj::CodecFmtp >::iterator > *>(iter) != 0));
      if (_v) {
        return _wrap_CodecFmtpVector_erase__SWIG_0(self, argc, argv);
      }
    }
  }
  if (argc == 3) {
    int _v;
    int res = swig::asptr(argv[0], (std::vector< pj::CodecFmtp,std::allocator< pj::CodecFmtp > >**)(0));
    _v = SWIG_CheckState(res);
    if (_v) {
      swig::SwigPyIterator *iter = 0;
      int res = SWIG_ConvertPtr(argv[1], SWIG_as_voidptrptr(&iter), swig::SwigPyIterator::descriptor(), 0);
      _v = (SWIG_IsOK(res) && iter && (dynamic_cast<swig::SwigPyIterator_T<std::vector< pj::CodecFmtp >::iterator > *>(iter) != 0));
      if (_v) {
        swig::SwigPyIterator *iter = 0;
        int res = SWIG_ConvertPtr(argv[2], SWIG_as_voidptrptr(&iter), swig::SwigPyIterator::descriptor(), 0);
        _v = (SWIG_IsOK(res) && iter && (dynamic_cast<swig::SwigPyIterator_T<std::vector< pj::CodecFmtp >::iterator > *>(iter) != 0));
        if (_v) {
          return _wrap_CodecFmtpVector_erase__SWIG_1(self, argc, argv);
        }
      }
    }
  }
  
fail:
  SWIG_Python_RaiseOrModifyTypeError("Wrong number or type of arguments for overloaded function 'CodecFmtpVector_erase'.\n"
    "  Possible C/C++ prototypes are:\n"
    "    std::vector< pj::CodecFmtp >::erase(std::vector< pj::CodecFmtp >::iterator)\n"
    "    std::vector< pj::CodecFmtp >::erase(std::vector< pj::CodecFmtp >::iterator,std::vector< pj::CodecFmtp >::iterator)\n");
  return 0;
}


SWIGINTERN PyObject *_wrap_new_CodecFmtpVector__SWIG_3(PyObject *SWIGUNUSEDPARM(self), Py_ssize_t nobjs, PyObject **swig_obj) {
  PyObject *resultobj = 0;
  std::vector< pj::CodecFmtp >::size_type arg1 ;
  std::vector< pj::CodecFmtp >::value_type *arg2 = 0 ;
  size_t val1 ;
  int ecode1 = 0 ;
  void *argp2 = 0 ;
  int res2 = 0 ;
  std::vector< pj::CodecFmtp > *result = 0 ;
  
  if ((nobjs < 2) || (nobjs > 2)) SWIG_fail;
  ecode1 = SWIG_AsVal_size_t(swig_obj[0], &val1);
  if (!SWIG_IsOK(ecode1)) {
    SWIG_exception_fail(SWIG_ArgError(ecode1), "in method '" "new_CodecFmtpVector" "', argument " "1"" of type '" "std::vector< pj::CodecFmtp >::size_type""'");
  } 
  arg1 = static_cast< std::vector< pj::CodecFmtp >::size_type >(val1);
  res2 = SWIG_ConvertPtr(swig_obj[1], &argp2, SWIGTYPE_p_pj__CodecFmtp,  0  | 0);
  if (!SWIG_IsOK(res2)) {
    SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "new_CodecFmtpVector" "', argument " "2"" of type '" "std::vector< pj::CodecFmtp >::value_type const &""'"); 
  }
  if (!argp2) {
    SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "new_CodecFmtpVector" "', argument " "2"" of type '" "std::vector< pj::CodecFmtp >::value_type const &""'"); 
  }
  arg2 = reinterpret_cast< std::vector< pj::CodecFmtp >::value_type * >(argp2);
  result = (std::vector< pj::CodecFmtp > *)new std::vector< pj::CodecFmtp >(arg1,(std::vector< pj::CodecFmtp >::value_type const &)*arg2);
  resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(result), SWIGTYPE_p_std__vectorT_pj__CodecFmtp_std__allocatorT_pj__CodecFmtp_t_t, SWIG_POINTER_NEW |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_new_CodecFmtpVector(PyObject *self, PyObject *args) {
  Py_ssize_t argc;
  PyObject *argv[3] = {
    0
  };
  
  if (!(argc = SWIG_Python_UnpackTuple(args, "new_CodecFmtpVector", 0, 2, argv))) SWIG_fail;
  --argc;
  if (argc == 0) {
    return _wrap_new_CodecFmtpVector__SWIG_0(self, argc, argv);
  }
  if (argc == 1) {
    int _v;
    {
      int res = SWIG_AsVal_size_t(argv[0], NULL);
      _v = SWIG_CheckState(res);
    }
    if (_v) {
      return _wrap_new_CodecFmtpVector__SWIG_2(self, argc, argv);
    }
  }
  if (argc == 1) {
    int _v;
    int res = swig::asptr(argv[0], (std::vector< pj::CodecFmtp,std::allocator< pj::CodecFmtp > >**)(0));
    _v = SWIG_CheckState(res);
    if (_v) {
      return _wrap_new_CodecFmtpVector__SWIG_1(self, argc, argv);
    }
  }
  if (argc == 2) {
    int _v;
    {
      int res = SWIG_AsVal_size_t(argv[0], NULL);
      _v = SWIG_CheckState(res);
    }
    if (_v) {
      int res = SWIG_ConvertPtr(argv[1], 0, SWIGTYPE_p_pj__CodecFmtp, SWIG_POINTER_NO_NULL | 0);
      _v = SWIG_CheckState(res);
      if (_v) {
        return _wrap_new_CodecFmtpVector__SWIG_3(self, argc, argv);
      }
    }
  }
  
fail:
  SWIG_Python_RaiseOrModifyTypeError("Wrong number or type of arguments for overloaded function 'new_CodecFmtpVector'.\n"
    "  Possible C/C++ prototypes are:\n"
    "    std::vector< pj::CodecFmtp >::vector()\n"
    "    std::vector< pj::CodecFmtp >::vector(std::vector< pj::CodecFmtp > const &)\n"
    "    std::vector< pj::CodecFmtp >::vector(std::vector< pj::CodecFmtp >::size_type)\n"
    "    std::vector< pj::CodecFmtp >::vector(std::vector< pj::CodecFmtp >::size_type,std::vector< pj::CodecFmtp >::value_type const &)\n");
  return 0;
}


SWIGINTERN PyObject *_wrap_CodecFmtpVector_push_back(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  std::vector< pj::CodecFmtp > *arg1 = (std::vector< pj::CodecFmtp > *) 0 ;
  std::vector< pj::CodecFmtp >::value_type *arg2 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  void *argp2 = 0 ;
  int res2 = 0 ;
  PyObject *swig_obj[2] ;
  
  if (!SWIG_Python_UnpackTuple(args, "CodecFmtpVector_push_back", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__vectorT_pj__CodecFmtp_std__allocatorT_pj__CodecFmtp_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "CodecFmtpVector_push_back" "', argument " "1"" of type '" "std::vector< pj::CodecFmtp > *""'"); 
  }
  arg1 = reinterpret_cast< std::vector< pj::CodecFmtp > * >(argp1);
  res2 = SWIG_ConvertPtr(swig_obj[1], &argp2, SWIGTYPE_p_pj__CodecFmtp,  0  | 0);
  if (!SWIG_IsOK(res2)) {
    SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "CodecFmtpVector_push_back" "', argument " "2"" of type '" "std::vector< pj::CodecFmtp >::value_type const &""'"); 
  }
  if (!argp2) {
    SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "CodecFmtpVector_push_back" "', argument " "2"" of type '" "std::vector< pj::CodecFmtp >::value_type const &""'"); 
  }
  arg2 = reinterpret_cast< std::vector< pj::CodecFmtp >::value_type * >(argp2);
  (arg1)->push_back((std::vector< pj::CodecFmtp >::value_type const &)*arg2);
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_CodecFmtpVector_front(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  std::vector< pj::CodecFmtp > *arg1 = (std::vector< pj::CodecFmtp > *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  std::vector< pj::CodecFmtp >::value_type *result = 0 ;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__vectorT_pj__CodecFmtp_std__allocatorT_pj__CodecFmtp_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "CodecFmtpVector_front" "', argument " "1"" of type '" "std::vector< pj::CodecFmtp > const *""'"); 
  }
  arg1 = reinterpret_cast< std::vector< pj::CodecFmtp > * >(argp1);
  result = (std::vector< pj::CodecFmtp >::value_type *) &((std::vector< pj::CodecFmtp > const *)arg1)->front();
  resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(result), SWIGTYPE_p_pj__CodecFmtp, 0 |  0 );
  (void)swig::container_owner<swig::traits<std::vector< pj::CodecFmtp >::value_type>::category>::back_reference(resultobj, swig_obj[0]);
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_CodecFmtpVector_back(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  std::vector< pj::CodecFmtp > *arg1 = (std::vector< pj::CodecFmtp > *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  std::vector< pj::CodecFmtp >::value_type *result = 0 ;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__vectorT_pj__CodecFmtp_std__allocatorT_pj__CodecFmtp_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "CodecFmtpVector_back" "', argument " "1"" of type '" "std::vector< pj::CodecFmtp > const *""'"); 
  }
  arg1 = reinterpret_cast< std::vector< pj::CodecFmtp > * >(argp1);
  result = (std::vector< pj::CodecFmtp >::value_type *) &((std::vector< pj::CodecFmtp > const *)arg1)->back();
  resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(result), SWIGTYPE_p_pj__CodecFmtp, 0 |  0 );
  (void)swig::container_owner<swig::traits<std::vector< pj::CodecFmtp >::value_type>::category>::back_reference(resultobj, swig_obj[0]);
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_CodecFmtpVector_assign(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  std::vector< pj::CodecFmtp > *arg1 = (std::vector< pj::CodecFmtp > *) 0 ;
  std::vector< pj::CodecFmtp >::size_type arg2 ;
  std::vector< pj::CodecFmtp >::value_type *arg3 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  size_t val2 ;
  int ecode2 = 0 ;
  void *argp3 = 0 ;
  int res3 = 0 ;
  PyObject *swig_obj[3] ;
  
  if (!SWIG_Python_UnpackTuple(args, "CodecFmtpVector_assign", 3, 3, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__vectorT_pj__CodecFmtp_std__allocatorT_pj__CodecFmtp_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "CodecFmtpVector_assign" "', argument " "1"" of type '" "std::vector< pj::CodecFmtp > *""'"); 
  }
  arg1 = reinterpret_cast< std::vector< pj::CodecFmtp > * >(argp1);
  ecode2 = SWIG_AsVal_size_t(swig_obj[1], &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "CodecFmtpVector_assign" "', argument " "2"" of type '" "std::vector< pj::CodecFmtp >::size_type""'");
  } 
  arg2 = static_cast< std::vector< pj::CodecFmtp >::size_type >(val2);
  res3 = SWIG_ConvertPtr(swig_obj[2], &argp3, SWIGTYPE_p_pj__CodecFmtp,  0  | 0);
  if (!SWIG_IsOK(res3)) {
    SWIG_exception_fail(SWIG_ArgError(res3), "in method '" "CodecFmtpVector_assign" "', argument " "3"" of type '" "std::vector< pj::CodecFmtp >::value_type const &""'"); 
  }
  if (!argp3) {
    SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "CodecFmtpVector_assign" "', argument " "3"" of type '" "std::vector< pj::CodecFmtp >::value_type const &""'"); 
  }
  arg3 = reinterpret_cast< std::vector< pj::CodecFmtp >::value_type * >(argp3);
  (arg1)->assign(arg2,(std::vector< pj::CodecFmtp >::value_type const &)*arg3);
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_CodecFmtpVector_resize__SWIG_1(PyObject *SWIGUNUSEDPARM(self), Py_ssize_t nobjs, PyObject **swig_obj) {
  PyObject *resultobj = 0;
  std::vector< pj::CodecFmtp > *arg1 = (std::vector< pj::CodecFmtp > *) 0 ;
  std::vector< pj::CodecFmtp >::size_type arg2 ;
  std::vector< pj::CodecFmtp >::value_type *arg3 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  size_t val2 ;
  int ecode2 = 0 ;
  void *argp3 = 0 ;
  int res3 = 0 ;
  
  if ((nobjs < 3) || (nobjs > 3)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__vectorT_pj__CodecFmtp_std__allocatorT_pj__CodecFmtp_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "CodecFmtpVector_resize" "', argument " "1"" of type '" "std::vector< pj::CodecFmtp > *""'"); 
  }
  arg1 = reinterpret_cast< std::vector< pj::CodecFmtp > * >(argp1);
  ecode2 = SWIG_AsVal_size_t(swig_obj[1], &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "CodecFmtpVector_resize" "', argument " "2"" of type '" "std::vector< pj::CodecFmtp >::size_type""'");
  } 
  arg2 = static_cast< std::vector< pj::CodecFmtp >::size_type >(val2);
  res3 = SWIG_ConvertPtr(swig_obj[2], &argp3, SWIGTYPE_p_pj__CodecFmtp,  0  | 0);
  if (!SWIG_IsOK(res3)) {
    SWIG_exception_fail(SWIG_ArgError(res3), "in method '" "CodecFmtpVector_resize" "', argument " "3"" of type '" "std::vector< pj::CodecFmtp >::value_type const &""'"); 
  }
  if (!argp3) {
    SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "CodecFmtpVector_resize" "', argument " "3"" of type '" "std::vector< pj::CodecFmtp >::value_type const &""'"); 
  }
  arg3 = reinterpret_cast< std::vector< pj::CodecFmtp >::value_type * >(argp3);
  (arg1)->resize(arg2,(std::vector< pj::CodecFmtp >::value_type const &)*arg3);
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_CodecFmtpVector_resize(PyObject *self, PyObject *args) {
  Py_ssize_t argc;
  PyObject *argv[4] = {
    0
  };
  
  if (!(argc = SWIG_Python_UnpackTuple(args, "CodecFmtpVector_resize", 0, 3, argv))) SWIG_fail;
  --argc;
  if (argc == 2) {
    int _v;
    int res = swig::asptr(argv[0], (std::vector< pj::CodecFmtp,std::allocator< pj::CodecFmtp > >**)(0));
    _v = SWIG_CheckState(res);
    if (_v) {
      {
        int res = SWIG_AsVal_size_t(argv[1], NULL);
        _v = SWIG_CheckState(res);
      }
      if (_v) {
        return _wrap_CodecFmtpVector_resize__SWIG_0(self, argc, argv);
      }
    }
  }
  if (argc == 3) {
    int _v;
    int res = swig::asptr(argv[0], (std::vector< pj::CodecFmtp,std::allocator< pj::CodecFmtp > >**)(0));
    _v = SWIG_CheckState(res);
    if (_v) {
      {
        int res = SWIG_AsVal_size_t(argv[1], NULL);
        _v = SWIG_CheckState(res);
      }
      if (_v) {
        int res = SWIG_ConvertPtr(argv[2], 0, SWIGTYPE_p_pj__CodecFmtp, SWIG_POINTER_NO_NULL | 0);
        _v = SWIG_CheckState(res);
        if (_v) {
          return _wrap_CodecFmtpVector_resize__SWIG_1(self, argc, argv);
        }
      }
    }
  }
  
fail:
  SWIG_Python_RaiseOrModifyTypeError("Wrong number or type of arguments for overloaded function 'CodecFmtpVector_resize'.\n"
    "  Possible C/C++ prototypes are:\n"
    "    std::vector< pj::CodecFmtp >::resize(std::vector< pj::CodecFmtp >::size_type)\n"
    "    std::vector< pj::CodecFmtp >::resize(std::vector< pj::CodecFmtp >::size_type,std::vector< pj::CodecFmtp >::value_type const &)\n");
  return 0;
}


SWIGINTERN PyObject *_wrap_CodecFmtpVector_insert__SWIG_0(PyObject *SWIGUNUSEDPARM(self), Py_ssize_t nobjs, PyObject **swig_obj) {
  PyObject *resultobj = 0;
  std::vector< pj::CodecFmtp > *arg1 = (std::vector< pj::CodecFmtp > *) 0 ;
  std::vector< pj::CodecFmtp >::iterator arg2 ;
  std::vector< pj::CodecFmtp >::value_type *arg3 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  swig::SwigPyIterator *iter2 = 0 ;
  int res2 ;
  void *argp3 = 0 ;
  int res3 = 0 ;
  std::vector< pj::CodecFmtp >::iterator result;
  
  if ((nobjs < 3) || (nobjs > 3)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__vectorT_pj__CodecFmtp_std__allocatorT_pj__CodecFmtp_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "CodecFmtpVector_insert" "', argument " "1"" of type '" "std::vector< pj::CodecFmtp > *""'"); 
  }
  arg1 = reinterpret_cast< std::vector< pj::CodecFmtp > * >(argp1);
  res2 = SWIG_ConvertPtr(swig_obj[1], SWIG_as_voidptrptr(&iter2), swig::SwigPyIterator::descriptor(), 0);
  if (!SWIG_IsOK(res2) || !iter2) {
    SWIG_exception_fail(SWIG_ArgError(SWIG_TypeError), "in method '" "CodecFmtpVector_insert" "', argument " "2"" of type '" "std::vector< pj::CodecFmtp >::iterator""'");
  } else {
    swig::SwigPyIterator_T<std::vector< pj::CodecFmtp >::iterator > *iter_t = dynamic_cast<swig::SwigPyIterator_T<std::vector< pj::CodecFmtp >::iterator > *>(iter2);
    if (iter_t) {
      arg2 = iter_t->get_current();
    } else {
      SWIG_exception_fail(SWIG_ArgError(SWIG_TypeError), "in method '" "CodecFmtpVector_insert" "', argument " "2"" of type '" "std::vector< pj::CodecFmtp >::iterator""'");
    }
  }
  res3 = SWIG_ConvertPtr(swig_obj[2], &argp3, SWIGTYPE_p_pj__CodecFmtp,  0  | 0);
  if (!SWIG_IsOK(res3)) {
    SWIG_exception_fail(SWIG_ArgError(res3), "in method '" "CodecFmtpVector_insert" "', argument " "3"" of type '" "std::vector< pj::CodecFmtp >::value_type const &""'"); 
  }
  if (!argp3) {
    SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "CodecFmtpVector_insert" "', argument " "3"" of type '" "std::vector< pj::CodecFmtp >::value_type const &""'"); 
  }
  arg3 = reinterpret_cast< std::vector< pj::CodecFmtp >::value_type * >(argp3);
  result = std_vector_Sl_pj_CodecFmtp_Sg__insert__SWIG_0(arg1,arg2,(pj::CodecFmtp const &)*arg3);
  resultobj = SWIG_NewPointerObj(swig::make_output_iterator(static_cast< const std::vector< pj::CodecFmtp >::iterator & >(result)),
    swig::SwigPyIterator::descriptor(),SWIG_POINTER_OWN);
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_CodecFmtpVector_insert__SWIG_1(PyObject *SWIGUNUSEDPARM(self), Py_ssize_t nobjs, PyObject **swig_obj) {
  PyObject *resultobj = 0;
  std::vector< pj::CodecFmtp > *arg1 = (std::vector< pj::CodecFmtp > *) 0 ;
  std::vector< pj::CodecFmtp >::iterator arg2 ;
  std::vector< pj::CodecFmtp >::size_type arg3 ;
  std::vector< pj::CodecFmtp >::value_type *arg4 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  swig::SwigPyIterator *iter2 = 0 ;
  int res2 ;
  size_t val3 ;
  int ecode3 = 0 ;
  void *argp4 = 0 ;
  int res4 = 0 ;
  
  if ((nobjs < 4) || (nobjs > 4)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__vectorT_pj__CodecFmtp_std__allocatorT_pj__CodecFmtp_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "CodecFmtpVector_insert" "', argument " "1"" of type '" "std::vector< pj::CodecFmtp > *""'"); 
  }
  arg1 = reinterpret_cast< std::vector< pj::CodecFmtp > * >(argp1);
  res2 = SWIG_ConvertPtr(swig_obj[1], SWIG_as_voidptrptr(&iter2), swig::SwigPyIterator::descriptor(), 0);
  if (!SWIG_IsOK(res2) || !iter2) {
    SWIG_exception_fail(SWIG_ArgError(SWIG_TypeError), "in method '" "CodecFmtpVector_insert" "', argument " "2"" of type '" "std::vector< pj::CodecFmtp >::iterator""'");
  } else {
    swig::SwigPyIterator_T<std::vector< pj::CodecFmtp >::iterator > *iter_t = dynamic_cast<swig::SwigPyIterator_T<std::vector< pj::CodecFmtp >::iterator > *>(iter2);
    if (iter_t) {
      arg2 = iter_t->get_current();
    } else {
      SWIG_exception_fail(SWIG_ArgError(SWIG_TypeError), "in method '" "CodecFmtpVector_insert" "', argument " "2"" of type '" "std::vector< pj::CodecFmtp >::iterator""'");
    }
  }
  ecode3 = SWIG_AsVal_size_t(swig_obj[2], &val3);
  if (!SWIG_IsOK(ecode3)) {
    SWIG_exception_fail(SWIG_ArgError(ecode3), "in method '" "CodecFmtpVector_insert" "', argument " "3"" of type '" "std::vector< pj::CodecFmtp >::size_type""'");
  } 
  arg3 = static_cast< std::vector< pj::CodecFmtp >::size_type >(val3);
  res4 = SWIG_ConvertPtr(swig_obj[3], &argp4, SWIGTYPE_p_pj__CodecFmtp,  0  | 0);
  if (!SWIG_IsOK(res4)) {
    SWIG_exception_fail(SWIG_ArgError(res4), "in method '" "CodecFmtpVector_insert" "', argument " "4"" of type '" "std::vector< pj::CodecFmtp >::value_type const &""'"); 
  }
  if (!argp4) {
    SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "CodecFmtpVector_insert" "', argument " "4"" of type '" "std::vector< pj::CodecFmtp >::value_type const &""'"); 
  }
  arg4 = reinterpret_cast< std::vector< pj::CodecFmtp >::value_type * >(argp4);
  std_vector_Sl_pj_CodecFmtp_Sg__insert__SWIG_1(arg1,arg2,arg3,(pj::CodecFmtp const &)*arg4);
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_CodecFmtpVector_insert(PyObject *self, PyObject *args) {
  Py_ssize_t argc;
  PyObject *argv[5] = {
    0
  };
  
  if (!(argc = SWIG_Python_UnpackTuple(args, "CodecFmtpVector_insert", 0, 4, argv))) SWIG_fail;
  --argc;
  if (argc == 3) {
    int _v;
    int res = swig::asptr(argv[0], (std::vector< pj::CodecFmtp,std::allocator< pj::CodecFmtp > >**)(0));
    _v = SWIG_CheckState(res);
    if (_v) {
      swig::SwigPyIterator *iter = 0;
      int res = SWIG_ConvertPtr(argv[1], SWIG_as_voidptrptr(&iter), swig::SwigPyIterator::descriptor(), 0);
      _v = (SWIG_IsOK(res) && iter && (dynamic_cast<swig::SwigPyIterator_T<std::vector< pj::CodecFmtp >::iterator > *>(iter) != 0));
      if (_v) {
        int res = SWIG_ConvertPtr(argv[2], 0, SWIGTYPE_p_pj__CodecFmtp, SWIG_POINTER_NO_NULL | 0);
        _v = SWIG_CheckState(res);
        if (_v) {
          return _wrap_CodecFmtpVector_insert__SWIG_0(self, argc, argv);
        }
      }
    }
  }
  if (argc == 4) {
    int _v;
    int res = swig::asptr(argv[0], (std::vector< pj::CodecFmtp,std::allocator< pj::CodecFmtp > >**)(0));
    _v = SWIG_CheckState(res);
    if (_v) {
      swig::SwigPyIterator *iter = 0;
      int res = SWIG_ConvertPtr(argv[1], SWIG_as_voidptrptr(&iter), swig::SwigPyIterator::descriptor(), 0);
      _v = (SWIG_IsOK(res) && iter && (dynamic_cast<swig::SwigPyIterator_T<std::vector< pj::CodecFmtp >::iterator > *>(iter) != 0));
      if (_v) {
        {
          int res = SWIG_AsVal_size_t(argv[2], NULL);
          _v = SWIG_CheckState(res);
        }
        if (_v) {
          int res = SWIG_ConvertPtr(argv[3], 0, SWIGTYPE_p_pj__CodecFmtp, SWIG_POINTER_NO_NULL | 0);
          _v = SWIG_CheckState(res);
          if (_v) {
            return _wrap_CodecFmtpVector_insert__SWIG_1(self, argc, argv);
          }
        }
      }
    }
  }
  
fail:
  SWIG_Python_RaiseOrModifyTypeError("Wrong number or type of arguments for overloaded function 'CodecFmtpVector_insert'.\n"
    "  Possible C/C++ prototypes are:\n"
    "    std::vector< pj::CodecFmtp >::insert(std::vector< pj::CodecFmtp >::iterator,std::vector< pj::CodecFmtp >::value_type const &)\n"
    "    std::vector< pj::CodecFmtp >::insert(std::vector< pj::CodecFmtp >::iterator,std::vector< pj::CodecFmtp >::size_type,std::vector< pj::CodecFmtp >::value_type const &)\n");
  return 0;
}


SWIGINTERN PyObject *_wrap_CodecFmtpVector_reserve(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  std::vector< pj::CodecFmtp > *arg1 = (std::vector< pj::CodecFmtp > *) 0 ;
  std::vector< pj::CodecFmtp >::size_type arg2 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  size_t val2 ;
  int ecode2 = 0 ;
  PyObject *swig_obj[2] ;
  
  if (!SWIG_Python_UnpackTuple(args, "CodecFmtpVector_reserve", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__vectorT_pj__CodecFmtp_std__allocatorT_pj__CodecFmtp_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "CodecFmtpVector_reserve" "', argument " "1"" of type '" "std::vector< pj::CodecFmtp > *""'"); 
  }
  arg1 = reinterpret_cast< std::vector< pj::CodecFmtp > * >(argp1);
  ecode2 = SWIG_AsVal_size_t(swig_obj[1], &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "CodecFmtpVector_reserve" "', argument " "2"" of type '" "std::vector< pj::CodecFmtp >::size_type""'");
  } 
  arg2 = static_cast< std::vector< pj::CodecFmtp >::size_type >(val2);
  (arg1)->reserve(arg2);
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_CodecFmtpVector_capacity(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  std::vector< pj::CodecFmtp > *arg1 = (std::vector< pj::CodecFmtp > *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  std::vector< pj::CodecFmtp >::size_type result;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__vectorT_pj__CodecFmtp_std__allocatorT_pj__CodecFmtp_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "CodecFmtpVector_capacity" "', argument " "1"" of type '" "std::vector< pj::CodecFmtp > const *""'"); 
  }
  arg1 = reinterpret_cast< std::vector< pj::CodecFmtp > * >(argp1);
  result = ((std::vector< pj::CodecFmtp > const *)arg1)->capacity();
  resultobj = SWIG_From_size_t(static_cast< size_t >(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_delete_CodecFmtpVector(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  std::vector< pj::CodecFmtp > *arg1 = (std::vector< pj::CodecFmtp > *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__vectorT_pj__CodecFmtp_std__allocatorT_pj__CodecFmtp_t_t, SWIG_POINTER_DISOWN |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "delete_CodecFmtpVector" "', argument " "1"" of type '" "std::vector< pj::CodecFmtp > *""'"); 
  }
  arg1 = reinterpret_cast< std::vector< pj::CodecFmtp > * >(argp1);
  delete arg1;
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *CodecFmtpVector_swigregister(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *obj;
  if (!SWIG_Python_UnpackTuple(args, "swigregister", 1, 1, &obj)) return NULL;
  SWIG_TypeNewClientData(SWIGTYPE_p_std__vectorT_pj__CodecFmtp_std__allocatorT_pj__CodecFmtp_t_t, SWIG_NewClientData(obj));
  return SWIG_Py_Void();
}

SWIGINTERN PyObject *CodecFmtpVector_swiginit(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  return SWIG_Python_InitShadowInstance(args);
}

SWIGINTERN PyObject *_wrap_MediaFormatAudioVector_iterator(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  std::vector< pj::MediaFormatAudio > *arg1 = (std::vector< pj::MediaFormatAudio > *) 0 ;
  PyObject **arg2 = (PyObject **) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  swig::SwigPyIterator *result = 0 ;
  
  arg2 = &swig_obj[0];
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__vectorT_pj__MediaFormatAudio_std__allocatorT_pj__MediaFormatAudio_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "MediaFormatAudioVector_iterator" "', argument " "1"" of type '" "std::vector< pj::MediaFormatAudio > *""'"); 
  }
  arg1 = reinterpret_cast< std::vector< pj::MediaFormatAudio > * >(argp1);
  result = (swig::SwigPyIterator *)std_vector_Sl_pj_MediaFormatAudio_Sg__iterator(arg1,arg2);
  resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(result), SWIGTYPE_p_swig__SwigPyIterator, SWIG_POINTER_OWN |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_MediaFormatAudioVector___nonzero__(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  std::vector< pj::MediaFormatAudio > *arg1 = (std::vector< pj::MediaFormatAudio > *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  bool result;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__vectorT_pj__MediaFormatAudio_std__allocatorT_pj__MediaFormatAudio_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "MediaFormatAudioVector___nonzero__" "', argument " "1"" of type '" "std::vector< pj::MediaFormatAudio > const *""'"); 
  }
  arg1 = reinterpret_cast< std::vector< pj::MediaFormatAudio > * >(argp1);
  result = (bool)std_vector_Sl_pj_MediaFormatAudio_Sg____nonzero__((std::vector< pj::MediaFormatAudio > const *)arg1);
  resultobj = SWIG_From_bool(static_cast< bool >(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_MediaFormatAudioVector___bool__(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  std::vector< pj::MediaFormatAudio > *arg1 = (std::vector< pj::MediaFormatAudio > *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  bool result;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__vectorT_pj__MediaFormatAudio_std__allocatorT_pj__MediaFormatAudio_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "MediaFormatAudioVector___bool__" "', argument " "1"" of type '" "std::vector< pj::MediaFormatAudio > const *""'"); 
  }
  arg1 = reinterpret_cast< std::vector< pj::MediaFormatAudio > * >(argp1);
  result = (bool)std_vector_Sl_pj_MediaFormatAudio_Sg____bool__((std::vector< pj::MediaFormatAudio > const *)arg1);
  resultobj = SWIG_From_bool(static_cast< bool >(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_MediaFormatAudioVector___len__(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  std::vector< pj::MediaFormatAudio > *arg1 = (std::vector< pj::MediaFormatAudio > *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  std::vector< pj::MediaFormatAudio >::size_type result;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__vectorT_pj__MediaFormatAudio_std__allocatorT_pj__MediaFormatAudio_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "MediaFormatAudioVector___len__" "', argument " "1"" of type '" "std::vector< pj::MediaFormatAudio > const *""'"); 
  }
  arg1 = reinterpret_cast< std::vector< pj::MediaFormatAudio > * >(argp1);
  result = std_vector_Sl_pj_MediaFormatAudio_Sg____len__((std::vector< pj::MediaFormatAudio > const *)arg1);
  resultobj = SWIG_From_size_t(static_cast< size_t >(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_MediaFormatAudioVector___getslice__(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  std::vector< pj::MediaFormatAudio > *arg1 = (std::vector< pj::MediaFormatAudio > *) 0 ;
  std::vector< pj::MediaFormatAudio >::difference_type arg2 ;
  std::vector< pj::MediaFormatAudio >::difference_type arg3 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  ptrdiff_t val2 ;
  int ecode2 = 0 ;
  ptrdiff_t val3 ;
  int ecode3 = 0 ;
  PyObject *swig_obj[3] ;
  std::vector< pj::MediaFormatAudio,std::allocator< pj::MediaFormatAudio > > *result = 0 ;
  
  if (!SWIG_Python_UnpackTuple(args, "MediaFormatAudioVector___getslice__", 3, 3, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__vectorT_pj__MediaFormatAudio_std__allocatorT_pj__MediaFormatAudio_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "MediaFormatAudioVector___getslice__" "', argument " "1"" of type '" "std::vector< pj::MediaFormatAudio > *""'"); 
  }
  arg1 = reinterpret_cast< std::vector< pj::MediaFormatAudio > * >(argp1);
  ecode2 = SWIG_AsVal_ptrdiff_t(swig_obj[1], &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "MediaFormatAudioVector___getslice__" "', argument " "2"" of type '" "std::vector< pj::MediaFormatAudio >::difference_type""'");
  } 
  arg2 = static_cast< std::vector< pj::MediaFormatAudio >::difference_type >(val2);
  ecode3 = SWIG_AsVal_ptrdiff_t(swig_obj[2], &val3);
  if (!SWIG_IsOK(ecode3)) {
    SWIG_exception_fail(SWIG_ArgError(ecode3), "in method '" "MediaFormatAudioVector___getslice__" "', argument " "3"" of type '" "std::vector< pj::MediaFormatAudio >::difference_type""'");
  } 
  arg3 = static_cast< std::vector< pj::MediaFormatAudio >::difference_type >(val3);
  try {
    result = (std::vector< pj::MediaFormatAudio,std::allocator< pj::MediaFormatAudio > > *)std_vector_Sl_pj_MediaFormatAudio_Sg____getslice__(arg1,arg2,arg3);
  } catch(std::out_of_range &_e) {
    SWIG_exception_fail(SWIG_IndexError, (&_e)->what());
  } catch(std::invalid_argument &_e) {
    SWIG_exception_fail(SWIG_ValueError, (&_e)->what());
  }
  resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(result), SWIGTYPE_p_std__vectorT_pj__MediaFormatAudio_std__allocatorT_pj__MediaFormatAudio_t_t, SWIG_POINTER_OWN |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_MediaFormatAudioVector___setslice____SWIG_0(PyObject *SWIGUNUSEDPARM(self), Py_ssize_t nobjs, PyObject **swig_obj) {
  PyObject *resultobj = 0;
  std::vector< pj::MediaFormatAudio > *arg1 = (std::vector< pj::MediaFormatAudio > *) 0 ;
  std::vector< pj::MediaFormatAudio >::difference_type arg2 ;
  std::vector< pj::MediaFormatAudio >::difference_type arg3 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  ptrdiff_t val2 ;
  int ecode2 = 0 ;
  ptrdiff_t val3 ;
  int ecode3 = 0 ;
  
  if ((nobjs < 3) || (nobjs > 3)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__vectorT_pj__MediaFormatAudio_std__allocatorT_pj__MediaFormatAudio_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "MediaFormatAudioVector___setslice__" "', argument " "1"" of type '" "std::vector< pj::MediaFormatAudio > *""'"); 
  }
  arg1 = reinterpret_cast< std::vector< pj::MediaFormatAudio > * >(argp1);
  ecode2 = SWIG_AsVal_ptrdiff_t(swig_obj[1], &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "MediaFormatAudioVector___setslice__" "', argument " "2"" of type '" "std::vector< pj::MediaFormatAudio >::difference_type""'");
  } 
  arg2 = static_cast< std::vector< pj::MediaFormatAudio >::difference_type >(val2);
  ecode3 = SWIG_AsVal_ptrdiff_t(swig_obj[2], &val3);
  if (!SWIG_IsOK(ecode3)) {
    SWIG_exception_fail(SWIG_ArgError(ecode3), "in method '" "MediaFormatAudioVector___setslice__" "', argument " "3"" of type '" "std::vector< pj::MediaFormatAudio >::difference_type""'");
  } 
  arg3 = static_cast< std::vector< pj::MediaFormatAudio >::difference_type >(val3);
  try {
    std_vector_Sl_pj_MediaFormatAudio_Sg____setslice____SWIG_0(arg1,arg2,arg3);
  } catch(std::out_of_range &_e) {
    SWIG_exception_fail(SWIG_IndexError, (&_e)->what());
  } catch(std::invalid_argument &_e) {
    SWIG_exception_fail(SWIG_ValueError, (&_e)->what());
  }
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_MediaFormatAudioVector___setslice____SWIG_1(PyObject *SWIGUNUSEDPARM(self), Py_ssize_t nobjs, PyObject **swig_obj) {
  PyObject *resultobj = 0;
  std::vector< pj::MediaFormatAudio > *arg1 = (std::vector< pj::MediaFormatAudio > *) 0 ;
  std::vector< pj::MediaFormatAudio >::difference_type arg2 ;
  std::vector< pj::MediaFormatAudio >::difference_type arg3 ;
  std::vector< pj::MediaFormatAudio,std::allocator< pj::MediaFormatAudio > > *arg4 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  ptrdiff_t val2 ;
  int ecode2 = 0 ;
  ptrdiff_t val3 ;
  int ecode3 = 0 ;
  int res4 = SWIG_OLDOBJ ;
  
  if ((nobjs < 4) || (nobjs > 4)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__vectorT_pj__MediaFormatAudio_std__allocatorT_pj__MediaFormatAudio_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "MediaFormatAudioVector___setslice__" "', argument " "1"" of type '" "std::vector< pj::MediaFormatAudio > *""'"); 
  }
  arg1 = reinterpret_cast< std::vector< pj::MediaFormatAudio > * >(argp1);
  ecode2 = SWIG_AsVal_ptrdiff_t(swig_obj[1], &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "MediaFormatAudioVector___setslice__" "', argument " "2"" of type '" "std::vector< pj::MediaFormatAudio >::difference_type""'");
  } 
  arg2 = static_cast< std::vector< pj::MediaFormatAudio >::difference_type >(val2);
  ecode3 = SWIG_AsVal_ptrdiff_t(swig_obj[2], &val3);
  if (!SWIG_IsOK(ecode3)) {
    SWIG_exception_fail(SWIG_ArgError(ecode3), "in method '" "MediaFormatAudioVector___setslice__" "', argument " "3"" of type '" "std::vector< pj::MediaFormatAudio >::difference_type""'");
  } 
  arg3 = static_cast< std::vector< pj::MediaFormatAudio >::difference_type >(val3);
  {
    std::vector< pj::MediaFormatAudio,std::allocator< pj::MediaFormatAudio > > *ptr = (std::vector< pj::MediaFormatAudio,std::allocator< pj::MediaFormatAudio > > *)0;
    res4 = swig::asptr(swig_obj[3], &ptr);
    if (!SWIG_IsOK(res4)) {
      SWIG_exception_fail(SWIG_ArgError(res4), "in method '" "MediaFormatAudioVector___setslice__" "', argument " "4"" of type '" "std::vector< pj::MediaFormatAudio,std::allocator< pj::MediaFormatAudio > > const &""'"); 
    }
    if (!ptr) {
      SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "MediaFormatAudioVector___setslice__" "', argument " "4"" of type '" "std::vector< pj::MediaFormatAudio,std::allocator< pj::MediaFormatAudio > > const &""'"); 
    }
    arg4 = ptr;
  }
  try {
    std_vector_Sl_pj_MediaFormatAudio_Sg____setslice____SWIG_1(arg1,arg2,arg3,(std::vector< pj::MediaFormatAudio,std::allocator< pj::MediaFormatAudio > > const &)*arg4);
  } catch(std::out_of_range &_e) {
    SWIG_exception_fail(SWIG_IndexError, (&_e)->what());
  } catch(std::invalid_argument &_e) {
    SWIG_exception_fail(SWIG_ValueError, (&_e)->what());
  }
  resultobj = SWIG_Py_Void();
  if (SWIG_IsNewObj(res4)) delete arg4;
  return resultobj;
fail:
  if (SWIG_IsNewObj(res4)) delete arg4;
  return NULL;
}


SWIGINTERN PyObject *_wrap_MediaFormatAudioVector___setslice__(PyObject *self, PyObject *args) {
  Py_ssize_t argc;
  PyObject *argv[5] = {
    0
  };
  
  if (!(argc = SWIG_Python_UnpackTuple(args, "MediaFormatAudioVector___setslice__", 0, 4, argv))) SWIG_fail;
  --argc;
  if (argc == 3) {
    int _v;
    int res = swig::asptr(argv[0], (std::vector< pj::MediaFormatAudio,std::allocator< pj::MediaFormatAudio > >**)(0));
    _v = SWIG_CheckState(res);
    if (_v) {
      {
        int res = SWIG_AsVal_ptrdiff_t(argv[1], NULL);
        _v = SWIG_CheckState(res);
      }
      if (_v) {
        {
          int res = SWIG_AsVal_ptrdiff_t(argv[2], NULL);
          _v = SWIG_CheckState(res);
        }
        if (_v) {
          return _wrap_MediaFormatAudioVector___setslice____SWIG_0(self, argc, argv);
        }
      }
    }
  }
  if (argc == 4) {
    int _v;
    int res = swig::asptr(argv[0], (std::vector< pj::MediaFormatAudio,std::allocator< pj::MediaFormatAudio > >**)(0));
    _v = SWIG_CheckState(res);
    if (_v) {
      {
        int res = SWIG_AsVal_ptrdiff_t(argv[1], NULL);
        _v = SWIG_CheckState(res);
      }
      if (_v) {
        {
          int res = SWIG_AsVal_ptrdiff_t(argv[2], NULL);
          _v = SWIG_CheckState(res);
        }
        if (_v) {
          int res = swig::asptr(argv[3], (std::vector< pj::MediaFormatAudio,std::allocator< pj::MediaFormatAudio > >**)(0));
          _v = SWIG_CheckState(res);
          if (_v) {
            return _wrap_MediaFormatAudioVector___setslice____SWIG_1(self, argc, argv);
          }
        }
      }
    }
  }
  
fail:
  SWIG_Python_RaiseOrModifyTypeError("Wrong number or type of arguments for overloaded function 'MediaFormatAudioVector___setslice__'.\n"
    "  Possible C/C++ prototypes are:\n"
    "    std::vector< pj::MediaFormatAudio >::__setslice__(std::vector< pj::MediaFormatAudio >::difference_type,std::vector< pj::MediaFormatAudio >::difference_type)\n"
    "    std::vector< pj::MediaFormatAudio >::__setslice__(std::vector< pj::MediaFormatAudio >::difference_type,std::vector< pj::MediaFormatAudio >::difference_type,std::vector< pj::MediaFormatAudio,std::allocator< pj::MediaFormatAudio > > const &)\n");
  return 0;
}


SWIGINTERN PyObject *_wrap_MediaFormatAudioVector___delslice__(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  std::vector< pj::MediaFormatAudio > *arg1 = (std::vector< pj::MediaFormatAudio > *) 0 ;
  std::vector< pj::MediaFormatAudio >::difference_type arg2 ;
  std::vector< pj::MediaFormatAudio >::difference_type arg3 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  ptrdiff_t val2 ;
  int ecode2 = 0 ;
  ptrdiff_t val3 ;
  int ecode3 = 0 ;
  PyObject *swig_obj[3] ;
  
  if (!SWIG_Python_UnpackTuple(args, "MediaFormatAudioVector___delslice__", 3, 3, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__vectorT_pj__MediaFormatAudio_std__allocatorT_pj__MediaFormatAudio_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "MediaFormatAudioVector___delslice__" "', argument " "1"" of type '" "std::vector< pj::MediaFormatAudio > *""'"); 
  }
  arg1 = reinterpret_cast< std::vector< pj::MediaFormatAudio > * >(argp1);
  ecode2 = SWIG_AsVal_ptrdiff_t(swig_obj[1], &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "MediaFormatAudioVector___delslice__" "', argument " "2"" of type '" "std::vector< pj::MediaFormatAudio >::difference_type""'");
  } 
  arg2 = static_cast< std::vector< pj::MediaFormatAudio >::difference_type >(val2);
  ecode3 = SWIG_AsVal_ptrdiff_t(swig_obj[2], &val3);
  if (!SWIG_IsOK(ecode3)) {
    SWIG_exception_fail(SWIG_ArgError(ecode3), "in method '" "MediaFormatAudioVector___delslice__" "', argument " "3"" of type '" "std::vector< pj::MediaFormatAudio >::difference_type""'");
  } 
  arg3 = static_cast< std::vector< pj::MediaFormatAudio >::difference_type >(val3);
  try {
    std_vector_Sl_pj_MediaFormatAudio_Sg____delslice__(arg1,arg2,arg3);
  } catch(std::out_of_range &_e) {
    SWIG_exception_fail(SWIG_IndexError, (&_e)->what());
  } catch(std::invalid_argument &_e) {
    SWIG_exception_fail(SWIG_ValueError, (&_e)->what());
  }
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_MediaFormatAudioVector___delitem____SWIG_0(PyObject *SWIGUNUSEDPARM(self), Py_ssize_t nobjs, PyObject **swig_obj) {
  PyObject *resultobj = 0;
  std::vector< pj::MediaFormatAudio > *arg1 = (std::vector< pj::MediaFormatAudio > *) 0 ;
  std::vector< pj::MediaFormatAudio >::difference_type arg2 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  ptrdiff_t val2 ;
  int ecode2 = 0 ;
  
  if ((nobjs < 2) || (nobjs > 2)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__vectorT_pj__MediaFormatAudio_std__allocatorT_pj__MediaFormatAudio_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "MediaFormatAudioVector___delitem__" "', argument " "1"" of type '" "std::vector< pj::MediaFormatAudio > *""'"); 
  }
  arg1 = reinterpret_cast< std::vector< pj::MediaFormatAudio > * >(argp1);
  ecode2 = SWIG_AsVal_ptrdiff_t(swig_obj[1], &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "MediaFormatAudioVector___delitem__" "', argument " "2"" of type '" "std::vector< pj::MediaFormatAudio >::difference_type""'");
  } 
  arg2 = static_cast< std::vector< pj::MediaFormatAudio >::difference_type >(val2);
  try {
    std_vector_Sl_pj_MediaFormatAudio_Sg____delitem____SWIG_0(arg1,arg2);
  } catch(std::out_of_range &_e) {
    SWIG_exception_fail(SWIG_IndexError, (&_e)->what());
  } catch(std::invalid_argument &_e) {
    SWIG_exception_fail(SWIG_ValueError, (&_e)->what());
  }
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_MediaFormatAudioVector___getitem____SWIG_0(PyObject *SWIGUNUSEDPARM(self), Py_ssize_t nobjs, PyObject **swig_obj) {
  PyObject *resultobj = 0;
  std::vector< pj::MediaFormatAudio > *arg1 = (std::vector< pj::MediaFormatAudio > *) 0 ;
  PySliceObject *arg2 = (PySliceObject *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  std::vector< pj::MediaFormatAudio,std::allocator< pj::MediaFormatAudio > > *result = 0 ;
  
  if ((nobjs < 2) || (nobjs > 2)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__vectorT_pj__MediaFormatAudio_std__allocatorT_pj__MediaFormatAudio_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "MediaFormatAudioVector___getitem__" "', argument " "1"" of type '" "std::vector< pj::MediaFormatAudio > *""'"); 
  }
  arg1 = reinterpret_cast< std::vector< pj::MediaFormatAudio > * >(argp1);
  {
    if (!PySlice_Check(swig_obj[1])) {
      SWIG_exception_fail(SWIG_ArgError(SWIG_TypeError), "in method '" "MediaFormatAudioVector___getitem__" "', argument " "2"" of type '" "PySliceObject *""'");
    }
    arg2 = (PySliceObject *) swig_obj[1];
  }
  try {
    result = (std::vector< pj::MediaFormatAudio,std::allocator< pj::MediaFormatAudio > > *)std_vector_Sl_pj_MediaFormatAudio_Sg____getitem____SWIG_0(arg1,arg2);
  } catch(std::out_of_range &_e) {
    SWIG_exception_fail(SWIG_IndexError, (&_e)->what());
  } catch(std::invalid_argument &_e) {
    SWIG_exception_fail(SWIG_ValueError, (&_e)->what());
  }
  resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(result), SWIGTYPE_p_std__vectorT_pj__MediaFormatAudio_std__allocatorT_pj__MediaFormatAudio_t_t, SWIG_POINTER_OWN |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_MediaFormatAudioVector___setitem____SWIG_0(PyObject *SWIGUNUSEDPARM(self), Py_ssize_t nobjs, PyObject **swig_obj) {
  PyObject *resultobj = 0;
  std::vector< pj::MediaFormatAudio > *arg1 = (std::vector< pj::MediaFormatAudio > *) 0 ;
  PySliceObject *arg2 = (PySliceObject *) 0 ;
  std::vector< pj::MediaFormatAudio,std::allocator< pj::MediaFormatAudio > > *arg3 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  int res3 = SWIG_OLDOBJ ;
  
  if ((nobjs < 3) || (nobjs > 3)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__vectorT_pj__MediaFormatAudio_std__allocatorT_pj__MediaFormatAudio_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "MediaFormatAudioVector___setitem__" "', argument " "1"" of type '" "std::vector< pj::MediaFormatAudio > *""'"); 
  }
  arg1 = reinterpret_cast< std::vector< pj::MediaFormatAudio > * >(argp1);
  {
    if (!PySlice_Check(swig_obj[1])) {
      SWIG_exception_fail(SWIG_ArgError(SWIG_TypeError), "in method '" "MediaFormatAudioVector___setitem__" "', argument " "2"" of type '" "PySliceObject *""'");
    }
    arg2 = (PySliceObject *) swig_obj[1];
  }
  {
    std::vector< pj::MediaFormatAudio,std::allocator< pj::MediaFormatAudio > > *ptr = (std::vector< pj::MediaFormatAudio,std::allocator< pj::MediaFormatAudio > > *)0;
    res3 = swig::asptr(swig_obj[2], &ptr);
    if (!SWIG_IsOK(res3)) {
      SWIG_exception_fail(SWIG_ArgError(res3), "in method '" "MediaFormatAudioVector___setitem__" "', argument " "3"" of type '" "std::vector< pj::MediaFormatAudio,std::allocator< pj::MediaFormatAudio > > const &""'"); 
    }
    if (!ptr) {
      SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "MediaFormatAudioVector___setitem__" "', argument " "3"" of type '" "std::vector< pj::MediaFormatAudio,std::allocator< pj::MediaFormatAudio > > const &""'"); 
    }
    arg3 = ptr;
  }
  try {
    std_vector_Sl_pj_MediaFormatAudio_Sg____setitem____SWIG_0(arg1,arg2,(std::vector< pj::MediaFormatAudio,std::allocator< pj::MediaFormatAudio > > const &)*arg3);
  } catch(std::out_of_range &_e) {
    SWIG_exception_fail(SWIG_IndexError, (&_e)->what());
  } catch(std::invalid_argument &_e) {
    SWIG_exception_fail(SWIG_ValueError, (&_e)->what());
  }
  resultobj = SWIG_Py_Void();
  if (SWIG_IsNewObj(res3)) delete arg3;
  return resultobj;
fail:
  if (SWIG_IsNewObj(res3)) delete arg3;
  return NULL;
}


SWIGINTERN PyObject *_wrap_MediaFormatAudioVector___setitem____SWIG_1(PyObject *SWIGUNUSEDPARM(self), Py_ssize_t nobjs, PyObject **swig_obj) {
  PyObject *resultobj = 0;
  std::vector< pj::MediaFormatAudio > *arg1 = (std::vector< pj::MediaFormatAudio > *) 0 ;
  PySliceObject *arg2 = (PySliceObject *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  
  if ((nobjs < 2) || (nobjs > 2)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__vectorT_pj__MediaFormatAudio_std__allocatorT_pj__MediaFormatAudio_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "MediaFormatAudioVector___setitem__" "', argument " "1"" of type '" "std::vector< pj::MediaFormatAudio > *""'"); 
  }
  arg1 = reinterpret_cast< std::vector< pj::MediaFormatAudio > * >(argp1);
  {
    if (!PySlice_Check(swig_obj[1])) {
      SWIG_exception_fail(SWIG_ArgError(SWIG_TypeError), "in method '" "MediaFormatAudioVector___setitem__" "', argument " "2"" of type '" "PySliceObject *""'");
    }
    arg2 = (PySliceObject *) swig_obj[1];
  }
  try {
    std_vector_Sl_pj_MediaFormatAudio_Sg____setitem____SWIG_1(arg1,arg2);
  } catch(std::out_of_range &_e) {
    SWIG_exception_fail(SWIG_IndexError, (&_e)->what());
  } catch(std::invalid_argument &_e) {
    SWIG_exception_fail(SWIG_ValueError, (&_e)->what());
  }
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_MediaFormatAudioVector___delitem____SWIG_1(PyObject *SWIGUNUSEDPARM(self), Py_ssize_t nobjs, PyObject **swig_obj) {
  PyObject *resultobj = 0;
  std::vector< pj::MediaFormatAudio > *arg1 = (std::vector< pj::MediaFormatAudio > *) 0 ;
  PySliceObject *arg2 = (PySliceObject *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  
  if ((nobjs < 2) || (nobjs > 2)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__vectorT_pj__MediaFormatAudio_std__allocatorT_pj__MediaFormatAudio_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "MediaFormatAudioVector___delitem__" "', argument " "1"" of type '" "std::vector< pj::MediaFormatAudio > *""'"); 
  }
  arg1 = reinterpret_cast< std::vector< pj::MediaFormatAudio > * >(argp1);
  {
    if (!PySlice_Check(swig_obj[1])) {
      SWIG_exception_fail(SWIG_ArgError(SWIG_TypeError), "in method '" "MediaFormatAudioVector___delitem__" "', argument " "2"" of type '" "PySliceObject *""'");
    }
    arg2 = (PySliceObject *) swig_obj[1];
  }
  try {
    std_vector_Sl_pj_MediaFormatAudio_Sg____delitem____SWIG_1(arg1,arg2);
  } catch(std::out_of_range &_e) {
    SWIG_exception_fail(SWIG_IndexError, (&_e)->what());
  } catch(std::invalid_argument &_e) {
    SWIG_exception_fail(SWIG_ValueError, (&_e)->what());
  }
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_MediaFormatAudioVector___delitem__(PyObject *self, PyObject *args) {
  Py_ssize_t argc;
  PyObject *argv[3] = {
    0
  };
  
  if (!(argc = SWIG_Python_UnpackTuple(args, "MediaFormatAudioVector___delitem__", 0, 2, argv))) SWIG_fail;
  --argc;
  if (argc == 2) {
    int _v;
    int res = swig::asptr(argv[0], (std::vector< pj::MediaFormatAudio,std::allocator< pj::MediaFormatAudio > >**)(0));
    _v = SWIG_CheckState(res);
    if (_v) {
      {
        _v = PySlice_Check(argv[1]);
      }
      if (_v) {
        return _wrap_MediaFormatAudioVector___delitem____SWIG_1(self, argc, argv);
      }
    }
  }
  if (argc == 2) {
    int _v;
    int res = swig::asptr(argv[0], (std::vector< pj::MediaFormatAudio,std::allocator< pj::MediaFormatAudio > >**)(0));
    _v = SWIG_CheckState(res);
    if (_v) {
      {
        int res = SWIG_AsVal_ptrdiff_t(argv[1], NULL);
        _v = SWIG_CheckState(res);
      }
      if (_v) {
        return _wrap_MediaFormatAudioVector___delitem____SWIG_0(self, argc, argv);
      }
    }
  }
  
fail:
  SWIG_Python_RaiseOrModifyTypeError("Wrong number or type of arguments for overloaded function 'MediaFormatAudioVector___delitem__'.\n"
    "  Possible C/C++ prototypes are:\n"
    "    std::vector< pj::MediaFormatAudio >::__delitem__(std::vector< pj::MediaFormatAudio >::difference_type)\n"
    "    std::vector< pj::MediaFormatAudio >::__delitem__(PySliceObject *)\n");
  return 0;
}


SWIGINTERN PyObject *_wrap_MediaFormatAudioVector___getitem____SWIG_1(PyObject *SWIGUNUSEDPARM(self), Py_ssize_t nobjs, PyObject **swig_obj) {
  PyObject *resultobj = 0;
  std::vector< pj::MediaFormatAudio > *arg1 = (std::vector< pj::MediaFormatAudio > *) 0 ;
  std::vector< pj::MediaFormatAudio >::difference_type arg2 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  ptrdiff_t val2 ;
  int ecode2 = 0 ;
  std::vector< pj::MediaFormatAudio >::value_type *result = 0 ;
  
  if ((nobjs < 2) || (nobjs > 2)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__vectorT_pj__MediaFormatAudio_std__allocatorT_pj__MediaFormatAudio_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "MediaFormatAudioVector___getitem__" "', argument " "1"" of type '" "std::vector< pj::MediaFormatAudio > const *""'"); 
  }
  arg1 = reinterpret_cast< std::vector< pj::MediaFormatAudio > * >(argp1);
  ecode2 = SWIG_AsVal_ptrdiff_t(swig_obj[1], &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "MediaFormatAudioVector___getitem__" "', argument " "2"" of type '" "std::vector< pj::MediaFormatAudio >::difference_type""'");
  } 
  arg2 = static_cast< std::vector< pj::MediaFormatAudio >::difference_type >(val2);
  try {
    result = (std::vector< pj::MediaFormatAudio >::value_type *) &std_vector_Sl_pj_MediaFormatAudio_Sg____getitem____SWIG_1((std::vector< pj::MediaFormatAudio > const *)arg1,arg2);
  } catch(std::out_of_range &_e) {
    SWIG_exception_fail(SWIG_IndexError, (&_e)->what());
  }
  resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(result), SWIGTYPE_p_pj__MediaFormatAudio, 0 |  0 );
  (void)swig::container_owner<swig::traits<std::vector< pj::MediaFormatAudio >::value_type>::category>::back_reference(resultobj, swig_obj[0]);
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_MediaFormatAudioVector___getitem__(PyObject *self, PyObject *args) {
  Py_ssize_t argc;
  PyObject *argv[3] = {
    0
  };
  
  if (!(argc = SWIG_Python_UnpackTuple(args, "MediaFormatAudioVector___getitem__", 0, 2, argv))) SWIG_fail;
  --argc;
  if (argc == 2) {
    int _v;
    int res = swig::asptr(argv[0], (std::vector< pj::MediaFormatAudio,std::allocator< pj::MediaFormatAudio > >**)(0));
    _v = SWIG_CheckState(res);
    if (_v) {
      {
        _v = PySlice_Check(argv[1]);
      }
      if (_v) {
        return _wrap_MediaFormatAudioVector___getitem____SWIG_0(self, argc, argv);
      }
    }
  }
  if (argc == 2) {
    int _v;
    int res = swig::asptr(argv[0], (std::vector< pj::MediaFormatAudio,std::allocator< pj::MediaFormatAudio > >**)(0));
    _v = SWIG_CheckState(res);
    if (_v) {
      {
        int res = SWIG_AsVal_ptrdiff_t(argv[1], NULL);
        _v = SWIG_CheckState(res);
      }
      if (_v) {
        return _wrap_MediaFormatAudioVector___getitem____SWIG_1(self, argc, argv);
      }
    }
  }
  
fail:
  SWIG_Python_RaiseOrModifyTypeError("Wrong number or type of arguments for overloaded function 'MediaFormatAudioVector___getitem__'.\n"
    "  Possible C/C++ prototypes are:\n"
    "    std::vector< pj::MediaFormatAudio >::__getitem__(PySliceObject *)\n"
    "    std::vector< pj::MediaFormatAudio >::__getitem__(std::vector< pj::MediaFormatAudio >::difference_type) const\n");
  return 0;
}


SWIGINTERN PyObject *_wrap_MediaFormatAudioVector___setitem____SWIG_2(PyObject *SWIGUNUSEDPARM(self), Py_ssize_t nobjs, PyObject **swig_obj) {
  PyObject *resultobj = 0;
  std::vector< pj::MediaFormatAudio > *arg1 = (std::vector< pj::MediaFormatAudio > *) 0 ;
  std::vector< pj::MediaFormatAudio >::difference_type arg2 ;
  std::vector< pj::MediaFormatAudio >::value_type *arg3 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  ptrdiff_t val2 ;
  int ecode2 = 0 ;
  void *argp3 = 0 ;
  int res3 = 0 ;
  
  if ((nobjs < 3) || (nobjs > 3)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__vectorT_pj__MediaFormatAudio_std__allocatorT_pj__MediaFormatAudio_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "MediaFormatAudioVector___setitem__" "', argument " "1"" of type '" "std::vector< pj::MediaFormatAudio > *""'"); 
  }
  arg1 = reinterpret_cast< std::vector< pj::MediaFormatAudio > * >(argp1);
  ecode2 = SWIG_AsVal_ptrdiff_t(swig_obj[1], &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "MediaFormatAudioVector___setitem__" "', argument " "2"" of type '" "std::vector< pj::MediaFormatAudio >::difference_type""'");
  } 
  arg2 = static_cast< std::vector< pj::MediaFormatAudio >::difference_type >(val2);
  res3 = SWIG_ConvertPtr(swig_obj[2], &argp3, SWIGTYPE_p_pj__MediaFormatAudio,  0  | 0);
  if (!SWIG_IsOK(res3)) {
    SWIG_exception_fail(SWIG_ArgError(res3), "in method '" "MediaFormatAudioVector___setitem__" "', argument " "3"" of type '" "std::vector< pj::MediaFormatAudio >::value_type const &""'"); 
  }
  if (!argp3) {
    SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "MediaFormatAudioVector___setitem__" "', argument " "3"" of type '" "std::vector< pj::MediaFormatAudio >::value_type const &""'"); 
  }
  arg3 = reinterpret_cast< std::vector< pj::MediaFormatAudio >::value_type * >(argp3);
  try {
    std_vector_Sl_pj_MediaFormatAudio_Sg____setitem____SWIG_2(arg1,arg2,(pj::MediaFormatAudio const &)*arg3);
  } catch(std::out_of_range &_e) {
    SWIG_exception_fail(SWIG_IndexError, (&_e)->what());
  }
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_MediaFormatAudioVector___setitem__(PyObject *self, PyObject *args) {
  Py_ssize_t argc;
  PyObject *argv[4] = {
    0
  };
  
  if (!(argc = SWIG_Python_UnpackTuple(args, "MediaFormatAudioVector___setitem__", 0, 3, argv))) SWIG_fail;
  --argc;
  if (argc == 2) {
    int _v;
    int res = swig::asptr(argv[0], (std::vector< pj::MediaFormatAudio,std::allocator< pj::MediaFormatAudio > >**)(0));
    _v = SWIG_CheckState(res);
    if (_v) {
      {
        _v = PySlice_Check(argv[1]);
      }
      if (_v) {
        return _wrap_MediaFormatAudioVector___setitem____SWIG_1(self, argc, argv);
      }
    }
  }
  if (argc == 3) {
    int _v;
    int res = swig::asptr(argv[0], (std::vector< pj::MediaFormatAudio,std::allocator< pj::MediaFormatAudio > >**)(0));
    _v = SWIG_CheckState(res);
    if (_v) {
      {
        _v = PySlice_Check(argv[1]);
      }
      if (_v) {
        int res = swig::asptr(argv[2], (std::vector< pj::MediaFormatAudio,std::allocator< pj::MediaFormatAudio > >**)(0));
        _v = SWIG_CheckState(res);
        if (_v) {
          return _wrap_MediaFormatAudioVector___setitem____SWIG_0(self, argc, argv);
        }
      }
    }
  }
  if (argc == 3) {
    int _v;
    int res = swig::asptr(argv[0], (std::vector< pj::MediaFormatAudio,std::allocator< pj::MediaFormatAudio > >**)(0));
    _v = SWIG_CheckState(res);
    if (_v) {
      {
        int res = SWIG_AsVal_ptrdiff_t(argv[1], NULL);
        _v = SWIG_CheckState(res);
      }
      if (_v) {
        int res = SWIG_ConvertPtr(argv[2], 0, SWIGTYPE_p_pj__MediaFormatAudio, SWIG_POINTER_NO_NULL | 0);
        _v = SWIG_CheckState(res);
        if (_v) {
          return _wrap_MediaFormatAudioVector___setitem____SWIG_2(self, argc, argv);
        }
      }
    }
  }
  
fail:
  SWIG_Python_RaiseOrModifyTypeError("Wrong number or type of arguments for overloaded function 'MediaFormatAudioVector___setitem__'.\n"
    "  Possible C/C++ prototypes are:\n"
    "    std::vector< pj::MediaFormatAudio >::__setitem__(PySliceObject *,std::vector< pj::MediaFormatAudio,std::allocator< pj::MediaFormatAudio > > const &)\n"
    "    std::vector< pj::MediaFormatAudio >::__setitem__(PySliceObject *)\n"
    "    std::vector< pj::MediaFormatAudio >::__setitem__(std::vector< pj::MediaFormatAudio >::difference_type,std::vector< pj::MediaFormatAudio >::value_type const &)\n");
  return 0;
}


SWIGINTERN PyObject *_wrap_MediaFormatAudioVector_pop(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  std::vector< pj::MediaFormatAudio > *arg1 = (std::vector< pj::MediaFormatAudio > *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  std::vector< pj::MediaFormatAudio >::value_type result;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__vectorT_pj__MediaFormatAudio_std__allocatorT_pj__MediaFormatAudio_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "MediaFormatAudioVector_pop" "', argument " "1"" of type '" "std::vector< pj::MediaFormatAudio > *""'"); 
  }
  arg1 = reinterpret_cast< std::vector< pj::MediaFormatAudio > * >(argp1);
  try {
    result = std_vector_Sl_pj_MediaFormatAudio_Sg__pop(arg1);
  } catch(std::out_of_range &_e) {
    SWIG_exception_fail(SWIG_IndexError, (&_e)->what());
  }
  resultobj = SWIG_NewPointerObj((new std::vector< pj::MediaFormatAudio >::value_type(static_cast< const std::vector< pj::MediaFormatAudio >::value_type& >(result))), SWIGTYPE_p_pj__MediaFormatAudio, SWIG_POINTER_OWN |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_MediaFormatAudioVector_append(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  std::vector< pj::MediaFormatAudio > *arg1 = (std::vector< pj::MediaFormatAudio > *) 0 ;
  std::vector< pj::MediaFormatAudio >::value_type *arg2 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  void *argp2 = 0 ;
  int res2 = 0 ;
  PyObject *swig_obj[2] ;
  
  if (!SWIG_Python_UnpackTuple(args, "MediaFormatAudioVector_append", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__vectorT_pj__MediaFormatAudio_std__allocatorT_pj__MediaFormatAudio_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "MediaFormatAudioVector_append" "', argument " "1"" of type '" "std::vector< pj::MediaFormatAudio > *""'"); 
  }
  arg1 = reinterpret_cast< std::vector< pj::MediaFormatAudio > * >(argp1);
  res2 = SWIG_ConvertPtr(swig_obj[1], &argp2, SWIGTYPE_p_pj__MediaFormatAudio,  0  | 0);
  if (!SWIG_IsOK(res2)) {
    SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "MediaFormatAudioVector_append" "', argument " "2"" of type '" "std::vector< pj::MediaFormatAudio >::value_type const &""'"); 
  }
  if (!argp2) {
    SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "MediaFormatAudioVector_append" "', argument " "2"" of type '" "std::vector< pj::MediaFormatAudio >::value_type const &""'"); 
  }
  arg2 = reinterpret_cast< std::vector< pj::MediaFormatAudio >::value_type * >(argp2);
  std_vector_Sl_pj_MediaFormatAudio_Sg__append(arg1,(pj::MediaFormatAudio const &)*arg2);
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_new_MediaFormatAudioVector__SWIG_0(PyObject *SWIGUNUSEDPARM(self), Py_ssize_t nobjs, PyObject **SWIGUNUSEDPARM(swig_obj)) {
  PyObject *resultobj = 0;
  std::vector< pj::MediaFormatAudio > *result = 0 ;
  
  if ((nobjs < 0) || (nobjs > 0)) SWIG_fail;
  result = (std::vector< pj::MediaFormatAudio > *)new std::vector< pj::MediaFormatAudio >();
  resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(result), SWIGTYPE_p_std__vectorT_pj__MediaFormatAudio_std__allocatorT_pj__MediaFormatAudio_t_t, SWIG_POINTER_NEW |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_new_MediaFormatAudioVector__SWIG_1(PyObject *SWIGUNUSEDPARM(self), Py_ssize_t nobjs, PyObject **swig_obj) {
  PyObject *resultobj = 0;
  std::vector< pj::MediaFormatAudio > *arg1 = 0 ;
  int res1 = SWIG_OLDOBJ ;
  std::vector< pj::MediaFormatAudio > *result = 0 ;
  
  if ((nobjs < 1) || (nobjs > 1)) SWIG_fail;
  {
    std::vector< pj::MediaFormatAudio,std::allocator< pj::MediaFormatAudio > > *ptr = (std::vector< pj::MediaFormatAudio,std::allocator< pj::MediaFormatAudio > > *)0;
    res1 = swig::asptr(swig_obj[0], &ptr);
    if (!SWIG_IsOK(res1)) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "new_MediaFormatAudioVector" "', argument " "1"" of type '" "std::vector< pj::MediaFormatAudio > const &""'"); 
    }
    if (!ptr) {
      SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "new_MediaFormatAudioVector" "', argument " "1"" of type '" "std::vector< pj::MediaFormatAudio > const &""'"); 
    }
    arg1 = ptr;
  }
  result = (std::vector< pj::MediaFormatAudio > *)new std::vector< pj::MediaFormatAudio >((std::vector< pj::MediaFormatAudio > const &)*arg1);
  resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(result), SWIGTYPE_p_std__vectorT_pj__MediaFormatAudio_std__allocatorT_pj__MediaFormatAudio_t_t, SWIG_POINTER_NEW |  0 );
  if (SWIG_IsNewObj(res1)) delete arg1;
  return resultobj;
fail:
  if (SWIG_IsNewObj(res1)) delete arg1;
  return NULL;
}


SWIGINTERN PyObject *_wrap_MediaFormatAudioVector_empty(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  std::vector< pj::MediaFormatAudio > *arg1 = (std::vector< pj::MediaFormatAudio > *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  bool result;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__vectorT_pj__MediaFormatAudio_std__allocatorT_pj__MediaFormatAudio_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "MediaFormatAudioVector_empty" "', argument " "1"" of type '" "std::vector< pj::MediaFormatAudio > const *""'"); 
  }
  arg1 = reinterpret_cast< std::vector< pj::MediaFormatAudio > * >(argp1);
  result = (bool)((std::vector< pj::MediaFormatAudio > const *)arg1)->empty();
  resultobj = SWIG_From_bool(static_cast< bool >(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_MediaFormatAudioVector_size(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  std::vector< pj::MediaFormatAudio > *arg1 = (std::vector< pj::MediaFormatAudio > *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  std::vector< pj::MediaFormatAudio >::size_type result;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__vectorT_pj__MediaFormatAudio_std__allocatorT_pj__MediaFormatAudio_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "MediaFormatAudioVector_size" "', argument " "1"" of type '" "std::vector< pj::MediaFormatAudio > const *""'"); 
  }
  arg1 = reinterpret_cast< std::vector< pj::MediaFormatAudio > * >(argp1);
  result = ((std::vector< pj::MediaFormatAudio > const *)arg1)->size();
  resultobj = SWIG_From_size_t(static_cast< size_t >(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_MediaFormatAudioVector_swap(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  std::vector< pj::MediaFormatAudio > *arg1 = (std::vector< pj::MediaFormatAudio > *) 0 ;
  std::vector< pj::MediaFormatAudio > *arg2 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  void *argp2 = 0 ;
  int res2 = 0 ;
  PyObject *swig_obj[2] ;
  
  if (!SWIG_Python_UnpackTuple(args, "MediaFormatAudioVector_swap", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__vectorT_pj__MediaFormatAudio_std__allocatorT_pj__MediaFormatAudio_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "MediaFormatAudioVector_swap" "', argument " "1"" of type '" "std::vector< pj::MediaFormatAudio > *""'"); 
  }
  arg1 = reinterpret_cast< std::vector< pj::MediaFormatAudio > * >(argp1);
  res2 = SWIG_ConvertPtr(swig_obj[1], &argp2, SWIGTYPE_p_std__vectorT_pj__MediaFormatAudio_std__allocatorT_pj__MediaFormatAudio_t_t,  0 );
  if (!SWIG_IsOK(res2)) {
    SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "MediaFormatAudioVector_swap" "', argument " "2"" of type '" "std::vector< pj::MediaFormatAudio > &""'"); 
  }
  if (!argp2) {
    SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "MediaFormatAudioVector_swap" "', argument " "2"" of type '" "std::vector< pj::MediaFormatAudio > &""'"); 
  }
  arg2 = reinterpret_cast< std::vector< pj::MediaFormatAudio > * >(argp2);
  (arg1)->swap(*arg2);
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_MediaFormatAudioVector_begin(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  std::vector< pj::MediaFormatAudio > *arg1 = (std::vector< pj::MediaFormatAudio > *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  std::vector< pj::MediaFormatAudio >::iterator result;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__vectorT_pj__MediaFormatAudio_std__allocatorT_pj__MediaFormatAudio_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "MediaFormatAudioVector_begin" "', argument " "1"" of type '" "std::vector< pj::MediaFormatAudio > *""'"); 
  }
  arg1 = reinterpret_cast< std::vector< pj::MediaFormatAudio > * >(argp1);
  result = (arg1)->begin();
  resultobj = SWIG_NewPointerObj(swig::make_output_iterator(static_cast< const std::vector< pj::MediaFormatAudio >::iterator & >(result)),
    swig::SwigPyIterator::descriptor(),SWIG_POINTER_OWN);
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_MediaFormatAudioVector_end(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  std::vector< pj::MediaFormatAudio > *arg1 = (std::vector< pj::MediaFormatAudio > *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  std::vector< pj::MediaFormatAudio >::iterator result;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__vectorT_pj__MediaFormatAudio_std__allocatorT_pj__MediaFormatAudio_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "MediaFormatAudioVector_end" "', argument " "1"" of type '" "std::vector< pj::MediaFormatAudio > *""'"); 
  }
  arg1 = reinterpret_cast< std::vector< pj::MediaFormatAudio > * >(argp1);
  result = (arg1)->end();
  resultobj = SWIG_NewPointerObj(swig::make_output_iterator(static_cast< const std::vector< pj::MediaFormatAudio >::iterator & >(result)),
    swig::SwigPyIterator::descriptor(),SWIG_POINTER_OWN);
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_MediaFormatAudioVector_rbegin(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  std::vector< pj::MediaFormatAudio > *arg1 = (std::vector< pj::MediaFormatAudio > *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  std::vector< pj::MediaFormatAudio >::reverse_iterator result;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__vectorT_pj__MediaFormatAudio_std__allocatorT_pj__MediaFormatAudio_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "MediaFormatAudioVector_rbegin" "', argument " "1"" of type '" "std::vector< pj::MediaFormatAudio > *""'"); 
  }
  arg1 = reinterpret_cast< std::vector< pj::MediaFormatAudio > * >(argp1);
  result = (arg1)->rbegin();
  resultobj = SWIG_NewPointerObj(swig::make_output_iterator(static_cast< const std::vector< pj::MediaFormatAudio >::reverse_iterator & >(result)),
    swig::SwigPyIterator::descriptor(),SWIG_POINTER_OWN);
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_MediaFormatAudioVector_rend(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  std::vector< pj::MediaFormatAudio > *arg1 = (std::vector< pj::MediaFormatAudio > *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  std::vector< pj::MediaFormatAudio >::reverse_iterator result;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__vectorT_pj__MediaFormatAudio_std__allocatorT_pj__MediaFormatAudio_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "MediaFormatAudioVector_rend" "', argument " "1"" of type '" "std::vector< pj::MediaFormatAudio > *""'"); 
  }
  arg1 = reinterpret_cast< std::vector< pj::MediaFormatAudio > * >(argp1);
  result = (arg1)->rend();
  resultobj = SWIG_NewPointerObj(swig::make_output_iterator(static_cast< const std::vector< pj::MediaFormatAudio >::reverse_iterator & >(result)),
    swig::SwigPyIterator::descriptor(),SWIG_POINTER_OWN);
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_MediaFormatAudioVector_clear(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  std::vector< pj::MediaFormatAudio > *arg1 = (std::vector< pj::MediaFormatAudio > *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__vectorT_pj__MediaFormatAudio_std__allocatorT_pj__MediaFormatAudio_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "MediaFormatAudioVector_clear" "', argument " "1"" of type '" "std::vector< pj::MediaFormatAudio > *""'"); 
  }
  arg1 = reinterpret_cast< std::vector< pj::MediaFormatAudio > * >(argp1);
  (arg1)->clear();
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_MediaFormatAudioVector_get_allocator(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  std::vector< pj::MediaFormatAudio > *arg1 = (std::vector< pj::MediaFormatAudio > *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  SwigValueWrapper< std::allocator< pj::MediaFormatAudio > > result;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__vectorT_pj__MediaFormatAudio_std__allocatorT_pj__MediaFormatAudio_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "MediaFormatAudioVector_get_allocator" "', argument " "1"" of type '" "std::vector< pj::MediaFormatAudio > const *""'"); 
  }
  arg1 = reinterpret_cast< std::vector< pj::MediaFormatAudio > * >(argp1);
  result = ((std::vector< pj::MediaFormatAudio > const *)arg1)->get_allocator();
  resultobj = SWIG_NewPointerObj((new std::vector< pj::MediaFormatAudio >::allocator_type(static_cast< const std::vector< pj::MediaFormatAudio >::allocator_type& >(result))), SWIGTYPE_p_std__allocatorT_pj__MediaFormatAudio_t, SWIG_POINTER_OWN |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_new_MediaFormatAudioVector__SWIG_2(PyObject *SWIGUNUSEDPARM(self), Py_ssize_t nobjs, PyObject **swig_obj) {
  PyObject *resultobj = 0;
  std::vector< pj::MediaFormatAudio >::size_type arg1 ;
  size_t val1 ;
  int ecode1 = 0 ;
  std::vector< pj::MediaFormatAudio > *result = 0 ;
  
  if ((nobjs < 1) || (nobjs > 1)) SWIG_fail;
  ecode1 = SWIG_AsVal_size_t(swig_obj[0], &val1);
  if (!SWIG_IsOK(ecode1)) {
    SWIG_exception_fail(SWIG_ArgError(ecode1), "in method '" "new_MediaFormatAudioVector" "', argument " "1"" of type '" "std::vector< pj::MediaFormatAudio >::size_type""'");
  } 
  arg1 = static_cast< std::vector< pj::MediaFormatAudio >::size_type >(val1);
  result = (std::vector< pj::MediaFormatAudio > *)new std::vector< pj::MediaFormatAudio >(arg1);
  resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(result), SWIGTYPE_p_std__vectorT_pj__MediaFormatAudio_std__allocatorT_pj__MediaFormatAudio_t_t, SWIG_POINTER_NEW |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_MediaFormatAudioVector_pop_back(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  std::vector< pj::MediaFormatAudio > *arg1 = (std::vector< pj::MediaFormatAudio > *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__vectorT_pj__MediaFormatAudio_std__allocatorT_pj__MediaFormatAudio_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "MediaFormatAudioVector_pop_back" "', argument " "1"" of type '" "std::vector< pj::MediaFormatAudio > *""'"); 
  }
  arg1 = reinterpret_cast< std::vector< pj::MediaFormatAudio > * >(argp1);
  (arg1)->pop_back();
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_MediaFormatAudioVector_resize__SWIG_0(PyObject *SWIGUNUSEDPARM(self), Py_ssize_t nobjs, PyObject **swig_obj) {
  PyObject *resultobj = 0;
  std::vector< pj::MediaFormatAudio > *arg1 = (std::vector< pj::MediaFormatAudio > *) 0 ;
  std::vector< pj::MediaFormatAudio >::size_type arg2 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  size_t val2 ;
  int ecode2 = 0 ;
  
  if ((nobjs < 2) || (nobjs > 2)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__vectorT_pj__MediaFormatAudio_std__allocatorT_pj__MediaFormatAudio_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "MediaFormatAudioVector_resize" "', argument " "1"" of type '" "std::vector< pj::MediaFormatAudio > *""'"); 
  }
  arg1 = reinterpret_cast< std::vector< pj::MediaFormatAudio > * >(argp1);
  ecode2 = SWIG_AsVal_size_t(swig_obj[1], &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "MediaFormatAudioVector_resize" "', argument " "2"" of type '" "std::vector< pj::MediaFormatAudio >::size_type""'");
  } 
  arg2 = static_cast< std::vector< pj::MediaFormatAudio >::size_type >(val2);
  (arg1)->resize(arg2);
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_MediaFormatAudioVector_erase__SWIG_0(PyObject *SWIGUNUSEDPARM(self), Py_ssize_t nobjs, PyObject **swig_obj) {
  PyObject *resultobj = 0;
  std::vector< pj::MediaFormatAudio > *arg1 = (std::vector< pj::MediaFormatAudio > *) 0 ;
  std::vector< pj::MediaFormatAudio >::iterator arg2 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  swig::SwigPyIterator *iter2 = 0 ;
  int res2 ;
  std::vector< pj::MediaFormatAudio >::iterator result;
  
  if ((nobjs < 2) || (nobjs > 2)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__vectorT_pj__MediaFormatAudio_std__allocatorT_pj__MediaFormatAudio_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "MediaFormatAudioVector_erase" "', argument " "1"" of type '" "std::vector< pj::MediaFormatAudio > *""'"); 
  }
  arg1 = reinterpret_cast< std::vector< pj::MediaFormatAudio > * >(argp1);
  res2 = SWIG_ConvertPtr(swig_obj[1], SWIG_as_voidptrptr(&iter2), swig::SwigPyIterator::descriptor(), 0);
  if (!SWIG_IsOK(res2) || !iter2) {
    SWIG_exception_fail(SWIG_ArgError(SWIG_TypeError), "in method '" "MediaFormatAudioVector_erase" "', argument " "2"" of type '" "std::vector< pj::MediaFormatAudio >::iterator""'");
  } else {
    swig::SwigPyIterator_T<std::vector< pj::MediaFormatAudio >::iterator > *iter_t = dynamic_cast<swig::SwigPyIterator_T<std::vector< pj::MediaFormatAudio >::iterator > *>(iter2);
    if (iter_t) {
      arg2 = iter_t->get_current();
    } else {
      SWIG_exception_fail(SWIG_ArgError(SWIG_TypeError), "in method '" "MediaFormatAudioVector_erase" "', argument " "2"" of type '" "std::vector< pj::MediaFormatAudio >::iterator""'");
    }
  }
  result = std_vector_Sl_pj_MediaFormatAudio_Sg__erase__SWIG_0(arg1,arg2);
  resultobj = SWIG_NewPointerObj(swig::make_output_iterator(static_cast< const std::vector< pj::MediaFormatAudio >::iterator & >(result)),
    swig::SwigPyIterator::descriptor(),SWIG_POINTER_OWN);
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_MediaFormatAudioVector_erase__SWIG_1(PyObject *SWIGUNUSEDPARM(self), Py_ssize_t nobjs, PyObject **swig_obj) {
  PyObject *resultobj = 0;
  std::vector< pj::MediaFormatAudio > *arg1 = (std::vector< pj::MediaFormatAudio > *) 0 ;
  std::vector< pj::MediaFormatAudio >::iterator arg2 ;
  std::vector< pj::MediaFormatAudio >::iterator arg3 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  swig::SwigPyIterator *iter2 = 0 ;
  int res2 ;
  swig::SwigPyIterator *iter3 = 0 ;
  int res3 ;
  std::vector< pj::MediaFormatAudio >::iterator result;
  
  if ((nobjs < 3) || (nobjs > 3)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__vectorT_pj__MediaFormatAudio_std__allocatorT_pj__MediaFormatAudio_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "MediaFormatAudioVector_erase" "', argument " "1"" of type '" "std::vector< pj::MediaFormatAudio > *""'"); 
  }
  arg1 = reinterpret_cast< std::vector< pj::MediaFormatAudio > * >(argp1);
  res2 = SWIG_ConvertPtr(swig_obj[1], SWIG_as_voidptrptr(&iter2), swig::SwigPyIterator::descriptor(), 0);
  if (!SWIG_IsOK(res2) || !iter2) {
    SWIG_exception_fail(SWIG_ArgError(SWIG_TypeError), "in method '" "MediaFormatAudioVector_erase" "', argument " "2"" of type '" "std::vector< pj::MediaFormatAudio >::iterator""'");
  } else {
    swig::SwigPyIterator_T<std::vector< pj::MediaFormatAudio >::iterator > *iter_t = dynamic_cast<swig::SwigPyIterator_T<std::vector< pj::MediaFormatAudio >::iterator > *>(iter2);
    if (iter_t) {
      arg2 = iter_t->get_current();
    } else {
      SWIG_exception_fail(SWIG_ArgError(SWIG_TypeError), "in method '" "MediaFormatAudioVector_erase" "', argument " "2"" of type '" "std::vector< pj::MediaFormatAudio >::iterator""'");
    }
  }
  res3 = SWIG_ConvertPtr(swig_obj[2], SWIG_as_voidptrptr(&iter3), swig::SwigPyIterator::descriptor(), 0);
  if (!SWIG_IsOK(res3) || !iter3) {
    SWIG_exception_fail(SWIG_ArgError(SWIG_TypeError), "in method '" "MediaFormatAudioVector_erase" "', argument " "3"" of type '" "std::vector< pj::MediaFormatAudio >::iterator""'");
  } else {
    swig::SwigPyIterator_T<std::vector< pj::MediaFormatAudio >::iterator > *iter_t = dynamic_cast<swig::SwigPyIterator_T<std::vector< pj::MediaFormatAudio >::iterator > *>(iter3);
    if (iter_t) {
      arg3 = iter_t->get_current();
    } else {
      SWIG_exception_fail(SWIG_ArgError(SWIG_TypeError), "in method '" "MediaFormatAudioVector_erase" "', argument " "3"" of type '" "std::vector< pj::MediaFormatAudio >::iterator""'");
    }
  }
  result = std_vector_Sl_pj_MediaFormatAudio_Sg__erase__SWIG_1(arg1,arg2,arg3);
  resultobj = SWIG_NewPointerObj(swig::make_output_iterator(static_cast< const std::vector< pj::MediaFormatAudio >::iterator & >(result)),
    swig::SwigPyIterator::descriptor(),SWIG_POINTER_OWN);
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_MediaFormatAudioVector_erase(PyObject *self, PyObject *args) {
  Py_ssize_t argc;
  PyObject *argv[4] = {
    0
  };
  
  if (!(argc = SWIG_Python_UnpackTuple(args, "MediaFormatAudioVector_erase", 0, 3, argv))) SWIG_fail;
  --argc;
  if (argc == 2) {
    int _v;
    int res = swig::asptr(argv[0], (std::vector< pj::MediaFormatAudio,std::allocator< pj::MediaFormatAudio > >**)(0));
    _v = SWIG_CheckState(res);
    if (_v) {
      swig::SwigPyIterator *iter = 0;
      int res = SWIG_ConvertPtr(argv[1], SWIG_as_voidptrptr(&iter), swig::SwigPyIterator::descriptor(), 0);
      _v = (SWIG_IsOK(res) && iter && (dynamic_cast<swig::SwigPyIterator_T<std::vector< pj::MediaFormatAudio >::iterator > *>(iter) != 0));
      if (_v) {
        return _wrap_MediaFormatAudioVector_erase__SWIG_0(self, argc, argv);
      }
    }
  }
  if (argc == 3) {
    int _v;
    int res = swig::asptr(argv[0], (std::vector< pj::MediaFormatAudio,std::allocator< pj::MediaFormatAudio > >**)(0));
    _v = SWIG_CheckState(res);
    if (_v) {
      swig::SwigPyIterator *iter = 0;
      int res = SWIG_ConvertPtr(argv[1], SWIG_as_voidptrptr(&iter), swig::SwigPyIterator::descriptor(), 0);
      _v = (SWIG_IsOK(res) && iter && (dynamic_cast<swig::SwigPyIterator_T<std::vector< pj::MediaFormatAudio >::iterator > *>(iter) != 0));
      if (_v) {
        swig::SwigPyIterator *iter = 0;
        int res = SWIG_ConvertPtr(argv[2], SWIG_as_voidptrptr(&iter), swig::SwigPyIterator::descriptor(), 0);
        _v = (SWIG_IsOK(res) && iter && (dynamic_cast<swig::SwigPyIterator_T<std::vector< pj::MediaFormatAudio >::iterator > *>(iter) != 0));
        if (_v) {
          return _wrap_MediaFormatAudioVector_erase__SWIG_1(self, argc, argv);
        }
      }
    }
  }
  
fail:
  SWIG_Python_RaiseOrModifyTypeError("Wrong number or type of arguments for overloaded function 'MediaFormatAudioVector_erase'.\n"
    "  Possible C/C++ prototypes are:\n"
    "    std::vector< pj::MediaFormatAudio >::erase(std::vector< pj::MediaFormatAudio >::iterator)\n"
    "    std::vector< pj::MediaFormatAudio >::erase(std::vector< pj::MediaFormatAudio >::iterator,std::vector< pj::MediaFormatAudio >::iterator)\n");
  return 0;
}


SWIGINTERN PyObject *_wrap_new_MediaFormatAudioVector__SWIG_3(PyObject *SWIGUNUSEDPARM(self), Py_ssize_t nobjs, PyObject **swig_obj) {
  PyObject *resultobj = 0;
  std::vector< pj::MediaFormatAudio >::size_type arg1 ;
  std::vector< pj::MediaFormatAudio >::value_type *arg2 = 0 ;
  size_t val1 ;
  int ecode1 = 0 ;
  void *argp2 = 0 ;
  int res2 = 0 ;
  std::vector< pj::MediaFormatAudio > *result = 0 ;
  
  if ((nobjs < 2) || (nobjs > 2)) SWIG_fail;
  ecode1 = SWIG_AsVal_size_t(swig_obj[0], &val1);
  if (!SWIG_IsOK(ecode1)) {
    SWIG_exception_fail(SWIG_ArgError(ecode1), "in method '" "new_MediaFormatAudioVector" "', argument " "1"" of type '" "std::vector< pj::MediaFormatAudio >::size_type""'");
  } 
  arg1 = static_cast< std::vector< pj::MediaFormatAudio >::size_type >(val1);
  res2 = SWIG_ConvertPtr(swig_obj[1], &argp2, SWIGTYPE_p_pj__MediaFormatAudio,  0  | 0);
  if (!SWIG_IsOK(res2)) {
    SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "new_MediaFormatAudioVector" "', argument " "2"" of type '" "std::vector< pj::MediaFormatAudio >::value_type const &""'"); 
  }
  if (!argp2) {
    SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "new_MediaFormatAudioVector" "', argument " "2"" of type '" "std::vector< pj::MediaFormatAudio >::value_type const &""'"); 
  }
  arg2 = reinterpret_cast< std::vector< pj::MediaFormatAudio >::value_type * >(argp2);
  result = (std::vector< pj::MediaFormatAudio > *)new std::vector< pj::MediaFormatAudio >(arg1,(std::vector< pj::MediaFormatAudio >::value_type const &)*arg2);
  resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(result), SWIGTYPE_p_std__vectorT_pj__MediaFormatAudio_std__allocatorT_pj__MediaFormatAudio_t_t, SWIG_POINTER_NEW |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_new_MediaFormatAudioVector(PyObject *self, PyObject *args) {
  Py_ssize_t argc;
  PyObject *argv[3] = {
    0
  };
  
  if (!(argc = SWIG_Python_UnpackTuple(args, "new_MediaFormatAudioVector", 0, 2, argv))) SWIG_fail;
  --argc;
  if (argc == 0) {
    return _wrap_new_MediaFormatAudioVector__SWIG_0(self, argc, argv);
  }
  if (argc == 1) {
    int _v;
    {
      int res = SWIG_AsVal_size_t(argv[0], NULL);
      _v = SWIG_CheckState(res);
    }
    if (_v) {
      return _wrap_new_MediaFormatAudioVector__SWIG_2(self, argc, argv);
    }
  }
  if (argc == 1) {
    int _v;
    int res = swig::asptr(argv[0], (std::vector< pj::MediaFormatAudio,std::allocator< pj::MediaFormatAudio > >**)(0));
    _v = SWIG_CheckState(res);
    if (_v) {
      return _wrap_new_MediaFormatAudioVector__SWIG_1(self, argc, argv);
    }
  }
  if (argc == 2) {
    int _v;
    {
      int res = SWIG_AsVal_size_t(argv[0], NULL);
      _v = SWIG_CheckState(res);
    }
    if (_v) {
      int res = SWIG_ConvertPtr(argv[1], 0, SWIGTYPE_p_pj__MediaFormatAudio, SWIG_POINTER_NO_NULL | 0);
      _v = SWIG_CheckState(res);
      if (_v) {
        return _wrap_new_MediaFormatAudioVector__SWIG_3(self, argc, argv);
      }
    }
  }
  
fail:
  SWIG_Python_RaiseOrModifyTypeError("Wrong number or type of arguments for overloaded function 'new_MediaFormatAudioVector'.\n"
    "  Possible C/C++ prototypes are:\n"
    "    std::vector< pj::MediaFormatAudio >::vector()\n"
    "    std::vector< pj::MediaFormatAudio >::vector(std::vector< pj::MediaFormatAudio > const &)\n"
    "    std::vector< pj::MediaFormatAudio >::vector(std::vector< pj::MediaFormatAudio >::size_type)\n"
    "    std::vector< pj::MediaFormatAudio >::vector(std::vector< pj::MediaFormatAudio >::size_type,std::vector< pj::MediaFormatAudio >::value_type const &)\n");
  return 0;
}


SWIGINTERN PyObject *_wrap_MediaFormatAudioVector_push_back(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  std::vector< pj::MediaFormatAudio > *arg1 = (std::vector< pj::MediaFormatAudio > *) 0 ;
  std::vector< pj::MediaFormatAudio >::value_type *arg2 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  void *argp2 = 0 ;
  int res2 = 0 ;
  PyObject *swig_obj[2] ;
  
  if (!SWIG_Python_UnpackTuple(args, "MediaFormatAudioVector_push_back", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__vectorT_pj__MediaFormatAudio_std__allocatorT_pj__MediaFormatAudio_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "MediaFormatAudioVector_push_back" "', argument " "1"" of type '" "std::vector< pj::MediaFormatAudio > *""'"); 
  }
  arg1 = reinterpret_cast< std::vector< pj::MediaFormatAudio > * >(argp1);
  res2 = SWIG_ConvertPtr(swig_obj[1], &argp2, SWIGTYPE_p_pj__MediaFormatAudio,  0  | 0);
  if (!SWIG_IsOK(res2)) {
    SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "MediaFormatAudioVector_push_back" "', argument " "2"" of type '" "std::vector< pj::MediaFormatAudio >::value_type const &""'"); 
  }
  if (!argp2) {
    SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "MediaFormatAudioVector_push_back" "', argument " "2"" of type '" "std::vector< pj::MediaFormatAudio >::value_type const &""'"); 
  }
  arg2 = reinterpret_cast< std::vector< pj::MediaFormatAudio >::value_type * >(argp2);
  (arg1)->push_back((std::vector< pj::MediaFormatAudio >::value_type const &)*arg2);
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_MediaFormatAudioVector_front(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  std::vector< pj::MediaFormatAudio > *arg1 = (std::vector< pj::MediaFormatAudio > *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  std::vector< pj::MediaFormatAudio >::value_type *result = 0 ;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__vectorT_pj__MediaFormatAudio_std__allocatorT_pj__MediaFormatAudio_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "MediaFormatAudioVector_front" "', argument " "1"" of type '" "std::vector< pj::MediaFormatAudio > const *""'"); 
  }
  arg1 = reinterpret_cast< std::vector< pj::MediaFormatAudio > * >(argp1);
  result = (std::vector< pj::MediaFormatAudio >::value_type *) &((std::vector< pj::MediaFormatAudio > const *)arg1)->front();
  resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(result), SWIGTYPE_p_pj__MediaFormatAudio, 0 |  0 );
  (void)swig::container_owner<swig::traits<std::vector< pj::MediaFormatAudio >::value_type>::category>::back_reference(resultobj, swig_obj[0]);
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_MediaFormatAudioVector_back(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  std::vector< pj::MediaFormatAudio > *arg1 = (std::vector< pj::MediaFormatAudio > *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  std::vector< pj::MediaFormatAudio >::value_type *result = 0 ;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__vectorT_pj__MediaFormatAudio_std__allocatorT_pj__MediaFormatAudio_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "MediaFormatAudioVector_back" "', argument " "1"" of type '" "std::vector< pj::MediaFormatAudio > const *""'"); 
  }
  arg1 = reinterpret_cast< std::vector< pj::MediaFormatAudio > * >(argp1);
  result = (std::vector< pj::MediaFormatAudio >::value_type *) &((std::vector< pj::MediaFormatAudio > const *)arg1)->back();
  resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(result), SWIGTYPE_p_pj__MediaFormatAudio, 0 |  0 );
  (void)swig::container_owner<swig::traits<std::vector< pj::MediaFormatAudio >::value_type>::category>::back_reference(resultobj, swig_obj[0]);
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_MediaFormatAudioVector_assign(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  std::vector< pj::MediaFormatAudio > *arg1 = (std::vector< pj::MediaFormatAudio > *) 0 ;
  std::vector< pj::MediaFormatAudio >::size_type arg2 ;
  std::vector< pj::MediaFormatAudio >::value_type *arg3 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  size_t val2 ;
  int ecode2 = 0 ;
  void *argp3 = 0 ;
  int res3 = 0 ;
  PyObject *swig_obj[3] ;
  
  if (!SWIG_Python_UnpackTuple(args, "MediaFormatAudioVector_assign", 3, 3, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__vectorT_pj__MediaFormatAudio_std__allocatorT_pj__MediaFormatAudio_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "MediaFormatAudioVector_assign" "', argument " "1"" of type '" "std::vector< pj::MediaFormatAudio > *""'"); 
  }
  arg1 = reinterpret_cast< std::vector< pj::MediaFormatAudio > * >(argp1);
  ecode2 = SWIG_AsVal_size_t(swig_obj[1], &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "MediaFormatAudioVector_assign" "', argument " "2"" of type '" "std::vector< pj::MediaFormatAudio >::size_type""'");
  } 
  arg2 = static_cast< std::vector< pj::MediaFormatAudio >::size_type >(val2);
  res3 = SWIG_ConvertPtr(swig_obj[2], &argp3, SWIGTYPE_p_pj__MediaFormatAudio,  0  | 0);
  if (!SWIG_IsOK(res3)) {
    SWIG_exception_fail(SWIG_ArgError(res3), "in method '" "MediaFormatAudioVector_assign" "', argument " "3"" of type '" "std::vector< pj::MediaFormatAudio >::value_type const &""'"); 
  }
  if (!argp3) {
    SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "MediaFormatAudioVector_assign" "', argument " "3"" of type '" "std::vector< pj::MediaFormatAudio >::value_type const &""'"); 
  }
  arg3 = reinterpret_cast< std::vector< pj::MediaFormatAudio >::value_type * >(argp3);
  (arg1)->assign(arg2,(std::vector< pj::MediaFormatAudio >::value_type const &)*arg3);
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_MediaFormatAudioVector_resize__SWIG_1(PyObject *SWIGUNUSEDPARM(self), Py_ssize_t nobjs, PyObject **swig_obj) {
  PyObject *resultobj = 0;
  std::vector< pj::MediaFormatAudio > *arg1 = (std::vector< pj::MediaFormatAudio > *) 0 ;
  std::vector< pj::MediaFormatAudio >::size_type arg2 ;
  std::vector< pj::MediaFormatAudio >::value_type *arg3 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  size_t val2 ;
  int ecode2 = 0 ;
  void *argp3 = 0 ;
  int res3 = 0 ;
  
  if ((nobjs < 3) || (nobjs > 3)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__vectorT_pj__MediaFormatAudio_std__allocatorT_pj__MediaFormatAudio_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "MediaFormatAudioVector_resize" "', argument " "1"" of type '" "std::vector< pj::MediaFormatAudio > *""'"); 
  }
  arg1 = reinterpret_cast< std::vector< pj::MediaFormatAudio > * >(argp1);
  ecode2 = SWIG_AsVal_size_t(swig_obj[1], &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "MediaFormatAudioVector_resize" "', argument " "2"" of type '" "std::vector< pj::MediaFormatAudio >::size_type""'");
  } 
  arg2 = static_cast< std::vector< pj::MediaFormatAudio >::size_type >(val2);
  res3 = SWIG_ConvertPtr(swig_obj[2], &argp3, SWIGTYPE_p_pj__MediaFormatAudio,  0  | 0);
  if (!SWIG_IsOK(res3)) {
    SWIG_exception_fail(SWIG_ArgError(res3), "in method '" "MediaFormatAudioVector_resize" "', argument " "3"" of type '" "std::vector< pj::MediaFormatAudio >::value_type const &""'"); 
  }
  if (!argp3) {
    SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "MediaFormatAudioVector_resize" "', argument " "3"" of type '" "std::vector< pj::MediaFormatAudio >::value_type const &""'"); 
  }
  arg3 = reinterpret_cast< std::vector< pj::MediaFormatAudio >::value_type * >(argp3);
  (arg1)->resize(arg2,(std::vector< pj::MediaFormatAudio >::value_type const &)*arg3);
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_MediaFormatAudioVector_resize(PyObject *self, PyObject *args) {
  Py_ssize_t argc;
  PyObject *argv[4] = {
    0
  };
  
  if (!(argc = SWIG_Python_UnpackTuple(args, "MediaFormatAudioVector_resize", 0, 3, argv))) SWIG_fail;
  --argc;
  if (argc == 2) {
    int _v;
    int res = swig::asptr(argv[0], (std::vector< pj::MediaFormatAudio,std::allocator< pj::MediaFormatAudio > >**)(0));
    _v = SWIG_CheckState(res);
    if (_v) {
      {
        int res = SWIG_AsVal_size_t(argv[1], NULL);
        _v = SWIG_CheckState(res);
      }
      if (_v) {
        return _wrap_MediaFormatAudioVector_resize__SWIG_0(self, argc, argv);
      }
    }
  }
  if (argc == 3) {
    int _v;
    int res = swig::asptr(argv[0], (std::vector< pj::MediaFormatAudio,std::allocator< pj::MediaFormatAudio > >**)(0));
    _v = SWIG_CheckState(res);
    if (_v) {
      {
        int res = SWIG_AsVal_size_t(argv[1], NULL);
        _v = SWIG_CheckState(res);
      }
      if (_v) {
        int res = SWIG_ConvertPtr(argv[2], 0, SWIGTYPE_p_pj__MediaFormatAudio, SWIG_POINTER_NO_NULL | 0);
        _v = SWIG_CheckState(res);
        if (_v) {
          return _wrap_MediaFormatAudioVector_resize__SWIG_1(self, argc, argv);
        }
      }
    }
  }
  
fail:
  SWIG_Python_RaiseOrModifyTypeError("Wrong number or type of arguments for overloaded function 'MediaFormatAudioVector_resize'.\n"
    "  Possible C/C++ prototypes are:\n"
    "    std::vector< pj::MediaFormatAudio >::resize(std::vector< pj::MediaFormatAudio >::size_type)\n"
    "    std::vector< pj::MediaFormatAudio >::resize(std::vector< pj::MediaFormatAudio >::size_type,std::vector< pj::MediaFormatAudio >::value_type const &)\n");
  return 0;
}


SWIGINTERN PyObject *_wrap_MediaFormatAudioVector_insert__SWIG_0(PyObject *SWIGUNUSEDPARM(self), Py_ssize_t nobjs, PyObject **swig_obj) {
  PyObject *resultobj = 0;
  std::vector< pj::MediaFormatAudio > *arg1 = (std::vector< pj::MediaFormatAudio > *) 0 ;
  std::vector< pj::MediaFormatAudio >::iterator arg2 ;
  std::vector< pj::MediaFormatAudio >::value_type *arg3 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  swig::SwigPyIterator *iter2 = 0 ;
  int res2 ;
  void *argp3 = 0 ;
  int res3 = 0 ;
  std::vector< pj::MediaFormatAudio >::iterator result;
  
  if ((nobjs < 3) || (nobjs > 3)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__vectorT_pj__MediaFormatAudio_std__allocatorT_pj__MediaFormatAudio_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "MediaFormatAudioVector_insert" "', argument " "1"" of type '" "std::vector< pj::MediaFormatAudio > *""'"); 
  }
  arg1 = reinterpret_cast< std::vector< pj::MediaFormatAudio > * >(argp1);
  res2 = SWIG_ConvertPtr(swig_obj[1], SWIG_as_voidptrptr(&iter2), swig::SwigPyIterator::descriptor(), 0);
  if (!SWIG_IsOK(res2) || !iter2) {
    SWIG_exception_fail(SWIG_ArgError(SWIG_TypeError), "in method '" "MediaFormatAudioVector_insert" "', argument " "2"" of type '" "std::vector< pj::MediaFormatAudio >::iterator""'");
  } else {
    swig::SwigPyIterator_T<std::vector< pj::MediaFormatAudio >::iterator > *iter_t = dynamic_cast<swig::SwigPyIterator_T<std::vector< pj::MediaFormatAudio >::iterator > *>(iter2);
    if (iter_t) {
      arg2 = iter_t->get_current();
    } else {
      SWIG_exception_fail(SWIG_ArgError(SWIG_TypeError), "in method '" "MediaFormatAudioVector_insert" "', argument " "2"" of type '" "std::vector< pj::MediaFormatAudio >::iterator""'");
    }
  }
  res3 = SWIG_ConvertPtr(swig_obj[2], &argp3, SWIGTYPE_p_pj__MediaFormatAudio,  0  | 0);
  if (!SWIG_IsOK(res3)) {
    SWIG_exception_fail(SWIG_ArgError(res3), "in method '" "MediaFormatAudioVector_insert" "', argument " "3"" of type '" "std::vector< pj::MediaFormatAudio >::value_type const &""'"); 
  }
  if (!argp3) {
    SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "MediaFormatAudioVector_insert" "', argument " "3"" of type '" "std::vector< pj::MediaFormatAudio >::value_type const &""'"); 
  }
  arg3 = reinterpret_cast< std::vector< pj::MediaFormatAudio >::value_type * >(argp3);
  result = std_vector_Sl_pj_MediaFormatAudio_Sg__insert__SWIG_0(arg1,arg2,(pj::MediaFormatAudio const &)*arg3);
  resultobj = SWIG_NewPointerObj(swig::make_output_iterator(static_cast< const std::vector< pj::MediaFormatAudio >::iterator & >(result)),
    swig::SwigPyIterator::descriptor(),SWIG_POINTER_OWN);
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_MediaFormatAudioVector_insert__SWIG_1(PyObject *SWIGUNUSEDPARM(self), Py_ssize_t nobjs, PyObject **swig_obj) {
  PyObject *resultobj = 0;
  std::vector< pj::MediaFormatAudio > *arg1 = (std::vector< pj::MediaFormatAudio > *) 0 ;
  std::vector< pj::MediaFormatAudio >::iterator arg2 ;
  std::vector< pj::MediaFormatAudio >::size_type arg3 ;
  std::vector< pj::MediaFormatAudio >::value_type *arg4 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  swig::SwigPyIterator *iter2 = 0 ;
  int res2 ;
  size_t val3 ;
  int ecode3 = 0 ;
  void *argp4 = 0 ;
  int res4 = 0 ;
  
  if ((nobjs < 4) || (nobjs > 4)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__vectorT_pj__MediaFormatAudio_std__allocatorT_pj__MediaFormatAudio_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "MediaFormatAudioVector_insert" "', argument " "1"" of type '" "std::vector< pj::MediaFormatAudio > *""'"); 
  }
  arg1 = reinterpret_cast< std::vector< pj::MediaFormatAudio > * >(argp1);
  res2 = SWIG_ConvertPtr(swig_obj[1], SWIG_as_voidptrptr(&iter2), swig::SwigPyIterator::descriptor(), 0);
  if (!SWIG_IsOK(res2) || !iter2) {
    SWIG_exception_fail(SWIG_ArgError(SWIG_TypeError), "in method '" "MediaFormatAudioVector_insert" "', argument " "2"" of type '" "std::vector< pj::MediaFormatAudio >::iterator""'");
  } else {
    swig::SwigPyIterator_T<std::vector< pj::MediaFormatAudio >::iterator > *iter_t = dynamic_cast<swig::SwigPyIterator_T<std::vector< pj::MediaFormatAudio >::iterator > *>(iter2);
    if (iter_t) {
      arg2 = iter_t->get_current();
    } else {
      SWIG_exception_fail(SWIG_ArgError(SWIG_TypeError), "in method '" "MediaFormatAudioVector_insert" "', argument " "2"" of type '" "std::vector< pj::MediaFormatAudio >::iterator""'");
    }
  }
  ecode3 = SWIG_AsVal_size_t(swig_obj[2], &val3);
  if (!SWIG_IsOK(ecode3)) {
    SWIG_exception_fail(SWIG_ArgError(ecode3), "in method '" "MediaFormatAudioVector_insert" "', argument " "3"" of type '" "std::vector< pj::MediaFormatAudio >::size_type""'");
  } 
  arg3 = static_cast< std::vector< pj::MediaFormatAudio >::size_type >(val3);
  res4 = SWIG_ConvertPtr(swig_obj[3], &argp4, SWIGTYPE_p_pj__MediaFormatAudio,  0  | 0);
  if (!SWIG_IsOK(res4)) {
    SWIG_exception_fail(SWIG_ArgError(res4), "in method '" "MediaFormatAudioVector_insert" "', argument " "4"" of type '" "std::vector< pj::MediaFormatAudio >::value_type const &""'"); 
  }
  if (!argp4) {
    SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "MediaFormatAudioVector_insert" "', argument " "4"" of type '" "std::vector< pj::MediaFormatAudio >::value_type const &""'"); 
  }
  arg4 = reinterpret_cast< std::vector< pj::MediaFormatAudio >::value_type * >(argp4);
  std_vector_Sl_pj_MediaFormatAudio_Sg__insert__SWIG_1(arg1,arg2,arg3,(pj::MediaFormatAudio const &)*arg4);
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_MediaFormatAudioVector_insert(PyObject *self, PyObject *args) {
  Py_ssize_t argc;
  PyObject *argv[5] = {
    0
  };
  
  if (!(argc = SWIG_Python_UnpackTuple(args, "MediaFormatAudioVector_insert", 0, 4, argv))) SWIG_fail;
  --argc;
  if (argc == 3) {
    int _v;
    int res = swig::asptr(argv[0], (std::vector< pj::MediaFormatAudio,std::allocator< pj::MediaFormatAudio > >**)(0));
    _v = SWIG_CheckState(res);
    if (_v) {
      swig::SwigPyIterator *iter = 0;
      int res = SWIG_ConvertPtr(argv[1], SWIG_as_voidptrptr(&iter), swig::SwigPyIterator::descriptor(), 0);
      _v = (SWIG_IsOK(res) && iter && (dynamic_cast<swig::SwigPyIterator_T<std::vector< pj::MediaFormatAudio >::iterator > *>(iter) != 0));
      if (_v) {
        int res = SWIG_ConvertPtr(argv[2], 0, SWIGTYPE_p_pj__MediaFormatAudio, SWIG_POINTER_NO_NULL | 0);
        _v = SWIG_CheckState(res);
        if (_v) {
          return _wrap_MediaFormatAudioVector_insert__SWIG_0(self, argc, argv);
        }
      }
    }
  }
  if (argc == 4) {
    int _v;
    int res = swig::asptr(argv[0], (std::vector< pj::MediaFormatAudio,std::allocator< pj::MediaFormatAudio > >**)(0));
    _v = SWIG_CheckState(res);
    if (_v) {
      swig::SwigPyIterator *iter = 0;
      int res = SWIG_ConvertPtr(argv[1], SWIG_as_voidptrptr(&iter), swig::SwigPyIterator::descriptor(), 0);
      _v = (SWIG_IsOK(res) && iter && (dynamic_cast<swig::SwigPyIterator_T<std::vector< pj::MediaFormatAudio >::iterator > *>(iter) != 0));
      if (_v) {
        {
          int res = SWIG_AsVal_size_t(argv[2], NULL);
          _v = SWIG_CheckState(res);
        }
        if (_v) {
          int res = SWIG_ConvertPtr(argv[3], 0, SWIGTYPE_p_pj__MediaFormatAudio, SWIG_POINTER_NO_NULL | 0);
          _v = SWIG_CheckState(res);
          if (_v) {
            return _wrap_MediaFormatAudioVector_insert__SWIG_1(self, argc, argv);
          }
        }
      }
    }
  }
  
fail:
  SWIG_Python_RaiseOrModifyTypeError("Wrong number or type of arguments for overloaded function 'MediaFormatAudioVector_insert'.\n"
    "  Possible C/C++ prototypes are:\n"
    "    std::vector< pj::MediaFormatAudio >::insert(std::vector< pj::MediaFormatAudio >::iterator,std::vector< pj::MediaFormatAudio >::value_type const &)\n"
    "    std::vector< pj::MediaFormatAudio >::insert(std::vector< pj::MediaFormatAudio >::iterator,std::vector< pj::MediaFormatAudio >::size_type,std::vector< pj::MediaFormatAudio >::value_type const &)\n");
  return 0;
}


SWIGINTERN PyObject *_wrap_MediaFormatAudioVector_reserve(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  std::vector< pj::MediaFormatAudio > *arg1 = (std::vector< pj::MediaFormatAudio > *) 0 ;
  std::vector< pj::MediaFormatAudio >::size_type arg2 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  size_t val2 ;
  int ecode2 = 0 ;
  PyObject *swig_obj[2] ;
  
  if (!SWIG_Python_UnpackTuple(args, "MediaFormatAudioVector_reserve", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__vectorT_pj__MediaFormatAudio_std__allocatorT_pj__MediaFormatAudio_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "MediaFormatAudioVector_reserve" "', argument " "1"" of type '" "std::vector< pj::MediaFormatAudio > *""'"); 
  }
  arg1 = reinterpret_cast< std::vector< pj::MediaFormatAudio > * >(argp1);
  ecode2 = SWIG_AsVal_size_t(swig_obj[1], &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "MediaFormatAudioVector_reserve" "', argument " "2"" of type '" "std::vector< pj::MediaFormatAudio >::size_type""'");
  } 
  arg2 = static_cast< std::vector< pj::MediaFormatAudio >::size_type >(val2);
  (arg1)->reserve(arg2);
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_MediaFormatAudioVector_capacity(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  std::vector< pj::MediaFormatAudio > *arg1 = (std::vector< pj::MediaFormatAudio > *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  std::vector< pj::MediaFormatAudio >::size_type result;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__vectorT_pj__MediaFormatAudio_std__allocatorT_pj__MediaFormatAudio_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "MediaFormatAudioVector_capacity" "', argument " "1"" of type '" "std::vector< pj::MediaFormatAudio > const *""'"); 
  }
  arg1 = reinterpret_cast< std::vector< pj::MediaFormatAudio > * >(argp1);
  result = ((std::vector< pj::MediaFormatAudio > const *)arg1)->capacity();
  resultobj = SWIG_From_size_t(static_cast< size_t >(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_delete_MediaFormatAudioVector(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  std::vector< pj::MediaFormatAudio > *arg1 = (std::vector< pj::MediaFormatAudio > *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__vectorT_pj__MediaFormatAudio_std__allocatorT_pj__MediaFormatAudio_t_t, SWIG_POINTER_DISOWN |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "delete_MediaFormatAudioVector" "', argument " "1"" of type '" "std::vector< pj::MediaFormatAudio > *""'"); 
  }
  arg1 = reinterpret_cast< std::vector< pj::MediaFormatAudio > * >(argp1);
  delete arg1;
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *MediaFormatAudioVector_swigregister(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *obj;
  if (!SWIG_Python_UnpackTuple(args, "swigregister", 1, 1, &obj)) return NULL;
  SWIG_TypeNewClientData(SWIGTYPE_p_std__vectorT_pj__MediaFormatAudio_std__allocatorT_pj__MediaFormatAudio_t_t, SWIG_NewClientData(obj));
  return SWIG_Py_Void();
}

SWIGINTERN PyObject *MediaFormatAudioVector_swiginit(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  return SWIG_Python_InitShadowInstance(args);
}

SWIGINTERN PyObject *_wrap_MediaFormatVideoVector_iterator(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  std::vector< pj::MediaFormatVideo > *arg1 = (std::vector< pj::MediaFormatVideo > *) 0 ;
  PyObject **arg2 = (PyObject **) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  swig::SwigPyIterator *result = 0 ;
  
  arg2 = &swig_obj[0];
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__vectorT_pj__MediaFormatVideo_std__allocatorT_pj__MediaFormatVideo_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "MediaFormatVideoVector_iterator" "', argument " "1"" of type '" "std::vector< pj::MediaFormatVideo > *""'"); 
  }
  arg1 = reinterpret_cast< std::vector< pj::MediaFormatVideo > * >(argp1);
  result = (swig::SwigPyIterator *)std_vector_Sl_pj_MediaFormatVideo_Sg__iterator(arg1,arg2);
  resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(result), SWIGTYPE_p_swig__SwigPyIterator, SWIG_POINTER_OWN |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_MediaFormatVideoVector___nonzero__(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  std::vector< pj::MediaFormatVideo > *arg1 = (std::vector< pj::MediaFormatVideo > *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  bool result;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__vectorT_pj__MediaFormatVideo_std__allocatorT_pj__MediaFormatVideo_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "MediaFormatVideoVector___nonzero__" "', argument " "1"" of type '" "std::vector< pj::MediaFormatVideo > const *""'"); 
  }
  arg1 = reinterpret_cast< std::vector< pj::MediaFormatVideo > * >(argp1);
  result = (bool)std_vector_Sl_pj_MediaFormatVideo_Sg____nonzero__((std::vector< pj::MediaFormatVideo > const *)arg1);
  resultobj = SWIG_From_bool(static_cast< bool >(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_MediaFormatVideoVector___bool__(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  std::vector< pj::MediaFormatVideo > *arg1 = (std::vector< pj::MediaFormatVideo > *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  bool result;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__vectorT_pj__MediaFormatVideo_std__allocatorT_pj__MediaFormatVideo_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "MediaFormatVideoVector___bool__" "', argument " "1"" of type '" "std::vector< pj::MediaFormatVideo > const *""'"); 
  }
  arg1 = reinterpret_cast< std::vector< pj::MediaFormatVideo > * >(argp1);
  result = (bool)std_vector_Sl_pj_MediaFormatVideo_Sg____bool__((std::vector< pj::MediaFormatVideo > const *)arg1);
  resultobj = SWIG_From_bool(static_cast< bool >(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_MediaFormatVideoVector___len__(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  std::vector< pj::MediaFormatVideo > *arg1 = (std::vector< pj::MediaFormatVideo > *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  std::vector< pj::MediaFormatVideo >::size_type result;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__vectorT_pj__MediaFormatVideo_std__allocatorT_pj__MediaFormatVideo_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "MediaFormatVideoVector___len__" "', argument " "1"" of type '" "std::vector< pj::MediaFormatVideo > const *""'"); 
  }
  arg1 = reinterpret_cast< std::vector< pj::MediaFormatVideo > * >(argp1);
  result = std_vector_Sl_pj_MediaFormatVideo_Sg____len__((std::vector< pj::MediaFormatVideo > const *)arg1);
  resultobj = SWIG_From_size_t(static_cast< size_t >(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_MediaFormatVideoVector___getslice__(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  std::vector< pj::MediaFormatVideo > *arg1 = (std::vector< pj::MediaFormatVideo > *) 0 ;
  std::vector< pj::MediaFormatVideo >::difference_type arg2 ;
  std::vector< pj::MediaFormatVideo >::difference_type arg3 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  ptrdiff_t val2 ;
  int ecode2 = 0 ;
  ptrdiff_t val3 ;
  int ecode3 = 0 ;
  PyObject *swig_obj[3] ;
  std::vector< pj::MediaFormatVideo,std::allocator< pj::MediaFormatVideo > > *result = 0 ;
  
  if (!SWIG_Python_UnpackTuple(args, "MediaFormatVideoVector___getslice__", 3, 3, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__vectorT_pj__MediaFormatVideo_std__allocatorT_pj__MediaFormatVideo_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "MediaFormatVideoVector___getslice__" "', argument " "1"" of type '" "std::vector< pj::MediaFormatVideo > *""'"); 
  }
  arg1 = reinterpret_cast< std::vector< pj::MediaFormatVideo > * >(argp1);
  ecode2 = SWIG_AsVal_ptrdiff_t(swig_obj[1], &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "MediaFormatVideoVector___getslice__" "', argument " "2"" of type '" "std::vector< pj::MediaFormatVideo >::difference_type""'");
  } 
  arg2 = static_cast< std::vector< pj::MediaFormatVideo >::difference_type >(val2);
  ecode3 = SWIG_AsVal_ptrdiff_t(swig_obj[2], &val3);
  if (!SWIG_IsOK(ecode3)) {
    SWIG_exception_fail(SWIG_ArgError(ecode3), "in method '" "MediaFormatVideoVector___getslice__" "', argument " "3"" of type '" "std::vector< pj::MediaFormatVideo >::difference_type""'");
  } 
  arg3 = static_cast< std::vector< pj::MediaFormatVideo >::difference_type >(val3);
  try {
    result = (std::vector< pj::MediaFormatVideo,std::allocator< pj::MediaFormatVideo > > *)std_vector_Sl_pj_MediaFormatVideo_Sg____getslice__(arg1,arg2,arg3);
  } catch(std::out_of_range &_e) {
    SWIG_exception_fail(SWIG_IndexError, (&_e)->what());
  } catch(std::invalid_argument &_e) {
    SWIG_exception_fail(SWIG_ValueError, (&_e)->what());
  }
  resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(result), SWIGTYPE_p_std__vectorT_pj__MediaFormatVideo_std__allocatorT_pj__MediaFormatVideo_t_t, SWIG_POINTER_OWN |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_MediaFormatVideoVector___setslice____SWIG_0(PyObject *SWIGUNUSEDPARM(self), Py_ssize_t nobjs, PyObject **swig_obj) {
  PyObject *resultobj = 0;
  std::vector< pj::MediaFormatVideo > *arg1 = (std::vector< pj::MediaFormatVideo > *) 0 ;
  std::vector< pj::MediaFormatVideo >::difference_type arg2 ;
  std::vector< pj::MediaFormatVideo >::difference_type arg3 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  ptrdiff_t val2 ;
  int ecode2 = 0 ;
  ptrdiff_t val3 ;
  int ecode3 = 0 ;
  
  if ((nobjs < 3) || (nobjs > 3)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__vectorT_pj__MediaFormatVideo_std__allocatorT_pj__MediaFormatVideo_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "MediaFormatVideoVector___setslice__" "', argument " "1"" of type '" "std::vector< pj::MediaFormatVideo > *""'"); 
  }
  arg1 = reinterpret_cast< std::vector< pj::MediaFormatVideo > * >(argp1);
  ecode2 = SWIG_AsVal_ptrdiff_t(swig_obj[1], &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "MediaFormatVideoVector___setslice__" "', argument " "2"" of type '" "std::vector< pj::MediaFormatVideo >::difference_type""'");
  } 
  arg2 = static_cast< std::vector< pj::MediaFormatVideo >::difference_type >(val2);
  ecode3 = SWIG_AsVal_ptrdiff_t(swig_obj[2], &val3);
  if (!SWIG_IsOK(ecode3)) {
    SWIG_exception_fail(SWIG_ArgError(ecode3), "in method '" "MediaFormatVideoVector___setslice__" "', argument " "3"" of type '" "std::vector< pj::MediaFormatVideo >::difference_type""'");
  } 
  arg3 = static_cast< std::vector< pj::MediaFormatVideo >::difference_type >(val3);
  try {
    std_vector_Sl_pj_MediaFormatVideo_Sg____setslice____SWIG_0(arg1,arg2,arg3);
  } catch(std::out_of_range &_e) {
    SWIG_exception_fail(SWIG_IndexError, (&_e)->what());
  } catch(std::invalid_argument &_e) {
    SWIG_exception_fail(SWIG_ValueError, (&_e)->what());
  }
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_MediaFormatVideoVector___setslice____SWIG_1(PyObject *SWIGUNUSEDPARM(self), Py_ssize_t nobjs, PyObject **swig_obj) {
  PyObject *resultobj = 0;
  std::vector< pj::MediaFormatVideo > *arg1 = (std::vector< pj::MediaFormatVideo > *) 0 ;
  std::vector< pj::MediaFormatVideo >::difference_type arg2 ;
  std::vector< pj::MediaFormatVideo >::difference_type arg3 ;
  std::vector< pj::MediaFormatVideo,std::allocator< pj::MediaFormatVideo > > *arg4 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  ptrdiff_t val2 ;
  int ecode2 = 0 ;
  ptrdiff_t val3 ;
  int ecode3 = 0 ;
  int res4 = SWIG_OLDOBJ ;
  
  if ((nobjs < 4) || (nobjs > 4)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__vectorT_pj__MediaFormatVideo_std__allocatorT_pj__MediaFormatVideo_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "MediaFormatVideoVector___setslice__" "', argument " "1"" of type '" "std::vector< pj::MediaFormatVideo > *""'"); 
  }
  arg1 = reinterpret_cast< std::vector< pj::MediaFormatVideo > * >(argp1);
  ecode2 = SWIG_AsVal_ptrdiff_t(swig_obj[1], &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "MediaFormatVideoVector___setslice__" "', argument " "2"" of type '" "std::vector< pj::MediaFormatVideo >::difference_type""'");
  } 
  arg2 = static_cast< std::vector< pj::MediaFormatVideo >::difference_type >(val2);
  ecode3 = SWIG_AsVal_ptrdiff_t(swig_obj[2], &val3);
  if (!SWIG_IsOK(ecode3)) {
    SWIG_exception_fail(SWIG_ArgError(ecode3), "in method '" "MediaFormatVideoVector___setslice__" "', argument " "3"" of type '" "std::vector< pj::MediaFormatVideo >::difference_type""'");
  } 
  arg3 = static_cast< std::vector< pj::MediaFormatVideo >::difference_type >(val3);
  {
    std::vector< pj::MediaFormatVideo,std::allocator< pj::MediaFormatVideo > > *ptr = (std::vector< pj::MediaFormatVideo,std::allocator< pj::MediaFormatVideo > > *)0;
    res4 = swig::asptr(swig_obj[3], &ptr);
    if (!SWIG_IsOK(res4)) {
      SWIG_exception_fail(SWIG_ArgError(res4), "in method '" "MediaFormatVideoVector___setslice__" "', argument " "4"" of type '" "std::vector< pj::MediaFormatVideo,std::allocator< pj::MediaFormatVideo > > const &""'"); 
    }
    if (!ptr) {
      SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "MediaFormatVideoVector___setslice__" "', argument " "4"" of type '" "std::vector< pj::MediaFormatVideo,std::allocator< pj::MediaFormatVideo > > const &""'"); 
    }
    arg4 = ptr;
  }
  try {
    std_vector_Sl_pj_MediaFormatVideo_Sg____setslice____SWIG_1(arg1,arg2,arg3,(std::vector< pj::MediaFormatVideo,std::allocator< pj::MediaFormatVideo > > const &)*arg4);
  } catch(std::out_of_range &_e) {
    SWIG_exception_fail(SWIG_IndexError, (&_e)->what());
  } catch(std::invalid_argument &_e) {
    SWIG_exception_fail(SWIG_ValueError, (&_e)->what());
  }
  resultobj = SWIG_Py_Void();
  if (SWIG_IsNewObj(res4)) delete arg4;
  return resultobj;
fail:
  if (SWIG_IsNewObj(res4)) delete arg4;
  return NULL;
}


SWIGINTERN PyObject *_wrap_MediaFormatVideoVector___setslice__(PyObject *self, PyObject *args) {
  Py_ssize_t argc;
  PyObject *argv[5] = {
    0
  };
  
  if (!(argc = SWIG_Python_UnpackTuple(args, "MediaFormatVideoVector___setslice__", 0, 4, argv))) SWIG_fail;
  --argc;
  if (argc == 3) {
    int _v;
    int res = swig::asptr(argv[0], (std::vector< pj::MediaFormatVideo,std::allocator< pj::MediaFormatVideo > >**)(0));
    _v = SWIG_CheckState(res);
    if (_v) {
      {
        int res = SWIG_AsVal_ptrdiff_t(argv[1], NULL);
        _v = SWIG_CheckState(res);
      }
      if (_v) {
        {
          int res = SWIG_AsVal_ptrdiff_t(argv[2], NULL);
          _v = SWIG_CheckState(res);
        }
        if (_v) {
          return _wrap_MediaFormatVideoVector___setslice____SWIG_0(self, argc, argv);
        }
      }
    }
  }
  if (argc == 4) {
    int _v;
    int res = swig::asptr(argv[0], (std::vector< pj::MediaFormatVideo,std::allocator< pj::MediaFormatVideo > >**)(0));
    _v = SWIG_CheckState(res);
    if (_v) {
      {
        int res = SWIG_AsVal_ptrdiff_t(argv[1], NULL);
        _v = SWIG_CheckState(res);
      }
      if (_v) {
        {
          int res = SWIG_AsVal_ptrdiff_t(argv[2], NULL);
          _v = SWIG_CheckState(res);
        }
        if (_v) {
          int res = swig::asptr(argv[3], (std::vector< pj::MediaFormatVideo,std::allocator< pj::MediaFormatVideo > >**)(0));
          _v = SWIG_CheckState(res);
          if (_v) {
            return _wrap_MediaFormatVideoVector___setslice____SWIG_1(self, argc, argv);
          }
        }
      }
    }
  }
  
fail:
  SWIG_Python_RaiseOrModifyTypeError("Wrong number or type of arguments for overloaded function 'MediaFormatVideoVector___setslice__'.\n"
    "  Possible C/C++ prototypes are:\n"
    "    std::vector< pj::MediaFormatVideo >::__setslice__(std::vector< pj::MediaFormatVideo >::difference_type,std::vector< pj::MediaFormatVideo >::difference_type)\n"
    "    std::vector< pj::MediaFormatVideo >::__setslice__(std::vector< pj::MediaFormatVideo >::difference_type,std::vector< pj::MediaFormatVideo >::difference_type,std::vector< pj::MediaFormatVideo,std::allocator< pj::MediaFormatVideo > > const &)\n");
  return 0;
}


SWIGINTERN PyObject *_wrap_MediaFormatVideoVector___delslice__(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  std::vector< pj::MediaFormatVideo > *arg1 = (std::vector< pj::MediaFormatVideo > *) 0 ;
  std::vector< pj::MediaFormatVideo >::difference_type arg2 ;
  std::vector< pj::MediaFormatVideo >::difference_type arg3 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  ptrdiff_t val2 ;
  int ecode2 = 0 ;
  ptrdiff_t val3 ;
  int ecode3 = 0 ;
  PyObject *swig_obj[3] ;
  
  if (!SWIG_Python_UnpackTuple(args, "MediaFormatVideoVector___delslice__", 3, 3, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__vectorT_pj__MediaFormatVideo_std__allocatorT_pj__MediaFormatVideo_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "MediaFormatVideoVector___delslice__" "', argument " "1"" of type '" "std::vector< pj::MediaFormatVideo > *""'"); 
  }
  arg1 = reinterpret_cast< std::vector< pj::MediaFormatVideo > * >(argp1);
  ecode2 = SWIG_AsVal_ptrdiff_t(swig_obj[1], &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "MediaFormatVideoVector___delslice__" "', argument " "2"" of type '" "std::vector< pj::MediaFormatVideo >::difference_type""'");
  } 
  arg2 = static_cast< std::vector< pj::MediaFormatVideo >::difference_type >(val2);
  ecode3 = SWIG_AsVal_ptrdiff_t(swig_obj[2], &val3);
  if (!SWIG_IsOK(ecode3)) {
    SWIG_exception_fail(SWIG_ArgError(ecode3), "in method '" "MediaFormatVideoVector___delslice__" "', argument " "3"" of type '" "std::vector< pj::MediaFormatVideo >::difference_type""'");
  } 
  arg3 = static_cast< std::vector< pj::MediaFormatVideo >::difference_type >(val3);
  try {
    std_vector_Sl_pj_MediaFormatVideo_Sg____delslice__(arg1,arg2,arg3);
  } catch(std::out_of_range &_e) {
    SWIG_exception_fail(SWIG_IndexError, (&_e)->what());
  } catch(std::invalid_argument &_e) {
    SWIG_exception_fail(SWIG_ValueError, (&_e)->what());
  }
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_MediaFormatVideoVector___delitem____SWIG_0(PyObject *SWIGUNUSEDPARM(self), Py_ssize_t nobjs, PyObject **swig_obj) {
  PyObject *resultobj = 0;
  std::vector< pj::MediaFormatVideo > *arg1 = (std::vector< pj::MediaFormatVideo > *) 0 ;
  std::vector< pj::MediaFormatVideo >::difference_type arg2 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  ptrdiff_t val2 ;
  int ecode2 = 0 ;
  
  if ((nobjs < 2) || (nobjs > 2)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__vectorT_pj__MediaFormatVideo_std__allocatorT_pj__MediaFormatVideo_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "MediaFormatVideoVector___delitem__" "', argument " "1"" of type '" "std::vector< pj::MediaFormatVideo > *""'"); 
  }
  arg1 = reinterpret_cast< std::vector< pj::MediaFormatVideo > * >(argp1);
  ecode2 = SWIG_AsVal_ptrdiff_t(swig_obj[1], &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "MediaFormatVideoVector___delitem__" "', argument " "2"" of type '" "std::vector< pj::MediaFormatVideo >::difference_type""'");
  } 
  arg2 = static_cast< std::vector< pj::MediaFormatVideo >::difference_type >(val2);
  try {
    std_vector_Sl_pj_MediaFormatVideo_Sg____delitem____SWIG_0(arg1,arg2);
  } catch(std::out_of_range &_e) {
    SWIG_exception_fail(SWIG_IndexError, (&_e)->what());
  } catch(std::invalid_argument &_e) {
    SWIG_exception_fail(SWIG_ValueError, (&_e)->what());
  }
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_MediaFormatVideoVector___getitem____SWIG_0(PyObject *SWIGUNUSEDPARM(self), Py_ssize_t nobjs, PyObject **swig_obj) {
  PyObject *resultobj = 0;
  std::vector< pj::MediaFormatVideo > *arg1 = (std::vector< pj::MediaFormatVideo > *) 0 ;
  PySliceObject *arg2 = (PySliceObject *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  std::vector< pj::MediaFormatVideo,std::allocator< pj::MediaFormatVideo > > *result = 0 ;
  
  if ((nobjs < 2) || (nobjs > 2)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__vectorT_pj__MediaFormatVideo_std__allocatorT_pj__MediaFormatVideo_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "MediaFormatVideoVector___getitem__" "', argument " "1"" of type '" "std::vector< pj::MediaFormatVideo > *""'"); 
  }
  arg1 = reinterpret_cast< std::vector< pj::MediaFormatVideo > * >(argp1);
  {
    if (!PySlice_Check(swig_obj[1])) {
      SWIG_exception_fail(SWIG_ArgError(SWIG_TypeError), "in method '" "MediaFormatVideoVector___getitem__" "', argument " "2"" of type '" "PySliceObject *""'");
    }
    arg2 = (PySliceObject *) swig_obj[1];
  }
  try {
    result = (std::vector< pj::MediaFormatVideo,std::allocator< pj::MediaFormatVideo > > *)std_vector_Sl_pj_MediaFormatVideo_Sg____getitem____SWIG_0(arg1,arg2);
  } catch(std::out_of_range &_e) {
    SWIG_exception_fail(SWIG_IndexError, (&_e)->what());
  } catch(std::invalid_argument &_e) {
    SWIG_exception_fail(SWIG_ValueError, (&_e)->what());
  }
  resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(result), SWIGTYPE_p_std__vectorT_pj__MediaFormatVideo_std__allocatorT_pj__MediaFormatVideo_t_t, SWIG_POINTER_OWN |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_MediaFormatVideoVector___setitem____SWIG_0(PyObject *SWIGUNUSEDPARM(self), Py_ssize_t nobjs, PyObject **swig_obj) {
  PyObject *resultobj = 0;
  std::vector< pj::MediaFormatVideo > *arg1 = (std::vector< pj::MediaFormatVideo > *) 0 ;
  PySliceObject *arg2 = (PySliceObject *) 0 ;
  std::vector< pj::MediaFormatVideo,std::allocator< pj::MediaFormatVideo > > *arg3 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  int res3 = SWIG_OLDOBJ ;
  
  if ((nobjs < 3) || (nobjs > 3)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__vectorT_pj__MediaFormatVideo_std__allocatorT_pj__MediaFormatVideo_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "MediaFormatVideoVector___setitem__" "', argument " "1"" of type '" "std::vector< pj::MediaFormatVideo > *""'"); 
  }
  arg1 = reinterpret_cast< std::vector< pj::MediaFormatVideo > * >(argp1);
  {
    if (!PySlice_Check(swig_obj[1])) {
      SWIG_exception_fail(SWIG_ArgError(SWIG_TypeError), "in method '" "MediaFormatVideoVector___setitem__" "', argument " "2"" of type '" "PySliceObject *""'");
    }
    arg2 = (PySliceObject *) swig_obj[1];
  }
  {
    std::vector< pj::MediaFormatVideo,std::allocator< pj::MediaFormatVideo > > *ptr = (std::vector< pj::MediaFormatVideo,std::allocator< pj::MediaFormatVideo > > *)0;
    res3 = swig::asptr(swig_obj[2], &ptr);
    if (!SWIG_IsOK(res3)) {
      SWIG_exception_fail(SWIG_ArgError(res3), "in method '" "MediaFormatVideoVector___setitem__" "', argument " "3"" of type '" "std::vector< pj::MediaFormatVideo,std::allocator< pj::MediaFormatVideo > > const &""'"); 
    }
    if (!ptr) {
      SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "MediaFormatVideoVector___setitem__" "', argument " "3"" of type '" "std::vector< pj::MediaFormatVideo,std::allocator< pj::MediaFormatVideo > > const &""'"); 
    }
    arg3 = ptr;
  }
  try {
    std_vector_Sl_pj_MediaFormatVideo_Sg____setitem____SWIG_0(arg1,arg2,(std::vector< pj::MediaFormatVideo,std::allocator< pj::MediaFormatVideo > > const &)*arg3);
  } catch(std::out_of_range &_e) {
    SWIG_exception_fail(SWIG_IndexError, (&_e)->what());
  } catch(std::invalid_argument &_e) {
    SWIG_exception_fail(SWIG_ValueError, (&_e)->what());
  }
  resultobj = SWIG_Py_Void();
  if (SWIG_IsNewObj(res3)) delete arg3;
  return resultobj;
fail:
  if (SWIG_IsNewObj(res3)) delete arg3;
  return NULL;
}


SWIGINTERN PyObject *_wrap_MediaFormatVideoVector___setitem____SWIG_1(PyObject *SWIGUNUSEDPARM(self), Py_ssize_t nobjs, PyObject **swig_obj) {
  PyObject *resultobj = 0;
  std::vector< pj::MediaFormatVideo > *arg1 = (std::vector< pj::MediaFormatVideo > *) 0 ;
  PySliceObject *arg2 = (PySliceObject *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  
  if ((nobjs < 2) || (nobjs > 2)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__vectorT_pj__MediaFormatVideo_std__allocatorT_pj__MediaFormatVideo_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "MediaFormatVideoVector___setitem__" "', argument " "1"" of type '" "std::vector< pj::MediaFormatVideo > *""'"); 
  }
  arg1 = reinterpret_cast< std::vector< pj::MediaFormatVideo > * >(argp1);
  {
    if (!PySlice_Check(swig_obj[1])) {
      SWIG_exception_fail(SWIG_ArgError(SWIG_TypeError), "in method '" "MediaFormatVideoVector___setitem__" "', argument " "2"" of type '" "PySliceObject *""'");
    }
    arg2 = (PySliceObject *) swig_obj[1];
  }
  try {
    std_vector_Sl_pj_MediaFormatVideo_Sg____setitem____SWIG_1(arg1,arg2);
  } catch(std::out_of_range &_e) {
    SWIG_exception_fail(SWIG_IndexError, (&_e)->what());
  } catch(std::invalid_argument &_e) {
    SWIG_exception_fail(SWIG_ValueError, (&_e)->what());
  }
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_MediaFormatVideoVector___delitem____SWIG_1(PyObject *SWIGUNUSEDPARM(self), Py_ssize_t nobjs, PyObject **swig_obj) {
  PyObject *resultobj = 0;
  std::vector< pj::MediaFormatVideo > *arg1 = (std::vector< pj::MediaFormatVideo > *) 0 ;
  PySliceObject *arg2 = (PySliceObject *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  
  if ((nobjs < 2) || (nobjs > 2)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__vectorT_pj__MediaFormatVideo_std__allocatorT_pj__MediaFormatVideo_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "MediaFormatVideoVector___delitem__" "', argument " "1"" of type '" "std::vector< pj::MediaFormatVideo > *""'"); 
  }
  arg1 = reinterpret_cast< std::vector< pj::MediaFormatVideo > * >(argp1);
  {
    if (!PySlice_Check(swig_obj[1])) {
      SWIG_exception_fail(SWIG_ArgError(SWIG_TypeError), "in method '" "MediaFormatVideoVector___delitem__" "', argument " "2"" of type '" "PySliceObject *""'");
    }
    arg2 = (PySliceObject *) swig_obj[1];
  }
  try {
    std_vector_Sl_pj_MediaFormatVideo_Sg____delitem____SWIG_1(arg1,arg2);
  } catch(std::out_of_range &_e) {
    SWIG_exception_fail(SWIG_IndexError, (&_e)->what());
  } catch(std::invalid_argument &_e) {
    SWIG_exception_fail(SWIG_ValueError, (&_e)->what());
  }
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_MediaFormatVideoVector___delitem__(PyObject *self, PyObject *args) {
  Py_ssize_t argc;
  PyObject *argv[3] = {
    0
  };
  
  if (!(argc = SWIG_Python_UnpackTuple(args, "MediaFormatVideoVector___delitem__", 0, 2, argv))) SWIG_fail;
  --argc;
  if (argc == 2) {
    int _v;
    int res = swig::asptr(argv[0], (std::vector< pj::MediaFormatVideo,std::allocator< pj::MediaFormatVideo > >**)(0));
    _v = SWIG_CheckState(res);
    if (_v) {
      {
        _v = PySlice_Check(argv[1]);
      }
      if (_v) {
        return _wrap_MediaFormatVideoVector___delitem____SWIG_1(self, argc, argv);
      }
    }
  }
  if (argc == 2) {
    int _v;
    int res = swig::asptr(argv[0], (std::vector< pj::MediaFormatVideo,std::allocator< pj::MediaFormatVideo > >**)(0));
    _v = SWIG_CheckState(res);
    if (_v) {
      {
        int res = SWIG_AsVal_ptrdiff_t(argv[1], NULL);
        _v = SWIG_CheckState(res);
      }
      if (_v) {
        return _wrap_MediaFormatVideoVector___delitem____SWIG_0(self, argc, argv);
      }
    }
  }
  
fail:
  SWIG_Python_RaiseOrModifyTypeError("Wrong number or type of arguments for overloaded function 'MediaFormatVideoVector___delitem__'.\n"
    "  Possible C/C++ prototypes are:\n"
    "    std::vector< pj::MediaFormatVideo >::__delitem__(std::vector< pj::MediaFormatVideo >::difference_type)\n"
    "    std::vector< pj::MediaFormatVideo >::__delitem__(PySliceObject *)\n");
  return 0;
}


SWIGINTERN PyObject *_wrap_MediaFormatVideoVector___getitem____SWIG_1(PyObject *SWIGUNUSEDPARM(self), Py_ssize_t nobjs, PyObject **swig_obj) {
  PyObject *resultobj = 0;
  std::vector< pj::MediaFormatVideo > *arg1 = (std::vector< pj::MediaFormatVideo > *) 0 ;
  std::vector< pj::MediaFormatVideo >::difference_type arg2 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  ptrdiff_t val2 ;
  int ecode2 = 0 ;
  std::vector< pj::MediaFormatVideo >::value_type *result = 0 ;
  
  if ((nobjs < 2) || (nobjs > 2)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__vectorT_pj__MediaFormatVideo_std__allocatorT_pj__MediaFormatVideo_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "MediaFormatVideoVector___getitem__" "', argument " "1"" of type '" "std::vector< pj::MediaFormatVideo > const *""'"); 
  }
  arg1 = reinterpret_cast< std::vector< pj::MediaFormatVideo > * >(argp1);
  ecode2 = SWIG_AsVal_ptrdiff_t(swig_obj[1], &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "MediaFormatVideoVector___getitem__" "', argument " "2"" of type '" "std::vector< pj::MediaFormatVideo >::difference_type""'");
  } 
  arg2 = static_cast< std::vector< pj::MediaFormatVideo >::difference_type >(val2);
  try {
    result = (std::vector< pj::MediaFormatVideo >::value_type *) &std_vector_Sl_pj_MediaFormatVideo_Sg____getitem____SWIG_1((std::vector< pj::MediaFormatVideo > const *)arg1,arg2);
  } catch(std::out_of_range &_e) {
    SWIG_exception_fail(SWIG_IndexError, (&_e)->what());
  }
  resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(result), SWIGTYPE_p_pj__MediaFormatVideo, 0 |  0 );
  (void)swig::container_owner<swig::traits<std::vector< pj::MediaFormatVideo >::value_type>::category>::back_reference(resultobj, swig_obj[0]);
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_MediaFormatVideoVector___getitem__(PyObject *self, PyObject *args) {
  Py_ssize_t argc;
  PyObject *argv[3] = {
    0
  };
  
  if (!(argc = SWIG_Python_UnpackTuple(args, "MediaFormatVideoVector___getitem__", 0, 2, argv))) SWIG_fail;
  --argc;
  if (argc == 2) {
    int _v;
    int res = swig::asptr(argv[0], (std::vector< pj::MediaFormatVideo,std::allocator< pj::MediaFormatVideo > >**)(0));
    _v = SWIG_CheckState(res);
    if (_v) {
      {
        _v = PySlice_Check(argv[1]);
      }
      if (_v) {
        return _wrap_MediaFormatVideoVector___getitem____SWIG_0(self, argc, argv);
      }
    }
  }
  if (argc == 2) {
    int _v;
    int res = swig::asptr(argv[0], (std::vector< pj::MediaFormatVideo,std::allocator< pj::MediaFormatVideo > >**)(0));
    _v = SWIG_CheckState(res);
    if (_v) {
      {
        int res = SWIG_AsVal_ptrdiff_t(argv[1], NULL);
        _v = SWIG_CheckState(res);
      }
      if (_v) {
        return _wrap_MediaFormatVideoVector___getitem____SWIG_1(self, argc, argv);
      }
    }
  }
  
fail:
  SWIG_Python_RaiseOrModifyTypeError("Wrong number or type of arguments for overloaded function 'MediaFormatVideoVector___getitem__'.\n"
    "  Possible C/C++ prototypes are:\n"
    "    std::vector< pj::MediaFormatVideo >::__getitem__(PySliceObject *)\n"
    "    std::vector< pj::MediaFormatVideo >::__getitem__(std::vector< pj::MediaFormatVideo >::difference_type) const\n");
  return 0;
}


SWIGINTERN PyObject *_wrap_MediaFormatVideoVector___setitem____SWIG_2(PyObject *SWIGUNUSEDPARM(self), Py_ssize_t nobjs, PyObject **swig_obj) {
  PyObject *resultobj = 0;
  std::vector< pj::MediaFormatVideo > *arg1 = (std::vector< pj::MediaFormatVideo > *) 0 ;
  std::vector< pj::MediaFormatVideo >::difference_type arg2 ;
  std::vector< pj::MediaFormatVideo >::value_type *arg3 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  ptrdiff_t val2 ;
  int ecode2 = 0 ;
  void *argp3 = 0 ;
  int res3 = 0 ;
  
  if ((nobjs < 3) || (nobjs > 3)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__vectorT_pj__MediaFormatVideo_std__allocatorT_pj__MediaFormatVideo_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "MediaFormatVideoVector___setitem__" "', argument " "1"" of type '" "std::vector< pj::MediaFormatVideo > *""'"); 
  }
  arg1 = reinterpret_cast< std::vector< pj::MediaFormatVideo > * >(argp1);
  ecode2 = SWIG_AsVal_ptrdiff_t(swig_obj[1], &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "MediaFormatVideoVector___setitem__" "', argument " "2"" of type '" "std::vector< pj::MediaFormatVideo >::difference_type""'");
  } 
  arg2 = static_cast< std::vector< pj::MediaFormatVideo >::difference_type >(val2);
  res3 = SWIG_ConvertPtr(swig_obj[2], &argp3, SWIGTYPE_p_pj__MediaFormatVideo,  0  | 0);
  if (!SWIG_IsOK(res3)) {
    SWIG_exception_fail(SWIG_ArgError(res3), "in method '" "MediaFormatVideoVector___setitem__" "', argument " "3"" of type '" "std::vector< pj::MediaFormatVideo >::value_type const &""'"); 
  }
  if (!argp3) {
    SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "MediaFormatVideoVector___setitem__" "', argument " "3"" of type '" "std::vector< pj::MediaFormatVideo >::value_type const &""'"); 
  }
  arg3 = reinterpret_cast< std::vector< pj::MediaFormatVideo >::value_type * >(argp3);
  try {
    std_vector_Sl_pj_MediaFormatVideo_Sg____setitem____SWIG_2(arg1,arg2,(pj::MediaFormatVideo const &)*arg3);
  } catch(std::out_of_range &_e) {
    SWIG_exception_fail(SWIG_IndexError, (&_e)->what());
  }
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_MediaFormatVideoVector___setitem__(PyObject *self, PyObject *args) {
  Py_ssize_t argc;
  PyObject *argv[4] = {
    0
  };
  
  if (!(argc = SWIG_Python_UnpackTuple(args, "MediaFormatVideoVector___setitem__", 0, 3, argv))) SWIG_fail;
  --argc;
  if (argc == 2) {
    int _v;
    int res = swig::asptr(argv[0], (std::vector< pj::MediaFormatVideo,std::allocator< pj::MediaFormatVideo > >**)(0));
    _v = SWIG_CheckState(res);
    if (_v) {
      {
        _v = PySlice_Check(argv[1]);
      }
      if (_v) {
        return _wrap_MediaFormatVideoVector___setitem____SWIG_1(self, argc, argv);
      }
    }
  }
  if (argc == 3) {
    int _v;
    int res = swig::asptr(argv[0], (std::vector< pj::MediaFormatVideo,std::allocator< pj::MediaFormatVideo > >**)(0));
    _v = SWIG_CheckState(res);
    if (_v) {
      {
        _v = PySlice_Check(argv[1]);
      }
      if (_v) {
        int res = swig::asptr(argv[2], (std::vector< pj::MediaFormatVideo,std::allocator< pj::MediaFormatVideo > >**)(0));
        _v = SWIG_CheckState(res);
        if (_v) {
          return _wrap_MediaFormatVideoVector___setitem____SWIG_0(self, argc, argv);
        }
      }
    }
  }
  if (argc == 3) {
    int _v;
    int res = swig::asptr(argv[0], (std::vector< pj::MediaFormatVideo,std::allocator< pj::MediaFormatVideo > >**)(0));
    _v = SWIG_CheckState(res);
    if (_v) {
      {
        int res = SWIG_AsVal_ptrdiff_t(argv[1], NULL);
        _v = SWIG_CheckState(res);
      }
      if (_v) {
        int res = SWIG_ConvertPtr(argv[2], 0, SWIGTYPE_p_pj__MediaFormatVideo, SWIG_POINTER_NO_NULL | 0);
        _v = SWIG_CheckState(res);
        if (_v) {
          return _wrap_MediaFormatVideoVector___setitem____SWIG_2(self, argc, argv);
        }
      }
    }
  }
  
fail:
  SWIG_Python_RaiseOrModifyTypeError("Wrong number or type of arguments for overloaded function 'MediaFormatVideoVector___setitem__'.\n"
    "  Possible C/C++ prototypes are:\n"
    "    std::vector< pj::MediaFormatVideo >::__setitem__(PySliceObject *,std::vector< pj::MediaFormatVideo,std::allocator< pj::MediaFormatVideo > > const &)\n"
    "    std::vector< pj::MediaFormatVideo >::__setitem__(PySliceObject *)\n"
    "    std::vector< pj::MediaFormatVideo >::__setitem__(std::vector< pj::MediaFormatVideo >::difference_type,std::vector< pj::MediaFormatVideo >::value_type const &)\n");
  return 0;
}


SWIGINTERN PyObject *_wrap_MediaFormatVideoVector_pop(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  std::vector< pj::MediaFormatVideo > *arg1 = (std::vector< pj::MediaFormatVideo > *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  std::vector< pj::MediaFormatVideo >::value_type result;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__vectorT_pj__MediaFormatVideo_std__allocatorT_pj__MediaFormatVideo_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "MediaFormatVideoVector_pop" "', argument " "1"" of type '" "std::vector< pj::MediaFormatVideo > *""'"); 
  }
  arg1 = reinterpret_cast< std::vector< pj::MediaFormatVideo > * >(argp1);
  try {
    result = std_vector_Sl_pj_MediaFormatVideo_Sg__pop(arg1);
  } catch(std::out_of_range &_e) {
    SWIG_exception_fail(SWIG_IndexError, (&_e)->what());
  }
  resultobj = SWIG_NewPointerObj((new std::vector< pj::MediaFormatVideo >::value_type(static_cast< const std::vector< pj::MediaFormatVideo >::value_type& >(result))), SWIGTYPE_p_pj__MediaFormatVideo, SWIG_POINTER_OWN |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_MediaFormatVideoVector_append(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  std::vector< pj::MediaFormatVideo > *arg1 = (std::vector< pj::MediaFormatVideo > *) 0 ;
  std::vector< pj::MediaFormatVideo >::value_type *arg2 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  void *argp2 = 0 ;
  int res2 = 0 ;
  PyObject *swig_obj[2] ;
  
  if (!SWIG_Python_UnpackTuple(args, "MediaFormatVideoVector_append", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__vectorT_pj__MediaFormatVideo_std__allocatorT_pj__MediaFormatVideo_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "MediaFormatVideoVector_append" "', argument " "1"" of type '" "std::vector< pj::MediaFormatVideo > *""'"); 
  }
  arg1 = reinterpret_cast< std::vector< pj::MediaFormatVideo > * >(argp1);
  res2 = SWIG_ConvertPtr(swig_obj[1], &argp2, SWIGTYPE_p_pj__MediaFormatVideo,  0  | 0);
  if (!SWIG_IsOK(res2)) {
    SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "MediaFormatVideoVector_append" "', argument " "2"" of type '" "std::vector< pj::MediaFormatVideo >::value_type const &""'"); 
  }
  if (!argp2) {
    SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "MediaFormatVideoVector_append" "', argument " "2"" of type '" "std::vector< pj::MediaFormatVideo >::value_type const &""'"); 
  }
  arg2 = reinterpret_cast< std::vector< pj::MediaFormatVideo >::value_type * >(argp2);
  std_vector_Sl_pj_MediaFormatVideo_Sg__append(arg1,(pj::MediaFormatVideo const &)*arg2);
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_new_MediaFormatVideoVector__SWIG_0(PyObject *SWIGUNUSEDPARM(self), Py_ssize_t nobjs, PyObject **SWIGUNUSEDPARM(swig_obj)) {
  PyObject *resultobj = 0;
  std::vector< pj::MediaFormatVideo > *result = 0 ;
  
  if ((nobjs < 0) || (nobjs > 0)) SWIG_fail;
  result = (std::vector< pj::MediaFormatVideo > *)new std::vector< pj::MediaFormatVideo >();
  resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(result), SWIGTYPE_p_std__vectorT_pj__MediaFormatVideo_std__allocatorT_pj__MediaFormatVideo_t_t, SWIG_POINTER_NEW |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_new_MediaFormatVideoVector__SWIG_1(PyObject *SWIGUNUSEDPARM(self), Py_ssize_t nobjs, PyObject **swig_obj) {
  PyObject *resultobj = 0;
  std::vector< pj::MediaFormatVideo > *arg1 = 0 ;
  int res1 = SWIG_OLDOBJ ;
  std::vector< pj::MediaFormatVideo > *result = 0 ;
  
  if ((nobjs < 1) || (nobjs > 1)) SWIG_fail;
  {
    std::vector< pj::MediaFormatVideo,std::allocator< pj::MediaFormatVideo > > *ptr = (std::vector< pj::MediaFormatVideo,std::allocator< pj::MediaFormatVideo > > *)0;
    res1 = swig::asptr(swig_obj[0], &ptr);
    if (!SWIG_IsOK(res1)) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "new_MediaFormatVideoVector" "', argument " "1"" of type '" "std::vector< pj::MediaFormatVideo > const &""'"); 
    }
    if (!ptr) {
      SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "new_MediaFormatVideoVector" "', argument " "1"" of type '" "std::vector< pj::MediaFormatVideo > const &""'"); 
    }
    arg1 = ptr;
  }
  result = (std::vector< pj::MediaFormatVideo > *)new std::vector< pj::MediaFormatVideo >((std::vector< pj::MediaFormatVideo > const &)*arg1);
  resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(result), SWIGTYPE_p_std__vectorT_pj__MediaFormatVideo_std__allocatorT_pj__MediaFormatVideo_t_t, SWIG_POINTER_NEW |  0 );
  if (SWIG_IsNewObj(res1)) delete arg1;
  return resultobj;
fail:
  if (SWIG_IsNewObj(res1)) delete arg1;
  return NULL;
}


SWIGINTERN PyObject *_wrap_MediaFormatVideoVector_empty(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  std::vector< pj::MediaFormatVideo > *arg1 = (std::vector< pj::MediaFormatVideo > *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  bool result;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__vectorT_pj__MediaFormatVideo_std__allocatorT_pj__MediaFormatVideo_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "MediaFormatVideoVector_empty" "', argument " "1"" of type '" "std::vector< pj::MediaFormatVideo > const *""'"); 
  }
  arg1 = reinterpret_cast< std::vector< pj::MediaFormatVideo > * >(argp1);
  result = (bool)((std::vector< pj::MediaFormatVideo > const *)arg1)->empty();
  resultobj = SWIG_From_bool(static_cast< bool >(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_MediaFormatVideoVector_size(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  std::vector< pj::MediaFormatVideo > *arg1 = (std::vector< pj::MediaFormatVideo > *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  std::vector< pj::MediaFormatVideo >::size_type result;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__vectorT_pj__MediaFormatVideo_std__allocatorT_pj__MediaFormatVideo_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "MediaFormatVideoVector_size" "', argument " "1"" of type '" "std::vector< pj::MediaFormatVideo > const *""'"); 
  }
  arg1 = reinterpret_cast< std::vector< pj::MediaFormatVideo > * >(argp1);
  result = ((std::vector< pj::MediaFormatVideo > const *)arg1)->size();
  resultobj = SWIG_From_size_t(static_cast< size_t >(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_MediaFormatVideoVector_swap(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  std::vector< pj::MediaFormatVideo > *arg1 = (std::vector< pj::MediaFormatVideo > *) 0 ;
  std::vector< pj::MediaFormatVideo > *arg2 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  void *argp2 = 0 ;
  int res2 = 0 ;
  PyObject *swig_obj[2] ;
  
  if (!SWIG_Python_UnpackTuple(args, "MediaFormatVideoVector_swap", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__vectorT_pj__MediaFormatVideo_std__allocatorT_pj__MediaFormatVideo_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "MediaFormatVideoVector_swap" "', argument " "1"" of type '" "std::vector< pj::MediaFormatVideo > *""'"); 
  }
  arg1 = reinterpret_cast< std::vector< pj::MediaFormatVideo > * >(argp1);
  res2 = SWIG_ConvertPtr(swig_obj[1], &argp2, SWIGTYPE_p_std__vectorT_pj__MediaFormatVideo_std__allocatorT_pj__MediaFormatVideo_t_t,  0 );
  if (!SWIG_IsOK(res2)) {
    SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "MediaFormatVideoVector_swap" "', argument " "2"" of type '" "std::vector< pj::MediaFormatVideo > &""'"); 
  }
  if (!argp2) {
    SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "MediaFormatVideoVector_swap" "', argument " "2"" of type '" "std::vector< pj::MediaFormatVideo > &""'"); 
  }
  arg2 = reinterpret_cast< std::vector< pj::MediaFormatVideo > * >(argp2);
  (arg1)->swap(*arg2);
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_MediaFormatVideoVector_begin(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  std::vector< pj::MediaFormatVideo > *arg1 = (std::vector< pj::MediaFormatVideo > *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  std::vector< pj::MediaFormatVideo >::iterator result;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__vectorT_pj__MediaFormatVideo_std__allocatorT_pj__MediaFormatVideo_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "MediaFormatVideoVector_begin" "', argument " "1"" of type '" "std::vector< pj::MediaFormatVideo > *""'"); 
  }
  arg1 = reinterpret_cast< std::vector< pj::MediaFormatVideo > * >(argp1);
  result = (arg1)->begin();
  resultobj = SWIG_NewPointerObj(swig::make_output_iterator(static_cast< const std::vector< pj::MediaFormatVideo >::iterator & >(result)),
    swig::SwigPyIterator::descriptor(),SWIG_POINTER_OWN);
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_MediaFormatVideoVector_end(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  std::vector< pj::MediaFormatVideo > *arg1 = (std::vector< pj::MediaFormatVideo > *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  std::vector< pj::MediaFormatVideo >::iterator result;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__vectorT_pj__MediaFormatVideo_std__allocatorT_pj__MediaFormatVideo_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "MediaFormatVideoVector_end" "', argument " "1"" of type '" "std::vector< pj::MediaFormatVideo > *""'"); 
  }
  arg1 = reinterpret_cast< std::vector< pj::MediaFormatVideo > * >(argp1);
  result = (arg1)->end();
  resultobj = SWIG_NewPointerObj(swig::make_output_iterator(static_cast< const std::vector< pj::MediaFormatVideo >::iterator & >(result)),
    swig::SwigPyIterator::descriptor(),SWIG_POINTER_OWN);
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_MediaFormatVideoVector_rbegin(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  std::vector< pj::MediaFormatVideo > *arg1 = (std::vector< pj::MediaFormatVideo > *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  std::vector< pj::MediaFormatVideo >::reverse_iterator result;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__vectorT_pj__MediaFormatVideo_std__allocatorT_pj__MediaFormatVideo_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "MediaFormatVideoVector_rbegin" "', argument " "1"" of type '" "std::vector< pj::MediaFormatVideo > *""'"); 
  }
  arg1 = reinterpret_cast< std::vector< pj::MediaFormatVideo > * >(argp1);
  result = (arg1)->rbegin();
  resultobj = SWIG_NewPointerObj(swig::make_output_iterator(static_cast< const std::vector< pj::MediaFormatVideo >::reverse_iterator & >(result)),
    swig::SwigPyIterator::descriptor(),SWIG_POINTER_OWN);
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_MediaFormatVideoVector_rend(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  std::vector< pj::MediaFormatVideo > *arg1 = (std::vector< pj::MediaFormatVideo > *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  std::vector< pj::MediaFormatVideo >::reverse_iterator result;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__vectorT_pj__MediaFormatVideo_std__allocatorT_pj__MediaFormatVideo_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "MediaFormatVideoVector_rend" "', argument " "1"" of type '" "std::vector< pj::MediaFormatVideo > *""'"); 
  }
  arg1 = reinterpret_cast< std::vector< pj::MediaFormatVideo > * >(argp1);
  result = (arg1)->rend();
  resultobj = SWIG_NewPointerObj(swig::make_output_iterator(static_cast< const std::vector< pj::MediaFormatVideo >::reverse_iterator & >(result)),
    swig::SwigPyIterator::descriptor(),SWIG_POINTER_OWN);
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_MediaFormatVideoVector_clear(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  std::vector< pj::MediaFormatVideo > *arg1 = (std::vector< pj::MediaFormatVideo > *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__vectorT_pj__MediaFormatVideo_std__allocatorT_pj__MediaFormatVideo_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "MediaFormatVideoVector_clear" "', argument " "1"" of type '" "std::vector< pj::MediaFormatVideo > *""'"); 
  }
  arg1 = reinterpret_cast< std::vector< pj::MediaFormatVideo > * >(argp1);
  (arg1)->clear();
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_MediaFormatVideoVector_get_allocator(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  std::vector< pj::MediaFormatVideo > *arg1 = (std::vector< pj::MediaFormatVideo > *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  SwigValueWrapper< std::allocator< pj::MediaFormatVideo > > result;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__vectorT_pj__MediaFormatVideo_std__allocatorT_pj__MediaFormatVideo_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "MediaFormatVideoVector_get_allocator" "', argument " "1"" of type '" "std::vector< pj::MediaFormatVideo > const *""'"); 
  }
  arg1 = reinterpret_cast< std::vector< pj::MediaFormatVideo > * >(argp1);
  result = ((std::vector< pj::MediaFormatVideo > const *)arg1)->get_allocator();
  resultobj = SWIG_NewPointerObj((new std::vector< pj::MediaFormatVideo >::allocator_type(static_cast< const std::vector< pj::MediaFormatVideo >::allocator_type& >(result))), SWIGTYPE_p_std__allocatorT_pj__MediaFormatVideo_t, SWIG_POINTER_OWN |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_new_MediaFormatVideoVector__SWIG_2(PyObject *SWIGUNUSEDPARM(self), Py_ssize_t nobjs, PyObject **swig_obj) {
  PyObject *resultobj = 0;
  std::vector< pj::MediaFormatVideo >::size_type arg1 ;
  size_t val1 ;
  int ecode1 = 0 ;
  std::vector< pj::MediaFormatVideo > *result = 0 ;
  
  if ((nobjs < 1) || (nobjs > 1)) SWIG_fail;
  ecode1 = SWIG_AsVal_size_t(swig_obj[0], &val1);
  if (!SWIG_IsOK(ecode1)) {
    SWIG_exception_fail(SWIG_ArgError(ecode1), "in method '" "new_MediaFormatVideoVector" "', argument " "1"" of type '" "std::vector< pj::MediaFormatVideo >::size_type""'");
  } 
  arg1 = static_cast< std::vector< pj::MediaFormatVideo >::size_type >(val1);
  result = (std::vector< pj::MediaFormatVideo > *)new std::vector< pj::MediaFormatVideo >(arg1);
  resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(result), SWIGTYPE_p_std__vectorT_pj__MediaFormatVideo_std__allocatorT_pj__MediaFormatVideo_t_t, SWIG_POINTER_NEW |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_MediaFormatVideoVector_pop_back(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  std::vector< pj::MediaFormatVideo > *arg1 = (std::vector< pj::MediaFormatVideo > *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__vectorT_pj__MediaFormatVideo_std__allocatorT_pj__MediaFormatVideo_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "MediaFormatVideoVector_pop_back" "', argument " "1"" of type '" "std::vector< pj::MediaFormatVideo > *""'"); 
  }
  arg1 = reinterpret_cast< std::vector< pj::MediaFormatVideo > * >(argp1);
  (arg1)->pop_back();
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_MediaFormatVideoVector_resize__SWIG_0(PyObject *SWIGUNUSEDPARM(self), Py_ssize_t nobjs, PyObject **swig_obj) {
  PyObject *resultobj = 0;
  std::vector< pj::MediaFormatVideo > *arg1 = (std::vector< pj::MediaFormatVideo > *) 0 ;
  std::vector< pj::MediaFormatVideo >::size_type arg2 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  size_t val2 ;
  int ecode2 = 0 ;
  
  if ((nobjs < 2) || (nobjs > 2)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__vectorT_pj__MediaFormatVideo_std__allocatorT_pj__MediaFormatVideo_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "MediaFormatVideoVector_resize" "', argument " "1"" of type '" "std::vector< pj::MediaFormatVideo > *""'"); 
  }
  arg1 = reinterpret_cast< std::vector< pj::MediaFormatVideo > * >(argp1);
  ecode2 = SWIG_AsVal_size_t(swig_obj[1], &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "MediaFormatVideoVector_resize" "', argument " "2"" of type '" "std::vector< pj::MediaFormatVideo >::size_type""'");
  } 
  arg2 = static_cast< std::vector< pj::MediaFormatVideo >::size_type >(val2);
  (arg1)->resize(arg2);
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_MediaFormatVideoVector_erase__SWIG_0(PyObject *SWIGUNUSEDPARM(self), Py_ssize_t nobjs, PyObject **swig_obj) {
  PyObject *resultobj = 0;
  std::vector< pj::MediaFormatVideo > *arg1 = (std::vector< pj::MediaFormatVideo > *) 0 ;
  std::vector< pj::MediaFormatVideo >::iterator arg2 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  swig::SwigPyIterator *iter2 = 0 ;
  int res2 ;
  std::vector< pj::MediaFormatVideo >::iterator result;
  
  if ((nobjs < 2) || (nobjs > 2)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__vectorT_pj__MediaFormatVideo_std__allocatorT_pj__MediaFormatVideo_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "MediaFormatVideoVector_erase" "', argument " "1"" of type '" "std::vector< pj::MediaFormatVideo > *""'"); 
  }
  arg1 = reinterpret_cast< std::vector< pj::MediaFormatVideo > * >(argp1);
  res2 = SWIG_ConvertPtr(swig_obj[1], SWIG_as_voidptrptr(&iter2), swig::SwigPyIterator::descriptor(), 0);
  if (!SWIG_IsOK(res2) || !iter2) {
    SWIG_exception_fail(SWIG_ArgError(SWIG_TypeError), "in method '" "MediaFormatVideoVector_erase" "', argument " "2"" of type '" "std::vector< pj::MediaFormatVideo >::iterator""'");
  } else {
    swig::SwigPyIterator_T<std::vector< pj::MediaFormatVideo >::iterator > *iter_t = dynamic_cast<swig::SwigPyIterator_T<std::vector< pj::MediaFormatVideo >::iterator > *>(iter2);
    if (iter_t) {
      arg2 = iter_t->get_current();
    } else {
      SWIG_exception_fail(SWIG_ArgError(SWIG_TypeError), "in method '" "MediaFormatVideoVector_erase" "', argument " "2"" of type '" "std::vector< pj::MediaFormatVideo >::iterator""'");
    }
  }
  result = std_vector_Sl_pj_MediaFormatVideo_Sg__erase__SWIG_0(arg1,arg2);
  resultobj = SWIG_NewPointerObj(swig::make_output_iterator(static_cast< const std::vector< pj::MediaFormatVideo >::iterator & >(result)),
    swig::SwigPyIterator::descriptor(),SWIG_POINTER_OWN);
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_MediaFormatVideoVector_erase__SWIG_1(PyObject *SWIGUNUSEDPARM(self), Py_ssize_t nobjs, PyObject **swig_obj) {
  PyObject *resultobj = 0;
  std::vector< pj::MediaFormatVideo > *arg1 = (std::vector< pj::MediaFormatVideo > *) 0 ;
  std::vector< pj::MediaFormatVideo >::iterator arg2 ;
  std::vector< pj::MediaFormatVideo >::iterator arg3 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  swig::SwigPyIterator *iter2 = 0 ;
  int res2 ;
  swig::SwigPyIterator *iter3 = 0 ;
  int res3 ;
  std::vector< pj::MediaFormatVideo >::iterator result;
  
  if ((nobjs < 3) || (nobjs > 3)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__vectorT_pj__MediaFormatVideo_std__allocatorT_pj__MediaFormatVideo_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "MediaFormatVideoVector_erase" "', argument " "1"" of type '" "std::vector< pj::MediaFormatVideo > *""'"); 
  }
  arg1 = reinterpret_cast< std::vector< pj::MediaFormatVideo > * >(argp1);
  res2 = SWIG_ConvertPtr(swig_obj[1], SWIG_as_voidptrptr(&iter2), swig::SwigPyIterator::descriptor(), 0);
  if (!SWIG_IsOK(res2) || !iter2) {
    SWIG_exception_fail(SWIG_ArgError(SWIG_TypeError), "in method '" "MediaFormatVideoVector_erase" "', argument " "2"" of type '" "std::vector< pj::MediaFormatVideo >::iterator""'");
  } else {
    swig::SwigPyIterator_T<std::vector< pj::MediaFormatVideo >::iterator > *iter_t = dynamic_cast<swig::SwigPyIterator_T<std::vector< pj::MediaFormatVideo >::iterator > *>(iter2);
    if (iter_t) {
      arg2 = iter_t->get_current();
    } else {
      SWIG_exception_fail(SWIG_ArgError(SWIG_TypeError), "in method '" "MediaFormatVideoVector_erase" "', argument " "2"" of type '" "std::vector< pj::MediaFormatVideo >::iterator""'");
    }
  }
  res3 = SWIG_ConvertPtr(swig_obj[2], SWIG_as_voidptrptr(&iter3), swig::SwigPyIterator::descriptor(), 0);
  if (!SWIG_IsOK(res3) || !iter3) {
    SWIG_exception_fail(SWIG_ArgError(SWIG_TypeError), "in method '" "MediaFormatVideoVector_erase" "', argument " "3"" of type '" "std::vector< pj::MediaFormatVideo >::iterator""'");
  } else {
    swig::SwigPyIterator_T<std::vector< pj::MediaFormatVideo >::iterator > *iter_t = dynamic_cast<swig::SwigPyIterator_T<std::vector< pj::MediaFormatVideo >::iterator > *>(iter3);
    if (iter_t) {
      arg3 = iter_t->get_current();
    } else {
      SWIG_exception_fail(SWIG_ArgError(SWIG_TypeError), "in method '" "MediaFormatVideoVector_erase" "', argument " "3"" of type '" "std::vector< pj::MediaFormatVideo >::iterator""'");
    }
  }
  result = std_vector_Sl_pj_MediaFormatVideo_Sg__erase__SWIG_1(arg1,arg2,arg3);
  resultobj = SWIG_NewPointerObj(swig::make_output_iterator(static_cast< const std::vector< pj::MediaFormatVideo >::iterator & >(result)),
    swig::SwigPyIterator::descriptor(),SWIG_POINTER_OWN);
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_MediaFormatVideoVector_erase(PyObject *self, PyObject *args) {
  Py_ssize_t argc;
  PyObject *argv[4] = {
    0
  };
  
  if (!(argc = SWIG_Python_UnpackTuple(args, "MediaFormatVideoVector_erase", 0, 3, argv))) SWIG_fail;
  --argc;
  if (argc == 2) {
    int _v;
    int res = swig::asptr(argv[0], (std::vector< pj::MediaFormatVideo,std::allocator< pj::MediaFormatVideo > >**)(0));
    _v = SWIG_CheckState(res);
    if (_v) {
      swig::SwigPyIterator *iter = 0;
      int res = SWIG_ConvertPtr(argv[1], SWIG_as_voidptrptr(&iter), swig::SwigPyIterator::descriptor(), 0);
      _v = (SWIG_IsOK(res) && iter && (dynamic_cast<swig::SwigPyIterator_T<std::vector< pj::MediaFormatVideo >::iterator > *>(iter) != 0));
      if (_v) {
        return _wrap_MediaFormatVideoVector_erase__SWIG_0(self, argc, argv);
      }
    }
  }
  if (argc == 3) {
    int _v;
    int res = swig::asptr(argv[0], (std::vector< pj::MediaFormatVideo,std::allocator< pj::MediaFormatVideo > >**)(0));
    _v = SWIG_CheckState(res);
    if (_v) {
      swig::SwigPyIterator *iter = 0;
      int res = SWIG_ConvertPtr(argv[1], SWIG_as_voidptrptr(&iter), swig::SwigPyIterator::descriptor(), 0);
      _v = (SWIG_IsOK(res) && iter && (dynamic_cast<swig::SwigPyIterator_T<std::vector< pj::MediaFormatVideo >::iterator > *>(iter) != 0));
      if (_v) {
        swig::SwigPyIterator *iter = 0;
        int res = SWIG_ConvertPtr(argv[2], SWIG_as_voidptrptr(&iter), swig::SwigPyIterator::descriptor(), 0);
        _v = (SWIG_IsOK(res) && iter && (dynamic_cast<swig::SwigPyIterator_T<std::vector< pj::MediaFormatVideo >::iterator > *>(iter) != 0));
        if (_v) {
          return _wrap_MediaFormatVideoVector_erase__SWIG_1(self, argc, argv);
        }
      }
    }
  }
  
fail:
  SWIG_Python_RaiseOrModifyTypeError("Wrong number or type of arguments for overloaded function 'MediaFormatVideoVector_erase'.\n"
    "  Possible C/C++ prototypes are:\n"
    "    std::vector< pj::MediaFormatVideo >::erase(std::vector< pj::MediaFormatVideo >::iterator)\n"
    "    std::vector< pj::MediaFormatVideo >::erase(std::vector< pj::MediaFormatVideo >::iterator,std::vector< pj::MediaFormatVideo >::iterator)\n");
  return 0;
}


SWIGINTERN PyObject *_wrap_new_MediaFormatVideoVector__SWIG_3(PyObject *SWIGUNUSEDPARM(self), Py_ssize_t nobjs, PyObject **swig_obj) {
  PyObject *resultobj = 0;
  std::vector< pj::MediaFormatVideo >::size_type arg1 ;
  std::vector< pj::MediaFormatVideo >::value_type *arg2 = 0 ;
  size_t val1 ;
  int ecode1 = 0 ;
  void *argp2 = 0 ;
  int res2 = 0 ;
  std::vector< pj::MediaFormatVideo > *result = 0 ;
  
  if ((nobjs < 2) || (nobjs > 2)) SWIG_fail;
  ecode1 = SWIG_AsVal_size_t(swig_obj[0], &val1);
  if (!SWIG_IsOK(ecode1)) {
    SWIG_exception_fail(SWIG_ArgError(ecode1), "in method '" "new_MediaFormatVideoVector" "', argument " "1"" of type '" "std::vector< pj::MediaFormatVideo >::size_type""'");
  } 
  arg1 = static_cast< std::vector< pj::MediaFormatVideo >::size_type >(val1);
  res2 = SWIG_ConvertPtr(swig_obj[1], &argp2, SWIGTYPE_p_pj__MediaFormatVideo,  0  | 0);
  if (!SWIG_IsOK(res2)) {
    SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "new_MediaFormatVideoVector" "', argument " "2"" of type '" "std::vector< pj::MediaFormatVideo >::value_type const &""'"); 
  }
  if (!argp2) {
    SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "new_MediaFormatVideoVector" "', argument " "2"" of type '" "std::vector< pj::MediaFormatVideo >::value_type const &""'"); 
  }
  arg2 = reinterpret_cast< std::vector< pj::MediaFormatVideo >::value_type * >(argp2);
  result = (std::vector< pj::MediaFormatVideo > *)new std::vector< pj::MediaFormatVideo >(arg1,(std::vector< pj::MediaFormatVideo >::value_type const &)*arg2);
  resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(result), SWIGTYPE_p_std__vectorT_pj__MediaFormatVideo_std__allocatorT_pj__MediaFormatVideo_t_t, SWIG_POINTER_NEW |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_new_MediaFormatVideoVector(PyObject *self, PyObject *args) {
  Py_ssize_t argc;
  PyObject *argv[3] = {
    0
  };
  
  if (!(argc = SWIG_Python_UnpackTuple(args, "new_MediaFormatVideoVector", 0, 2, argv))) SWIG_fail;
  --argc;
  if (argc == 0) {
    return _wrap_new_MediaFormatVideoVector__SWIG_0(self, argc, argv);
  }
  if (argc == 1) {
    int _v;
    {
      int res = SWIG_AsVal_size_t(argv[0], NULL);
      _v = SWIG_CheckState(res);
    }
    if (_v) {
      return _wrap_new_MediaFormatVideoVector__SWIG_2(self, argc, argv);
    }
  }
  if (argc == 1) {
    int _v;
    int res = swig::asptr(argv[0], (std::vector< pj::MediaFormatVideo,std::allocator< pj::MediaFormatVideo > >**)(0));
    _v = SWIG_CheckState(res);
    if (_v) {
      return _wrap_new_MediaFormatVideoVector__SWIG_1(self, argc, argv);
    }
  }
  if (argc == 2) {
    int _v;
    {
      int res = SWIG_AsVal_size_t(argv[0], NULL);
      _v = SWIG_CheckState(res);
    }
    if (_v) {
      int res = SWIG_ConvertPtr(argv[1], 0, SWIGTYPE_p_pj__MediaFormatVideo, SWIG_POINTER_NO_NULL | 0);
      _v = SWIG_CheckState(res);
      if (_v) {
        return _wrap_new_MediaFormatVideoVector__SWIG_3(self, argc, argv);
      }
    }
  }
  
fail:
  SWIG_Python_RaiseOrModifyTypeError("Wrong number or type of arguments for overloaded function 'new_MediaFormatVideoVector'.\n"
    "  Possible C/C++ prototypes are:\n"
    "    std::vector< pj::MediaFormatVideo >::vector()\n"
    "    std::vector< pj::MediaFormatVideo >::vector(std::vector< pj::MediaFormatVideo > const &)\n"
    "    std::vector< pj::MediaFormatVideo >::vector(std::vector< pj::MediaFormatVideo >::size_type)\n"
    "    std::vector< pj::MediaFormatVideo >::vector(std::vector< pj::MediaFormatVideo >::size_type,std::vector< pj::MediaFormatVideo >::value_type const &)\n");
  return 0;
}


SWIGINTERN PyObject *_wrap_MediaFormatVideoVector_push_back(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  std::vector< pj::MediaFormatVideo > *arg1 = (std::vector< pj::MediaFormatVideo > *) 0 ;
  std::vector< pj::MediaFormatVideo >::value_type *arg2 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  void *argp2 = 0 ;
  int res2 = 0 ;
  PyObject *swig_obj[2] ;
  
  if (!SWIG_Python_UnpackTuple(args, "MediaFormatVideoVector_push_back", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__vectorT_pj__MediaFormatVideo_std__allocatorT_pj__MediaFormatVideo_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "MediaFormatVideoVector_push_back" "', argument " "1"" of type '" "std::vector< pj::MediaFormatVideo > *""'"); 
  }
  arg1 = reinterpret_cast< std::vector< pj::MediaFormatVideo > * >(argp1);
  res2 = SWIG_ConvertPtr(swig_obj[1], &argp2, SWIGTYPE_p_pj__MediaFormatVideo,  0  | 0);
  if (!SWIG_IsOK(res2)) {
    SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "MediaFormatVideoVector_push_back" "', argument " "2"" of type '" "std::vector< pj::MediaFormatVideo >::value_type const &""'"); 
  }
  if (!argp2) {
    SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "MediaFormatVideoVector_push_back" "', argument " "2"" of type '" "std::vector< pj::MediaFormatVideo >::value_type const &""'"); 
  }
  arg2 = reinterpret_cast< std::vector< pj::MediaFormatVideo >::value_type * >(argp2);
  (arg1)->push_back((std::vector< pj::MediaFormatVideo >::value_type const &)*arg2);
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_MediaFormatVideoVector_front(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  std::vector< pj::MediaFormatVideo > *arg1 = (std::vector< pj::MediaFormatVideo > *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  std::vector< pj::MediaFormatVideo >::value_type *result = 0 ;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__vectorT_pj__MediaFormatVideo_std__allocatorT_pj__MediaFormatVideo_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "MediaFormatVideoVector_front" "', argument " "1"" of type '" "std::vector< pj::MediaFormatVideo > const *""'"); 
  }
  arg1 = reinterpret_cast< std::vector< pj::MediaFormatVideo > * >(argp1);
  result = (std::vector< pj::MediaFormatVideo >::value_type *) &((std::vector< pj::MediaFormatVideo > const *)arg1)->front();
  resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(result), SWIGTYPE_p_pj__MediaFormatVideo, 0 |  0 );
  (void)swig::container_owner<swig::traits<std::vector< pj::MediaFormatVideo >::value_type>::category>::back_reference(resultobj, swig_obj[0]);
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_MediaFormatVideoVector_back(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  std::vector< pj::MediaFormatVideo > *arg1 = (std::vector< pj::MediaFormatVideo > *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  std::vector< pj::MediaFormatVideo >::value_type *result = 0 ;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__vectorT_pj__MediaFormatVideo_std__allocatorT_pj__MediaFormatVideo_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "MediaFormatVideoVector_back" "', argument " "1"" of type '" "std::vector< pj::MediaFormatVideo > const *""'"); 
  }
  arg1 = reinterpret_cast< std::vector< pj::MediaFormatVideo > * >(argp1);
  result = (std::vector< pj::MediaFormatVideo >::value_type *) &((std::vector< pj::MediaFormatVideo > const *)arg1)->back();
  resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(result), SWIGTYPE_p_pj__MediaFormatVideo, 0 |  0 );
  (void)swig::container_owner<swig::traits<std::vector< pj::MediaFormatVideo >::value_type>::category>::back_reference(resultobj, swig_obj[0]);
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_MediaFormatVideoVector_assign(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  std::vector< pj::MediaFormatVideo > *arg1 = (std::vector< pj::MediaFormatVideo > *) 0 ;
  std::vector< pj::MediaFormatVideo >::size_type arg2 ;
  std::vector< pj::MediaFormatVideo >::value_type *arg3 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  size_t val2 ;
  int ecode2 = 0 ;
  void *argp3 = 0 ;
  int res3 = 0 ;
  PyObject *swig_obj[3] ;
  
  if (!SWIG_Python_UnpackTuple(args, "MediaFormatVideoVector_assign", 3, 3, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__vectorT_pj__MediaFormatVideo_std__allocatorT_pj__MediaFormatVideo_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "MediaFormatVideoVector_assign" "', argument " "1"" of type '" "std::vector< pj::MediaFormatVideo > *""'"); 
  }
  arg1 = reinterpret_cast< std::vector< pj::MediaFormatVideo > * >(argp1);
  ecode2 = SWIG_AsVal_size_t(swig_obj[1], &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "MediaFormatVideoVector_assign" "', argument " "2"" of type '" "std::vector< pj::MediaFormatVideo >::size_type""'");
  } 
  arg2 = static_cast< std::vector< pj::MediaFormatVideo >::size_type >(val2);
  res3 = SWIG_ConvertPtr(swig_obj[2], &argp3, SWIGTYPE_p_pj__MediaFormatVideo,  0  | 0);
  if (!SWIG_IsOK(res3)) {
    SWIG_exception_fail(SWIG_ArgError(res3), "in method '" "MediaFormatVideoVector_assign" "', argument " "3"" of type '" "std::vector< pj::MediaFormatVideo >::value_type const &""'"); 
  }
  if (!argp3) {
    SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "MediaFormatVideoVector_assign" "', argument " "3"" of type '" "std::vector< pj::MediaFormatVideo >::value_type const &""'"); 
  }
  arg3 = reinterpret_cast< std::vector< pj::MediaFormatVideo >::value_type * >(argp3);
  (arg1)->assign(arg2,(std::vector< pj::MediaFormatVideo >::value_type const &)*arg3);
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_MediaFormatVideoVector_resize__SWIG_1(PyObject *SWIGUNUSEDPARM(self), Py_ssize_t nobjs, PyObject **swig_obj) {
  PyObject *resultobj = 0;
  std::vector< pj::MediaFormatVideo > *arg1 = (std::vector< pj::MediaFormatVideo > *) 0 ;
  std::vector< pj::MediaFormatVideo >::size_type arg2 ;
  std::vector< pj::MediaFormatVideo >::value_type *arg3 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  size_t val2 ;
  int ecode2 = 0 ;
  void *argp3 = 0 ;
  int res3 = 0 ;
  
  if ((nobjs < 3) || (nobjs > 3)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__vectorT_pj__MediaFormatVideo_std__allocatorT_pj__MediaFormatVideo_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "MediaFormatVideoVector_resize" "', argument " "1"" of type '" "std::vector< pj::MediaFormatVideo > *""'"); 
  }
  arg1 = reinterpret_cast< std::vector< pj::MediaFormatVideo > * >(argp1);
  ecode2 = SWIG_AsVal_size_t(swig_obj[1], &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "MediaFormatVideoVector_resize" "', argument " "2"" of type '" "std::vector< pj::MediaFormatVideo >::size_type""'");
  } 
  arg2 = static_cast< std::vector< pj::MediaFormatVideo >::size_type >(val2);
  res3 = SWIG_ConvertPtr(swig_obj[2], &argp3, SWIGTYPE_p_pj__MediaFormatVideo,  0  | 0);
  if (!SWIG_IsOK(res3)) {
    SWIG_exception_fail(SWIG_ArgError(res3), "in method '" "MediaFormatVideoVector_resize" "', argument " "3"" of type '" "std::vector< pj::MediaFormatVideo >::value_type const &""'"); 
  }
  if (!argp3) {
    SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "MediaFormatVideoVector_resize" "', argument " "3"" of type '" "std::vector< pj::MediaFormatVideo >::value_type const &""'"); 
  }
  arg3 = reinterpret_cast< std::vector< pj::MediaFormatVideo >::value_type * >(argp3);
  (arg1)->resize(arg2,(std::vector< pj::MediaFormatVideo >::value_type const &)*arg3);
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_MediaFormatVideoVector_resize(PyObject *self, PyObject *args) {
  Py_ssize_t argc;
  PyObject *argv[4] = {
    0
  };
  
  if (!(argc = SWIG_Python_UnpackTuple(args, "MediaFormatVideoVector_resize", 0, 3, argv))) SWIG_fail;
  --argc;
  if (argc == 2) {
    int _v;
    int res = swig::asptr(argv[0], (std::vector< pj::MediaFormatVideo,std::allocator< pj::MediaFormatVideo > >**)(0));
    _v = SWIG_CheckState(res);
    if (_v) {
      {
        int res = SWIG_AsVal_size_t(argv[1], NULL);
        _v = SWIG_CheckState(res);
      }
      if (_v) {
        return _wrap_MediaFormatVideoVector_resize__SWIG_0(self, argc, argv);
      }
    }
  }
  if (argc == 3) {
    int _v;
    int res = swig::asptr(argv[0], (std::vector< pj::MediaFormatVideo,std::allocator< pj::MediaFormatVideo > >**)(0));
    _v = SWIG_CheckState(res);
    if (_v) {
      {
        int res = SWIG_AsVal_size_t(argv[1], NULL);
        _v = SWIG_CheckState(res);
      }
      if (_v) {
        int res = SWIG_ConvertPtr(argv[2], 0, SWIGTYPE_p_pj__MediaFormatVideo, SWIG_POINTER_NO_NULL | 0);
        _v = SWIG_CheckState(res);
        if (_v) {
          return _wrap_MediaFormatVideoVector_resize__SWIG_1(self, argc, argv);
        }
      }
    }
  }
  
fail:
  SWIG_Python_RaiseOrModifyTypeError("Wrong number or type of arguments for overloaded function 'MediaFormatVideoVector_resize'.\n"
    "  Possible C/C++ prototypes are:\n"
    "    std::vector< pj::MediaFormatVideo >::resize(std::vector< pj::MediaFormatVideo >::size_type)\n"
    "    std::vector< pj::MediaFormatVideo >::resize(std::vector< pj::MediaFormatVideo >::size_type,std::vector< pj::MediaFormatVideo >::value_type const &)\n");
  return 0;
}


SWIGINTERN PyObject *_wrap_MediaFormatVideoVector_insert__SWIG_0(PyObject *SWIGUNUSEDPARM(self), Py_ssize_t nobjs, PyObject **swig_obj) {
  PyObject *resultobj = 0;
  std::vector< pj::MediaFormatVideo > *arg1 = (std::vector< pj::MediaFormatVideo > *) 0 ;
  std::vector< pj::MediaFormatVideo >::iterator arg2 ;
  std::vector< pj::MediaFormatVideo >::value_type *arg3 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  swig::SwigPyIterator *iter2 = 0 ;
  int res2 ;
  void *argp3 = 0 ;
  int res3 = 0 ;
  std::vector< pj::MediaFormatVideo >::iterator result;
  
  if ((nobjs < 3) || (nobjs > 3)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__vectorT_pj__MediaFormatVideo_std__allocatorT_pj__MediaFormatVideo_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "MediaFormatVideoVector_insert" "', argument " "1"" of type '" "std::vector< pj::MediaFormatVideo > *""'"); 
  }
  arg1 = reinterpret_cast< std::vector< pj::MediaFormatVideo > * >(argp1);
  res2 = SWIG_ConvertPtr(swig_obj[1], SWIG_as_voidptrptr(&iter2), swig::SwigPyIterator::descriptor(), 0);
  if (!SWIG_IsOK(res2) || !iter2) {
    SWIG_exception_fail(SWIG_ArgError(SWIG_TypeError), "in method '" "MediaFormatVideoVector_insert" "', argument " "2"" of type '" "std::vector< pj::MediaFormatVideo >::iterator""'");
  } else {
    swig::SwigPyIterator_T<std::vector< pj::MediaFormatVideo >::iterator > *iter_t = dynamic_cast<swig::SwigPyIterator_T<std::vector< pj::MediaFormatVideo >::iterator > *>(iter2);
    if (iter_t) {
      arg2 = iter_t->get_current();
    } else {
      SWIG_exception_fail(SWIG_ArgError(SWIG_TypeError), "in method '" "MediaFormatVideoVector_insert" "', argument " "2"" of type '" "std::vector< pj::MediaFormatVideo >::iterator""'");
    }
  }
  res3 = SWIG_ConvertPtr(swig_obj[2], &argp3, SWIGTYPE_p_pj__MediaFormatVideo,  0  | 0);
  if (!SWIG_IsOK(res3)) {
    SWIG_exception_fail(SWIG_ArgError(res3), "in method '" "MediaFormatVideoVector_insert" "', argument " "3"" of type '" "std::vector< pj::MediaFormatVideo >::value_type const &""'"); 
  }
  if (!argp3) {
    SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "MediaFormatVideoVector_insert" "', argument " "3"" of type '" "std::vector< pj::MediaFormatVideo >::value_type const &""'"); 
  }
  arg3 = reinterpret_cast< std::vector< pj::MediaFormatVideo >::value_type * >(argp3);
  result = std_vector_Sl_pj_MediaFormatVideo_Sg__insert__SWIG_0(arg1,arg2,(pj::MediaFormatVideo const &)*arg3);
  resultobj = SWIG_NewPointerObj(swig::make_output_iterator(static_cast< const std::vector< pj::MediaFormatVideo >::iterator & >(result)),
    swig::SwigPyIterator::descriptor(),SWIG_POINTER_OWN);
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_MediaFormatVideoVector_insert__SWIG_1(PyObject *SWIGUNUSEDPARM(self), Py_ssize_t nobjs, PyObject **swig_obj) {
  PyObject *resultobj = 0;
  std::vector< pj::MediaFormatVideo > *arg1 = (std::vector< pj::MediaFormatVideo > *) 0 ;
  std::vector< pj::MediaFormatVideo >::iterator arg2 ;
  std::vector< pj::MediaFormatVideo >::size_type arg3 ;
  std::vector< pj::MediaFormatVideo >::value_type *arg4 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  swig::SwigPyIterator *iter2 = 0 ;
  int res2 ;
  size_t val3 ;
  int ecode3 = 0 ;
  void *argp4 = 0 ;
  int res4 = 0 ;
  
  if ((nobjs < 4) || (nobjs > 4)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__vectorT_pj__MediaFormatVideo_std__allocatorT_pj__MediaFormatVideo_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "MediaFormatVideoVector_insert" "', argument " "1"" of type '" "std::vector< pj::MediaFormatVideo > *""'"); 
  }
  arg1 = reinterpret_cast< std::vector< pj::MediaFormatVideo > * >(argp1);
  res2 = SWIG_ConvertPtr(swig_obj[1], SWIG_as_voidptrptr(&iter2), swig::SwigPyIterator::descriptor(), 0);
  if (!SWIG_IsOK(res2) || !iter2) {
    SWIG_exception_fail(SWIG_ArgError(SWIG_TypeError), "in method '" "MediaFormatVideoVector_insert" "', argument " "2"" of type '" "std::vector< pj::MediaFormatVideo >::iterator""'");
  } else {
    swig::SwigPyIterator_T<std::vector< pj::MediaFormatVideo >::iterator > *iter_t = dynamic_cast<swig::SwigPyIterator_T<std::vector< pj::MediaFormatVideo >::iterator > *>(iter2);
    if (iter_t) {
      arg2 = iter_t->get_current();
    } else {
      SWIG_exception_fail(SWIG_ArgError(SWIG_TypeError), "in method '" "MediaFormatVideoVector_insert" "', argument " "2"" of type '" "std::vector< pj::MediaFormatVideo >::iterator""'");
    }
  }
  ecode3 = SWIG_AsVal_size_t(swig_obj[2], &val3);
  if (!SWIG_IsOK(ecode3)) {
    SWIG_exception_fail(SWIG_ArgError(ecode3), "in method '" "MediaFormatVideoVector_insert" "', argument " "3"" of type '" "std::vector< pj::MediaFormatVideo >::size_type""'");
  } 
  arg3 = static_cast< std::vector< pj::MediaFormatVideo >::size_type >(val3);
  res4 = SWIG_ConvertPtr(swig_obj[3], &argp4, SWIGTYPE_p_pj__MediaFormatVideo,  0  | 0);
  if (!SWIG_IsOK(res4)) {
    SWIG_exception_fail(SWIG_ArgError(res4), "in method '" "MediaFormatVideoVector_insert" "', argument " "4"" of type '" "std::vector< pj::MediaFormatVideo >::value_type const &""'"); 
  }
  if (!argp4) {
    SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "MediaFormatVideoVector_insert" "', argument " "4"" of type '" "std::vector< pj::MediaFormatVideo >::value_type const &""'"); 
  }
  arg4 = reinterpret_cast< std::vector< pj::MediaFormatVideo >::value_type * >(argp4);
  std_vector_Sl_pj_MediaFormatVideo_Sg__insert__SWIG_1(arg1,arg2,arg3,(pj::MediaFormatVideo const &)*arg4);
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_MediaFormatVideoVector_insert(PyObject *self, PyObject *args) {
  Py_ssize_t argc;
  PyObject *argv[5] = {
    0
  };
  
  if (!(argc = SWIG_Python_UnpackTuple(args, "MediaFormatVideoVector_insert", 0, 4, argv))) SWIG_fail;
  --argc;
  if (argc == 3) {
    int _v;
    int res = swig::asptr(argv[0], (std::vector< pj::MediaFormatVideo,std::allocator< pj::MediaFormatVideo > >**)(0));
    _v = SWIG_CheckState(res);
    if (_v) {
      swig::SwigPyIterator *iter = 0;
      int res = SWIG_ConvertPtr(argv[1], SWIG_as_voidptrptr(&iter), swig::SwigPyIterator::descriptor(), 0);
      _v = (SWIG_IsOK(res) && iter && (dynamic_cast<swig::SwigPyIterator_T<std::vector< pj::MediaFormatVideo >::iterator > *>(iter) != 0));
      if (_v) {
        int res = SWIG_ConvertPtr(argv[2], 0, SWIGTYPE_p_pj__MediaFormatVideo, SWIG_POINTER_NO_NULL | 0);
        _v = SWIG_CheckState(res);
        if (_v) {
          return _wrap_MediaFormatVideoVector_insert__SWIG_0(self, argc, argv);
        }
      }
    }
  }
  if (argc == 4) {
    int _v;
    int res = swig::asptr(argv[0], (std::vector< pj::MediaFormatVideo,std::allocator< pj::MediaFormatVideo > >**)(0));
    _v = SWIG_CheckState(res);
    if (_v) {
      swig::SwigPyIterator *iter = 0;
      int res = SWIG_ConvertPtr(argv[1], SWIG_as_voidptrptr(&iter), swig::SwigPyIterator::descriptor(), 0);
      _v = (SWIG_IsOK(res) && iter && (dynamic_cast<swig::SwigPyIterator_T<std::vector< pj::MediaFormatVideo >::iterator > *>(iter) != 0));
      if (_v) {
        {
          int res = SWIG_AsVal_size_t(argv[2], NULL);
          _v = SWIG_CheckState(res);
        }
        if (_v) {
          int res = SWIG_ConvertPtr(argv[3], 0, SWIGTYPE_p_pj__MediaFormatVideo, SWIG_POINTER_NO_NULL | 0);
          _v = SWIG_CheckState(res);
          if (_v) {
            return _wrap_MediaFormatVideoVector_insert__SWIG_1(self, argc, argv);
          }
        }
      }
    }
  }
  
fail:
  SWIG_Python_RaiseOrModifyTypeError("Wrong number or type of arguments for overloaded function 'MediaFormatVideoVector_insert'.\n"
    "  Possible C/C++ prototypes are:\n"
    "    std::vector< pj::MediaFormatVideo >::insert(std::vector< pj::MediaFormatVideo >::iterator,std::vector< pj::MediaFormatVideo >::value_type const &)\n"
    "    std::vector< pj::MediaFormatVideo >::insert(std::vector< pj::MediaFormatVideo >::iterator,std::vector< pj::MediaFormatVideo >::size_type,std::vector< pj::MediaFormatVideo >::value_type const &)\n");
  return 0;
}


SWIGINTERN PyObject *_wrap_MediaFormatVideoVector_reserve(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  std::vector< pj::MediaFormatVideo > *arg1 = (std::vector< pj::MediaFormatVideo > *) 0 ;
  std::vector< pj::MediaFormatVideo >::size_type arg2 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  size_t val2 ;
  int ecode2 = 0 ;
  PyObject *swig_obj[2] ;
  
  if (!SWIG_Python_UnpackTuple(args, "MediaFormatVideoVector_reserve", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__vectorT_pj__MediaFormatVideo_std__allocatorT_pj__MediaFormatVideo_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "MediaFormatVideoVector_reserve" "', argument " "1"" of type '" "std::vector< pj::MediaFormatVideo > *""'"); 
  }
  arg1 = reinterpret_cast< std::vector< pj::MediaFormatVideo > * >(argp1);
  ecode2 = SWIG_AsVal_size_t(swig_obj[1], &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "MediaFormatVideoVector_reserve" "', argument " "2"" of type '" "std::vector< pj::MediaFormatVideo >::size_type""'");
  } 
  arg2 = static_cast< std::vector< pj::MediaFormatVideo >::size_type >(val2);
  (arg1)->reserve(arg2);
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_MediaFormatVideoVector_capacity(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  std::vector< pj::MediaFormatVideo > *arg1 = (std::vector< pj::MediaFormatVideo > *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  std::vector< pj::MediaFormatVideo >::size_type result;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__vectorT_pj__MediaFormatVideo_std__allocatorT_pj__MediaFormatVideo_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "MediaFormatVideoVector_capacity" "', argument " "1"" of type '" "std::vector< pj::MediaFormatVideo > const *""'"); 
  }
  arg1 = reinterpret_cast< std::vector< pj::MediaFormatVideo > * >(argp1);
  result = ((std::vector< pj::MediaFormatVideo > const *)arg1)->capacity();
  resultobj = SWIG_From_size_t(static_cast< size_t >(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_delete_MediaFormatVideoVector(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  std::vector< pj::MediaFormatVideo > *arg1 = (std::vector< pj::MediaFormatVideo > *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__vectorT_pj__MediaFormatVideo_std__allocatorT_pj__MediaFormatVideo_t_t, SWIG_POINTER_DISOWN |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "delete_MediaFormatVideoVector" "', argument " "1"" of type '" "std::vector< pj::MediaFormatVideo > *""'"); 
  }
  arg1 = reinterpret_cast< std::vector< pj::MediaFormatVideo > * >(argp1);
  delete arg1;
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *MediaFormatVideoVector_swigregister(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *obj;
  if (!SWIG_Python_UnpackTuple(args, "swigregister", 1, 1, &obj)) return NULL;
  SWIG_TypeNewClientData(SWIGTYPE_p_std__vectorT_pj__MediaFormatVideo_std__allocatorT_pj__MediaFormatVideo_t_t, SWIG_NewClientData(obj));
  return SWIG_Py_Void();
}

SWIGINTERN PyObject *MediaFormatVideoVector_swiginit(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  return SWIG_Python_InitShadowInstance(args);
}

SWIGINTERN PyObject *_wrap_CallMediaInfoVector_iterator(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  std::vector< pj::CallMediaInfo > *arg1 = (std::vector< pj::CallMediaInfo > *) 0 ;
  PyObject **arg2 = (PyObject **) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  swig::SwigPyIterator *result = 0 ;
  
  arg2 = &swig_obj[0];
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__vectorT_pj__CallMediaInfo_std__allocatorT_pj__CallMediaInfo_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "CallMediaInfoVector_iterator" "', argument " "1"" of type '" "std::vector< pj::CallMediaInfo > *""'"); 
  }
  arg1 = reinterpret_cast< std::vector< pj::CallMediaInfo > * >(argp1);
  result = (swig::SwigPyIterator *)std_vector_Sl_pj_CallMediaInfo_Sg__iterator(arg1,arg2);
  resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(result), SWIGTYPE_p_swig__SwigPyIterator, SWIG_POINTER_OWN |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_CallMediaInfoVector___nonzero__(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  std::vector< pj::CallMediaInfo > *arg1 = (std::vector< pj::CallMediaInfo > *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  bool result;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__vectorT_pj__CallMediaInfo_std__allocatorT_pj__CallMediaInfo_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "CallMediaInfoVector___nonzero__" "', argument " "1"" of type '" "std::vector< pj::CallMediaInfo > const *""'"); 
  }
  arg1 = reinterpret_cast< std::vector< pj::CallMediaInfo > * >(argp1);
  result = (bool)std_vector_Sl_pj_CallMediaInfo_Sg____nonzero__((std::vector< pj::CallMediaInfo > const *)arg1);
  resultobj = SWIG_From_bool(static_cast< bool >(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_CallMediaInfoVector___bool__(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  std::vector< pj::CallMediaInfo > *arg1 = (std::vector< pj::CallMediaInfo > *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  bool result;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__vectorT_pj__CallMediaInfo_std__allocatorT_pj__CallMediaInfo_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "CallMediaInfoVector___bool__" "', argument " "1"" of type '" "std::vector< pj::CallMediaInfo > const *""'"); 
  }
  arg1 = reinterpret_cast< std::vector< pj::CallMediaInfo > * >(argp1);
  result = (bool)std_vector_Sl_pj_CallMediaInfo_Sg____bool__((std::vector< pj::CallMediaInfo > const *)arg1);
  resultobj = SWIG_From_bool(static_cast< bool >(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_CallMediaInfoVector___len__(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  std::vector< pj::CallMediaInfo > *arg1 = (std::vector< pj::CallMediaInfo > *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  std::vector< pj::CallMediaInfo >::size_type result;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__vectorT_pj__CallMediaInfo_std__allocatorT_pj__CallMediaInfo_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "CallMediaInfoVector___len__" "', argument " "1"" of type '" "std::vector< pj::CallMediaInfo > const *""'"); 
  }
  arg1 = reinterpret_cast< std::vector< pj::CallMediaInfo > * >(argp1);
  result = std_vector_Sl_pj_CallMediaInfo_Sg____len__((std::vector< pj::CallMediaInfo > const *)arg1);
  resultobj = SWIG_From_size_t(static_cast< size_t >(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_CallMediaInfoVector___getslice__(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  std::vector< pj::CallMediaInfo > *arg1 = (std::vector< pj::CallMediaInfo > *) 0 ;
  std::vector< pj::CallMediaInfo >::difference_type arg2 ;
  std::vector< pj::CallMediaInfo >::difference_type arg3 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  ptrdiff_t val2 ;
  int ecode2 = 0 ;
  ptrdiff_t val3 ;
  int ecode3 = 0 ;
  PyObject *swig_obj[3] ;
  std::vector< pj::CallMediaInfo,std::allocator< pj::CallMediaInfo > > *result = 0 ;
  
  if (!SWIG_Python_UnpackTuple(args, "CallMediaInfoVector___getslice__", 3, 3, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__vectorT_pj__CallMediaInfo_std__allocatorT_pj__CallMediaInfo_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "CallMediaInfoVector___getslice__" "', argument " "1"" of type '" "std::vector< pj::CallMediaInfo > *""'"); 
  }
  arg1 = reinterpret_cast< std::vector< pj::CallMediaInfo > * >(argp1);
  ecode2 = SWIG_AsVal_ptrdiff_t(swig_obj[1], &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "CallMediaInfoVector___getslice__" "', argument " "2"" of type '" "std::vector< pj::CallMediaInfo >::difference_type""'");
  } 
  arg2 = static_cast< std::vector< pj::CallMediaInfo >::difference_type >(val2);
  ecode3 = SWIG_AsVal_ptrdiff_t(swig_obj[2], &val3);
  if (!SWIG_IsOK(ecode3)) {
    SWIG_exception_fail(SWIG_ArgError(ecode3), "in method '" "CallMediaInfoVector___getslice__" "', argument " "3"" of type '" "std::vector< pj::CallMediaInfo >::difference_type""'");
  } 
  arg3 = static_cast< std::vector< pj::CallMediaInfo >::difference_type >(val3);
  try {
    result = (std::vector< pj::CallMediaInfo,std::allocator< pj::CallMediaInfo > > *)std_vector_Sl_pj_CallMediaInfo_Sg____getslice__(arg1,arg2,arg3);
  } catch(std::out_of_range &_e) {
    SWIG_exception_fail(SWIG_IndexError, (&_e)->what());
  } catch(std::invalid_argument &_e) {
    SWIG_exception_fail(SWIG_ValueError, (&_e)->what());
  }
  resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(result), SWIGTYPE_p_std__vectorT_pj__CallMediaInfo_std__allocatorT_pj__CallMediaInfo_t_t, SWIG_POINTER_OWN |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_CallMediaInfoVector___setslice____SWIG_0(PyObject *SWIGUNUSEDPARM(self), Py_ssize_t nobjs, PyObject **swig_obj) {
  PyObject *resultobj = 0;
  std::vector< pj::CallMediaInfo > *arg1 = (std::vector< pj::CallMediaInfo > *) 0 ;
  std::vector< pj::CallMediaInfo >::difference_type arg2 ;
  std::vector< pj::CallMediaInfo >::difference_type arg3 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  ptrdiff_t val2 ;
  int ecode2 = 0 ;
  ptrdiff_t val3 ;
  int ecode3 = 0 ;
  
  if ((nobjs < 3) || (nobjs > 3)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__vectorT_pj__CallMediaInfo_std__allocatorT_pj__CallMediaInfo_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "CallMediaInfoVector___setslice__" "', argument " "1"" of type '" "std::vector< pj::CallMediaInfo > *""'"); 
  }
  arg1 = reinterpret_cast< std::vector< pj::CallMediaInfo > * >(argp1);
  ecode2 = SWIG_AsVal_ptrdiff_t(swig_obj[1], &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "CallMediaInfoVector___setslice__" "', argument " "2"" of type '" "std::vector< pj::CallMediaInfo >::difference_type""'");
  } 
  arg2 = static_cast< std::vector< pj::CallMediaInfo >::difference_type >(val2);
  ecode3 = SWIG_AsVal_ptrdiff_t(swig_obj[2], &val3);
  if (!SWIG_IsOK(ecode3)) {
    SWIG_exception_fail(SWIG_ArgError(ecode3), "in method '" "CallMediaInfoVector___setslice__" "', argument " "3"" of type '" "std::vector< pj::CallMediaInfo >::difference_type""'");
  } 
  arg3 = static_cast< std::vector< pj::CallMediaInfo >::difference_type >(val3);
  try {
    std_vector_Sl_pj_CallMediaInfo_Sg____setslice____SWIG_0(arg1,arg2,arg3);
  } catch(std::out_of_range &_e) {
    SWIG_exception_fail(SWIG_IndexError, (&_e)->what());
  } catch(std::invalid_argument &_e) {
    SWIG_exception_fail(SWIG_ValueError, (&_e)->what());
  }
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_CallMediaInfoVector___setslice____SWIG_1(PyObject *SWIGUNUSEDPARM(self), Py_ssize_t nobjs, PyObject **swig_obj) {
  PyObject *resultobj = 0;
  std::vector< pj::CallMediaInfo > *arg1 = (std::vector< pj::CallMediaInfo > *) 0 ;
  std::vector< pj::CallMediaInfo >::difference_type arg2 ;
  std::vector< pj::CallMediaInfo >::difference_type arg3 ;
  std::vector< pj::CallMediaInfo,std::allocator< pj::CallMediaInfo > > *arg4 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  ptrdiff_t val2 ;
  int ecode2 = 0 ;
  ptrdiff_t val3 ;
  int ecode3 = 0 ;
  int res4 = SWIG_OLDOBJ ;
  
  if ((nobjs < 4) || (nobjs > 4)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__vectorT_pj__CallMediaInfo_std__allocatorT_pj__CallMediaInfo_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "CallMediaInfoVector___setslice__" "', argument " "1"" of type '" "std::vector< pj::CallMediaInfo > *""'"); 
  }
  arg1 = reinterpret_cast< std::vector< pj::CallMediaInfo > * >(argp1);
  ecode2 = SWIG_AsVal_ptrdiff_t(swig_obj[1], &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "CallMediaInfoVector___setslice__" "', argument " "2"" of type '" "std::vector< pj::CallMediaInfo >::difference_type""'");
  } 
  arg2 = static_cast< std::vector< pj::CallMediaInfo >::difference_type >(val2);
  ecode3 = SWIG_AsVal_ptrdiff_t(swig_obj[2], &val3);
  if (!SWIG_IsOK(ecode3)) {
    SWIG_exception_fail(SWIG_ArgError(ecode3), "in method '" "CallMediaInfoVector___setslice__" "', argument " "3"" of type '" "std::vector< pj::CallMediaInfo >::difference_type""'");
  } 
  arg3 = static_cast< std::vector< pj::CallMediaInfo >::difference_type >(val3);
  {
    std::vector< pj::CallMediaInfo,std::allocator< pj::CallMediaInfo > > *ptr = (std::vector< pj::CallMediaInfo,std::allocator< pj::CallMediaInfo > > *)0;
    res4 = swig::asptr(swig_obj[3], &ptr);
    if (!SWIG_IsOK(res4)) {
      SWIG_exception_fail(SWIG_ArgError(res4), "in method '" "CallMediaInfoVector___setslice__" "', argument " "4"" of type '" "std::vector< pj::CallMediaInfo,std::allocator< pj::CallMediaInfo > > const &""'"); 
    }
    if (!ptr) {
      SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "CallMediaInfoVector___setslice__" "', argument " "4"" of type '" "std::vector< pj::CallMediaInfo,std::allocator< pj::CallMediaInfo > > const &""'"); 
    }
    arg4 = ptr;
  }
  try {
    std_vector_Sl_pj_CallMediaInfo_Sg____setslice____SWIG_1(arg1,arg2,arg3,(std::vector< pj::CallMediaInfo,std::allocator< pj::CallMediaInfo > > const &)*arg4);
  } catch(std::out_of_range &_e) {
    SWIG_exception_fail(SWIG_IndexError, (&_e)->what());
  } catch(std::invalid_argument &_e) {
    SWIG_exception_fail(SWIG_ValueError, (&_e)->what());
  }
  resultobj = SWIG_Py_Void();
  if (SWIG_IsNewObj(res4)) delete arg4;
  return resultobj;
fail:
  if (SWIG_IsNewObj(res4)) delete arg4;
  return NULL;
}


SWIGINTERN PyObject *_wrap_CallMediaInfoVector___setslice__(PyObject *self, PyObject *args) {
  Py_ssize_t argc;
  PyObject *argv[5] = {
    0
  };
  
  if (!(argc = SWIG_Python_UnpackTuple(args, "CallMediaInfoVector___setslice__", 0, 4, argv))) SWIG_fail;
  --argc;
  if (argc == 3) {
    int _v;
    int res = swig::asptr(argv[0], (std::vector< pj::CallMediaInfo,std::allocator< pj::CallMediaInfo > >**)(0));
    _v = SWIG_CheckState(res);
    if (_v) {
      {
        int res = SWIG_AsVal_ptrdiff_t(argv[1], NULL);
        _v = SWIG_CheckState(res);
      }
      if (_v) {
        {
          int res = SWIG_AsVal_ptrdiff_t(argv[2], NULL);
          _v = SWIG_CheckState(res);
        }
        if (_v) {
          return _wrap_CallMediaInfoVector___setslice____SWIG_0(self, argc, argv);
        }
      }
    }
  }
  if (argc == 4) {
    int _v;
    int res = swig::asptr(argv[0], (std::vector< pj::CallMediaInfo,std::allocator< pj::CallMediaInfo > >**)(0));
    _v = SWIG_CheckState(res);
    if (_v) {
      {
        int res = SWIG_AsVal_ptrdiff_t(argv[1], NULL);
        _v = SWIG_CheckState(res);
      }
      if (_v) {
        {
          int res = SWIG_AsVal_ptrdiff_t(argv[2], NULL);
          _v = SWIG_CheckState(res);
        }
        if (_v) {
          int res = swig::asptr(argv[3], (std::vector< pj::CallMediaInfo,std::allocator< pj::CallMediaInfo > >**)(0));
          _v = SWIG_CheckState(res);
          if (_v) {
            return _wrap_CallMediaInfoVector___setslice____SWIG_1(self, argc, argv);
          }
        }
      }
    }
  }
  
fail:
  SWIG_Python_RaiseOrModifyTypeError("Wrong number or type of arguments for overloaded function 'CallMediaInfoVector___setslice__'.\n"
    "  Possible C/C++ prototypes are:\n"
    "    std::vector< pj::CallMediaInfo >::__setslice__(std::vector< pj::CallMediaInfo >::difference_type,std::vector< pj::CallMediaInfo >::difference_type)\n"
    "    std::vector< pj::CallMediaInfo >::__setslice__(std::vector< pj::CallMediaInfo >::difference_type,std::vector< pj::CallMediaInfo >::difference_type,std::vector< pj::CallMediaInfo,std::allocator< pj::CallMediaInfo > > const &)\n");
  return 0;
}


SWIGINTERN PyObject *_wrap_CallMediaInfoVector___delslice__(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  std::vector< pj::CallMediaInfo > *arg1 = (std::vector< pj::CallMediaInfo > *) 0 ;
  std::vector< pj::CallMediaInfo >::difference_type arg2 ;
  std::vector< pj::CallMediaInfo >::difference_type arg3 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  ptrdiff_t val2 ;
  int ecode2 = 0 ;
  ptrdiff_t val3 ;
  int ecode3 = 0 ;
  PyObject *swig_obj[3] ;
  
  if (!SWIG_Python_UnpackTuple(args, "CallMediaInfoVector___delslice__", 3, 3, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__vectorT_pj__CallMediaInfo_std__allocatorT_pj__CallMediaInfo_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "CallMediaInfoVector___delslice__" "', argument " "1"" of type '" "std::vector< pj::CallMediaInfo > *""'"); 
  }
  arg1 = reinterpret_cast< std::vector< pj::CallMediaInfo > * >(argp1);
  ecode2 = SWIG_AsVal_ptrdiff_t(swig_obj[1], &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "CallMediaInfoVector___delslice__" "', argument " "2"" of type '" "std::vector< pj::CallMediaInfo >::difference_type""'");
  } 
  arg2 = static_cast< std::vector< pj::CallMediaInfo >::difference_type >(val2);
  ecode3 = SWIG_AsVal_ptrdiff_t(swig_obj[2], &val3);
  if (!SWIG_IsOK(ecode3)) {
    SWIG_exception_fail(SWIG_ArgError(ecode3), "in method '" "CallMediaInfoVector___delslice__" "', argument " "3"" of type '" "std::vector< pj::CallMediaInfo >::difference_type""'");
  } 
  arg3 = static_cast< std::vector< pj::CallMediaInfo >::difference_type >(val3);
  try {
    std_vector_Sl_pj_CallMediaInfo_Sg____delslice__(arg1,arg2,arg3);
  } catch(std::out_of_range &_e) {
    SWIG_exception_fail(SWIG_IndexError, (&_e)->what());
  } catch(std::invalid_argument &_e) {
    SWIG_exception_fail(SWIG_ValueError, (&_e)->what());
  }
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_CallMediaInfoVector___delitem____SWIG_0(PyObject *SWIGUNUSEDPARM(self), Py_ssize_t nobjs, PyObject **swig_obj) {
  PyObject *resultobj = 0;
  std::vector< pj::CallMediaInfo > *arg1 = (std::vector< pj::CallMediaInfo > *) 0 ;
  std::vector< pj::CallMediaInfo >::difference_type arg2 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  ptrdiff_t val2 ;
  int ecode2 = 0 ;
  
  if ((nobjs < 2) || (nobjs > 2)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__vectorT_pj__CallMediaInfo_std__allocatorT_pj__CallMediaInfo_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "CallMediaInfoVector___delitem__" "', argument " "1"" of type '" "std::vector< pj::CallMediaInfo > *""'"); 
  }
  arg1 = reinterpret_cast< std::vector< pj::CallMediaInfo > * >(argp1);
  ecode2 = SWIG_AsVal_ptrdiff_t(swig_obj[1], &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "CallMediaInfoVector___delitem__" "', argument " "2"" of type '" "std::vector< pj::CallMediaInfo >::difference_type""'");
  } 
  arg2 = static_cast< std::vector< pj::CallMediaInfo >::difference_type >(val2);
  try {
    std_vector_Sl_pj_CallMediaInfo_Sg____delitem____SWIG_0(arg1,arg2);
  } catch(std::out_of_range &_e) {
    SWIG_exception_fail(SWIG_IndexError, (&_e)->what());
  } catch(std::invalid_argument &_e) {
    SWIG_exception_fail(SWIG_ValueError, (&_e)->what());
  }
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_CallMediaInfoVector___getitem____SWIG_0(PyObject *SWIGUNUSEDPARM(self), Py_ssize_t nobjs, PyObject **swig_obj) {
  PyObject *resultobj = 0;
  std::vector< pj::CallMediaInfo > *arg1 = (std::vector< pj::CallMediaInfo > *) 0 ;
  PySliceObject *arg2 = (PySliceObject *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  std::vector< pj::CallMediaInfo,std::allocator< pj::CallMediaInfo > > *result = 0 ;
  
  if ((nobjs < 2) || (nobjs > 2)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__vectorT_pj__CallMediaInfo_std__allocatorT_pj__CallMediaInfo_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "CallMediaInfoVector___getitem__" "', argument " "1"" of type '" "std::vector< pj::CallMediaInfo > *""'"); 
  }
  arg1 = reinterpret_cast< std::vector< pj::CallMediaInfo > * >(argp1);
  {
    if (!PySlice_Check(swig_obj[1])) {
      SWIG_exception_fail(SWIG_ArgError(SWIG_TypeError), "in method '" "CallMediaInfoVector___getitem__" "', argument " "2"" of type '" "PySliceObject *""'");
    }
    arg2 = (PySliceObject *) swig_obj[1];
  }
  try {
    result = (std::vector< pj::CallMediaInfo,std::allocator< pj::CallMediaInfo > > *)std_vector_Sl_pj_CallMediaInfo_Sg____getitem____SWIG_0(arg1,arg2);
  } catch(std::out_of_range &_e) {
    SWIG_exception_fail(SWIG_IndexError, (&_e)->what());
  } catch(std::invalid_argument &_e) {
    SWIG_exception_fail(SWIG_ValueError, (&_e)->what());
  }
  resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(result), SWIGTYPE_p_std__vectorT_pj__CallMediaInfo_std__allocatorT_pj__CallMediaInfo_t_t, SWIG_POINTER_OWN |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_CallMediaInfoVector___setitem____SWIG_0(PyObject *SWIGUNUSEDPARM(self), Py_ssize_t nobjs, PyObject **swig_obj) {
  PyObject *resultobj = 0;
  std::vector< pj::CallMediaInfo > *arg1 = (std::vector< pj::CallMediaInfo > *) 0 ;
  PySliceObject *arg2 = (PySliceObject *) 0 ;
  std::vector< pj::CallMediaInfo,std::allocator< pj::CallMediaInfo > > *arg3 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  int res3 = SWIG_OLDOBJ ;
  
  if ((nobjs < 3) || (nobjs > 3)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__vectorT_pj__CallMediaInfo_std__allocatorT_pj__CallMediaInfo_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "CallMediaInfoVector___setitem__" "', argument " "1"" of type '" "std::vector< pj::CallMediaInfo > *""'"); 
  }
  arg1 = reinterpret_cast< std::vector< pj::CallMediaInfo > * >(argp1);
  {
    if (!PySlice_Check(swig_obj[1])) {
      SWIG_exception_fail(SWIG_ArgError(SWIG_TypeError), "in method '" "CallMediaInfoVector___setitem__" "', argument " "2"" of type '" "PySliceObject *""'");
    }
    arg2 = (PySliceObject *) swig_obj[1];
  }
  {
    std::vector< pj::CallMediaInfo,std::allocator< pj::CallMediaInfo > > *ptr = (std::vector< pj::CallMediaInfo,std::allocator< pj::CallMediaInfo > > *)0;
    res3 = swig::asptr(swig_obj[2], &ptr);
    if (!SWIG_IsOK(res3)) {
      SWIG_exception_fail(SWIG_ArgError(res3), "in method '" "CallMediaInfoVector___setitem__" "', argument " "3"" of type '" "std::vector< pj::CallMediaInfo,std::allocator< pj::CallMediaInfo > > const &""'"); 
    }
    if (!ptr) {
      SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "CallMediaInfoVector___setitem__" "', argument " "3"" of type '" "std::vector< pj::CallMediaInfo,std::allocator< pj::CallMediaInfo > > const &""'"); 
    }
    arg3 = ptr;
  }
  try {
    std_vector_Sl_pj_CallMediaInfo_Sg____setitem____SWIG_0(arg1,arg2,(std::vector< pj::CallMediaInfo,std::allocator< pj::CallMediaInfo > > const &)*arg3);
  } catch(std::out_of_range &_e) {
    SWIG_exception_fail(SWIG_IndexError, (&_e)->what());
  } catch(std::invalid_argument &_e) {
    SWIG_exception_fail(SWIG_ValueError, (&_e)->what());
  }
  resultobj = SWIG_Py_Void();
  if (SWIG_IsNewObj(res3)) delete arg3;
  return resultobj;
fail:
  if (SWIG_IsNewObj(res3)) delete arg3;
  return NULL;
}


SWIGINTERN PyObject *_wrap_CallMediaInfoVector___setitem____SWIG_1(PyObject *SWIGUNUSEDPARM(self), Py_ssize_t nobjs, PyObject **swig_obj) {
  PyObject *resultobj = 0;
  std::vector< pj::CallMediaInfo > *arg1 = (std::vector< pj::CallMediaInfo > *) 0 ;
  PySliceObject *arg2 = (PySliceObject *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  
  if ((nobjs < 2) || (nobjs > 2)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__vectorT_pj__CallMediaInfo_std__allocatorT_pj__CallMediaInfo_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "CallMediaInfoVector___setitem__" "', argument " "1"" of type '" "std::vector< pj::CallMediaInfo > *""'"); 
  }
  arg1 = reinterpret_cast< std::vector< pj::CallMediaInfo > * >(argp1);
  {
    if (!PySlice_Check(swig_obj[1])) {
      SWIG_exception_fail(SWIG_ArgError(SWIG_TypeError), "in method '" "CallMediaInfoVector___setitem__" "', argument " "2"" of type '" "PySliceObject *""'");
    }
    arg2 = (PySliceObject *) swig_obj[1];
  }
  try {
    std_vector_Sl_pj_CallMediaInfo_Sg____setitem____SWIG_1(arg1,arg2);
  } catch(std::out_of_range &_e) {
    SWIG_exception_fail(SWIG_IndexError, (&_e)->what());
  } catch(std::invalid_argument &_e) {
    SWIG_exception_fail(SWIG_ValueError, (&_e)->what());
  }
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_CallMediaInfoVector___delitem____SWIG_1(PyObject *SWIGUNUSEDPARM(self), Py_ssize_t nobjs, PyObject **swig_obj) {
  PyObject *resultobj = 0;
  std::vector< pj::CallMediaInfo > *arg1 = (std::vector< pj::CallMediaInfo > *) 0 ;
  PySliceObject *arg2 = (PySliceObject *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  
  if ((nobjs < 2) || (nobjs > 2)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__vectorT_pj__CallMediaInfo_std__allocatorT_pj__CallMediaInfo_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "CallMediaInfoVector___delitem__" "', argument " "1"" of type '" "std::vector< pj::CallMediaInfo > *""'"); 
  }
  arg1 = reinterpret_cast< std::vector< pj::CallMediaInfo > * >(argp1);
  {
    if (!PySlice_Check(swig_obj[1])) {
      SWIG_exception_fail(SWIG_ArgError(SWIG_TypeError), "in method '" "CallMediaInfoVector___delitem__" "', argument " "2"" of type '" "PySliceObject *""'");
    }
    arg2 = (PySliceObject *) swig_obj[1];
  }
  try {
    std_vector_Sl_pj_CallMediaInfo_Sg____delitem____SWIG_1(arg1,arg2);
  } catch(std::out_of_range &_e) {
    SWIG_exception_fail(SWIG_IndexError, (&_e)->what());
  } catch(std::invalid_argument &_e) {
    SWIG_exception_fail(SWIG_ValueError, (&_e)->what());
  }
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_CallMediaInfoVector___delitem__(PyObject *self, PyObject *args) {
  Py_ssize_t argc;
  PyObject *argv[3] = {
    0
  };
  
  if (!(argc = SWIG_Python_UnpackTuple(args, "CallMediaInfoVector___delitem__", 0, 2, argv))) SWIG_fail;
  --argc;
  if (argc == 2) {
    int _v;
    int res = swig::asptr(argv[0], (std::vector< pj::CallMediaInfo,std::allocator< pj::CallMediaInfo > >**)(0));
    _v = SWIG_CheckState(res);
    if (_v) {
      {
        _v = PySlice_Check(argv[1]);
      }
      if (_v) {
        return _wrap_CallMediaInfoVector___delitem____SWIG_1(self, argc, argv);
      }
    }
  }
  if (argc == 2) {
    int _v;
    int res = swig::asptr(argv[0], (std::vector< pj::CallMediaInfo,std::allocator< pj::CallMediaInfo > >**)(0));
    _v = SWIG_CheckState(res);
    if (_v) {
      {
        int res = SWIG_AsVal_ptrdiff_t(argv[1], NULL);
        _v = SWIG_CheckState(res);
      }
      if (_v) {
        return _wrap_CallMediaInfoVector___delitem____SWIG_0(self, argc, argv);
      }
    }
  }
  
fail:
  SWIG_Python_RaiseOrModifyTypeError("Wrong number or type of arguments for overloaded function 'CallMediaInfoVector___delitem__'.\n"
    "  Possible C/C++ prototypes are:\n"
    "    std::vector< pj::CallMediaInfo >::__delitem__(std::vector< pj::CallMediaInfo >::difference_type)\n"
    "    std::vector< pj::CallMediaInfo >::__delitem__(PySliceObject *)\n");
  return 0;
}


SWIGINTERN PyObject *_wrap_CallMediaInfoVector___getitem____SWIG_1(PyObject *SWIGUNUSEDPARM(self), Py_ssize_t nobjs, PyObject **swig_obj) {
  PyObject *resultobj = 0;
  std::vector< pj::CallMediaInfo > *arg1 = (std::vector< pj::CallMediaInfo > *) 0 ;
  std::vector< pj::CallMediaInfo >::difference_type arg2 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  ptrdiff_t val2 ;
  int ecode2 = 0 ;
  std::vector< pj::CallMediaInfo >::value_type *result = 0 ;
  
  if ((nobjs < 2) || (nobjs > 2)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__vectorT_pj__CallMediaInfo_std__allocatorT_pj__CallMediaInfo_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "CallMediaInfoVector___getitem__" "', argument " "1"" of type '" "std::vector< pj::CallMediaInfo > const *""'"); 
  }
  arg1 = reinterpret_cast< std::vector< pj::CallMediaInfo > * >(argp1);
  ecode2 = SWIG_AsVal_ptrdiff_t(swig_obj[1], &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "CallMediaInfoVector___getitem__" "', argument " "2"" of type '" "std::vector< pj::CallMediaInfo >::difference_type""'");
  } 
  arg2 = static_cast< std::vector< pj::CallMediaInfo >::difference_type >(val2);
  try {
    result = (std::vector< pj::CallMediaInfo >::value_type *) &std_vector_Sl_pj_CallMediaInfo_Sg____getitem____SWIG_1((std::vector< pj::CallMediaInfo > const *)arg1,arg2);
  } catch(std::out_of_range &_e) {
    SWIG_exception_fail(SWIG_IndexError, (&_e)->what());
  }
  resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(result), SWIGTYPE_p_pj__CallMediaInfo, 0 |  0 );
  (void)swig::container_owner<swig::traits<std::vector< pj::CallMediaInfo >::value_type>::category>::back_reference(resultobj, swig_obj[0]);
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_CallMediaInfoVector___getitem__(PyObject *self, PyObject *args) {
  Py_ssize_t argc;
  PyObject *argv[3] = {
    0
  };
  
  if (!(argc = SWIG_Python_UnpackTuple(args, "CallMediaInfoVector___getitem__", 0, 2, argv))) SWIG_fail;
  --argc;
  if (argc == 2) {
    int _v;
    int res = swig::asptr(argv[0], (std::vector< pj::CallMediaInfo,std::allocator< pj::CallMediaInfo > >**)(0));
    _v = SWIG_CheckState(res);
    if (_v) {
      {
        _v = PySlice_Check(argv[1]);
      }
      if (_v) {
        return _wrap_CallMediaInfoVector___getitem____SWIG_0(self, argc, argv);
      }
    }
  }
  if (argc == 2) {
    int _v;
    int res = swig::asptr(argv[0], (std::vector< pj::CallMediaInfo,std::allocator< pj::CallMediaInfo > >**)(0));
    _v = SWIG_CheckState(res);
    if (_v) {
      {
        int res = SWIG_AsVal_ptrdiff_t(argv[1], NULL);
        _v = SWIG_CheckState(res);
      }
      if (_v) {
        return _wrap_CallMediaInfoVector___getitem____SWIG_1(self, argc, argv);
      }
    }
  }
  
fail:
  SWIG_Python_RaiseOrModifyTypeError("Wrong number or type of arguments for overloaded function 'CallMediaInfoVector___getitem__'.\n"
    "  Possible C/C++ prototypes are:\n"
    "    std::vector< pj::CallMediaInfo >::__getitem__(PySliceObject *)\n"
    "    std::vector< pj::CallMediaInfo >::__getitem__(std::vector< pj::CallMediaInfo >::difference_type) const\n");
  return 0;
}


SWIGINTERN PyObject *_wrap_CallMediaInfoVector___setitem____SWIG_2(PyObject *SWIGUNUSEDPARM(self), Py_ssize_t nobjs, PyObject **swig_obj) {
  PyObject *resultobj = 0;
  std::vector< pj::CallMediaInfo > *arg1 = (std::vector< pj::CallMediaInfo > *) 0 ;
  std::vector< pj::CallMediaInfo >::difference_type arg2 ;
  std::vector< pj::CallMediaInfo >::value_type *arg3 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  ptrdiff_t val2 ;
  int ecode2 = 0 ;
  void *argp3 = 0 ;
  int res3 = 0 ;
  
  if ((nobjs < 3) || (nobjs > 3)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__vectorT_pj__CallMediaInfo_std__allocatorT_pj__CallMediaInfo_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "CallMediaInfoVector___setitem__" "', argument " "1"" of type '" "std::vector< pj::CallMediaInfo > *""'"); 
  }
  arg1 = reinterpret_cast< std::vector< pj::CallMediaInfo > * >(argp1);
  ecode2 = SWIG_AsVal_ptrdiff_t(swig_obj[1], &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "CallMediaInfoVector___setitem__" "', argument " "2"" of type '" "std::vector< pj::CallMediaInfo >::difference_type""'");
  } 
  arg2 = static_cast< std::vector< pj::CallMediaInfo >::difference_type >(val2);
  res3 = SWIG_ConvertPtr(swig_obj[2], &argp3, SWIGTYPE_p_pj__CallMediaInfo,  0  | 0);
  if (!SWIG_IsOK(res3)) {
    SWIG_exception_fail(SWIG_ArgError(res3), "in method '" "CallMediaInfoVector___setitem__" "', argument " "3"" of type '" "std::vector< pj::CallMediaInfo >::value_type const &""'"); 
  }
  if (!argp3) {
    SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "CallMediaInfoVector___setitem__" "', argument " "3"" of type '" "std::vector< pj::CallMediaInfo >::value_type const &""'"); 
  }
  arg3 = reinterpret_cast< std::vector< pj::CallMediaInfo >::value_type * >(argp3);
  try {
    std_vector_Sl_pj_CallMediaInfo_Sg____setitem____SWIG_2(arg1,arg2,(pj::CallMediaInfo const &)*arg3);
  } catch(std::out_of_range &_e) {
    SWIG_exception_fail(SWIG_IndexError, (&_e)->what());
  }
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_CallMediaInfoVector___setitem__(PyObject *self, PyObject *args) {
  Py_ssize_t argc;
  PyObject *argv[4] = {
    0
  };
  
  if (!(argc = SWIG_Python_UnpackTuple(args, "CallMediaInfoVector___setitem__", 0, 3, argv))) SWIG_fail;
  --argc;
  if (argc == 2) {
    int _v;
    int res = swig::asptr(argv[0], (std::vector< pj::CallMediaInfo,std::allocator< pj::CallMediaInfo > >**)(0));
    _v = SWIG_CheckState(res);
    if (_v) {
      {
        _v = PySlice_Check(argv[1]);
      }
      if (_v) {
        return _wrap_CallMediaInfoVector___setitem____SWIG_1(self, argc, argv);
      }
    }
  }
  if (argc == 3) {
    int _v;
    int res = swig::asptr(argv[0], (std::vector< pj::CallMediaInfo,std::allocator< pj::CallMediaInfo > >**)(0));
    _v = SWIG_CheckState(res);
    if (_v) {
      {
        _v = PySlice_Check(argv[1]);
      }
      if (_v) {
        int res = swig::asptr(argv[2], (std::vector< pj::CallMediaInfo,std::allocator< pj::CallMediaInfo > >**)(0));
        _v = SWIG_CheckState(res);
        if (_v) {
          return _wrap_CallMediaInfoVector___setitem____SWIG_0(self, argc, argv);
        }
      }
    }
  }
  if (argc == 3) {
    int _v;
    int res = swig::asptr(argv[0], (std::vector< pj::CallMediaInfo,std::allocator< pj::CallMediaInfo > >**)(0));
    _v = SWIG_CheckState(res);
    if (_v) {
      {
        int res = SWIG_AsVal_ptrdiff_t(argv[1], NULL);
        _v = SWIG_CheckState(res);
      }
      if (_v) {
        int res = SWIG_ConvertPtr(argv[2], 0, SWIGTYPE_p_pj__CallMediaInfo, SWIG_POINTER_NO_NULL | 0);
        _v = SWIG_CheckState(res);
        if (_v) {
          return _wrap_CallMediaInfoVector___setitem____SWIG_2(self, argc, argv);
        }
      }
    }
  }
  
fail:
  SWIG_Python_RaiseOrModifyTypeError("Wrong number or type of arguments for overloaded function 'CallMediaInfoVector___setitem__'.\n"
    "  Possible C/C++ prototypes are:\n"
    "    std::vector< pj::CallMediaInfo >::__setitem__(PySliceObject *,std::vector< pj::CallMediaInfo,std::allocator< pj::CallMediaInfo > > const &)\n"
    "    std::vector< pj::CallMediaInfo >::__setitem__(PySliceObject *)\n"
    "    std::vector< pj::CallMediaInfo >::__setitem__(std::vector< pj::CallMediaInfo >::difference_type,std::vector< pj::CallMediaInfo >::value_type const &)\n");
  return 0;
}


SWIGINTERN PyObject *_wrap_CallMediaInfoVector_pop(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  std::vector< pj::CallMediaInfo > *arg1 = (std::vector< pj::CallMediaInfo > *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  std::vector< pj::CallMediaInfo >::value_type result;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__vectorT_pj__CallMediaInfo_std__allocatorT_pj__CallMediaInfo_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "CallMediaInfoVector_pop" "', argument " "1"" of type '" "std::vector< pj::CallMediaInfo > *""'"); 
  }
  arg1 = reinterpret_cast< std::vector< pj::CallMediaInfo > * >(argp1);
  try {
    result = std_vector_Sl_pj_CallMediaInfo_Sg__pop(arg1);
  } catch(std::out_of_range &_e) {
    SWIG_exception_fail(SWIG_IndexError, (&_e)->what());
  }
  resultobj = SWIG_NewPointerObj((new std::vector< pj::CallMediaInfo >::value_type(static_cast< const std::vector< pj::CallMediaInfo >::value_type& >(result))), SWIGTYPE_p_pj__CallMediaInfo, SWIG_POINTER_OWN |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_CallMediaInfoVector_append(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  std::vector< pj::CallMediaInfo > *arg1 = (std::vector< pj::CallMediaInfo > *) 0 ;
  std::vector< pj::CallMediaInfo >::value_type *arg2 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  void *argp2 = 0 ;
  int res2 = 0 ;
  PyObject *swig_obj[2] ;
  
  if (!SWIG_Python_UnpackTuple(args, "CallMediaInfoVector_append", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__vectorT_pj__CallMediaInfo_std__allocatorT_pj__CallMediaInfo_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "CallMediaInfoVector_append" "', argument " "1"" of type '" "std::vector< pj::CallMediaInfo > *""'"); 
  }
  arg1 = reinterpret_cast< std::vector< pj::CallMediaInfo > * >(argp1);
  res2 = SWIG_ConvertPtr(swig_obj[1], &argp2, SWIGTYPE_p_pj__CallMediaInfo,  0  | 0);
  if (!SWIG_IsOK(res2)) {
    SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "CallMediaInfoVector_append" "', argument " "2"" of type '" "std::vector< pj::CallMediaInfo >::value_type const &""'"); 
  }
  if (!argp2) {
    SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "CallMediaInfoVector_append" "', argument " "2"" of type '" "std::vector< pj::CallMediaInfo >::value_type const &""'"); 
  }
  arg2 = reinterpret_cast< std::vector< pj::CallMediaInfo >::value_type * >(argp2);
  std_vector_Sl_pj_CallMediaInfo_Sg__append(arg1,(pj::CallMediaInfo const &)*arg2);
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_new_CallMediaInfoVector__SWIG_0(PyObject *SWIGUNUSEDPARM(self), Py_ssize_t nobjs, PyObject **SWIGUNUSEDPARM(swig_obj)) {
  PyObject *resultobj = 0;
  std::vector< pj::CallMediaInfo > *result = 0 ;
  
  if ((nobjs < 0) || (nobjs > 0)) SWIG_fail;
  result = (std::vector< pj::CallMediaInfo > *)new std::vector< pj::CallMediaInfo >();
  resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(result), SWIGTYPE_p_std__vectorT_pj__CallMediaInfo_std__allocatorT_pj__CallMediaInfo_t_t, SWIG_POINTER_NEW |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_new_CallMediaInfoVector__SWIG_1(PyObject *SWIGUNUSEDPARM(self), Py_ssize_t nobjs, PyObject **swig_obj) {
  PyObject *resultobj = 0;
  std::vector< pj::CallMediaInfo > *arg1 = 0 ;
  int res1 = SWIG_OLDOBJ ;
  std::vector< pj::CallMediaInfo > *result = 0 ;
  
  if ((nobjs < 1) || (nobjs > 1)) SWIG_fail;
  {
    std::vector< pj::CallMediaInfo,std::allocator< pj::CallMediaInfo > > *ptr = (std::vector< pj::CallMediaInfo,std::allocator< pj::CallMediaInfo > > *)0;
    res1 = swig::asptr(swig_obj[0], &ptr);
    if (!SWIG_IsOK(res1)) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "new_CallMediaInfoVector" "', argument " "1"" of type '" "std::vector< pj::CallMediaInfo > const &""'"); 
    }
    if (!ptr) {
      SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "new_CallMediaInfoVector" "', argument " "1"" of type '" "std::vector< pj::CallMediaInfo > const &""'"); 
    }
    arg1 = ptr;
  }
  result = (std::vector< pj::CallMediaInfo > *)new std::vector< pj::CallMediaInfo >((std::vector< pj::CallMediaInfo > const &)*arg1);
  resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(result), SWIGTYPE_p_std__vectorT_pj__CallMediaInfo_std__allocatorT_pj__CallMediaInfo_t_t, SWIG_POINTER_NEW |  0 );
  if (SWIG_IsNewObj(res1)) delete arg1;
  return resultobj;
fail:
  if (SWIG_IsNewObj(res1)) delete arg1;
  return NULL;
}


SWIGINTERN PyObject *_wrap_CallMediaInfoVector_empty(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  std::vector< pj::CallMediaInfo > *arg1 = (std::vector< pj::CallMediaInfo > *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  bool result;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__vectorT_pj__CallMediaInfo_std__allocatorT_pj__CallMediaInfo_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "CallMediaInfoVector_empty" "', argument " "1"" of type '" "std::vector< pj::CallMediaInfo > const *""'"); 
  }
  arg1 = reinterpret_cast< std::vector< pj::CallMediaInfo > * >(argp1);
  result = (bool)((std::vector< pj::CallMediaInfo > const *)arg1)->empty();
  resultobj = SWIG_From_bool(static_cast< bool >(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_CallMediaInfoVector_size(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  std::vector< pj::CallMediaInfo > *arg1 = (std::vector< pj::CallMediaInfo > *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  std::vector< pj::CallMediaInfo >::size_type result;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__vectorT_pj__CallMediaInfo_std__allocatorT_pj__CallMediaInfo_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "CallMediaInfoVector_size" "', argument " "1"" of type '" "std::vector< pj::CallMediaInfo > const *""'"); 
  }
  arg1 = reinterpret_cast< std::vector< pj::CallMediaInfo > * >(argp1);
  result = ((std::vector< pj::CallMediaInfo > const *)arg1)->size();
  resultobj = SWIG_From_size_t(static_cast< size_t >(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_CallMediaInfoVector_swap(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  std::vector< pj::CallMediaInfo > *arg1 = (std::vector< pj::CallMediaInfo > *) 0 ;
  std::vector< pj::CallMediaInfo > *arg2 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  void *argp2 = 0 ;
  int res2 = 0 ;
  PyObject *swig_obj[2] ;
  
  if (!SWIG_Python_UnpackTuple(args, "CallMediaInfoVector_swap", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__vectorT_pj__CallMediaInfo_std__allocatorT_pj__CallMediaInfo_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "CallMediaInfoVector_swap" "', argument " "1"" of type '" "std::vector< pj::CallMediaInfo > *""'"); 
  }
  arg1 = reinterpret_cast< std::vector< pj::CallMediaInfo > * >(argp1);
  res2 = SWIG_ConvertPtr(swig_obj[1], &argp2, SWIGTYPE_p_std__vectorT_pj__CallMediaInfo_std__allocatorT_pj__CallMediaInfo_t_t,  0 );
  if (!SWIG_IsOK(res2)) {
    SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "CallMediaInfoVector_swap" "', argument " "2"" of type '" "std::vector< pj::CallMediaInfo > &""'"); 
  }
  if (!argp2) {
    SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "CallMediaInfoVector_swap" "', argument " "2"" of type '" "std::vector< pj::CallMediaInfo > &""'"); 
  }
  arg2 = reinterpret_cast< std::vector< pj::CallMediaInfo > * >(argp2);
  (arg1)->swap(*arg2);
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_CallMediaInfoVector_begin(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  std::vector< pj::CallMediaInfo > *arg1 = (std::vector< pj::CallMediaInfo > *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  std::vector< pj::CallMediaInfo >::iterator result;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__vectorT_pj__CallMediaInfo_std__allocatorT_pj__CallMediaInfo_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "CallMediaInfoVector_begin" "', argument " "1"" of type '" "std::vector< pj::CallMediaInfo > *""'"); 
  }
  arg1 = reinterpret_cast< std::vector< pj::CallMediaInfo > * >(argp1);
  result = (arg1)->begin();
  resultobj = SWIG_NewPointerObj(swig::make_output_iterator(static_cast< const std::vector< pj::CallMediaInfo >::iterator & >(result)),
    swig::SwigPyIterator::descriptor(),SWIG_POINTER_OWN);
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_CallMediaInfoVector_end(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  std::vector< pj::CallMediaInfo > *arg1 = (std::vector< pj::CallMediaInfo > *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  std::vector< pj::CallMediaInfo >::iterator result;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__vectorT_pj__CallMediaInfo_std__allocatorT_pj__CallMediaInfo_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "CallMediaInfoVector_end" "', argument " "1"" of type '" "std::vector< pj::CallMediaInfo > *""'"); 
  }
  arg1 = reinterpret_cast< std::vector< pj::CallMediaInfo > * >(argp1);
  result = (arg1)->end();
  resultobj = SWIG_NewPointerObj(swig::make_output_iterator(static_cast< const std::vector< pj::CallMediaInfo >::iterator & >(result)),
    swig::SwigPyIterator::descriptor(),SWIG_POINTER_OWN);
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_CallMediaInfoVector_rbegin(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  std::vector< pj::CallMediaInfo > *arg1 = (std::vector< pj::CallMediaInfo > *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  std::vector< pj::CallMediaInfo >::reverse_iterator result;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__vectorT_pj__CallMediaInfo_std__allocatorT_pj__CallMediaInfo_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "CallMediaInfoVector_rbegin" "', argument " "1"" of type '" "std::vector< pj::CallMediaInfo > *""'"); 
  }
  arg1 = reinterpret_cast< std::vector< pj::CallMediaInfo > * >(argp1);
  result = (arg1)->rbegin();
  resultobj = SWIG_NewPointerObj(swig::make_output_iterator(static_cast< const std::vector< pj::CallMediaInfo >::reverse_iterator & >(result)),
    swig::SwigPyIterator::descriptor(),SWIG_POINTER_OWN);
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_CallMediaInfoVector_rend(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  std::vector< pj::CallMediaInfo > *arg1 = (std::vector< pj::CallMediaInfo > *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  std::vector< pj::CallMediaInfo >::reverse_iterator result;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__vectorT_pj__CallMediaInfo_std__allocatorT_pj__CallMediaInfo_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "CallMediaInfoVector_rend" "', argument " "1"" of type '" "std::vector< pj::CallMediaInfo > *""'"); 
  }
  arg1 = reinterpret_cast< std::vector< pj::CallMediaInfo > * >(argp1);
  result = (arg1)->rend();
  resultobj = SWIG_NewPointerObj(swig::make_output_iterator(static_cast< const std::vector< pj::CallMediaInfo >::reverse_iterator & >(result)),
    swig::SwigPyIterator::descriptor(),SWIG_POINTER_OWN);
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_CallMediaInfoVector_clear(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  std::vector< pj::CallMediaInfo > *arg1 = (std::vector< pj::CallMediaInfo > *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__vectorT_pj__CallMediaInfo_std__allocatorT_pj__CallMediaInfo_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "CallMediaInfoVector_clear" "', argument " "1"" of type '" "std::vector< pj::CallMediaInfo > *""'"); 
  }
  arg1 = reinterpret_cast< std::vector< pj::CallMediaInfo > * >(argp1);
  (arg1)->clear();
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_CallMediaInfoVector_get_allocator(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  std::vector< pj::CallMediaInfo > *arg1 = (std::vector< pj::CallMediaInfo > *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  SwigValueWrapper< std::allocator< pj::CallMediaInfo > > result;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__vectorT_pj__CallMediaInfo_std__allocatorT_pj__CallMediaInfo_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "CallMediaInfoVector_get_allocator" "', argument " "1"" of type '" "std::vector< pj::CallMediaInfo > const *""'"); 
  }
  arg1 = reinterpret_cast< std::vector< pj::CallMediaInfo > * >(argp1);
  result = ((std::vector< pj::CallMediaInfo > const *)arg1)->get_allocator();
  resultobj = SWIG_NewPointerObj((new std::vector< pj::CallMediaInfo >::allocator_type(static_cast< const std::vector< pj::CallMediaInfo >::allocator_type& >(result))), SWIGTYPE_p_std__allocatorT_pj__CallMediaInfo_t, SWIG_POINTER_OWN |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_new_CallMediaInfoVector__SWIG_2(PyObject *SWIGUNUSEDPARM(self), Py_ssize_t nobjs, PyObject **swig_obj) {
  PyObject *resultobj = 0;
  std::vector< pj::CallMediaInfo >::size_type arg1 ;
  size_t val1 ;
  int ecode1 = 0 ;
  std::vector< pj::CallMediaInfo > *result = 0 ;
  
  if ((nobjs < 1) || (nobjs > 1)) SWIG_fail;
  ecode1 = SWIG_AsVal_size_t(swig_obj[0], &val1);
  if (!SWIG_IsOK(ecode1)) {
    SWIG_exception_fail(SWIG_ArgError(ecode1), "in method '" "new_CallMediaInfoVector" "', argument " "1"" of type '" "std::vector< pj::CallMediaInfo >::size_type""'");
  } 
  arg1 = static_cast< std::vector< pj::CallMediaInfo >::size_type >(val1);
  result = (std::vector< pj::CallMediaInfo > *)new std::vector< pj::CallMediaInfo >(arg1);
  resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(result), SWIGTYPE_p_std__vectorT_pj__CallMediaInfo_std__allocatorT_pj__CallMediaInfo_t_t, SWIG_POINTER_NEW |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_CallMediaInfoVector_pop_back(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  std::vector< pj::CallMediaInfo > *arg1 = (std::vector< pj::CallMediaInfo > *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__vectorT_pj__CallMediaInfo_std__allocatorT_pj__CallMediaInfo_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "CallMediaInfoVector_pop_back" "', argument " "1"" of type '" "std::vector< pj::CallMediaInfo > *""'"); 
  }
  arg1 = reinterpret_cast< std::vector< pj::CallMediaInfo > * >(argp1);
  (arg1)->pop_back();
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_CallMediaInfoVector_resize__SWIG_0(PyObject *SWIGUNUSEDPARM(self), Py_ssize_t nobjs, PyObject **swig_obj) {
  PyObject *resultobj = 0;
  std::vector< pj::CallMediaInfo > *arg1 = (std::vector< pj::CallMediaInfo > *) 0 ;
  std::vector< pj::CallMediaInfo >::size_type arg2 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  size_t val2 ;
  int ecode2 = 0 ;
  
  if ((nobjs < 2) || (nobjs > 2)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__vectorT_pj__CallMediaInfo_std__allocatorT_pj__CallMediaInfo_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "CallMediaInfoVector_resize" "', argument " "1"" of type '" "std::vector< pj::CallMediaInfo > *""'"); 
  }
  arg1 = reinterpret_cast< std::vector< pj::CallMediaInfo > * >(argp1);
  ecode2 = SWIG_AsVal_size_t(swig_obj[1], &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "CallMediaInfoVector_resize" "', argument " "2"" of type '" "std::vector< pj::CallMediaInfo >::size_type""'");
  } 
  arg2 = static_cast< std::vector< pj::CallMediaInfo >::size_type >(val2);
  (arg1)->resize(arg2);
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_CallMediaInfoVector_erase__SWIG_0(PyObject *SWIGUNUSEDPARM(self), Py_ssize_t nobjs, PyObject **swig_obj) {
  PyObject *resultobj = 0;
  std::vector< pj::CallMediaInfo > *arg1 = (std::vector< pj::CallMediaInfo > *) 0 ;
  std::vector< pj::CallMediaInfo >::iterator arg2 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  swig::SwigPyIterator *iter2 = 0 ;
  int res2 ;
  std::vector< pj::CallMediaInfo >::iterator result;
  
  if ((nobjs < 2) || (nobjs > 2)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__vectorT_pj__CallMediaInfo_std__allocatorT_pj__CallMediaInfo_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "CallMediaInfoVector_erase" "', argument " "1"" of type '" "std::vector< pj::CallMediaInfo > *""'"); 
  }
  arg1 = reinterpret_cast< std::vector< pj::CallMediaInfo > * >(argp1);
  res2 = SWIG_ConvertPtr(swig_obj[1], SWIG_as_voidptrptr(&iter2), swig::SwigPyIterator::descriptor(), 0);
  if (!SWIG_IsOK(res2) || !iter2) {
    SWIG_exception_fail(SWIG_ArgError(SWIG_TypeError), "in method '" "CallMediaInfoVector_erase" "', argument " "2"" of type '" "std::vector< pj::CallMediaInfo >::iterator""'");
  } else {
    swig::SwigPyIterator_T<std::vector< pj::CallMediaInfo >::iterator > *iter_t = dynamic_cast<swig::SwigPyIterator_T<std::vector< pj::CallMediaInfo >::iterator > *>(iter2);
    if (iter_t) {
      arg2 = iter_t->get_current();
    } else {
      SWIG_exception_fail(SWIG_ArgError(SWIG_TypeError), "in method '" "CallMediaInfoVector_erase" "', argument " "2"" of type '" "std::vector< pj::CallMediaInfo >::iterator""'");
    }
  }
  result = std_vector_Sl_pj_CallMediaInfo_Sg__erase__SWIG_0(arg1,arg2);
  resultobj = SWIG_NewPointerObj(swig::make_output_iterator(static_cast< const std::vector< pj::CallMediaInfo >::iterator & >(result)),
    swig::SwigPyIterator::descriptor(),SWIG_POINTER_OWN);
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_CallMediaInfoVector_erase__SWIG_1(PyObject *SWIGUNUSEDPARM(self), Py_ssize_t nobjs, PyObject **swig_obj) {
  PyObject *resultobj = 0;
  std::vector< pj::CallMediaInfo > *arg1 = (std::vector< pj::CallMediaInfo > *) 0 ;
  std::vector< pj::CallMediaInfo >::iterator arg2 ;
  std::vector< pj::CallMediaInfo >::iterator arg3 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  swig::SwigPyIterator *iter2 = 0 ;
  int res2 ;
  swig::SwigPyIterator *iter3 = 0 ;
  int res3 ;
  std::vector< pj::CallMediaInfo >::iterator result;
  
  if ((nobjs < 3) || (nobjs > 3)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__vectorT_pj__CallMediaInfo_std__allocatorT_pj__CallMediaInfo_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "CallMediaInfoVector_erase" "', argument " "1"" of type '" "std::vector< pj::CallMediaInfo > *""'"); 
  }
  arg1 = reinterpret_cast< std::vector< pj::CallMediaInfo > * >(argp1);
  res2 = SWIG_ConvertPtr(swig_obj[1], SWIG_as_voidptrptr(&iter2), swig::SwigPyIterator::descriptor(), 0);
  if (!SWIG_IsOK(res2) || !iter2) {
    SWIG_exception_fail(SWIG_ArgError(SWIG_TypeError), "in method '" "CallMediaInfoVector_erase" "', argument " "2"" of type '" "std::vector< pj::CallMediaInfo >::iterator""'");
  } else {
    swig::SwigPyIterator_T<std::vector< pj::CallMediaInfo >::iterator > *iter_t = dynamic_cast<swig::SwigPyIterator_T<std::vector< pj::CallMediaInfo >::iterator > *>(iter2);
    if (iter_t) {
      arg2 = iter_t->get_current();
    } else {
      SWIG_exception_fail(SWIG_ArgError(SWIG_TypeError), "in method '" "CallMediaInfoVector_erase" "', argument " "2"" of type '" "std::vector< pj::CallMediaInfo >::iterator""'");
    }
  }
  res3 = SWIG_ConvertPtr(swig_obj[2], SWIG_as_voidptrptr(&iter3), swig::SwigPyIterator::descriptor(), 0);
  if (!SWIG_IsOK(res3) || !iter3) {
    SWIG_exception_fail(SWIG_ArgError(SWIG_TypeError), "in method '" "CallMediaInfoVector_erase" "', argument " "3"" of type '" "std::vector< pj::CallMediaInfo >::iterator""'");
  } else {
    swig::SwigPyIterator_T<std::vector< pj::CallMediaInfo >::iterator > *iter_t = dynamic_cast<swig::SwigPyIterator_T<std::vector< pj::CallMediaInfo >::iterator > *>(iter3);
    if (iter_t) {
      arg3 = iter_t->get_current();
    } else {
      SWIG_exception_fail(SWIG_ArgError(SWIG_TypeError), "in method '" "CallMediaInfoVector_erase" "', argument " "3"" of type '" "std::vector< pj::CallMediaInfo >::iterator""'");
    }
  }
  result = std_vector_Sl_pj_CallMediaInfo_Sg__erase__SWIG_1(arg1,arg2,arg3);
  resultobj = SWIG_NewPointerObj(swig::make_output_iterator(static_cast< const std::vector< pj::CallMediaInfo >::iterator & >(result)),
    swig::SwigPyIterator::descriptor(),SWIG_POINTER_OWN);
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_CallMediaInfoVector_erase(PyObject *self, PyObject *args) {
  Py_ssize_t argc;
  PyObject *argv[4] = {
    0
  };
  
  if (!(argc = SWIG_Python_UnpackTuple(args, "CallMediaInfoVector_erase", 0, 3, argv))) SWIG_fail;
  --argc;
  if (argc == 2) {
    int _v;
    int res = swig::asptr(argv[0], (std::vector< pj::CallMediaInfo,std::allocator< pj::CallMediaInfo > >**)(0));
    _v = SWIG_CheckState(res);
    if (_v) {
      swig::SwigPyIterator *iter = 0;
      int res = SWIG_ConvertPtr(argv[1], SWIG_as_voidptrptr(&iter), swig::SwigPyIterator::descriptor(), 0);
      _v = (SWIG_IsOK(res) && iter && (dynamic_cast<swig::SwigPyIterator_T<std::vector< pj::CallMediaInfo >::iterator > *>(iter) != 0));
      if (_v) {
        return _wrap_CallMediaInfoVector_erase__SWIG_0(self, argc, argv);
      }
    }
  }
  if (argc == 3) {
    int _v;
    int res = swig::asptr(argv[0], (std::vector< pj::CallMediaInfo,std::allocator< pj::CallMediaInfo > >**)(0));
    _v = SWIG_CheckState(res);
    if (_v) {
      swig::SwigPyIterator *iter = 0;
      int res = SWIG_ConvertPtr(argv[1], SWIG_as_voidptrptr(&iter), swig::SwigPyIterator::descriptor(), 0);
      _v = (SWIG_IsOK(res) && iter && (dynamic_cast<swig::SwigPyIterator_T<std::vector< pj::CallMediaInfo >::iterator > *>(iter) != 0));
      if (_v) {
        swig::SwigPyIterator *iter = 0;
        int res = SWIG_ConvertPtr(argv[2], SWIG_as_voidptrptr(&iter), swig::SwigPyIterator::descriptor(), 0);
        _v = (SWIG_IsOK(res) && iter && (dynamic_cast<swig::SwigPyIterator_T<std::vector< pj::CallMediaInfo >::iterator > *>(iter) != 0));
        if (_v) {
          return _wrap_CallMediaInfoVector_erase__SWIG_1(self, argc, argv);
        }
      }
    }
  }
  
fail:
  SWIG_Python_RaiseOrModifyTypeError("Wrong number or type of arguments for overloaded function 'CallMediaInfoVector_erase'.\n"
    "  Possible C/C++ prototypes are:\n"
    "    std::vector< pj::CallMediaInfo >::erase(std::vector< pj::CallMediaInfo >::iterator)\n"
    "    std::vector< pj::CallMediaInfo >::erase(std::vector< pj::CallMediaInfo >::iterator,std::vector< pj::CallMediaInfo >::iterator)\n");
  return 0;
}


SWIGINTERN PyObject *_wrap_new_CallMediaInfoVector__SWIG_3(PyObject *SWIGUNUSEDPARM(self), Py_ssize_t nobjs, PyObject **swig_obj) {
  PyObject *resultobj = 0;
  std::vector< pj::CallMediaInfo >::size_type arg1 ;
  std::vector< pj::CallMediaInfo >::value_type *arg2 = 0 ;
  size_t val1 ;
  int ecode1 = 0 ;
  void *argp2 = 0 ;
  int res2 = 0 ;
  std::vector< pj::CallMediaInfo > *result = 0 ;
  
  if ((nobjs < 2) || (nobjs > 2)) SWIG_fail;
  ecode1 = SWIG_AsVal_size_t(swig_obj[0], &val1);
  if (!SWIG_IsOK(ecode1)) {
    SWIG_exception_fail(SWIG_ArgError(ecode1), "in method '" "new_CallMediaInfoVector" "', argument " "1"" of type '" "std::vector< pj::CallMediaInfo >::size_type""'");
  } 
  arg1 = static_cast< std::vector< pj::CallMediaInfo >::size_type >(val1);
  res2 = SWIG_ConvertPtr(swig_obj[1], &argp2, SWIGTYPE_p_pj__CallMediaInfo,  0  | 0);
  if (!SWIG_IsOK(res2)) {
    SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "new_CallMediaInfoVector" "', argument " "2"" of type '" "std::vector< pj::CallMediaInfo >::value_type const &""'"); 
  }
  if (!argp2) {
    SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "new_CallMediaInfoVector" "', argument " "2"" of type '" "std::vector< pj::CallMediaInfo >::value_type const &""'"); 
  }
  arg2 = reinterpret_cast< std::vector< pj::CallMediaInfo >::value_type * >(argp2);
  result = (std::vector< pj::CallMediaInfo > *)new std::vector< pj::CallMediaInfo >(arg1,(std::vector< pj::CallMediaInfo >::value_type const &)*arg2);
  resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(result), SWIGTYPE_p_std__vectorT_pj__CallMediaInfo_std__allocatorT_pj__CallMediaInfo_t_t, SWIG_POINTER_NEW |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_new_CallMediaInfoVector(PyObject *self, PyObject *args) {
  Py_ssize_t argc;
  PyObject *argv[3] = {
    0
  };
  
  if (!(argc = SWIG_Python_UnpackTuple(args, "new_CallMediaInfoVector", 0, 2, argv))) SWIG_fail;
  --argc;
  if (argc == 0) {
    return _wrap_new_CallMediaInfoVector__SWIG_0(self, argc, argv);
  }
  if (argc == 1) {
    int _v;
    {
      int res = SWIG_AsVal_size_t(argv[0], NULL);
      _v = SWIG_CheckState(res);
    }
    if (_v) {
      return _wrap_new_CallMediaInfoVector__SWIG_2(self, argc, argv);
    }
  }
  if (argc == 1) {
    int _v;
    int res = swig::asptr(argv[0], (std::vector< pj::CallMediaInfo,std::allocator< pj::CallMediaInfo > >**)(0));
    _v = SWIG_CheckState(res);
    if (_v) {
      return _wrap_new_CallMediaInfoVector__SWIG_1(self, argc, argv);
    }
  }
  if (argc == 2) {
    int _v;
    {
      int res = SWIG_AsVal_size_t(argv[0], NULL);
      _v = SWIG_CheckState(res);
    }
    if (_v) {
      int res = SWIG_ConvertPtr(argv[1], 0, SWIGTYPE_p_pj__CallMediaInfo, SWIG_POINTER_NO_NULL | 0);
      _v = SWIG_CheckState(res);
      if (_v) {
        return _wrap_new_CallMediaInfoVector__SWIG_3(self, argc, argv);
      }
    }
  }
  
fail:
  SWIG_Python_RaiseOrModifyTypeError("Wrong number or type of arguments for overloaded function 'new_CallMediaInfoVector'.\n"
    "  Possible C/C++ prototypes are:\n"
    "    std::vector< pj::CallMediaInfo >::vector()\n"
    "    std::vector< pj::CallMediaInfo >::vector(std::vector< pj::CallMediaInfo > const &)\n"
    "    std::vector< pj::CallMediaInfo >::vector(std::vector< pj::CallMediaInfo >::size_type)\n"
    "    std::vector< pj::CallMediaInfo >::vector(std::vector< pj::CallMediaInfo >::size_type,std::vector< pj::CallMediaInfo >::value_type const &)\n");
  return 0;
}


SWIGINTERN PyObject *_wrap_CallMediaInfoVector_push_back(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  std::vector< pj::CallMediaInfo > *arg1 = (std::vector< pj::CallMediaInfo > *) 0 ;
  std::vector< pj::CallMediaInfo >::value_type *arg2 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  void *argp2 = 0 ;
  int res2 = 0 ;
  PyObject *swig_obj[2] ;
  
  if (!SWIG_Python_UnpackTuple(args, "CallMediaInfoVector_push_back", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__vectorT_pj__CallMediaInfo_std__allocatorT_pj__CallMediaInfo_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "CallMediaInfoVector_push_back" "', argument " "1"" of type '" "std::vector< pj::CallMediaInfo > *""'"); 
  }
  arg1 = reinterpret_cast< std::vector< pj::CallMediaInfo > * >(argp1);
  res2 = SWIG_ConvertPtr(swig_obj[1], &argp2, SWIGTYPE_p_pj__CallMediaInfo,  0  | 0);
  if (!SWIG_IsOK(res2)) {
    SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "CallMediaInfoVector_push_back" "', argument " "2"" of type '" "std::vector< pj::CallMediaInfo >::value_type const &""'"); 
  }
  if (!argp2) {
    SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "CallMediaInfoVector_push_back" "', argument " "2"" of type '" "std::vector< pj::CallMediaInfo >::value_type const &""'"); 
  }
  arg2 = reinterpret_cast< std::vector< pj::CallMediaInfo >::value_type * >(argp2);
  (arg1)->push_back((std::vector< pj::CallMediaInfo >::value_type const &)*arg2);
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_CallMediaInfoVector_front(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  std::vector< pj::CallMediaInfo > *arg1 = (std::vector< pj::CallMediaInfo > *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  std::vector< pj::CallMediaInfo >::value_type *result = 0 ;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__vectorT_pj__CallMediaInfo_std__allocatorT_pj__CallMediaInfo_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "CallMediaInfoVector_front" "', argument " "1"" of type '" "std::vector< pj::CallMediaInfo > const *""'"); 
  }
  arg1 = reinterpret_cast< std::vector< pj::CallMediaInfo > * >(argp1);
  result = (std::vector< pj::CallMediaInfo >::value_type *) &((std::vector< pj::CallMediaInfo > const *)arg1)->front();
  resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(result), SWIGTYPE_p_pj__CallMediaInfo, 0 |  0 );
  (void)swig::container_owner<swig::traits<std::vector< pj::CallMediaInfo >::value_type>::category>::back_reference(resultobj, swig_obj[0]);
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_CallMediaInfoVector_back(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  std::vector< pj::CallMediaInfo > *arg1 = (std::vector< pj::CallMediaInfo > *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  std::vector< pj::CallMediaInfo >::value_type *result = 0 ;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__vectorT_pj__CallMediaInfo_std__allocatorT_pj__CallMediaInfo_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "CallMediaInfoVector_back" "', argument " "1"" of type '" "std::vector< pj::CallMediaInfo > const *""'"); 
  }
  arg1 = reinterpret_cast< std::vector< pj::CallMediaInfo > * >(argp1);
  result = (std::vector< pj::CallMediaInfo >::value_type *) &((std::vector< pj::CallMediaInfo > const *)arg1)->back();
  resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(result), SWIGTYPE_p_pj__CallMediaInfo, 0 |  0 );
  (void)swig::container_owner<swig::traits<std::vector< pj::CallMediaInfo >::value_type>::category>::back_reference(resultobj, swig_obj[0]);
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_CallMediaInfoVector_assign(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  std::vector< pj::CallMediaInfo > *arg1 = (std::vector< pj::CallMediaInfo > *) 0 ;
  std::vector< pj::CallMediaInfo >::size_type arg2 ;
  std::vector< pj::CallMediaInfo >::value_type *arg3 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  size_t val2 ;
  int ecode2 = 0 ;
  void *argp3 = 0 ;
  int res3 = 0 ;
  PyObject *swig_obj[3] ;
  
  if (!SWIG_Python_UnpackTuple(args, "CallMediaInfoVector_assign", 3, 3, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__vectorT_pj__CallMediaInfo_std__allocatorT_pj__CallMediaInfo_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "CallMediaInfoVector_assign" "', argument " "1"" of type '" "std::vector< pj::CallMediaInfo > *""'"); 
  }
  arg1 = reinterpret_cast< std::vector< pj::CallMediaInfo > * >(argp1);
  ecode2 = SWIG_AsVal_size_t(swig_obj[1], &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "CallMediaInfoVector_assign" "', argument " "2"" of type '" "std::vector< pj::CallMediaInfo >::size_type""'");
  } 
  arg2 = static_cast< std::vector< pj::CallMediaInfo >::size_type >(val2);
  res3 = SWIG_ConvertPtr(swig_obj[2], &argp3, SWIGTYPE_p_pj__CallMediaInfo,  0  | 0);
  if (!SWIG_IsOK(res3)) {
    SWIG_exception_fail(SWIG_ArgError(res3), "in method '" "CallMediaInfoVector_assign" "', argument " "3"" of type '" "std::vector< pj::CallMediaInfo >::value_type const &""'"); 
  }
  if (!argp3) {
    SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "CallMediaInfoVector_assign" "', argument " "3"" of type '" "std::vector< pj::CallMediaInfo >::value_type const &""'"); 
  }
  arg3 = reinterpret_cast< std::vector< pj::CallMediaInfo >::value_type * >(argp3);
  (arg1)->assign(arg2,(std::vector< pj::CallMediaInfo >::value_type const &)*arg3);
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_CallMediaInfoVector_resize__SWIG_1(PyObject *SWIGUNUSEDPARM(self), Py_ssize_t nobjs, PyObject **swig_obj) {
  PyObject *resultobj = 0;
  std::vector< pj::CallMediaInfo > *arg1 = (std::vector< pj::CallMediaInfo > *) 0 ;
  std::vector< pj::CallMediaInfo >::size_type arg2 ;
  std::vector< pj::CallMediaInfo >::value_type *arg3 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  size_t val2 ;
  int ecode2 = 0 ;
  void *argp3 = 0 ;
  int res3 = 0 ;
  
  if ((nobjs < 3) || (nobjs > 3)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__vectorT_pj__CallMediaInfo_std__allocatorT_pj__CallMediaInfo_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "CallMediaInfoVector_resize" "', argument " "1"" of type '" "std::vector< pj::CallMediaInfo > *""'"); 
  }
  arg1 = reinterpret_cast< std::vector< pj::CallMediaInfo > * >(argp1);
  ecode2 = SWIG_AsVal_size_t(swig_obj[1], &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "CallMediaInfoVector_resize" "', argument " "2"" of type '" "std::vector< pj::CallMediaInfo >::size_type""'");
  } 
  arg2 = static_cast< std::vector< pj::CallMediaInfo >::size_type >(val2);
  res3 = SWIG_ConvertPtr(swig_obj[2], &argp3, SWIGTYPE_p_pj__CallMediaInfo,  0  | 0);
  if (!SWIG_IsOK(res3)) {
    SWIG_exception_fail(SWIG_ArgError(res3), "in method '" "CallMediaInfoVector_resize" "', argument " "3"" of type '" "std::vector< pj::CallMediaInfo >::value_type const &""'"); 
  }
  if (!argp3) {
    SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "CallMediaInfoVector_resize" "', argument " "3"" of type '" "std::vector< pj::CallMediaInfo >::value_type const &""'"); 
  }
  arg3 = reinterpret_cast< std::vector< pj::CallMediaInfo >::value_type * >(argp3);
  (arg1)->resize(arg2,(std::vector< pj::CallMediaInfo >::value_type const &)*arg3);
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_CallMediaInfoVector_resize(PyObject *self, PyObject *args) {
  Py_ssize_t argc;
  PyObject *argv[4] = {
    0
  };
  
  if (!(argc = SWIG_Python_UnpackTuple(args, "CallMediaInfoVector_resize", 0, 3, argv))) SWIG_fail;
  --argc;
  if (argc == 2) {
    int _v;
    int res = swig::asptr(argv[0], (std::vector< pj::CallMediaInfo,std::allocator< pj::CallMediaInfo > >**)(0));
    _v = SWIG_CheckState(res);
    if (_v) {
      {
        int res = SWIG_AsVal_size_t(argv[1], NULL);
        _v = SWIG_CheckState(res);
      }
      if (_v) {
        return _wrap_CallMediaInfoVector_resize__SWIG_0(self, argc, argv);
      }
    }
  }
  if (argc == 3) {
    int _v;
    int res = swig::asptr(argv[0], (std::vector< pj::CallMediaInfo,std::allocator< pj::CallMediaInfo > >**)(0));
    _v = SWIG_CheckState(res);
    if (_v) {
      {
        int res = SWIG_AsVal_size_t(argv[1], NULL);
        _v = SWIG_CheckState(res);
      }
      if (_v) {
        int res = SWIG_ConvertPtr(argv[2], 0, SWIGTYPE_p_pj__CallMediaInfo, SWIG_POINTER_NO_NULL | 0);
        _v = SWIG_CheckState(res);
        if (_v) {
          return _wrap_CallMediaInfoVector_resize__SWIG_1(self, argc, argv);
        }
      }
    }
  }
  
fail:
  SWIG_Python_RaiseOrModifyTypeError("Wrong number or type of arguments for overloaded function 'CallMediaInfoVector_resize'.\n"
    "  Possible C/C++ prototypes are:\n"
    "    std::vector< pj::CallMediaInfo >::resize(std::vector< pj::CallMediaInfo >::size_type)\n"
    "    std::vector< pj::CallMediaInfo >::resize(std::vector< pj::CallMediaInfo >::size_type,std::vector< pj::CallMediaInfo >::value_type const &)\n");
  return 0;
}


SWIGINTERN PyObject *_wrap_CallMediaInfoVector_insert__SWIG_0(PyObject *SWIGUNUSEDPARM(self), Py_ssize_t nobjs, PyObject **swig_obj) {
  PyObject *resultobj = 0;
  std::vector< pj::CallMediaInfo > *arg1 = (std::vector< pj::CallMediaInfo > *) 0 ;
  std::vector< pj::CallMediaInfo >::iterator arg2 ;
  std::vector< pj::CallMediaInfo >::value_type *arg3 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  swig::SwigPyIterator *iter2 = 0 ;
  int res2 ;
  void *argp3 = 0 ;
  int res3 = 0 ;
  std::vector< pj::CallMediaInfo >::iterator result;
  
  if ((nobjs < 3) || (nobjs > 3)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__vectorT_pj__CallMediaInfo_std__allocatorT_pj__CallMediaInfo_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "CallMediaInfoVector_insert" "', argument " "1"" of type '" "std::vector< pj::CallMediaInfo > *""'"); 
  }
  arg1 = reinterpret_cast< std::vector< pj::CallMediaInfo > * >(argp1);
  res2 = SWIG_ConvertPtr(swig_obj[1], SWIG_as_voidptrptr(&iter2), swig::SwigPyIterator::descriptor(), 0);
  if (!SWIG_IsOK(res2) || !iter2) {
    SWIG_exception_fail(SWIG_ArgError(SWIG_TypeError), "in method '" "CallMediaInfoVector_insert" "', argument " "2"" of type '" "std::vector< pj::CallMediaInfo >::iterator""'");
  } else {
    swig::SwigPyIterator_T<std::vector< pj::CallMediaInfo >::iterator > *iter_t = dynamic_cast<swig::SwigPyIterator_T<std::vector< pj::CallMediaInfo >::iterator > *>(iter2);
    if (iter_t) {
      arg2 = iter_t->get_current();
    } else {
      SWIG_exception_fail(SWIG_ArgError(SWIG_TypeError), "in method '" "CallMediaInfoVector_insert" "', argument " "2"" of type '" "std::vector< pj::CallMediaInfo >::iterator""'");
    }
  }
  res3 = SWIG_ConvertPtr(swig_obj[2], &argp3, SWIGTYPE_p_pj__CallMediaInfo,  0  | 0);
  if (!SWIG_IsOK(res3)) {
    SWIG_exception_fail(SWIG_ArgError(res3), "in method '" "CallMediaInfoVector_insert" "', argument " "3"" of type '" "std::vector< pj::CallMediaInfo >::value_type const &""'"); 
  }
  if (!argp3) {
    SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "CallMediaInfoVector_insert" "', argument " "3"" of type '" "std::vector< pj::CallMediaInfo >::value_type const &""'"); 
  }
  arg3 = reinterpret_cast< std::vector< pj::CallMediaInfo >::value_type * >(argp3);
  result = std_vector_Sl_pj_CallMediaInfo_Sg__insert__SWIG_0(arg1,arg2,(pj::CallMediaInfo const &)*arg3);
  resultobj = SWIG_NewPointerObj(swig::make_output_iterator(static_cast< const std::vector< pj::CallMediaInfo >::iterator & >(result)),
    swig::SwigPyIterator::descriptor(),SWIG_POINTER_OWN);
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_CallMediaInfoVector_insert__SWIG_1(PyObject *SWIGUNUSEDPARM(self), Py_ssize_t nobjs, PyObject **swig_obj) {
  PyObject *resultobj = 0;
  std::vector< pj::CallMediaInfo > *arg1 = (std::vector< pj::CallMediaInfo > *) 0 ;
  std::vector< pj::CallMediaInfo >::iterator arg2 ;
  std::vector< pj::CallMediaInfo >::size_type arg3 ;
  std::vector< pj::CallMediaInfo >::value_type *arg4 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  swig::SwigPyIterator *iter2 = 0 ;
  int res2 ;
  size_t val3 ;
  int ecode3 = 0 ;
  void *argp4 = 0 ;
  int res4 = 0 ;
  
  if ((nobjs < 4) || (nobjs > 4)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__vectorT_pj__CallMediaInfo_std__allocatorT_pj__CallMediaInfo_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "CallMediaInfoVector_insert" "', argument " "1"" of type '" "std::vector< pj::CallMediaInfo > *""'"); 
  }
  arg1 = reinterpret_cast< std::vector< pj::CallMediaInfo > * >(argp1);
  res2 = SWIG_ConvertPtr(swig_obj[1], SWIG_as_voidptrptr(&iter2), swig::SwigPyIterator::descriptor(), 0);
  if (!SWIG_IsOK(res2) || !iter2) {
    SWIG_exception_fail(SWIG_ArgError(SWIG_TypeError), "in method '" "CallMediaInfoVector_insert" "', argument " "2"" of type '" "std::vector< pj::CallMediaInfo >::iterator""'");
  } else {
    swig::SwigPyIterator_T<std::vector< pj::CallMediaInfo >::iterator > *iter_t = dynamic_cast<swig::SwigPyIterator_T<std::vector< pj::CallMediaInfo >::iterator > *>(iter2);
    if (iter_t) {
      arg2 = iter_t->get_current();
    } else {
      SWIG_exception_fail(SWIG_ArgError(SWIG_TypeError), "in method '" "CallMediaInfoVector_insert" "', argument " "2"" of type '" "std::vector< pj::CallMediaInfo >::iterator""'");
    }
  }
  ecode3 = SWIG_AsVal_size_t(swig_obj[2], &val3);
  if (!SWIG_IsOK(ecode3)) {
    SWIG_exception_fail(SWIG_ArgError(ecode3), "in method '" "CallMediaInfoVector_insert" "', argument " "3"" of type '" "std::vector< pj::CallMediaInfo >::size_type""'");
  } 
  arg3 = static_cast< std::vector< pj::CallMediaInfo >::size_type >(val3);
  res4 = SWIG_ConvertPtr(swig_obj[3], &argp4, SWIGTYPE_p_pj__CallMediaInfo,  0  | 0);
  if (!SWIG_IsOK(res4)) {
    SWIG_exception_fail(SWIG_ArgError(res4), "in method '" "CallMediaInfoVector_insert" "', argument " "4"" of type '" "std::vector< pj::CallMediaInfo >::value_type const &""'"); 
  }
  if (!argp4) {
    SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "CallMediaInfoVector_insert" "', argument " "4"" of type '" "std::vector< pj::CallMediaInfo >::value_type const &""'"); 
  }
  arg4 = reinterpret_cast< std::vector< pj::CallMediaInfo >::value_type * >(argp4);
  std_vector_Sl_pj_CallMediaInfo_Sg__insert__SWIG_1(arg1,arg2,arg3,(pj::CallMediaInfo const &)*arg4);
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_CallMediaInfoVector_insert(PyObject *self, PyObject *args) {
  Py_ssize_t argc;
  PyObject *argv[5] = {
    0
  };
  
  if (!(argc = SWIG_Python_UnpackTuple(args, "CallMediaInfoVector_insert", 0, 4, argv))) SWIG_fail;
  --argc;
  if (argc == 3) {
    int _v;
    int res = swig::asptr(argv[0], (std::vector< pj::CallMediaInfo,std::allocator< pj::CallMediaInfo > >**)(0));
    _v = SWIG_CheckState(res);
    if (_v) {
      swig::SwigPyIterator *iter = 0;
      int res = SWIG_ConvertPtr(argv[1], SWIG_as_voidptrptr(&iter), swig::SwigPyIterator::descriptor(), 0);
      _v = (SWIG_IsOK(res) && iter && (dynamic_cast<swig::SwigPyIterator_T<std::vector< pj::CallMediaInfo >::iterator > *>(iter) != 0));
      if (_v) {
        int res = SWIG_ConvertPtr(argv[2], 0, SWIGTYPE_p_pj__CallMediaInfo, SWIG_POINTER_NO_NULL | 0);
        _v = SWIG_CheckState(res);
        if (_v) {
          return _wrap_CallMediaInfoVector_insert__SWIG_0(self, argc, argv);
        }
      }
    }
  }
  if (argc == 4) {
    int _v;
    int res = swig::asptr(argv[0], (std::vector< pj::CallMediaInfo,std::allocator< pj::CallMediaInfo > >**)(0));
    _v = SWIG_CheckState(res);
    if (_v) {
      swig::SwigPyIterator *iter = 0;
      int res = SWIG_ConvertPtr(argv[1], SWIG_as_voidptrptr(&iter), swig::SwigPyIterator::descriptor(), 0);
      _v = (SWIG_IsOK(res) && iter && (dynamic_cast<swig::SwigPyIterator_T<std::vector< pj::CallMediaInfo >::iterator > *>(iter) != 0));
      if (_v) {
        {
          int res = SWIG_AsVal_size_t(argv[2], NULL);
          _v = SWIG_CheckState(res);
        }
        if (_v) {
          int res = SWIG_ConvertPtr(argv[3], 0, SWIGTYPE_p_pj__CallMediaInfo, SWIG_POINTER_NO_NULL | 0);
          _v = SWIG_CheckState(res);
          if (_v) {
            return _wrap_CallMediaInfoVector_insert__SWIG_1(self, argc, argv);
          }
        }
      }
    }
  }
  
fail:
  SWIG_Python_RaiseOrModifyTypeError("Wrong number or type of arguments for overloaded function 'CallMediaInfoVector_insert'.\n"
    "  Possible C/C++ prototypes are:\n"
    "    std::vector< pj::CallMediaInfo >::insert(std::vector< pj::CallMediaInfo >::iterator,std::vector< pj::CallMediaInfo >::value_type const &)\n"
    "    std::vector< pj::CallMediaInfo >::insert(std::vector< pj::CallMediaInfo >::iterator,std::vector< pj::CallMediaInfo >::size_type,std::vector< pj::CallMediaInfo >::value_type const &)\n");
  return 0;
}


SWIGINTERN PyObject *_wrap_CallMediaInfoVector_reserve(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  std::vector< pj::CallMediaInfo > *arg1 = (std::vector< pj::CallMediaInfo > *) 0 ;
  std::vector< pj::CallMediaInfo >::size_type arg2 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  size_t val2 ;
  int ecode2 = 0 ;
  PyObject *swig_obj[2] ;
  
  if (!SWIG_Python_UnpackTuple(args, "CallMediaInfoVector_reserve", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__vectorT_pj__CallMediaInfo_std__allocatorT_pj__CallMediaInfo_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "CallMediaInfoVector_reserve" "', argument " "1"" of type '" "std::vector< pj::CallMediaInfo > *""'"); 
  }
  arg1 = reinterpret_cast< std::vector< pj::CallMediaInfo > * >(argp1);
  ecode2 = SWIG_AsVal_size_t(swig_obj[1], &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "CallMediaInfoVector_reserve" "', argument " "2"" of type '" "std::vector< pj::CallMediaInfo >::size_type""'");
  } 
  arg2 = static_cast< std::vector< pj::CallMediaInfo >::size_type >(val2);
  (arg1)->reserve(arg2);
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_CallMediaInfoVector_capacity(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  std::vector< pj::CallMediaInfo > *arg1 = (std::vector< pj::CallMediaInfo > *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  std::vector< pj::CallMediaInfo >::size_type result;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__vectorT_pj__CallMediaInfo_std__allocatorT_pj__CallMediaInfo_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "CallMediaInfoVector_capacity" "', argument " "1"" of type '" "std::vector< pj::CallMediaInfo > const *""'"); 
  }
  arg1 = reinterpret_cast< std::vector< pj::CallMediaInfo > * >(argp1);
  result = ((std::vector< pj::CallMediaInfo > const *)arg1)->capacity();
  resultobj = SWIG_From_size_t(static_cast< size_t >(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_delete_CallMediaInfoVector(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  std::vector< pj::CallMediaInfo > *arg1 = (std::vector< pj::CallMediaInfo > *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__vectorT_pj__CallMediaInfo_std__allocatorT_pj__CallMediaInfo_t_t, SWIG_POINTER_DISOWN |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "delete_CallMediaInfoVector" "', argument " "1"" of type '" "std::vector< pj::CallMediaInfo > *""'"); 
  }
  arg1 = reinterpret_cast< std::vector< pj::CallMediaInfo > * >(argp1);
  delete arg1;
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *CallMediaInfoVector_swigregister(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *obj;
  if (!SWIG_Python_UnpackTuple(args, "swigregister", 1, 1, &obj)) return NULL;
  SWIG_TypeNewClientData(SWIGTYPE_p_std__vectorT_pj__CallMediaInfo_std__allocatorT_pj__CallMediaInfo_t_t, SWIG_NewClientData(obj));
  return SWIG_Py_Void();
}

SWIGINTERN PyObject *CallMediaInfoVector_swiginit(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  return SWIG_Python_InitShadowInstance(args);
}

SWIGINTERN PyObject *_wrap_RtcpFbCapVector_iterator(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  std::vector< pj::RtcpFbCap > *arg1 = (std::vector< pj::RtcpFbCap > *) 0 ;
  PyObject **arg2 = (PyObject **) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  swig::SwigPyIterator *result = 0 ;
  
  arg2 = &swig_obj[0];
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__vectorT_pj__RtcpFbCap_std__allocatorT_pj__RtcpFbCap_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "RtcpFbCapVector_iterator" "', argument " "1"" of type '" "std::vector< pj::RtcpFbCap > *""'"); 
  }
  arg1 = reinterpret_cast< std::vector< pj::RtcpFbCap > * >(argp1);
  result = (swig::SwigPyIterator *)std_vector_Sl_pj_RtcpFbCap_Sg__iterator(arg1,arg2);
  resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(result), SWIGTYPE_p_swig__SwigPyIterator, SWIG_POINTER_OWN |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_RtcpFbCapVector___nonzero__(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  std::vector< pj::RtcpFbCap > *arg1 = (std::vector< pj::RtcpFbCap > *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  bool result;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__vectorT_pj__RtcpFbCap_std__allocatorT_pj__RtcpFbCap_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "RtcpFbCapVector___nonzero__" "', argument " "1"" of type '" "std::vector< pj::RtcpFbCap > const *""'"); 
  }
  arg1 = reinterpret_cast< std::vector< pj::RtcpFbCap > * >(argp1);
  result = (bool)std_vector_Sl_pj_RtcpFbCap_Sg____nonzero__((std::vector< pj::RtcpFbCap > const *)arg1);
  resultobj = SWIG_From_bool(static_cast< bool >(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_RtcpFbCapVector___bool__(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  std::vector< pj::RtcpFbCap > *arg1 = (std::vector< pj::RtcpFbCap > *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  bool result;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__vectorT_pj__RtcpFbCap_std__allocatorT_pj__RtcpFbCap_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "RtcpFbCapVector___bool__" "', argument " "1"" of type '" "std::vector< pj::RtcpFbCap > const *""'"); 
  }
  arg1 = reinterpret_cast< std::vector< pj::RtcpFbCap > * >(argp1);
  result = (bool)std_vector_Sl_pj_RtcpFbCap_Sg____bool__((std::vector< pj::RtcpFbCap > const *)arg1);
  resultobj = SWIG_From_bool(static_cast< bool >(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_RtcpFbCapVector___len__(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  std::vector< pj::RtcpFbCap > *arg1 = (std::vector< pj::RtcpFbCap > *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  std::vector< pj::RtcpFbCap >::size_type result;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__vectorT_pj__RtcpFbCap_std__allocatorT_pj__RtcpFbCap_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "RtcpFbCapVector___len__" "', argument " "1"" of type '" "std::vector< pj::RtcpFbCap > const *""'"); 
  }
  arg1 = reinterpret_cast< std::vector< pj::RtcpFbCap > * >(argp1);
  result = std_vector_Sl_pj_RtcpFbCap_Sg____len__((std::vector< pj::RtcpFbCap > const *)arg1);
  resultobj = SWIG_From_size_t(static_cast< size_t >(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_RtcpFbCapVector___getslice__(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  std::vector< pj::RtcpFbCap > *arg1 = (std::vector< pj::RtcpFbCap > *) 0 ;
  std::vector< pj::RtcpFbCap >::difference_type arg2 ;
  std::vector< pj::RtcpFbCap >::difference_type arg3 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  ptrdiff_t val2 ;
  int ecode2 = 0 ;
  ptrdiff_t val3 ;
  int ecode3 = 0 ;
  PyObject *swig_obj[3] ;
  std::vector< pj::RtcpFbCap,std::allocator< pj::RtcpFbCap > > *result = 0 ;
  
  if (!SWIG_Python_UnpackTuple(args, "RtcpFbCapVector___getslice__", 3, 3, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__vectorT_pj__RtcpFbCap_std__allocatorT_pj__RtcpFbCap_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "RtcpFbCapVector___getslice__" "', argument " "1"" of type '" "std::vector< pj::RtcpFbCap > *""'"); 
  }
  arg1 = reinterpret_cast< std::vector< pj::RtcpFbCap > * >(argp1);
  ecode2 = SWIG_AsVal_ptrdiff_t(swig_obj[1], &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "RtcpFbCapVector___getslice__" "', argument " "2"" of type '" "std::vector< pj::RtcpFbCap >::difference_type""'");
  } 
  arg2 = static_cast< std::vector< pj::RtcpFbCap >::difference_type >(val2);
  ecode3 = SWIG_AsVal_ptrdiff_t(swig_obj[2], &val3);
  if (!SWIG_IsOK(ecode3)) {
    SWIG_exception_fail(SWIG_ArgError(ecode3), "in method '" "RtcpFbCapVector___getslice__" "', argument " "3"" of type '" "std::vector< pj::RtcpFbCap >::difference_type""'");
  } 
  arg3 = static_cast< std::vector< pj::RtcpFbCap >::difference_type >(val3);
  try {
    result = (std::vector< pj::RtcpFbCap,std::allocator< pj::RtcpFbCap > > *)std_vector_Sl_pj_RtcpFbCap_Sg____getslice__(arg1,arg2,arg3);
  } catch(std::out_of_range &_e) {
    SWIG_exception_fail(SWIG_IndexError, (&_e)->what());
  } catch(std::invalid_argument &_e) {
    SWIG_exception_fail(SWIG_ValueError, (&_e)->what());
  }
  resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(result), SWIGTYPE_p_std__vectorT_pj__RtcpFbCap_std__allocatorT_pj__RtcpFbCap_t_t, SWIG_POINTER_OWN |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_RtcpFbCapVector___setslice____SWIG_0(PyObject *SWIGUNUSEDPARM(self), Py_ssize_t nobjs, PyObject **swig_obj) {
  PyObject *resultobj = 0;
  std::vector< pj::RtcpFbCap > *arg1 = (std::vector< pj::RtcpFbCap > *) 0 ;
  std::vector< pj::RtcpFbCap >::difference_type arg2 ;
  std::vector< pj::RtcpFbCap >::difference_type arg3 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  ptrdiff_t val2 ;
  int ecode2 = 0 ;
  ptrdiff_t val3 ;
  int ecode3 = 0 ;
  
  if ((nobjs < 3) || (nobjs > 3)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__vectorT_pj__RtcpFbCap_std__allocatorT_pj__RtcpFbCap_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "RtcpFbCapVector___setslice__" "', argument " "1"" of type '" "std::vector< pj::RtcpFbCap > *""'"); 
  }
  arg1 = reinterpret_cast< std::vector< pj::RtcpFbCap > * >(argp1);
  ecode2 = SWIG_AsVal_ptrdiff_t(swig_obj[1], &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "RtcpFbCapVector___setslice__" "', argument " "2"" of type '" "std::vector< pj::RtcpFbCap >::difference_type""'");
  } 
  arg2 = static_cast< std::vector< pj::RtcpFbCap >::difference_type >(val2);
  ecode3 = SWIG_AsVal_ptrdiff_t(swig_obj[2], &val3);
  if (!SWIG_IsOK(ecode3)) {
    SWIG_exception_fail(SWIG_ArgError(ecode3), "in method '" "RtcpFbCapVector___setslice__" "', argument " "3"" of type '" "std::vector< pj::RtcpFbCap >::difference_type""'");
  } 
  arg3 = static_cast< std::vector< pj::RtcpFbCap >::difference_type >(val3);
  try {
    std_vector_Sl_pj_RtcpFbCap_Sg____setslice____SWIG_0(arg1,arg2,arg3);
  } catch(std::out_of_range &_e) {
    SWIG_exception_fail(SWIG_IndexError, (&_e)->what());
  } catch(std::invalid_argument &_e) {
    SWIG_exception_fail(SWIG_ValueError, (&_e)->what());
  }
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_RtcpFbCapVector___setslice____SWIG_1(PyObject *SWIGUNUSEDPARM(self), Py_ssize_t nobjs, PyObject **swig_obj) {
  PyObject *resultobj = 0;
  std::vector< pj::RtcpFbCap > *arg1 = (std::vector< pj::RtcpFbCap > *) 0 ;
  std::vector< pj::RtcpFbCap >::difference_type arg2 ;
  std::vector< pj::RtcpFbCap >::difference_type arg3 ;
  std::vector< pj::RtcpFbCap,std::allocator< pj::RtcpFbCap > > *arg4 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  ptrdiff_t val2 ;
  int ecode2 = 0 ;
  ptrdiff_t val3 ;
  int ecode3 = 0 ;
  int res4 = SWIG_OLDOBJ ;
  
  if ((nobjs < 4) || (nobjs > 4)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__vectorT_pj__RtcpFbCap_std__allocatorT_pj__RtcpFbCap_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "RtcpFbCapVector___setslice__" "', argument " "1"" of type '" "std::vector< pj::RtcpFbCap > *""'"); 
  }
  arg1 = reinterpret_cast< std::vector< pj::RtcpFbCap > * >(argp1);
  ecode2 = SWIG_AsVal_ptrdiff_t(swig_obj[1], &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "RtcpFbCapVector___setslice__" "', argument " "2"" of type '" "std::vector< pj::RtcpFbCap >::difference_type""'");
  } 
  arg2 = static_cast< std::vector< pj::RtcpFbCap >::difference_type >(val2);
  ecode3 = SWIG_AsVal_ptrdiff_t(swig_obj[2], &val3);
  if (!SWIG_IsOK(ecode3)) {
    SWIG_exception_fail(SWIG_ArgError(ecode3), "in method '" "RtcpFbCapVector___setslice__" "', argument " "3"" of type '" "std::vector< pj::RtcpFbCap >::difference_type""'");
  } 
  arg3 = static_cast< std::vector< pj::RtcpFbCap >::difference_type >(val3);
  {
    std::vector< pj::RtcpFbCap,std::allocator< pj::RtcpFbCap > > *ptr = (std::vector< pj::RtcpFbCap,std::allocator< pj::RtcpFbCap > > *)0;
    res4 = swig::asptr(swig_obj[3], &ptr);
    if (!SWIG_IsOK(res4)) {
      SWIG_exception_fail(SWIG_ArgError(res4), "in method '" "RtcpFbCapVector___setslice__" "', argument " "4"" of type '" "std::vector< pj::RtcpFbCap,std::allocator< pj::RtcpFbCap > > const &""'"); 
    }
    if (!ptr) {
      SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "RtcpFbCapVector___setslice__" "', argument " "4"" of type '" "std::vector< pj::RtcpFbCap,std::allocator< pj::RtcpFbCap > > const &""'"); 
    }
    arg4 = ptr;
  }
  try {
    std_vector_Sl_pj_RtcpFbCap_Sg____setslice____SWIG_1(arg1,arg2,arg3,(std::vector< pj::RtcpFbCap,std::allocator< pj::RtcpFbCap > > const &)*arg4);
  } catch(std::out_of_range &_e) {
    SWIG_exception_fail(SWIG_IndexError, (&_e)->what());
  } catch(std::invalid_argument &_e) {
    SWIG_exception_fail(SWIG_ValueError, (&_e)->what());
  }
  resultobj = SWIG_Py_Void();
  if (SWIG_IsNewObj(res4)) delete arg4;
  return resultobj;
fail:
  if (SWIG_IsNewObj(res4)) delete arg4;
  return NULL;
}


SWIGINTERN PyObject *_wrap_RtcpFbCapVector___setslice__(PyObject *self, PyObject *args) {
  Py_ssize_t argc;
  PyObject *argv[5] = {
    0
  };
  
  if (!(argc = SWIG_Python_UnpackTuple(args, "RtcpFbCapVector___setslice__", 0, 4, argv))) SWIG_fail;
  --argc;
  if (argc == 3) {
    int _v;
    int res = swig::asptr(argv[0], (std::vector< pj::RtcpFbCap,std::allocator< pj::RtcpFbCap > >**)(0));
    _v = SWIG_CheckState(res);
    if (_v) {
      {
        int res = SWIG_AsVal_ptrdiff_t(argv[1], NULL);
        _v = SWIG_CheckState(res);
      }
      if (_v) {
        {
          int res = SWIG_AsVal_ptrdiff_t(argv[2], NULL);
          _v = SWIG_CheckState(res);
        }
        if (_v) {
          return _wrap_RtcpFbCapVector___setslice____SWIG_0(self, argc, argv);
        }
      }
    }
  }
  if (argc == 4) {
    int _v;
    int res = swig::asptr(argv[0], (std::vector< pj::RtcpFbCap,std::allocator< pj::RtcpFbCap > >**)(0));
    _v = SWIG_CheckState(res);
    if (_v) {
      {
        int res = SWIG_AsVal_ptrdiff_t(argv[1], NULL);
        _v = SWIG_CheckState(res);
      }
      if (_v) {
        {
          int res = SWIG_AsVal_ptrdiff_t(argv[2], NULL);
          _v = SWIG_CheckState(res);
        }
        if (_v) {
          int res = swig::asptr(argv[3], (std::vector< pj::RtcpFbCap,std::allocator< pj::RtcpFbCap > >**)(0));
          _v = SWIG_CheckState(res);
          if (_v) {
            return _wrap_RtcpFbCapVector___setslice____SWIG_1(self, argc, argv);
          }
        }
      }
    }
  }
  
fail:
  SWIG_Python_RaiseOrModifyTypeError("Wrong number or type of arguments for overloaded function 'RtcpFbCapVector___setslice__'.\n"
    "  Possible C/C++ prototypes are:\n"
    "    std::vector< pj::RtcpFbCap >::__setslice__(std::vector< pj::RtcpFbCap >::difference_type,std::vector< pj::RtcpFbCap >::difference_type)\n"
    "    std::vector< pj::RtcpFbCap >::__setslice__(std::vector< pj::RtcpFbCap >::difference_type,std::vector< pj::RtcpFbCap >::difference_type,std::vector< pj::RtcpFbCap,std::allocator< pj::RtcpFbCap > > const &)\n");
  return 0;
}


SWIGINTERN PyObject *_wrap_RtcpFbCapVector___delslice__(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  std::vector< pj::RtcpFbCap > *arg1 = (std::vector< pj::RtcpFbCap > *) 0 ;
  std::vector< pj::RtcpFbCap >::difference_type arg2 ;
  std::vector< pj::RtcpFbCap >::difference_type arg3 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  ptrdiff_t val2 ;
  int ecode2 = 0 ;
  ptrdiff_t val3 ;
  int ecode3 = 0 ;
  PyObject *swig_obj[3] ;
  
  if (!SWIG_Python_UnpackTuple(args, "RtcpFbCapVector___delslice__", 3, 3, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__vectorT_pj__RtcpFbCap_std__allocatorT_pj__RtcpFbCap_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "RtcpFbCapVector___delslice__" "', argument " "1"" of type '" "std::vector< pj::RtcpFbCap > *""'"); 
  }
  arg1 = reinterpret_cast< std::vector< pj::RtcpFbCap > * >(argp1);
  ecode2 = SWIG_AsVal_ptrdiff_t(swig_obj[1], &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "RtcpFbCapVector___delslice__" "', argument " "2"" of type '" "std::vector< pj::RtcpFbCap >::difference_type""'");
  } 
  arg2 = static_cast< std::vector< pj::RtcpFbCap >::difference_type >(val2);
  ecode3 = SWIG_AsVal_ptrdiff_t(swig_obj[2], &val3);
  if (!SWIG_IsOK(ecode3)) {
    SWIG_exception_fail(SWIG_ArgError(ecode3), "in method '" "RtcpFbCapVector___delslice__" "', argument " "3"" of type '" "std::vector< pj::RtcpFbCap >::difference_type""'");
  } 
  arg3 = static_cast< std::vector< pj::RtcpFbCap >::difference_type >(val3);
  try {
    std_vector_Sl_pj_RtcpFbCap_Sg____delslice__(arg1,arg2,arg3);
  } catch(std::out_of_range &_e) {
    SWIG_exception_fail(SWIG_IndexError, (&_e)->what());
  } catch(std::invalid_argument &_e) {
    SWIG_exception_fail(SWIG_ValueError, (&_e)->what());
  }
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_RtcpFbCapVector___delitem____SWIG_0(PyObject *SWIGUNUSEDPARM(self), Py_ssize_t nobjs, PyObject **swig_obj) {
  PyObject *resultobj = 0;
  std::vector< pj::RtcpFbCap > *arg1 = (std::vector< pj::RtcpFbCap > *) 0 ;
  std::vector< pj::RtcpFbCap >::difference_type arg2 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  ptrdiff_t val2 ;
  int ecode2 = 0 ;
  
  if ((nobjs < 2) || (nobjs > 2)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__vectorT_pj__RtcpFbCap_std__allocatorT_pj__RtcpFbCap_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "RtcpFbCapVector___delitem__" "', argument " "1"" of type '" "std::vector< pj::RtcpFbCap > *""'"); 
  }
  arg1 = reinterpret_cast< std::vector< pj::RtcpFbCap > * >(argp1);
  ecode2 = SWIG_AsVal_ptrdiff_t(swig_obj[1], &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "RtcpFbCapVector___delitem__" "', argument " "2"" of type '" "std::vector< pj::RtcpFbCap >::difference_type""'");
  } 
  arg2 = static_cast< std::vector< pj::RtcpFbCap >::difference_type >(val2);
  try {
    std_vector_Sl_pj_RtcpFbCap_Sg____delitem____SWIG_0(arg1,arg2);
  } catch(std::out_of_range &_e) {
    SWIG_exception_fail(SWIG_IndexError, (&_e)->what());
  } catch(std::invalid_argument &_e) {
    SWIG_exception_fail(SWIG_ValueError, (&_e)->what());
  }
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_RtcpFbCapVector___getitem____SWIG_0(PyObject *SWIGUNUSEDPARM(self), Py_ssize_t nobjs, PyObject **swig_obj) {
  PyObject *resultobj = 0;
  std::vector< pj::RtcpFbCap > *arg1 = (std::vector< pj::RtcpFbCap > *) 0 ;
  PySliceObject *arg2 = (PySliceObject *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  std::vector< pj::RtcpFbCap,std::allocator< pj::RtcpFbCap > > *result = 0 ;
  
  if ((nobjs < 2) || (nobjs > 2)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__vectorT_pj__RtcpFbCap_std__allocatorT_pj__RtcpFbCap_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "RtcpFbCapVector___getitem__" "', argument " "1"" of type '" "std::vector< pj::RtcpFbCap > *""'"); 
  }
  arg1 = reinterpret_cast< std::vector< pj::RtcpFbCap > * >(argp1);
  {
    if (!PySlice_Check(swig_obj[1])) {
      SWIG_exception_fail(SWIG_ArgError(SWIG_TypeError), "in method '" "RtcpFbCapVector___getitem__" "', argument " "2"" of type '" "PySliceObject *""'");
    }
    arg2 = (PySliceObject *) swig_obj[1];
  }
  try {
    result = (std::vector< pj::RtcpFbCap,std::allocator< pj::RtcpFbCap > > *)std_vector_Sl_pj_RtcpFbCap_Sg____getitem____SWIG_0(arg1,arg2);
  } catch(std::out_of_range &_e) {
    SWIG_exception_fail(SWIG_IndexError, (&_e)->what());
  } catch(std::invalid_argument &_e) {
    SWIG_exception_fail(SWIG_ValueError, (&_e)->what());
  }
  resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(result), SWIGTYPE_p_std__vectorT_pj__RtcpFbCap_std__allocatorT_pj__RtcpFbCap_t_t, SWIG_POINTER_OWN |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_RtcpFbCapVector___setitem____SWIG_0(PyObject *SWIGUNUSEDPARM(self), Py_ssize_t nobjs, PyObject **swig_obj) {
  PyObject *resultobj = 0;
  std::vector< pj::RtcpFbCap > *arg1 = (std::vector< pj::RtcpFbCap > *) 0 ;
  PySliceObject *arg2 = (PySliceObject *) 0 ;
  std::vector< pj::RtcpFbCap,std::allocator< pj::RtcpFbCap > > *arg3 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  int res3 = SWIG_OLDOBJ ;
  
  if ((nobjs < 3) || (nobjs > 3)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__vectorT_pj__RtcpFbCap_std__allocatorT_pj__RtcpFbCap_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "RtcpFbCapVector___setitem__" "', argument " "1"" of type '" "std::vector< pj::RtcpFbCap > *""'"); 
  }
  arg1 = reinterpret_cast< std::vector< pj::RtcpFbCap > * >(argp1);
  {
    if (!PySlice_Check(swig_obj[1])) {
      SWIG_exception_fail(SWIG_ArgError(SWIG_TypeError), "in method '" "RtcpFbCapVector___setitem__" "', argument " "2"" of type '" "PySliceObject *""'");
    }
    arg2 = (PySliceObject *) swig_obj[1];
  }
  {
    std::vector< pj::RtcpFbCap,std::allocator< pj::RtcpFbCap > > *ptr = (std::vector< pj::RtcpFbCap,std::allocator< pj::RtcpFbCap > > *)0;
    res3 = swig::asptr(swig_obj[2], &ptr);
    if (!SWIG_IsOK(res3)) {
      SWIG_exception_fail(SWIG_ArgError(res3), "in method '" "RtcpFbCapVector___setitem__" "', argument " "3"" of type '" "std::vector< pj::RtcpFbCap,std::allocator< pj::RtcpFbCap > > const &""'"); 
    }
    if (!ptr) {
      SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "RtcpFbCapVector___setitem__" "', argument " "3"" of type '" "std::vector< pj::RtcpFbCap,std::allocator< pj::RtcpFbCap > > const &""'"); 
    }
    arg3 = ptr;
  }
  try {
    std_vector_Sl_pj_RtcpFbCap_Sg____setitem____SWIG_0(arg1,arg2,(std::vector< pj::RtcpFbCap,std::allocator< pj::RtcpFbCap > > const &)*arg3);
  } catch(std::out_of_range &_e) {
    SWIG_exception_fail(SWIG_IndexError, (&_e)->what());
  } catch(std::invalid_argument &_e) {
    SWIG_exception_fail(SWIG_ValueError, (&_e)->what());
  }
  resultobj = SWIG_Py_Void();
  if (SWIG_IsNewObj(res3)) delete arg3;
  return resultobj;
fail:
  if (SWIG_IsNewObj(res3)) delete arg3;
  return NULL;
}


SWIGINTERN PyObject *_wrap_RtcpFbCapVector___setitem____SWIG_1(PyObject *SWIGUNUSEDPARM(self), Py_ssize_t nobjs, PyObject **swig_obj) {
  PyObject *resultobj = 0;
  std::vector< pj::RtcpFbCap > *arg1 = (std::vector< pj::RtcpFbCap > *) 0 ;
  PySliceObject *arg2 = (PySliceObject *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  
  if ((nobjs < 2) || (nobjs > 2)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__vectorT_pj__RtcpFbCap_std__allocatorT_pj__RtcpFbCap_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "RtcpFbCapVector___setitem__" "', argument " "1"" of type '" "std::vector< pj::RtcpFbCap > *""'"); 
  }
  arg1 = reinterpret_cast< std::vector< pj::RtcpFbCap > * >(argp1);
  {
    if (!PySlice_Check(swig_obj[1])) {
      SWIG_exception_fail(SWIG_ArgError(SWIG_TypeError), "in method '" "RtcpFbCapVector___setitem__" "', argument " "2"" of type '" "PySliceObject *""'");
    }
    arg2 = (PySliceObject *) swig_obj[1];
  }
  try {
    std_vector_Sl_pj_RtcpFbCap_Sg____setitem____SWIG_1(arg1,arg2);
  } catch(std::out_of_range &_e) {
    SWIG_exception_fail(SWIG_IndexError, (&_e)->what());
  } catch(std::invalid_argument &_e) {
    SWIG_exception_fail(SWIG_ValueError, (&_e)->what());
  }
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_RtcpFbCapVector___delitem____SWIG_1(PyObject *SWIGUNUSEDPARM(self), Py_ssize_t nobjs, PyObject **swig_obj) {
  PyObject *resultobj = 0;
  std::vector< pj::RtcpFbCap > *arg1 = (std::vector< pj::RtcpFbCap > *) 0 ;
  PySliceObject *arg2 = (PySliceObject *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  
  if ((nobjs < 2) || (nobjs > 2)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__vectorT_pj__RtcpFbCap_std__allocatorT_pj__RtcpFbCap_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "RtcpFbCapVector___delitem__" "', argument " "1"" of type '" "std::vector< pj::RtcpFbCap > *""'"); 
  }
  arg1 = reinterpret_cast< std::vector< pj::RtcpFbCap > * >(argp1);
  {
    if (!PySlice_Check(swig_obj[1])) {
      SWIG_exception_fail(SWIG_ArgError(SWIG_TypeError), "in method '" "RtcpFbCapVector___delitem__" "', argument " "2"" of type '" "PySliceObject *""'");
    }
    arg2 = (PySliceObject *) swig_obj[1];
  }
  try {
    std_vector_Sl_pj_RtcpFbCap_Sg____delitem____SWIG_1(arg1,arg2);
  } catch(std::out_of_range &_e) {
    SWIG_exception_fail(SWIG_IndexError, (&_e)->what());
  } catch(std::invalid_argument &_e) {
    SWIG_exception_fail(SWIG_ValueError, (&_e)->what());
  }
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_RtcpFbCapVector___delitem__(PyObject *self, PyObject *args) {
  Py_ssize_t argc;
  PyObject *argv[3] = {
    0
  };
  
  if (!(argc = SWIG_Python_UnpackTuple(args, "RtcpFbCapVector___delitem__", 0, 2, argv))) SWIG_fail;
  --argc;
  if (argc == 2) {
    int _v;
    int res = swig::asptr(argv[0], (std::vector< pj::RtcpFbCap,std::allocator< pj::RtcpFbCap > >**)(0));
    _v = SWIG_CheckState(res);
    if (_v) {
      {
        _v = PySlice_Check(argv[1]);
      }
      if (_v) {
        return _wrap_RtcpFbCapVector___delitem____SWIG_1(self, argc, argv);
      }
    }
  }
  if (argc == 2) {
    int _v;
    int res = swig::asptr(argv[0], (std::vector< pj::RtcpFbCap,std::allocator< pj::RtcpFbCap > >**)(0));
    _v = SWIG_CheckState(res);
    if (_v) {
      {
        int res = SWIG_AsVal_ptrdiff_t(argv[1], NULL);
        _v = SWIG_CheckState(res);
      }
      if (_v) {
        return _wrap_RtcpFbCapVector___delitem____SWIG_0(self, argc, argv);
      }
    }
  }
  
fail:
  SWIG_Python_RaiseOrModifyTypeError("Wrong number or type of arguments for overloaded function 'RtcpFbCapVector___delitem__'.\n"
    "  Possible C/C++ prototypes are:\n"
    "    std::vector< pj::RtcpFbCap >::__delitem__(std::vector< pj::RtcpFbCap >::difference_type)\n"
    "    std::vector< pj::RtcpFbCap >::__delitem__(PySliceObject *)\n");
  return 0;
}


SWIGINTERN PyObject *_wrap_RtcpFbCapVector___getitem____SWIG_1(PyObject *SWIGUNUSEDPARM(self), Py_ssize_t nobjs, PyObject **swig_obj) {
  PyObject *resultobj = 0;
  std::vector< pj::RtcpFbCap > *arg1 = (std::vector< pj::RtcpFbCap > *) 0 ;
  std::vector< pj::RtcpFbCap >::difference_type arg2 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  ptrdiff_t val2 ;
  int ecode2 = 0 ;
  std::vector< pj::RtcpFbCap >::value_type *result = 0 ;
  
  if ((nobjs < 2) || (nobjs > 2)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__vectorT_pj__RtcpFbCap_std__allocatorT_pj__RtcpFbCap_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "RtcpFbCapVector___getitem__" "', argument " "1"" of type '" "std::vector< pj::RtcpFbCap > const *""'"); 
  }
  arg1 = reinterpret_cast< std::vector< pj::RtcpFbCap > * >(argp1);
  ecode2 = SWIG_AsVal_ptrdiff_t(swig_obj[1], &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "RtcpFbCapVector___getitem__" "', argument " "2"" of type '" "std::vector< pj::RtcpFbCap >::difference_type""'");
  } 
  arg2 = static_cast< std::vector< pj::RtcpFbCap >::difference_type >(val2);
  try {
    result = (std::vector< pj::RtcpFbCap >::value_type *) &std_vector_Sl_pj_RtcpFbCap_Sg____getitem____SWIG_1((std::vector< pj::RtcpFbCap > const *)arg1,arg2);
  } catch(std::out_of_range &_e) {
    SWIG_exception_fail(SWIG_IndexError, (&_e)->what());
  }
  resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(result), SWIGTYPE_p_pj__RtcpFbCap, 0 |  0 );
  (void)swig::container_owner<swig::traits<std::vector< pj::RtcpFbCap >::value_type>::category>::back_reference(resultobj, swig_obj[0]);
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_RtcpFbCapVector___getitem__(PyObject *self, PyObject *args) {
  Py_ssize_t argc;
  PyObject *argv[3] = {
    0
  };
  
  if (!(argc = SWIG_Python_UnpackTuple(args, "RtcpFbCapVector___getitem__", 0, 2, argv))) SWIG_fail;
  --argc;
  if (argc == 2) {
    int _v;
    int res = swig::asptr(argv[0], (std::vector< pj::RtcpFbCap,std::allocator< pj::RtcpFbCap > >**)(0));
    _v = SWIG_CheckState(res);
    if (_v) {
      {
        _v = PySlice_Check(argv[1]);
      }
      if (_v) {
        return _wrap_RtcpFbCapVector___getitem____SWIG_0(self, argc, argv);
      }
    }
  }
  if (argc == 2) {
    int _v;
    int res = swig::asptr(argv[0], (std::vector< pj::RtcpFbCap,std::allocator< pj::RtcpFbCap > >**)(0));
    _v = SWIG_CheckState(res);
    if (_v) {
      {
        int res = SWIG_AsVal_ptrdiff_t(argv[1], NULL);
        _v = SWIG_CheckState(res);
      }
      if (_v) {
        return _wrap_RtcpFbCapVector___getitem____SWIG_1(self, argc, argv);
      }
    }
  }
  
fail:
  SWIG_Python_RaiseOrModifyTypeError("Wrong number or type of arguments for overloaded function 'RtcpFbCapVector___getitem__'.\n"
    "  Possible C/C++ prototypes are:\n"
    "    std::vector< pj::RtcpFbCap >::__getitem__(PySliceObject *)\n"
    "    std::vector< pj::RtcpFbCap >::__getitem__(std::vector< pj::RtcpFbCap >::difference_type) const\n");
  return 0;
}


SWIGINTERN PyObject *_wrap_RtcpFbCapVector___setitem____SWIG_2(PyObject *SWIGUNUSEDPARM(self), Py_ssize_t nobjs, PyObject **swig_obj) {
  PyObject *resultobj = 0;
  std::vector< pj::RtcpFbCap > *arg1 = (std::vector< pj::RtcpFbCap > *) 0 ;
  std::vector< pj::RtcpFbCap >::difference_type arg2 ;
  std::vector< pj::RtcpFbCap >::value_type *arg3 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  ptrdiff_t val2 ;
  int ecode2 = 0 ;
  void *argp3 = 0 ;
  int res3 = 0 ;
  
  if ((nobjs < 3) || (nobjs > 3)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__vectorT_pj__RtcpFbCap_std__allocatorT_pj__RtcpFbCap_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "RtcpFbCapVector___setitem__" "', argument " "1"" of type '" "std::vector< pj::RtcpFbCap > *""'"); 
  }
  arg1 = reinterpret_cast< std::vector< pj::RtcpFbCap > * >(argp1);
  ecode2 = SWIG_AsVal_ptrdiff_t(swig_obj[1], &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "RtcpFbCapVector___setitem__" "', argument " "2"" of type '" "std::vector< pj::RtcpFbCap >::difference_type""'");
  } 
  arg2 = static_cast< std::vector< pj::RtcpFbCap >::difference_type >(val2);
  res3 = SWIG_ConvertPtr(swig_obj[2], &argp3, SWIGTYPE_p_pj__RtcpFbCap,  0  | 0);
  if (!SWIG_IsOK(res3)) {
    SWIG_exception_fail(SWIG_ArgError(res3), "in method '" "RtcpFbCapVector___setitem__" "', argument " "3"" of type '" "std::vector< pj::RtcpFbCap >::value_type const &""'"); 
  }
  if (!argp3) {
    SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "RtcpFbCapVector___setitem__" "', argument " "3"" of type '" "std::vector< pj::RtcpFbCap >::value_type const &""'"); 
  }
  arg3 = reinterpret_cast< std::vector< pj::RtcpFbCap >::value_type * >(argp3);
  try {
    std_vector_Sl_pj_RtcpFbCap_Sg____setitem____SWIG_2(arg1,arg2,(pj::RtcpFbCap const &)*arg3);
  } catch(std::out_of_range &_e) {
    SWIG_exception_fail(SWIG_IndexError, (&_e)->what());
  }
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_RtcpFbCapVector___setitem__(PyObject *self, PyObject *args) {
  Py_ssize_t argc;
  PyObject *argv[4] = {
    0
  };
  
  if (!(argc = SWIG_Python_UnpackTuple(args, "RtcpFbCapVector___setitem__", 0, 3, argv))) SWIG_fail;
  --argc;
  if (argc == 2) {
    int _v;
    int res = swig::asptr(argv[0], (std::vector< pj::RtcpFbCap,std::allocator< pj::RtcpFbCap > >**)(0));
    _v = SWIG_CheckState(res);
    if (_v) {
      {
        _v = PySlice_Check(argv[1]);
      }
      if (_v) {
        return _wrap_RtcpFbCapVector___setitem____SWIG_1(self, argc, argv);
      }
    }
  }
  if (argc == 3) {
    int _v;
    int res = swig::asptr(argv[0], (std::vector< pj::RtcpFbCap,std::allocator< pj::RtcpFbCap > >**)(0));
    _v = SWIG_CheckState(res);
    if (_v) {
      {
        _v = PySlice_Check(argv[1]);
      }
      if (_v) {
        int res = swig::asptr(argv[2], (std::vector< pj::RtcpFbCap,std::allocator< pj::RtcpFbCap > >**)(0));
        _v = SWIG_CheckState(res);
        if (_v) {
          return _wrap_RtcpFbCapVector___setitem____SWIG_0(self, argc, argv);
        }
      }
    }
  }
  if (argc == 3) {
    int _v;
    int res = swig::asptr(argv[0], (std::vector< pj::RtcpFbCap,std::allocator< pj::RtcpFbCap > >**)(0));
    _v = SWIG_CheckState(res);
    if (_v) {
      {
        int res = SWIG_AsVal_ptrdiff_t(argv[1], NULL);
        _v = SWIG_CheckState(res);
      }
      if (_v) {
        int res = SWIG_ConvertPtr(argv[2], 0, SWIGTYPE_p_pj__RtcpFbCap, SWIG_POINTER_NO_NULL | 0);
        _v = SWIG_CheckState(res);
        if (_v) {
          return _wrap_RtcpFbCapVector___setitem____SWIG_2(self, argc, argv);
        }
      }
    }
  }
  
fail:
  SWIG_Python_RaiseOrModifyTypeError("Wrong number or type of arguments for overloaded function 'RtcpFbCapVector___setitem__'.\n"
    "  Possible C/C++ prototypes are:\n"
    "    std::vector< pj::RtcpFbCap >::__setitem__(PySliceObject *,std::vector< pj::RtcpFbCap,std::allocator< pj::RtcpFbCap > > const &)\n"
    "    std::vector< pj::RtcpFbCap >::__setitem__(PySliceObject *)\n"
    "    std::vector< pj::RtcpFbCap >::__setitem__(std::vector< pj::RtcpFbCap >::difference_type,std::vector< pj::RtcpFbCap >::value_type const &)\n");
  return 0;
}


SWIGINTERN PyObject *_wrap_RtcpFbCapVector_pop(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  std::vector< pj::RtcpFbCap > *arg1 = (std::vector< pj::RtcpFbCap > *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  std::vector< pj::RtcpFbCap >::value_type result;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__vectorT_pj__RtcpFbCap_std__allocatorT_pj__RtcpFbCap_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "RtcpFbCapVector_pop" "', argument " "1"" of type '" "std::vector< pj::RtcpFbCap > *""'"); 
  }
  arg1 = reinterpret_cast< std::vector< pj::RtcpFbCap > * >(argp1);
  try {
    result = std_vector_Sl_pj_RtcpFbCap_Sg__pop(arg1);
  } catch(std::out_of_range &_e) {
    SWIG_exception_fail(SWIG_IndexError, (&_e)->what());
  }
  resultobj = SWIG_NewPointerObj((new std::vector< pj::RtcpFbCap >::value_type(static_cast< const std::vector< pj::RtcpFbCap >::value_type& >(result))), SWIGTYPE_p_pj__RtcpFbCap, SWIG_POINTER_OWN |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_RtcpFbCapVector_append(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  std::vector< pj::RtcpFbCap > *arg1 = (std::vector< pj::RtcpFbCap > *) 0 ;
  std::vector< pj::RtcpFbCap >::value_type *arg2 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  void *argp2 = 0 ;
  int res2 = 0 ;
  PyObject *swig_obj[2] ;
  
  if (!SWIG_Python_UnpackTuple(args, "RtcpFbCapVector_append", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__vectorT_pj__RtcpFbCap_std__allocatorT_pj__RtcpFbCap_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "RtcpFbCapVector_append" "', argument " "1"" of type '" "std::vector< pj::RtcpFbCap > *""'"); 
  }
  arg1 = reinterpret_cast< std::vector< pj::RtcpFbCap > * >(argp1);
  res2 = SWIG_ConvertPtr(swig_obj[1], &argp2, SWIGTYPE_p_pj__RtcpFbCap,  0  | 0);
  if (!SWIG_IsOK(res2)) {
    SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "RtcpFbCapVector_append" "', argument " "2"" of type '" "std::vector< pj::RtcpFbCap >::value_type const &""'"); 
  }
  if (!argp2) {
    SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "RtcpFbCapVector_append" "', argument " "2"" of type '" "std::vector< pj::RtcpFbCap >::value_type const &""'"); 
  }
  arg2 = reinterpret_cast< std::vector< pj::RtcpFbCap >::value_type * >(argp2);
  std_vector_Sl_pj_RtcpFbCap_Sg__append(arg1,(pj::RtcpFbCap const &)*arg2);
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_new_RtcpFbCapVector__SWIG_0(PyObject *SWIGUNUSEDPARM(self), Py_ssize_t nobjs, PyObject **SWIGUNUSEDPARM(swig_obj)) {
  PyObject *resultobj = 0;
  std::vector< pj::RtcpFbCap > *result = 0 ;
  
  if ((nobjs < 0) || (nobjs > 0)) SWIG_fail;
  result = (std::vector< pj::RtcpFbCap > *)new std::vector< pj::RtcpFbCap >();
  resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(result), SWIGTYPE_p_std__vectorT_pj__RtcpFbCap_std__allocatorT_pj__RtcpFbCap_t_t, SWIG_POINTER_NEW |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_new_RtcpFbCapVector__SWIG_1(PyObject *SWIGUNUSEDPARM(self), Py_ssize_t nobjs, PyObject **swig_obj) {
  PyObject *resultobj = 0;
  std::vector< pj::RtcpFbCap > *arg1 = 0 ;
  int res1 = SWIG_OLDOBJ ;
  std::vector< pj::RtcpFbCap > *result = 0 ;
  
  if ((nobjs < 1) || (nobjs > 1)) SWIG_fail;
  {
    std::vector< pj::RtcpFbCap,std::allocator< pj::RtcpFbCap > > *ptr = (std::vector< pj::RtcpFbCap,std::allocator< pj::RtcpFbCap > > *)0;
    res1 = swig::asptr(swig_obj[0], &ptr);
    if (!SWIG_IsOK(res1)) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "new_RtcpFbCapVector" "', argument " "1"" of type '" "std::vector< pj::RtcpFbCap > const &""'"); 
    }
    if (!ptr) {
      SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "new_RtcpFbCapVector" "', argument " "1"" of type '" "std::vector< pj::RtcpFbCap > const &""'"); 
    }
    arg1 = ptr;
  }
  result = (std::vector< pj::RtcpFbCap > *)new std::vector< pj::RtcpFbCap >((std::vector< pj::RtcpFbCap > const &)*arg1);
  resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(result), SWIGTYPE_p_std__vectorT_pj__RtcpFbCap_std__allocatorT_pj__RtcpFbCap_t_t, SWIG_POINTER_NEW |  0 );
  if (SWIG_IsNewObj(res1)) delete arg1;
  return resultobj;
fail:
  if (SWIG_IsNewObj(res1)) delete arg1;
  return NULL;
}


SWIGINTERN PyObject *_wrap_RtcpFbCapVector_empty(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  std::vector< pj::RtcpFbCap > *arg1 = (std::vector< pj::RtcpFbCap > *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  bool result;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__vectorT_pj__RtcpFbCap_std__allocatorT_pj__RtcpFbCap_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "RtcpFbCapVector_empty" "', argument " "1"" of type '" "std::vector< pj::RtcpFbCap > const *""'"); 
  }
  arg1 = reinterpret_cast< std::vector< pj::RtcpFbCap > * >(argp1);
  result = (bool)((std::vector< pj::RtcpFbCap > const *)arg1)->empty();
  resultobj = SWIG_From_bool(static_cast< bool >(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_RtcpFbCapVector_size(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  std::vector< pj::RtcpFbCap > *arg1 = (std::vector< pj::RtcpFbCap > *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  std::vector< pj::RtcpFbCap >::size_type result;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__vectorT_pj__RtcpFbCap_std__allocatorT_pj__RtcpFbCap_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "RtcpFbCapVector_size" "', argument " "1"" of type '" "std::vector< pj::RtcpFbCap > const *""'"); 
  }
  arg1 = reinterpret_cast< std::vector< pj::RtcpFbCap > * >(argp1);
  result = ((std::vector< pj::RtcpFbCap > const *)arg1)->size();
  resultobj = SWIG_From_size_t(static_cast< size_t >(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_RtcpFbCapVector_swap(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  std::vector< pj::RtcpFbCap > *arg1 = (std::vector< pj::RtcpFbCap > *) 0 ;
  std::vector< pj::RtcpFbCap > *arg2 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  void *argp2 = 0 ;
  int res2 = 0 ;
  PyObject *swig_obj[2] ;
  
  if (!SWIG_Python_UnpackTuple(args, "RtcpFbCapVector_swap", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__vectorT_pj__RtcpFbCap_std__allocatorT_pj__RtcpFbCap_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "RtcpFbCapVector_swap" "', argument " "1"" of type '" "std::vector< pj::RtcpFbCap > *""'"); 
  }
  arg1 = reinterpret_cast< std::vector< pj::RtcpFbCap > * >(argp1);
  res2 = SWIG_ConvertPtr(swig_obj[1], &argp2, SWIGTYPE_p_std__vectorT_pj__RtcpFbCap_std__allocatorT_pj__RtcpFbCap_t_t,  0 );
  if (!SWIG_IsOK(res2)) {
    SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "RtcpFbCapVector_swap" "', argument " "2"" of type '" "std::vector< pj::RtcpFbCap > &""'"); 
  }
  if (!argp2) {
    SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "RtcpFbCapVector_swap" "', argument " "2"" of type '" "std::vector< pj::RtcpFbCap > &""'"); 
  }
  arg2 = reinterpret_cast< std::vector< pj::RtcpFbCap > * >(argp2);
  (arg1)->swap(*arg2);
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_RtcpFbCapVector_begin(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  std::vector< pj::RtcpFbCap > *arg1 = (std::vector< pj::RtcpFbCap > *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  std::vector< pj::RtcpFbCap >::iterator result;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__vectorT_pj__RtcpFbCap_std__allocatorT_pj__RtcpFbCap_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "RtcpFbCapVector_begin" "', argument " "1"" of type '" "std::vector< pj::RtcpFbCap > *""'"); 
  }
  arg1 = reinterpret_cast< std::vector< pj::RtcpFbCap > * >(argp1);
  result = (arg1)->begin();
  resultobj = SWIG_NewPointerObj(swig::make_output_iterator(static_cast< const std::vector< pj::RtcpFbCap >::iterator & >(result)),
    swig::SwigPyIterator::descriptor(),SWIG_POINTER_OWN);
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_RtcpFbCapVector_end(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  std::vector< pj::RtcpFbCap > *arg1 = (std::vector< pj::RtcpFbCap > *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  std::vector< pj::RtcpFbCap >::iterator result;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__vectorT_pj__RtcpFbCap_std__allocatorT_pj__RtcpFbCap_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "RtcpFbCapVector_end" "', argument " "1"" of type '" "std::vector< pj::RtcpFbCap > *""'"); 
  }
  arg1 = reinterpret_cast< std::vector< pj::RtcpFbCap > * >(argp1);
  result = (arg1)->end();
  resultobj = SWIG_NewPointerObj(swig::make_output_iterator(static_cast< const std::vector< pj::RtcpFbCap >::iterator & >(result)),
    swig::SwigPyIterator::descriptor(),SWIG_POINTER_OWN);
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_RtcpFbCapVector_rbegin(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  std::vector< pj::RtcpFbCap > *arg1 = (std::vector< pj::RtcpFbCap > *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  std::vector< pj::RtcpFbCap >::reverse_iterator result;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__vectorT_pj__RtcpFbCap_std__allocatorT_pj__RtcpFbCap_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "RtcpFbCapVector_rbegin" "', argument " "1"" of type '" "std::vector< pj::RtcpFbCap > *""'"); 
  }
  arg1 = reinterpret_cast< std::vector< pj::RtcpFbCap > * >(argp1);
  result = (arg1)->rbegin();
  resultobj = SWIG_NewPointerObj(swig::make_output_iterator(static_cast< const std::vector< pj::RtcpFbCap >::reverse_iterator & >(result)),
    swig::SwigPyIterator::descriptor(),SWIG_POINTER_OWN);
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_RtcpFbCapVector_rend(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  std::vector< pj::RtcpFbCap > *arg1 = (std::vector< pj::RtcpFbCap > *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  std::vector< pj::RtcpFbCap >::reverse_iterator result;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__vectorT_pj__RtcpFbCap_std__allocatorT_pj__RtcpFbCap_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "RtcpFbCapVector_rend" "', argument " "1"" of type '" "std::vector< pj::RtcpFbCap > *""'"); 
  }
  arg1 = reinterpret_cast< std::vector< pj::RtcpFbCap > * >(argp1);
  result = (arg1)->rend();
  resultobj = SWIG_NewPointerObj(swig::make_output_iterator(static_cast< const std::vector< pj::RtcpFbCap >::reverse_iterator & >(result)),
    swig::SwigPyIterator::descriptor(),SWIG_POINTER_OWN);
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_RtcpFbCapVector_clear(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  std::vector< pj::RtcpFbCap > *arg1 = (std::vector< pj::RtcpFbCap > *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__vectorT_pj__RtcpFbCap_std__allocatorT_pj__RtcpFbCap_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "RtcpFbCapVector_clear" "', argument " "1"" of type '" "std::vector< pj::RtcpFbCap > *""'"); 
  }
  arg1 = reinterpret_cast< std::vector< pj::RtcpFbCap > * >(argp1);
  (arg1)->clear();
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_RtcpFbCapVector_get_allocator(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  std::vector< pj::RtcpFbCap > *arg1 = (std::vector< pj::RtcpFbCap > *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  SwigValueWrapper< std::allocator< pj::RtcpFbCap > > result;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__vectorT_pj__RtcpFbCap_std__allocatorT_pj__RtcpFbCap_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "RtcpFbCapVector_get_allocator" "', argument " "1"" of type '" "std::vector< pj::RtcpFbCap > const *""'"); 
  }
  arg1 = reinterpret_cast< std::vector< pj::RtcpFbCap > * >(argp1);
  result = ((std::vector< pj::RtcpFbCap > const *)arg1)->get_allocator();
  resultobj = SWIG_NewPointerObj((new std::vector< pj::RtcpFbCap >::allocator_type(static_cast< const std::vector< pj::RtcpFbCap >::allocator_type& >(result))), SWIGTYPE_p_std__allocatorT_pj__RtcpFbCap_t, SWIG_POINTER_OWN |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_new_RtcpFbCapVector__SWIG_2(PyObject *SWIGUNUSEDPARM(self), Py_ssize_t nobjs, PyObject **swig_obj) {
  PyObject *resultobj = 0;
  std::vector< pj::RtcpFbCap >::size_type arg1 ;
  size_t val1 ;
  int ecode1 = 0 ;
  std::vector< pj::RtcpFbCap > *result = 0 ;
  
  if ((nobjs < 1) || (nobjs > 1)) SWIG_fail;
  ecode1 = SWIG_AsVal_size_t(swig_obj[0], &val1);
  if (!SWIG_IsOK(ecode1)) {
    SWIG_exception_fail(SWIG_ArgError(ecode1), "in method '" "new_RtcpFbCapVector" "', argument " "1"" of type '" "std::vector< pj::RtcpFbCap >::size_type""'");
  } 
  arg1 = static_cast< std::vector< pj::RtcpFbCap >::size_type >(val1);
  result = (std::vector< pj::RtcpFbCap > *)new std::vector< pj::RtcpFbCap >(arg1);
  resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(result), SWIGTYPE_p_std__vectorT_pj__RtcpFbCap_std__allocatorT_pj__RtcpFbCap_t_t, SWIG_POINTER_NEW |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_RtcpFbCapVector_pop_back(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  std::vector< pj::RtcpFbCap > *arg1 = (std::vector< pj::RtcpFbCap > *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__vectorT_pj__RtcpFbCap_std__allocatorT_pj__RtcpFbCap_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "RtcpFbCapVector_pop_back" "', argument " "1"" of type '" "std::vector< pj::RtcpFbCap > *""'"); 
  }
  arg1 = reinterpret_cast< std::vector< pj::RtcpFbCap > * >(argp1);
  (arg1)->pop_back();
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_RtcpFbCapVector_resize__SWIG_0(PyObject *SWIGUNUSEDPARM(self), Py_ssize_t nobjs, PyObject **swig_obj) {
  PyObject *resultobj = 0;
  std::vector< pj::RtcpFbCap > *arg1 = (std::vector< pj::RtcpFbCap > *) 0 ;
  std::vector< pj::RtcpFbCap >::size_type arg2 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  size_t val2 ;
  int ecode2 = 0 ;
  
  if ((nobjs < 2) || (nobjs > 2)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__vectorT_pj__RtcpFbCap_std__allocatorT_pj__RtcpFbCap_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "RtcpFbCapVector_resize" "', argument " "1"" of type '" "std::vector< pj::RtcpFbCap > *""'"); 
  }
  arg1 = reinterpret_cast< std::vector< pj::RtcpFbCap > * >(argp1);
  ecode2 = SWIG_AsVal_size_t(swig_obj[1], &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "RtcpFbCapVector_resize" "', argument " "2"" of type '" "std::vector< pj::RtcpFbCap >::size_type""'");
  } 
  arg2 = static_cast< std::vector< pj::RtcpFbCap >::size_type >(val2);
  (arg1)->resize(arg2);
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_RtcpFbCapVector_erase__SWIG_0(PyObject *SWIGUNUSEDPARM(self), Py_ssize_t nobjs, PyObject **swig_obj) {
  PyObject *resultobj = 0;
  std::vector< pj::RtcpFbCap > *arg1 = (std::vector< pj::RtcpFbCap > *) 0 ;
  std::vector< pj::RtcpFbCap >::iterator arg2 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  swig::SwigPyIterator *iter2 = 0 ;
  int res2 ;
  std::vector< pj::RtcpFbCap >::iterator result;
  
  if ((nobjs < 2) || (nobjs > 2)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__vectorT_pj__RtcpFbCap_std__allocatorT_pj__RtcpFbCap_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "RtcpFbCapVector_erase" "', argument " "1"" of type '" "std::vector< pj::RtcpFbCap > *""'"); 
  }
  arg1 = reinterpret_cast< std::vector< pj::RtcpFbCap > * >(argp1);
  res2 = SWIG_ConvertPtr(swig_obj[1], SWIG_as_voidptrptr(&iter2), swig::SwigPyIterator::descriptor(), 0);
  if (!SWIG_IsOK(res2) || !iter2) {
    SWIG_exception_fail(SWIG_ArgError(SWIG_TypeError), "in method '" "RtcpFbCapVector_erase" "', argument " "2"" of type '" "std::vector< pj::RtcpFbCap >::iterator""'");
  } else {
    swig::SwigPyIterator_T<std::vector< pj::RtcpFbCap >::iterator > *iter_t = dynamic_cast<swig::SwigPyIterator_T<std::vector< pj::RtcpFbCap >::iterator > *>(iter2);
    if (iter_t) {
      arg2 = iter_t->get_current();
    } else {
      SWIG_exception_fail(SWIG_ArgError(SWIG_TypeError), "in method '" "RtcpFbCapVector_erase" "', argument " "2"" of type '" "std::vector< pj::RtcpFbCap >::iterator""'");
    }
  }
  result = std_vector_Sl_pj_RtcpFbCap_Sg__erase__SWIG_0(arg1,arg2);
  resultobj = SWIG_NewPointerObj(swig::make_output_iterator(static_cast< const std::vector< pj::RtcpFbCap >::iterator & >(result)),
    swig::SwigPyIterator::descriptor(),SWIG_POINTER_OWN);
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_RtcpFbCapVector_erase__SWIG_1(PyObject *SWIGUNUSEDPARM(self), Py_ssize_t nobjs, PyObject **swig_obj) {
  PyObject *resultobj = 0;
  std::vector< pj::RtcpFbCap > *arg1 = (std::vector< pj::RtcpFbCap > *) 0 ;
  std::vector< pj::RtcpFbCap >::iterator arg2 ;
  std::vector< pj::RtcpFbCap >::iterator arg3 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  swig::SwigPyIterator *iter2 = 0 ;
  int res2 ;
  swig::SwigPyIterator *iter3 = 0 ;
  int res3 ;
  std::vector< pj::RtcpFbCap >::iterator result;
  
  if ((nobjs < 3) || (nobjs > 3)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__vectorT_pj__RtcpFbCap_std__allocatorT_pj__RtcpFbCap_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "RtcpFbCapVector_erase" "', argument " "1"" of type '" "std::vector< pj::RtcpFbCap > *""'"); 
  }
  arg1 = reinterpret_cast< std::vector< pj::RtcpFbCap > * >(argp1);
  res2 = SWIG_ConvertPtr(swig_obj[1], SWIG_as_voidptrptr(&iter2), swig::SwigPyIterator::descriptor(), 0);
  if (!SWIG_IsOK(res2) || !iter2) {
    SWIG_exception_fail(SWIG_ArgError(SWIG_TypeError), "in method '" "RtcpFbCapVector_erase" "', argument " "2"" of type '" "std::vector< pj::RtcpFbCap >::iterator""'");
  } else {
    swig::SwigPyIterator_T<std::vector< pj::RtcpFbCap >::iterator > *iter_t = dynamic_cast<swig::SwigPyIterator_T<std::vector< pj::RtcpFbCap >::iterator > *>(iter2);
    if (iter_t) {
      arg2 = iter_t->get_current();
    } else {
      SWIG_exception_fail(SWIG_ArgError(SWIG_TypeError), "in method '" "RtcpFbCapVector_erase" "', argument " "2"" of type '" "std::vector< pj::RtcpFbCap >::iterator""'");
    }
  }
  res3 = SWIG_ConvertPtr(swig_obj[2], SWIG_as_voidptrptr(&iter3), swig::SwigPyIterator::descriptor(), 0);
  if (!SWIG_IsOK(res3) || !iter3) {
    SWIG_exception_fail(SWIG_ArgError(SWIG_TypeError), "in method '" "RtcpFbCapVector_erase" "', argument " "3"" of type '" "std::vector< pj::RtcpFbCap >::iterator""'");
  } else {
    swig::SwigPyIterator_T<std::vector< pj::RtcpFbCap >::iterator > *iter_t = dynamic_cast<swig::SwigPyIterator_T<std::vector< pj::RtcpFbCap >::iterator > *>(iter3);
    if (iter_t) {
      arg3 = iter_t->get_current();
    } else {
      SWIG_exception_fail(SWIG_ArgError(SWIG_TypeError), "in method '" "RtcpFbCapVector_erase" "', argument " "3"" of type '" "std::vector< pj::RtcpFbCap >::iterator""'");
    }
  }
  result = std_vector_Sl_pj_RtcpFbCap_Sg__erase__SWIG_1(arg1,arg2,arg3);
  resultobj = SWIG_NewPointerObj(swig::make_output_iterator(static_cast< const std::vector< pj::RtcpFbCap >::iterator & >(result)),
    swig::SwigPyIterator::descriptor(),SWIG_POINTER_OWN);
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_RtcpFbCapVector_erase(PyObject *self, PyObject *args) {
  Py_ssize_t argc;
  PyObject *argv[4] = {
    0
  };
  
  if (!(argc = SWIG_Python_UnpackTuple(args, "RtcpFbCapVector_erase", 0, 3, argv))) SWIG_fail;
  --argc;
  if (argc == 2) {
    int _v;
    int res = swig::asptr(argv[0], (std::vector< pj::RtcpFbCap,std::allocator< pj::RtcpFbCap > >**)(0));
    _v = SWIG_CheckState(res);
    if (_v) {
      swig::SwigPyIterator *iter = 0;
      int res = SWIG_ConvertPtr(argv[1], SWIG_as_voidptrptr(&iter), swig::SwigPyIterator::descriptor(), 0);
      _v = (SWIG_IsOK(res) && iter && (dynamic_cast<swig::SwigPyIterator_T<std::vector< pj::RtcpFbCap >::iterator > *>(iter) != 0));
      if (_v) {
        return _wrap_RtcpFbCapVector_erase__SWIG_0(self, argc, argv);
      }
    }
  }
  if (argc == 3) {
    int _v;
    int res = swig::asptr(argv[0], (std::vector< pj::RtcpFbCap,std::allocator< pj::RtcpFbCap > >**)(0));
    _v = SWIG_CheckState(res);
    if (_v) {
      swig::SwigPyIterator *iter = 0;
      int res = SWIG_ConvertPtr(argv[1], SWIG_as_voidptrptr(&iter), swig::SwigPyIterator::descriptor(), 0);
      _v = (SWIG_IsOK(res) && iter && (dynamic_cast<swig::SwigPyIterator_T<std::vector< pj::RtcpFbCap >::iterator > *>(iter) != 0));
      if (_v) {
        swig::SwigPyIterator *iter = 0;
        int res = SWIG_ConvertPtr(argv[2], SWIG_as_voidptrptr(&iter), swig::SwigPyIterator::descriptor(), 0);
        _v = (SWIG_IsOK(res) && iter && (dynamic_cast<swig::SwigPyIterator_T<std::vector< pj::RtcpFbCap >::iterator > *>(iter) != 0));
        if (_v) {
          return _wrap_RtcpFbCapVector_erase__SWIG_1(self, argc, argv);
        }
      }
    }
  }
  
fail:
  SWIG_Python_RaiseOrModifyTypeError("Wrong number or type of arguments for overloaded function 'RtcpFbCapVector_erase'.\n"
    "  Possible C/C++ prototypes are:\n"
    "    std::vector< pj::RtcpFbCap >::erase(std::vector< pj::RtcpFbCap >::iterator)\n"
    "    std::vector< pj::RtcpFbCap >::erase(std::vector< pj::RtcpFbCap >::iterator,std::vector< pj::RtcpFbCap >::iterator)\n");
  return 0;
}


SWIGINTERN PyObject *_wrap_new_RtcpFbCapVector__SWIG_3(PyObject *SWIGUNUSEDPARM(self), Py_ssize_t nobjs, PyObject **swig_obj) {
  PyObject *resultobj = 0;
  std::vector< pj::RtcpFbCap >::size_type arg1 ;
  std::vector< pj::RtcpFbCap >::value_type *arg2 = 0 ;
  size_t val1 ;
  int ecode1 = 0 ;
  void *argp2 = 0 ;
  int res2 = 0 ;
  std::vector< pj::RtcpFbCap > *result = 0 ;
  
  if ((nobjs < 2) || (nobjs > 2)) SWIG_fail;
  ecode1 = SWIG_AsVal_size_t(swig_obj[0], &val1);
  if (!SWIG_IsOK(ecode1)) {
    SWIG_exception_fail(SWIG_ArgError(ecode1), "in method '" "new_RtcpFbCapVector" "', argument " "1"" of type '" "std::vector< pj::RtcpFbCap >::size_type""'");
  } 
  arg1 = static_cast< std::vector< pj::RtcpFbCap >::size_type >(val1);
  res2 = SWIG_ConvertPtr(swig_obj[1], &argp2, SWIGTYPE_p_pj__RtcpFbCap,  0  | 0);
  if (!SWIG_IsOK(res2)) {
    SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "new_RtcpFbCapVector" "', argument " "2"" of type '" "std::vector< pj::RtcpFbCap >::value_type const &""'"); 
  }
  if (!argp2) {
    SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "new_RtcpFbCapVector" "', argument " "2"" of type '" "std::vector< pj::RtcpFbCap >::value_type const &""'"); 
  }
  arg2 = reinterpret_cast< std::vector< pj::RtcpFbCap >::value_type * >(argp2);
  result = (std::vector< pj::RtcpFbCap > *)new std::vector< pj::RtcpFbCap >(arg1,(std::vector< pj::RtcpFbCap >::value_type const &)*arg2);
  resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(result), SWIGTYPE_p_std__vectorT_pj__RtcpFbCap_std__allocatorT_pj__RtcpFbCap_t_t, SWIG_POINTER_NEW |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_new_RtcpFbCapVector(PyObject *self, PyObject *args) {
  Py_ssize_t argc;
  PyObject *argv[3] = {
    0
  };
  
  if (!(argc = SWIG_Python_UnpackTuple(args, "new_RtcpFbCapVector", 0, 2, argv))) SWIG_fail;
  --argc;
  if (argc == 0) {
    return _wrap_new_RtcpFbCapVector__SWIG_0(self, argc, argv);
  }
  if (argc == 1) {
    int _v;
    {
      int res = SWIG_AsVal_size_t(argv[0], NULL);
      _v = SWIG_CheckState(res);
    }
    if (_v) {
      return _wrap_new_RtcpFbCapVector__SWIG_2(self, argc, argv);
    }
  }
  if (argc == 1) {
    int _v;
    int res = swig::asptr(argv[0], (std::vector< pj::RtcpFbCap,std::allocator< pj::RtcpFbCap > >**)(0));
    _v = SWIG_CheckState(res);
    if (_v) {
      return _wrap_new_RtcpFbCapVector__SWIG_1(self, argc, argv);
    }
  }
  if (argc == 2) {
    int _v;
    {
      int res = SWIG_AsVal_size_t(argv[0], NULL);
      _v = SWIG_CheckState(res);
    }
    if (_v) {
      int res = SWIG_ConvertPtr(argv[1], 0, SWIGTYPE_p_pj__RtcpFbCap, SWIG_POINTER_NO_NULL | 0);
      _v = SWIG_CheckState(res);
      if (_v) {
        return _wrap_new_RtcpFbCapVector__SWIG_3(self, argc, argv);
      }
    }
  }
  
fail:
  SWIG_Python_RaiseOrModifyTypeError("Wrong number or type of arguments for overloaded function 'new_RtcpFbCapVector'.\n"
    "  Possible C/C++ prototypes are:\n"
    "    std::vector< pj::RtcpFbCap >::vector()\n"
    "    std::vector< pj::RtcpFbCap >::vector(std::vector< pj::RtcpFbCap > const &)\n"
    "    std::vector< pj::RtcpFbCap >::vector(std::vector< pj::RtcpFbCap >::size_type)\n"
    "    std::vector< pj::RtcpFbCap >::vector(std::vector< pj::RtcpFbCap >::size_type,std::vector< pj::RtcpFbCap >::value_type const &)\n");
  return 0;
}


SWIGINTERN PyObject *_wrap_RtcpFbCapVector_push_back(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  std::vector< pj::RtcpFbCap > *arg1 = (std::vector< pj::RtcpFbCap > *) 0 ;
  std::vector< pj::RtcpFbCap >::value_type *arg2 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  void *argp2 = 0 ;
  int res2 = 0 ;
  PyObject *swig_obj[2] ;
  
  if (!SWIG_Python_UnpackTuple(args, "RtcpFbCapVector_push_back", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__vectorT_pj__RtcpFbCap_std__allocatorT_pj__RtcpFbCap_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "RtcpFbCapVector_push_back" "', argument " "1"" of type '" "std::vector< pj::RtcpFbCap > *""'"); 
  }
  arg1 = reinterpret_cast< std::vector< pj::RtcpFbCap > * >(argp1);
  res2 = SWIG_ConvertPtr(swig_obj[1], &argp2, SWIGTYPE_p_pj__RtcpFbCap,  0  | 0);
  if (!SWIG_IsOK(res2)) {
    SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "RtcpFbCapVector_push_back" "', argument " "2"" of type '" "std::vector< pj::RtcpFbCap >::value_type const &""'"); 
  }
  if (!argp2) {
    SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "RtcpFbCapVector_push_back" "', argument " "2"" of type '" "std::vector< pj::RtcpFbCap >::value_type const &""'"); 
  }
  arg2 = reinterpret_cast< std::vector< pj::RtcpFbCap >::value_type * >(argp2);
  (arg1)->push_back((std::vector< pj::RtcpFbCap >::value_type const &)*arg2);
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_RtcpFbCapVector_front(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  std::vector< pj::RtcpFbCap > *arg1 = (std::vector< pj::RtcpFbCap > *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  std::vector< pj::RtcpFbCap >::value_type *result = 0 ;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__vectorT_pj__RtcpFbCap_std__allocatorT_pj__RtcpFbCap_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "RtcpFbCapVector_front" "', argument " "1"" of type '" "std::vector< pj::RtcpFbCap > const *""'"); 
  }
  arg1 = reinterpret_cast< std::vector< pj::RtcpFbCap > * >(argp1);
  result = (std::vector< pj::RtcpFbCap >::value_type *) &((std::vector< pj::RtcpFbCap > const *)arg1)->front();
  resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(result), SWIGTYPE_p_pj__RtcpFbCap, 0 |  0 );
  (void)swig::container_owner<swig::traits<std::vector< pj::RtcpFbCap >::value_type>::category>::back_reference(resultobj, swig_obj[0]);
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_RtcpFbCapVector_back(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  std::vector< pj::RtcpFbCap > *arg1 = (std::vector< pj::RtcpFbCap > *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  std::vector< pj::RtcpFbCap >::value_type *result = 0 ;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__vectorT_pj__RtcpFbCap_std__allocatorT_pj__RtcpFbCap_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "RtcpFbCapVector_back" "', argument " "1"" of type '" "std::vector< pj::RtcpFbCap > const *""'"); 
  }
  arg1 = reinterpret_cast< std::vector< pj::RtcpFbCap > * >(argp1);
  result = (std::vector< pj::RtcpFbCap >::value_type *) &((std::vector< pj::RtcpFbCap > const *)arg1)->back();
  resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(result), SWIGTYPE_p_pj__RtcpFbCap, 0 |  0 );
  (void)swig::container_owner<swig::traits<std::vector< pj::RtcpFbCap >::value_type>::category>::back_reference(resultobj, swig_obj[0]);
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_RtcpFbCapVector_assign(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  std::vector< pj::RtcpFbCap > *arg1 = (std::vector< pj::RtcpFbCap > *) 0 ;
  std::vector< pj::RtcpFbCap >::size_type arg2 ;
  std::vector< pj::RtcpFbCap >::value_type *arg3 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  size_t val2 ;
  int ecode2 = 0 ;
  void *argp3 = 0 ;
  int res3 = 0 ;
  PyObject *swig_obj[3] ;
  
  if (!SWIG_Python_UnpackTuple(args, "RtcpFbCapVector_assign", 3, 3, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__vectorT_pj__RtcpFbCap_std__allocatorT_pj__RtcpFbCap_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "RtcpFbCapVector_assign" "', argument " "1"" of type '" "std::vector< pj::RtcpFbCap > *""'"); 
  }
  arg1 = reinterpret_cast< std::vector< pj::RtcpFbCap > * >(argp1);
  ecode2 = SWIG_AsVal_size_t(swig_obj[1], &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "RtcpFbCapVector_assign" "', argument " "2"" of type '" "std::vector< pj::RtcpFbCap >::size_type""'");
  } 
  arg2 = static_cast< std::vector< pj::RtcpFbCap >::size_type >(val2);
  res3 = SWIG_ConvertPtr(swig_obj[2], &argp3, SWIGTYPE_p_pj__RtcpFbCap,  0  | 0);
  if (!SWIG_IsOK(res3)) {
    SWIG_exception_fail(SWIG_ArgError(res3), "in method '" "RtcpFbCapVector_assign" "', argument " "3"" of type '" "std::vector< pj::RtcpFbCap >::value_type const &""'"); 
  }
  if (!argp3) {
    SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "RtcpFbCapVector_assign" "', argument " "3"" of type '" "std::vector< pj::RtcpFbCap >::value_type const &""'"); 
  }
  arg3 = reinterpret_cast< std::vector< pj::RtcpFbCap >::value_type * >(argp3);
  (arg1)->assign(arg2,(std::vector< pj::RtcpFbCap >::value_type const &)*arg3);
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_RtcpFbCapVector_resize__SWIG_1(PyObject *SWIGUNUSEDPARM(self), Py_ssize_t nobjs, PyObject **swig_obj) {
  PyObject *resultobj = 0;
  std::vector< pj::RtcpFbCap > *arg1 = (std::vector< pj::RtcpFbCap > *) 0 ;
  std::vector< pj::RtcpFbCap >::size_type arg2 ;
  std::vector< pj::RtcpFbCap >::value_type *arg3 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  size_t val2 ;
  int ecode2 = 0 ;
  void *argp3 = 0 ;
  int res3 = 0 ;
  
  if ((nobjs < 3) || (nobjs > 3)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__vectorT_pj__RtcpFbCap_std__allocatorT_pj__RtcpFbCap_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "RtcpFbCapVector_resize" "', argument " "1"" of type '" "std::vector< pj::RtcpFbCap > *""'"); 
  }
  arg1 = reinterpret_cast< std::vector< pj::RtcpFbCap > * >(argp1);
  ecode2 = SWIG_AsVal_size_t(swig_obj[1], &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "RtcpFbCapVector_resize" "', argument " "2"" of type '" "std::vector< pj::RtcpFbCap >::size_type""'");
  } 
  arg2 = static_cast< std::vector< pj::RtcpFbCap >::size_type >(val2);
  res3 = SWIG_ConvertPtr(swig_obj[2], &argp3, SWIGTYPE_p_pj__RtcpFbCap,  0  | 0);
  if (!SWIG_IsOK(res3)) {
    SWIG_exception_fail(SWIG_ArgError(res3), "in method '" "RtcpFbCapVector_resize" "', argument " "3"" of type '" "std::vector< pj::RtcpFbCap >::value_type const &""'"); 
  }
  if (!argp3) {
    SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "RtcpFbCapVector_resize" "', argument " "3"" of type '" "std::vector< pj::RtcpFbCap >::value_type const &""'"); 
  }
  arg3 = reinterpret_cast< std::vector< pj::RtcpFbCap >::value_type * >(argp3);
  (arg1)->resize(arg2,(std::vector< pj::RtcpFbCap >::value_type const &)*arg3);
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_RtcpFbCapVector_resize(PyObject *self, PyObject *args) {
  Py_ssize_t argc;
  PyObject *argv[4] = {
    0
  };
  
  if (!(argc = SWIG_Python_UnpackTuple(args, "RtcpFbCapVector_resize", 0, 3, argv))) SWIG_fail;
  --argc;
  if (argc == 2) {
    int _v;
    int res = swig::asptr(argv[0], (std::vector< pj::RtcpFbCap,std::allocator< pj::RtcpFbCap > >**)(0));
    _v = SWIG_CheckState(res);
    if (_v) {
      {
        int res = SWIG_AsVal_size_t(argv[1], NULL);
        _v = SWIG_CheckState(res);
      }
      if (_v) {
        return _wrap_RtcpFbCapVector_resize__SWIG_0(self, argc, argv);
      }
    }
  }
  if (argc == 3) {
    int _v;
    int res = swig::asptr(argv[0], (std::vector< pj::RtcpFbCap,std::allocator< pj::RtcpFbCap > >**)(0));
    _v = SWIG_CheckState(res);
    if (_v) {
      {
        int res = SWIG_AsVal_size_t(argv[1], NULL);
        _v = SWIG_CheckState(res);
      }
      if (_v) {
        int res = SWIG_ConvertPtr(argv[2], 0, SWIGTYPE_p_pj__RtcpFbCap, SWIG_POINTER_NO_NULL | 0);
        _v = SWIG_CheckState(res);
        if (_v) {
          return _wrap_RtcpFbCapVector_resize__SWIG_1(self, argc, argv);
        }
      }
    }
  }
  
fail:
  SWIG_Python_RaiseOrModifyTypeError("Wrong number or type of arguments for overloaded function 'RtcpFbCapVector_resize'.\n"
    "  Possible C/C++ prototypes are:\n"
    "    std::vector< pj::RtcpFbCap >::resize(std::vector< pj::RtcpFbCap >::size_type)\n"
    "    std::vector< pj::RtcpFbCap >::resize(std::vector< pj::RtcpFbCap >::size_type,std::vector< pj::RtcpFbCap >::value_type const &)\n");
  return 0;
}


SWIGINTERN PyObject *_wrap_RtcpFbCapVector_insert__SWIG_0(PyObject *SWIGUNUSEDPARM(self), Py_ssize_t nobjs, PyObject **swig_obj) {
  PyObject *resultobj = 0;
  std::vector< pj::RtcpFbCap > *arg1 = (std::vector< pj::RtcpFbCap > *) 0 ;
  std::vector< pj::RtcpFbCap >::iterator arg2 ;
  std::vector< pj::RtcpFbCap >::value_type *arg3 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  swig::SwigPyIterator *iter2 = 0 ;
  int res2 ;
  void *argp3 = 0 ;
  int res3 = 0 ;
  std::vector< pj::RtcpFbCap >::iterator result;
  
  if ((nobjs < 3) || (nobjs > 3)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__vectorT_pj__RtcpFbCap_std__allocatorT_pj__RtcpFbCap_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "RtcpFbCapVector_insert" "', argument " "1"" of type '" "std::vector< pj::RtcpFbCap > *""'"); 
  }
  arg1 = reinterpret_cast< std::vector< pj::RtcpFbCap > * >(argp1);
  res2 = SWIG_ConvertPtr(swig_obj[1], SWIG_as_voidptrptr(&iter2), swig::SwigPyIterator::descriptor(), 0);
  if (!SWIG_IsOK(res2) || !iter2) {
    SWIG_exception_fail(SWIG_ArgError(SWIG_TypeError), "in method '" "RtcpFbCapVector_insert" "', argument " "2"" of type '" "std::vector< pj::RtcpFbCap >::iterator""'");
  } else {
    swig::SwigPyIterator_T<std::vector< pj::RtcpFbCap >::iterator > *iter_t = dynamic_cast<swig::SwigPyIterator_T<std::vector< pj::RtcpFbCap >::iterator > *>(iter2);
    if (iter_t) {
      arg2 = iter_t->get_current();
    } else {
      SWIG_exception_fail(SWIG_ArgError(SWIG_TypeError), "in method '" "RtcpFbCapVector_insert" "', argument " "2"" of type '" "std::vector< pj::RtcpFbCap >::iterator""'");
    }
  }
  res3 = SWIG_ConvertPtr(swig_obj[2], &argp3, SWIGTYPE_p_pj__RtcpFbCap,  0  | 0);
  if (!SWIG_IsOK(res3)) {
    SWIG_exception_fail(SWIG_ArgError(res3), "in method '" "RtcpFbCapVector_insert" "', argument " "3"" of type '" "std::vector< pj::RtcpFbCap >::value_type const &""'"); 
  }
  if (!argp3) {
    SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "RtcpFbCapVector_insert" "', argument " "3"" of type '" "std::vector< pj::RtcpFbCap >::value_type const &""'"); 
  }
  arg3 = reinterpret_cast< std::vector< pj::RtcpFbCap >::value_type * >(argp3);
  result = std_vector_Sl_pj_RtcpFbCap_Sg__insert__SWIG_0(arg1,arg2,(pj::RtcpFbCap const &)*arg3);
  resultobj = SWIG_NewPointerObj(swig::make_output_iterator(static_cast< const std::vector< pj::RtcpFbCap >::iterator & >(result)),
    swig::SwigPyIterator::descriptor(),SWIG_POINTER_OWN);
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_RtcpFbCapVector_insert__SWIG_1(PyObject *SWIGUNUSEDPARM(self), Py_ssize_t nobjs, PyObject **swig_obj) {
  PyObject *resultobj = 0;
  std::vector< pj::RtcpFbCap > *arg1 = (std::vector< pj::RtcpFbCap > *) 0 ;
  std::vector< pj::RtcpFbCap >::iterator arg2 ;
  std::vector< pj::RtcpFbCap >::size_type arg3 ;
  std::vector< pj::RtcpFbCap >::value_type *arg4 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  swig::SwigPyIterator *iter2 = 0 ;
  int res2 ;
  size_t val3 ;
  int ecode3 = 0 ;
  void *argp4 = 0 ;
  int res4 = 0 ;
  
  if ((nobjs < 4) || (nobjs > 4)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__vectorT_pj__RtcpFbCap_std__allocatorT_pj__RtcpFbCap_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "RtcpFbCapVector_insert" "', argument " "1"" of type '" "std::vector< pj::RtcpFbCap > *""'"); 
  }
  arg1 = reinterpret_cast< std::vector< pj::RtcpFbCap > * >(argp1);
  res2 = SWIG_ConvertPtr(swig_obj[1], SWIG_as_voidptrptr(&iter2), swig::SwigPyIterator::descriptor(), 0);
  if (!SWIG_IsOK(res2) || !iter2) {
    SWIG_exception_fail(SWIG_ArgError(SWIG_TypeError), "in method '" "RtcpFbCapVector_insert" "', argument " "2"" of type '" "std::vector< pj::RtcpFbCap >::iterator""'");
  } else {
    swig::SwigPyIterator_T<std::vector< pj::RtcpFbCap >::iterator > *iter_t = dynamic_cast<swig::SwigPyIterator_T<std::vector< pj::RtcpFbCap >::iterator > *>(iter2);
    if (iter_t) {
      arg2 = iter_t->get_current();
    } else {
      SWIG_exception_fail(SWIG_ArgError(SWIG_TypeError), "in method '" "RtcpFbCapVector_insert" "', argument " "2"" of type '" "std::vector< pj::RtcpFbCap >::iterator""'");
    }
  }
  ecode3 = SWIG_AsVal_size_t(swig_obj[2], &val3);
  if (!SWIG_IsOK(ecode3)) {
    SWIG_exception_fail(SWIG_ArgError(ecode3), "in method '" "RtcpFbCapVector_insert" "', argument " "3"" of type '" "std::vector< pj::RtcpFbCap >::size_type""'");
  } 
  arg3 = static_cast< std::vector< pj::RtcpFbCap >::size_type >(val3);
  res4 = SWIG_ConvertPtr(swig_obj[3], &argp4, SWIGTYPE_p_pj__RtcpFbCap,  0  | 0);
  if (!SWIG_IsOK(res4)) {
    SWIG_exception_fail(SWIG_ArgError(res4), "in method '" "RtcpFbCapVector_insert" "', argument " "4"" of type '" "std::vector< pj::RtcpFbCap >::value_type const &""'"); 
  }
  if (!argp4) {
    SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "RtcpFbCapVector_insert" "', argument " "4"" of type '" "std::vector< pj::RtcpFbCap >::value_type const &""'"); 
  }
  arg4 = reinterpret_cast< std::vector< pj::RtcpFbCap >::value_type * >(argp4);
  std_vector_Sl_pj_RtcpFbCap_Sg__insert__SWIG_1(arg1,arg2,arg3,(pj::RtcpFbCap const &)*arg4);
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_RtcpFbCapVector_insert(PyObject *self, PyObject *args) {
  Py_ssize_t argc;
  PyObject *argv[5] = {
    0
  };
  
  if (!(argc = SWIG_Python_UnpackTuple(args, "RtcpFbCapVector_insert", 0, 4, argv))) SWIG_fail;
  --argc;
  if (argc == 3) {
    int _v;
    int res = swig::asptr(argv[0], (std::vector< pj::RtcpFbCap,std::allocator< pj::RtcpFbCap > >**)(0));
    _v = SWIG_CheckState(res);
    if (_v) {
      swig::SwigPyIterator *iter = 0;
      int res = SWIG_ConvertPtr(argv[1], SWIG_as_voidptrptr(&iter), swig::SwigPyIterator::descriptor(), 0);
      _v = (SWIG_IsOK(res) && iter && (dynamic_cast<swig::SwigPyIterator_T<std::vector< pj::RtcpFbCap >::iterator > *>(iter) != 0));
      if (_v) {
        int res = SWIG_ConvertPtr(argv[2], 0, SWIGTYPE_p_pj__RtcpFbCap, SWIG_POINTER_NO_NULL | 0);
        _v = SWIG_CheckState(res);
        if (_v) {
          return _wrap_RtcpFbCapVector_insert__SWIG_0(self, argc, argv);
        }
      }
    }
  }
  if (argc == 4) {
    int _v;
    int res = swig::asptr(argv[0], (std::vector< pj::RtcpFbCap,std::allocator< pj::RtcpFbCap > >**)(0));
    _v = SWIG_CheckState(res);
    if (_v) {
      swig::SwigPyIterator *iter = 0;
      int res = SWIG_ConvertPtr(argv[1], SWIG_as_voidptrptr(&iter), swig::SwigPyIterator::descriptor(), 0);
      _v = (SWIG_IsOK(res) && iter && (dynamic_cast<swig::SwigPyIterator_T<std::vector< pj::RtcpFbCap >::iterator > *>(iter) != 0));
      if (_v) {
        {
          int res = SWIG_AsVal_size_t(argv[2], NULL);
          _v = SWIG_CheckState(res);
        }
        if (_v) {
          int res = SWIG_ConvertPtr(argv[3], 0, SWIGTYPE_p_pj__RtcpFbCap, SWIG_POINTER_NO_NULL | 0);
          _v = SWIG_CheckState(res);
          if (_v) {
            return _wrap_RtcpFbCapVector_insert__SWIG_1(self, argc, argv);
          }
        }
      }
    }
  }
  
fail:
  SWIG_Python_RaiseOrModifyTypeError("Wrong number or type of arguments for overloaded function 'RtcpFbCapVector_insert'.\n"
    "  Possible C/C++ prototypes are:\n"
    "    std::vector< pj::RtcpFbCap >::insert(std::vector< pj::RtcpFbCap >::iterator,std::vector< pj::RtcpFbCap >::value_type const &)\n"
    "    std::vector< pj::RtcpFbCap >::insert(std::vector< pj::RtcpFbCap >::iterator,std::vector< pj::RtcpFbCap >::size_type,std::vector< pj::RtcpFbCap >::value_type const &)\n");
  return 0;
}


SWIGINTERN PyObject *_wrap_RtcpFbCapVector_reserve(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  std::vector< pj::RtcpFbCap > *arg1 = (std::vector< pj::RtcpFbCap > *) 0 ;
  std::vector< pj::RtcpFbCap >::size_type arg2 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  size_t val2 ;
  int ecode2 = 0 ;
  PyObject *swig_obj[2] ;
  
  if (!SWIG_Python_UnpackTuple(args, "RtcpFbCapVector_reserve", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__vectorT_pj__RtcpFbCap_std__allocatorT_pj__RtcpFbCap_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "RtcpFbCapVector_reserve" "', argument " "1"" of type '" "std::vector< pj::RtcpFbCap > *""'"); 
  }
  arg1 = reinterpret_cast< std::vector< pj::RtcpFbCap > * >(argp1);
  ecode2 = SWIG_AsVal_size_t(swig_obj[1], &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "RtcpFbCapVector_reserve" "', argument " "2"" of type '" "std::vector< pj::RtcpFbCap >::size_type""'");
  } 
  arg2 = static_cast< std::vector< pj::RtcpFbCap >::size_type >(val2);
  (arg1)->reserve(arg2);
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_RtcpFbCapVector_capacity(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  std::vector< pj::RtcpFbCap > *arg1 = (std::vector< pj::RtcpFbCap > *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  std::vector< pj::RtcpFbCap >::size_type result;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__vectorT_pj__RtcpFbCap_std__allocatorT_pj__RtcpFbCap_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "RtcpFbCapVector_capacity" "', argument " "1"" of type '" "std::vector< pj::RtcpFbCap > const *""'"); 
  }
  arg1 = reinterpret_cast< std::vector< pj::RtcpFbCap > * >(argp1);
  result = ((std::vector< pj::RtcpFbCap > const *)arg1)->capacity();
  resultobj = SWIG_From_size_t(static_cast< size_t >(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_delete_RtcpFbCapVector(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  std::vector< pj::RtcpFbCap > *arg1 = (std::vector< pj::RtcpFbCap > *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__vectorT_pj__RtcpFbCap_std__allocatorT_pj__RtcpFbCap_t_t, SWIG_POINTER_DISOWN |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "delete_RtcpFbCapVector" "', argument " "1"" of type '" "std::vector< pj::RtcpFbCap > *""'"); 
  }
  arg1 = reinterpret_cast< std::vector< pj::RtcpFbCap > * >(argp1);
  delete arg1;
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *RtcpFbCapVector_swigregister(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *obj;
  if (!SWIG_Python_UnpackTuple(args, "swigregister", 1, 1, &obj)) return NULL;
  SWIG_TypeNewClientData(SWIGTYPE_p_std__vectorT_pj__RtcpFbCap_std__allocatorT_pj__RtcpFbCap_t_t, SWIG_NewClientData(obj));
  return SWIG_Py_Void();
}

SWIGINTERN PyObject *RtcpFbCapVector_swiginit(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  return SWIG_Python_InitShadowInstance(args);
}

SWIGINTERN PyObject *_wrap_SslCertNameVector_iterator(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  std::vector< pj::SslCertName > *arg1 = (std::vector< pj::SslCertName > *) 0 ;
  PyObject **arg2 = (PyObject **) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  swig::SwigPyIterator *result = 0 ;
  
  arg2 = &swig_obj[0];
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__vectorT_pj__SslCertName_std__allocatorT_pj__SslCertName_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "SslCertNameVector_iterator" "', argument " "1"" of type '" "std::vector< pj::SslCertName > *""'"); 
  }
  arg1 = reinterpret_cast< std::vector< pj::SslCertName > * >(argp1);
  result = (swig::SwigPyIterator *)std_vector_Sl_pj_SslCertName_Sg__iterator(arg1,arg2);
  resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(result), SWIGTYPE_p_swig__SwigPyIterator, SWIG_POINTER_OWN |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_SslCertNameVector___nonzero__(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  std::vector< pj::SslCertName > *arg1 = (std::vector< pj::SslCertName > *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  bool result;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__vectorT_pj__SslCertName_std__allocatorT_pj__SslCertName_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "SslCertNameVector___nonzero__" "', argument " "1"" of type '" "std::vector< pj::SslCertName > const *""'"); 
  }
  arg1 = reinterpret_cast< std::vector< pj::SslCertName > * >(argp1);
  result = (bool)std_vector_Sl_pj_SslCertName_Sg____nonzero__((std::vector< pj::SslCertName > const *)arg1);
  resultobj = SWIG_From_bool(static_cast< bool >(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_SslCertNameVector___bool__(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  std::vector< pj::SslCertName > *arg1 = (std::vector< pj::SslCertName > *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  bool result;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__vectorT_pj__SslCertName_std__allocatorT_pj__SslCertName_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "SslCertNameVector___bool__" "', argument " "1"" of type '" "std::vector< pj::SslCertName > const *""'"); 
  }
  arg1 = reinterpret_cast< std::vector< pj::SslCertName > * >(argp1);
  result = (bool)std_vector_Sl_pj_SslCertName_Sg____bool__((std::vector< pj::SslCertName > const *)arg1);
  resultobj = SWIG_From_bool(static_cast< bool >(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_SslCertNameVector___len__(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  std::vector< pj::SslCertName > *arg1 = (std::vector< pj::SslCertName > *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  std::vector< pj::SslCertName >::size_type result;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__vectorT_pj__SslCertName_std__allocatorT_pj__SslCertName_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "SslCertNameVector___len__" "', argument " "1"" of type '" "std::vector< pj::SslCertName > const *""'"); 
  }
  arg1 = reinterpret_cast< std::vector< pj::SslCertName > * >(argp1);
  result = std_vector_Sl_pj_SslCertName_Sg____len__((std::vector< pj::SslCertName > const *)arg1);
  resultobj = SWIG_From_size_t(static_cast< size_t >(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_SslCertNameVector___getslice__(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  std::vector< pj::SslCertName > *arg1 = (std::vector< pj::SslCertName > *) 0 ;
  std::vector< pj::SslCertName >::difference_type arg2 ;
  std::vector< pj::SslCertName >::difference_type arg3 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  ptrdiff_t val2 ;
  int ecode2 = 0 ;
  ptrdiff_t val3 ;
  int ecode3 = 0 ;
  PyObject *swig_obj[3] ;
  std::vector< pj::SslCertName,std::allocator< pj::SslCertName > > *result = 0 ;
  
  if (!SWIG_Python_UnpackTuple(args, "SslCertNameVector___getslice__", 3, 3, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__vectorT_pj__SslCertName_std__allocatorT_pj__SslCertName_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "SslCertNameVector___getslice__" "', argument " "1"" of type '" "std::vector< pj::SslCertName > *""'"); 
  }
  arg1 = reinterpret_cast< std::vector< pj::SslCertName > * >(argp1);
  ecode2 = SWIG_AsVal_ptrdiff_t(swig_obj[1], &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "SslCertNameVector___getslice__" "', argument " "2"" of type '" "std::vector< pj::SslCertName >::difference_type""'");
  } 
  arg2 = static_cast< std::vector< pj::SslCertName >::difference_type >(val2);
  ecode3 = SWIG_AsVal_ptrdiff_t(swig_obj[2], &val3);
  if (!SWIG_IsOK(ecode3)) {
    SWIG_exception_fail(SWIG_ArgError(ecode3), "in method '" "SslCertNameVector___getslice__" "', argument " "3"" of type '" "std::vector< pj::SslCertName >::difference_type""'");
  } 
  arg3 = static_cast< std::vector< pj::SslCertName >::difference_type >(val3);
  try {
    result = (std::vector< pj::SslCertName,std::allocator< pj::SslCertName > > *)std_vector_Sl_pj_SslCertName_Sg____getslice__(arg1,arg2,arg3);
  } catch(std::out_of_range &_e) {
    SWIG_exception_fail(SWIG_IndexError, (&_e)->what());
  } catch(std::invalid_argument &_e) {
    SWIG_exception_fail(SWIG_ValueError, (&_e)->what());
  }
  resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(result), SWIGTYPE_p_std__vectorT_pj__SslCertName_std__allocatorT_pj__SslCertName_t_t, SWIG_POINTER_OWN |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_SslCertNameVector___setslice____SWIG_0(PyObject *SWIGUNUSEDPARM(self), Py_ssize_t nobjs, PyObject **swig_obj) {
  PyObject *resultobj = 0;
  std::vector< pj::SslCertName > *arg1 = (std::vector< pj::SslCertName > *) 0 ;
  std::vector< pj::SslCertName >::difference_type arg2 ;
  std::vector< pj::SslCertName >::difference_type arg3 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  ptrdiff_t val2 ;
  int ecode2 = 0 ;
  ptrdiff_t val3 ;
  int ecode3 = 0 ;
  
  if ((nobjs < 3) || (nobjs > 3)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__vectorT_pj__SslCertName_std__allocatorT_pj__SslCertName_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "SslCertNameVector___setslice__" "', argument " "1"" of type '" "std::vector< pj::SslCertName > *""'"); 
  }
  arg1 = reinterpret_cast< std::vector< pj::SslCertName > * >(argp1);
  ecode2 = SWIG_AsVal_ptrdiff_t(swig_obj[1], &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "SslCertNameVector___setslice__" "', argument " "2"" of type '" "std::vector< pj::SslCertName >::difference_type""'");
  } 
  arg2 = static_cast< std::vector< pj::SslCertName >::difference_type >(val2);
  ecode3 = SWIG_AsVal_ptrdiff_t(swig_obj[2], &val3);
  if (!SWIG_IsOK(ecode3)) {
    SWIG_exception_fail(SWIG_ArgError(ecode3), "in method '" "SslCertNameVector___setslice__" "', argument " "3"" of type '" "std::vector< pj::SslCertName >::difference_type""'");
  } 
  arg3 = static_cast< std::vector< pj::SslCertName >::difference_type >(val3);
  try {
    std_vector_Sl_pj_SslCertName_Sg____setslice____SWIG_0(arg1,arg2,arg3);
  } catch(std::out_of_range &_e) {
    SWIG_exception_fail(SWIG_IndexError, (&_e)->what());
  } catch(std::invalid_argument &_e) {
    SWIG_exception_fail(SWIG_ValueError, (&_e)->what());
  }
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_SslCertNameVector___setslice____SWIG_1(PyObject *SWIGUNUSEDPARM(self), Py_ssize_t nobjs, PyObject **swig_obj) {
  PyObject *resultobj = 0;
  std::vector< pj::SslCertName > *arg1 = (std::vector< pj::SslCertName > *) 0 ;
  std::vector< pj::SslCertName >::difference_type arg2 ;
  std::vector< pj::SslCertName >::difference_type arg3 ;
  std::vector< pj::SslCertName,std::allocator< pj::SslCertName > > *arg4 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  ptrdiff_t val2 ;
  int ecode2 = 0 ;
  ptrdiff_t val3 ;
  int ecode3 = 0 ;
  int res4 = SWIG_OLDOBJ ;
  
  if ((nobjs < 4) || (nobjs > 4)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__vectorT_pj__SslCertName_std__allocatorT_pj__SslCertName_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "SslCertNameVector___setslice__" "', argument " "1"" of type '" "std::vector< pj::SslCertName > *""'"); 
  }
  arg1 = reinterpret_cast< std::vector< pj::SslCertName > * >(argp1);
  ecode2 = SWIG_AsVal_ptrdiff_t(swig_obj[1], &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "SslCertNameVector___setslice__" "', argument " "2"" of type '" "std::vector< pj::SslCertName >::difference_type""'");
  } 
  arg2 = static_cast< std::vector< pj::SslCertName >::difference_type >(val2);
  ecode3 = SWIG_AsVal_ptrdiff_t(swig_obj[2], &val3);
  if (!SWIG_IsOK(ecode3)) {
    SWIG_exception_fail(SWIG_ArgError(ecode3), "in method '" "SslCertNameVector___setslice__" "', argument " "3"" of type '" "std::vector< pj::SslCertName >::difference_type""'");
  } 
  arg3 = static_cast< std::vector< pj::SslCertName >::difference_type >(val3);
  {
    std::vector< pj::SslCertName,std::allocator< pj::SslCertName > > *ptr = (std::vector< pj::SslCertName,std::allocator< pj::SslCertName > > *)0;
    res4 = swig::asptr(swig_obj[3], &ptr);
    if (!SWIG_IsOK(res4)) {
      SWIG_exception_fail(SWIG_ArgError(res4), "in method '" "SslCertNameVector___setslice__" "', argument " "4"" of type '" "std::vector< pj::SslCertName,std::allocator< pj::SslCertName > > const &""'"); 
    }
    if (!ptr) {
      SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "SslCertNameVector___setslice__" "', argument " "4"" of type '" "std::vector< pj::SslCertName,std::allocator< pj::SslCertName > > const &""'"); 
    }
    arg4 = ptr;
  }
  try {
    std_vector_Sl_pj_SslCertName_Sg____setslice____SWIG_1(arg1,arg2,arg3,(std::vector< pj::SslCertName,std::allocator< pj::SslCertName > > const &)*arg4);
  } catch(std::out_of_range &_e) {
    SWIG_exception_fail(SWIG_IndexError, (&_e)->what());
  } catch(std::invalid_argument &_e) {
    SWIG_exception_fail(SWIG_ValueError, (&_e)->what());
  }
  resultobj = SWIG_Py_Void();
  if (SWIG_IsNewObj(res4)) delete arg4;
  return resultobj;
fail:
  if (SWIG_IsNewObj(res4)) delete arg4;
  return NULL;
}


SWIGINTERN PyObject *_wrap_SslCertNameVector___setslice__(PyObject *self, PyObject *args) {
  Py_ssize_t argc;
  PyObject *argv[5] = {
    0
  };
  
  if (!(argc = SWIG_Python_UnpackTuple(args, "SslCertNameVector___setslice__", 0, 4, argv))) SWIG_fail;
  --argc;
  if (argc == 3) {
    int _v;
    int res = swig::asptr(argv[0], (std::vector< pj::SslCertName,std::allocator< pj::SslCertName > >**)(0));
    _v = SWIG_CheckState(res);
    if (_v) {
      {
        int res = SWIG_AsVal_ptrdiff_t(argv[1], NULL);
        _v = SWIG_CheckState(res);
      }
      if (_v) {
        {
          int res = SWIG_AsVal_ptrdiff_t(argv[2], NULL);
          _v = SWIG_CheckState(res);
        }
        if (_v) {
          return _wrap_SslCertNameVector___setslice____SWIG_0(self, argc, argv);
        }
      }
    }
  }
  if (argc == 4) {
    int _v;
    int res = swig::asptr(argv[0], (std::vector< pj::SslCertName,std::allocator< pj::SslCertName > >**)(0));
    _v = SWIG_CheckState(res);
    if (_v) {
      {
        int res = SWIG_AsVal_ptrdiff_t(argv[1], NULL);
        _v = SWIG_CheckState(res);
      }
      if (_v) {
        {
          int res = SWIG_AsVal_ptrdiff_t(argv[2], NULL);
          _v = SWIG_CheckState(res);
        }
        if (_v) {
          int res = swig::asptr(argv[3], (std::vector< pj::SslCertName,std::allocator< pj::SslCertName > >**)(0));
          _v = SWIG_CheckState(res);
          if (_v) {
            return _wrap_SslCertNameVector___setslice____SWIG_1(self, argc, argv);
          }
        }
      }
    }
  }
  
fail:
  SWIG_Python_RaiseOrModifyTypeError("Wrong number or type of arguments for overloaded function 'SslCertNameVector___setslice__'.\n"
    "  Possible C/C++ prototypes are:\n"
    "    std::vector< pj::SslCertName >::__setslice__(std::vector< pj::SslCertName >::difference_type,std::vector< pj::SslCertName >::difference_type)\n"
    "    std::vector< pj::SslCertName >::__setslice__(std::vector< pj::SslCertName >::difference_type,std::vector< pj::SslCertName >::difference_type,std::vector< pj::SslCertName,std::allocator< pj::SslCertName > > const &)\n");
  return 0;
}


SWIGINTERN PyObject *_wrap_SslCertNameVector___delslice__(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  std::vector< pj::SslCertName > *arg1 = (std::vector< pj::SslCertName > *) 0 ;
  std::vector< pj::SslCertName >::difference_type arg2 ;
  std::vector< pj::SslCertName >::difference_type arg3 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  ptrdiff_t val2 ;
  int ecode2 = 0 ;
  ptrdiff_t val3 ;
  int ecode3 = 0 ;
  PyObject *swig_obj[3] ;
  
  if (!SWIG_Python_UnpackTuple(args, "SslCertNameVector___delslice__", 3, 3, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__vectorT_pj__SslCertName_std__allocatorT_pj__SslCertName_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "SslCertNameVector___delslice__" "', argument " "1"" of type '" "std::vector< pj::SslCertName > *""'"); 
  }
  arg1 = reinterpret_cast< std::vector< pj::SslCertName > * >(argp1);
  ecode2 = SWIG_AsVal_ptrdiff_t(swig_obj[1], &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "SslCertNameVector___delslice__" "', argument " "2"" of type '" "std::vector< pj::SslCertName >::difference_type""'");
  } 
  arg2 = static_cast< std::vector< pj::SslCertName >::difference_type >(val2);
  ecode3 = SWIG_AsVal_ptrdiff_t(swig_obj[2], &val3);
  if (!SWIG_IsOK(ecode3)) {
    SWIG_exception_fail(SWIG_ArgError(ecode3), "in method '" "SslCertNameVector___delslice__" "', argument " "3"" of type '" "std::vector< pj::SslCertName >::difference_type""'");
  } 
  arg3 = static_cast< std::vector< pj::SslCertName >::difference_type >(val3);
  try {
    std_vector_Sl_pj_SslCertName_Sg____delslice__(arg1,arg2,arg3);
  } catch(std::out_of_range &_e) {
    SWIG_exception_fail(SWIG_IndexError, (&_e)->what());
  } catch(std::invalid_argument &_e) {
    SWIG_exception_fail(SWIG_ValueError, (&_e)->what());
  }
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_SslCertNameVector___delitem____SWIG_0(PyObject *SWIGUNUSEDPARM(self), Py_ssize_t nobjs, PyObject **swig_obj) {
  PyObject *resultobj = 0;
  std::vector< pj::SslCertName > *arg1 = (std::vector< pj::SslCertName > *) 0 ;
  std::vector< pj::SslCertName >::difference_type arg2 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  ptrdiff_t val2 ;
  int ecode2 = 0 ;
  
  if ((nobjs < 2) || (nobjs > 2)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__vectorT_pj__SslCertName_std__allocatorT_pj__SslCertName_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "SslCertNameVector___delitem__" "', argument " "1"" of type '" "std::vector< pj::SslCertName > *""'"); 
  }
  arg1 = reinterpret_cast< std::vector< pj::SslCertName > * >(argp1);
  ecode2 = SWIG_AsVal_ptrdiff_t(swig_obj[1], &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "SslCertNameVector___delitem__" "', argument " "2"" of type '" "std::vector< pj::SslCertName >::difference_type""'");
  } 
  arg2 = static_cast< std::vector< pj::SslCertName >::difference_type >(val2);
  try {
    std_vector_Sl_pj_SslCertName_Sg____delitem____SWIG_0(arg1,arg2);
  } catch(std::out_of_range &_e) {
    SWIG_exception_fail(SWIG_IndexError, (&_e)->what());
  } catch(std::invalid_argument &_e) {
    SWIG_exception_fail(SWIG_ValueError, (&_e)->what());
  }
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_SslCertNameVector___getitem____SWIG_0(PyObject *SWIGUNUSEDPARM(self), Py_ssize_t nobjs, PyObject **swig_obj) {
  PyObject *resultobj = 0;
  std::vector< pj::SslCertName > *arg1 = (std::vector< pj::SslCertName > *) 0 ;
  PySliceObject *arg2 = (PySliceObject *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  std::vector< pj::SslCertName,std::allocator< pj::SslCertName > > *result = 0 ;
  
  if ((nobjs < 2) || (nobjs > 2)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__vectorT_pj__SslCertName_std__allocatorT_pj__SslCertName_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "SslCertNameVector___getitem__" "', argument " "1"" of type '" "std::vector< pj::SslCertName > *""'"); 
  }
  arg1 = reinterpret_cast< std::vector< pj::SslCertName > * >(argp1);
  {
    if (!PySlice_Check(swig_obj[1])) {
      SWIG_exception_fail(SWIG_ArgError(SWIG_TypeError), "in method '" "SslCertNameVector___getitem__" "', argument " "2"" of type '" "PySliceObject *""'");
    }
    arg2 = (PySliceObject *) swig_obj[1];
  }
  try {
    result = (std::vector< pj::SslCertName,std::allocator< pj::SslCertName > > *)std_vector_Sl_pj_SslCertName_Sg____getitem____SWIG_0(arg1,arg2);
  } catch(std::out_of_range &_e) {
    SWIG_exception_fail(SWIG_IndexError, (&_e)->what());
  } catch(std::invalid_argument &_e) {
    SWIG_exception_fail(SWIG_ValueError, (&_e)->what());
  }
  resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(result), SWIGTYPE_p_std__vectorT_pj__SslCertName_std__allocatorT_pj__SslCertName_t_t, SWIG_POINTER_OWN |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_SslCertNameVector___setitem____SWIG_0(PyObject *SWIGUNUSEDPARM(self), Py_ssize_t nobjs, PyObject **swig_obj) {
  PyObject *resultobj = 0;
  std::vector< pj::SslCertName > *arg1 = (std::vector< pj::SslCertName > *) 0 ;
  PySliceObject *arg2 = (PySliceObject *) 0 ;
  std::vector< pj::SslCertName,std::allocator< pj::SslCertName > > *arg3 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  int res3 = SWIG_OLDOBJ ;
  
  if ((nobjs < 3) || (nobjs > 3)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__vectorT_pj__SslCertName_std__allocatorT_pj__SslCertName_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "SslCertNameVector___setitem__" "', argument " "1"" of type '" "std::vector< pj::SslCertName > *""'"); 
  }
  arg1 = reinterpret_cast< std::vector< pj::SslCertName > * >(argp1);
  {
    if (!PySlice_Check(swig_obj[1])) {
      SWIG_exception_fail(SWIG_ArgError(SWIG_TypeError), "in method '" "SslCertNameVector___setitem__" "', argument " "2"" of type '" "PySliceObject *""'");
    }
    arg2 = (PySliceObject *) swig_obj[1];
  }
  {
    std::vector< pj::SslCertName,std::allocator< pj::SslCertName > > *ptr = (std::vector< pj::SslCertName,std::allocator< pj::SslCertName > > *)0;
    res3 = swig::asptr(swig_obj[2], &ptr);
    if (!SWIG_IsOK(res3)) {
      SWIG_exception_fail(SWIG_ArgError(res3), "in method '" "SslCertNameVector___setitem__" "', argument " "3"" of type '" "std::vector< pj::SslCertName,std::allocator< pj::SslCertName > > const &""'"); 
    }
    if (!ptr) {
      SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "SslCertNameVector___setitem__" "', argument " "3"" of type '" "std::vector< pj::SslCertName,std::allocator< pj::SslCertName > > const &""'"); 
    }
    arg3 = ptr;
  }
  try {
    std_vector_Sl_pj_SslCertName_Sg____setitem____SWIG_0(arg1,arg2,(std::vector< pj::SslCertName,std::allocator< pj::SslCertName > > const &)*arg3);
  } catch(std::out_of_range &_e) {
    SWIG_exception_fail(SWIG_IndexError, (&_e)->what());
  } catch(std::invalid_argument &_e) {
    SWIG_exception_fail(SWIG_ValueError, (&_e)->what());
  }
  resultobj = SWIG_Py_Void();
  if (SWIG_IsNewObj(res3)) delete arg3;
  return resultobj;
fail:
  if (SWIG_IsNewObj(res3)) delete arg3;
  return NULL;
}


SWIGINTERN PyObject *_wrap_SslCertNameVector___setitem____SWIG_1(PyObject *SWIGUNUSEDPARM(self), Py_ssize_t nobjs, PyObject **swig_obj) {
  PyObject *resultobj = 0;
  std::vector< pj::SslCertName > *arg1 = (std::vector< pj::SslCertName > *) 0 ;
  PySliceObject *arg2 = (PySliceObject *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  
  if ((nobjs < 2) || (nobjs > 2)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__vectorT_pj__SslCertName_std__allocatorT_pj__SslCertName_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "SslCertNameVector___setitem__" "', argument " "1"" of type '" "std::vector< pj::SslCertName > *""'"); 
  }
  arg1 = reinterpret_cast< std::vector< pj::SslCertName > * >(argp1);
  {
    if (!PySlice_Check(swig_obj[1])) {
      SWIG_exception_fail(SWIG_ArgError(SWIG_TypeError), "in method '" "SslCertNameVector___setitem__" "', argument " "2"" of type '" "PySliceObject *""'");
    }
    arg2 = (PySliceObject *) swig_obj[1];
  }
  try {
    std_vector_Sl_pj_SslCertName_Sg____setitem____SWIG_1(arg1,arg2);
  } catch(std::out_of_range &_e) {
    SWIG_exception_fail(SWIG_IndexError, (&_e)->what());
  } catch(std::invalid_argument &_e) {
    SWIG_exception_fail(SWIG_ValueError, (&_e)->what());
  }
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_SslCertNameVector___delitem____SWIG_1(PyObject *SWIGUNUSEDPARM(self), Py_ssize_t nobjs, PyObject **swig_obj) {
  PyObject *resultobj = 0;
  std::vector< pj::SslCertName > *arg1 = (std::vector< pj::SslCertName > *) 0 ;
  PySliceObject *arg2 = (PySliceObject *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  
  if ((nobjs < 2) || (nobjs > 2)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__vectorT_pj__SslCertName_std__allocatorT_pj__SslCertName_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "SslCertNameVector___delitem__" "', argument " "1"" of type '" "std::vector< pj::SslCertName > *""'"); 
  }
  arg1 = reinterpret_cast< std::vector< pj::SslCertName > * >(argp1);
  {
    if (!PySlice_Check(swig_obj[1])) {
      SWIG_exception_fail(SWIG_ArgError(SWIG_TypeError), "in method '" "SslCertNameVector___delitem__" "', argument " "2"" of type '" "PySliceObject *""'");
    }
    arg2 = (PySliceObject *) swig_obj[1];
  }
  try {
    std_vector_Sl_pj_SslCertName_Sg____delitem____SWIG_1(arg1,arg2);
  } catch(std::out_of_range &_e) {
    SWIG_exception_fail(SWIG_IndexError, (&_e)->what());
  } catch(std::invalid_argument &_e) {
    SWIG_exception_fail(SWIG_ValueError, (&_e)->what());
  }
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_SslCertNameVector___delitem__(PyObject *self, PyObject *args) {
  Py_ssize_t argc;
  PyObject *argv[3] = {
    0
  };
  
  if (!(argc = SWIG_Python_UnpackTuple(args, "SslCertNameVector___delitem__", 0, 2, argv))) SWIG_fail;
  --argc;
  if (argc == 2) {
    int _v;
    int res = swig::asptr(argv[0], (std::vector< pj::SslCertName,std::allocator< pj::SslCertName > >**)(0));
    _v = SWIG_CheckState(res);
    if (_v) {
      {
        _v = PySlice_Check(argv[1]);
      }
      if (_v) {
        return _wrap_SslCertNameVector___delitem____SWIG_1(self, argc, argv);
      }
    }
  }
  if (argc == 2) {
    int _v;
    int res = swig::asptr(argv[0], (std::vector< pj::SslCertName,std::allocator< pj::SslCertName > >**)(0));
    _v = SWIG_CheckState(res);
    if (_v) {
      {
        int res = SWIG_AsVal_ptrdiff_t(argv[1], NULL);
        _v = SWIG_CheckState(res);
      }
      if (_v) {
        return _wrap_SslCertNameVector___delitem____SWIG_0(self, argc, argv);
      }
    }
  }
  
fail:
  SWIG_Python_RaiseOrModifyTypeError("Wrong number or type of arguments for overloaded function 'SslCertNameVector___delitem__'.\n"
    "  Possible C/C++ prototypes are:\n"
    "    std::vector< pj::SslCertName >::__delitem__(std::vector< pj::SslCertName >::difference_type)\n"
    "    std::vector< pj::SslCertName >::__delitem__(PySliceObject *)\n");
  return 0;
}


SWIGINTERN PyObject *_wrap_SslCertNameVector___getitem____SWIG_1(PyObject *SWIGUNUSEDPARM(self), Py_ssize_t nobjs, PyObject **swig_obj) {
  PyObject *resultobj = 0;
  std::vector< pj::SslCertName > *arg1 = (std::vector< pj::SslCertName > *) 0 ;
  std::vector< pj::SslCertName >::difference_type arg2 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  ptrdiff_t val2 ;
  int ecode2 = 0 ;
  std::vector< pj::SslCertName >::value_type *result = 0 ;
  
  if ((nobjs < 2) || (nobjs > 2)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__vectorT_pj__SslCertName_std__allocatorT_pj__SslCertName_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "SslCertNameVector___getitem__" "', argument " "1"" of type '" "std::vector< pj::SslCertName > const *""'"); 
  }
  arg1 = reinterpret_cast< std::vector< pj::SslCertName > * >(argp1);
  ecode2 = SWIG_AsVal_ptrdiff_t(swig_obj[1], &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "SslCertNameVector___getitem__" "', argument " "2"" of type '" "std::vector< pj::SslCertName >::difference_type""'");
  } 
  arg2 = static_cast< std::vector< pj::SslCertName >::difference_type >(val2);
  try {
    result = (std::vector< pj::SslCertName >::value_type *) &std_vector_Sl_pj_SslCertName_Sg____getitem____SWIG_1((std::vector< pj::SslCertName > const *)arg1,arg2);
  } catch(std::out_of_range &_e) {
    SWIG_exception_fail(SWIG_IndexError, (&_e)->what());
  }
  resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(result), SWIGTYPE_p_pj__SslCertName, 0 |  0 );
  (void)swig::container_owner<swig::traits<std::vector< pj::SslCertName >::value_type>::category>::back_reference(resultobj, swig_obj[0]);
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_SslCertNameVector___getitem__(PyObject *self, PyObject *args) {
  Py_ssize_t argc;
  PyObject *argv[3] = {
    0
  };
  
  if (!(argc = SWIG_Python_UnpackTuple(args, "SslCertNameVector___getitem__", 0, 2, argv))) SWIG_fail;
  --argc;
  if (argc == 2) {
    int _v;
    int res = swig::asptr(argv[0], (std::vector< pj::SslCertName,std::allocator< pj::SslCertName > >**)(0));
    _v = SWIG_CheckState(res);
    if (_v) {
      {
        _v = PySlice_Check(argv[1]);
      }
      if (_v) {
        return _wrap_SslCertNameVector___getitem____SWIG_0(self, argc, argv);
      }
    }
  }
  if (argc == 2) {
    int _v;
    int res = swig::asptr(argv[0], (std::vector< pj::SslCertName,std::allocator< pj::SslCertName > >**)(0));
    _v = SWIG_CheckState(res);
    if (_v) {
      {
        int res = SWIG_AsVal_ptrdiff_t(argv[1], NULL);
        _v = SWIG_CheckState(res);
      }
      if (_v) {
        return _wrap_SslCertNameVector___getitem____SWIG_1(self, argc, argv);
      }
    }
  }
  
fail:
  SWIG_Python_RaiseOrModifyTypeError("Wrong number or type of arguments for overloaded function 'SslCertNameVector___getitem__'.\n"
    "  Possible C/C++ prototypes are:\n"
    "    std::vector< pj::SslCertName >::__getitem__(PySliceObject *)\n"
    "    std::vector< pj::SslCertName >::__getitem__(std::vector< pj::SslCertName >::difference_type) const\n");
  return 0;
}


SWIGINTERN PyObject *_wrap_SslCertNameVector___setitem____SWIG_2(PyObject *SWIGUNUSEDPARM(self), Py_ssize_t nobjs, PyObject **swig_obj) {
  PyObject *resultobj = 0;
  std::vector< pj::SslCertName > *arg1 = (std::vector< pj::SslCertName > *) 0 ;
  std::vector< pj::SslCertName >::difference_type arg2 ;
  std::vector< pj::SslCertName >::value_type *arg3 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  ptrdiff_t val2 ;
  int ecode2 = 0 ;
  void *argp3 = 0 ;
  int res3 = 0 ;
  
  if ((nobjs < 3) || (nobjs > 3)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__vectorT_pj__SslCertName_std__allocatorT_pj__SslCertName_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "SslCertNameVector___setitem__" "', argument " "1"" of type '" "std::vector< pj::SslCertName > *""'"); 
  }
  arg1 = reinterpret_cast< std::vector< pj::SslCertName > * >(argp1);
  ecode2 = SWIG_AsVal_ptrdiff_t(swig_obj[1], &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "SslCertNameVector___setitem__" "', argument " "2"" of type '" "std::vector< pj::SslCertName >::difference_type""'");
  } 
  arg2 = static_cast< std::vector< pj::SslCertName >::difference_type >(val2);
  res3 = SWIG_ConvertPtr(swig_obj[2], &argp3, SWIGTYPE_p_pj__SslCertName,  0  | 0);
  if (!SWIG_IsOK(res3)) {
    SWIG_exception_fail(SWIG_ArgError(res3), "in method '" "SslCertNameVector___setitem__" "', argument " "3"" of type '" "std::vector< pj::SslCertName >::value_type const &""'"); 
  }
  if (!argp3) {
    SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "SslCertNameVector___setitem__" "', argument " "3"" of type '" "std::vector< pj::SslCertName >::value_type const &""'"); 
  }
  arg3 = reinterpret_cast< std::vector< pj::SslCertName >::value_type * >(argp3);
  try {
    std_vector_Sl_pj_SslCertName_Sg____setitem____SWIG_2(arg1,arg2,(pj::SslCertName const &)*arg3);
  } catch(std::out_of_range &_e) {
    SWIG_exception_fail(SWIG_IndexError, (&_e)->what());
  }
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_SslCertNameVector___setitem__(PyObject *self, PyObject *args) {
  Py_ssize_t argc;
  PyObject *argv[4] = {
    0
  };
  
  if (!(argc = SWIG_Python_UnpackTuple(args, "SslCertNameVector___setitem__", 0, 3, argv))) SWIG_fail;
  --argc;
  if (argc == 2) {
    int _v;
    int res = swig::asptr(argv[0], (std::vector< pj::SslCertName,std::allocator< pj::SslCertName > >**)(0));
    _v = SWIG_CheckState(res);
    if (_v) {
      {
        _v = PySlice_Check(argv[1]);
      }
      if (_v) {
        return _wrap_SslCertNameVector___setitem____SWIG_1(self, argc, argv);
      }
    }
  }
  if (argc == 3) {
    int _v;
    int res = swig::asptr(argv[0], (std::vector< pj::SslCertName,std::allocator< pj::SslCertName > >**)(0));
    _v = SWIG_CheckState(res);
    if (_v) {
      {
        _v = PySlice_Check(argv[1]);
      }
      if (_v) {
        int res = swig::asptr(argv[2], (std::vector< pj::SslCertName,std::allocator< pj::SslCertName > >**)(0));
        _v = SWIG_CheckState(res);
        if (_v) {
          return _wrap_SslCertNameVector___setitem____SWIG_0(self, argc, argv);
        }
      }
    }
  }
  if (argc == 3) {
    int _v;
    int res = swig::asptr(argv[0], (std::vector< pj::SslCertName,std::allocator< pj::SslCertName > >**)(0));
    _v = SWIG_CheckState(res);
    if (_v) {
      {
        int res = SWIG_AsVal_ptrdiff_t(argv[1], NULL);
        _v = SWIG_CheckState(res);
      }
      if (_v) {
        int res = SWIG_ConvertPtr(argv[2], 0, SWIGTYPE_p_pj__SslCertName, SWIG_POINTER_NO_NULL | 0);
        _v = SWIG_CheckState(res);
        if (_v) {
          return _wrap_SslCertNameVector___setitem____SWIG_2(self, argc, argv);
        }
      }
    }
  }
  
fail:
  SWIG_Python_RaiseOrModifyTypeError("Wrong number or type of arguments for overloaded function 'SslCertNameVector___setitem__'.\n"
    "  Possible C/C++ prototypes are:\n"
    "    std::vector< pj::SslCertName >::__setitem__(PySliceObject *,std::vector< pj::SslCertName,std::allocator< pj::SslCertName > > const &)\n"
    "    std::vector< pj::SslCertName >::__setitem__(PySliceObject *)\n"
    "    std::vector< pj::SslCertName >::__setitem__(std::vector< pj::SslCertName >::difference_type,std::vector< pj::SslCertName >::value_type const &)\n");
  return 0;
}


SWIGINTERN PyObject *_wrap_SslCertNameVector_pop(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  std::vector< pj::SslCertName > *arg1 = (std::vector< pj::SslCertName > *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  std::vector< pj::SslCertName >::value_type result;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__vectorT_pj__SslCertName_std__allocatorT_pj__SslCertName_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "SslCertNameVector_pop" "', argument " "1"" of type '" "std::vector< pj::SslCertName > *""'"); 
  }
  arg1 = reinterpret_cast< std::vector< pj::SslCertName > * >(argp1);
  try {
    result = std_vector_Sl_pj_SslCertName_Sg__pop(arg1);
  } catch(std::out_of_range &_e) {
    SWIG_exception_fail(SWIG_IndexError, (&_e)->what());
  }
  resultobj = SWIG_NewPointerObj((new std::vector< pj::SslCertName >::value_type(static_cast< const std::vector< pj::SslCertName >::value_type& >(result))), SWIGTYPE_p_pj__SslCertName, SWIG_POINTER_OWN |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_SslCertNameVector_append(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  std::vector< pj::SslCertName > *arg1 = (std::vector< pj::SslCertName > *) 0 ;
  std::vector< pj::SslCertName >::value_type *arg2 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  void *argp2 = 0 ;
  int res2 = 0 ;
  PyObject *swig_obj[2] ;
  
  if (!SWIG_Python_UnpackTuple(args, "SslCertNameVector_append", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__vectorT_pj__SslCertName_std__allocatorT_pj__SslCertName_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "SslCertNameVector_append" "', argument " "1"" of type '" "std::vector< pj::SslCertName > *""'"); 
  }
  arg1 = reinterpret_cast< std::vector< pj::SslCertName > * >(argp1);
  res2 = SWIG_ConvertPtr(swig_obj[1], &argp2, SWIGTYPE_p_pj__SslCertName,  0  | 0);
  if (!SWIG_IsOK(res2)) {
    SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "SslCertNameVector_append" "', argument " "2"" of type '" "std::vector< pj::SslCertName >::value_type const &""'"); 
  }
  if (!argp2) {
    SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "SslCertNameVector_append" "', argument " "2"" of type '" "std::vector< pj::SslCertName >::value_type const &""'"); 
  }
  arg2 = reinterpret_cast< std::vector< pj::SslCertName >::value_type * >(argp2);
  std_vector_Sl_pj_SslCertName_Sg__append(arg1,(pj::SslCertName const &)*arg2);
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_new_SslCertNameVector__SWIG_0(PyObject *SWIGUNUSEDPARM(self), Py_ssize_t nobjs, PyObject **SWIGUNUSEDPARM(swig_obj)) {
  PyObject *resultobj = 0;
  std::vector< pj::SslCertName > *result = 0 ;
  
  if ((nobjs < 0) || (nobjs > 0)) SWIG_fail;
  result = (std::vector< pj::SslCertName > *)new std::vector< pj::SslCertName >();
  resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(result), SWIGTYPE_p_std__vectorT_pj__SslCertName_std__allocatorT_pj__SslCertName_t_t, SWIG_POINTER_NEW |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_new_SslCertNameVector__SWIG_1(PyObject *SWIGUNUSEDPARM(self), Py_ssize_t nobjs, PyObject **swig_obj) {
  PyObject *resultobj = 0;
  std::vector< pj::SslCertName > *arg1 = 0 ;
  int res1 = SWIG_OLDOBJ ;
  std::vector< pj::SslCertName > *result = 0 ;
  
  if ((nobjs < 1) || (nobjs > 1)) SWIG_fail;
  {
    std::vector< pj::SslCertName,std::allocator< pj::SslCertName > > *ptr = (std::vector< pj::SslCertName,std::allocator< pj::SslCertName > > *)0;
    res1 = swig::asptr(swig_obj[0], &ptr);
    if (!SWIG_IsOK(res1)) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "new_SslCertNameVector" "', argument " "1"" of type '" "std::vector< pj::SslCertName > const &""'"); 
    }
    if (!ptr) {
      SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "new_SslCertNameVector" "', argument " "1"" of type '" "std::vector< pj::SslCertName > const &""'"); 
    }
    arg1 = ptr;
  }
  result = (std::vector< pj::SslCertName > *)new std::vector< pj::SslCertName >((std::vector< pj::SslCertName > const &)*arg1);
  resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(result), SWIGTYPE_p_std__vectorT_pj__SslCertName_std__allocatorT_pj__SslCertName_t_t, SWIG_POINTER_NEW |  0 );
  if (SWIG_IsNewObj(res1)) delete arg1;
  return resultobj;
fail:
  if (SWIG_IsNewObj(res1)) delete arg1;
  return NULL;
}


SWIGINTERN PyObject *_wrap_SslCertNameVector_empty(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  std::vector< pj::SslCertName > *arg1 = (std::vector< pj::SslCertName > *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  bool result;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__vectorT_pj__SslCertName_std__allocatorT_pj__SslCertName_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "SslCertNameVector_empty" "', argument " "1"" of type '" "std::vector< pj::SslCertName > const *""'"); 
  }
  arg1 = reinterpret_cast< std::vector< pj::SslCertName > * >(argp1);
  result = (bool)((std::vector< pj::SslCertName > const *)arg1)->empty();
  resultobj = SWIG_From_bool(static_cast< bool >(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_SslCertNameVector_size(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  std::vector< pj::SslCertName > *arg1 = (std::vector< pj::SslCertName > *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  std::vector< pj::SslCertName >::size_type result;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__vectorT_pj__SslCertName_std__allocatorT_pj__SslCertName_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "SslCertNameVector_size" "', argument " "1"" of type '" "std::vector< pj::SslCertName > const *""'"); 
  }
  arg1 = reinterpret_cast< std::vector< pj::SslCertName > * >(argp1);
  result = ((std::vector< pj::SslCertName > const *)arg1)->size();
  resultobj = SWIG_From_size_t(static_cast< size_t >(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_SslCertNameVector_swap(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  std::vector< pj::SslCertName > *arg1 = (std::vector< pj::SslCertName > *) 0 ;
  std::vector< pj::SslCertName > *arg2 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  void *argp2 = 0 ;
  int res2 = 0 ;
  PyObject *swig_obj[2] ;
  
  if (!SWIG_Python_UnpackTuple(args, "SslCertNameVector_swap", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__vectorT_pj__SslCertName_std__allocatorT_pj__SslCertName_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "SslCertNameVector_swap" "', argument " "1"" of type '" "std::vector< pj::SslCertName > *""'"); 
  }
  arg1 = reinterpret_cast< std::vector< pj::SslCertName > * >(argp1);
  res2 = SWIG_ConvertPtr(swig_obj[1], &argp2, SWIGTYPE_p_std__vectorT_pj__SslCertName_std__allocatorT_pj__SslCertName_t_t,  0 );
  if (!SWIG_IsOK(res2)) {
    SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "SslCertNameVector_swap" "', argument " "2"" of type '" "std::vector< pj::SslCertName > &""'"); 
  }
  if (!argp2) {
    SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "SslCertNameVector_swap" "', argument " "2"" of type '" "std::vector< pj::SslCertName > &""'"); 
  }
  arg2 = reinterpret_cast< std::vector< pj::SslCertName > * >(argp2);
  (arg1)->swap(*arg2);
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_SslCertNameVector_begin(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  std::vector< pj::SslCertName > *arg1 = (std::vector< pj::SslCertName > *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  std::vector< pj::SslCertName >::iterator result;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__vectorT_pj__SslCertName_std__allocatorT_pj__SslCertName_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "SslCertNameVector_begin" "', argument " "1"" of type '" "std::vector< pj::SslCertName > *""'"); 
  }
  arg1 = reinterpret_cast< std::vector< pj::SslCertName > * >(argp1);
  result = (arg1)->begin();
  resultobj = SWIG_NewPointerObj(swig::make_output_iterator(static_cast< const std::vector< pj::SslCertName >::iterator & >(result)),
    swig::SwigPyIterator::descriptor(),SWIG_POINTER_OWN);
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_SslCertNameVector_end(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  std::vector< pj::SslCertName > *arg1 = (std::vector< pj::SslCertName > *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  std::vector< pj::SslCertName >::iterator result;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__vectorT_pj__SslCertName_std__allocatorT_pj__SslCertName_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "SslCertNameVector_end" "', argument " "1"" of type '" "std::vector< pj::SslCertName > *""'"); 
  }
  arg1 = reinterpret_cast< std::vector< pj::SslCertName > * >(argp1);
  result = (arg1)->end();
  resultobj = SWIG_NewPointerObj(swig::make_output_iterator(static_cast< const std::vector< pj::SslCertName >::iterator & >(result)),
    swig::SwigPyIterator::descriptor(),SWIG_POINTER_OWN);
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_SslCertNameVector_rbegin(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  std::vector< pj::SslCertName > *arg1 = (std::vector< pj::SslCertName > *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  std::vector< pj::SslCertName >::reverse_iterator result;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__vectorT_pj__SslCertName_std__allocatorT_pj__SslCertName_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "SslCertNameVector_rbegin" "', argument " "1"" of type '" "std::vector< pj::SslCertName > *""'"); 
  }
  arg1 = reinterpret_cast< std::vector< pj::SslCertName > * >(argp1);
  result = (arg1)->rbegin();
  resultobj = SWIG_NewPointerObj(swig::make_output_iterator(static_cast< const std::vector< pj::SslCertName >::reverse_iterator & >(result)),
    swig::SwigPyIterator::descriptor(),SWIG_POINTER_OWN);
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_SslCertNameVector_rend(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  std::vector< pj::SslCertName > *arg1 = (std::vector< pj::SslCertName > *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  std::vector< pj::SslCertName >::reverse_iterator result;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__vectorT_pj__SslCertName_std__allocatorT_pj__SslCertName_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "SslCertNameVector_rend" "', argument " "1"" of type '" "std::vector< pj::SslCertName > *""'"); 
  }
  arg1 = reinterpret_cast< std::vector< pj::SslCertName > * >(argp1);
  result = (arg1)->rend();
  resultobj = SWIG_NewPointerObj(swig::make_output_iterator(static_cast< const std::vector< pj::SslCertName >::reverse_iterator & >(result)),
    swig::SwigPyIterator::descriptor(),SWIG_POINTER_OWN);
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_SslCertNameVector_clear(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  std::vector< pj::SslCertName > *arg1 = (std::vector< pj::SslCertName > *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__vectorT_pj__SslCertName_std__allocatorT_pj__SslCertName_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "SslCertNameVector_clear" "', argument " "1"" of type '" "std::vector< pj::SslCertName > *""'"); 
  }
  arg1 = reinterpret_cast< std::vector< pj::SslCertName > * >(argp1);
  (arg1)->clear();
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_SslCertNameVector_get_allocator(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  std::vector< pj::SslCertName > *arg1 = (std::vector< pj::SslCertName > *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  SwigValueWrapper< std::allocator< pj::SslCertName > > result;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__vectorT_pj__SslCertName_std__allocatorT_pj__SslCertName_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "SslCertNameVector_get_allocator" "', argument " "1"" of type '" "std::vector< pj::SslCertName > const *""'"); 
  }
  arg1 = reinterpret_cast< std::vector< pj::SslCertName > * >(argp1);
  result = ((std::vector< pj::SslCertName > const *)arg1)->get_allocator();
  resultobj = SWIG_NewPointerObj((new std::vector< pj::SslCertName >::allocator_type(static_cast< const std::vector< pj::SslCertName >::allocator_type& >(result))), SWIGTYPE_p_std__allocatorT_pj__SslCertName_t, SWIG_POINTER_OWN |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_new_SslCertNameVector__SWIG_2(PyObject *SWIGUNUSEDPARM(self), Py_ssize_t nobjs, PyObject **swig_obj) {
  PyObject *resultobj = 0;
  std::vector< pj::SslCertName >::size_type arg1 ;
  size_t val1 ;
  int ecode1 = 0 ;
  std::vector< pj::SslCertName > *result = 0 ;
  
  if ((nobjs < 1) || (nobjs > 1)) SWIG_fail;
  ecode1 = SWIG_AsVal_size_t(swig_obj[0], &val1);
  if (!SWIG_IsOK(ecode1)) {
    SWIG_exception_fail(SWIG_ArgError(ecode1), "in method '" "new_SslCertNameVector" "', argument " "1"" of type '" "std::vector< pj::SslCertName >::size_type""'");
  } 
  arg1 = static_cast< std::vector< pj::SslCertName >::size_type >(val1);
  result = (std::vector< pj::SslCertName > *)new std::vector< pj::SslCertName >(arg1);
  resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(result), SWIGTYPE_p_std__vectorT_pj__SslCertName_std__allocatorT_pj__SslCertName_t_t, SWIG_POINTER_NEW |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_SslCertNameVector_pop_back(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  std::vector< pj::SslCertName > *arg1 = (std::vector< pj::SslCertName > *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__vectorT_pj__SslCertName_std__allocatorT_pj__SslCertName_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "SslCertNameVector_pop_back" "', argument " "1"" of type '" "std::vector< pj::SslCertName > *""'"); 
  }
  arg1 = reinterpret_cast< std::vector< pj::SslCertName > * >(argp1);
  (arg1)->pop_back();
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_SslCertNameVector_resize__SWIG_0(PyObject *SWIGUNUSEDPARM(self), Py_ssize_t nobjs, PyObject **swig_obj) {
  PyObject *resultobj = 0;
  std::vector< pj::SslCertName > *arg1 = (std::vector< pj::SslCertName > *) 0 ;
  std::vector< pj::SslCertName >::size_type arg2 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  size_t val2 ;
  int ecode2 = 0 ;
  
  if ((nobjs < 2) || (nobjs > 2)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__vectorT_pj__SslCertName_std__allocatorT_pj__SslCertName_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "SslCertNameVector_resize" "', argument " "1"" of type '" "std::vector< pj::SslCertName > *""'"); 
  }
  arg1 = reinterpret_cast< std::vector< pj::SslCertName > * >(argp1);
  ecode2 = SWIG_AsVal_size_t(swig_obj[1], &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "SslCertNameVector_resize" "', argument " "2"" of type '" "std::vector< pj::SslCertName >::size_type""'");
  } 
  arg2 = static_cast< std::vector< pj::SslCertName >::size_type >(val2);
  (arg1)->resize(arg2);
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_SslCertNameVector_erase__SWIG_0(PyObject *SWIGUNUSEDPARM(self), Py_ssize_t nobjs, PyObject **swig_obj) {
  PyObject *resultobj = 0;
  std::vector< pj::SslCertName > *arg1 = (std::vector< pj::SslCertName > *) 0 ;
  std::vector< pj::SslCertName >::iterator arg2 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  swig::SwigPyIterator *iter2 = 0 ;
  int res2 ;
  std::vector< pj::SslCertName >::iterator result;
  
  if ((nobjs < 2) || (nobjs > 2)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__vectorT_pj__SslCertName_std__allocatorT_pj__SslCertName_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "SslCertNameVector_erase" "', argument " "1"" of type '" "std::vector< pj::SslCertName > *""'"); 
  }
  arg1 = reinterpret_cast< std::vector< pj::SslCertName > * >(argp1);
  res2 = SWIG_ConvertPtr(swig_obj[1], SWIG_as_voidptrptr(&iter2), swig::SwigPyIterator::descriptor(), 0);
  if (!SWIG_IsOK(res2) || !iter2) {
    SWIG_exception_fail(SWIG_ArgError(SWIG_TypeError), "in method '" "SslCertNameVector_erase" "', argument " "2"" of type '" "std::vector< pj::SslCertName >::iterator""'");
  } else {
    swig::SwigPyIterator_T<std::vector< pj::SslCertName >::iterator > *iter_t = dynamic_cast<swig::SwigPyIterator_T<std::vector< pj::SslCertName >::iterator > *>(iter2);
    if (iter_t) {
      arg2 = iter_t->get_current();
    } else {
      SWIG_exception_fail(SWIG_ArgError(SWIG_TypeError), "in method '" "SslCertNameVector_erase" "', argument " "2"" of type '" "std::vector< pj::SslCertName >::iterator""'");
    }
  }
  result = std_vector_Sl_pj_SslCertName_Sg__erase__SWIG_0(arg1,arg2);
  resultobj = SWIG_NewPointerObj(swig::make_output_iterator(static_cast< const std::vector< pj::SslCertName >::iterator & >(result)),
    swig::SwigPyIterator::descriptor(),SWIG_POINTER_OWN);
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_SslCertNameVector_erase__SWIG_1(PyObject *SWIGUNUSEDPARM(self), Py_ssize_t nobjs, PyObject **swig_obj) {
  PyObject *resultobj = 0;
  std::vector< pj::SslCertName > *arg1 = (std::vector< pj::SslCertName > *) 0 ;
  std::vector< pj::SslCertName >::iterator arg2 ;
  std::vector< pj::SslCertName >::iterator arg3 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  swig::SwigPyIterator *iter2 = 0 ;
  int res2 ;
  swig::SwigPyIterator *iter3 = 0 ;
  int res3 ;
  std::vector< pj::SslCertName >::iterator result;
  
  if ((nobjs < 3) || (nobjs > 3)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__vectorT_pj__SslCertName_std__allocatorT_pj__SslCertName_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "SslCertNameVector_erase" "', argument " "1"" of type '" "std::vector< pj::SslCertName > *""'"); 
  }
  arg1 = reinterpret_cast< std::vector< pj::SslCertName > * >(argp1);
  res2 = SWIG_ConvertPtr(swig_obj[1], SWIG_as_voidptrptr(&iter2), swig::SwigPyIterator::descriptor(), 0);
  if (!SWIG_IsOK(res2) || !iter2) {
    SWIG_exception_fail(SWIG_ArgError(SWIG_TypeError), "in method '" "SslCertNameVector_erase" "', argument " "2"" of type '" "std::vector< pj::SslCertName >::iterator""'");
  } else {
    swig::SwigPyIterator_T<std::vector< pj::SslCertName >::iterator > *iter_t = dynamic_cast<swig::SwigPyIterator_T<std::vector< pj::SslCertName >::iterator > *>(iter2);
    if (iter_t) {
      arg2 = iter_t->get_current();
    } else {
      SWIG_exception_fail(SWIG_ArgError(SWIG_TypeError), "in method '" "SslCertNameVector_erase" "', argument " "2"" of type '" "std::vector< pj::SslCertName >::iterator""'");
    }
  }
  res3 = SWIG_ConvertPtr(swig_obj[2], SWIG_as_voidptrptr(&iter3), swig::SwigPyIterator::descriptor(), 0);
  if (!SWIG_IsOK(res3) || !iter3) {
    SWIG_exception_fail(SWIG_ArgError(SWIG_TypeError), "in method '" "SslCertNameVector_erase" "', argument " "3"" of type '" "std::vector< pj::SslCertName >::iterator""'");
  } else {
    swig::SwigPyIterator_T<std::vector< pj::SslCertName >::iterator > *iter_t = dynamic_cast<swig::SwigPyIterator_T<std::vector< pj::SslCertName >::iterator > *>(iter3);
    if (iter_t) {
      arg3 = iter_t->get_current();
    } else {
      SWIG_exception_fail(SWIG_ArgError(SWIG_TypeError), "in method '" "SslCertNameVector_erase" "', argument " "3"" of type '" "std::vector< pj::SslCertName >::iterator""'");
    }
  }
  result = std_vector_Sl_pj_SslCertName_Sg__erase__SWIG_1(arg1,arg2,arg3);
  resultobj = SWIG_NewPointerObj(swig::make_output_iterator(static_cast< const std::vector< pj::SslCertName >::iterator & >(result)),
    swig::SwigPyIterator::descriptor(),SWIG_POINTER_OWN);
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_SslCertNameVector_erase(PyObject *self, PyObject *args) {
  Py_ssize_t argc;
  PyObject *argv[4] = {
    0
  };
  
  if (!(argc = SWIG_Python_UnpackTuple(args, "SslCertNameVector_erase", 0, 3, argv))) SWIG_fail;
  --argc;
  if (argc == 2) {
    int _v;
    int res = swig::asptr(argv[0], (std::vector< pj::SslCertName,std::allocator< pj::SslCertName > >**)(0));
    _v = SWIG_CheckState(res);
    if (_v) {
      swig::SwigPyIterator *iter = 0;
      int res = SWIG_ConvertPtr(argv[1], SWIG_as_voidptrptr(&iter), swig::SwigPyIterator::descriptor(), 0);
      _v = (SWIG_IsOK(res) && iter && (dynamic_cast<swig::SwigPyIterator_T<std::vector< pj::SslCertName >::iterator > *>(iter) != 0));
      if (_v) {
        return _wrap_SslCertNameVector_erase__SWIG_0(self, argc, argv);
      }
    }
  }
  if (argc == 3) {
    int _v;
    int res = swig::asptr(argv[0], (std::vector< pj::SslCertName,std::allocator< pj::SslCertName > >**)(0));
    _v = SWIG_CheckState(res);
    if (_v) {
      swig::SwigPyIterator *iter = 0;
      int res = SWIG_ConvertPtr(argv[1], SWIG_as_voidptrptr(&iter), swig::SwigPyIterator::descriptor(), 0);
      _v = (SWIG_IsOK(res) && iter && (dynamic_cast<swig::SwigPyIterator_T<std::vector< pj::SslCertName >::iterator > *>(iter) != 0));
      if (_v) {
        swig::SwigPyIterator *iter = 0;
        int res = SWIG_ConvertPtr(argv[2], SWIG_as_voidptrptr(&iter), swig::SwigPyIterator::descriptor(), 0);
        _v = (SWIG_IsOK(res) && iter && (dynamic_cast<swig::SwigPyIterator_T<std::vector< pj::SslCertName >::iterator > *>(iter) != 0));
        if (_v) {
          return _wrap_SslCertNameVector_erase__SWIG_1(self, argc, argv);
        }
      }
    }
  }
  
fail:
  SWIG_Python_RaiseOrModifyTypeError("Wrong number or type of arguments for overloaded function 'SslCertNameVector_erase'.\n"
    "  Possible C/C++ prototypes are:\n"
    "    std::vector< pj::SslCertName >::erase(std::vector< pj::SslCertName >::iterator)\n"
    "    std::vector< pj::SslCertName >::erase(std::vector< pj::SslCertName >::iterator,std::vector< pj::SslCertName >::iterator)\n");
  return 0;
}


SWIGINTERN PyObject *_wrap_new_SslCertNameVector__SWIG_3(PyObject *SWIGUNUSEDPARM(self), Py_ssize_t nobjs, PyObject **swig_obj) {
  PyObject *resultobj = 0;
  std::vector< pj::SslCertName >::size_type arg1 ;
  std::vector< pj::SslCertName >::value_type *arg2 = 0 ;
  size_t val1 ;
  int ecode1 = 0 ;
  void *argp2 = 0 ;
  int res2 = 0 ;
  std::vector< pj::SslCertName > *result = 0 ;
  
  if ((nobjs < 2) || (nobjs > 2)) SWIG_fail;
  ecode1 = SWIG_AsVal_size_t(swig_obj[0], &val1);
  if (!SWIG_IsOK(ecode1)) {
    SWIG_exception_fail(SWIG_ArgError(ecode1), "in method '" "new_SslCertNameVector" "', argument " "1"" of type '" "std::vector< pj::SslCertName >::size_type""'");
  } 
  arg1 = static_cast< std::vector< pj::SslCertName >::size_type >(val1);
  res2 = SWIG_ConvertPtr(swig_obj[1], &argp2, SWIGTYPE_p_pj__SslCertName,  0  | 0);
  if (!SWIG_IsOK(res2)) {
    SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "new_SslCertNameVector" "', argument " "2"" of type '" "std::vector< pj::SslCertName >::value_type const &""'"); 
  }
  if (!argp2) {
    SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "new_SslCertNameVector" "', argument " "2"" of type '" "std::vector< pj::SslCertName >::value_type const &""'"); 
  }
  arg2 = reinterpret_cast< std::vector< pj::SslCertName >::value_type * >(argp2);
  result = (std::vector< pj::SslCertName > *)new std::vector< pj::SslCertName >(arg1,(std::vector< pj::SslCertName >::value_type const &)*arg2);
  resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(result), SWIGTYPE_p_std__vectorT_pj__SslCertName_std__allocatorT_pj__SslCertName_t_t, SWIG_POINTER_NEW |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_new_SslCertNameVector(PyObject *self, PyObject *args) {
  Py_ssize_t argc;
  PyObject *argv[3] = {
    0
  };
  
  if (!(argc = SWIG_Python_UnpackTuple(args, "new_SslCertNameVector", 0, 2, argv))) SWIG_fail;
  --argc;
  if (argc == 0) {
    return _wrap_new_SslCertNameVector__SWIG_0(self, argc, argv);
  }
  if (argc == 1) {
    int _v;
    {
      int res = SWIG_AsVal_size_t(argv[0], NULL);
      _v = SWIG_CheckState(res);
    }
    if (_v) {
      return _wrap_new_SslCertNameVector__SWIG_2(self, argc, argv);
    }
  }
  if (argc == 1) {
    int _v;
    int res = swig::asptr(argv[0], (std::vector< pj::SslCertName,std::allocator< pj::SslCertName > >**)(0));
    _v = SWIG_CheckState(res);
    if (_v) {
      return _wrap_new_SslCertNameVector__SWIG_1(self, argc, argv);
    }
  }
  if (argc == 2) {
    int _v;
    {
      int res = SWIG_AsVal_size_t(argv[0], NULL);
      _v = SWIG_CheckState(res);
    }
    if (_v) {
      int res = SWIG_ConvertPtr(argv[1], 0, SWIGTYPE_p_pj__SslCertName, SWIG_POINTER_NO_NULL | 0);
      _v = SWIG_CheckState(res);
      if (_v) {
        return _wrap_new_SslCertNameVector__SWIG_3(self, argc, argv);
      }
    }
  }
  
fail:
  SWIG_Python_RaiseOrModifyTypeError("Wrong number or type of arguments for overloaded function 'new_SslCertNameVector'.\n"
    "  Possible C/C++ prototypes are:\n"
    "    std::vector< pj::SslCertName >::vector()\n"
    "    std::vector< pj::SslCertName >::vector(std::vector< pj::SslCertName > const &)\n"
    "    std::vector< pj::SslCertName >::vector(std::vector< pj::SslCertName >::size_type)\n"
    "    std::vector< pj::SslCertName >::vector(std::vector< pj::SslCertName >::size_type,std::vector< pj::SslCertName >::value_type const &)\n");
  return 0;
}


SWIGINTERN PyObject *_wrap_SslCertNameVector_push_back(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  std::vector< pj::SslCertName > *arg1 = (std::vector< pj::SslCertName > *) 0 ;
  std::vector< pj::SslCertName >::value_type *arg2 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  void *argp2 = 0 ;
  int res2 = 0 ;
  PyObject *swig_obj[2] ;
  
  if (!SWIG_Python_UnpackTuple(args, "SslCertNameVector_push_back", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__vectorT_pj__SslCertName_std__allocatorT_pj__SslCertName_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "SslCertNameVector_push_back" "', argument " "1"" of type '" "std::vector< pj::SslCertName > *""'"); 
  }
  arg1 = reinterpret_cast< std::vector< pj::SslCertName > * >(argp1);
  res2 = SWIG_ConvertPtr(swig_obj[1], &argp2, SWIGTYPE_p_pj__SslCertName,  0  | 0);
  if (!SWIG_IsOK(res2)) {
    SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "SslCertNameVector_push_back" "', argument " "2"" of type '" "std::vector< pj::SslCertName >::value_type const &""'"); 
  }
  if (!argp2) {
    SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "SslCertNameVector_push_back" "', argument " "2"" of type '" "std::vector< pj::SslCertName >::value_type const &""'"); 
  }
  arg2 = reinterpret_cast< std::vector< pj::SslCertName >::value_type * >(argp2);
  (arg1)->push_back((std::vector< pj::SslCertName >::value_type const &)*arg2);
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_SslCertNameVector_front(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  std::vector< pj::SslCertName > *arg1 = (std::vector< pj::SslCertName > *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  std::vector< pj::SslCertName >::value_type *result = 0 ;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__vectorT_pj__SslCertName_std__allocatorT_pj__SslCertName_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "SslCertNameVector_front" "', argument " "1"" of type '" "std::vector< pj::SslCertName > const *""'"); 
  }
  arg1 = reinterpret_cast< std::vector< pj::SslCertName > * >(argp1);
  result = (std::vector< pj::SslCertName >::value_type *) &((std::vector< pj::SslCertName > const *)arg1)->front();
  resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(result), SWIGTYPE_p_pj__SslCertName, 0 |  0 );
  (void)swig::container_owner<swig::traits<std::vector< pj::SslCertName >::value_type>::category>::back_reference(resultobj, swig_obj[0]);
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_SslCertNameVector_back(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  std::vector< pj::SslCertName > *arg1 = (std::vector< pj::SslCertName > *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  std::vector< pj::SslCertName >::value_type *result = 0 ;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__vectorT_pj__SslCertName_std__allocatorT_pj__SslCertName_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "SslCertNameVector_back" "', argument " "1"" of type '" "std::vector< pj::SslCertName > const *""'"); 
  }
  arg1 = reinterpret_cast< std::vector< pj::SslCertName > * >(argp1);
  result = (std::vector< pj::SslCertName >::value_type *) &((std::vector< pj::SslCertName > const *)arg1)->back();
  resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(result), SWIGTYPE_p_pj__SslCertName, 0 |  0 );
  (void)swig::container_owner<swig::traits<std::vector< pj::SslCertName >::value_type>::category>::back_reference(resultobj, swig_obj[0]);
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_SslCertNameVector_assign(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  std::vector< pj::SslCertName > *arg1 = (std::vector< pj::SslCertName > *) 0 ;
  std::vector< pj::SslCertName >::size_type arg2 ;
  std::vector< pj::SslCertName >::value_type *arg3 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  size_t val2 ;
  int ecode2 = 0 ;
  void *argp3 = 0 ;
  int res3 = 0 ;
  PyObject *swig_obj[3] ;
  
  if (!SWIG_Python_UnpackTuple(args, "SslCertNameVector_assign", 3, 3, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__vectorT_pj__SslCertName_std__allocatorT_pj__SslCertName_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "SslCertNameVector_assign" "', argument " "1"" of type '" "std::vector< pj::SslCertName > *""'"); 
  }
  arg1 = reinterpret_cast< std::vector< pj::SslCertName > * >(argp1);
  ecode2 = SWIG_AsVal_size_t(swig_obj[1], &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "SslCertNameVector_assign" "', argument " "2"" of type '" "std::vector< pj::SslCertName >::size_type""'");
  } 
  arg2 = static_cast< std::vector< pj::SslCertName >::size_type >(val2);
  res3 = SWIG_ConvertPtr(swig_obj[2], &argp3, SWIGTYPE_p_pj__SslCertName,  0  | 0);
  if (!SWIG_IsOK(res3)) {
    SWIG_exception_fail(SWIG_ArgError(res3), "in method '" "SslCertNameVector_assign" "', argument " "3"" of type '" "std::vector< pj::SslCertName >::value_type const &""'"); 
  }
  if (!argp3) {
    SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "SslCertNameVector_assign" "', argument " "3"" of type '" "std::vector< pj::SslCertName >::value_type const &""'"); 
  }
  arg3 = reinterpret_cast< std::vector< pj::SslCertName >::value_type * >(argp3);
  (arg1)->assign(arg2,(std::vector< pj::SslCertName >::value_type const &)*arg3);
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_SslCertNameVector_resize__SWIG_1(PyObject *SWIGUNUSEDPARM(self), Py_ssize_t nobjs, PyObject **swig_obj) {
  PyObject *resultobj = 0;
  std::vector< pj::SslCertName > *arg1 = (std::vector< pj::SslCertName > *) 0 ;
  std::vector< pj::SslCertName >::size_type arg2 ;
  std::vector< pj::SslCertName >::value_type *arg3 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  size_t val2 ;
  int ecode2 = 0 ;
  void *argp3 = 0 ;
  int res3 = 0 ;
  
  if ((nobjs < 3) || (nobjs > 3)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__vectorT_pj__SslCertName_std__allocatorT_pj__SslCertName_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "SslCertNameVector_resize" "', argument " "1"" of type '" "std::vector< pj::SslCertName > *""'"); 
  }
  arg1 = reinterpret_cast< std::vector< pj::SslCertName > * >(argp1);
  ecode2 = SWIG_AsVal_size_t(swig_obj[1], &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "SslCertNameVector_resize" "', argument " "2"" of type '" "std::vector< pj::SslCertName >::size_type""'");
  } 
  arg2 = static_cast< std::vector< pj::SslCertName >::size_type >(val2);
  res3 = SWIG_ConvertPtr(swig_obj[2], &argp3, SWIGTYPE_p_pj__SslCertName,  0  | 0);
  if (!SWIG_IsOK(res3)) {
    SWIG_exception_fail(SWIG_ArgError(res3), "in method '" "SslCertNameVector_resize" "', argument " "3"" of type '" "std::vector< pj::SslCertName >::value_type const &""'"); 
  }
  if (!argp3) {
    SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "SslCertNameVector_resize" "', argument " "3"" of type '" "std::vector< pj::SslCertName >::value_type const &""'"); 
  }
  arg3 = reinterpret_cast< std::vector< pj::SslCertName >::value_type * >(argp3);
  (arg1)->resize(arg2,(std::vector< pj::SslCertName >::value_type const &)*arg3);
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_SslCertNameVector_resize(PyObject *self, PyObject *args) {
  Py_ssize_t argc;
  PyObject *argv[4] = {
    0
  };
  
  if (!(argc = SWIG_Python_UnpackTuple(args, "SslCertNameVector_resize", 0, 3, argv))) SWIG_fail;
  --argc;
  if (argc == 2) {
    int _v;
    int res = swig::asptr(argv[0], (std::vector< pj::SslCertName,std::allocator< pj::SslCertName > >**)(0));
    _v = SWIG_CheckState(res);
    if (_v) {
      {
        int res = SWIG_AsVal_size_t(argv[1], NULL);
        _v = SWIG_CheckState(res);
      }
      if (_v) {
        return _wrap_SslCertNameVector_resize__SWIG_0(self, argc, argv);
      }
    }
  }
  if (argc == 3) {
    int _v;
    int res = swig::asptr(argv[0], (std::vector< pj::SslCertName,std::allocator< pj::SslCertName > >**)(0));
    _v = SWIG_CheckState(res);
    if (_v) {
      {
        int res = SWIG_AsVal_size_t(argv[1], NULL);
        _v = SWIG_CheckState(res);
      }
      if (_v) {
        int res = SWIG_ConvertPtr(argv[2], 0, SWIGTYPE_p_pj__SslCertName, SWIG_POINTER_NO_NULL | 0);
        _v = SWIG_CheckState(res);
        if (_v) {
          return _wrap_SslCertNameVector_resize__SWIG_1(self, argc, argv);
        }
      }
    }
  }
  
fail:
  SWIG_Python_RaiseOrModifyTypeError("Wrong number or type of arguments for overloaded function 'SslCertNameVector_resize'.\n"
    "  Possible C/C++ prototypes are:\n"
    "    std::vector< pj::SslCertName >::resize(std::vector< pj::SslCertName >::size_type)\n"
    "    std::vector< pj::SslCertName >::resize(std::vector< pj::SslCertName >::size_type,std::vector< pj::SslCertName >::value_type const &)\n");
  return 0;
}


SWIGINTERN PyObject *_wrap_SslCertNameVector_insert__SWIG_0(PyObject *SWIGUNUSEDPARM(self), Py_ssize_t nobjs, PyObject **swig_obj) {
  PyObject *resultobj = 0;
  std::vector< pj::SslCertName > *arg1 = (std::vector< pj::SslCertName > *) 0 ;
  std::vector< pj::SslCertName >::iterator arg2 ;
  std::vector< pj::SslCertName >::value_type *arg3 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  swig::SwigPyIterator *iter2 = 0 ;
  int res2 ;
  void *argp3 = 0 ;
  int res3 = 0 ;
  std::vector< pj::SslCertName >::iterator result;
  
  if ((nobjs < 3) || (nobjs > 3)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__vectorT_pj__SslCertName_std__allocatorT_pj__SslCertName_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "SslCertNameVector_insert" "', argument " "1"" of type '" "std::vector< pj::SslCertName > *""'"); 
  }
  arg1 = reinterpret_cast< std::vector< pj::SslCertName > * >(argp1);
  res2 = SWIG_ConvertPtr(swig_obj[1], SWIG_as_voidptrptr(&iter2), swig::SwigPyIterator::descriptor(), 0);
  if (!SWIG_IsOK(res2) || !iter2) {
    SWIG_exception_fail(SWIG_ArgError(SWIG_TypeError), "in method '" "SslCertNameVector_insert" "', argument " "2"" of type '" "std::vector< pj::SslCertName >::iterator""'");
  } else {
    swig::SwigPyIterator_T<std::vector< pj::SslCertName >::iterator > *iter_t = dynamic_cast<swig::SwigPyIterator_T<std::vector< pj::SslCertName >::iterator > *>(iter2);
    if (iter_t) {
      arg2 = iter_t->get_current();
    } else {
      SWIG_exception_fail(SWIG_ArgError(SWIG_TypeError), "in method '" "SslCertNameVector_insert" "', argument " "2"" of type '" "std::vector< pj::SslCertName >::iterator""'");
    }
  }
  res3 = SWIG_ConvertPtr(swig_obj[2], &argp3, SWIGTYPE_p_pj__SslCertName,  0  | 0);
  if (!SWIG_IsOK(res3)) {
    SWIG_exception_fail(SWIG_ArgError(res3), "in method '" "SslCertNameVector_insert" "', argument " "3"" of type '" "std::vector< pj::SslCertName >::value_type const &""'"); 
  }
  if (!argp3) {
    SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "SslCertNameVector_insert" "', argument " "3"" of type '" "std::vector< pj::SslCertName >::value_type const &""'"); 
  }
  arg3 = reinterpret_cast< std::vector< pj::SslCertName >::value_type * >(argp3);
  result = std_vector_Sl_pj_SslCertName_Sg__insert__SWIG_0(arg1,arg2,(pj::SslCertName const &)*arg3);
  resultobj = SWIG_NewPointerObj(swig::make_output_iterator(static_cast< const std::vector< pj::SslCertName >::iterator & >(result)),
    swig::SwigPyIterator::descriptor(),SWIG_POINTER_OWN);
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_SslCertNameVector_insert__SWIG_1(PyObject *SWIGUNUSEDPARM(self), Py_ssize_t nobjs, PyObject **swig_obj) {
  PyObject *resultobj = 0;
  std::vector< pj::SslCertName > *arg1 = (std::vector< pj::SslCertName > *) 0 ;
  std::vector< pj::SslCertName >::iterator arg2 ;
  std::vector< pj::SslCertName >::size_type arg3 ;
  std::vector< pj::SslCertName >::value_type *arg4 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  swig::SwigPyIterator *iter2 = 0 ;
  int res2 ;
  size_t val3 ;
  int ecode3 = 0 ;
  void *argp4 = 0 ;
  int res4 = 0 ;
  
  if ((nobjs < 4) || (nobjs > 4)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__vectorT_pj__SslCertName_std__allocatorT_pj__SslCertName_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "SslCertNameVector_insert" "', argument " "1"" of type '" "std::vector< pj::SslCertName > *""'"); 
  }
  arg1 = reinterpret_cast< std::vector< pj::SslCertName > * >(argp1);
  res2 = SWIG_ConvertPtr(swig_obj[1], SWIG_as_voidptrptr(&iter2), swig::SwigPyIterator::descriptor(), 0);
  if (!SWIG_IsOK(res2) || !iter2) {
    SWIG_exception_fail(SWIG_ArgError(SWIG_TypeError), "in method '" "SslCertNameVector_insert" "', argument " "2"" of type '" "std::vector< pj::SslCertName >::iterator""'");
  } else {
    swig::SwigPyIterator_T<std::vector< pj::SslCertName >::iterator > *iter_t = dynamic_cast<swig::SwigPyIterator_T<std::vector< pj::SslCertName >::iterator > *>(iter2);
    if (iter_t) {
      arg2 = iter_t->get_current();
    } else {
      SWIG_exception_fail(SWIG_ArgError(SWIG_TypeError), "in method '" "SslCertNameVector_insert" "', argument " "2"" of type '" "std::vector< pj::SslCertName >::iterator""'");
    }
  }
  ecode3 = SWIG_AsVal_size_t(swig_obj[2], &val3);
  if (!SWIG_IsOK(ecode3)) {
    SWIG_exception_fail(SWIG_ArgError(ecode3), "in method '" "SslCertNameVector_insert" "', argument " "3"" of type '" "std::vector< pj::SslCertName >::size_type""'");
  } 
  arg3 = static_cast< std::vector< pj::SslCertName >::size_type >(val3);
  res4 = SWIG_ConvertPtr(swig_obj[3], &argp4, SWIGTYPE_p_pj__SslCertName,  0  | 0);
  if (!SWIG_IsOK(res4)) {
    SWIG_exception_fail(SWIG_ArgError(res4), "in method '" "SslCertNameVector_insert" "', argument " "4"" of type '" "std::vector< pj::SslCertName >::value_type const &""'"); 
  }
  if (!argp4) {
    SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "SslCertNameVector_insert" "', argument " "4"" of type '" "std::vector< pj::SslCertName >::value_type const &""'"); 
  }
  arg4 = reinterpret_cast< std::vector< pj::SslCertName >::value_type * >(argp4);
  std_vector_Sl_pj_SslCertName_Sg__insert__SWIG_1(arg1,arg2,arg3,(pj::SslCertName const &)*arg4);
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_SslCertNameVector_insert(PyObject *self, PyObject *args) {
  Py_ssize_t argc;
  PyObject *argv[5] = {
    0
  };
  
  if (!(argc = SWIG_Python_UnpackTuple(args, "SslCertNameVector_insert", 0, 4, argv))) SWIG_fail;
  --argc;
  if (argc == 3) {
    int _v;
    int res = swig::asptr(argv[0], (std::vector< pj::SslCertName,std::allocator< pj::SslCertName > >**)(0));
    _v = SWIG_CheckState(res);
    if (_v) {
      swig::SwigPyIterator *iter = 0;
      int res = SWIG_ConvertPtr(argv[1], SWIG_as_voidptrptr(&iter), swig::SwigPyIterator::descriptor(), 0);
      _v = (SWIG_IsOK(res) && iter && (dynamic_cast<swig::SwigPyIterator_T<std::vector< pj::SslCertName >::iterator > *>(iter) != 0));
      if (_v) {
        int res = SWIG_ConvertPtr(argv[2], 0, SWIGTYPE_p_pj__SslCertName, SWIG_POINTER_NO_NULL | 0);
        _v = SWIG_CheckState(res);
        if (_v) {
          return _wrap_SslCertNameVector_insert__SWIG_0(self, argc, argv);
        }
      }
    }
  }
  if (argc == 4) {
    int _v;
    int res = swig::asptr(argv[0], (std::vector< pj::SslCertName,std::allocator< pj::SslCertName > >**)(0));
    _v = SWIG_CheckState(res);
    if (_v) {
      swig::SwigPyIterator *iter = 0;
      int res = SWIG_ConvertPtr(argv[1], SWIG_as_voidptrptr(&iter), swig::SwigPyIterator::descriptor(), 0);
      _v = (SWIG_IsOK(res) && iter && (dynamic_cast<swig::SwigPyIterator_T<std::vector< pj::SslCertName >::iterator > *>(iter) != 0));
      if (_v) {
        {
          int res = SWIG_AsVal_size_t(argv[2], NULL);
          _v = SWIG_CheckState(res);
        }
        if (_v) {
          int res = SWIG_ConvertPtr(argv[3], 0, SWIGTYPE_p_pj__SslCertName, SWIG_POINTER_NO_NULL | 0);
          _v = SWIG_CheckState(res);
          if (_v) {
            return _wrap_SslCertNameVector_insert__SWIG_1(self, argc, argv);
          }
        }
      }
    }
  }
  
fail:
  SWIG_Python_RaiseOrModifyTypeError("Wrong number or type of arguments for overloaded function 'SslCertNameVector_insert'.\n"
    "  Possible C/C++ prototypes are:\n"
    "    std::vector< pj::SslCertName >::insert(std::vector< pj::SslCertName >::iterator,std::vector< pj::SslCertName >::value_type const &)\n"
    "    std::vector< pj::SslCertName >::insert(std::vector< pj::SslCertName >::iterator,std::vector< pj::SslCertName >::size_type,std::vector< pj::SslCertName >::value_type const &)\n");
  return 0;
}


SWIGINTERN PyObject *_wrap_SslCertNameVector_reserve(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  std::vector< pj::SslCertName > *arg1 = (std::vector< pj::SslCertName > *) 0 ;
  std::vector< pj::SslCertName >::size_type arg2 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  size_t val2 ;
  int ecode2 = 0 ;
  PyObject *swig_obj[2] ;
  
  if (!SWIG_Python_UnpackTuple(args, "SslCertNameVector_reserve", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__vectorT_pj__SslCertName_std__allocatorT_pj__SslCertName_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "SslCertNameVector_reserve" "', argument " "1"" of type '" "std::vector< pj::SslCertName > *""'"); 
  }
  arg1 = reinterpret_cast< std::vector< pj::SslCertName > * >(argp1);
  ecode2 = SWIG_AsVal_size_t(swig_obj[1], &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "SslCertNameVector_reserve" "', argument " "2"" of type '" "std::vector< pj::SslCertName >::size_type""'");
  } 
  arg2 = static_cast< std::vector< pj::SslCertName >::size_type >(val2);
  (arg1)->reserve(arg2);
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_SslCertNameVector_capacity(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  std::vector< pj::SslCertName > *arg1 = (std::vector< pj::SslCertName > *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  std::vector< pj::SslCertName >::size_type result;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__vectorT_pj__SslCertName_std__allocatorT_pj__SslCertName_t_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "SslCertNameVector_capacity" "', argument " "1"" of type '" "std::vector< pj::SslCertName > const *""'"); 
  }
  arg1 = reinterpret_cast< std::vector< pj::SslCertName > * >(argp1);
  result = ((std::vector< pj::SslCertName > const *)arg1)->capacity();
  resultobj = SWIG_From_size_t(static_cast< size_t >(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_delete_SslCertNameVector(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  std::vector< pj::SslCertName > *arg1 = (std::vector< pj::SslCertName > *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_std__vectorT_pj__SslCertName_std__allocatorT_pj__SslCertName_t_t, SWIG_POINTER_DISOWN |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "delete_SslCertNameVector" "', argument " "1"" of type '" "std::vector< pj::SslCertName > *""'"); 
  }
  arg1 = reinterpret_cast< std::vector< pj::SslCertName > * >(argp1);
  delete arg1;
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *SslCertNameVector_swigregister(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *obj;
  if (!SWIG_Python_UnpackTuple(args, "swigregister", 1, 1, &obj)) return NULL;
  SWIG_TypeNewClientData(SWIGTYPE_p_std__vectorT_pj__SslCertName_std__allocatorT_pj__SslCertName_t_t, SWIG_NewClientData(obj));
  return SWIG_Py_Void();
}

SWIGINTERN PyObject *SslCertNameVector_swiginit(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  return SWIG_Python_InitShadowInstance(args);
}

SWIGINTERN PyObject *_wrap_MediaFormat_id_set(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::MediaFormat *arg1 = (pj::MediaFormat *) 0 ;
  pj_uint32_t arg2 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  unsigned int val2 ;
  int ecode2 = 0 ;
  PyObject *swig_obj[2] ;
  
  if (!SWIG_Python_UnpackTuple(args, "MediaFormat_id_set", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__MediaFormat, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "MediaFormat_id_set" "', argument " "1"" of type '" "pj::MediaFormat *""'"); 
  }
  arg1 = reinterpret_cast< pj::MediaFormat * >(argp1);
  ecode2 = SWIG_AsVal_unsigned_SS_int(swig_obj[1], &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "MediaFormat_id_set" "', argument " "2"" of type '" "pj_uint32_t""'");
  } 
  arg2 = static_cast< pj_uint32_t >(val2);
  if (arg1) (arg1)->id = arg2;
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_MediaFormat_id_get(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::MediaFormat *arg1 = (pj::MediaFormat *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  pj_uint32_t result;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__MediaFormat, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "MediaFormat_id_get" "', argument " "1"" of type '" "pj::MediaFormat *""'"); 
  }
  arg1 = reinterpret_cast< pj::MediaFormat * >(argp1);
  result = (pj_uint32_t) ((arg1)->id);
  resultobj = SWIG_From_unsigned_SS_int(static_cast< unsigned int >(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_MediaFormat_type_set(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::MediaFormat *arg1 = (pj::MediaFormat *) 0 ;
  pjmedia_type arg2 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  int val2 ;
  int ecode2 = 0 ;
  PyObject *swig_obj[2] ;
  
  if (!SWIG_Python_UnpackTuple(args, "MediaFormat_type_set", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__MediaFormat, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "MediaFormat_type_set" "', argument " "1"" of type '" "pj::MediaFormat *""'"); 
  }
  arg1 = reinterpret_cast< pj::MediaFormat * >(argp1);
  ecode2 = SWIG_AsVal_int(swig_obj[1], &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "MediaFormat_type_set" "', argument " "2"" of type '" "pjmedia_type""'");
  } 
  arg2 = static_cast< pjmedia_type >(val2);
  if (arg1) (arg1)->type = arg2;
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_MediaFormat_type_get(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::MediaFormat *arg1 = (pj::MediaFormat *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  pjmedia_type result;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__MediaFormat, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "MediaFormat_type_get" "', argument " "1"" of type '" "pj::MediaFormat *""'"); 
  }
  arg1 = reinterpret_cast< pj::MediaFormat * >(argp1);
  result = (pjmedia_type) ((arg1)->type);
  resultobj = SWIG_From_int(static_cast< int >(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_new_MediaFormat(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::MediaFormat *result = 0 ;
  
  if (!SWIG_Python_UnpackTuple(args, "new_MediaFormat", 0, 0, 0)) SWIG_fail;
  result = (pj::MediaFormat *)new pj::MediaFormat();
  resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(result), SWIGTYPE_p_pj__MediaFormat, SWIG_POINTER_NEW |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_delete_MediaFormat(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::MediaFormat *arg1 = (pj::MediaFormat *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__MediaFormat, SWIG_POINTER_DISOWN |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "delete_MediaFormat" "', argument " "1"" of type '" "pj::MediaFormat *""'"); 
  }
  arg1 = reinterpret_cast< pj::MediaFormat * >(argp1);
  delete arg1;
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *MediaFormat_swigregister(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *obj;
  if (!SWIG_Python_UnpackTuple(args, "swigregister", 1, 1, &obj)) return NULL;
  SWIG_TypeNewClientData(SWIGTYPE_p_pj__MediaFormat, SWIG_NewClientData(obj));
  return SWIG_Py_Void();
}

SWIGINTERN PyObject *MediaFormat_swiginit(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  return SWIG_Python_InitShadowInstance(args);
}

SWIGINTERN PyObject *_wrap_MediaFormatAudio_clockRate_set(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::MediaFormatAudio *arg1 = (pj::MediaFormatAudio *) 0 ;
  unsigned int arg2 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  unsigned int val2 ;
  int ecode2 = 0 ;
  PyObject *swig_obj[2] ;
  
  if (!SWIG_Python_UnpackTuple(args, "MediaFormatAudio_clockRate_set", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__MediaFormatAudio, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "MediaFormatAudio_clockRate_set" "', argument " "1"" of type '" "pj::MediaFormatAudio *""'"); 
  }
  arg1 = reinterpret_cast< pj::MediaFormatAudio * >(argp1);
  ecode2 = SWIG_AsVal_unsigned_SS_int(swig_obj[1], &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "MediaFormatAudio_clockRate_set" "', argument " "2"" of type '" "unsigned int""'");
  } 
  arg2 = static_cast< unsigned int >(val2);
  if (arg1) (arg1)->clockRate = arg2;
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_MediaFormatAudio_clockRate_get(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::MediaFormatAudio *arg1 = (pj::MediaFormatAudio *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  unsigned int result;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__MediaFormatAudio, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "MediaFormatAudio_clockRate_get" "', argument " "1"" of type '" "pj::MediaFormatAudio *""'"); 
  }
  arg1 = reinterpret_cast< pj::MediaFormatAudio * >(argp1);
  result = (unsigned int) ((arg1)->clockRate);
  resultobj = SWIG_From_unsigned_SS_int(static_cast< unsigned int >(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_MediaFormatAudio_channelCount_set(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::MediaFormatAudio *arg1 = (pj::MediaFormatAudio *) 0 ;
  unsigned int arg2 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  unsigned int val2 ;
  int ecode2 = 0 ;
  PyObject *swig_obj[2] ;
  
  if (!SWIG_Python_UnpackTuple(args, "MediaFormatAudio_channelCount_set", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__MediaFormatAudio, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "MediaFormatAudio_channelCount_set" "', argument " "1"" of type '" "pj::MediaFormatAudio *""'"); 
  }
  arg1 = reinterpret_cast< pj::MediaFormatAudio * >(argp1);
  ecode2 = SWIG_AsVal_unsigned_SS_int(swig_obj[1], &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "MediaFormatAudio_channelCount_set" "', argument " "2"" of type '" "unsigned int""'");
  } 
  arg2 = static_cast< unsigned int >(val2);
  if (arg1) (arg1)->channelCount = arg2;
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_MediaFormatAudio_channelCount_get(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::MediaFormatAudio *arg1 = (pj::MediaFormatAudio *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  unsigned int result;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__MediaFormatAudio, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "MediaFormatAudio_channelCount_get" "', argument " "1"" of type '" "pj::MediaFormatAudio *""'"); 
  }
  arg1 = reinterpret_cast< pj::MediaFormatAudio * >(argp1);
  result = (unsigned int) ((arg1)->channelCount);
  resultobj = SWIG_From_unsigned_SS_int(static_cast< unsigned int >(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_MediaFormatAudio_frameTimeUsec_set(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::MediaFormatAudio *arg1 = (pj::MediaFormatAudio *) 0 ;
  unsigned int arg2 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  unsigned int val2 ;
  int ecode2 = 0 ;
  PyObject *swig_obj[2] ;
  
  if (!SWIG_Python_UnpackTuple(args, "MediaFormatAudio_frameTimeUsec_set", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__MediaFormatAudio, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "MediaFormatAudio_frameTimeUsec_set" "', argument " "1"" of type '" "pj::MediaFormatAudio *""'"); 
  }
  arg1 = reinterpret_cast< pj::MediaFormatAudio * >(argp1);
  ecode2 = SWIG_AsVal_unsigned_SS_int(swig_obj[1], &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "MediaFormatAudio_frameTimeUsec_set" "', argument " "2"" of type '" "unsigned int""'");
  } 
  arg2 = static_cast< unsigned int >(val2);
  if (arg1) (arg1)->frameTimeUsec = arg2;
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_MediaFormatAudio_frameTimeUsec_get(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::MediaFormatAudio *arg1 = (pj::MediaFormatAudio *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  unsigned int result;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__MediaFormatAudio, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "MediaFormatAudio_frameTimeUsec_get" "', argument " "1"" of type '" "pj::MediaFormatAudio *""'"); 
  }
  arg1 = reinterpret_cast< pj::MediaFormatAudio * >(argp1);
  result = (unsigned int) ((arg1)->frameTimeUsec);
  resultobj = SWIG_From_unsigned_SS_int(static_cast< unsigned int >(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_MediaFormatAudio_bitsPerSample_set(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::MediaFormatAudio *arg1 = (pj::MediaFormatAudio *) 0 ;
  unsigned int arg2 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  unsigned int val2 ;
  int ecode2 = 0 ;
  PyObject *swig_obj[2] ;
  
  if (!SWIG_Python_UnpackTuple(args, "MediaFormatAudio_bitsPerSample_set", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__MediaFormatAudio, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "MediaFormatAudio_bitsPerSample_set" "', argument " "1"" of type '" "pj::MediaFormatAudio *""'"); 
  }
  arg1 = reinterpret_cast< pj::MediaFormatAudio * >(argp1);
  ecode2 = SWIG_AsVal_unsigned_SS_int(swig_obj[1], &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "MediaFormatAudio_bitsPerSample_set" "', argument " "2"" of type '" "unsigned int""'");
  } 
  arg2 = static_cast< unsigned int >(val2);
  if (arg1) (arg1)->bitsPerSample = arg2;
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_MediaFormatAudio_bitsPerSample_get(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::MediaFormatAudio *arg1 = (pj::MediaFormatAudio *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  unsigned int result;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__MediaFormatAudio, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "MediaFormatAudio_bitsPerSample_get" "', argument " "1"" of type '" "pj::MediaFormatAudio *""'"); 
  }
  arg1 = reinterpret_cast< pj::MediaFormatAudio * >(argp1);
  result = (unsigned int) ((arg1)->bitsPerSample);
  resultobj = SWIG_From_unsigned_SS_int(static_cast< unsigned int >(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_MediaFormatAudio_avgBps_set(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::MediaFormatAudio *arg1 = (pj::MediaFormatAudio *) 0 ;
  pj_uint32_t arg2 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  unsigned int val2 ;
  int ecode2 = 0 ;
  PyObject *swig_obj[2] ;
  
  if (!SWIG_Python_UnpackTuple(args, "MediaFormatAudio_avgBps_set", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__MediaFormatAudio, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "MediaFormatAudio_avgBps_set" "', argument " "1"" of type '" "pj::MediaFormatAudio *""'"); 
  }
  arg1 = reinterpret_cast< pj::MediaFormatAudio * >(argp1);
  ecode2 = SWIG_AsVal_unsigned_SS_int(swig_obj[1], &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "MediaFormatAudio_avgBps_set" "', argument " "2"" of type '" "pj_uint32_t""'");
  } 
  arg2 = static_cast< pj_uint32_t >(val2);
  if (arg1) (arg1)->avgBps = arg2;
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_MediaFormatAudio_avgBps_get(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::MediaFormatAudio *arg1 = (pj::MediaFormatAudio *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  pj_uint32_t result;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__MediaFormatAudio, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "MediaFormatAudio_avgBps_get" "', argument " "1"" of type '" "pj::MediaFormatAudio *""'"); 
  }
  arg1 = reinterpret_cast< pj::MediaFormatAudio * >(argp1);
  result = (pj_uint32_t) ((arg1)->avgBps);
  resultobj = SWIG_From_unsigned_SS_int(static_cast< unsigned int >(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_MediaFormatAudio_maxBps_set(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::MediaFormatAudio *arg1 = (pj::MediaFormatAudio *) 0 ;
  pj_uint32_t arg2 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  unsigned int val2 ;
  int ecode2 = 0 ;
  PyObject *swig_obj[2] ;
  
  if (!SWIG_Python_UnpackTuple(args, "MediaFormatAudio_maxBps_set", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__MediaFormatAudio, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "MediaFormatAudio_maxBps_set" "', argument " "1"" of type '" "pj::MediaFormatAudio *""'"); 
  }
  arg1 = reinterpret_cast< pj::MediaFormatAudio * >(argp1);
  ecode2 = SWIG_AsVal_unsigned_SS_int(swig_obj[1], &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "MediaFormatAudio_maxBps_set" "', argument " "2"" of type '" "pj_uint32_t""'");
  } 
  arg2 = static_cast< pj_uint32_t >(val2);
  if (arg1) (arg1)->maxBps = arg2;
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_MediaFormatAudio_maxBps_get(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::MediaFormatAudio *arg1 = (pj::MediaFormatAudio *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  pj_uint32_t result;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__MediaFormatAudio, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "MediaFormatAudio_maxBps_get" "', argument " "1"" of type '" "pj::MediaFormatAudio *""'"); 
  }
  arg1 = reinterpret_cast< pj::MediaFormatAudio * >(argp1);
  result = (pj_uint32_t) ((arg1)->maxBps);
  resultobj = SWIG_From_unsigned_SS_int(static_cast< unsigned int >(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_new_MediaFormatAudio(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::MediaFormatAudio *result = 0 ;
  
  if (!SWIG_Python_UnpackTuple(args, "new_MediaFormatAudio", 0, 0, 0)) SWIG_fail;
  result = (pj::MediaFormatAudio *)new pj::MediaFormatAudio();
  resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(result), SWIGTYPE_p_pj__MediaFormatAudio, SWIG_POINTER_NEW |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_delete_MediaFormatAudio(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::MediaFormatAudio *arg1 = (pj::MediaFormatAudio *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__MediaFormatAudio, SWIG_POINTER_DISOWN |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "delete_MediaFormatAudio" "', argument " "1"" of type '" "pj::MediaFormatAudio *""'"); 
  }
  arg1 = reinterpret_cast< pj::MediaFormatAudio * >(argp1);
  delete arg1;
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *MediaFormatAudio_swigregister(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *obj;
  if (!SWIG_Python_UnpackTuple(args, "swigregister", 1, 1, &obj)) return NULL;
  SWIG_TypeNewClientData(SWIGTYPE_p_pj__MediaFormatAudio, SWIG_NewClientData(obj));
  return SWIG_Py_Void();
}

SWIGINTERN PyObject *MediaFormatAudio_swiginit(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  return SWIG_Python_InitShadowInstance(args);
}

SWIGINTERN PyObject *_wrap_MediaFormatVideo_width_set(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::MediaFormatVideo *arg1 = (pj::MediaFormatVideo *) 0 ;
  unsigned int arg2 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  unsigned int val2 ;
  int ecode2 = 0 ;
  PyObject *swig_obj[2] ;
  
  if (!SWIG_Python_UnpackTuple(args, "MediaFormatVideo_width_set", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__MediaFormatVideo, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "MediaFormatVideo_width_set" "', argument " "1"" of type '" "pj::MediaFormatVideo *""'"); 
  }
  arg1 = reinterpret_cast< pj::MediaFormatVideo * >(argp1);
  ecode2 = SWIG_AsVal_unsigned_SS_int(swig_obj[1], &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "MediaFormatVideo_width_set" "', argument " "2"" of type '" "unsigned int""'");
  } 
  arg2 = static_cast< unsigned int >(val2);
  if (arg1) (arg1)->width = arg2;
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_MediaFormatVideo_width_get(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::MediaFormatVideo *arg1 = (pj::MediaFormatVideo *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  unsigned int result;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__MediaFormatVideo, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "MediaFormatVideo_width_get" "', argument " "1"" of type '" "pj::MediaFormatVideo *""'"); 
  }
  arg1 = reinterpret_cast< pj::MediaFormatVideo * >(argp1);
  result = (unsigned int) ((arg1)->width);
  resultobj = SWIG_From_unsigned_SS_int(static_cast< unsigned int >(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_MediaFormatVideo_height_set(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::MediaFormatVideo *arg1 = (pj::MediaFormatVideo *) 0 ;
  unsigned int arg2 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  unsigned int val2 ;
  int ecode2 = 0 ;
  PyObject *swig_obj[2] ;
  
  if (!SWIG_Python_UnpackTuple(args, "MediaFormatVideo_height_set", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__MediaFormatVideo, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "MediaFormatVideo_height_set" "', argument " "1"" of type '" "pj::MediaFormatVideo *""'"); 
  }
  arg1 = reinterpret_cast< pj::MediaFormatVideo * >(argp1);
  ecode2 = SWIG_AsVal_unsigned_SS_int(swig_obj[1], &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "MediaFormatVideo_height_set" "', argument " "2"" of type '" "unsigned int""'");
  } 
  arg2 = static_cast< unsigned int >(val2);
  if (arg1) (arg1)->height = arg2;
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_MediaFormatVideo_height_get(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::MediaFormatVideo *arg1 = (pj::MediaFormatVideo *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  unsigned int result;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__MediaFormatVideo, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "MediaFormatVideo_height_get" "', argument " "1"" of type '" "pj::MediaFormatVideo *""'"); 
  }
  arg1 = reinterpret_cast< pj::MediaFormatVideo * >(argp1);
  result = (unsigned int) ((arg1)->height);
  resultobj = SWIG_From_unsigned_SS_int(static_cast< unsigned int >(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_MediaFormatVideo_fpsNum_set(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::MediaFormatVideo *arg1 = (pj::MediaFormatVideo *) 0 ;
  int arg2 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  int val2 ;
  int ecode2 = 0 ;
  PyObject *swig_obj[2] ;
  
  if (!SWIG_Python_UnpackTuple(args, "MediaFormatVideo_fpsNum_set", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__MediaFormatVideo, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "MediaFormatVideo_fpsNum_set" "', argument " "1"" of type '" "pj::MediaFormatVideo *""'"); 
  }
  arg1 = reinterpret_cast< pj::MediaFormatVideo * >(argp1);
  ecode2 = SWIG_AsVal_int(swig_obj[1], &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "MediaFormatVideo_fpsNum_set" "', argument " "2"" of type '" "int""'");
  } 
  arg2 = static_cast< int >(val2);
  if (arg1) (arg1)->fpsNum = arg2;
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_MediaFormatVideo_fpsNum_get(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::MediaFormatVideo *arg1 = (pj::MediaFormatVideo *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  int result;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__MediaFormatVideo, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "MediaFormatVideo_fpsNum_get" "', argument " "1"" of type '" "pj::MediaFormatVideo *""'"); 
  }
  arg1 = reinterpret_cast< pj::MediaFormatVideo * >(argp1);
  result = (int) ((arg1)->fpsNum);
  resultobj = SWIG_From_int(static_cast< int >(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_MediaFormatVideo_fpsDenum_set(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::MediaFormatVideo *arg1 = (pj::MediaFormatVideo *) 0 ;
  int arg2 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  int val2 ;
  int ecode2 = 0 ;
  PyObject *swig_obj[2] ;
  
  if (!SWIG_Python_UnpackTuple(args, "MediaFormatVideo_fpsDenum_set", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__MediaFormatVideo, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "MediaFormatVideo_fpsDenum_set" "', argument " "1"" of type '" "pj::MediaFormatVideo *""'"); 
  }
  arg1 = reinterpret_cast< pj::MediaFormatVideo * >(argp1);
  ecode2 = SWIG_AsVal_int(swig_obj[1], &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "MediaFormatVideo_fpsDenum_set" "', argument " "2"" of type '" "int""'");
  } 
  arg2 = static_cast< int >(val2);
  if (arg1) (arg1)->fpsDenum = arg2;
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_MediaFormatVideo_fpsDenum_get(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::MediaFormatVideo *arg1 = (pj::MediaFormatVideo *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  int result;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__MediaFormatVideo, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "MediaFormatVideo_fpsDenum_get" "', argument " "1"" of type '" "pj::MediaFormatVideo *""'"); 
  }
  arg1 = reinterpret_cast< pj::MediaFormatVideo * >(argp1);
  result = (int) ((arg1)->fpsDenum);
  resultobj = SWIG_From_int(static_cast< int >(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_MediaFormatVideo_avgBps_set(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::MediaFormatVideo *arg1 = (pj::MediaFormatVideo *) 0 ;
  pj_uint32_t arg2 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  unsigned int val2 ;
  int ecode2 = 0 ;
  PyObject *swig_obj[2] ;
  
  if (!SWIG_Python_UnpackTuple(args, "MediaFormatVideo_avgBps_set", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__MediaFormatVideo, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "MediaFormatVideo_avgBps_set" "', argument " "1"" of type '" "pj::MediaFormatVideo *""'"); 
  }
  arg1 = reinterpret_cast< pj::MediaFormatVideo * >(argp1);
  ecode2 = SWIG_AsVal_unsigned_SS_int(swig_obj[1], &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "MediaFormatVideo_avgBps_set" "', argument " "2"" of type '" "pj_uint32_t""'");
  } 
  arg2 = static_cast< pj_uint32_t >(val2);
  if (arg1) (arg1)->avgBps = arg2;
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_MediaFormatVideo_avgBps_get(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::MediaFormatVideo *arg1 = (pj::MediaFormatVideo *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  pj_uint32_t result;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__MediaFormatVideo, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "MediaFormatVideo_avgBps_get" "', argument " "1"" of type '" "pj::MediaFormatVideo *""'"); 
  }
  arg1 = reinterpret_cast< pj::MediaFormatVideo * >(argp1);
  result = (pj_uint32_t) ((arg1)->avgBps);
  resultobj = SWIG_From_unsigned_SS_int(static_cast< unsigned int >(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_MediaFormatVideo_maxBps_set(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::MediaFormatVideo *arg1 = (pj::MediaFormatVideo *) 0 ;
  pj_uint32_t arg2 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  unsigned int val2 ;
  int ecode2 = 0 ;
  PyObject *swig_obj[2] ;
  
  if (!SWIG_Python_UnpackTuple(args, "MediaFormatVideo_maxBps_set", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__MediaFormatVideo, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "MediaFormatVideo_maxBps_set" "', argument " "1"" of type '" "pj::MediaFormatVideo *""'"); 
  }
  arg1 = reinterpret_cast< pj::MediaFormatVideo * >(argp1);
  ecode2 = SWIG_AsVal_unsigned_SS_int(swig_obj[1], &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "MediaFormatVideo_maxBps_set" "', argument " "2"" of type '" "pj_uint32_t""'");
  } 
  arg2 = static_cast< pj_uint32_t >(val2);
  if (arg1) (arg1)->maxBps = arg2;
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_MediaFormatVideo_maxBps_get(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::MediaFormatVideo *arg1 = (pj::MediaFormatVideo *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  pj_uint32_t result;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__MediaFormatVideo, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "MediaFormatVideo_maxBps_get" "', argument " "1"" of type '" "pj::MediaFormatVideo *""'"); 
  }
  arg1 = reinterpret_cast< pj::MediaFormatVideo * >(argp1);
  result = (pj_uint32_t) ((arg1)->maxBps);
  resultobj = SWIG_From_unsigned_SS_int(static_cast< unsigned int >(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_new_MediaFormatVideo(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::MediaFormatVideo *result = 0 ;
  
  if (!SWIG_Python_UnpackTuple(args, "new_MediaFormatVideo", 0, 0, 0)) SWIG_fail;
  result = (pj::MediaFormatVideo *)new pj::MediaFormatVideo();
  resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(result), SWIGTYPE_p_pj__MediaFormatVideo, SWIG_POINTER_NEW |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_delete_MediaFormatVideo(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::MediaFormatVideo *arg1 = (pj::MediaFormatVideo *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__MediaFormatVideo, SWIG_POINTER_DISOWN |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "delete_MediaFormatVideo" "', argument " "1"" of type '" "pj::MediaFormatVideo *""'"); 
  }
  arg1 = reinterpret_cast< pj::MediaFormatVideo * >(argp1);
  delete arg1;
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *MediaFormatVideo_swigregister(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *obj;
  if (!SWIG_Python_UnpackTuple(args, "swigregister", 1, 1, &obj)) return NULL;
  SWIG_TypeNewClientData(SWIGTYPE_p_pj__MediaFormatVideo, SWIG_NewClientData(obj));
  return SWIG_Py_Void();
}

SWIGINTERN PyObject *MediaFormatVideo_swiginit(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  return SWIG_Python_InitShadowInstance(args);
}

SWIGINTERN PyObject *_wrap_ConfPortInfo_portId_set(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::ConfPortInfo *arg1 = (pj::ConfPortInfo *) 0 ;
  int arg2 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  int val2 ;
  int ecode2 = 0 ;
  PyObject *swig_obj[2] ;
  
  if (!SWIG_Python_UnpackTuple(args, "ConfPortInfo_portId_set", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__ConfPortInfo, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "ConfPortInfo_portId_set" "', argument " "1"" of type '" "pj::ConfPortInfo *""'"); 
  }
  arg1 = reinterpret_cast< pj::ConfPortInfo * >(argp1);
  ecode2 = SWIG_AsVal_int(swig_obj[1], &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "ConfPortInfo_portId_set" "', argument " "2"" of type '" "int""'");
  } 
  arg2 = static_cast< int >(val2);
  if (arg1) (arg1)->portId = arg2;
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_ConfPortInfo_portId_get(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::ConfPortInfo *arg1 = (pj::ConfPortInfo *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  int result;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__ConfPortInfo, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "ConfPortInfo_portId_get" "', argument " "1"" of type '" "pj::ConfPortInfo *""'"); 
  }
  arg1 = reinterpret_cast< pj::ConfPortInfo * >(argp1);
  result = (int) ((arg1)->portId);
  resultobj = SWIG_From_int(static_cast< int >(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_ConfPortInfo_name_set(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::ConfPortInfo *arg1 = (pj::ConfPortInfo *) 0 ;
  pj::string *arg2 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  int res2 = SWIG_OLDOBJ ;
  PyObject *swig_obj[2] ;
  
  if (!SWIG_Python_UnpackTuple(args, "ConfPortInfo_name_set", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__ConfPortInfo, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "ConfPortInfo_name_set" "', argument " "1"" of type '" "pj::ConfPortInfo *""'"); 
  }
  arg1 = reinterpret_cast< pj::ConfPortInfo * >(argp1);
  {
    std::string *ptr = (std::string *)0;
    res2 = SWIG_AsPtr_std_string(swig_obj[1], &ptr);
    if (!SWIG_IsOK(res2)) {
      SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "ConfPortInfo_name_set" "', argument " "2"" of type '" "pj::string const &""'"); 
    }
    if (!ptr) {
      SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "ConfPortInfo_name_set" "', argument " "2"" of type '" "pj::string const &""'"); 
    }
    arg2 = ptr;
  }
  if (arg1) (arg1)->name = *arg2;
  resultobj = SWIG_Py_Void();
  if (SWIG_IsNewObj(res2)) delete arg2;
  return resultobj;
fail:
  if (SWIG_IsNewObj(res2)) delete arg2;
  return NULL;
}


SWIGINTERN PyObject *_wrap_ConfPortInfo_name_get(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::ConfPortInfo *arg1 = (pj::ConfPortInfo *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  pj::string *result = 0 ;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__ConfPortInfo, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "ConfPortInfo_name_get" "', argument " "1"" of type '" "pj::ConfPortInfo *""'"); 
  }
  arg1 = reinterpret_cast< pj::ConfPortInfo * >(argp1);
  result = (pj::string *) & ((arg1)->name);
  resultobj = SWIG_From_std_string(static_cast< std::string >(*result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_ConfPortInfo_format_set(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::ConfPortInfo *arg1 = (pj::ConfPortInfo *) 0 ;
  pj::MediaFormatAudio *arg2 = (pj::MediaFormatAudio *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  void *argp2 = 0 ;
  int res2 = 0 ;
  PyObject *swig_obj[2] ;
  
  if (!SWIG_Python_UnpackTuple(args, "ConfPortInfo_format_set", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__ConfPortInfo, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "ConfPortInfo_format_set" "', argument " "1"" of type '" "pj::ConfPortInfo *""'"); 
  }
  arg1 = reinterpret_cast< pj::ConfPortInfo * >(argp1);
  res2 = SWIG_ConvertPtr(swig_obj[1], &argp2,SWIGTYPE_p_pj__MediaFormatAudio, 0 |  0 );
  if (!SWIG_IsOK(res2)) {
    SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "ConfPortInfo_format_set" "', argument " "2"" of type '" "pj::MediaFormatAudio *""'"); 
  }
  arg2 = reinterpret_cast< pj::MediaFormatAudio * >(argp2);
  if (arg1) (arg1)->format = *arg2;
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_ConfPortInfo_format_get(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::ConfPortInfo *arg1 = (pj::ConfPortInfo *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  pj::MediaFormatAudio *result = 0 ;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__ConfPortInfo, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "ConfPortInfo_format_get" "', argument " "1"" of type '" "pj::ConfPortInfo *""'"); 
  }
  arg1 = reinterpret_cast< pj::ConfPortInfo * >(argp1);
  result = (pj::MediaFormatAudio *)& ((arg1)->format);
  resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(result), SWIGTYPE_p_pj__MediaFormatAudio, 0 |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_ConfPortInfo_txLevelAdj_set(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::ConfPortInfo *arg1 = (pj::ConfPortInfo *) 0 ;
  float arg2 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  float val2 ;
  int ecode2 = 0 ;
  PyObject *swig_obj[2] ;
  
  if (!SWIG_Python_UnpackTuple(args, "ConfPortInfo_txLevelAdj_set", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__ConfPortInfo, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "ConfPortInfo_txLevelAdj_set" "', argument " "1"" of type '" "pj::ConfPortInfo *""'"); 
  }
  arg1 = reinterpret_cast< pj::ConfPortInfo * >(argp1);
  ecode2 = SWIG_AsVal_float(swig_obj[1], &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "ConfPortInfo_txLevelAdj_set" "', argument " "2"" of type '" "float""'");
  } 
  arg2 = static_cast< float >(val2);
  if (arg1) (arg1)->txLevelAdj = arg2;
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_ConfPortInfo_txLevelAdj_get(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::ConfPortInfo *arg1 = (pj::ConfPortInfo *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  float result;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__ConfPortInfo, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "ConfPortInfo_txLevelAdj_get" "', argument " "1"" of type '" "pj::ConfPortInfo *""'"); 
  }
  arg1 = reinterpret_cast< pj::ConfPortInfo * >(argp1);
  result = (float) ((arg1)->txLevelAdj);
  resultobj = SWIG_From_float(static_cast< float >(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_ConfPortInfo_rxLevelAdj_set(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::ConfPortInfo *arg1 = (pj::ConfPortInfo *) 0 ;
  float arg2 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  float val2 ;
  int ecode2 = 0 ;
  PyObject *swig_obj[2] ;
  
  if (!SWIG_Python_UnpackTuple(args, "ConfPortInfo_rxLevelAdj_set", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__ConfPortInfo, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "ConfPortInfo_rxLevelAdj_set" "', argument " "1"" of type '" "pj::ConfPortInfo *""'"); 
  }
  arg1 = reinterpret_cast< pj::ConfPortInfo * >(argp1);
  ecode2 = SWIG_AsVal_float(swig_obj[1], &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "ConfPortInfo_rxLevelAdj_set" "', argument " "2"" of type '" "float""'");
  } 
  arg2 = static_cast< float >(val2);
  if (arg1) (arg1)->rxLevelAdj = arg2;
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_ConfPortInfo_rxLevelAdj_get(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::ConfPortInfo *arg1 = (pj::ConfPortInfo *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  float result;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__ConfPortInfo, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "ConfPortInfo_rxLevelAdj_get" "', argument " "1"" of type '" "pj::ConfPortInfo *""'"); 
  }
  arg1 = reinterpret_cast< pj::ConfPortInfo * >(argp1);
  result = (float) ((arg1)->rxLevelAdj);
  resultobj = SWIG_From_float(static_cast< float >(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_ConfPortInfo_listeners_set(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::ConfPortInfo *arg1 = (pj::ConfPortInfo *) 0 ;
  pj::IntVector *arg2 = (pj::IntVector *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  void *argp2 = 0 ;
  int res2 = 0 ;
  PyObject *swig_obj[2] ;
  
  if (!SWIG_Python_UnpackTuple(args, "ConfPortInfo_listeners_set", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__ConfPortInfo, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "ConfPortInfo_listeners_set" "', argument " "1"" of type '" "pj::ConfPortInfo *""'"); 
  }
  arg1 = reinterpret_cast< pj::ConfPortInfo * >(argp1);
  res2 = SWIG_ConvertPtr(swig_obj[1], &argp2,SWIGTYPE_p_std__vectorT_int_std__allocatorT_int_t_t, 0 |  0 );
  if (!SWIG_IsOK(res2)) {
    SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "ConfPortInfo_listeners_set" "', argument " "2"" of type '" "pj::IntVector *""'"); 
  }
  arg2 = reinterpret_cast< pj::IntVector * >(argp2);
  if (arg1) (arg1)->listeners = *arg2;
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_ConfPortInfo_listeners_get(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::ConfPortInfo *arg1 = (pj::ConfPortInfo *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  pj::IntVector *result = 0 ;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__ConfPortInfo, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "ConfPortInfo_listeners_get" "', argument " "1"" of type '" "pj::ConfPortInfo *""'"); 
  }
  arg1 = reinterpret_cast< pj::ConfPortInfo * >(argp1);
  result = (pj::IntVector *)& ((arg1)->listeners);
  resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(result), SWIGTYPE_p_std__vectorT_int_std__allocatorT_int_t_t, 0 |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_new_ConfPortInfo(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::ConfPortInfo *result = 0 ;
  
  if (!SWIG_Python_UnpackTuple(args, "new_ConfPortInfo", 0, 0, 0)) SWIG_fail;
  result = (pj::ConfPortInfo *)new pj::ConfPortInfo();
  resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(result), SWIGTYPE_p_pj__ConfPortInfo, SWIG_POINTER_NEW |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_delete_ConfPortInfo(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::ConfPortInfo *arg1 = (pj::ConfPortInfo *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__ConfPortInfo, SWIG_POINTER_DISOWN |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "delete_ConfPortInfo" "', argument " "1"" of type '" "pj::ConfPortInfo *""'"); 
  }
  arg1 = reinterpret_cast< pj::ConfPortInfo * >(argp1);
  delete arg1;
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *ConfPortInfo_swigregister(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *obj;
  if (!SWIG_Python_UnpackTuple(args, "swigregister", 1, 1, &obj)) return NULL;
  SWIG_TypeNewClientData(SWIGTYPE_p_pj__ConfPortInfo, SWIG_NewClientData(obj));
  return SWIG_Py_Void();
}

SWIGINTERN PyObject *ConfPortInfo_swiginit(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  return SWIG_Python_InitShadowInstance(args);
}

SWIGINTERN PyObject *_wrap_delete_Media(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::Media *arg1 = (pj::Media *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__Media, SWIG_POINTER_DISOWN |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "delete_Media" "', argument " "1"" of type '" "pj::Media *""'"); 
  }
  arg1 = reinterpret_cast< pj::Media * >(argp1);
  delete arg1;
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_Media_getType(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::Media *arg1 = (pj::Media *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  pjmedia_type result;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__Media, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "Media_getType" "', argument " "1"" of type '" "pj::Media const *""'"); 
  }
  arg1 = reinterpret_cast< pj::Media * >(argp1);
  result = (pjmedia_type)((pj::Media const *)arg1)->getType();
  resultobj = SWIG_From_int(static_cast< int >(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *Media_swigregister(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *obj;
  if (!SWIG_Python_UnpackTuple(args, "swigregister", 1, 1, &obj)) return NULL;
  SWIG_TypeNewClientData(SWIGTYPE_p_pj__Media, SWIG_NewClientData(obj));
  return SWIG_Py_Void();
}

SWIGINTERN PyObject *_wrap_AudioMediaTransmitParam_level_set(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::AudioMediaTransmitParam *arg1 = (pj::AudioMediaTransmitParam *) 0 ;
  float arg2 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  float val2 ;
  int ecode2 = 0 ;
  PyObject *swig_obj[2] ;
  
  if (!SWIG_Python_UnpackTuple(args, "AudioMediaTransmitParam_level_set", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__AudioMediaTransmitParam, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "AudioMediaTransmitParam_level_set" "', argument " "1"" of type '" "pj::AudioMediaTransmitParam *""'"); 
  }
  arg1 = reinterpret_cast< pj::AudioMediaTransmitParam * >(argp1);
  ecode2 = SWIG_AsVal_float(swig_obj[1], &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "AudioMediaTransmitParam_level_set" "', argument " "2"" of type '" "float""'");
  } 
  arg2 = static_cast< float >(val2);
  if (arg1) (arg1)->level = arg2;
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_AudioMediaTransmitParam_level_get(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::AudioMediaTransmitParam *arg1 = (pj::AudioMediaTransmitParam *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  float result;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__AudioMediaTransmitParam, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "AudioMediaTransmitParam_level_get" "', argument " "1"" of type '" "pj::AudioMediaTransmitParam *""'"); 
  }
  arg1 = reinterpret_cast< pj::AudioMediaTransmitParam * >(argp1);
  result = (float) ((arg1)->level);
  resultobj = SWIG_From_float(static_cast< float >(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_new_AudioMediaTransmitParam(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::AudioMediaTransmitParam *result = 0 ;
  
  if (!SWIG_Python_UnpackTuple(args, "new_AudioMediaTransmitParam", 0, 0, 0)) SWIG_fail;
  result = (pj::AudioMediaTransmitParam *)new pj::AudioMediaTransmitParam();
  resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(result), SWIGTYPE_p_pj__AudioMediaTransmitParam, SWIG_POINTER_NEW |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_delete_AudioMediaTransmitParam(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::AudioMediaTransmitParam *arg1 = (pj::AudioMediaTransmitParam *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__AudioMediaTransmitParam, SWIG_POINTER_DISOWN |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "delete_AudioMediaTransmitParam" "', argument " "1"" of type '" "pj::AudioMediaTransmitParam *""'"); 
  }
  arg1 = reinterpret_cast< pj::AudioMediaTransmitParam * >(argp1);
  delete arg1;
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *AudioMediaTransmitParam_swigregister(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *obj;
  if (!SWIG_Python_UnpackTuple(args, "swigregister", 1, 1, &obj)) return NULL;
  SWIG_TypeNewClientData(SWIGTYPE_p_pj__AudioMediaTransmitParam, SWIG_NewClientData(obj));
  return SWIG_Py_Void();
}

SWIGINTERN PyObject *AudioMediaTransmitParam_swiginit(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  return SWIG_Python_InitShadowInstance(args);
}

SWIGINTERN PyObject *_wrap_AudioMedia_getPortInfo(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::AudioMedia *arg1 = (pj::AudioMedia *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  pj::ConfPortInfo result;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__AudioMedia, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "AudioMedia_getPortInfo" "', argument " "1"" of type '" "pj::AudioMedia const *""'"); 
  }
  arg1 = reinterpret_cast< pj::AudioMedia * >(argp1);
  try {
    result = ((pj::AudioMedia const *)arg1)->getPortInfo();
  } catch(pj::Error &_e) {
    SWIG_Python_Raise(SWIG_NewPointerObj((new pj::Error(static_cast< const pj::Error& >(_e))),SWIGTYPE_p_pj__Error,SWIG_POINTER_OWN), "pj::Error", SWIGTYPE_p_pj__Error); SWIG_fail;
  }
  resultobj = SWIG_NewPointerObj((new pj::ConfPortInfo(static_cast< const pj::ConfPortInfo& >(result))), SWIGTYPE_p_pj__ConfPortInfo, SWIG_POINTER_OWN |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_AudioMedia_getPortId(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::AudioMedia *arg1 = (pj::AudioMedia *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  int result;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__AudioMedia, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "AudioMedia_getPortId" "', argument " "1"" of type '" "pj::AudioMedia const *""'"); 
  }
  arg1 = reinterpret_cast< pj::AudioMedia * >(argp1);
  result = (int)((pj::AudioMedia const *)arg1)->getPortId();
  resultobj = SWIG_From_int(static_cast< int >(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_AudioMedia_getPortInfoFromId(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  int arg1 ;
  int val1 ;
  int ecode1 = 0 ;
  PyObject *swig_obj[1] ;
  pj::ConfPortInfo result;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  ecode1 = SWIG_AsVal_int(swig_obj[0], &val1);
  if (!SWIG_IsOK(ecode1)) {
    SWIG_exception_fail(SWIG_ArgError(ecode1), "in method '" "AudioMedia_getPortInfoFromId" "', argument " "1"" of type '" "int""'");
  } 
  arg1 = static_cast< int >(val1);
  try {
    result = pj::AudioMedia::getPortInfoFromId(arg1);
  } catch(pj::Error &_e) {
    SWIG_Python_Raise(SWIG_NewPointerObj((new pj::Error(static_cast< const pj::Error& >(_e))),SWIGTYPE_p_pj__Error,SWIG_POINTER_OWN), "pj::Error", SWIGTYPE_p_pj__Error); SWIG_fail;
  }
  resultobj = SWIG_NewPointerObj((new pj::ConfPortInfo(static_cast< const pj::ConfPortInfo& >(result))), SWIGTYPE_p_pj__ConfPortInfo, SWIG_POINTER_OWN |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_AudioMedia_startTransmit(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::AudioMedia *arg1 = (pj::AudioMedia *) 0 ;
  pj::AudioMedia *arg2 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  void *argp2 = 0 ;
  int res2 = 0 ;
  PyObject *swig_obj[2] ;
  
  if (!SWIG_Python_UnpackTuple(args, "AudioMedia_startTransmit", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__AudioMedia, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "AudioMedia_startTransmit" "', argument " "1"" of type '" "pj::AudioMedia const *""'"); 
  }
  arg1 = reinterpret_cast< pj::AudioMedia * >(argp1);
  res2 = SWIG_ConvertPtr(swig_obj[1], &argp2, SWIGTYPE_p_pj__AudioMedia,  0  | 0);
  if (!SWIG_IsOK(res2)) {
    SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "AudioMedia_startTransmit" "', argument " "2"" of type '" "pj::AudioMedia const &""'"); 
  }
  if (!argp2) {
    SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "AudioMedia_startTransmit" "', argument " "2"" of type '" "pj::AudioMedia const &""'"); 
  }
  arg2 = reinterpret_cast< pj::AudioMedia * >(argp2);
  try {
    ((pj::AudioMedia const *)arg1)->startTransmit((pj::AudioMedia const &)*arg2);
  } catch(pj::Error &_e) {
    SWIG_Python_Raise(SWIG_NewPointerObj((new pj::Error(static_cast< const pj::Error& >(_e))),SWIGTYPE_p_pj__Error,SWIG_POINTER_OWN), "pj::Error", SWIGTYPE_p_pj__Error); SWIG_fail;
  }
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_AudioMedia_startTransmit2(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::AudioMedia *arg1 = (pj::AudioMedia *) 0 ;
  pj::AudioMedia *arg2 = 0 ;
  pj::AudioMediaTransmitParam *arg3 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  void *argp2 = 0 ;
  int res2 = 0 ;
  void *argp3 = 0 ;
  int res3 = 0 ;
  PyObject *swig_obj[3] ;
  
  if (!SWIG_Python_UnpackTuple(args, "AudioMedia_startTransmit2", 3, 3, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__AudioMedia, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "AudioMedia_startTransmit2" "', argument " "1"" of type '" "pj::AudioMedia const *""'"); 
  }
  arg1 = reinterpret_cast< pj::AudioMedia * >(argp1);
  res2 = SWIG_ConvertPtr(swig_obj[1], &argp2, SWIGTYPE_p_pj__AudioMedia,  0  | 0);
  if (!SWIG_IsOK(res2)) {
    SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "AudioMedia_startTransmit2" "', argument " "2"" of type '" "pj::AudioMedia const &""'"); 
  }
  if (!argp2) {
    SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "AudioMedia_startTransmit2" "', argument " "2"" of type '" "pj::AudioMedia const &""'"); 
  }
  arg2 = reinterpret_cast< pj::AudioMedia * >(argp2);
  res3 = SWIG_ConvertPtr(swig_obj[2], &argp3, SWIGTYPE_p_pj__AudioMediaTransmitParam,  0  | 0);
  if (!SWIG_IsOK(res3)) {
    SWIG_exception_fail(SWIG_ArgError(res3), "in method '" "AudioMedia_startTransmit2" "', argument " "3"" of type '" "pj::AudioMediaTransmitParam const &""'"); 
  }
  if (!argp3) {
    SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "AudioMedia_startTransmit2" "', argument " "3"" of type '" "pj::AudioMediaTransmitParam const &""'"); 
  }
  arg3 = reinterpret_cast< pj::AudioMediaTransmitParam * >(argp3);
  try {
    ((pj::AudioMedia const *)arg1)->startTransmit2((pj::AudioMedia const &)*arg2,(pj::AudioMediaTransmitParam const &)*arg3);
  } catch(pj::Error &_e) {
    SWIG_Python_Raise(SWIG_NewPointerObj((new pj::Error(static_cast< const pj::Error& >(_e))),SWIGTYPE_p_pj__Error,SWIG_POINTER_OWN), "pj::Error", SWIGTYPE_p_pj__Error); SWIG_fail;
  }
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_AudioMedia_stopTransmit(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::AudioMedia *arg1 = (pj::AudioMedia *) 0 ;
  pj::AudioMedia *arg2 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  void *argp2 = 0 ;
  int res2 = 0 ;
  PyObject *swig_obj[2] ;
  
  if (!SWIG_Python_UnpackTuple(args, "AudioMedia_stopTransmit", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__AudioMedia, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "AudioMedia_stopTransmit" "', argument " "1"" of type '" "pj::AudioMedia const *""'"); 
  }
  arg1 = reinterpret_cast< pj::AudioMedia * >(argp1);
  res2 = SWIG_ConvertPtr(swig_obj[1], &argp2, SWIGTYPE_p_pj__AudioMedia,  0  | 0);
  if (!SWIG_IsOK(res2)) {
    SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "AudioMedia_stopTransmit" "', argument " "2"" of type '" "pj::AudioMedia const &""'"); 
  }
  if (!argp2) {
    SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "AudioMedia_stopTransmit" "', argument " "2"" of type '" "pj::AudioMedia const &""'"); 
  }
  arg2 = reinterpret_cast< pj::AudioMedia * >(argp2);
  try {
    ((pj::AudioMedia const *)arg1)->stopTransmit((pj::AudioMedia const &)*arg2);
  } catch(pj::Error &_e) {
    SWIG_Python_Raise(SWIG_NewPointerObj((new pj::Error(static_cast< const pj::Error& >(_e))),SWIGTYPE_p_pj__Error,SWIG_POINTER_OWN), "pj::Error", SWIGTYPE_p_pj__Error); SWIG_fail;
  }
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_AudioMedia_adjustRxLevel(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::AudioMedia *arg1 = (pj::AudioMedia *) 0 ;
  float arg2 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  float val2 ;
  int ecode2 = 0 ;
  PyObject *swig_obj[2] ;
  
  if (!SWIG_Python_UnpackTuple(args, "AudioMedia_adjustRxLevel", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__AudioMedia, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "AudioMedia_adjustRxLevel" "', argument " "1"" of type '" "pj::AudioMedia *""'"); 
  }
  arg1 = reinterpret_cast< pj::AudioMedia * >(argp1);
  ecode2 = SWIG_AsVal_float(swig_obj[1], &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "AudioMedia_adjustRxLevel" "', argument " "2"" of type '" "float""'");
  } 
  arg2 = static_cast< float >(val2);
  try {
    (arg1)->adjustRxLevel(arg2);
  } catch(pj::Error &_e) {
    SWIG_Python_Raise(SWIG_NewPointerObj((new pj::Error(static_cast< const pj::Error& >(_e))),SWIGTYPE_p_pj__Error,SWIG_POINTER_OWN), "pj::Error", SWIGTYPE_p_pj__Error); SWIG_fail;
  }
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_AudioMedia_adjustTxLevel(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::AudioMedia *arg1 = (pj::AudioMedia *) 0 ;
  float arg2 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  float val2 ;
  int ecode2 = 0 ;
  PyObject *swig_obj[2] ;
  
  if (!SWIG_Python_UnpackTuple(args, "AudioMedia_adjustTxLevel", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__AudioMedia, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "AudioMedia_adjustTxLevel" "', argument " "1"" of type '" "pj::AudioMedia *""'"); 
  }
  arg1 = reinterpret_cast< pj::AudioMedia * >(argp1);
  ecode2 = SWIG_AsVal_float(swig_obj[1], &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "AudioMedia_adjustTxLevel" "', argument " "2"" of type '" "float""'");
  } 
  arg2 = static_cast< float >(val2);
  try {
    (arg1)->adjustTxLevel(arg2);
  } catch(pj::Error &_e) {
    SWIG_Python_Raise(SWIG_NewPointerObj((new pj::Error(static_cast< const pj::Error& >(_e))),SWIGTYPE_p_pj__Error,SWIG_POINTER_OWN), "pj::Error", SWIGTYPE_p_pj__Error); SWIG_fail;
  }
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_AudioMedia_getRxLevel(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::AudioMedia *arg1 = (pj::AudioMedia *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  unsigned int result;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__AudioMedia, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "AudioMedia_getRxLevel" "', argument " "1"" of type '" "pj::AudioMedia const *""'"); 
  }
  arg1 = reinterpret_cast< pj::AudioMedia * >(argp1);
  try {
    result = (unsigned int)((pj::AudioMedia const *)arg1)->getRxLevel();
  } catch(pj::Error &_e) {
    SWIG_Python_Raise(SWIG_NewPointerObj((new pj::Error(static_cast< const pj::Error& >(_e))),SWIGTYPE_p_pj__Error,SWIG_POINTER_OWN), "pj::Error", SWIGTYPE_p_pj__Error); SWIG_fail;
  }
  resultobj = SWIG_From_unsigned_SS_int(static_cast< unsigned int >(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_AudioMedia_getTxLevel(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::AudioMedia *arg1 = (pj::AudioMedia *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  unsigned int result;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__AudioMedia, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "AudioMedia_getTxLevel" "', argument " "1"" of type '" "pj::AudioMedia const *""'"); 
  }
  arg1 = reinterpret_cast< pj::AudioMedia * >(argp1);
  try {
    result = (unsigned int)((pj::AudioMedia const *)arg1)->getTxLevel();
  } catch(pj::Error &_e) {
    SWIG_Python_Raise(SWIG_NewPointerObj((new pj::Error(static_cast< const pj::Error& >(_e))),SWIGTYPE_p_pj__Error,SWIG_POINTER_OWN), "pj::Error", SWIGTYPE_p_pj__Error); SWIG_fail;
  }
  resultobj = SWIG_From_unsigned_SS_int(static_cast< unsigned int >(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_AudioMedia_typecastFromMedia(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::Media *arg1 = (pj::Media *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  pj::AudioMedia *result = 0 ;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__Media, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "AudioMedia_typecastFromMedia" "', argument " "1"" of type '" "pj::Media *""'"); 
  }
  arg1 = reinterpret_cast< pj::Media * >(argp1);
  result = (pj::AudioMedia *)pj::AudioMedia::typecastFromMedia(arg1);
  resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(result), SWIGTYPE_p_pj__AudioMedia, 0 |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_new_AudioMedia(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::AudioMedia *result = 0 ;
  
  if (!SWIG_Python_UnpackTuple(args, "new_AudioMedia", 0, 0, 0)) SWIG_fail;
  result = (pj::AudioMedia *)new pj::AudioMedia();
  resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(result), SWIGTYPE_p_pj__AudioMedia, SWIG_POINTER_NEW |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_delete_AudioMedia(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::AudioMedia *arg1 = (pj::AudioMedia *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__AudioMedia, SWIG_POINTER_DISOWN |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "delete_AudioMedia" "', argument " "1"" of type '" "pj::AudioMedia *""'"); 
  }
  arg1 = reinterpret_cast< pj::AudioMedia * >(argp1);
  delete arg1;
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *AudioMedia_swigregister(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *obj;
  if (!SWIG_Python_UnpackTuple(args, "swigregister", 1, 1, &obj)) return NULL;
  SWIG_TypeNewClientData(SWIGTYPE_p_pj__AudioMedia, SWIG_NewClientData(obj));
  return SWIG_Py_Void();
}

SWIGINTERN PyObject *AudioMedia_swiginit(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  return SWIG_Python_InitShadowInstance(args);
}

SWIGINTERN PyObject *_wrap_AudioMediaPlayerInfo_formatId_set(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::AudioMediaPlayerInfo *arg1 = (pj::AudioMediaPlayerInfo *) 0 ;
  pjmedia_format_id arg2 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  int val2 ;
  int ecode2 = 0 ;
  PyObject *swig_obj[2] ;
  
  if (!SWIG_Python_UnpackTuple(args, "AudioMediaPlayerInfo_formatId_set", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__AudioMediaPlayerInfo, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "AudioMediaPlayerInfo_formatId_set" "', argument " "1"" of type '" "pj::AudioMediaPlayerInfo *""'"); 
  }
  arg1 = reinterpret_cast< pj::AudioMediaPlayerInfo * >(argp1);
  ecode2 = SWIG_AsVal_int(swig_obj[1], &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "AudioMediaPlayerInfo_formatId_set" "', argument " "2"" of type '" "pjmedia_format_id""'");
  } 
  arg2 = static_cast< pjmedia_format_id >(val2);
  if (arg1) (arg1)->formatId = arg2;
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_AudioMediaPlayerInfo_formatId_get(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::AudioMediaPlayerInfo *arg1 = (pj::AudioMediaPlayerInfo *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  pjmedia_format_id result;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__AudioMediaPlayerInfo, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "AudioMediaPlayerInfo_formatId_get" "', argument " "1"" of type '" "pj::AudioMediaPlayerInfo *""'"); 
  }
  arg1 = reinterpret_cast< pj::AudioMediaPlayerInfo * >(argp1);
  result = (pjmedia_format_id) ((arg1)->formatId);
  resultobj = SWIG_From_int(static_cast< int >(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_AudioMediaPlayerInfo_payloadBitsPerSample_set(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::AudioMediaPlayerInfo *arg1 = (pj::AudioMediaPlayerInfo *) 0 ;
  unsigned int arg2 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  unsigned int val2 ;
  int ecode2 = 0 ;
  PyObject *swig_obj[2] ;
  
  if (!SWIG_Python_UnpackTuple(args, "AudioMediaPlayerInfo_payloadBitsPerSample_set", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__AudioMediaPlayerInfo, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "AudioMediaPlayerInfo_payloadBitsPerSample_set" "', argument " "1"" of type '" "pj::AudioMediaPlayerInfo *""'"); 
  }
  arg1 = reinterpret_cast< pj::AudioMediaPlayerInfo * >(argp1);
  ecode2 = SWIG_AsVal_unsigned_SS_int(swig_obj[1], &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "AudioMediaPlayerInfo_payloadBitsPerSample_set" "', argument " "2"" of type '" "unsigned int""'");
  } 
  arg2 = static_cast< unsigned int >(val2);
  if (arg1) (arg1)->payloadBitsPerSample = arg2;
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_AudioMediaPlayerInfo_payloadBitsPerSample_get(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::AudioMediaPlayerInfo *arg1 = (pj::AudioMediaPlayerInfo *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  unsigned int result;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__AudioMediaPlayerInfo, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "AudioMediaPlayerInfo_payloadBitsPerSample_get" "', argument " "1"" of type '" "pj::AudioMediaPlayerInfo *""'"); 
  }
  arg1 = reinterpret_cast< pj::AudioMediaPlayerInfo * >(argp1);
  result = (unsigned int) ((arg1)->payloadBitsPerSample);
  resultobj = SWIG_From_unsigned_SS_int(static_cast< unsigned int >(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_AudioMediaPlayerInfo_sizeBytes_set(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::AudioMediaPlayerInfo *arg1 = (pj::AudioMediaPlayerInfo *) 0 ;
  pj_uint32_t arg2 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  unsigned int val2 ;
  int ecode2 = 0 ;
  PyObject *swig_obj[2] ;
  
  if (!SWIG_Python_UnpackTuple(args, "AudioMediaPlayerInfo_sizeBytes_set", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__AudioMediaPlayerInfo, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "AudioMediaPlayerInfo_sizeBytes_set" "', argument " "1"" of type '" "pj::AudioMediaPlayerInfo *""'"); 
  }
  arg1 = reinterpret_cast< pj::AudioMediaPlayerInfo * >(argp1);
  ecode2 = SWIG_AsVal_unsigned_SS_int(swig_obj[1], &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "AudioMediaPlayerInfo_sizeBytes_set" "', argument " "2"" of type '" "pj_uint32_t""'");
  } 
  arg2 = static_cast< pj_uint32_t >(val2);
  if (arg1) (arg1)->sizeBytes = arg2;
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_AudioMediaPlayerInfo_sizeBytes_get(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::AudioMediaPlayerInfo *arg1 = (pj::AudioMediaPlayerInfo *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  pj_uint32_t result;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__AudioMediaPlayerInfo, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "AudioMediaPlayerInfo_sizeBytes_get" "', argument " "1"" of type '" "pj::AudioMediaPlayerInfo *""'"); 
  }
  arg1 = reinterpret_cast< pj::AudioMediaPlayerInfo * >(argp1);
  result = (pj_uint32_t) ((arg1)->sizeBytes);
  resultobj = SWIG_From_unsigned_SS_int(static_cast< unsigned int >(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_AudioMediaPlayerInfo_sizeSamples_set(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::AudioMediaPlayerInfo *arg1 = (pj::AudioMediaPlayerInfo *) 0 ;
  pj_uint32_t arg2 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  unsigned int val2 ;
  int ecode2 = 0 ;
  PyObject *swig_obj[2] ;
  
  if (!SWIG_Python_UnpackTuple(args, "AudioMediaPlayerInfo_sizeSamples_set", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__AudioMediaPlayerInfo, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "AudioMediaPlayerInfo_sizeSamples_set" "', argument " "1"" of type '" "pj::AudioMediaPlayerInfo *""'"); 
  }
  arg1 = reinterpret_cast< pj::AudioMediaPlayerInfo * >(argp1);
  ecode2 = SWIG_AsVal_unsigned_SS_int(swig_obj[1], &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "AudioMediaPlayerInfo_sizeSamples_set" "', argument " "2"" of type '" "pj_uint32_t""'");
  } 
  arg2 = static_cast< pj_uint32_t >(val2);
  if (arg1) (arg1)->sizeSamples = arg2;
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_AudioMediaPlayerInfo_sizeSamples_get(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::AudioMediaPlayerInfo *arg1 = (pj::AudioMediaPlayerInfo *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  pj_uint32_t result;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__AudioMediaPlayerInfo, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "AudioMediaPlayerInfo_sizeSamples_get" "', argument " "1"" of type '" "pj::AudioMediaPlayerInfo *""'"); 
  }
  arg1 = reinterpret_cast< pj::AudioMediaPlayerInfo * >(argp1);
  result = (pj_uint32_t) ((arg1)->sizeSamples);
  resultobj = SWIG_From_unsigned_SS_int(static_cast< unsigned int >(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_new_AudioMediaPlayerInfo(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::AudioMediaPlayerInfo *result = 0 ;
  
  if (!SWIG_Python_UnpackTuple(args, "new_AudioMediaPlayerInfo", 0, 0, 0)) SWIG_fail;
  result = (pj::AudioMediaPlayerInfo *)new pj::AudioMediaPlayerInfo();
  resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(result), SWIGTYPE_p_pj__AudioMediaPlayerInfo, SWIG_POINTER_NEW |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_delete_AudioMediaPlayerInfo(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::AudioMediaPlayerInfo *arg1 = (pj::AudioMediaPlayerInfo *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__AudioMediaPlayerInfo, SWIG_POINTER_DISOWN |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "delete_AudioMediaPlayerInfo" "', argument " "1"" of type '" "pj::AudioMediaPlayerInfo *""'"); 
  }
  arg1 = reinterpret_cast< pj::AudioMediaPlayerInfo * >(argp1);
  delete arg1;
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *AudioMediaPlayerInfo_swigregister(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *obj;
  if (!SWIG_Python_UnpackTuple(args, "swigregister", 1, 1, &obj)) return NULL;
  SWIG_TypeNewClientData(SWIGTYPE_p_pj__AudioMediaPlayerInfo, SWIG_NewClientData(obj));
  return SWIG_Py_Void();
}

SWIGINTERN PyObject *AudioMediaPlayerInfo_swiginit(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  return SWIG_Python_InitShadowInstance(args);
}

SWIGINTERN PyObject *_wrap_new_AudioMediaPlayer(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  PyObject *arg1 = (PyObject *) 0 ;
  PyObject *swig_obj[1] ;
  pj::AudioMediaPlayer *result = 0 ;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  arg1 = swig_obj[0];
  if ( arg1 != Py_None ) {
    /* subclassed */
    result = (pj::AudioMediaPlayer *)new SwigDirector_AudioMediaPlayer(arg1); 
  } else {
    result = (pj::AudioMediaPlayer *)new pj::AudioMediaPlayer(); 
  }
  
  resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(result), SWIGTYPE_p_pj__AudioMediaPlayer, SWIG_POINTER_NEW |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_AudioMediaPlayer_createPlayer__SWIG_0(PyObject *SWIGUNUSEDPARM(self), Py_ssize_t nobjs, PyObject **swig_obj) {
  PyObject *resultobj = 0;
  pj::AudioMediaPlayer *arg1 = (pj::AudioMediaPlayer *) 0 ;
  pj::string *arg2 = 0 ;
  unsigned int arg3 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  int res2 = SWIG_OLDOBJ ;
  unsigned int val3 ;
  int ecode3 = 0 ;
  
  if ((nobjs < 3) || (nobjs > 3)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__AudioMediaPlayer, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "AudioMediaPlayer_createPlayer" "', argument " "1"" of type '" "pj::AudioMediaPlayer *""'"); 
  }
  arg1 = reinterpret_cast< pj::AudioMediaPlayer * >(argp1);
  {
    std::string *ptr = (std::string *)0;
    res2 = SWIG_AsPtr_std_string(swig_obj[1], &ptr);
    if (!SWIG_IsOK(res2)) {
      SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "AudioMediaPlayer_createPlayer" "', argument " "2"" of type '" "pj::string const &""'"); 
    }
    if (!ptr) {
      SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "AudioMediaPlayer_createPlayer" "', argument " "2"" of type '" "pj::string const &""'"); 
    }
    arg2 = ptr;
  }
  ecode3 = SWIG_AsVal_unsigned_SS_int(swig_obj[2], &val3);
  if (!SWIG_IsOK(ecode3)) {
    SWIG_exception_fail(SWIG_ArgError(ecode3), "in method '" "AudioMediaPlayer_createPlayer" "', argument " "3"" of type '" "unsigned int""'");
  } 
  arg3 = static_cast< unsigned int >(val3);
  try {
    (arg1)->createPlayer((pj::string const &)*arg2,arg3);
  } catch(pj::Error &_e) {
    SWIG_Python_Raise(SWIG_NewPointerObj((new pj::Error(static_cast< const pj::Error& >(_e))),SWIGTYPE_p_pj__Error,SWIG_POINTER_OWN), "pj::Error", SWIGTYPE_p_pj__Error); SWIG_fail;
  }
  resultobj = SWIG_Py_Void();
  if (SWIG_IsNewObj(res2)) delete arg2;
  return resultobj;
fail:
  if (SWIG_IsNewObj(res2)) delete arg2;
  return NULL;
}


SWIGINTERN PyObject *_wrap_AudioMediaPlayer_createPlayer__SWIG_1(PyObject *SWIGUNUSEDPARM(self), Py_ssize_t nobjs, PyObject **swig_obj) {
  PyObject *resultobj = 0;
  pj::AudioMediaPlayer *arg1 = (pj::AudioMediaPlayer *) 0 ;
  pj::string *arg2 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  int res2 = SWIG_OLDOBJ ;
  
  if ((nobjs < 2) || (nobjs > 2)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__AudioMediaPlayer, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "AudioMediaPlayer_createPlayer" "', argument " "1"" of type '" "pj::AudioMediaPlayer *""'"); 
  }
  arg1 = reinterpret_cast< pj::AudioMediaPlayer * >(argp1);
  {
    std::string *ptr = (std::string *)0;
    res2 = SWIG_AsPtr_std_string(swig_obj[1], &ptr);
    if (!SWIG_IsOK(res2)) {
      SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "AudioMediaPlayer_createPlayer" "', argument " "2"" of type '" "pj::string const &""'"); 
    }
    if (!ptr) {
      SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "AudioMediaPlayer_createPlayer" "', argument " "2"" of type '" "pj::string const &""'"); 
    }
    arg2 = ptr;
  }
  try {
    (arg1)->createPlayer((pj::string const &)*arg2);
  } catch(pj::Error &_e) {
    SWIG_Python_Raise(SWIG_NewPointerObj((new pj::Error(static_cast< const pj::Error& >(_e))),SWIGTYPE_p_pj__Error,SWIG_POINTER_OWN), "pj::Error", SWIGTYPE_p_pj__Error); SWIG_fail;
  }
  resultobj = SWIG_Py_Void();
  if (SWIG_IsNewObj(res2)) delete arg2;
  return resultobj;
fail:
  if (SWIG_IsNewObj(res2)) delete arg2;
  return NULL;
}


SWIGINTERN PyObject *_wrap_AudioMediaPlayer_createPlayer(PyObject *self, PyObject *args) {
  Py_ssize_t argc;
  PyObject *argv[4] = {
    0
  };
  
  if (!(argc = SWIG_Python_UnpackTuple(args, "AudioMediaPlayer_createPlayer", 0, 3, argv))) SWIG_fail;
  --argc;
  if (argc == 2) {
    int _v;
    void *vptr = 0;
    int res = SWIG_ConvertPtr(argv[0], &vptr, SWIGTYPE_p_pj__AudioMediaPlayer, 0);
    _v = SWIG_CheckState(res);
    if (_v) {
      int res = SWIG_AsPtr_std_string(argv[1], (std::string**)(0));
      _v = SWIG_CheckState(res);
      if (_v) {
        return _wrap_AudioMediaPlayer_createPlayer__SWIG_1(self, argc, argv);
      }
    }
  }
  if (argc == 3) {
    int _v;
    void *vptr = 0;
    int res = SWIG_ConvertPtr(argv[0], &vptr, SWIGTYPE_p_pj__AudioMediaPlayer, 0);
    _v = SWIG_CheckState(res);
    if (_v) {
      int res = SWIG_AsPtr_std_string(argv[1], (std::string**)(0));
      _v = SWIG_CheckState(res);
      if (_v) {
        {
          int res = SWIG_AsVal_unsigned_SS_int(argv[2], NULL);
          _v = SWIG_CheckState(res);
        }
        if (_v) {
          return _wrap_AudioMediaPlayer_createPlayer__SWIG_0(self, argc, argv);
        }
      }
    }
  }
  
fail:
  SWIG_Python_RaiseOrModifyTypeError("Wrong number or type of arguments for overloaded function 'AudioMediaPlayer_createPlayer'.\n"
    "  Possible C/C++ prototypes are:\n"
    "    pj::AudioMediaPlayer::createPlayer(pj::string const &,unsigned int)\n"
    "    pj::AudioMediaPlayer::createPlayer(pj::string const &)\n");
  return 0;
}


SWIGINTERN PyObject *_wrap_AudioMediaPlayer_createPlaylist__SWIG_0(PyObject *SWIGUNUSEDPARM(self), Py_ssize_t nobjs, PyObject **swig_obj) {
  PyObject *resultobj = 0;
  pj::AudioMediaPlayer *arg1 = (pj::AudioMediaPlayer *) 0 ;
  pj::StringVector *arg2 = 0 ;
  pj::string *arg3 = 0 ;
  unsigned int arg4 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  int res2 = SWIG_OLDOBJ ;
  int res3 = SWIG_OLDOBJ ;
  unsigned int val4 ;
  int ecode4 = 0 ;
  
  if ((nobjs < 4) || (nobjs > 4)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__AudioMediaPlayer, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "AudioMediaPlayer_createPlaylist" "', argument " "1"" of type '" "pj::AudioMediaPlayer *""'"); 
  }
  arg1 = reinterpret_cast< pj::AudioMediaPlayer * >(argp1);
  {
    std::vector< std::string,std::allocator< std::string > > *ptr = (std::vector< std::string,std::allocator< std::string > > *)0;
    res2 = swig::asptr(swig_obj[1], &ptr);
    if (!SWIG_IsOK(res2)) {
      SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "AudioMediaPlayer_createPlaylist" "', argument " "2"" of type '" "pj::StringVector const &""'"); 
    }
    if (!ptr) {
      SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "AudioMediaPlayer_createPlaylist" "', argument " "2"" of type '" "pj::StringVector const &""'"); 
    }
    arg2 = ptr;
  }
  {
    std::string *ptr = (std::string *)0;
    res3 = SWIG_AsPtr_std_string(swig_obj[2], &ptr);
    if (!SWIG_IsOK(res3)) {
      SWIG_exception_fail(SWIG_ArgError(res3), "in method '" "AudioMediaPlayer_createPlaylist" "', argument " "3"" of type '" "pj::string const &""'"); 
    }
    if (!ptr) {
      SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "AudioMediaPlayer_createPlaylist" "', argument " "3"" of type '" "pj::string const &""'"); 
    }
    arg3 = ptr;
  }
  ecode4 = SWIG_AsVal_unsigned_SS_int(swig_obj[3], &val4);
  if (!SWIG_IsOK(ecode4)) {
    SWIG_exception_fail(SWIG_ArgError(ecode4), "in method '" "AudioMediaPlayer_createPlaylist" "', argument " "4"" of type '" "unsigned int""'");
  } 
  arg4 = static_cast< unsigned int >(val4);
  try {
    (arg1)->createPlaylist((pj::StringVector const &)*arg2,(pj::string const &)*arg3,arg4);
  } catch(pj::Error &_e) {
    SWIG_Python_Raise(SWIG_NewPointerObj((new pj::Error(static_cast< const pj::Error& >(_e))),SWIGTYPE_p_pj__Error,SWIG_POINTER_OWN), "pj::Error", SWIGTYPE_p_pj__Error); SWIG_fail;
  }
  resultobj = SWIG_Py_Void();
  if (SWIG_IsNewObj(res2)) delete arg2;
  if (SWIG_IsNewObj(res3)) delete arg3;
  return resultobj;
fail:
  if (SWIG_IsNewObj(res2)) delete arg2;
  if (SWIG_IsNewObj(res3)) delete arg3;
  return NULL;
}


SWIGINTERN PyObject *_wrap_AudioMediaPlayer_createPlaylist__SWIG_1(PyObject *SWIGUNUSEDPARM(self), Py_ssize_t nobjs, PyObject **swig_obj) {
  PyObject *resultobj = 0;
  pj::AudioMediaPlayer *arg1 = (pj::AudioMediaPlayer *) 0 ;
  pj::StringVector *arg2 = 0 ;
  pj::string *arg3 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  int res2 = SWIG_OLDOBJ ;
  int res3 = SWIG_OLDOBJ ;
  
  if ((nobjs < 3) || (nobjs > 3)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__AudioMediaPlayer, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "AudioMediaPlayer_createPlaylist" "', argument " "1"" of type '" "pj::AudioMediaPlayer *""'"); 
  }
  arg1 = reinterpret_cast< pj::AudioMediaPlayer * >(argp1);
  {
    std::vector< std::string,std::allocator< std::string > > *ptr = (std::vector< std::string,std::allocator< std::string > > *)0;
    res2 = swig::asptr(swig_obj[1], &ptr);
    if (!SWIG_IsOK(res2)) {
      SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "AudioMediaPlayer_createPlaylist" "', argument " "2"" of type '" "pj::StringVector const &""'"); 
    }
    if (!ptr) {
      SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "AudioMediaPlayer_createPlaylist" "', argument " "2"" of type '" "pj::StringVector const &""'"); 
    }
    arg2 = ptr;
  }
  {
    std::string *ptr = (std::string *)0;
    res3 = SWIG_AsPtr_std_string(swig_obj[2], &ptr);
    if (!SWIG_IsOK(res3)) {
      SWIG_exception_fail(SWIG_ArgError(res3), "in method '" "AudioMediaPlayer_createPlaylist" "', argument " "3"" of type '" "pj::string const &""'"); 
    }
    if (!ptr) {
      SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "AudioMediaPlayer_createPlaylist" "', argument " "3"" of type '" "pj::string const &""'"); 
    }
    arg3 = ptr;
  }
  try {
    (arg1)->createPlaylist((pj::StringVector const &)*arg2,(pj::string const &)*arg3);
  } catch(pj::Error &_e) {
    SWIG_Python_Raise(SWIG_NewPointerObj((new pj::Error(static_cast< const pj::Error& >(_e))),SWIGTYPE_p_pj__Error,SWIG_POINTER_OWN), "pj::Error", SWIGTYPE_p_pj__Error); SWIG_fail;
  }
  resultobj = SWIG_Py_Void();
  if (SWIG_IsNewObj(res2)) delete arg2;
  if (SWIG_IsNewObj(res3)) delete arg3;
  return resultobj;
fail:
  if (SWIG_IsNewObj(res2)) delete arg2;
  if (SWIG_IsNewObj(res3)) delete arg3;
  return NULL;
}


SWIGINTERN PyObject *_wrap_AudioMediaPlayer_createPlaylist__SWIG_2(PyObject *SWIGUNUSEDPARM(self), Py_ssize_t nobjs, PyObject **swig_obj) {
  PyObject *resultobj = 0;
  pj::AudioMediaPlayer *arg1 = (pj::AudioMediaPlayer *) 0 ;
  pj::StringVector *arg2 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  int res2 = SWIG_OLDOBJ ;
  
  if ((nobjs < 2) || (nobjs > 2)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__AudioMediaPlayer, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "AudioMediaPlayer_createPlaylist" "', argument " "1"" of type '" "pj::AudioMediaPlayer *""'"); 
  }
  arg1 = reinterpret_cast< pj::AudioMediaPlayer * >(argp1);
  {
    std::vector< std::string,std::allocator< std::string > > *ptr = (std::vector< std::string,std::allocator< std::string > > *)0;
    res2 = swig::asptr(swig_obj[1], &ptr);
    if (!SWIG_IsOK(res2)) {
      SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "AudioMediaPlayer_createPlaylist" "', argument " "2"" of type '" "pj::StringVector const &""'"); 
    }
    if (!ptr) {
      SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "AudioMediaPlayer_createPlaylist" "', argument " "2"" of type '" "pj::StringVector const &""'"); 
    }
    arg2 = ptr;
  }
  try {
    (arg1)->createPlaylist((pj::StringVector const &)*arg2);
  } catch(pj::Error &_e) {
    SWIG_Python_Raise(SWIG_NewPointerObj((new pj::Error(static_cast< const pj::Error& >(_e))),SWIGTYPE_p_pj__Error,SWIG_POINTER_OWN), "pj::Error", SWIGTYPE_p_pj__Error); SWIG_fail;
  }
  resultobj = SWIG_Py_Void();
  if (SWIG_IsNewObj(res2)) delete arg2;
  return resultobj;
fail:
  if (SWIG_IsNewObj(res2)) delete arg2;
  return NULL;
}


SWIGINTERN PyObject *_wrap_AudioMediaPlayer_createPlaylist(PyObject *self, PyObject *args) {
  Py_ssize_t argc;
  PyObject *argv[5] = {
    0
  };
  
  if (!(argc = SWIG_Python_UnpackTuple(args, "AudioMediaPlayer_createPlaylist", 0, 4, argv))) SWIG_fail;
  --argc;
  if (argc == 2) {
    int _v;
    void *vptr = 0;
    int res = SWIG_ConvertPtr(argv[0], &vptr, SWIGTYPE_p_pj__AudioMediaPlayer, 0);
    _v = SWIG_CheckState(res);
    if (_v) {
      int res = swig::asptr(argv[1], (std::vector< std::string,std::allocator< std::string > >**)(0));
      _v = SWIG_CheckState(res);
      if (_v) {
        return _wrap_AudioMediaPlayer_createPlaylist__SWIG_2(self, argc, argv);
      }
    }
  }
  if (argc == 3) {
    int _v;
    void *vptr = 0;
    int res = SWIG_ConvertPtr(argv[0], &vptr, SWIGTYPE_p_pj__AudioMediaPlayer, 0);
    _v = SWIG_CheckState(res);
    if (_v) {
      int res = swig::asptr(argv[1], (std::vector< std::string,std::allocator< std::string > >**)(0));
      _v = SWIG_CheckState(res);
      if (_v) {
        int res = SWIG_AsPtr_std_string(argv[2], (std::string**)(0));
        _v = SWIG_CheckState(res);
        if (_v) {
          return _wrap_AudioMediaPlayer_createPlaylist__SWIG_1(self, argc, argv);
        }
      }
    }
  }
  if (argc == 4) {
    int _v;
    void *vptr = 0;
    int res = SWIG_ConvertPtr(argv[0], &vptr, SWIGTYPE_p_pj__AudioMediaPlayer, 0);
    _v = SWIG_CheckState(res);
    if (_v) {
      int res = swig::asptr(argv[1], (std::vector< std::string,std::allocator< std::string > >**)(0));
      _v = SWIG_CheckState(res);
      if (_v) {
        int res = SWIG_AsPtr_std_string(argv[2], (std::string**)(0));
        _v = SWIG_CheckState(res);
        if (_v) {
          {
            int res = SWIG_AsVal_unsigned_SS_int(argv[3], NULL);
            _v = SWIG_CheckState(res);
          }
          if (_v) {
            return _wrap_AudioMediaPlayer_createPlaylist__SWIG_0(self, argc, argv);
          }
        }
      }
    }
  }
  
fail:
  SWIG_Python_RaiseOrModifyTypeError("Wrong number or type of arguments for overloaded function 'AudioMediaPlayer_createPlaylist'.\n"
    "  Possible C/C++ prototypes are:\n"
    "    pj::AudioMediaPlayer::createPlaylist(pj::StringVector const &,pj::string const &,unsigned int)\n"
    "    pj::AudioMediaPlayer::createPlaylist(pj::StringVector const &,pj::string const &)\n"
    "    pj::AudioMediaPlayer::createPlaylist(pj::StringVector const &)\n");
  return 0;
}


SWIGINTERN PyObject *_wrap_AudioMediaPlayer_getInfo(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::AudioMediaPlayer *arg1 = (pj::AudioMediaPlayer *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  pj::AudioMediaPlayerInfo result;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__AudioMediaPlayer, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "AudioMediaPlayer_getInfo" "', argument " "1"" of type '" "pj::AudioMediaPlayer const *""'"); 
  }
  arg1 = reinterpret_cast< pj::AudioMediaPlayer * >(argp1);
  try {
    result = ((pj::AudioMediaPlayer const *)arg1)->getInfo();
  } catch(pj::Error &_e) {
    SWIG_Python_Raise(SWIG_NewPointerObj((new pj::Error(static_cast< const pj::Error& >(_e))),SWIGTYPE_p_pj__Error,SWIG_POINTER_OWN), "pj::Error", SWIGTYPE_p_pj__Error); SWIG_fail;
  }
  resultobj = SWIG_NewPointerObj((new pj::AudioMediaPlayerInfo(static_cast< const pj::AudioMediaPlayerInfo& >(result))), SWIGTYPE_p_pj__AudioMediaPlayerInfo, SWIG_POINTER_OWN |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_AudioMediaPlayer_getPos(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::AudioMediaPlayer *arg1 = (pj::AudioMediaPlayer *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  pj_uint32_t result;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__AudioMediaPlayer, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "AudioMediaPlayer_getPos" "', argument " "1"" of type '" "pj::AudioMediaPlayer const *""'"); 
  }
  arg1 = reinterpret_cast< pj::AudioMediaPlayer * >(argp1);
  try {
    result = (pj_uint32_t)((pj::AudioMediaPlayer const *)arg1)->getPos();
  } catch(pj::Error &_e) {
    SWIG_Python_Raise(SWIG_NewPointerObj((new pj::Error(static_cast< const pj::Error& >(_e))),SWIGTYPE_p_pj__Error,SWIG_POINTER_OWN), "pj::Error", SWIGTYPE_p_pj__Error); SWIG_fail;
  }
  resultobj = SWIG_From_unsigned_SS_int(static_cast< unsigned int >(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_AudioMediaPlayer_setPos(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::AudioMediaPlayer *arg1 = (pj::AudioMediaPlayer *) 0 ;
  pj_uint32_t arg2 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  unsigned int val2 ;
  int ecode2 = 0 ;
  PyObject *swig_obj[2] ;
  
  if (!SWIG_Python_UnpackTuple(args, "AudioMediaPlayer_setPos", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__AudioMediaPlayer, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "AudioMediaPlayer_setPos" "', argument " "1"" of type '" "pj::AudioMediaPlayer *""'"); 
  }
  arg1 = reinterpret_cast< pj::AudioMediaPlayer * >(argp1);
  ecode2 = SWIG_AsVal_unsigned_SS_int(swig_obj[1], &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "AudioMediaPlayer_setPos" "', argument " "2"" of type '" "pj_uint32_t""'");
  } 
  arg2 = static_cast< pj_uint32_t >(val2);
  try {
    (arg1)->setPos(arg2);
  } catch(pj::Error &_e) {
    SWIG_Python_Raise(SWIG_NewPointerObj((new pj::Error(static_cast< const pj::Error& >(_e))),SWIGTYPE_p_pj__Error,SWIG_POINTER_OWN), "pj::Error", SWIGTYPE_p_pj__Error); SWIG_fail;
  }
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_AudioMediaPlayer_typecastFromAudioMedia(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::AudioMedia *arg1 = (pj::AudioMedia *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  Swig::Director *director = 0;
  pj::AudioMediaPlayer *result = 0 ;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__AudioMedia, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "AudioMediaPlayer_typecastFromAudioMedia" "', argument " "1"" of type '" "pj::AudioMedia *""'"); 
  }
  arg1 = reinterpret_cast< pj::AudioMedia * >(argp1);
  result = (pj::AudioMediaPlayer *)pj::AudioMediaPlayer::typecastFromAudioMedia(arg1);
  director = SWIG_DIRECTOR_CAST(result);
  if (director) {
    resultobj = director->swig_get_self();
    Py_INCREF(resultobj);
  } else {
    resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(result), SWIGTYPE_p_pj__AudioMediaPlayer, 0 |  0 );
  }
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_delete_AudioMediaPlayer(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::AudioMediaPlayer *arg1 = (pj::AudioMediaPlayer *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__AudioMediaPlayer, SWIG_POINTER_DISOWN |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "delete_AudioMediaPlayer" "', argument " "1"" of type '" "pj::AudioMediaPlayer *""'"); 
  }
  arg1 = reinterpret_cast< pj::AudioMediaPlayer * >(argp1);
  delete arg1;
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_AudioMediaPlayer_onEof2(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::AudioMediaPlayer *arg1 = (pj::AudioMediaPlayer *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  Swig::Director *director = 0;
  bool upcall = false;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__AudioMediaPlayer, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "AudioMediaPlayer_onEof2" "', argument " "1"" of type '" "pj::AudioMediaPlayer *""'"); 
  }
  arg1 = reinterpret_cast< pj::AudioMediaPlayer * >(argp1);
  director = SWIG_DIRECTOR_CAST(arg1);
  upcall = (director && (director->swig_get_self()==swig_obj[0]));
  try {
    if (upcall) {
      (arg1)->pj::AudioMediaPlayer::onEof2();
    } else {
      (arg1)->onEof2();
    }
  } catch (Swig::DirectorException&) {
    SWIG_fail;
  }
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_disown_AudioMediaPlayer(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::AudioMediaPlayer *arg1 = (pj::AudioMediaPlayer *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__AudioMediaPlayer, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "disown_AudioMediaPlayer" "', argument " "1"" of type '" "pj::AudioMediaPlayer *""'"); 
  }
  arg1 = reinterpret_cast< pj::AudioMediaPlayer * >(argp1);
  {
    Swig::Director *director = SWIG_DIRECTOR_CAST(arg1);
    if (director) director->swig_disown();
  }
  
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *AudioMediaPlayer_swigregister(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *obj;
  if (!SWIG_Python_UnpackTuple(args, "swigregister", 1, 1, &obj)) return NULL;
  SWIG_TypeNewClientData(SWIGTYPE_p_pj__AudioMediaPlayer, SWIG_NewClientData(obj));
  return SWIG_Py_Void();
}

SWIGINTERN PyObject *AudioMediaPlayer_swiginit(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  return SWIG_Python_InitShadowInstance(args);
}

SWIGINTERN PyObject *_wrap_new_AudioMediaRecorder(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::AudioMediaRecorder *result = 0 ;
  
  if (!SWIG_Python_UnpackTuple(args, "new_AudioMediaRecorder", 0, 0, 0)) SWIG_fail;
  result = (pj::AudioMediaRecorder *)new pj::AudioMediaRecorder();
  resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(result), SWIGTYPE_p_pj__AudioMediaRecorder, SWIG_POINTER_NEW |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_AudioMediaRecorder_createRecorder__SWIG_0(PyObject *SWIGUNUSEDPARM(self), Py_ssize_t nobjs, PyObject **swig_obj) {
  PyObject *resultobj = 0;
  pj::AudioMediaRecorder *arg1 = (pj::AudioMediaRecorder *) 0 ;
  pj::string *arg2 = 0 ;
  unsigned int arg3 ;
  long arg4 ;
  unsigned int arg5 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  int res2 = SWIG_OLDOBJ ;
  unsigned int val3 ;
  int ecode3 = 0 ;
  long val4 ;
  int ecode4 = 0 ;
  unsigned int val5 ;
  int ecode5 = 0 ;
  
  if ((nobjs < 5) || (nobjs > 5)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__AudioMediaRecorder, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "AudioMediaRecorder_createRecorder" "', argument " "1"" of type '" "pj::AudioMediaRecorder *""'"); 
  }
  arg1 = reinterpret_cast< pj::AudioMediaRecorder * >(argp1);
  {
    std::string *ptr = (std::string *)0;
    res2 = SWIG_AsPtr_std_string(swig_obj[1], &ptr);
    if (!SWIG_IsOK(res2)) {
      SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "AudioMediaRecorder_createRecorder" "', argument " "2"" of type '" "pj::string const &""'"); 
    }
    if (!ptr) {
      SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "AudioMediaRecorder_createRecorder" "', argument " "2"" of type '" "pj::string const &""'"); 
    }
    arg2 = ptr;
  }
  ecode3 = SWIG_AsVal_unsigned_SS_int(swig_obj[2], &val3);
  if (!SWIG_IsOK(ecode3)) {
    SWIG_exception_fail(SWIG_ArgError(ecode3), "in method '" "AudioMediaRecorder_createRecorder" "', argument " "3"" of type '" "unsigned int""'");
  } 
  arg3 = static_cast< unsigned int >(val3);
  ecode4 = SWIG_AsVal_long(swig_obj[3], &val4);
  if (!SWIG_IsOK(ecode4)) {
    SWIG_exception_fail(SWIG_ArgError(ecode4), "in method '" "AudioMediaRecorder_createRecorder" "', argument " "4"" of type '" "long""'");
  } 
  arg4 = static_cast< long >(val4);
  ecode5 = SWIG_AsVal_unsigned_SS_int(swig_obj[4], &val5);
  if (!SWIG_IsOK(ecode5)) {
    SWIG_exception_fail(SWIG_ArgError(ecode5), "in method '" "AudioMediaRecorder_createRecorder" "', argument " "5"" of type '" "unsigned int""'");
  } 
  arg5 = static_cast< unsigned int >(val5);
  try {
    (arg1)->createRecorder((pj::string const &)*arg2,arg3,arg4,arg5);
  } catch(pj::Error &_e) {
    SWIG_Python_Raise(SWIG_NewPointerObj((new pj::Error(static_cast< const pj::Error& >(_e))),SWIGTYPE_p_pj__Error,SWIG_POINTER_OWN), "pj::Error", SWIGTYPE_p_pj__Error); SWIG_fail;
  }
  resultobj = SWIG_Py_Void();
  if (SWIG_IsNewObj(res2)) delete arg2;
  return resultobj;
fail:
  if (SWIG_IsNewObj(res2)) delete arg2;
  return NULL;
}


SWIGINTERN PyObject *_wrap_AudioMediaRecorder_createRecorder__SWIG_1(PyObject *SWIGUNUSEDPARM(self), Py_ssize_t nobjs, PyObject **swig_obj) {
  PyObject *resultobj = 0;
  pj::AudioMediaRecorder *arg1 = (pj::AudioMediaRecorder *) 0 ;
  pj::string *arg2 = 0 ;
  unsigned int arg3 ;
  long arg4 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  int res2 = SWIG_OLDOBJ ;
  unsigned int val3 ;
  int ecode3 = 0 ;
  long val4 ;
  int ecode4 = 0 ;
  
  if ((nobjs < 4) || (nobjs > 4)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__AudioMediaRecorder, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "AudioMediaRecorder_createRecorder" "', argument " "1"" of type '" "pj::AudioMediaRecorder *""'"); 
  }
  arg1 = reinterpret_cast< pj::AudioMediaRecorder * >(argp1);
  {
    std::string *ptr = (std::string *)0;
    res2 = SWIG_AsPtr_std_string(swig_obj[1], &ptr);
    if (!SWIG_IsOK(res2)) {
      SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "AudioMediaRecorder_createRecorder" "', argument " "2"" of type '" "pj::string const &""'"); 
    }
    if (!ptr) {
      SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "AudioMediaRecorder_createRecorder" "', argument " "2"" of type '" "pj::string const &""'"); 
    }
    arg2 = ptr;
  }
  ecode3 = SWIG_AsVal_unsigned_SS_int(swig_obj[2], &val3);
  if (!SWIG_IsOK(ecode3)) {
    SWIG_exception_fail(SWIG_ArgError(ecode3), "in method '" "AudioMediaRecorder_createRecorder" "', argument " "3"" of type '" "unsigned int""'");
  } 
  arg3 = static_cast< unsigned int >(val3);
  ecode4 = SWIG_AsVal_long(swig_obj[3], &val4);
  if (!SWIG_IsOK(ecode4)) {
    SWIG_exception_fail(SWIG_ArgError(ecode4), "in method '" "AudioMediaRecorder_createRecorder" "', argument " "4"" of type '" "long""'");
  } 
  arg4 = static_cast< long >(val4);
  try {
    (arg1)->createRecorder((pj::string const &)*arg2,arg3,arg4);
  } catch(pj::Error &_e) {
    SWIG_Python_Raise(SWIG_NewPointerObj((new pj::Error(static_cast< const pj::Error& >(_e))),SWIGTYPE_p_pj__Error,SWIG_POINTER_OWN), "pj::Error", SWIGTYPE_p_pj__Error); SWIG_fail;
  }
  resultobj = SWIG_Py_Void();
  if (SWIG_IsNewObj(res2)) delete arg2;
  return resultobj;
fail:
  if (SWIG_IsNewObj(res2)) delete arg2;
  return NULL;
}


SWIGINTERN PyObject *_wrap_AudioMediaRecorder_createRecorder__SWIG_2(PyObject *SWIGUNUSEDPARM(self), Py_ssize_t nobjs, PyObject **swig_obj) {
  PyObject *resultobj = 0;
  pj::AudioMediaRecorder *arg1 = (pj::AudioMediaRecorder *) 0 ;
  pj::string *arg2 = 0 ;
  unsigned int arg3 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  int res2 = SWIG_OLDOBJ ;
  unsigned int val3 ;
  int ecode3 = 0 ;
  
  if ((nobjs < 3) || (nobjs > 3)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__AudioMediaRecorder, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "AudioMediaRecorder_createRecorder" "', argument " "1"" of type '" "pj::AudioMediaRecorder *""'"); 
  }
  arg1 = reinterpret_cast< pj::AudioMediaRecorder * >(argp1);
  {
    std::string *ptr = (std::string *)0;
    res2 = SWIG_AsPtr_std_string(swig_obj[1], &ptr);
    if (!SWIG_IsOK(res2)) {
      SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "AudioMediaRecorder_createRecorder" "', argument " "2"" of type '" "pj::string const &""'"); 
    }
    if (!ptr) {
      SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "AudioMediaRecorder_createRecorder" "', argument " "2"" of type '" "pj::string const &""'"); 
    }
    arg2 = ptr;
  }
  ecode3 = SWIG_AsVal_unsigned_SS_int(swig_obj[2], &val3);
  if (!SWIG_IsOK(ecode3)) {
    SWIG_exception_fail(SWIG_ArgError(ecode3), "in method '" "AudioMediaRecorder_createRecorder" "', argument " "3"" of type '" "unsigned int""'");
  } 
  arg3 = static_cast< unsigned int >(val3);
  try {
    (arg1)->createRecorder((pj::string const &)*arg2,arg3);
  } catch(pj::Error &_e) {
    SWIG_Python_Raise(SWIG_NewPointerObj((new pj::Error(static_cast< const pj::Error& >(_e))),SWIGTYPE_p_pj__Error,SWIG_POINTER_OWN), "pj::Error", SWIGTYPE_p_pj__Error); SWIG_fail;
  }
  resultobj = SWIG_Py_Void();
  if (SWIG_IsNewObj(res2)) delete arg2;
  return resultobj;
fail:
  if (SWIG_IsNewObj(res2)) delete arg2;
  return NULL;
}


SWIGINTERN PyObject *_wrap_AudioMediaRecorder_createRecorder__SWIG_3(PyObject *SWIGUNUSEDPARM(self), Py_ssize_t nobjs, PyObject **swig_obj) {
  PyObject *resultobj = 0;
  pj::AudioMediaRecorder *arg1 = (pj::AudioMediaRecorder *) 0 ;
  pj::string *arg2 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  int res2 = SWIG_OLDOBJ ;
  
  if ((nobjs < 2) || (nobjs > 2)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__AudioMediaRecorder, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "AudioMediaRecorder_createRecorder" "', argument " "1"" of type '" "pj::AudioMediaRecorder *""'"); 
  }
  arg1 = reinterpret_cast< pj::AudioMediaRecorder * >(argp1);
  {
    std::string *ptr = (std::string *)0;
    res2 = SWIG_AsPtr_std_string(swig_obj[1], &ptr);
    if (!SWIG_IsOK(res2)) {
      SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "AudioMediaRecorder_createRecorder" "', argument " "2"" of type '" "pj::string const &""'"); 
    }
    if (!ptr) {
      SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "AudioMediaRecorder_createRecorder" "', argument " "2"" of type '" "pj::string const &""'"); 
    }
    arg2 = ptr;
  }
  try {
    (arg1)->createRecorder((pj::string const &)*arg2);
  } catch(pj::Error &_e) {
    SWIG_Python_Raise(SWIG_NewPointerObj((new pj::Error(static_cast< const pj::Error& >(_e))),SWIGTYPE_p_pj__Error,SWIG_POINTER_OWN), "pj::Error", SWIGTYPE_p_pj__Error); SWIG_fail;
  }
  resultobj = SWIG_Py_Void();
  if (SWIG_IsNewObj(res2)) delete arg2;
  return resultobj;
fail:
  if (SWIG_IsNewObj(res2)) delete arg2;
  return NULL;
}


SWIGINTERN PyObject *_wrap_AudioMediaRecorder_createRecorder(PyObject *self, PyObject *args) {
  Py_ssize_t argc;
  PyObject *argv[6] = {
    0
  };
  
  if (!(argc = SWIG_Python_UnpackTuple(args, "AudioMediaRecorder_createRecorder", 0, 5, argv))) SWIG_fail;
  --argc;
  if (argc == 2) {
    int _v;
    void *vptr = 0;
    int res = SWIG_ConvertPtr(argv[0], &vptr, SWIGTYPE_p_pj__AudioMediaRecorder, 0);
    _v = SWIG_CheckState(res);
    if (_v) {
      int res = SWIG_AsPtr_std_string(argv[1], (std::string**)(0));
      _v = SWIG_CheckState(res);
      if (_v) {
        return _wrap_AudioMediaRecorder_createRecorder__SWIG_3(self, argc, argv);
      }
    }
  }
  if (argc == 3) {
    int _v;
    void *vptr = 0;
    int res = SWIG_ConvertPtr(argv[0], &vptr, SWIGTYPE_p_pj__AudioMediaRecorder, 0);
    _v = SWIG_CheckState(res);
    if (_v) {
      int res = SWIG_AsPtr_std_string(argv[1], (std::string**)(0));
      _v = SWIG_CheckState(res);
      if (_v) {
        {
          int res = SWIG_AsVal_unsigned_SS_int(argv[2], NULL);
          _v = SWIG_CheckState(res);
        }
        if (_v) {
          return _wrap_AudioMediaRecorder_createRecorder__SWIG_2(self, argc, argv);
        }
      }
    }
  }
  if (argc == 4) {
    int _v;
    void *vptr = 0;
    int res = SWIG_ConvertPtr(argv[0], &vptr, SWIGTYPE_p_pj__AudioMediaRecorder, 0);
    _v = SWIG_CheckState(res);
    if (_v) {
      int res = SWIG_AsPtr_std_string(argv[1], (std::string**)(0));
      _v = SWIG_CheckState(res);
      if (_v) {
        {
          int res = SWIG_AsVal_unsigned_SS_int(argv[2], NULL);
          _v = SWIG_CheckState(res);
        }
        if (_v) {
          {
            int res = SWIG_AsVal_long(argv[3], NULL);
            _v = SWIG_CheckState(res);
          }
          if (_v) {
            return _wrap_AudioMediaRecorder_createRecorder__SWIG_1(self, argc, argv);
          }
        }
      }
    }
  }
  if (argc == 5) {
    int _v;
    void *vptr = 0;
    int res = SWIG_ConvertPtr(argv[0], &vptr, SWIGTYPE_p_pj__AudioMediaRecorder, 0);
    _v = SWIG_CheckState(res);
    if (_v) {
      int res = SWIG_AsPtr_std_string(argv[1], (std::string**)(0));
      _v = SWIG_CheckState(res);
      if (_v) {
        {
          int res = SWIG_AsVal_unsigned_SS_int(argv[2], NULL);
          _v = SWIG_CheckState(res);
        }
        if (_v) {
          {
            int res = SWIG_AsVal_long(argv[3], NULL);
            _v = SWIG_CheckState(res);
          }
          if (_v) {
            {
              int res = SWIG_AsVal_unsigned_SS_int(argv[4], NULL);
              _v = SWIG_CheckState(res);
            }
            if (_v) {
              return _wrap_AudioMediaRecorder_createRecorder__SWIG_0(self, argc, argv);
            }
          }
        }
      }
    }
  }
  
fail:
  SWIG_Python_RaiseOrModifyTypeError("Wrong number or type of arguments for overloaded function 'AudioMediaRecorder_createRecorder'.\n"
    "  Possible C/C++ prototypes are:\n"
    "    pj::AudioMediaRecorder::createRecorder(pj::string const &,unsigned int,long,unsigned int)\n"
    "    pj::AudioMediaRecorder::createRecorder(pj::string const &,unsigned int,long)\n"
    "    pj::AudioMediaRecorder::createRecorder(pj::string const &,unsigned int)\n"
    "    pj::AudioMediaRecorder::createRecorder(pj::string const &)\n");
  return 0;
}


SWIGINTERN PyObject *_wrap_AudioMediaRecorder_typecastFromAudioMedia(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::AudioMedia *arg1 = (pj::AudioMedia *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  pj::AudioMediaRecorder *result = 0 ;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__AudioMedia, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "AudioMediaRecorder_typecastFromAudioMedia" "', argument " "1"" of type '" "pj::AudioMedia *""'"); 
  }
  arg1 = reinterpret_cast< pj::AudioMedia * >(argp1);
  result = (pj::AudioMediaRecorder *)pj::AudioMediaRecorder::typecastFromAudioMedia(arg1);
  resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(result), SWIGTYPE_p_pj__AudioMediaRecorder, 0 |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_delete_AudioMediaRecorder(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::AudioMediaRecorder *arg1 = (pj::AudioMediaRecorder *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__AudioMediaRecorder, SWIG_POINTER_DISOWN |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "delete_AudioMediaRecorder" "', argument " "1"" of type '" "pj::AudioMediaRecorder *""'"); 
  }
  arg1 = reinterpret_cast< pj::AudioMediaRecorder * >(argp1);
  delete arg1;
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *AudioMediaRecorder_swigregister(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *obj;
  if (!SWIG_Python_UnpackTuple(args, "swigregister", 1, 1, &obj)) return NULL;
  SWIG_TypeNewClientData(SWIGTYPE_p_pj__AudioMediaRecorder, SWIG_NewClientData(obj));
  return SWIG_Py_Void();
}

SWIGINTERN PyObject *AudioMediaRecorder_swiginit(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  return SWIG_Python_InitShadowInstance(args);
}

SWIGINTERN PyObject *_wrap_new_ToneDesc(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::ToneDesc *result = 0 ;
  
  if (!SWIG_Python_UnpackTuple(args, "new_ToneDesc", 0, 0, 0)) SWIG_fail;
  result = (pj::ToneDesc *)new pj::ToneDesc();
  resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(result), SWIGTYPE_p_pj__ToneDesc, SWIG_POINTER_NEW |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_delete_ToneDesc(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::ToneDesc *arg1 = (pj::ToneDesc *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__ToneDesc, SWIG_POINTER_DISOWN |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "delete_ToneDesc" "', argument " "1"" of type '" "pj::ToneDesc *""'"); 
  }
  arg1 = reinterpret_cast< pj::ToneDesc * >(argp1);
  delete arg1;
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *ToneDesc_swigregister(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *obj;
  if (!SWIG_Python_UnpackTuple(args, "swigregister", 1, 1, &obj)) return NULL;
  SWIG_TypeNewClientData(SWIGTYPE_p_pj__ToneDesc, SWIG_NewClientData(obj));
  return SWIG_Py_Void();
}

SWIGINTERN PyObject *ToneDesc_swiginit(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  return SWIG_Python_InitShadowInstance(args);
}

SWIGINTERN PyObject *_wrap_new_ToneDigit(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::ToneDigit *result = 0 ;
  
  if (!SWIG_Python_UnpackTuple(args, "new_ToneDigit", 0, 0, 0)) SWIG_fail;
  result = (pj::ToneDigit *)new pj::ToneDigit();
  resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(result), SWIGTYPE_p_pj__ToneDigit, SWIG_POINTER_NEW |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_delete_ToneDigit(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::ToneDigit *arg1 = (pj::ToneDigit *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__ToneDigit, SWIG_POINTER_DISOWN |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "delete_ToneDigit" "', argument " "1"" of type '" "pj::ToneDigit *""'"); 
  }
  arg1 = reinterpret_cast< pj::ToneDigit * >(argp1);
  delete arg1;
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *ToneDigit_swigregister(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *obj;
  if (!SWIG_Python_UnpackTuple(args, "swigregister", 1, 1, &obj)) return NULL;
  SWIG_TypeNewClientData(SWIGTYPE_p_pj__ToneDigit, SWIG_NewClientData(obj));
  return SWIG_Py_Void();
}

SWIGINTERN PyObject *ToneDigit_swiginit(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  return SWIG_Python_InitShadowInstance(args);
}

SWIGINTERN PyObject *_wrap_ToneDigitMapDigit_digit_set(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::ToneDigitMapDigit *arg1 = (pj::ToneDigitMapDigit *) 0 ;
  pj::string *arg2 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  int res2 = SWIG_OLDOBJ ;
  PyObject *swig_obj[2] ;
  
  if (!SWIG_Python_UnpackTuple(args, "ToneDigitMapDigit_digit_set", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__ToneDigitMapDigit, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "ToneDigitMapDigit_digit_set" "', argument " "1"" of type '" "pj::ToneDigitMapDigit *""'"); 
  }
  arg1 = reinterpret_cast< pj::ToneDigitMapDigit * >(argp1);
  {
    std::string *ptr = (std::string *)0;
    res2 = SWIG_AsPtr_std_string(swig_obj[1], &ptr);
    if (!SWIG_IsOK(res2)) {
      SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "ToneDigitMapDigit_digit_set" "', argument " "2"" of type '" "pj::string const &""'"); 
    }
    if (!ptr) {
      SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "ToneDigitMapDigit_digit_set" "', argument " "2"" of type '" "pj::string const &""'"); 
    }
    arg2 = ptr;
  }
  if (arg1) (arg1)->digit = *arg2;
  resultobj = SWIG_Py_Void();
  if (SWIG_IsNewObj(res2)) delete arg2;
  return resultobj;
fail:
  if (SWIG_IsNewObj(res2)) delete arg2;
  return NULL;
}


SWIGINTERN PyObject *_wrap_ToneDigitMapDigit_digit_get(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::ToneDigitMapDigit *arg1 = (pj::ToneDigitMapDigit *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  pj::string *result = 0 ;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__ToneDigitMapDigit, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "ToneDigitMapDigit_digit_get" "', argument " "1"" of type '" "pj::ToneDigitMapDigit *""'"); 
  }
  arg1 = reinterpret_cast< pj::ToneDigitMapDigit * >(argp1);
  result = (pj::string *) & ((arg1)->digit);
  resultobj = SWIG_From_std_string(static_cast< std::string >(*result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_ToneDigitMapDigit_freq1_set(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::ToneDigitMapDigit *arg1 = (pj::ToneDigitMapDigit *) 0 ;
  int arg2 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  int val2 ;
  int ecode2 = 0 ;
  PyObject *swig_obj[2] ;
  
  if (!SWIG_Python_UnpackTuple(args, "ToneDigitMapDigit_freq1_set", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__ToneDigitMapDigit, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "ToneDigitMapDigit_freq1_set" "', argument " "1"" of type '" "pj::ToneDigitMapDigit *""'"); 
  }
  arg1 = reinterpret_cast< pj::ToneDigitMapDigit * >(argp1);
  ecode2 = SWIG_AsVal_int(swig_obj[1], &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "ToneDigitMapDigit_freq1_set" "', argument " "2"" of type '" "int""'");
  } 
  arg2 = static_cast< int >(val2);
  if (arg1) (arg1)->freq1 = arg2;
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_ToneDigitMapDigit_freq1_get(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::ToneDigitMapDigit *arg1 = (pj::ToneDigitMapDigit *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  int result;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__ToneDigitMapDigit, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "ToneDigitMapDigit_freq1_get" "', argument " "1"" of type '" "pj::ToneDigitMapDigit *""'"); 
  }
  arg1 = reinterpret_cast< pj::ToneDigitMapDigit * >(argp1);
  result = (int) ((arg1)->freq1);
  resultobj = SWIG_From_int(static_cast< int >(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_ToneDigitMapDigit_freq2_set(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::ToneDigitMapDigit *arg1 = (pj::ToneDigitMapDigit *) 0 ;
  int arg2 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  int val2 ;
  int ecode2 = 0 ;
  PyObject *swig_obj[2] ;
  
  if (!SWIG_Python_UnpackTuple(args, "ToneDigitMapDigit_freq2_set", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__ToneDigitMapDigit, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "ToneDigitMapDigit_freq2_set" "', argument " "1"" of type '" "pj::ToneDigitMapDigit *""'"); 
  }
  arg1 = reinterpret_cast< pj::ToneDigitMapDigit * >(argp1);
  ecode2 = SWIG_AsVal_int(swig_obj[1], &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "ToneDigitMapDigit_freq2_set" "', argument " "2"" of type '" "int""'");
  } 
  arg2 = static_cast< int >(val2);
  if (arg1) (arg1)->freq2 = arg2;
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_ToneDigitMapDigit_freq2_get(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::ToneDigitMapDigit *arg1 = (pj::ToneDigitMapDigit *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  int result;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__ToneDigitMapDigit, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "ToneDigitMapDigit_freq2_get" "', argument " "1"" of type '" "pj::ToneDigitMapDigit *""'"); 
  }
  arg1 = reinterpret_cast< pj::ToneDigitMapDigit * >(argp1);
  result = (int) ((arg1)->freq2);
  resultobj = SWIG_From_int(static_cast< int >(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_new_ToneDigitMapDigit(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::ToneDigitMapDigit *result = 0 ;
  
  if (!SWIG_Python_UnpackTuple(args, "new_ToneDigitMapDigit", 0, 0, 0)) SWIG_fail;
  result = (pj::ToneDigitMapDigit *)new pj::ToneDigitMapDigit();
  resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(result), SWIGTYPE_p_pj__ToneDigitMapDigit, SWIG_POINTER_NEW |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_delete_ToneDigitMapDigit(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::ToneDigitMapDigit *arg1 = (pj::ToneDigitMapDigit *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__ToneDigitMapDigit, SWIG_POINTER_DISOWN |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "delete_ToneDigitMapDigit" "', argument " "1"" of type '" "pj::ToneDigitMapDigit *""'"); 
  }
  arg1 = reinterpret_cast< pj::ToneDigitMapDigit * >(argp1);
  delete arg1;
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *ToneDigitMapDigit_swigregister(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *obj;
  if (!SWIG_Python_UnpackTuple(args, "swigregister", 1, 1, &obj)) return NULL;
  SWIG_TypeNewClientData(SWIGTYPE_p_pj__ToneDigitMapDigit, SWIG_NewClientData(obj));
  return SWIG_Py_Void();
}

SWIGINTERN PyObject *ToneDigitMapDigit_swiginit(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  return SWIG_Python_InitShadowInstance(args);
}

SWIGINTERN PyObject *_wrap_new_ToneGenerator(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::ToneGenerator *result = 0 ;
  
  if (!SWIG_Python_UnpackTuple(args, "new_ToneGenerator", 0, 0, 0)) SWIG_fail;
  result = (pj::ToneGenerator *)new pj::ToneGenerator();
  resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(result), SWIGTYPE_p_pj__ToneGenerator, SWIG_POINTER_NEW |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_delete_ToneGenerator(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::ToneGenerator *arg1 = (pj::ToneGenerator *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__ToneGenerator, SWIG_POINTER_DISOWN |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "delete_ToneGenerator" "', argument " "1"" of type '" "pj::ToneGenerator *""'"); 
  }
  arg1 = reinterpret_cast< pj::ToneGenerator * >(argp1);
  delete arg1;
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_ToneGenerator_createToneGenerator__SWIG_0(PyObject *SWIGUNUSEDPARM(self), Py_ssize_t nobjs, PyObject **swig_obj) {
  PyObject *resultobj = 0;
  pj::ToneGenerator *arg1 = (pj::ToneGenerator *) 0 ;
  unsigned int arg2 ;
  unsigned int arg3 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  unsigned int val2 ;
  int ecode2 = 0 ;
  unsigned int val3 ;
  int ecode3 = 0 ;
  
  if ((nobjs < 3) || (nobjs > 3)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__ToneGenerator, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "ToneGenerator_createToneGenerator" "', argument " "1"" of type '" "pj::ToneGenerator *""'"); 
  }
  arg1 = reinterpret_cast< pj::ToneGenerator * >(argp1);
  ecode2 = SWIG_AsVal_unsigned_SS_int(swig_obj[1], &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "ToneGenerator_createToneGenerator" "', argument " "2"" of type '" "unsigned int""'");
  } 
  arg2 = static_cast< unsigned int >(val2);
  ecode3 = SWIG_AsVal_unsigned_SS_int(swig_obj[2], &val3);
  if (!SWIG_IsOK(ecode3)) {
    SWIG_exception_fail(SWIG_ArgError(ecode3), "in method '" "ToneGenerator_createToneGenerator" "', argument " "3"" of type '" "unsigned int""'");
  } 
  arg3 = static_cast< unsigned int >(val3);
  try {
    (arg1)->createToneGenerator(arg2,arg3);
  } catch(pj::Error &_e) {
    SWIG_Python_Raise(SWIG_NewPointerObj((new pj::Error(static_cast< const pj::Error& >(_e))),SWIGTYPE_p_pj__Error,SWIG_POINTER_OWN), "pj::Error", SWIGTYPE_p_pj__Error); SWIG_fail;
  }
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_ToneGenerator_createToneGenerator__SWIG_1(PyObject *SWIGUNUSEDPARM(self), Py_ssize_t nobjs, PyObject **swig_obj) {
  PyObject *resultobj = 0;
  pj::ToneGenerator *arg1 = (pj::ToneGenerator *) 0 ;
  unsigned int arg2 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  unsigned int val2 ;
  int ecode2 = 0 ;
  
  if ((nobjs < 2) || (nobjs > 2)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__ToneGenerator, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "ToneGenerator_createToneGenerator" "', argument " "1"" of type '" "pj::ToneGenerator *""'"); 
  }
  arg1 = reinterpret_cast< pj::ToneGenerator * >(argp1);
  ecode2 = SWIG_AsVal_unsigned_SS_int(swig_obj[1], &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "ToneGenerator_createToneGenerator" "', argument " "2"" of type '" "unsigned int""'");
  } 
  arg2 = static_cast< unsigned int >(val2);
  try {
    (arg1)->createToneGenerator(arg2);
  } catch(pj::Error &_e) {
    SWIG_Python_Raise(SWIG_NewPointerObj((new pj::Error(static_cast< const pj::Error& >(_e))),SWIGTYPE_p_pj__Error,SWIG_POINTER_OWN), "pj::Error", SWIGTYPE_p_pj__Error); SWIG_fail;
  }
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_ToneGenerator_createToneGenerator__SWIG_2(PyObject *SWIGUNUSEDPARM(self), Py_ssize_t nobjs, PyObject **swig_obj) {
  PyObject *resultobj = 0;
  pj::ToneGenerator *arg1 = (pj::ToneGenerator *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  
  if ((nobjs < 1) || (nobjs > 1)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__ToneGenerator, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "ToneGenerator_createToneGenerator" "', argument " "1"" of type '" "pj::ToneGenerator *""'"); 
  }
  arg1 = reinterpret_cast< pj::ToneGenerator * >(argp1);
  try {
    (arg1)->createToneGenerator();
  } catch(pj::Error &_e) {
    SWIG_Python_Raise(SWIG_NewPointerObj((new pj::Error(static_cast< const pj::Error& >(_e))),SWIGTYPE_p_pj__Error,SWIG_POINTER_OWN), "pj::Error", SWIGTYPE_p_pj__Error); SWIG_fail;
  }
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_ToneGenerator_createToneGenerator(PyObject *self, PyObject *args) {
  Py_ssize_t argc;
  PyObject *argv[4] = {
    0
  };
  
  if (!(argc = SWIG_Python_UnpackTuple(args, "ToneGenerator_createToneGenerator", 0, 3, argv))) SWIG_fail;
  --argc;
  if (argc == 1) {
    int _v;
    void *vptr = 0;
    int res = SWIG_ConvertPtr(argv[0], &vptr, SWIGTYPE_p_pj__ToneGenerator, 0);
    _v = SWIG_CheckState(res);
    if (_v) {
      return _wrap_ToneGenerator_createToneGenerator__SWIG_2(self, argc, argv);
    }
  }
  if (argc == 2) {
    int _v;
    void *vptr = 0;
    int res = SWIG_ConvertPtr(argv[0], &vptr, SWIGTYPE_p_pj__ToneGenerator, 0);
    _v = SWIG_CheckState(res);
    if (_v) {
      {
        int res = SWIG_AsVal_unsigned_SS_int(argv[1], NULL);
        _v = SWIG_CheckState(res);
      }
      if (_v) {
        return _wrap_ToneGenerator_createToneGenerator__SWIG_1(self, argc, argv);
      }
    }
  }
  if (argc == 3) {
    int _v;
    void *vptr = 0;
    int res = SWIG_ConvertPtr(argv[0], &vptr, SWIGTYPE_p_pj__ToneGenerator, 0);
    _v = SWIG_CheckState(res);
    if (_v) {
      {
        int res = SWIG_AsVal_unsigned_SS_int(argv[1], NULL);
        _v = SWIG_CheckState(res);
      }
      if (_v) {
        {
          int res = SWIG_AsVal_unsigned_SS_int(argv[2], NULL);
          _v = SWIG_CheckState(res);
        }
        if (_v) {
          return _wrap_ToneGenerator_createToneGenerator__SWIG_0(self, argc, argv);
        }
      }
    }
  }
  
fail:
  SWIG_Python_RaiseOrModifyTypeError("Wrong number or type of arguments for overloaded function 'ToneGenerator_createToneGenerator'.\n"
    "  Possible C/C++ prototypes are:\n"
    "    pj::ToneGenerator::createToneGenerator(unsigned int,unsigned int)\n"
    "    pj::ToneGenerator::createToneGenerator(unsigned int)\n"
    "    pj::ToneGenerator::createToneGenerator()\n");
  return 0;
}


SWIGINTERN PyObject *_wrap_ToneGenerator_isBusy(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::ToneGenerator *arg1 = (pj::ToneGenerator *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  bool result;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__ToneGenerator, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "ToneGenerator_isBusy" "', argument " "1"" of type '" "pj::ToneGenerator const *""'"); 
  }
  arg1 = reinterpret_cast< pj::ToneGenerator * >(argp1);
  result = (bool)((pj::ToneGenerator const *)arg1)->isBusy();
  resultobj = SWIG_From_bool(static_cast< bool >(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_ToneGenerator_stop(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::ToneGenerator *arg1 = (pj::ToneGenerator *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__ToneGenerator, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "ToneGenerator_stop" "', argument " "1"" of type '" "pj::ToneGenerator *""'"); 
  }
  arg1 = reinterpret_cast< pj::ToneGenerator * >(argp1);
  try {
    (arg1)->stop();
  } catch(pj::Error &_e) {
    SWIG_Python_Raise(SWIG_NewPointerObj((new pj::Error(static_cast< const pj::Error& >(_e))),SWIGTYPE_p_pj__Error,SWIG_POINTER_OWN), "pj::Error", SWIGTYPE_p_pj__Error); SWIG_fail;
  }
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_ToneGenerator_rewind(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::ToneGenerator *arg1 = (pj::ToneGenerator *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__ToneGenerator, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "ToneGenerator_rewind" "', argument " "1"" of type '" "pj::ToneGenerator *""'"); 
  }
  arg1 = reinterpret_cast< pj::ToneGenerator * >(argp1);
  try {
    (arg1)->rewind();
  } catch(pj::Error &_e) {
    SWIG_Python_Raise(SWIG_NewPointerObj((new pj::Error(static_cast< const pj::Error& >(_e))),SWIGTYPE_p_pj__Error,SWIG_POINTER_OWN), "pj::Error", SWIGTYPE_p_pj__Error); SWIG_fail;
  }
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_ToneGenerator_play__SWIG_0(PyObject *SWIGUNUSEDPARM(self), Py_ssize_t nobjs, PyObject **swig_obj) {
  PyObject *resultobj = 0;
  pj::ToneGenerator *arg1 = (pj::ToneGenerator *) 0 ;
  pj::ToneDescVector *arg2 = 0 ;
  bool arg3 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  int res2 = SWIG_OLDOBJ ;
  bool val3 ;
  int ecode3 = 0 ;
  
  if ((nobjs < 3) || (nobjs > 3)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__ToneGenerator, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "ToneGenerator_play" "', argument " "1"" of type '" "pj::ToneGenerator *""'"); 
  }
  arg1 = reinterpret_cast< pj::ToneGenerator * >(argp1);
  {
    std::vector< pj::ToneDesc,std::allocator< pj::ToneDesc > > *ptr = (std::vector< pj::ToneDesc,std::allocator< pj::ToneDesc > > *)0;
    res2 = swig::asptr(swig_obj[1], &ptr);
    if (!SWIG_IsOK(res2)) {
      SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "ToneGenerator_play" "', argument " "2"" of type '" "pj::ToneDescVector const &""'"); 
    }
    if (!ptr) {
      SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "ToneGenerator_play" "', argument " "2"" of type '" "pj::ToneDescVector const &""'"); 
    }
    arg2 = ptr;
  }
  ecode3 = SWIG_AsVal_bool(swig_obj[2], &val3);
  if (!SWIG_IsOK(ecode3)) {
    SWIG_exception_fail(SWIG_ArgError(ecode3), "in method '" "ToneGenerator_play" "', argument " "3"" of type '" "bool""'");
  } 
  arg3 = static_cast< bool >(val3);
  try {
    (arg1)->play((pj::ToneDescVector const &)*arg2,arg3);
  } catch(pj::Error &_e) {
    SWIG_Python_Raise(SWIG_NewPointerObj((new pj::Error(static_cast< const pj::Error& >(_e))),SWIGTYPE_p_pj__Error,SWIG_POINTER_OWN), "pj::Error", SWIGTYPE_p_pj__Error); SWIG_fail;
  }
  resultobj = SWIG_Py_Void();
  if (SWIG_IsNewObj(res2)) delete arg2;
  return resultobj;
fail:
  if (SWIG_IsNewObj(res2)) delete arg2;
  return NULL;
}


SWIGINTERN PyObject *_wrap_ToneGenerator_play__SWIG_1(PyObject *SWIGUNUSEDPARM(self), Py_ssize_t nobjs, PyObject **swig_obj) {
  PyObject *resultobj = 0;
  pj::ToneGenerator *arg1 = (pj::ToneGenerator *) 0 ;
  pj::ToneDescVector *arg2 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  int res2 = SWIG_OLDOBJ ;
  
  if ((nobjs < 2) || (nobjs > 2)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__ToneGenerator, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "ToneGenerator_play" "', argument " "1"" of type '" "pj::ToneGenerator *""'"); 
  }
  arg1 = reinterpret_cast< pj::ToneGenerator * >(argp1);
  {
    std::vector< pj::ToneDesc,std::allocator< pj::ToneDesc > > *ptr = (std::vector< pj::ToneDesc,std::allocator< pj::ToneDesc > > *)0;
    res2 = swig::asptr(swig_obj[1], &ptr);
    if (!SWIG_IsOK(res2)) {
      SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "ToneGenerator_play" "', argument " "2"" of type '" "pj::ToneDescVector const &""'"); 
    }
    if (!ptr) {
      SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "ToneGenerator_play" "', argument " "2"" of type '" "pj::ToneDescVector const &""'"); 
    }
    arg2 = ptr;
  }
  try {
    (arg1)->play((pj::ToneDescVector const &)*arg2);
  } catch(pj::Error &_e) {
    SWIG_Python_Raise(SWIG_NewPointerObj((new pj::Error(static_cast< const pj::Error& >(_e))),SWIGTYPE_p_pj__Error,SWIG_POINTER_OWN), "pj::Error", SWIGTYPE_p_pj__Error); SWIG_fail;
  }
  resultobj = SWIG_Py_Void();
  if (SWIG_IsNewObj(res2)) delete arg2;
  return resultobj;
fail:
  if (SWIG_IsNewObj(res2)) delete arg2;
  return NULL;
}


SWIGINTERN PyObject *_wrap_ToneGenerator_play(PyObject *self, PyObject *args) {
  Py_ssize_t argc;
  PyObject *argv[4] = {
    0
  };
  
  if (!(argc = SWIG_Python_UnpackTuple(args, "ToneGenerator_play", 0, 3, argv))) SWIG_fail;
  --argc;
  if (argc == 2) {
    int _v;
    void *vptr = 0;
    int res = SWIG_ConvertPtr(argv[0], &vptr, SWIGTYPE_p_pj__ToneGenerator, 0);
    _v = SWIG_CheckState(res);
    if (_v) {
      int res = swig::asptr(argv[1], (std::vector< pj::ToneDesc,std::allocator< pj::ToneDesc > >**)(0));
      _v = SWIG_CheckState(res);
      if (_v) {
        return _wrap_ToneGenerator_play__SWIG_1(self, argc, argv);
      }
    }
  }
  if (argc == 3) {
    int _v;
    void *vptr = 0;
    int res = SWIG_ConvertPtr(argv[0], &vptr, SWIGTYPE_p_pj__ToneGenerator, 0);
    _v = SWIG_CheckState(res);
    if (_v) {
      int res = swig::asptr(argv[1], (std::vector< pj::ToneDesc,std::allocator< pj::ToneDesc > >**)(0));
      _v = SWIG_CheckState(res);
      if (_v) {
        {
          int res = SWIG_AsVal_bool(argv[2], NULL);
          _v = SWIG_CheckState(res);
        }
        if (_v) {
          return _wrap_ToneGenerator_play__SWIG_0(self, argc, argv);
        }
      }
    }
  }
  
fail:
  SWIG_Python_RaiseOrModifyTypeError("Wrong number or type of arguments for overloaded function 'ToneGenerator_play'.\n"
    "  Possible C/C++ prototypes are:\n"
    "    pj::ToneGenerator::play(pj::ToneDescVector const &,bool)\n"
    "    pj::ToneGenerator::play(pj::ToneDescVector const &)\n");
  return 0;
}


SWIGINTERN PyObject *_wrap_ToneGenerator_playDigits__SWIG_0(PyObject *SWIGUNUSEDPARM(self), Py_ssize_t nobjs, PyObject **swig_obj) {
  PyObject *resultobj = 0;
  pj::ToneGenerator *arg1 = (pj::ToneGenerator *) 0 ;
  pj::ToneDigitVector *arg2 = 0 ;
  bool arg3 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  int res2 = SWIG_OLDOBJ ;
  bool val3 ;
  int ecode3 = 0 ;
  
  if ((nobjs < 3) || (nobjs > 3)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__ToneGenerator, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "ToneGenerator_playDigits" "', argument " "1"" of type '" "pj::ToneGenerator *""'"); 
  }
  arg1 = reinterpret_cast< pj::ToneGenerator * >(argp1);
  {
    std::vector< pj::ToneDigit,std::allocator< pj::ToneDigit > > *ptr = (std::vector< pj::ToneDigit,std::allocator< pj::ToneDigit > > *)0;
    res2 = swig::asptr(swig_obj[1], &ptr);
    if (!SWIG_IsOK(res2)) {
      SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "ToneGenerator_playDigits" "', argument " "2"" of type '" "pj::ToneDigitVector const &""'"); 
    }
    if (!ptr) {
      SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "ToneGenerator_playDigits" "', argument " "2"" of type '" "pj::ToneDigitVector const &""'"); 
    }
    arg2 = ptr;
  }
  ecode3 = SWIG_AsVal_bool(swig_obj[2], &val3);
  if (!SWIG_IsOK(ecode3)) {
    SWIG_exception_fail(SWIG_ArgError(ecode3), "in method '" "ToneGenerator_playDigits" "', argument " "3"" of type '" "bool""'");
  } 
  arg3 = static_cast< bool >(val3);
  try {
    (arg1)->playDigits((pj::ToneDigitVector const &)*arg2,arg3);
  } catch(pj::Error &_e) {
    SWIG_Python_Raise(SWIG_NewPointerObj((new pj::Error(static_cast< const pj::Error& >(_e))),SWIGTYPE_p_pj__Error,SWIG_POINTER_OWN), "pj::Error", SWIGTYPE_p_pj__Error); SWIG_fail;
  }
  resultobj = SWIG_Py_Void();
  if (SWIG_IsNewObj(res2)) delete arg2;
  return resultobj;
fail:
  if (SWIG_IsNewObj(res2)) delete arg2;
  return NULL;
}


SWIGINTERN PyObject *_wrap_ToneGenerator_playDigits__SWIG_1(PyObject *SWIGUNUSEDPARM(self), Py_ssize_t nobjs, PyObject **swig_obj) {
  PyObject *resultobj = 0;
  pj::ToneGenerator *arg1 = (pj::ToneGenerator *) 0 ;
  pj::ToneDigitVector *arg2 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  int res2 = SWIG_OLDOBJ ;
  
  if ((nobjs < 2) || (nobjs > 2)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__ToneGenerator, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "ToneGenerator_playDigits" "', argument " "1"" of type '" "pj::ToneGenerator *""'"); 
  }
  arg1 = reinterpret_cast< pj::ToneGenerator * >(argp1);
  {
    std::vector< pj::ToneDigit,std::allocator< pj::ToneDigit > > *ptr = (std::vector< pj::ToneDigit,std::allocator< pj::ToneDigit > > *)0;
    res2 = swig::asptr(swig_obj[1], &ptr);
    if (!SWIG_IsOK(res2)) {
      SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "ToneGenerator_playDigits" "', argument " "2"" of type '" "pj::ToneDigitVector const &""'"); 
    }
    if (!ptr) {
      SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "ToneGenerator_playDigits" "', argument " "2"" of type '" "pj::ToneDigitVector const &""'"); 
    }
    arg2 = ptr;
  }
  try {
    (arg1)->playDigits((pj::ToneDigitVector const &)*arg2);
  } catch(pj::Error &_e) {
    SWIG_Python_Raise(SWIG_NewPointerObj((new pj::Error(static_cast< const pj::Error& >(_e))),SWIGTYPE_p_pj__Error,SWIG_POINTER_OWN), "pj::Error", SWIGTYPE_p_pj__Error); SWIG_fail;
  }
  resultobj = SWIG_Py_Void();
  if (SWIG_IsNewObj(res2)) delete arg2;
  return resultobj;
fail:
  if (SWIG_IsNewObj(res2)) delete arg2;
  return NULL;
}


SWIGINTERN PyObject *_wrap_ToneGenerator_playDigits(PyObject *self, PyObject *args) {
  Py_ssize_t argc;
  PyObject *argv[4] = {
    0
  };
  
  if (!(argc = SWIG_Python_UnpackTuple(args, "ToneGenerator_playDigits", 0, 3, argv))) SWIG_fail;
  --argc;
  if (argc == 2) {
    int _v;
    void *vptr = 0;
    int res = SWIG_ConvertPtr(argv[0], &vptr, SWIGTYPE_p_pj__ToneGenerator, 0);
    _v = SWIG_CheckState(res);
    if (_v) {
      int res = swig::asptr(argv[1], (std::vector< pj::ToneDigit,std::allocator< pj::ToneDigit > >**)(0));
      _v = SWIG_CheckState(res);
      if (_v) {
        return _wrap_ToneGenerator_playDigits__SWIG_1(self, argc, argv);
      }
    }
  }
  if (argc == 3) {
    int _v;
    void *vptr = 0;
    int res = SWIG_ConvertPtr(argv[0], &vptr, SWIGTYPE_p_pj__ToneGenerator, 0);
    _v = SWIG_CheckState(res);
    if (_v) {
      int res = swig::asptr(argv[1], (std::vector< pj::ToneDigit,std::allocator< pj::ToneDigit > >**)(0));
      _v = SWIG_CheckState(res);
      if (_v) {
        {
          int res = SWIG_AsVal_bool(argv[2], NULL);
          _v = SWIG_CheckState(res);
        }
        if (_v) {
          return _wrap_ToneGenerator_playDigits__SWIG_0(self, argc, argv);
        }
      }
    }
  }
  
fail:
  SWIG_Python_RaiseOrModifyTypeError("Wrong number or type of arguments for overloaded function 'ToneGenerator_playDigits'.\n"
    "  Possible C/C++ prototypes are:\n"
    "    pj::ToneGenerator::playDigits(pj::ToneDigitVector const &,bool)\n"
    "    pj::ToneGenerator::playDigits(pj::ToneDigitVector const &)\n");
  return 0;
}


SWIGINTERN PyObject *_wrap_ToneGenerator_getDigitMap(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::ToneGenerator *arg1 = (pj::ToneGenerator *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  pj::ToneDigitMapVector result;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__ToneGenerator, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "ToneGenerator_getDigitMap" "', argument " "1"" of type '" "pj::ToneGenerator const *""'"); 
  }
  arg1 = reinterpret_cast< pj::ToneGenerator * >(argp1);
  try {
    result = ((pj::ToneGenerator const *)arg1)->getDigitMap();
  } catch(pj::Error &_e) {
    SWIG_Python_Raise(SWIG_NewPointerObj((new pj::Error(static_cast< const pj::Error& >(_e))),SWIGTYPE_p_pj__Error,SWIG_POINTER_OWN), "pj::Error", SWIGTYPE_p_pj__Error); SWIG_fail;
  }
  resultobj = swig::from(static_cast< std::vector< pj::ToneDigitMapDigit,std::allocator< pj::ToneDigitMapDigit > > >(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_ToneGenerator_setDigitMap(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::ToneGenerator *arg1 = (pj::ToneGenerator *) 0 ;
  pj::ToneDigitMapVector *arg2 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  int res2 = SWIG_OLDOBJ ;
  PyObject *swig_obj[2] ;
  
  if (!SWIG_Python_UnpackTuple(args, "ToneGenerator_setDigitMap", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__ToneGenerator, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "ToneGenerator_setDigitMap" "', argument " "1"" of type '" "pj::ToneGenerator *""'"); 
  }
  arg1 = reinterpret_cast< pj::ToneGenerator * >(argp1);
  {
    std::vector< pj::ToneDigitMapDigit,std::allocator< pj::ToneDigitMapDigit > > *ptr = (std::vector< pj::ToneDigitMapDigit,std::allocator< pj::ToneDigitMapDigit > > *)0;
    res2 = swig::asptr(swig_obj[1], &ptr);
    if (!SWIG_IsOK(res2)) {
      SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "ToneGenerator_setDigitMap" "', argument " "2"" of type '" "pj::ToneDigitMapVector const &""'"); 
    }
    if (!ptr) {
      SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "ToneGenerator_setDigitMap" "', argument " "2"" of type '" "pj::ToneDigitMapVector const &""'"); 
    }
    arg2 = ptr;
  }
  try {
    (arg1)->setDigitMap((pj::ToneDigitMapVector const &)*arg2);
  } catch(pj::Error &_e) {
    SWIG_Python_Raise(SWIG_NewPointerObj((new pj::Error(static_cast< const pj::Error& >(_e))),SWIGTYPE_p_pj__Error,SWIG_POINTER_OWN), "pj::Error", SWIGTYPE_p_pj__Error); SWIG_fail;
  }
  resultobj = SWIG_Py_Void();
  if (SWIG_IsNewObj(res2)) delete arg2;
  return resultobj;
fail:
  if (SWIG_IsNewObj(res2)) delete arg2;
  return NULL;
}


SWIGINTERN PyObject *ToneGenerator_swigregister(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *obj;
  if (!SWIG_Python_UnpackTuple(args, "swigregister", 1, 1, &obj)) return NULL;
  SWIG_TypeNewClientData(SWIGTYPE_p_pj__ToneGenerator, SWIG_NewClientData(obj));
  return SWIG_Py_Void();
}

SWIGINTERN PyObject *ToneGenerator_swiginit(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  return SWIG_Python_InitShadowInstance(args);
}

SWIGINTERN PyObject *_wrap_AudioDevInfo_name_set(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::AudioDevInfo *arg1 = (pj::AudioDevInfo *) 0 ;
  pj::string *arg2 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  int res2 = SWIG_OLDOBJ ;
  PyObject *swig_obj[2] ;
  
  if (!SWIG_Python_UnpackTuple(args, "AudioDevInfo_name_set", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__AudioDevInfo, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "AudioDevInfo_name_set" "', argument " "1"" of type '" "pj::AudioDevInfo *""'"); 
  }
  arg1 = reinterpret_cast< pj::AudioDevInfo * >(argp1);
  {
    std::string *ptr = (std::string *)0;
    res2 = SWIG_AsPtr_std_string(swig_obj[1], &ptr);
    if (!SWIG_IsOK(res2)) {
      SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "AudioDevInfo_name_set" "', argument " "2"" of type '" "pj::string const &""'"); 
    }
    if (!ptr) {
      SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "AudioDevInfo_name_set" "', argument " "2"" of type '" "pj::string const &""'"); 
    }
    arg2 = ptr;
  }
  if (arg1) (arg1)->name = *arg2;
  resultobj = SWIG_Py_Void();
  if (SWIG_IsNewObj(res2)) delete arg2;
  return resultobj;
fail:
  if (SWIG_IsNewObj(res2)) delete arg2;
  return NULL;
}


SWIGINTERN PyObject *_wrap_AudioDevInfo_name_get(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::AudioDevInfo *arg1 = (pj::AudioDevInfo *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  pj::string *result = 0 ;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__AudioDevInfo, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "AudioDevInfo_name_get" "', argument " "1"" of type '" "pj::AudioDevInfo *""'"); 
  }
  arg1 = reinterpret_cast< pj::AudioDevInfo * >(argp1);
  result = (pj::string *) & ((arg1)->name);
  resultobj = SWIG_From_std_string(static_cast< std::string >(*result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_AudioDevInfo_inputCount_set(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::AudioDevInfo *arg1 = (pj::AudioDevInfo *) 0 ;
  unsigned int arg2 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  unsigned int val2 ;
  int ecode2 = 0 ;
  PyObject *swig_obj[2] ;
  
  if (!SWIG_Python_UnpackTuple(args, "AudioDevInfo_inputCount_set", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__AudioDevInfo, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "AudioDevInfo_inputCount_set" "', argument " "1"" of type '" "pj::AudioDevInfo *""'"); 
  }
  arg1 = reinterpret_cast< pj::AudioDevInfo * >(argp1);
  ecode2 = SWIG_AsVal_unsigned_SS_int(swig_obj[1], &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "AudioDevInfo_inputCount_set" "', argument " "2"" of type '" "unsigned int""'");
  } 
  arg2 = static_cast< unsigned int >(val2);
  if (arg1) (arg1)->inputCount = arg2;
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_AudioDevInfo_inputCount_get(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::AudioDevInfo *arg1 = (pj::AudioDevInfo *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  unsigned int result;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__AudioDevInfo, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "AudioDevInfo_inputCount_get" "', argument " "1"" of type '" "pj::AudioDevInfo *""'"); 
  }
  arg1 = reinterpret_cast< pj::AudioDevInfo * >(argp1);
  result = (unsigned int) ((arg1)->inputCount);
  resultobj = SWIG_From_unsigned_SS_int(static_cast< unsigned int >(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_AudioDevInfo_outputCount_set(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::AudioDevInfo *arg1 = (pj::AudioDevInfo *) 0 ;
  unsigned int arg2 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  unsigned int val2 ;
  int ecode2 = 0 ;
  PyObject *swig_obj[2] ;
  
  if (!SWIG_Python_UnpackTuple(args, "AudioDevInfo_outputCount_set", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__AudioDevInfo, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "AudioDevInfo_outputCount_set" "', argument " "1"" of type '" "pj::AudioDevInfo *""'"); 
  }
  arg1 = reinterpret_cast< pj::AudioDevInfo * >(argp1);
  ecode2 = SWIG_AsVal_unsigned_SS_int(swig_obj[1], &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "AudioDevInfo_outputCount_set" "', argument " "2"" of type '" "unsigned int""'");
  } 
  arg2 = static_cast< unsigned int >(val2);
  if (arg1) (arg1)->outputCount = arg2;
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_AudioDevInfo_outputCount_get(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::AudioDevInfo *arg1 = (pj::AudioDevInfo *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  unsigned int result;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__AudioDevInfo, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "AudioDevInfo_outputCount_get" "', argument " "1"" of type '" "pj::AudioDevInfo *""'"); 
  }
  arg1 = reinterpret_cast< pj::AudioDevInfo * >(argp1);
  result = (unsigned int) ((arg1)->outputCount);
  resultobj = SWIG_From_unsigned_SS_int(static_cast< unsigned int >(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_AudioDevInfo_defaultSamplesPerSec_set(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::AudioDevInfo *arg1 = (pj::AudioDevInfo *) 0 ;
  unsigned int arg2 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  unsigned int val2 ;
  int ecode2 = 0 ;
  PyObject *swig_obj[2] ;
  
  if (!SWIG_Python_UnpackTuple(args, "AudioDevInfo_defaultSamplesPerSec_set", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__AudioDevInfo, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "AudioDevInfo_defaultSamplesPerSec_set" "', argument " "1"" of type '" "pj::AudioDevInfo *""'"); 
  }
  arg1 = reinterpret_cast< pj::AudioDevInfo * >(argp1);
  ecode2 = SWIG_AsVal_unsigned_SS_int(swig_obj[1], &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "AudioDevInfo_defaultSamplesPerSec_set" "', argument " "2"" of type '" "unsigned int""'");
  } 
  arg2 = static_cast< unsigned int >(val2);
  if (arg1) (arg1)->defaultSamplesPerSec = arg2;
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_AudioDevInfo_defaultSamplesPerSec_get(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::AudioDevInfo *arg1 = (pj::AudioDevInfo *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  unsigned int result;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__AudioDevInfo, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "AudioDevInfo_defaultSamplesPerSec_get" "', argument " "1"" of type '" "pj::AudioDevInfo *""'"); 
  }
  arg1 = reinterpret_cast< pj::AudioDevInfo * >(argp1);
  result = (unsigned int) ((arg1)->defaultSamplesPerSec);
  resultobj = SWIG_From_unsigned_SS_int(static_cast< unsigned int >(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_AudioDevInfo_driver_set(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::AudioDevInfo *arg1 = (pj::AudioDevInfo *) 0 ;
  pj::string *arg2 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  int res2 = SWIG_OLDOBJ ;
  PyObject *swig_obj[2] ;
  
  if (!SWIG_Python_UnpackTuple(args, "AudioDevInfo_driver_set", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__AudioDevInfo, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "AudioDevInfo_driver_set" "', argument " "1"" of type '" "pj::AudioDevInfo *""'"); 
  }
  arg1 = reinterpret_cast< pj::AudioDevInfo * >(argp1);
  {
    std::string *ptr = (std::string *)0;
    res2 = SWIG_AsPtr_std_string(swig_obj[1], &ptr);
    if (!SWIG_IsOK(res2)) {
      SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "AudioDevInfo_driver_set" "', argument " "2"" of type '" "pj::string const &""'"); 
    }
    if (!ptr) {
      SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "AudioDevInfo_driver_set" "', argument " "2"" of type '" "pj::string const &""'"); 
    }
    arg2 = ptr;
  }
  if (arg1) (arg1)->driver = *arg2;
  resultobj = SWIG_Py_Void();
  if (SWIG_IsNewObj(res2)) delete arg2;
  return resultobj;
fail:
  if (SWIG_IsNewObj(res2)) delete arg2;
  return NULL;
}


SWIGINTERN PyObject *_wrap_AudioDevInfo_driver_get(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::AudioDevInfo *arg1 = (pj::AudioDevInfo *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  pj::string *result = 0 ;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__AudioDevInfo, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "AudioDevInfo_driver_get" "', argument " "1"" of type '" "pj::AudioDevInfo *""'"); 
  }
  arg1 = reinterpret_cast< pj::AudioDevInfo * >(argp1);
  result = (pj::string *) & ((arg1)->driver);
  resultobj = SWIG_From_std_string(static_cast< std::string >(*result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_AudioDevInfo_caps_set(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::AudioDevInfo *arg1 = (pj::AudioDevInfo *) 0 ;
  unsigned int arg2 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  unsigned int val2 ;
  int ecode2 = 0 ;
  PyObject *swig_obj[2] ;
  
  if (!SWIG_Python_UnpackTuple(args, "AudioDevInfo_caps_set", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__AudioDevInfo, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "AudioDevInfo_caps_set" "', argument " "1"" of type '" "pj::AudioDevInfo *""'"); 
  }
  arg1 = reinterpret_cast< pj::AudioDevInfo * >(argp1);
  ecode2 = SWIG_AsVal_unsigned_SS_int(swig_obj[1], &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "AudioDevInfo_caps_set" "', argument " "2"" of type '" "unsigned int""'");
  } 
  arg2 = static_cast< unsigned int >(val2);
  if (arg1) (arg1)->caps = arg2;
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_AudioDevInfo_caps_get(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::AudioDevInfo *arg1 = (pj::AudioDevInfo *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  unsigned int result;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__AudioDevInfo, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "AudioDevInfo_caps_get" "', argument " "1"" of type '" "pj::AudioDevInfo *""'"); 
  }
  arg1 = reinterpret_cast< pj::AudioDevInfo * >(argp1);
  result = (unsigned int) ((arg1)->caps);
  resultobj = SWIG_From_unsigned_SS_int(static_cast< unsigned int >(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_AudioDevInfo_routes_set(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::AudioDevInfo *arg1 = (pj::AudioDevInfo *) 0 ;
  unsigned int arg2 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  unsigned int val2 ;
  int ecode2 = 0 ;
  PyObject *swig_obj[2] ;
  
  if (!SWIG_Python_UnpackTuple(args, "AudioDevInfo_routes_set", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__AudioDevInfo, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "AudioDevInfo_routes_set" "', argument " "1"" of type '" "pj::AudioDevInfo *""'"); 
  }
  arg1 = reinterpret_cast< pj::AudioDevInfo * >(argp1);
  ecode2 = SWIG_AsVal_unsigned_SS_int(swig_obj[1], &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "AudioDevInfo_routes_set" "', argument " "2"" of type '" "unsigned int""'");
  } 
  arg2 = static_cast< unsigned int >(val2);
  if (arg1) (arg1)->routes = arg2;
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_AudioDevInfo_routes_get(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::AudioDevInfo *arg1 = (pj::AudioDevInfo *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  unsigned int result;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__AudioDevInfo, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "AudioDevInfo_routes_get" "', argument " "1"" of type '" "pj::AudioDevInfo *""'"); 
  }
  arg1 = reinterpret_cast< pj::AudioDevInfo * >(argp1);
  result = (unsigned int) ((arg1)->routes);
  resultobj = SWIG_From_unsigned_SS_int(static_cast< unsigned int >(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_AudioDevInfo_extFmt_set(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::AudioDevInfo *arg1 = (pj::AudioDevInfo *) 0 ;
  pj::MediaFormatAudioVector *arg2 = (pj::MediaFormatAudioVector *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  void *argp2 = 0 ;
  int res2 = 0 ;
  PyObject *swig_obj[2] ;
  
  if (!SWIG_Python_UnpackTuple(args, "AudioDevInfo_extFmt_set", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__AudioDevInfo, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "AudioDevInfo_extFmt_set" "', argument " "1"" of type '" "pj::AudioDevInfo *""'"); 
  }
  arg1 = reinterpret_cast< pj::AudioDevInfo * >(argp1);
  res2 = SWIG_ConvertPtr(swig_obj[1], &argp2,SWIGTYPE_p_std__vectorT_pj__MediaFormatAudio_std__allocatorT_pj__MediaFormatAudio_t_t, 0 |  0 );
  if (!SWIG_IsOK(res2)) {
    SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "AudioDevInfo_extFmt_set" "', argument " "2"" of type '" "pj::MediaFormatAudioVector *""'"); 
  }
  arg2 = reinterpret_cast< pj::MediaFormatAudioVector * >(argp2);
  if (arg1) (arg1)->extFmt = *arg2;
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_AudioDevInfo_extFmt_get(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::AudioDevInfo *arg1 = (pj::AudioDevInfo *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  pj::MediaFormatAudioVector *result = 0 ;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__AudioDevInfo, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "AudioDevInfo_extFmt_get" "', argument " "1"" of type '" "pj::AudioDevInfo *""'"); 
  }
  arg1 = reinterpret_cast< pj::AudioDevInfo * >(argp1);
  result = (pj::MediaFormatAudioVector *)& ((arg1)->extFmt);
  resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(result), SWIGTYPE_p_std__vectorT_pj__MediaFormatAudio_std__allocatorT_pj__MediaFormatAudio_t_t, 0 |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_delete_AudioDevInfo(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::AudioDevInfo *arg1 = (pj::AudioDevInfo *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__AudioDevInfo, SWIG_POINTER_DISOWN |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "delete_AudioDevInfo" "', argument " "1"" of type '" "pj::AudioDevInfo *""'"); 
  }
  arg1 = reinterpret_cast< pj::AudioDevInfo * >(argp1);
  delete arg1;
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_new_AudioDevInfo(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::AudioDevInfo *result = 0 ;
  
  if (!SWIG_Python_UnpackTuple(args, "new_AudioDevInfo", 0, 0, 0)) SWIG_fail;
  result = (pj::AudioDevInfo *)new pj::AudioDevInfo();
  resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(result), SWIGTYPE_p_pj__AudioDevInfo, SWIG_POINTER_NEW |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *AudioDevInfo_swigregister(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *obj;
  if (!SWIG_Python_UnpackTuple(args, "swigregister", 1, 1, &obj)) return NULL;
  SWIG_TypeNewClientData(SWIGTYPE_p_pj__AudioDevInfo, SWIG_NewClientData(obj));
  return SWIG_Py_Void();
}

SWIGINTERN PyObject *AudioDevInfo_swiginit(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  return SWIG_Python_InitShadowInstance(args);
}

SWIGINTERN PyObject *_wrap_AudDevManager_getCaptureDev(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::AudDevManager *arg1 = (pj::AudDevManager *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  int result;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__AudDevManager, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "AudDevManager_getCaptureDev" "', argument " "1"" of type '" "pj::AudDevManager const *""'"); 
  }
  arg1 = reinterpret_cast< pj::AudDevManager * >(argp1);
  try {
    result = (int)((pj::AudDevManager const *)arg1)->getCaptureDev();
  } catch(pj::Error &_e) {
    SWIG_Python_Raise(SWIG_NewPointerObj((new pj::Error(static_cast< const pj::Error& >(_e))),SWIGTYPE_p_pj__Error,SWIG_POINTER_OWN), "pj::Error", SWIGTYPE_p_pj__Error); SWIG_fail;
  }
  resultobj = SWIG_From_int(static_cast< int >(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_AudDevManager_getCaptureDevMedia(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::AudDevManager *arg1 = (pj::AudDevManager *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  pj::AudioMedia *result = 0 ;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__AudDevManager, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "AudDevManager_getCaptureDevMedia" "', argument " "1"" of type '" "pj::AudDevManager *""'"); 
  }
  arg1 = reinterpret_cast< pj::AudDevManager * >(argp1);
  try {
    result = (pj::AudioMedia *) &(arg1)->getCaptureDevMedia();
  } catch(pj::Error &_e) {
    SWIG_Python_Raise(SWIG_NewPointerObj((new pj::Error(static_cast< const pj::Error& >(_e))),SWIGTYPE_p_pj__Error,SWIG_POINTER_OWN), "pj::Error", SWIGTYPE_p_pj__Error); SWIG_fail;
  }
  resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(result), SWIGTYPE_p_pj__AudioMedia, 0 |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_AudDevManager_getPlaybackDev(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::AudDevManager *arg1 = (pj::AudDevManager *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  int result;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__AudDevManager, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "AudDevManager_getPlaybackDev" "', argument " "1"" of type '" "pj::AudDevManager const *""'"); 
  }
  arg1 = reinterpret_cast< pj::AudDevManager * >(argp1);
  try {
    result = (int)((pj::AudDevManager const *)arg1)->getPlaybackDev();
  } catch(pj::Error &_e) {
    SWIG_Python_Raise(SWIG_NewPointerObj((new pj::Error(static_cast< const pj::Error& >(_e))),SWIGTYPE_p_pj__Error,SWIG_POINTER_OWN), "pj::Error", SWIGTYPE_p_pj__Error); SWIG_fail;
  }
  resultobj = SWIG_From_int(static_cast< int >(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_AudDevManager_getPlaybackDevMedia(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::AudDevManager *arg1 = (pj::AudDevManager *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  pj::AudioMedia *result = 0 ;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__AudDevManager, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "AudDevManager_getPlaybackDevMedia" "', argument " "1"" of type '" "pj::AudDevManager *""'"); 
  }
  arg1 = reinterpret_cast< pj::AudDevManager * >(argp1);
  try {
    result = (pj::AudioMedia *) &(arg1)->getPlaybackDevMedia();
  } catch(pj::Error &_e) {
    SWIG_Python_Raise(SWIG_NewPointerObj((new pj::Error(static_cast< const pj::Error& >(_e))),SWIGTYPE_p_pj__Error,SWIG_POINTER_OWN), "pj::Error", SWIGTYPE_p_pj__Error); SWIG_fail;
  }
  resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(result), SWIGTYPE_p_pj__AudioMedia, 0 |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_AudDevManager_setCaptureDev(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::AudDevManager *arg1 = (pj::AudDevManager *) 0 ;
  int arg2 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  int val2 ;
  int ecode2 = 0 ;
  PyObject *swig_obj[2] ;
  
  if (!SWIG_Python_UnpackTuple(args, "AudDevManager_setCaptureDev", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__AudDevManager, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "AudDevManager_setCaptureDev" "', argument " "1"" of type '" "pj::AudDevManager const *""'"); 
  }
  arg1 = reinterpret_cast< pj::AudDevManager * >(argp1);
  ecode2 = SWIG_AsVal_int(swig_obj[1], &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "AudDevManager_setCaptureDev" "', argument " "2"" of type '" "int""'");
  } 
  arg2 = static_cast< int >(val2);
  try {
    ((pj::AudDevManager const *)arg1)->setCaptureDev(arg2);
  } catch(pj::Error &_e) {
    SWIG_Python_Raise(SWIG_NewPointerObj((new pj::Error(static_cast< const pj::Error& >(_e))),SWIGTYPE_p_pj__Error,SWIG_POINTER_OWN), "pj::Error", SWIGTYPE_p_pj__Error); SWIG_fail;
  }
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_AudDevManager_setPlaybackDev(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::AudDevManager *arg1 = (pj::AudDevManager *) 0 ;
  int arg2 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  int val2 ;
  int ecode2 = 0 ;
  PyObject *swig_obj[2] ;
  
  if (!SWIG_Python_UnpackTuple(args, "AudDevManager_setPlaybackDev", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__AudDevManager, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "AudDevManager_setPlaybackDev" "', argument " "1"" of type '" "pj::AudDevManager const *""'"); 
  }
  arg1 = reinterpret_cast< pj::AudDevManager * >(argp1);
  ecode2 = SWIG_AsVal_int(swig_obj[1], &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "AudDevManager_setPlaybackDev" "', argument " "2"" of type '" "int""'");
  } 
  arg2 = static_cast< int >(val2);
  try {
    ((pj::AudDevManager const *)arg1)->setPlaybackDev(arg2);
  } catch(pj::Error &_e) {
    SWIG_Python_Raise(SWIG_NewPointerObj((new pj::Error(static_cast< const pj::Error& >(_e))),SWIGTYPE_p_pj__Error,SWIG_POINTER_OWN), "pj::Error", SWIGTYPE_p_pj__Error); SWIG_fail;
  }
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_AudDevManager_enumDev2(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::AudDevManager *arg1 = (pj::AudDevManager *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  pj::AudioDevInfoVector2 result;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__AudDevManager, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "AudDevManager_enumDev2" "', argument " "1"" of type '" "pj::AudDevManager const *""'"); 
  }
  arg1 = reinterpret_cast< pj::AudDevManager * >(argp1);
  try {
    result = ((pj::AudDevManager const *)arg1)->enumDev2();
  } catch(pj::Error &_e) {
    SWIG_Python_Raise(SWIG_NewPointerObj((new pj::Error(static_cast< const pj::Error& >(_e))),SWIGTYPE_p_pj__Error,SWIG_POINTER_OWN), "pj::Error", SWIGTYPE_p_pj__Error); SWIG_fail;
  }
  resultobj = swig::from(static_cast< std::vector< pj::AudioDevInfo,std::allocator< pj::AudioDevInfo > > >(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_AudDevManager_setNullDev(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::AudDevManager *arg1 = (pj::AudDevManager *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__AudDevManager, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "AudDevManager_setNullDev" "', argument " "1"" of type '" "pj::AudDevManager *""'"); 
  }
  arg1 = reinterpret_cast< pj::AudDevManager * >(argp1);
  try {
    (arg1)->setNullDev();
  } catch(pj::Error &_e) {
    SWIG_Python_Raise(SWIG_NewPointerObj((new pj::Error(static_cast< const pj::Error& >(_e))),SWIGTYPE_p_pj__Error,SWIG_POINTER_OWN), "pj::Error", SWIGTYPE_p_pj__Error); SWIG_fail;
  }
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_AudDevManager_setNoDev(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::AudDevManager *arg1 = (pj::AudDevManager *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  pj::MediaPort *result = 0 ;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__AudDevManager, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "AudDevManager_setNoDev" "', argument " "1"" of type '" "pj::AudDevManager *""'"); 
  }
  arg1 = reinterpret_cast< pj::AudDevManager * >(argp1);
  result = (pj::MediaPort *)(arg1)->setNoDev();
  resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(result), SWIGTYPE_p_p_void, 0 |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_AudDevManager_setSndDevMode(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::AudDevManager *arg1 = (pj::AudDevManager *) 0 ;
  unsigned int arg2 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  unsigned int val2 ;
  int ecode2 = 0 ;
  PyObject *swig_obj[2] ;
  
  if (!SWIG_Python_UnpackTuple(args, "AudDevManager_setSndDevMode", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__AudDevManager, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "AudDevManager_setSndDevMode" "', argument " "1"" of type '" "pj::AudDevManager const *""'"); 
  }
  arg1 = reinterpret_cast< pj::AudDevManager * >(argp1);
  ecode2 = SWIG_AsVal_unsigned_SS_int(swig_obj[1], &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "AudDevManager_setSndDevMode" "', argument " "2"" of type '" "unsigned int""'");
  } 
  arg2 = static_cast< unsigned int >(val2);
  try {
    ((pj::AudDevManager const *)arg1)->setSndDevMode(arg2);
  } catch(pj::Error &_e) {
    SWIG_Python_Raise(SWIG_NewPointerObj((new pj::Error(static_cast< const pj::Error& >(_e))),SWIGTYPE_p_pj__Error,SWIG_POINTER_OWN), "pj::Error", SWIGTYPE_p_pj__Error); SWIG_fail;
  }
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_AudDevManager_setEcOptions(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::AudDevManager *arg1 = (pj::AudDevManager *) 0 ;
  unsigned int arg2 ;
  unsigned int arg3 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  unsigned int val2 ;
  int ecode2 = 0 ;
  unsigned int val3 ;
  int ecode3 = 0 ;
  PyObject *swig_obj[3] ;
  
  if (!SWIG_Python_UnpackTuple(args, "AudDevManager_setEcOptions", 3, 3, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__AudDevManager, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "AudDevManager_setEcOptions" "', argument " "1"" of type '" "pj::AudDevManager *""'"); 
  }
  arg1 = reinterpret_cast< pj::AudDevManager * >(argp1);
  ecode2 = SWIG_AsVal_unsigned_SS_int(swig_obj[1], &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "AudDevManager_setEcOptions" "', argument " "2"" of type '" "unsigned int""'");
  } 
  arg2 = static_cast< unsigned int >(val2);
  ecode3 = SWIG_AsVal_unsigned_SS_int(swig_obj[2], &val3);
  if (!SWIG_IsOK(ecode3)) {
    SWIG_exception_fail(SWIG_ArgError(ecode3), "in method '" "AudDevManager_setEcOptions" "', argument " "3"" of type '" "unsigned int""'");
  } 
  arg3 = static_cast< unsigned int >(val3);
  try {
    (arg1)->setEcOptions(arg2,arg3);
  } catch(pj::Error &_e) {
    SWIG_Python_Raise(SWIG_NewPointerObj((new pj::Error(static_cast< const pj::Error& >(_e))),SWIGTYPE_p_pj__Error,SWIG_POINTER_OWN), "pj::Error", SWIGTYPE_p_pj__Error); SWIG_fail;
  }
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_AudDevManager_getEcTail(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::AudDevManager *arg1 = (pj::AudDevManager *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  unsigned int result;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__AudDevManager, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "AudDevManager_getEcTail" "', argument " "1"" of type '" "pj::AudDevManager const *""'"); 
  }
  arg1 = reinterpret_cast< pj::AudDevManager * >(argp1);
  try {
    result = (unsigned int)((pj::AudDevManager const *)arg1)->getEcTail();
  } catch(pj::Error &_e) {
    SWIG_Python_Raise(SWIG_NewPointerObj((new pj::Error(static_cast< const pj::Error& >(_e))),SWIGTYPE_p_pj__Error,SWIG_POINTER_OWN), "pj::Error", SWIGTYPE_p_pj__Error); SWIG_fail;
  }
  resultobj = SWIG_From_unsigned_SS_int(static_cast< unsigned int >(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_AudDevManager_sndIsActive(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::AudDevManager *arg1 = (pj::AudDevManager *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  bool result;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__AudDevManager, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "AudDevManager_sndIsActive" "', argument " "1"" of type '" "pj::AudDevManager const *""'"); 
  }
  arg1 = reinterpret_cast< pj::AudDevManager * >(argp1);
  result = (bool)((pj::AudDevManager const *)arg1)->sndIsActive();
  resultobj = SWIG_From_bool(static_cast< bool >(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_AudDevManager_refreshDevs(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::AudDevManager *arg1 = (pj::AudDevManager *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__AudDevManager, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "AudDevManager_refreshDevs" "', argument " "1"" of type '" "pj::AudDevManager *""'"); 
  }
  arg1 = reinterpret_cast< pj::AudDevManager * >(argp1);
  try {
    (arg1)->refreshDevs();
  } catch(pj::Error &_e) {
    SWIG_Python_Raise(SWIG_NewPointerObj((new pj::Error(static_cast< const pj::Error& >(_e))),SWIGTYPE_p_pj__Error,SWIG_POINTER_OWN), "pj::Error", SWIGTYPE_p_pj__Error); SWIG_fail;
  }
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_AudDevManager_getDevCount(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::AudDevManager *arg1 = (pj::AudDevManager *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  unsigned int result;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__AudDevManager, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "AudDevManager_getDevCount" "', argument " "1"" of type '" "pj::AudDevManager const *""'"); 
  }
  arg1 = reinterpret_cast< pj::AudDevManager * >(argp1);
  result = (unsigned int)((pj::AudDevManager const *)arg1)->getDevCount();
  resultobj = SWIG_From_unsigned_SS_int(static_cast< unsigned int >(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_AudDevManager_getDevInfo(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::AudDevManager *arg1 = (pj::AudDevManager *) 0 ;
  int arg2 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  int val2 ;
  int ecode2 = 0 ;
  PyObject *swig_obj[2] ;
  pj::AudioDevInfo result;
  
  if (!SWIG_Python_UnpackTuple(args, "AudDevManager_getDevInfo", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__AudDevManager, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "AudDevManager_getDevInfo" "', argument " "1"" of type '" "pj::AudDevManager const *""'"); 
  }
  arg1 = reinterpret_cast< pj::AudDevManager * >(argp1);
  ecode2 = SWIG_AsVal_int(swig_obj[1], &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "AudDevManager_getDevInfo" "', argument " "2"" of type '" "int""'");
  } 
  arg2 = static_cast< int >(val2);
  try {
    result = ((pj::AudDevManager const *)arg1)->getDevInfo(arg2);
  } catch(pj::Error &_e) {
    SWIG_Python_Raise(SWIG_NewPointerObj((new pj::Error(static_cast< const pj::Error& >(_e))),SWIGTYPE_p_pj__Error,SWIG_POINTER_OWN), "pj::Error", SWIGTYPE_p_pj__Error); SWIG_fail;
  }
  resultobj = SWIG_NewPointerObj((new pj::AudioDevInfo(static_cast< const pj::AudioDevInfo& >(result))), SWIGTYPE_p_pj__AudioDevInfo, SWIG_POINTER_OWN |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_AudDevManager_lookupDev(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::AudDevManager *arg1 = (pj::AudDevManager *) 0 ;
  pj::string *arg2 = 0 ;
  pj::string *arg3 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  int res2 = SWIG_OLDOBJ ;
  int res3 = SWIG_OLDOBJ ;
  PyObject *swig_obj[3] ;
  int result;
  
  if (!SWIG_Python_UnpackTuple(args, "AudDevManager_lookupDev", 3, 3, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__AudDevManager, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "AudDevManager_lookupDev" "', argument " "1"" of type '" "pj::AudDevManager const *""'"); 
  }
  arg1 = reinterpret_cast< pj::AudDevManager * >(argp1);
  {
    std::string *ptr = (std::string *)0;
    res2 = SWIG_AsPtr_std_string(swig_obj[1], &ptr);
    if (!SWIG_IsOK(res2)) {
      SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "AudDevManager_lookupDev" "', argument " "2"" of type '" "pj::string const &""'"); 
    }
    if (!ptr) {
      SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "AudDevManager_lookupDev" "', argument " "2"" of type '" "pj::string const &""'"); 
    }
    arg2 = ptr;
  }
  {
    std::string *ptr = (std::string *)0;
    res3 = SWIG_AsPtr_std_string(swig_obj[2], &ptr);
    if (!SWIG_IsOK(res3)) {
      SWIG_exception_fail(SWIG_ArgError(res3), "in method '" "AudDevManager_lookupDev" "', argument " "3"" of type '" "pj::string const &""'"); 
    }
    if (!ptr) {
      SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "AudDevManager_lookupDev" "', argument " "3"" of type '" "pj::string const &""'"); 
    }
    arg3 = ptr;
  }
  try {
    result = (int)((pj::AudDevManager const *)arg1)->lookupDev((pj::string const &)*arg2,(pj::string const &)*arg3);
  } catch(pj::Error &_e) {
    SWIG_Python_Raise(SWIG_NewPointerObj((new pj::Error(static_cast< const pj::Error& >(_e))),SWIGTYPE_p_pj__Error,SWIG_POINTER_OWN), "pj::Error", SWIGTYPE_p_pj__Error); SWIG_fail;
  }
  resultobj = SWIG_From_int(static_cast< int >(result));
  if (SWIG_IsNewObj(res2)) delete arg2;
  if (SWIG_IsNewObj(res3)) delete arg3;
  return resultobj;
fail:
  if (SWIG_IsNewObj(res2)) delete arg2;
  if (SWIG_IsNewObj(res3)) delete arg3;
  return NULL;
}


SWIGINTERN PyObject *_wrap_AudDevManager_capName(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::AudDevManager *arg1 = (pj::AudDevManager *) 0 ;
  pjmedia_aud_dev_cap arg2 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  int val2 ;
  int ecode2 = 0 ;
  PyObject *swig_obj[2] ;
  pj::string result;
  
  if (!SWIG_Python_UnpackTuple(args, "AudDevManager_capName", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__AudDevManager, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "AudDevManager_capName" "', argument " "1"" of type '" "pj::AudDevManager const *""'"); 
  }
  arg1 = reinterpret_cast< pj::AudDevManager * >(argp1);
  ecode2 = SWIG_AsVal_int(swig_obj[1], &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "AudDevManager_capName" "', argument " "2"" of type '" "pjmedia_aud_dev_cap""'");
  } 
  arg2 = static_cast< pjmedia_aud_dev_cap >(val2);
  result = ((pj::AudDevManager const *)arg1)->capName(arg2);
  resultobj = SWIG_From_std_string(static_cast< std::string >(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_AudDevManager_setExtFormat__SWIG_0(PyObject *SWIGUNUSEDPARM(self), Py_ssize_t nobjs, PyObject **swig_obj) {
  PyObject *resultobj = 0;
  pj::AudDevManager *arg1 = (pj::AudDevManager *) 0 ;
  pj::MediaFormatAudio *arg2 = 0 ;
  bool arg3 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  void *argp2 = 0 ;
  int res2 = 0 ;
  bool val3 ;
  int ecode3 = 0 ;
  
  if ((nobjs < 3) || (nobjs > 3)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__AudDevManager, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "AudDevManager_setExtFormat" "', argument " "1"" of type '" "pj::AudDevManager *""'"); 
  }
  arg1 = reinterpret_cast< pj::AudDevManager * >(argp1);
  res2 = SWIG_ConvertPtr(swig_obj[1], &argp2, SWIGTYPE_p_pj__MediaFormatAudio,  0  | 0);
  if (!SWIG_IsOK(res2)) {
    SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "AudDevManager_setExtFormat" "', argument " "2"" of type '" "pj::MediaFormatAudio const &""'"); 
  }
  if (!argp2) {
    SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "AudDevManager_setExtFormat" "', argument " "2"" of type '" "pj::MediaFormatAudio const &""'"); 
  }
  arg2 = reinterpret_cast< pj::MediaFormatAudio * >(argp2);
  ecode3 = SWIG_AsVal_bool(swig_obj[2], &val3);
  if (!SWIG_IsOK(ecode3)) {
    SWIG_exception_fail(SWIG_ArgError(ecode3), "in method '" "AudDevManager_setExtFormat" "', argument " "3"" of type '" "bool""'");
  } 
  arg3 = static_cast< bool >(val3);
  try {
    (arg1)->setExtFormat((pj::MediaFormatAudio const &)*arg2,arg3);
  } catch(pj::Error &_e) {
    SWIG_Python_Raise(SWIG_NewPointerObj((new pj::Error(static_cast< const pj::Error& >(_e))),SWIGTYPE_p_pj__Error,SWIG_POINTER_OWN), "pj::Error", SWIGTYPE_p_pj__Error); SWIG_fail;
  }
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_AudDevManager_setExtFormat__SWIG_1(PyObject *SWIGUNUSEDPARM(self), Py_ssize_t nobjs, PyObject **swig_obj) {
  PyObject *resultobj = 0;
  pj::AudDevManager *arg1 = (pj::AudDevManager *) 0 ;
  pj::MediaFormatAudio *arg2 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  void *argp2 = 0 ;
  int res2 = 0 ;
  
  if ((nobjs < 2) || (nobjs > 2)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__AudDevManager, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "AudDevManager_setExtFormat" "', argument " "1"" of type '" "pj::AudDevManager *""'"); 
  }
  arg1 = reinterpret_cast< pj::AudDevManager * >(argp1);
  res2 = SWIG_ConvertPtr(swig_obj[1], &argp2, SWIGTYPE_p_pj__MediaFormatAudio,  0  | 0);
  if (!SWIG_IsOK(res2)) {
    SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "AudDevManager_setExtFormat" "', argument " "2"" of type '" "pj::MediaFormatAudio const &""'"); 
  }
  if (!argp2) {
    SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "AudDevManager_setExtFormat" "', argument " "2"" of type '" "pj::MediaFormatAudio const &""'"); 
  }
  arg2 = reinterpret_cast< pj::MediaFormatAudio * >(argp2);
  try {
    (arg1)->setExtFormat((pj::MediaFormatAudio const &)*arg2);
  } catch(pj::Error &_e) {
    SWIG_Python_Raise(SWIG_NewPointerObj((new pj::Error(static_cast< const pj::Error& >(_e))),SWIGTYPE_p_pj__Error,SWIG_POINTER_OWN), "pj::Error", SWIGTYPE_p_pj__Error); SWIG_fail;
  }
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_AudDevManager_setExtFormat(PyObject *self, PyObject *args) {
  Py_ssize_t argc;
  PyObject *argv[4] = {
    0
  };
  
  if (!(argc = SWIG_Python_UnpackTuple(args, "AudDevManager_setExtFormat", 0, 3, argv))) SWIG_fail;
  --argc;
  if (argc == 2) {
    int _v;
    void *vptr = 0;
    int res = SWIG_ConvertPtr(argv[0], &vptr, SWIGTYPE_p_pj__AudDevManager, 0);
    _v = SWIG_CheckState(res);
    if (_v) {
      int res = SWIG_ConvertPtr(argv[1], 0, SWIGTYPE_p_pj__MediaFormatAudio, SWIG_POINTER_NO_NULL | 0);
      _v = SWIG_CheckState(res);
      if (_v) {
        return _wrap_AudDevManager_setExtFormat__SWIG_1(self, argc, argv);
      }
    }
  }
  if (argc == 3) {
    int _v;
    void *vptr = 0;
    int res = SWIG_ConvertPtr(argv[0], &vptr, SWIGTYPE_p_pj__AudDevManager, 0);
    _v = SWIG_CheckState(res);
    if (_v) {
      int res = SWIG_ConvertPtr(argv[1], 0, SWIGTYPE_p_pj__MediaFormatAudio, SWIG_POINTER_NO_NULL | 0);
      _v = SWIG_CheckState(res);
      if (_v) {
        {
          int res = SWIG_AsVal_bool(argv[2], NULL);
          _v = SWIG_CheckState(res);
        }
        if (_v) {
          return _wrap_AudDevManager_setExtFormat__SWIG_0(self, argc, argv);
        }
      }
    }
  }
  
fail:
  SWIG_Python_RaiseOrModifyTypeError("Wrong number or type of arguments for overloaded function 'AudDevManager_setExtFormat'.\n"
    "  Possible C/C++ prototypes are:\n"
    "    pj::AudDevManager::setExtFormat(pj::MediaFormatAudio const &,bool)\n"
    "    pj::AudDevManager::setExtFormat(pj::MediaFormatAudio const &)\n");
  return 0;
}


SWIGINTERN PyObject *_wrap_AudDevManager_getExtFormat(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::AudDevManager *arg1 = (pj::AudDevManager *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  pj::MediaFormatAudio result;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__AudDevManager, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "AudDevManager_getExtFormat" "', argument " "1"" of type '" "pj::AudDevManager const *""'"); 
  }
  arg1 = reinterpret_cast< pj::AudDevManager * >(argp1);
  try {
    result = ((pj::AudDevManager const *)arg1)->getExtFormat();
  } catch(pj::Error &_e) {
    SWIG_Python_Raise(SWIG_NewPointerObj((new pj::Error(static_cast< const pj::Error& >(_e))),SWIGTYPE_p_pj__Error,SWIG_POINTER_OWN), "pj::Error", SWIGTYPE_p_pj__Error); SWIG_fail;
  }
  resultobj = SWIG_NewPointerObj((new pj::MediaFormatAudio(static_cast< const pj::MediaFormatAudio& >(result))), SWIGTYPE_p_pj__MediaFormatAudio, SWIG_POINTER_OWN |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_AudDevManager_setInputLatency__SWIG_0(PyObject *SWIGUNUSEDPARM(self), Py_ssize_t nobjs, PyObject **swig_obj) {
  PyObject *resultobj = 0;
  pj::AudDevManager *arg1 = (pj::AudDevManager *) 0 ;
  unsigned int arg2 ;
  bool arg3 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  unsigned int val2 ;
  int ecode2 = 0 ;
  bool val3 ;
  int ecode3 = 0 ;
  
  if ((nobjs < 3) || (nobjs > 3)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__AudDevManager, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "AudDevManager_setInputLatency" "', argument " "1"" of type '" "pj::AudDevManager *""'"); 
  }
  arg1 = reinterpret_cast< pj::AudDevManager * >(argp1);
  ecode2 = SWIG_AsVal_unsigned_SS_int(swig_obj[1], &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "AudDevManager_setInputLatency" "', argument " "2"" of type '" "unsigned int""'");
  } 
  arg2 = static_cast< unsigned int >(val2);
  ecode3 = SWIG_AsVal_bool(swig_obj[2], &val3);
  if (!SWIG_IsOK(ecode3)) {
    SWIG_exception_fail(SWIG_ArgError(ecode3), "in method '" "AudDevManager_setInputLatency" "', argument " "3"" of type '" "bool""'");
  } 
  arg3 = static_cast< bool >(val3);
  try {
    (arg1)->setInputLatency(arg2,arg3);
  } catch(pj::Error &_e) {
    SWIG_Python_Raise(SWIG_NewPointerObj((new pj::Error(static_cast< const pj::Error& >(_e))),SWIGTYPE_p_pj__Error,SWIG_POINTER_OWN), "pj::Error", SWIGTYPE_p_pj__Error); SWIG_fail;
  }
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_AudDevManager_setInputLatency__SWIG_1(PyObject *SWIGUNUSEDPARM(self), Py_ssize_t nobjs, PyObject **swig_obj) {
  PyObject *resultobj = 0;
  pj::AudDevManager *arg1 = (pj::AudDevManager *) 0 ;
  unsigned int arg2 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  unsigned int val2 ;
  int ecode2 = 0 ;
  
  if ((nobjs < 2) || (nobjs > 2)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__AudDevManager, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "AudDevManager_setInputLatency" "', argument " "1"" of type '" "pj::AudDevManager *""'"); 
  }
  arg1 = reinterpret_cast< pj::AudDevManager * >(argp1);
  ecode2 = SWIG_AsVal_unsigned_SS_int(swig_obj[1], &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "AudDevManager_setInputLatency" "', argument " "2"" of type '" "unsigned int""'");
  } 
  arg2 = static_cast< unsigned int >(val2);
  try {
    (arg1)->setInputLatency(arg2);
  } catch(pj::Error &_e) {
    SWIG_Python_Raise(SWIG_NewPointerObj((new pj::Error(static_cast< const pj::Error& >(_e))),SWIGTYPE_p_pj__Error,SWIG_POINTER_OWN), "pj::Error", SWIGTYPE_p_pj__Error); SWIG_fail;
  }
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_AudDevManager_setInputLatency(PyObject *self, PyObject *args) {
  Py_ssize_t argc;
  PyObject *argv[4] = {
    0
  };
  
  if (!(argc = SWIG_Python_UnpackTuple(args, "AudDevManager_setInputLatency", 0, 3, argv))) SWIG_fail;
  --argc;
  if (argc == 2) {
    int _v;
    void *vptr = 0;
    int res = SWIG_ConvertPtr(argv[0], &vptr, SWIGTYPE_p_pj__AudDevManager, 0);
    _v = SWIG_CheckState(res);
    if (_v) {
      {
        int res = SWIG_AsVal_unsigned_SS_int(argv[1], NULL);
        _v = SWIG_CheckState(res);
      }
      if (_v) {
        return _wrap_AudDevManager_setInputLatency__SWIG_1(self, argc, argv);
      }
    }
  }
  if (argc == 3) {
    int _v;
    void *vptr = 0;
    int res = SWIG_ConvertPtr(argv[0], &vptr, SWIGTYPE_p_pj__AudDevManager, 0);
    _v = SWIG_CheckState(res);
    if (_v) {
      {
        int res = SWIG_AsVal_unsigned_SS_int(argv[1], NULL);
        _v = SWIG_CheckState(res);
      }
      if (_v) {
        {
          int res = SWIG_AsVal_bool(argv[2], NULL);
          _v = SWIG_CheckState(res);
        }
        if (_v) {
          return _wrap_AudDevManager_setInputLatency__SWIG_0(self, argc, argv);
        }
      }
    }
  }
  
fail:
  SWIG_Python_RaiseOrModifyTypeError("Wrong number or type of arguments for overloaded function 'AudDevManager_setInputLatency'.\n"
    "  Possible C/C++ prototypes are:\n"
    "    pj::AudDevManager::setInputLatency(unsigned int,bool)\n"
    "    pj::AudDevManager::setInputLatency(unsigned int)\n");
  return 0;
}


SWIGINTERN PyObject *_wrap_AudDevManager_getInputLatency(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::AudDevManager *arg1 = (pj::AudDevManager *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  unsigned int result;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__AudDevManager, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "AudDevManager_getInputLatency" "', argument " "1"" of type '" "pj::AudDevManager const *""'"); 
  }
  arg1 = reinterpret_cast< pj::AudDevManager * >(argp1);
  try {
    result = (unsigned int)((pj::AudDevManager const *)arg1)->getInputLatency();
  } catch(pj::Error &_e) {
    SWIG_Python_Raise(SWIG_NewPointerObj((new pj::Error(static_cast< const pj::Error& >(_e))),SWIGTYPE_p_pj__Error,SWIG_POINTER_OWN), "pj::Error", SWIGTYPE_p_pj__Error); SWIG_fail;
  }
  resultobj = SWIG_From_unsigned_SS_int(static_cast< unsigned int >(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_AudDevManager_setOutputLatency__SWIG_0(PyObject *SWIGUNUSEDPARM(self), Py_ssize_t nobjs, PyObject **swig_obj) {
  PyObject *resultobj = 0;
  pj::AudDevManager *arg1 = (pj::AudDevManager *) 0 ;
  unsigned int arg2 ;
  bool arg3 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  unsigned int val2 ;
  int ecode2 = 0 ;
  bool val3 ;
  int ecode3 = 0 ;
  
  if ((nobjs < 3) || (nobjs > 3)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__AudDevManager, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "AudDevManager_setOutputLatency" "', argument " "1"" of type '" "pj::AudDevManager *""'"); 
  }
  arg1 = reinterpret_cast< pj::AudDevManager * >(argp1);
  ecode2 = SWIG_AsVal_unsigned_SS_int(swig_obj[1], &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "AudDevManager_setOutputLatency" "', argument " "2"" of type '" "unsigned int""'");
  } 
  arg2 = static_cast< unsigned int >(val2);
  ecode3 = SWIG_AsVal_bool(swig_obj[2], &val3);
  if (!SWIG_IsOK(ecode3)) {
    SWIG_exception_fail(SWIG_ArgError(ecode3), "in method '" "AudDevManager_setOutputLatency" "', argument " "3"" of type '" "bool""'");
  } 
  arg3 = static_cast< bool >(val3);
  try {
    (arg1)->setOutputLatency(arg2,arg3);
  } catch(pj::Error &_e) {
    SWIG_Python_Raise(SWIG_NewPointerObj((new pj::Error(static_cast< const pj::Error& >(_e))),SWIGTYPE_p_pj__Error,SWIG_POINTER_OWN), "pj::Error", SWIGTYPE_p_pj__Error); SWIG_fail;
  }
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_AudDevManager_setOutputLatency__SWIG_1(PyObject *SWIGUNUSEDPARM(self), Py_ssize_t nobjs, PyObject **swig_obj) {
  PyObject *resultobj = 0;
  pj::AudDevManager *arg1 = (pj::AudDevManager *) 0 ;
  unsigned int arg2 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  unsigned int val2 ;
  int ecode2 = 0 ;
  
  if ((nobjs < 2) || (nobjs > 2)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__AudDevManager, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "AudDevManager_setOutputLatency" "', argument " "1"" of type '" "pj::AudDevManager *""'"); 
  }
  arg1 = reinterpret_cast< pj::AudDevManager * >(argp1);
  ecode2 = SWIG_AsVal_unsigned_SS_int(swig_obj[1], &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "AudDevManager_setOutputLatency" "', argument " "2"" of type '" "unsigned int""'");
  } 
  arg2 = static_cast< unsigned int >(val2);
  try {
    (arg1)->setOutputLatency(arg2);
  } catch(pj::Error &_e) {
    SWIG_Python_Raise(SWIG_NewPointerObj((new pj::Error(static_cast< const pj::Error& >(_e))),SWIGTYPE_p_pj__Error,SWIG_POINTER_OWN), "pj::Error", SWIGTYPE_p_pj__Error); SWIG_fail;
  }
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_AudDevManager_setOutputLatency(PyObject *self, PyObject *args) {
  Py_ssize_t argc;
  PyObject *argv[4] = {
    0
  };
  
  if (!(argc = SWIG_Python_UnpackTuple(args, "AudDevManager_setOutputLatency", 0, 3, argv))) SWIG_fail;
  --argc;
  if (argc == 2) {
    int _v;
    void *vptr = 0;
    int res = SWIG_ConvertPtr(argv[0], &vptr, SWIGTYPE_p_pj__AudDevManager, 0);
    _v = SWIG_CheckState(res);
    if (_v) {
      {
        int res = SWIG_AsVal_unsigned_SS_int(argv[1], NULL);
        _v = SWIG_CheckState(res);
      }
      if (_v) {
        return _wrap_AudDevManager_setOutputLatency__SWIG_1(self, argc, argv);
      }
    }
  }
  if (argc == 3) {
    int _v;
    void *vptr = 0;
    int res = SWIG_ConvertPtr(argv[0], &vptr, SWIGTYPE_p_pj__AudDevManager, 0);
    _v = SWIG_CheckState(res);
    if (_v) {
      {
        int res = SWIG_AsVal_unsigned_SS_int(argv[1], NULL);
        _v = SWIG_CheckState(res);
      }
      if (_v) {
        {
          int res = SWIG_AsVal_bool(argv[2], NULL);
          _v = SWIG_CheckState(res);
        }
        if (_v) {
          return _wrap_AudDevManager_setOutputLatency__SWIG_0(self, argc, argv);
        }
      }
    }
  }
  
fail:
  SWIG_Python_RaiseOrModifyTypeError("Wrong number or type of arguments for overloaded function 'AudDevManager_setOutputLatency'.\n"
    "  Possible C/C++ prototypes are:\n"
    "    pj::AudDevManager::setOutputLatency(unsigned int,bool)\n"
    "    pj::AudDevManager::setOutputLatency(unsigned int)\n");
  return 0;
}


SWIGINTERN PyObject *_wrap_AudDevManager_getOutputLatency(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::AudDevManager *arg1 = (pj::AudDevManager *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  unsigned int result;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__AudDevManager, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "AudDevManager_getOutputLatency" "', argument " "1"" of type '" "pj::AudDevManager const *""'"); 
  }
  arg1 = reinterpret_cast< pj::AudDevManager * >(argp1);
  try {
    result = (unsigned int)((pj::AudDevManager const *)arg1)->getOutputLatency();
  } catch(pj::Error &_e) {
    SWIG_Python_Raise(SWIG_NewPointerObj((new pj::Error(static_cast< const pj::Error& >(_e))),SWIGTYPE_p_pj__Error,SWIG_POINTER_OWN), "pj::Error", SWIGTYPE_p_pj__Error); SWIG_fail;
  }
  resultobj = SWIG_From_unsigned_SS_int(static_cast< unsigned int >(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_AudDevManager_setInputVolume__SWIG_0(PyObject *SWIGUNUSEDPARM(self), Py_ssize_t nobjs, PyObject **swig_obj) {
  PyObject *resultobj = 0;
  pj::AudDevManager *arg1 = (pj::AudDevManager *) 0 ;
  unsigned int arg2 ;
  bool arg3 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  unsigned int val2 ;
  int ecode2 = 0 ;
  bool val3 ;
  int ecode3 = 0 ;
  
  if ((nobjs < 3) || (nobjs > 3)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__AudDevManager, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "AudDevManager_setInputVolume" "', argument " "1"" of type '" "pj::AudDevManager *""'"); 
  }
  arg1 = reinterpret_cast< pj::AudDevManager * >(argp1);
  ecode2 = SWIG_AsVal_unsigned_SS_int(swig_obj[1], &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "AudDevManager_setInputVolume" "', argument " "2"" of type '" "unsigned int""'");
  } 
  arg2 = static_cast< unsigned int >(val2);
  ecode3 = SWIG_AsVal_bool(swig_obj[2], &val3);
  if (!SWIG_IsOK(ecode3)) {
    SWIG_exception_fail(SWIG_ArgError(ecode3), "in method '" "AudDevManager_setInputVolume" "', argument " "3"" of type '" "bool""'");
  } 
  arg3 = static_cast< bool >(val3);
  try {
    (arg1)->setInputVolume(arg2,arg3);
  } catch(pj::Error &_e) {
    SWIG_Python_Raise(SWIG_NewPointerObj((new pj::Error(static_cast< const pj::Error& >(_e))),SWIGTYPE_p_pj__Error,SWIG_POINTER_OWN), "pj::Error", SWIGTYPE_p_pj__Error); SWIG_fail;
  }
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_AudDevManager_setInputVolume__SWIG_1(PyObject *SWIGUNUSEDPARM(self), Py_ssize_t nobjs, PyObject **swig_obj) {
  PyObject *resultobj = 0;
  pj::AudDevManager *arg1 = (pj::AudDevManager *) 0 ;
  unsigned int arg2 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  unsigned int val2 ;
  int ecode2 = 0 ;
  
  if ((nobjs < 2) || (nobjs > 2)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__AudDevManager, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "AudDevManager_setInputVolume" "', argument " "1"" of type '" "pj::AudDevManager *""'"); 
  }
  arg1 = reinterpret_cast< pj::AudDevManager * >(argp1);
  ecode2 = SWIG_AsVal_unsigned_SS_int(swig_obj[1], &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "AudDevManager_setInputVolume" "', argument " "2"" of type '" "unsigned int""'");
  } 
  arg2 = static_cast< unsigned int >(val2);
  try {
    (arg1)->setInputVolume(arg2);
  } catch(pj::Error &_e) {
    SWIG_Python_Raise(SWIG_NewPointerObj((new pj::Error(static_cast< const pj::Error& >(_e))),SWIGTYPE_p_pj__Error,SWIG_POINTER_OWN), "pj::Error", SWIGTYPE_p_pj__Error); SWIG_fail;
  }
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_AudDevManager_setInputVolume(PyObject *self, PyObject *args) {
  Py_ssize_t argc;
  PyObject *argv[4] = {
    0
  };
  
  if (!(argc = SWIG_Python_UnpackTuple(args, "AudDevManager_setInputVolume", 0, 3, argv))) SWIG_fail;
  --argc;
  if (argc == 2) {
    int _v;
    void *vptr = 0;
    int res = SWIG_ConvertPtr(argv[0], &vptr, SWIGTYPE_p_pj__AudDevManager, 0);
    _v = SWIG_CheckState(res);
    if (_v) {
      {
        int res = SWIG_AsVal_unsigned_SS_int(argv[1], NULL);
        _v = SWIG_CheckState(res);
      }
      if (_v) {
        return _wrap_AudDevManager_setInputVolume__SWIG_1(self, argc, argv);
      }
    }
  }
  if (argc == 3) {
    int _v;
    void *vptr = 0;
    int res = SWIG_ConvertPtr(argv[0], &vptr, SWIGTYPE_p_pj__AudDevManager, 0);
    _v = SWIG_CheckState(res);
    if (_v) {
      {
        int res = SWIG_AsVal_unsigned_SS_int(argv[1], NULL);
        _v = SWIG_CheckState(res);
      }
      if (_v) {
        {
          int res = SWIG_AsVal_bool(argv[2], NULL);
          _v = SWIG_CheckState(res);
        }
        if (_v) {
          return _wrap_AudDevManager_setInputVolume__SWIG_0(self, argc, argv);
        }
      }
    }
  }
  
fail:
  SWIG_Python_RaiseOrModifyTypeError("Wrong number or type of arguments for overloaded function 'AudDevManager_setInputVolume'.\n"
    "  Possible C/C++ prototypes are:\n"
    "    pj::AudDevManager::setInputVolume(unsigned int,bool)\n"
    "    pj::AudDevManager::setInputVolume(unsigned int)\n");
  return 0;
}


SWIGINTERN PyObject *_wrap_AudDevManager_getInputVolume(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::AudDevManager *arg1 = (pj::AudDevManager *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  unsigned int result;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__AudDevManager, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "AudDevManager_getInputVolume" "', argument " "1"" of type '" "pj::AudDevManager const *""'"); 
  }
  arg1 = reinterpret_cast< pj::AudDevManager * >(argp1);
  try {
    result = (unsigned int)((pj::AudDevManager const *)arg1)->getInputVolume();
  } catch(pj::Error &_e) {
    SWIG_Python_Raise(SWIG_NewPointerObj((new pj::Error(static_cast< const pj::Error& >(_e))),SWIGTYPE_p_pj__Error,SWIG_POINTER_OWN), "pj::Error", SWIGTYPE_p_pj__Error); SWIG_fail;
  }
  resultobj = SWIG_From_unsigned_SS_int(static_cast< unsigned int >(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_AudDevManager_setOutputVolume__SWIG_0(PyObject *SWIGUNUSEDPARM(self), Py_ssize_t nobjs, PyObject **swig_obj) {
  PyObject *resultobj = 0;
  pj::AudDevManager *arg1 = (pj::AudDevManager *) 0 ;
  unsigned int arg2 ;
  bool arg3 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  unsigned int val2 ;
  int ecode2 = 0 ;
  bool val3 ;
  int ecode3 = 0 ;
  
  if ((nobjs < 3) || (nobjs > 3)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__AudDevManager, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "AudDevManager_setOutputVolume" "', argument " "1"" of type '" "pj::AudDevManager *""'"); 
  }
  arg1 = reinterpret_cast< pj::AudDevManager * >(argp1);
  ecode2 = SWIG_AsVal_unsigned_SS_int(swig_obj[1], &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "AudDevManager_setOutputVolume" "', argument " "2"" of type '" "unsigned int""'");
  } 
  arg2 = static_cast< unsigned int >(val2);
  ecode3 = SWIG_AsVal_bool(swig_obj[2], &val3);
  if (!SWIG_IsOK(ecode3)) {
    SWIG_exception_fail(SWIG_ArgError(ecode3), "in method '" "AudDevManager_setOutputVolume" "', argument " "3"" of type '" "bool""'");
  } 
  arg3 = static_cast< bool >(val3);
  try {
    (arg1)->setOutputVolume(arg2,arg3);
  } catch(pj::Error &_e) {
    SWIG_Python_Raise(SWIG_NewPointerObj((new pj::Error(static_cast< const pj::Error& >(_e))),SWIGTYPE_p_pj__Error,SWIG_POINTER_OWN), "pj::Error", SWIGTYPE_p_pj__Error); SWIG_fail;
  }
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_AudDevManager_setOutputVolume__SWIG_1(PyObject *SWIGUNUSEDPARM(self), Py_ssize_t nobjs, PyObject **swig_obj) {
  PyObject *resultobj = 0;
  pj::AudDevManager *arg1 = (pj::AudDevManager *) 0 ;
  unsigned int arg2 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  unsigned int val2 ;
  int ecode2 = 0 ;
  
  if ((nobjs < 2) || (nobjs > 2)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__AudDevManager, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "AudDevManager_setOutputVolume" "', argument " "1"" of type '" "pj::AudDevManager *""'"); 
  }
  arg1 = reinterpret_cast< pj::AudDevManager * >(argp1);
  ecode2 = SWIG_AsVal_unsigned_SS_int(swig_obj[1], &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "AudDevManager_setOutputVolume" "', argument " "2"" of type '" "unsigned int""'");
  } 
  arg2 = static_cast< unsigned int >(val2);
  try {
    (arg1)->setOutputVolume(arg2);
  } catch(pj::Error &_e) {
    SWIG_Python_Raise(SWIG_NewPointerObj((new pj::Error(static_cast< const pj::Error& >(_e))),SWIGTYPE_p_pj__Error,SWIG_POINTER_OWN), "pj::Error", SWIGTYPE_p_pj__Error); SWIG_fail;
  }
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_AudDevManager_setOutputVolume(PyObject *self, PyObject *args) {
  Py_ssize_t argc;
  PyObject *argv[4] = {
    0
  };
  
  if (!(argc = SWIG_Python_UnpackTuple(args, "AudDevManager_setOutputVolume", 0, 3, argv))) SWIG_fail;
  --argc;
  if (argc == 2) {
    int _v;
    void *vptr = 0;
    int res = SWIG_ConvertPtr(argv[0], &vptr, SWIGTYPE_p_pj__AudDevManager, 0);
    _v = SWIG_CheckState(res);
    if (_v) {
      {
        int res = SWIG_AsVal_unsigned_SS_int(argv[1], NULL);
        _v = SWIG_CheckState(res);
      }
      if (_v) {
        return _wrap_AudDevManager_setOutputVolume__SWIG_1(self, argc, argv);
      }
    }
  }
  if (argc == 3) {
    int _v;
    void *vptr = 0;
    int res = SWIG_ConvertPtr(argv[0], &vptr, SWIGTYPE_p_pj__AudDevManager, 0);
    _v = SWIG_CheckState(res);
    if (_v) {
      {
        int res = SWIG_AsVal_unsigned_SS_int(argv[1], NULL);
        _v = SWIG_CheckState(res);
      }
      if (_v) {
        {
          int res = SWIG_AsVal_bool(argv[2], NULL);
          _v = SWIG_CheckState(res);
        }
        if (_v) {
          return _wrap_AudDevManager_setOutputVolume__SWIG_0(self, argc, argv);
        }
      }
    }
  }
  
fail:
  SWIG_Python_RaiseOrModifyTypeError("Wrong number or type of arguments for overloaded function 'AudDevManager_setOutputVolume'.\n"
    "  Possible C/C++ prototypes are:\n"
    "    pj::AudDevManager::setOutputVolume(unsigned int,bool)\n"
    "    pj::AudDevManager::setOutputVolume(unsigned int)\n");
  return 0;
}


SWIGINTERN PyObject *_wrap_AudDevManager_getOutputVolume(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::AudDevManager *arg1 = (pj::AudDevManager *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  unsigned int result;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__AudDevManager, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "AudDevManager_getOutputVolume" "', argument " "1"" of type '" "pj::AudDevManager const *""'"); 
  }
  arg1 = reinterpret_cast< pj::AudDevManager * >(argp1);
  try {
    result = (unsigned int)((pj::AudDevManager const *)arg1)->getOutputVolume();
  } catch(pj::Error &_e) {
    SWIG_Python_Raise(SWIG_NewPointerObj((new pj::Error(static_cast< const pj::Error& >(_e))),SWIGTYPE_p_pj__Error,SWIG_POINTER_OWN), "pj::Error", SWIGTYPE_p_pj__Error); SWIG_fail;
  }
  resultobj = SWIG_From_unsigned_SS_int(static_cast< unsigned int >(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_AudDevManager_getInputSignal(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::AudDevManager *arg1 = (pj::AudDevManager *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  unsigned int result;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__AudDevManager, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "AudDevManager_getInputSignal" "', argument " "1"" of type '" "pj::AudDevManager const *""'"); 
  }
  arg1 = reinterpret_cast< pj::AudDevManager * >(argp1);
  try {
    result = (unsigned int)((pj::AudDevManager const *)arg1)->getInputSignal();
  } catch(pj::Error &_e) {
    SWIG_Python_Raise(SWIG_NewPointerObj((new pj::Error(static_cast< const pj::Error& >(_e))),SWIGTYPE_p_pj__Error,SWIG_POINTER_OWN), "pj::Error", SWIGTYPE_p_pj__Error); SWIG_fail;
  }
  resultobj = SWIG_From_unsigned_SS_int(static_cast< unsigned int >(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_AudDevManager_getOutputSignal(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::AudDevManager *arg1 = (pj::AudDevManager *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  unsigned int result;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__AudDevManager, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "AudDevManager_getOutputSignal" "', argument " "1"" of type '" "pj::AudDevManager const *""'"); 
  }
  arg1 = reinterpret_cast< pj::AudDevManager * >(argp1);
  try {
    result = (unsigned int)((pj::AudDevManager const *)arg1)->getOutputSignal();
  } catch(pj::Error &_e) {
    SWIG_Python_Raise(SWIG_NewPointerObj((new pj::Error(static_cast< const pj::Error& >(_e))),SWIGTYPE_p_pj__Error,SWIG_POINTER_OWN), "pj::Error", SWIGTYPE_p_pj__Error); SWIG_fail;
  }
  resultobj = SWIG_From_unsigned_SS_int(static_cast< unsigned int >(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_AudDevManager_setInputRoute__SWIG_0(PyObject *SWIGUNUSEDPARM(self), Py_ssize_t nobjs, PyObject **swig_obj) {
  PyObject *resultobj = 0;
  pj::AudDevManager *arg1 = (pj::AudDevManager *) 0 ;
  pjmedia_aud_dev_route arg2 ;
  bool arg3 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  int val2 ;
  int ecode2 = 0 ;
  bool val3 ;
  int ecode3 = 0 ;
  
  if ((nobjs < 3) || (nobjs > 3)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__AudDevManager, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "AudDevManager_setInputRoute" "', argument " "1"" of type '" "pj::AudDevManager *""'"); 
  }
  arg1 = reinterpret_cast< pj::AudDevManager * >(argp1);
  ecode2 = SWIG_AsVal_int(swig_obj[1], &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "AudDevManager_setInputRoute" "', argument " "2"" of type '" "pjmedia_aud_dev_route""'");
  } 
  arg2 = static_cast< pjmedia_aud_dev_route >(val2);
  ecode3 = SWIG_AsVal_bool(swig_obj[2], &val3);
  if (!SWIG_IsOK(ecode3)) {
    SWIG_exception_fail(SWIG_ArgError(ecode3), "in method '" "AudDevManager_setInputRoute" "', argument " "3"" of type '" "bool""'");
  } 
  arg3 = static_cast< bool >(val3);
  try {
    (arg1)->setInputRoute(arg2,arg3);
  } catch(pj::Error &_e) {
    SWIG_Python_Raise(SWIG_NewPointerObj((new pj::Error(static_cast< const pj::Error& >(_e))),SWIGTYPE_p_pj__Error,SWIG_POINTER_OWN), "pj::Error", SWIGTYPE_p_pj__Error); SWIG_fail;
  }
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_AudDevManager_setInputRoute__SWIG_1(PyObject *SWIGUNUSEDPARM(self), Py_ssize_t nobjs, PyObject **swig_obj) {
  PyObject *resultobj = 0;
  pj::AudDevManager *arg1 = (pj::AudDevManager *) 0 ;
  pjmedia_aud_dev_route arg2 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  int val2 ;
  int ecode2 = 0 ;
  
  if ((nobjs < 2) || (nobjs > 2)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__AudDevManager, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "AudDevManager_setInputRoute" "', argument " "1"" of type '" "pj::AudDevManager *""'"); 
  }
  arg1 = reinterpret_cast< pj::AudDevManager * >(argp1);
  ecode2 = SWIG_AsVal_int(swig_obj[1], &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "AudDevManager_setInputRoute" "', argument " "2"" of type '" "pjmedia_aud_dev_route""'");
  } 
  arg2 = static_cast< pjmedia_aud_dev_route >(val2);
  try {
    (arg1)->setInputRoute(arg2);
  } catch(pj::Error &_e) {
    SWIG_Python_Raise(SWIG_NewPointerObj((new pj::Error(static_cast< const pj::Error& >(_e))),SWIGTYPE_p_pj__Error,SWIG_POINTER_OWN), "pj::Error", SWIGTYPE_p_pj__Error); SWIG_fail;
  }
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_AudDevManager_setInputRoute(PyObject *self, PyObject *args) {
  Py_ssize_t argc;
  PyObject *argv[4] = {
    0
  };
  
  if (!(argc = SWIG_Python_UnpackTuple(args, "AudDevManager_setInputRoute", 0, 3, argv))) SWIG_fail;
  --argc;
  if (argc == 2) {
    int _v;
    void *vptr = 0;
    int res = SWIG_ConvertPtr(argv[0], &vptr, SWIGTYPE_p_pj__AudDevManager, 0);
    _v = SWIG_CheckState(res);
    if (_v) {
      {
        int res = SWIG_AsVal_int(argv[1], NULL);
        _v = SWIG_CheckState(res);
      }
      if (_v) {
        return _wrap_AudDevManager_setInputRoute__SWIG_1(self, argc, argv);
      }
    }
  }
  if (argc == 3) {
    int _v;
    void *vptr = 0;
    int res = SWIG_ConvertPtr(argv[0], &vptr, SWIGTYPE_p_pj__AudDevManager, 0);
    _v = SWIG_CheckState(res);
    if (_v) {
      {
        int res = SWIG_AsVal_int(argv[1], NULL);
        _v = SWIG_CheckState(res);
      }
      if (_v) {
        {
          int res = SWIG_AsVal_bool(argv[2], NULL);
          _v = SWIG_CheckState(res);
        }
        if (_v) {
          return _wrap_AudDevManager_setInputRoute__SWIG_0(self, argc, argv);
        }
      }
    }
  }
  
fail:
  SWIG_Python_RaiseOrModifyTypeError("Wrong number or type of arguments for overloaded function 'AudDevManager_setInputRoute'.\n"
    "  Possible C/C++ prototypes are:\n"
    "    pj::AudDevManager::setInputRoute(pjmedia_aud_dev_route,bool)\n"
    "    pj::AudDevManager::setInputRoute(pjmedia_aud_dev_route)\n");
  return 0;
}


SWIGINTERN PyObject *_wrap_AudDevManager_getInputRoute(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::AudDevManager *arg1 = (pj::AudDevManager *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  pjmedia_aud_dev_route result;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__AudDevManager, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "AudDevManager_getInputRoute" "', argument " "1"" of type '" "pj::AudDevManager const *""'"); 
  }
  arg1 = reinterpret_cast< pj::AudDevManager * >(argp1);
  try {
    result = (pjmedia_aud_dev_route)((pj::AudDevManager const *)arg1)->getInputRoute();
  } catch(pj::Error &_e) {
    SWIG_Python_Raise(SWIG_NewPointerObj((new pj::Error(static_cast< const pj::Error& >(_e))),SWIGTYPE_p_pj__Error,SWIG_POINTER_OWN), "pj::Error", SWIGTYPE_p_pj__Error); SWIG_fail;
  }
  resultobj = SWIG_From_int(static_cast< int >(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_AudDevManager_setOutputRoute__SWIG_0(PyObject *SWIGUNUSEDPARM(self), Py_ssize_t nobjs, PyObject **swig_obj) {
  PyObject *resultobj = 0;
  pj::AudDevManager *arg1 = (pj::AudDevManager *) 0 ;
  pjmedia_aud_dev_route arg2 ;
  bool arg3 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  int val2 ;
  int ecode2 = 0 ;
  bool val3 ;
  int ecode3 = 0 ;
  
  if ((nobjs < 3) || (nobjs > 3)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__AudDevManager, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "AudDevManager_setOutputRoute" "', argument " "1"" of type '" "pj::AudDevManager *""'"); 
  }
  arg1 = reinterpret_cast< pj::AudDevManager * >(argp1);
  ecode2 = SWIG_AsVal_int(swig_obj[1], &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "AudDevManager_setOutputRoute" "', argument " "2"" of type '" "pjmedia_aud_dev_route""'");
  } 
  arg2 = static_cast< pjmedia_aud_dev_route >(val2);
  ecode3 = SWIG_AsVal_bool(swig_obj[2], &val3);
  if (!SWIG_IsOK(ecode3)) {
    SWIG_exception_fail(SWIG_ArgError(ecode3), "in method '" "AudDevManager_setOutputRoute" "', argument " "3"" of type '" "bool""'");
  } 
  arg3 = static_cast< bool >(val3);
  try {
    (arg1)->setOutputRoute(arg2,arg3);
  } catch(pj::Error &_e) {
    SWIG_Python_Raise(SWIG_NewPointerObj((new pj::Error(static_cast< const pj::Error& >(_e))),SWIGTYPE_p_pj__Error,SWIG_POINTER_OWN), "pj::Error", SWIGTYPE_p_pj__Error); SWIG_fail;
  }
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_AudDevManager_setOutputRoute__SWIG_1(PyObject *SWIGUNUSEDPARM(self), Py_ssize_t nobjs, PyObject **swig_obj) {
  PyObject *resultobj = 0;
  pj::AudDevManager *arg1 = (pj::AudDevManager *) 0 ;
  pjmedia_aud_dev_route arg2 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  int val2 ;
  int ecode2 = 0 ;
  
  if ((nobjs < 2) || (nobjs > 2)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__AudDevManager, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "AudDevManager_setOutputRoute" "', argument " "1"" of type '" "pj::AudDevManager *""'"); 
  }
  arg1 = reinterpret_cast< pj::AudDevManager * >(argp1);
  ecode2 = SWIG_AsVal_int(swig_obj[1], &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "AudDevManager_setOutputRoute" "', argument " "2"" of type '" "pjmedia_aud_dev_route""'");
  } 
  arg2 = static_cast< pjmedia_aud_dev_route >(val2);
  try {
    (arg1)->setOutputRoute(arg2);
  } catch(pj::Error &_e) {
    SWIG_Python_Raise(SWIG_NewPointerObj((new pj::Error(static_cast< const pj::Error& >(_e))),SWIGTYPE_p_pj__Error,SWIG_POINTER_OWN), "pj::Error", SWIGTYPE_p_pj__Error); SWIG_fail;
  }
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_AudDevManager_setOutputRoute(PyObject *self, PyObject *args) {
  Py_ssize_t argc;
  PyObject *argv[4] = {
    0
  };
  
  if (!(argc = SWIG_Python_UnpackTuple(args, "AudDevManager_setOutputRoute", 0, 3, argv))) SWIG_fail;
  --argc;
  if (argc == 2) {
    int _v;
    void *vptr = 0;
    int res = SWIG_ConvertPtr(argv[0], &vptr, SWIGTYPE_p_pj__AudDevManager, 0);
    _v = SWIG_CheckState(res);
    if (_v) {
      {
        int res = SWIG_AsVal_int(argv[1], NULL);
        _v = SWIG_CheckState(res);
      }
      if (_v) {
        return _wrap_AudDevManager_setOutputRoute__SWIG_1(self, argc, argv);
      }
    }
  }
  if (argc == 3) {
    int _v;
    void *vptr = 0;
    int res = SWIG_ConvertPtr(argv[0], &vptr, SWIGTYPE_p_pj__AudDevManager, 0);
    _v = SWIG_CheckState(res);
    if (_v) {
      {
        int res = SWIG_AsVal_int(argv[1], NULL);
        _v = SWIG_CheckState(res);
      }
      if (_v) {
        {
          int res = SWIG_AsVal_bool(argv[2], NULL);
          _v = SWIG_CheckState(res);
        }
        if (_v) {
          return _wrap_AudDevManager_setOutputRoute__SWIG_0(self, argc, argv);
        }
      }
    }
  }
  
fail:
  SWIG_Python_RaiseOrModifyTypeError("Wrong number or type of arguments for overloaded function 'AudDevManager_setOutputRoute'.\n"
    "  Possible C/C++ prototypes are:\n"
    "    pj::AudDevManager::setOutputRoute(pjmedia_aud_dev_route,bool)\n"
    "    pj::AudDevManager::setOutputRoute(pjmedia_aud_dev_route)\n");
  return 0;
}


SWIGINTERN PyObject *_wrap_AudDevManager_getOutputRoute(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::AudDevManager *arg1 = (pj::AudDevManager *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  pjmedia_aud_dev_route result;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__AudDevManager, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "AudDevManager_getOutputRoute" "', argument " "1"" of type '" "pj::AudDevManager const *""'"); 
  }
  arg1 = reinterpret_cast< pj::AudDevManager * >(argp1);
  try {
    result = (pjmedia_aud_dev_route)((pj::AudDevManager const *)arg1)->getOutputRoute();
  } catch(pj::Error &_e) {
    SWIG_Python_Raise(SWIG_NewPointerObj((new pj::Error(static_cast< const pj::Error& >(_e))),SWIGTYPE_p_pj__Error,SWIG_POINTER_OWN), "pj::Error", SWIGTYPE_p_pj__Error); SWIG_fail;
  }
  resultobj = SWIG_From_int(static_cast< int >(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_AudDevManager_setVad__SWIG_0(PyObject *SWIGUNUSEDPARM(self), Py_ssize_t nobjs, PyObject **swig_obj) {
  PyObject *resultobj = 0;
  pj::AudDevManager *arg1 = (pj::AudDevManager *) 0 ;
  bool arg2 ;
  bool arg3 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  bool val2 ;
  int ecode2 = 0 ;
  bool val3 ;
  int ecode3 = 0 ;
  
  if ((nobjs < 3) || (nobjs > 3)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__AudDevManager, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "AudDevManager_setVad" "', argument " "1"" of type '" "pj::AudDevManager *""'"); 
  }
  arg1 = reinterpret_cast< pj::AudDevManager * >(argp1);
  ecode2 = SWIG_AsVal_bool(swig_obj[1], &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "AudDevManager_setVad" "', argument " "2"" of type '" "bool""'");
  } 
  arg2 = static_cast< bool >(val2);
  ecode3 = SWIG_AsVal_bool(swig_obj[2], &val3);
  if (!SWIG_IsOK(ecode3)) {
    SWIG_exception_fail(SWIG_ArgError(ecode3), "in method '" "AudDevManager_setVad" "', argument " "3"" of type '" "bool""'");
  } 
  arg3 = static_cast< bool >(val3);
  try {
    (arg1)->setVad(arg2,arg3);
  } catch(pj::Error &_e) {
    SWIG_Python_Raise(SWIG_NewPointerObj((new pj::Error(static_cast< const pj::Error& >(_e))),SWIGTYPE_p_pj__Error,SWIG_POINTER_OWN), "pj::Error", SWIGTYPE_p_pj__Error); SWIG_fail;
  }
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_AudDevManager_setVad__SWIG_1(PyObject *SWIGUNUSEDPARM(self), Py_ssize_t nobjs, PyObject **swig_obj) {
  PyObject *resultobj = 0;
  pj::AudDevManager *arg1 = (pj::AudDevManager *) 0 ;
  bool arg2 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  bool val2 ;
  int ecode2 = 0 ;
  
  if ((nobjs < 2) || (nobjs > 2)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__AudDevManager, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "AudDevManager_setVad" "', argument " "1"" of type '" "pj::AudDevManager *""'"); 
  }
  arg1 = reinterpret_cast< pj::AudDevManager * >(argp1);
  ecode2 = SWIG_AsVal_bool(swig_obj[1], &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "AudDevManager_setVad" "', argument " "2"" of type '" "bool""'");
  } 
  arg2 = static_cast< bool >(val2);
  try {
    (arg1)->setVad(arg2);
  } catch(pj::Error &_e) {
    SWIG_Python_Raise(SWIG_NewPointerObj((new pj::Error(static_cast< const pj::Error& >(_e))),SWIGTYPE_p_pj__Error,SWIG_POINTER_OWN), "pj::Error", SWIGTYPE_p_pj__Error); SWIG_fail;
  }
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_AudDevManager_setVad(PyObject *self, PyObject *args) {
  Py_ssize_t argc;
  PyObject *argv[4] = {
    0
  };
  
  if (!(argc = SWIG_Python_UnpackTuple(args, "AudDevManager_setVad", 0, 3, argv))) SWIG_fail;
  --argc;
  if (argc == 2) {
    int _v;
    void *vptr = 0;
    int res = SWIG_ConvertPtr(argv[0], &vptr, SWIGTYPE_p_pj__AudDevManager, 0);
    _v = SWIG_CheckState(res);
    if (_v) {
      {
        int res = SWIG_AsVal_bool(argv[1], NULL);
        _v = SWIG_CheckState(res);
      }
      if (_v) {
        return _wrap_AudDevManager_setVad__SWIG_1(self, argc, argv);
      }
    }
  }
  if (argc == 3) {
    int _v;
    void *vptr = 0;
    int res = SWIG_ConvertPtr(argv[0], &vptr, SWIGTYPE_p_pj__AudDevManager, 0);
    _v = SWIG_CheckState(res);
    if (_v) {
      {
        int res = SWIG_AsVal_bool(argv[1], NULL);
        _v = SWIG_CheckState(res);
      }
      if (_v) {
        {
          int res = SWIG_AsVal_bool(argv[2], NULL);
          _v = SWIG_CheckState(res);
        }
        if (_v) {
          return _wrap_AudDevManager_setVad__SWIG_0(self, argc, argv);
        }
      }
    }
  }
  
fail:
  SWIG_Python_RaiseOrModifyTypeError("Wrong number or type of arguments for overloaded function 'AudDevManager_setVad'.\n"
    "  Possible C/C++ prototypes are:\n"
    "    pj::AudDevManager::setVad(bool,bool)\n"
    "    pj::AudDevManager::setVad(bool)\n");
  return 0;
}


SWIGINTERN PyObject *_wrap_AudDevManager_getVad(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::AudDevManager *arg1 = (pj::AudDevManager *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  bool result;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__AudDevManager, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "AudDevManager_getVad" "', argument " "1"" of type '" "pj::AudDevManager const *""'"); 
  }
  arg1 = reinterpret_cast< pj::AudDevManager * >(argp1);
  try {
    result = (bool)((pj::AudDevManager const *)arg1)->getVad();
  } catch(pj::Error &_e) {
    SWIG_Python_Raise(SWIG_NewPointerObj((new pj::Error(static_cast< const pj::Error& >(_e))),SWIGTYPE_p_pj__Error,SWIG_POINTER_OWN), "pj::Error", SWIGTYPE_p_pj__Error); SWIG_fail;
  }
  resultobj = SWIG_From_bool(static_cast< bool >(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_AudDevManager_setCng__SWIG_0(PyObject *SWIGUNUSEDPARM(self), Py_ssize_t nobjs, PyObject **swig_obj) {
  PyObject *resultobj = 0;
  pj::AudDevManager *arg1 = (pj::AudDevManager *) 0 ;
  bool arg2 ;
  bool arg3 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  bool val2 ;
  int ecode2 = 0 ;
  bool val3 ;
  int ecode3 = 0 ;
  
  if ((nobjs < 3) || (nobjs > 3)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__AudDevManager, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "AudDevManager_setCng" "', argument " "1"" of type '" "pj::AudDevManager *""'"); 
  }
  arg1 = reinterpret_cast< pj::AudDevManager * >(argp1);
  ecode2 = SWIG_AsVal_bool(swig_obj[1], &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "AudDevManager_setCng" "', argument " "2"" of type '" "bool""'");
  } 
  arg2 = static_cast< bool >(val2);
  ecode3 = SWIG_AsVal_bool(swig_obj[2], &val3);
  if (!SWIG_IsOK(ecode3)) {
    SWIG_exception_fail(SWIG_ArgError(ecode3), "in method '" "AudDevManager_setCng" "', argument " "3"" of type '" "bool""'");
  } 
  arg3 = static_cast< bool >(val3);
  try {
    (arg1)->setCng(arg2,arg3);
  } catch(pj::Error &_e) {
    SWIG_Python_Raise(SWIG_NewPointerObj((new pj::Error(static_cast< const pj::Error& >(_e))),SWIGTYPE_p_pj__Error,SWIG_POINTER_OWN), "pj::Error", SWIGTYPE_p_pj__Error); SWIG_fail;
  }
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_AudDevManager_setCng__SWIG_1(PyObject *SWIGUNUSEDPARM(self), Py_ssize_t nobjs, PyObject **swig_obj) {
  PyObject *resultobj = 0;
  pj::AudDevManager *arg1 = (pj::AudDevManager *) 0 ;
  bool arg2 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  bool val2 ;
  int ecode2 = 0 ;
  
  if ((nobjs < 2) || (nobjs > 2)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__AudDevManager, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "AudDevManager_setCng" "', argument " "1"" of type '" "pj::AudDevManager *""'"); 
  }
  arg1 = reinterpret_cast< pj::AudDevManager * >(argp1);
  ecode2 = SWIG_AsVal_bool(swig_obj[1], &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "AudDevManager_setCng" "', argument " "2"" of type '" "bool""'");
  } 
  arg2 = static_cast< bool >(val2);
  try {
    (arg1)->setCng(arg2);
  } catch(pj::Error &_e) {
    SWIG_Python_Raise(SWIG_NewPointerObj((new pj::Error(static_cast< const pj::Error& >(_e))),SWIGTYPE_p_pj__Error,SWIG_POINTER_OWN), "pj::Error", SWIGTYPE_p_pj__Error); SWIG_fail;
  }
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_AudDevManager_setCng(PyObject *self, PyObject *args) {
  Py_ssize_t argc;
  PyObject *argv[4] = {
    0
  };
  
  if (!(argc = SWIG_Python_UnpackTuple(args, "AudDevManager_setCng", 0, 3, argv))) SWIG_fail;
  --argc;
  if (argc == 2) {
    int _v;
    void *vptr = 0;
    int res = SWIG_ConvertPtr(argv[0], &vptr, SWIGTYPE_p_pj__AudDevManager, 0);
    _v = SWIG_CheckState(res);
    if (_v) {
      {
        int res = SWIG_AsVal_bool(argv[1], NULL);
        _v = SWIG_CheckState(res);
      }
      if (_v) {
        return _wrap_AudDevManager_setCng__SWIG_1(self, argc, argv);
      }
    }
  }
  if (argc == 3) {
    int _v;
    void *vptr = 0;
    int res = SWIG_ConvertPtr(argv[0], &vptr, SWIGTYPE_p_pj__AudDevManager, 0);
    _v = SWIG_CheckState(res);
    if (_v) {
      {
        int res = SWIG_AsVal_bool(argv[1], NULL);
        _v = SWIG_CheckState(res);
      }
      if (_v) {
        {
          int res = SWIG_AsVal_bool(argv[2], NULL);
          _v = SWIG_CheckState(res);
        }
        if (_v) {
          return _wrap_AudDevManager_setCng__SWIG_0(self, argc, argv);
        }
      }
    }
  }
  
fail:
  SWIG_Python_RaiseOrModifyTypeError("Wrong number or type of arguments for overloaded function 'AudDevManager_setCng'.\n"
    "  Possible C/C++ prototypes are:\n"
    "    pj::AudDevManager::setCng(bool,bool)\n"
    "    pj::AudDevManager::setCng(bool)\n");
  return 0;
}


SWIGINTERN PyObject *_wrap_AudDevManager_getCng(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::AudDevManager *arg1 = (pj::AudDevManager *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  bool result;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__AudDevManager, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "AudDevManager_getCng" "', argument " "1"" of type '" "pj::AudDevManager const *""'"); 
  }
  arg1 = reinterpret_cast< pj::AudDevManager * >(argp1);
  try {
    result = (bool)((pj::AudDevManager const *)arg1)->getCng();
  } catch(pj::Error &_e) {
    SWIG_Python_Raise(SWIG_NewPointerObj((new pj::Error(static_cast< const pj::Error& >(_e))),SWIGTYPE_p_pj__Error,SWIG_POINTER_OWN), "pj::Error", SWIGTYPE_p_pj__Error); SWIG_fail;
  }
  resultobj = SWIG_From_bool(static_cast< bool >(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_AudDevManager_setPlc__SWIG_0(PyObject *SWIGUNUSEDPARM(self), Py_ssize_t nobjs, PyObject **swig_obj) {
  PyObject *resultobj = 0;
  pj::AudDevManager *arg1 = (pj::AudDevManager *) 0 ;
  bool arg2 ;
  bool arg3 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  bool val2 ;
  int ecode2 = 0 ;
  bool val3 ;
  int ecode3 = 0 ;
  
  if ((nobjs < 3) || (nobjs > 3)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__AudDevManager, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "AudDevManager_setPlc" "', argument " "1"" of type '" "pj::AudDevManager *""'"); 
  }
  arg1 = reinterpret_cast< pj::AudDevManager * >(argp1);
  ecode2 = SWIG_AsVal_bool(swig_obj[1], &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "AudDevManager_setPlc" "', argument " "2"" of type '" "bool""'");
  } 
  arg2 = static_cast< bool >(val2);
  ecode3 = SWIG_AsVal_bool(swig_obj[2], &val3);
  if (!SWIG_IsOK(ecode3)) {
    SWIG_exception_fail(SWIG_ArgError(ecode3), "in method '" "AudDevManager_setPlc" "', argument " "3"" of type '" "bool""'");
  } 
  arg3 = static_cast< bool >(val3);
  try {
    (arg1)->setPlc(arg2,arg3);
  } catch(pj::Error &_e) {
    SWIG_Python_Raise(SWIG_NewPointerObj((new pj::Error(static_cast< const pj::Error& >(_e))),SWIGTYPE_p_pj__Error,SWIG_POINTER_OWN), "pj::Error", SWIGTYPE_p_pj__Error); SWIG_fail;
  }
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_AudDevManager_setPlc__SWIG_1(PyObject *SWIGUNUSEDPARM(self), Py_ssize_t nobjs, PyObject **swig_obj) {
  PyObject *resultobj = 0;
  pj::AudDevManager *arg1 = (pj::AudDevManager *) 0 ;
  bool arg2 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  bool val2 ;
  int ecode2 = 0 ;
  
  if ((nobjs < 2) || (nobjs > 2)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__AudDevManager, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "AudDevManager_setPlc" "', argument " "1"" of type '" "pj::AudDevManager *""'"); 
  }
  arg1 = reinterpret_cast< pj::AudDevManager * >(argp1);
  ecode2 = SWIG_AsVal_bool(swig_obj[1], &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "AudDevManager_setPlc" "', argument " "2"" of type '" "bool""'");
  } 
  arg2 = static_cast< bool >(val2);
  try {
    (arg1)->setPlc(arg2);
  } catch(pj::Error &_e) {
    SWIG_Python_Raise(SWIG_NewPointerObj((new pj::Error(static_cast< const pj::Error& >(_e))),SWIGTYPE_p_pj__Error,SWIG_POINTER_OWN), "pj::Error", SWIGTYPE_p_pj__Error); SWIG_fail;
  }
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_AudDevManager_setPlc(PyObject *self, PyObject *args) {
  Py_ssize_t argc;
  PyObject *argv[4] = {
    0
  };
  
  if (!(argc = SWIG_Python_UnpackTuple(args, "AudDevManager_setPlc", 0, 3, argv))) SWIG_fail;
  --argc;
  if (argc == 2) {
    int _v;
    void *vptr = 0;
    int res = SWIG_ConvertPtr(argv[0], &vptr, SWIGTYPE_p_pj__AudDevManager, 0);
    _v = SWIG_CheckState(res);
    if (_v) {
      {
        int res = SWIG_AsVal_bool(argv[1], NULL);
        _v = SWIG_CheckState(res);
      }
      if (_v) {
        return _wrap_AudDevManager_setPlc__SWIG_1(self, argc, argv);
      }
    }
  }
  if (argc == 3) {
    int _v;
    void *vptr = 0;
    int res = SWIG_ConvertPtr(argv[0], &vptr, SWIGTYPE_p_pj__AudDevManager, 0);
    _v = SWIG_CheckState(res);
    if (_v) {
      {
        int res = SWIG_AsVal_bool(argv[1], NULL);
        _v = SWIG_CheckState(res);
      }
      if (_v) {
        {
          int res = SWIG_AsVal_bool(argv[2], NULL);
          _v = SWIG_CheckState(res);
        }
        if (_v) {
          return _wrap_AudDevManager_setPlc__SWIG_0(self, argc, argv);
        }
      }
    }
  }
  
fail:
  SWIG_Python_RaiseOrModifyTypeError("Wrong number or type of arguments for overloaded function 'AudDevManager_setPlc'.\n"
    "  Possible C/C++ prototypes are:\n"
    "    pj::AudDevManager::setPlc(bool,bool)\n"
    "    pj::AudDevManager::setPlc(bool)\n");
  return 0;
}


SWIGINTERN PyObject *_wrap_AudDevManager_getPlc(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::AudDevManager *arg1 = (pj::AudDevManager *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  bool result;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__AudDevManager, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "AudDevManager_getPlc" "', argument " "1"" of type '" "pj::AudDevManager const *""'"); 
  }
  arg1 = reinterpret_cast< pj::AudDevManager * >(argp1);
  try {
    result = (bool)((pj::AudDevManager const *)arg1)->getPlc();
  } catch(pj::Error &_e) {
    SWIG_Python_Raise(SWIG_NewPointerObj((new pj::Error(static_cast< const pj::Error& >(_e))),SWIGTYPE_p_pj__Error,SWIG_POINTER_OWN), "pj::Error", SWIGTYPE_p_pj__Error); SWIG_fail;
  }
  resultobj = SWIG_From_bool(static_cast< bool >(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *AudDevManager_swigregister(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *obj;
  if (!SWIG_Python_UnpackTuple(args, "swigregister", 1, 1, &obj)) return NULL;
  SWIG_TypeNewClientData(SWIGTYPE_p_pj__AudDevManager, SWIG_NewClientData(obj));
  return SWIG_Py_Void();
}

SWIGINTERN PyObject *_wrap_new_ExtraAudioDevice(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  int arg1 ;
  int arg2 ;
  int val1 ;
  int ecode1 = 0 ;
  int val2 ;
  int ecode2 = 0 ;
  PyObject *swig_obj[2] ;
  pj::ExtraAudioDevice *result = 0 ;
  
  if (!SWIG_Python_UnpackTuple(args, "new_ExtraAudioDevice", 2, 2, swig_obj)) SWIG_fail;
  ecode1 = SWIG_AsVal_int(swig_obj[0], &val1);
  if (!SWIG_IsOK(ecode1)) {
    SWIG_exception_fail(SWIG_ArgError(ecode1), "in method '" "new_ExtraAudioDevice" "', argument " "1"" of type '" "int""'");
  } 
  arg1 = static_cast< int >(val1);
  ecode2 = SWIG_AsVal_int(swig_obj[1], &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "new_ExtraAudioDevice" "', argument " "2"" of type '" "int""'");
  } 
  arg2 = static_cast< int >(val2);
  result = (pj::ExtraAudioDevice *)new pj::ExtraAudioDevice(arg1,arg2);
  resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(result), SWIGTYPE_p_pj__ExtraAudioDevice, SWIG_POINTER_NEW |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_delete_ExtraAudioDevice(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::ExtraAudioDevice *arg1 = (pj::ExtraAudioDevice *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__ExtraAudioDevice, SWIG_POINTER_DISOWN |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "delete_ExtraAudioDevice" "', argument " "1"" of type '" "pj::ExtraAudioDevice *""'"); 
  }
  arg1 = reinterpret_cast< pj::ExtraAudioDevice * >(argp1);
  delete arg1;
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_ExtraAudioDevice_open(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::ExtraAudioDevice *arg1 = (pj::ExtraAudioDevice *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__ExtraAudioDevice, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "ExtraAudioDevice_open" "', argument " "1"" of type '" "pj::ExtraAudioDevice *""'"); 
  }
  arg1 = reinterpret_cast< pj::ExtraAudioDevice * >(argp1);
  (arg1)->open();
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_ExtraAudioDevice_close(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::ExtraAudioDevice *arg1 = (pj::ExtraAudioDevice *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__ExtraAudioDevice, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "ExtraAudioDevice_close" "', argument " "1"" of type '" "pj::ExtraAudioDevice *""'"); 
  }
  arg1 = reinterpret_cast< pj::ExtraAudioDevice * >(argp1);
  (arg1)->close();
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_ExtraAudioDevice_isOpened(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::ExtraAudioDevice *arg1 = (pj::ExtraAudioDevice *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  bool result;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__ExtraAudioDevice, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "ExtraAudioDevice_isOpened" "', argument " "1"" of type '" "pj::ExtraAudioDevice *""'"); 
  }
  arg1 = reinterpret_cast< pj::ExtraAudioDevice * >(argp1);
  result = (bool)(arg1)->isOpened();
  resultobj = SWIG_From_bool(static_cast< bool >(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *ExtraAudioDevice_swigregister(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *obj;
  if (!SWIG_Python_UnpackTuple(args, "swigregister", 1, 1, &obj)) return NULL;
  SWIG_TypeNewClientData(SWIGTYPE_p_pj__ExtraAudioDevice, SWIG_NewClientData(obj));
  return SWIG_Py_Void();
}

SWIGINTERN PyObject *ExtraAudioDevice_swiginit(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  return SWIG_Python_InitShadowInstance(args);
}

SWIGINTERN PyObject *_wrap_MediaCoordinate_x_set(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::MediaCoordinate *arg1 = (pj::MediaCoordinate *) 0 ;
  int arg2 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  int val2 ;
  int ecode2 = 0 ;
  PyObject *swig_obj[2] ;
  
  if (!SWIG_Python_UnpackTuple(args, "MediaCoordinate_x_set", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__MediaCoordinate, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "MediaCoordinate_x_set" "', argument " "1"" of type '" "pj::MediaCoordinate *""'"); 
  }
  arg1 = reinterpret_cast< pj::MediaCoordinate * >(argp1);
  ecode2 = SWIG_AsVal_int(swig_obj[1], &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "MediaCoordinate_x_set" "', argument " "2"" of type '" "int""'");
  } 
  arg2 = static_cast< int >(val2);
  if (arg1) (arg1)->x = arg2;
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_MediaCoordinate_x_get(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::MediaCoordinate *arg1 = (pj::MediaCoordinate *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  int result;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__MediaCoordinate, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "MediaCoordinate_x_get" "', argument " "1"" of type '" "pj::MediaCoordinate *""'"); 
  }
  arg1 = reinterpret_cast< pj::MediaCoordinate * >(argp1);
  result = (int) ((arg1)->x);
  resultobj = SWIG_From_int(static_cast< int >(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_MediaCoordinate_y_set(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::MediaCoordinate *arg1 = (pj::MediaCoordinate *) 0 ;
  int arg2 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  int val2 ;
  int ecode2 = 0 ;
  PyObject *swig_obj[2] ;
  
  if (!SWIG_Python_UnpackTuple(args, "MediaCoordinate_y_set", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__MediaCoordinate, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "MediaCoordinate_y_set" "', argument " "1"" of type '" "pj::MediaCoordinate *""'"); 
  }
  arg1 = reinterpret_cast< pj::MediaCoordinate * >(argp1);
  ecode2 = SWIG_AsVal_int(swig_obj[1], &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "MediaCoordinate_y_set" "', argument " "2"" of type '" "int""'");
  } 
  arg2 = static_cast< int >(val2);
  if (arg1) (arg1)->y = arg2;
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_MediaCoordinate_y_get(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::MediaCoordinate *arg1 = (pj::MediaCoordinate *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  int result;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__MediaCoordinate, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "MediaCoordinate_y_get" "', argument " "1"" of type '" "pj::MediaCoordinate *""'"); 
  }
  arg1 = reinterpret_cast< pj::MediaCoordinate * >(argp1);
  result = (int) ((arg1)->y);
  resultobj = SWIG_From_int(static_cast< int >(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_new_MediaCoordinate(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::MediaCoordinate *result = 0 ;
  
  if (!SWIG_Python_UnpackTuple(args, "new_MediaCoordinate", 0, 0, 0)) SWIG_fail;
  result = (pj::MediaCoordinate *)new pj::MediaCoordinate();
  resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(result), SWIGTYPE_p_pj__MediaCoordinate, SWIG_POINTER_NEW |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_delete_MediaCoordinate(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::MediaCoordinate *arg1 = (pj::MediaCoordinate *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__MediaCoordinate, SWIG_POINTER_DISOWN |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "delete_MediaCoordinate" "', argument " "1"" of type '" "pj::MediaCoordinate *""'"); 
  }
  arg1 = reinterpret_cast< pj::MediaCoordinate * >(argp1);
  delete arg1;
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *MediaCoordinate_swigregister(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *obj;
  if (!SWIG_Python_UnpackTuple(args, "swigregister", 1, 1, &obj)) return NULL;
  SWIG_TypeNewClientData(SWIGTYPE_p_pj__MediaCoordinate, SWIG_NewClientData(obj));
  return SWIG_Py_Void();
}

SWIGINTERN PyObject *MediaCoordinate_swiginit(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  return SWIG_Python_InitShadowInstance(args);
}

SWIGINTERN PyObject *_wrap_MediaSize_w_set(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::MediaSize *arg1 = (pj::MediaSize *) 0 ;
  unsigned int arg2 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  unsigned int val2 ;
  int ecode2 = 0 ;
  PyObject *swig_obj[2] ;
  
  if (!SWIG_Python_UnpackTuple(args, "MediaSize_w_set", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__MediaSize, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "MediaSize_w_set" "', argument " "1"" of type '" "pj::MediaSize *""'"); 
  }
  arg1 = reinterpret_cast< pj::MediaSize * >(argp1);
  ecode2 = SWIG_AsVal_unsigned_SS_int(swig_obj[1], &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "MediaSize_w_set" "', argument " "2"" of type '" "unsigned int""'");
  } 
  arg2 = static_cast< unsigned int >(val2);
  if (arg1) (arg1)->w = arg2;
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_MediaSize_w_get(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::MediaSize *arg1 = (pj::MediaSize *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  unsigned int result;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__MediaSize, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "MediaSize_w_get" "', argument " "1"" of type '" "pj::MediaSize *""'"); 
  }
  arg1 = reinterpret_cast< pj::MediaSize * >(argp1);
  result = (unsigned int) ((arg1)->w);
  resultobj = SWIG_From_unsigned_SS_int(static_cast< unsigned int >(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_MediaSize_h_set(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::MediaSize *arg1 = (pj::MediaSize *) 0 ;
  unsigned int arg2 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  unsigned int val2 ;
  int ecode2 = 0 ;
  PyObject *swig_obj[2] ;
  
  if (!SWIG_Python_UnpackTuple(args, "MediaSize_h_set", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__MediaSize, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "MediaSize_h_set" "', argument " "1"" of type '" "pj::MediaSize *""'"); 
  }
  arg1 = reinterpret_cast< pj::MediaSize * >(argp1);
  ecode2 = SWIG_AsVal_unsigned_SS_int(swig_obj[1], &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "MediaSize_h_set" "', argument " "2"" of type '" "unsigned int""'");
  } 
  arg2 = static_cast< unsigned int >(val2);
  if (arg1) (arg1)->h = arg2;
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_MediaSize_h_get(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::MediaSize *arg1 = (pj::MediaSize *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  unsigned int result;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__MediaSize, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "MediaSize_h_get" "', argument " "1"" of type '" "pj::MediaSize *""'"); 
  }
  arg1 = reinterpret_cast< pj::MediaSize * >(argp1);
  result = (unsigned int) ((arg1)->h);
  resultobj = SWIG_From_unsigned_SS_int(static_cast< unsigned int >(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_new_MediaSize(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::MediaSize *result = 0 ;
  
  if (!SWIG_Python_UnpackTuple(args, "new_MediaSize", 0, 0, 0)) SWIG_fail;
  result = (pj::MediaSize *)new pj::MediaSize();
  resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(result), SWIGTYPE_p_pj__MediaSize, SWIG_POINTER_NEW |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_delete_MediaSize(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::MediaSize *arg1 = (pj::MediaSize *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__MediaSize, SWIG_POINTER_DISOWN |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "delete_MediaSize" "', argument " "1"" of type '" "pj::MediaSize *""'"); 
  }
  arg1 = reinterpret_cast< pj::MediaSize * >(argp1);
  delete arg1;
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *MediaSize_swigregister(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *obj;
  if (!SWIG_Python_UnpackTuple(args, "swigregister", 1, 1, &obj)) return NULL;
  SWIG_TypeNewClientData(SWIGTYPE_p_pj__MediaSize, SWIG_NewClientData(obj));
  return SWIG_Py_Void();
}

SWIGINTERN PyObject *MediaSize_swiginit(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  return SWIG_Python_InitShadowInstance(args);
}

SWIGINTERN PyObject *_wrap_VidConfPortInfo_portId_set(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::VidConfPortInfo *arg1 = (pj::VidConfPortInfo *) 0 ;
  int arg2 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  int val2 ;
  int ecode2 = 0 ;
  PyObject *swig_obj[2] ;
  
  if (!SWIG_Python_UnpackTuple(args, "VidConfPortInfo_portId_set", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__VidConfPortInfo, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "VidConfPortInfo_portId_set" "', argument " "1"" of type '" "pj::VidConfPortInfo *""'"); 
  }
  arg1 = reinterpret_cast< pj::VidConfPortInfo * >(argp1);
  ecode2 = SWIG_AsVal_int(swig_obj[1], &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "VidConfPortInfo_portId_set" "', argument " "2"" of type '" "int""'");
  } 
  arg2 = static_cast< int >(val2);
  if (arg1) (arg1)->portId = arg2;
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_VidConfPortInfo_portId_get(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::VidConfPortInfo *arg1 = (pj::VidConfPortInfo *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  int result;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__VidConfPortInfo, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "VidConfPortInfo_portId_get" "', argument " "1"" of type '" "pj::VidConfPortInfo *""'"); 
  }
  arg1 = reinterpret_cast< pj::VidConfPortInfo * >(argp1);
  result = (int) ((arg1)->portId);
  resultobj = SWIG_From_int(static_cast< int >(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_VidConfPortInfo_name_set(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::VidConfPortInfo *arg1 = (pj::VidConfPortInfo *) 0 ;
  pj::string *arg2 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  int res2 = SWIG_OLDOBJ ;
  PyObject *swig_obj[2] ;
  
  if (!SWIG_Python_UnpackTuple(args, "VidConfPortInfo_name_set", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__VidConfPortInfo, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "VidConfPortInfo_name_set" "', argument " "1"" of type '" "pj::VidConfPortInfo *""'"); 
  }
  arg1 = reinterpret_cast< pj::VidConfPortInfo * >(argp1);
  {
    std::string *ptr = (std::string *)0;
    res2 = SWIG_AsPtr_std_string(swig_obj[1], &ptr);
    if (!SWIG_IsOK(res2)) {
      SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "VidConfPortInfo_name_set" "', argument " "2"" of type '" "pj::string const &""'"); 
    }
    if (!ptr) {
      SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "VidConfPortInfo_name_set" "', argument " "2"" of type '" "pj::string const &""'"); 
    }
    arg2 = ptr;
  }
  if (arg1) (arg1)->name = *arg2;
  resultobj = SWIG_Py_Void();
  if (SWIG_IsNewObj(res2)) delete arg2;
  return resultobj;
fail:
  if (SWIG_IsNewObj(res2)) delete arg2;
  return NULL;
}


SWIGINTERN PyObject *_wrap_VidConfPortInfo_name_get(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::VidConfPortInfo *arg1 = (pj::VidConfPortInfo *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  pj::string *result = 0 ;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__VidConfPortInfo, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "VidConfPortInfo_name_get" "', argument " "1"" of type '" "pj::VidConfPortInfo *""'"); 
  }
  arg1 = reinterpret_cast< pj::VidConfPortInfo * >(argp1);
  result = (pj::string *) & ((arg1)->name);
  resultobj = SWIG_From_std_string(static_cast< std::string >(*result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_VidConfPortInfo_format_set(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::VidConfPortInfo *arg1 = (pj::VidConfPortInfo *) 0 ;
  pj::MediaFormatVideo *arg2 = (pj::MediaFormatVideo *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  void *argp2 = 0 ;
  int res2 = 0 ;
  PyObject *swig_obj[2] ;
  
  if (!SWIG_Python_UnpackTuple(args, "VidConfPortInfo_format_set", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__VidConfPortInfo, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "VidConfPortInfo_format_set" "', argument " "1"" of type '" "pj::VidConfPortInfo *""'"); 
  }
  arg1 = reinterpret_cast< pj::VidConfPortInfo * >(argp1);
  res2 = SWIG_ConvertPtr(swig_obj[1], &argp2,SWIGTYPE_p_pj__MediaFormatVideo, 0 |  0 );
  if (!SWIG_IsOK(res2)) {
    SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "VidConfPortInfo_format_set" "', argument " "2"" of type '" "pj::MediaFormatVideo *""'"); 
  }
  arg2 = reinterpret_cast< pj::MediaFormatVideo * >(argp2);
  if (arg1) (arg1)->format = *arg2;
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_VidConfPortInfo_format_get(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::VidConfPortInfo *arg1 = (pj::VidConfPortInfo *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  pj::MediaFormatVideo *result = 0 ;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__VidConfPortInfo, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "VidConfPortInfo_format_get" "', argument " "1"" of type '" "pj::VidConfPortInfo *""'"); 
  }
  arg1 = reinterpret_cast< pj::VidConfPortInfo * >(argp1);
  result = (pj::MediaFormatVideo *)& ((arg1)->format);
  resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(result), SWIGTYPE_p_pj__MediaFormatVideo, 0 |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_VidConfPortInfo_listeners_set(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::VidConfPortInfo *arg1 = (pj::VidConfPortInfo *) 0 ;
  pj::IntVector *arg2 = (pj::IntVector *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  void *argp2 = 0 ;
  int res2 = 0 ;
  PyObject *swig_obj[2] ;
  
  if (!SWIG_Python_UnpackTuple(args, "VidConfPortInfo_listeners_set", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__VidConfPortInfo, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "VidConfPortInfo_listeners_set" "', argument " "1"" of type '" "pj::VidConfPortInfo *""'"); 
  }
  arg1 = reinterpret_cast< pj::VidConfPortInfo * >(argp1);
  res2 = SWIG_ConvertPtr(swig_obj[1], &argp2,SWIGTYPE_p_std__vectorT_int_std__allocatorT_int_t_t, 0 |  0 );
  if (!SWIG_IsOK(res2)) {
    SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "VidConfPortInfo_listeners_set" "', argument " "2"" of type '" "pj::IntVector *""'"); 
  }
  arg2 = reinterpret_cast< pj::IntVector * >(argp2);
  if (arg1) (arg1)->listeners = *arg2;
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_VidConfPortInfo_listeners_get(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::VidConfPortInfo *arg1 = (pj::VidConfPortInfo *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  pj::IntVector *result = 0 ;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__VidConfPortInfo, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "VidConfPortInfo_listeners_get" "', argument " "1"" of type '" "pj::VidConfPortInfo *""'"); 
  }
  arg1 = reinterpret_cast< pj::VidConfPortInfo * >(argp1);
  result = (pj::IntVector *)& ((arg1)->listeners);
  resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(result), SWIGTYPE_p_std__vectorT_int_std__allocatorT_int_t_t, 0 |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_VidConfPortInfo_transmitters_set(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::VidConfPortInfo *arg1 = (pj::VidConfPortInfo *) 0 ;
  pj::IntVector *arg2 = (pj::IntVector *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  void *argp2 = 0 ;
  int res2 = 0 ;
  PyObject *swig_obj[2] ;
  
  if (!SWIG_Python_UnpackTuple(args, "VidConfPortInfo_transmitters_set", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__VidConfPortInfo, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "VidConfPortInfo_transmitters_set" "', argument " "1"" of type '" "pj::VidConfPortInfo *""'"); 
  }
  arg1 = reinterpret_cast< pj::VidConfPortInfo * >(argp1);
  res2 = SWIG_ConvertPtr(swig_obj[1], &argp2,SWIGTYPE_p_std__vectorT_int_std__allocatorT_int_t_t, 0 |  0 );
  if (!SWIG_IsOK(res2)) {
    SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "VidConfPortInfo_transmitters_set" "', argument " "2"" of type '" "pj::IntVector *""'"); 
  }
  arg2 = reinterpret_cast< pj::IntVector * >(argp2);
  if (arg1) (arg1)->transmitters = *arg2;
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_VidConfPortInfo_transmitters_get(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::VidConfPortInfo *arg1 = (pj::VidConfPortInfo *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  pj::IntVector *result = 0 ;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__VidConfPortInfo, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "VidConfPortInfo_transmitters_get" "', argument " "1"" of type '" "pj::VidConfPortInfo *""'"); 
  }
  arg1 = reinterpret_cast< pj::VidConfPortInfo * >(argp1);
  result = (pj::IntVector *)& ((arg1)->transmitters);
  resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(result), SWIGTYPE_p_std__vectorT_int_std__allocatorT_int_t_t, 0 |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_new_VidConfPortInfo(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::VidConfPortInfo *result = 0 ;
  
  if (!SWIG_Python_UnpackTuple(args, "new_VidConfPortInfo", 0, 0, 0)) SWIG_fail;
  result = (pj::VidConfPortInfo *)new pj::VidConfPortInfo();
  resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(result), SWIGTYPE_p_pj__VidConfPortInfo, SWIG_POINTER_NEW |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_delete_VidConfPortInfo(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::VidConfPortInfo *arg1 = (pj::VidConfPortInfo *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__VidConfPortInfo, SWIG_POINTER_DISOWN |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "delete_VidConfPortInfo" "', argument " "1"" of type '" "pj::VidConfPortInfo *""'"); 
  }
  arg1 = reinterpret_cast< pj::VidConfPortInfo * >(argp1);
  delete arg1;
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *VidConfPortInfo_swigregister(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *obj;
  if (!SWIG_Python_UnpackTuple(args, "swigregister", 1, 1, &obj)) return NULL;
  SWIG_TypeNewClientData(SWIGTYPE_p_pj__VidConfPortInfo, SWIG_NewClientData(obj));
  return SWIG_Py_Void();
}

SWIGINTERN PyObject *VidConfPortInfo_swiginit(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  return SWIG_Python_InitShadowInstance(args);
}

SWIGINTERN PyObject *_wrap_new_VideoMediaTransmitParam(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::VideoMediaTransmitParam *result = 0 ;
  
  if (!SWIG_Python_UnpackTuple(args, "new_VideoMediaTransmitParam", 0, 0, 0)) SWIG_fail;
  result = (pj::VideoMediaTransmitParam *)new pj::VideoMediaTransmitParam();
  resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(result), SWIGTYPE_p_pj__VideoMediaTransmitParam, SWIG_POINTER_NEW |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_delete_VideoMediaTransmitParam(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::VideoMediaTransmitParam *arg1 = (pj::VideoMediaTransmitParam *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__VideoMediaTransmitParam, SWIG_POINTER_DISOWN |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "delete_VideoMediaTransmitParam" "', argument " "1"" of type '" "pj::VideoMediaTransmitParam *""'"); 
  }
  arg1 = reinterpret_cast< pj::VideoMediaTransmitParam * >(argp1);
  delete arg1;
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *VideoMediaTransmitParam_swigregister(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *obj;
  if (!SWIG_Python_UnpackTuple(args, "swigregister", 1, 1, &obj)) return NULL;
  SWIG_TypeNewClientData(SWIGTYPE_p_pj__VideoMediaTransmitParam, SWIG_NewClientData(obj));
  return SWIG_Py_Void();
}

SWIGINTERN PyObject *VideoMediaTransmitParam_swiginit(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  return SWIG_Python_InitShadowInstance(args);
}

SWIGINTERN PyObject *_wrap_VideoMedia_getPortInfo(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::VideoMedia *arg1 = (pj::VideoMedia *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  pj::VidConfPortInfo result;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__VideoMedia, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "VideoMedia_getPortInfo" "', argument " "1"" of type '" "pj::VideoMedia const *""'"); 
  }
  arg1 = reinterpret_cast< pj::VideoMedia * >(argp1);
  try {
    result = ((pj::VideoMedia const *)arg1)->getPortInfo();
  } catch(pj::Error &_e) {
    SWIG_Python_Raise(SWIG_NewPointerObj((new pj::Error(static_cast< const pj::Error& >(_e))),SWIGTYPE_p_pj__Error,SWIG_POINTER_OWN), "pj::Error", SWIGTYPE_p_pj__Error); SWIG_fail;
  }
  resultobj = SWIG_NewPointerObj((new pj::VidConfPortInfo(static_cast< const pj::VidConfPortInfo& >(result))), SWIGTYPE_p_pj__VidConfPortInfo, SWIG_POINTER_OWN |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_VideoMedia_getPortId(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::VideoMedia *arg1 = (pj::VideoMedia *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  int result;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__VideoMedia, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "VideoMedia_getPortId" "', argument " "1"" of type '" "pj::VideoMedia const *""'"); 
  }
  arg1 = reinterpret_cast< pj::VideoMedia * >(argp1);
  result = (int)((pj::VideoMedia const *)arg1)->getPortId();
  resultobj = SWIG_From_int(static_cast< int >(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_VideoMedia_getPortInfoFromId(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  int arg1 ;
  int val1 ;
  int ecode1 = 0 ;
  PyObject *swig_obj[1] ;
  pj::VidConfPortInfo result;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  ecode1 = SWIG_AsVal_int(swig_obj[0], &val1);
  if (!SWIG_IsOK(ecode1)) {
    SWIG_exception_fail(SWIG_ArgError(ecode1), "in method '" "VideoMedia_getPortInfoFromId" "', argument " "1"" of type '" "int""'");
  } 
  arg1 = static_cast< int >(val1);
  try {
    result = pj::VideoMedia::getPortInfoFromId(arg1);
  } catch(pj::Error &_e) {
    SWIG_Python_Raise(SWIG_NewPointerObj((new pj::Error(static_cast< const pj::Error& >(_e))),SWIGTYPE_p_pj__Error,SWIG_POINTER_OWN), "pj::Error", SWIGTYPE_p_pj__Error); SWIG_fail;
  }
  resultobj = SWIG_NewPointerObj((new pj::VidConfPortInfo(static_cast< const pj::VidConfPortInfo& >(result))), SWIGTYPE_p_pj__VidConfPortInfo, SWIG_POINTER_OWN |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_VideoMedia_startTransmit(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::VideoMedia *arg1 = (pj::VideoMedia *) 0 ;
  pj::VideoMedia *arg2 = 0 ;
  pj::VideoMediaTransmitParam *arg3 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  void *argp2 = 0 ;
  int res2 = 0 ;
  void *argp3 = 0 ;
  int res3 = 0 ;
  PyObject *swig_obj[3] ;
  
  if (!SWIG_Python_UnpackTuple(args, "VideoMedia_startTransmit", 3, 3, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__VideoMedia, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "VideoMedia_startTransmit" "', argument " "1"" of type '" "pj::VideoMedia const *""'"); 
  }
  arg1 = reinterpret_cast< pj::VideoMedia * >(argp1);
  res2 = SWIG_ConvertPtr(swig_obj[1], &argp2, SWIGTYPE_p_pj__VideoMedia,  0  | 0);
  if (!SWIG_IsOK(res2)) {
    SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "VideoMedia_startTransmit" "', argument " "2"" of type '" "pj::VideoMedia const &""'"); 
  }
  if (!argp2) {
    SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "VideoMedia_startTransmit" "', argument " "2"" of type '" "pj::VideoMedia const &""'"); 
  }
  arg2 = reinterpret_cast< pj::VideoMedia * >(argp2);
  res3 = SWIG_ConvertPtr(swig_obj[2], &argp3, SWIGTYPE_p_pj__VideoMediaTransmitParam,  0  | 0);
  if (!SWIG_IsOK(res3)) {
    SWIG_exception_fail(SWIG_ArgError(res3), "in method '" "VideoMedia_startTransmit" "', argument " "3"" of type '" "pj::VideoMediaTransmitParam const &""'"); 
  }
  if (!argp3) {
    SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "VideoMedia_startTransmit" "', argument " "3"" of type '" "pj::VideoMediaTransmitParam const &""'"); 
  }
  arg3 = reinterpret_cast< pj::VideoMediaTransmitParam * >(argp3);
  try {
    ((pj::VideoMedia const *)arg1)->startTransmit((pj::VideoMedia const &)*arg2,(pj::VideoMediaTransmitParam const &)*arg3);
  } catch(pj::Error &_e) {
    SWIG_Python_Raise(SWIG_NewPointerObj((new pj::Error(static_cast< const pj::Error& >(_e))),SWIGTYPE_p_pj__Error,SWIG_POINTER_OWN), "pj::Error", SWIGTYPE_p_pj__Error); SWIG_fail;
  }
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_VideoMedia_stopTransmit(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::VideoMedia *arg1 = (pj::VideoMedia *) 0 ;
  pj::VideoMedia *arg2 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  void *argp2 = 0 ;
  int res2 = 0 ;
  PyObject *swig_obj[2] ;
  
  if (!SWIG_Python_UnpackTuple(args, "VideoMedia_stopTransmit", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__VideoMedia, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "VideoMedia_stopTransmit" "', argument " "1"" of type '" "pj::VideoMedia const *""'"); 
  }
  arg1 = reinterpret_cast< pj::VideoMedia * >(argp1);
  res2 = SWIG_ConvertPtr(swig_obj[1], &argp2, SWIGTYPE_p_pj__VideoMedia,  0  | 0);
  if (!SWIG_IsOK(res2)) {
    SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "VideoMedia_stopTransmit" "', argument " "2"" of type '" "pj::VideoMedia const &""'"); 
  }
  if (!argp2) {
    SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "VideoMedia_stopTransmit" "', argument " "2"" of type '" "pj::VideoMedia const &""'"); 
  }
  arg2 = reinterpret_cast< pj::VideoMedia * >(argp2);
  try {
    ((pj::VideoMedia const *)arg1)->stopTransmit((pj::VideoMedia const &)*arg2);
  } catch(pj::Error &_e) {
    SWIG_Python_Raise(SWIG_NewPointerObj((new pj::Error(static_cast< const pj::Error& >(_e))),SWIGTYPE_p_pj__Error,SWIG_POINTER_OWN), "pj::Error", SWIGTYPE_p_pj__Error); SWIG_fail;
  }
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_VideoMedia_update(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::VideoMedia *arg1 = (pj::VideoMedia *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__VideoMedia, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "VideoMedia_update" "', argument " "1"" of type '" "pj::VideoMedia const *""'"); 
  }
  arg1 = reinterpret_cast< pj::VideoMedia * >(argp1);
  try {
    ((pj::VideoMedia const *)arg1)->update();
  } catch(pj::Error &_e) {
    SWIG_Python_Raise(SWIG_NewPointerObj((new pj::Error(static_cast< const pj::Error& >(_e))),SWIGTYPE_p_pj__Error,SWIG_POINTER_OWN), "pj::Error", SWIGTYPE_p_pj__Error); SWIG_fail;
  }
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_new_VideoMedia(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::VideoMedia *result = 0 ;
  
  if (!SWIG_Python_UnpackTuple(args, "new_VideoMedia", 0, 0, 0)) SWIG_fail;
  result = (pj::VideoMedia *)new pj::VideoMedia();
  resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(result), SWIGTYPE_p_pj__VideoMedia, SWIG_POINTER_NEW |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_delete_VideoMedia(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::VideoMedia *arg1 = (pj::VideoMedia *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__VideoMedia, SWIG_POINTER_DISOWN |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "delete_VideoMedia" "', argument " "1"" of type '" "pj::VideoMedia *""'"); 
  }
  arg1 = reinterpret_cast< pj::VideoMedia * >(argp1);
  delete arg1;
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *VideoMedia_swigregister(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *obj;
  if (!SWIG_Python_UnpackTuple(args, "swigregister", 1, 1, &obj)) return NULL;
  SWIG_TypeNewClientData(SWIGTYPE_p_pj__VideoMedia, SWIG_NewClientData(obj));
  return SWIG_Py_Void();
}

SWIGINTERN PyObject *VideoMedia_swiginit(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  return SWIG_Python_InitShadowInstance(args);
}

SWIGINTERN PyObject *_wrap_WindowHandle_setWindow(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::WindowHandle *arg1 = (pj::WindowHandle *) 0 ;
  long long arg2 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  long long val2 ;
  int ecode2 = 0 ;
  PyObject *swig_obj[2] ;
  
  if (!SWIG_Python_UnpackTuple(args, "WindowHandle_setWindow", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__WindowHandle, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "WindowHandle_setWindow" "', argument " "1"" of type '" "pj::WindowHandle *""'"); 
  }
  arg1 = reinterpret_cast< pj::WindowHandle * >(argp1);
  ecode2 = SWIG_AsVal_long_SS_long(swig_obj[1], &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "WindowHandle_setWindow" "', argument " "2"" of type '" "long long""'");
  } 
  arg2 = static_cast< long long >(val2);
  pj_WindowHandle_setWindow(arg1,arg2);
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_new_WindowHandle(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::WindowHandle *result = 0 ;
  
  if (!SWIG_Python_UnpackTuple(args, "new_WindowHandle", 0, 0, 0)) SWIG_fail;
  result = (pj::WindowHandle *)new pj::WindowHandle();
  resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(result), SWIGTYPE_p_pj__WindowHandle, SWIG_POINTER_NEW |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_delete_WindowHandle(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::WindowHandle *arg1 = (pj::WindowHandle *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__WindowHandle, SWIG_POINTER_DISOWN |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "delete_WindowHandle" "', argument " "1"" of type '" "pj::WindowHandle *""'"); 
  }
  arg1 = reinterpret_cast< pj::WindowHandle * >(argp1);
  delete arg1;
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *WindowHandle_swigregister(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *obj;
  if (!SWIG_Python_UnpackTuple(args, "swigregister", 1, 1, &obj)) return NULL;
  SWIG_TypeNewClientData(SWIGTYPE_p_pj__WindowHandle, SWIG_NewClientData(obj));
  return SWIG_Py_Void();
}

SWIGINTERN PyObject *WindowHandle_swiginit(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  return SWIG_Python_InitShadowInstance(args);
}

SWIGINTERN PyObject *_wrap_VideoWindowHandle_type_set(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::VideoWindowHandle *arg1 = (pj::VideoWindowHandle *) 0 ;
  pjmedia_vid_dev_hwnd_type arg2 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  void *argp2 ;
  int res2 = 0 ;
  PyObject *swig_obj[2] ;
  
  if (!SWIG_Python_UnpackTuple(args, "VideoWindowHandle_type_set", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__VideoWindowHandle, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "VideoWindowHandle_type_set" "', argument " "1"" of type '" "pj::VideoWindowHandle *""'"); 
  }
  arg1 = reinterpret_cast< pj::VideoWindowHandle * >(argp1);
  {
    res2 = SWIG_ConvertPtr(swig_obj[1], &argp2, SWIGTYPE_p_pjmedia_vid_dev_hwnd_type,  0  | 0);
    if (!SWIG_IsOK(res2)) {
      SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "VideoWindowHandle_type_set" "', argument " "2"" of type '" "pjmedia_vid_dev_hwnd_type""'"); 
    }  
    if (!argp2) {
      SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "VideoWindowHandle_type_set" "', argument " "2"" of type '" "pjmedia_vid_dev_hwnd_type""'");
    } else {
      pjmedia_vid_dev_hwnd_type * temp = reinterpret_cast< pjmedia_vid_dev_hwnd_type * >(argp2);
      arg2 = *temp;
      if (SWIG_IsNewObj(res2)) delete temp;
    }
  }
  if (arg1) (arg1)->type = arg2;
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_VideoWindowHandle_type_get(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::VideoWindowHandle *arg1 = (pj::VideoWindowHandle *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  pjmedia_vid_dev_hwnd_type result;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__VideoWindowHandle, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "VideoWindowHandle_type_get" "', argument " "1"" of type '" "pj::VideoWindowHandle *""'"); 
  }
  arg1 = reinterpret_cast< pj::VideoWindowHandle * >(argp1);
  result =  ((arg1)->type);
  resultobj = SWIG_NewPointerObj((new pjmedia_vid_dev_hwnd_type(static_cast< const pjmedia_vid_dev_hwnd_type& >(result))), SWIGTYPE_p_pjmedia_vid_dev_hwnd_type, SWIG_POINTER_OWN |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_VideoWindowHandle_handle_set(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::VideoWindowHandle *arg1 = (pj::VideoWindowHandle *) 0 ;
  pj::WindowHandle *arg2 = (pj::WindowHandle *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  void *argp2 = 0 ;
  int res2 = 0 ;
  PyObject *swig_obj[2] ;
  
  if (!SWIG_Python_UnpackTuple(args, "VideoWindowHandle_handle_set", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__VideoWindowHandle, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "VideoWindowHandle_handle_set" "', argument " "1"" of type '" "pj::VideoWindowHandle *""'"); 
  }
  arg1 = reinterpret_cast< pj::VideoWindowHandle * >(argp1);
  res2 = SWIG_ConvertPtr(swig_obj[1], &argp2,SWIGTYPE_p_pj__WindowHandle, 0 |  0 );
  if (!SWIG_IsOK(res2)) {
    SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "VideoWindowHandle_handle_set" "', argument " "2"" of type '" "pj::WindowHandle *""'"); 
  }
  arg2 = reinterpret_cast< pj::WindowHandle * >(argp2);
  if (arg1) (arg1)->handle = *arg2;
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_VideoWindowHandle_handle_get(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::VideoWindowHandle *arg1 = (pj::VideoWindowHandle *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  pj::WindowHandle *result = 0 ;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__VideoWindowHandle, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "VideoWindowHandle_handle_get" "', argument " "1"" of type '" "pj::VideoWindowHandle *""'"); 
  }
  arg1 = reinterpret_cast< pj::VideoWindowHandle * >(argp1);
  result = (pj::WindowHandle *)& ((arg1)->handle);
  resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(result), SWIGTYPE_p_pj__WindowHandle, 0 |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_new_VideoWindowHandle(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::VideoWindowHandle *result = 0 ;
  
  if (!SWIG_Python_UnpackTuple(args, "new_VideoWindowHandle", 0, 0, 0)) SWIG_fail;
  result = (pj::VideoWindowHandle *)new pj::VideoWindowHandle();
  resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(result), SWIGTYPE_p_pj__VideoWindowHandle, SWIG_POINTER_NEW |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_delete_VideoWindowHandle(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::VideoWindowHandle *arg1 = (pj::VideoWindowHandle *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__VideoWindowHandle, SWIG_POINTER_DISOWN |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "delete_VideoWindowHandle" "', argument " "1"" of type '" "pj::VideoWindowHandle *""'"); 
  }
  arg1 = reinterpret_cast< pj::VideoWindowHandle * >(argp1);
  delete arg1;
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *VideoWindowHandle_swigregister(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *obj;
  if (!SWIG_Python_UnpackTuple(args, "swigregister", 1, 1, &obj)) return NULL;
  SWIG_TypeNewClientData(SWIGTYPE_p_pj__VideoWindowHandle, SWIG_NewClientData(obj));
  return SWIG_Py_Void();
}

SWIGINTERN PyObject *VideoWindowHandle_swiginit(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  return SWIG_Python_InitShadowInstance(args);
}

SWIGINTERN PyObject *_wrap_VideoWindowInfo_isNative_set(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::VideoWindowInfo *arg1 = (pj::VideoWindowInfo *) 0 ;
  bool arg2 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  bool val2 ;
  int ecode2 = 0 ;
  PyObject *swig_obj[2] ;
  
  if (!SWIG_Python_UnpackTuple(args, "VideoWindowInfo_isNative_set", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__VideoWindowInfo, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "VideoWindowInfo_isNative_set" "', argument " "1"" of type '" "pj::VideoWindowInfo *""'"); 
  }
  arg1 = reinterpret_cast< pj::VideoWindowInfo * >(argp1);
  ecode2 = SWIG_AsVal_bool(swig_obj[1], &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "VideoWindowInfo_isNative_set" "', argument " "2"" of type '" "bool""'");
  } 
  arg2 = static_cast< bool >(val2);
  if (arg1) (arg1)->isNative = arg2;
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_VideoWindowInfo_isNative_get(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::VideoWindowInfo *arg1 = (pj::VideoWindowInfo *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  bool result;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__VideoWindowInfo, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "VideoWindowInfo_isNative_get" "', argument " "1"" of type '" "pj::VideoWindowInfo *""'"); 
  }
  arg1 = reinterpret_cast< pj::VideoWindowInfo * >(argp1);
  result = (bool) ((arg1)->isNative);
  resultobj = SWIG_From_bool(static_cast< bool >(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_VideoWindowInfo_winHandle_set(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::VideoWindowInfo *arg1 = (pj::VideoWindowInfo *) 0 ;
  pj::VideoWindowHandle *arg2 = (pj::VideoWindowHandle *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  void *argp2 = 0 ;
  int res2 = 0 ;
  PyObject *swig_obj[2] ;
  
  if (!SWIG_Python_UnpackTuple(args, "VideoWindowInfo_winHandle_set", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__VideoWindowInfo, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "VideoWindowInfo_winHandle_set" "', argument " "1"" of type '" "pj::VideoWindowInfo *""'"); 
  }
  arg1 = reinterpret_cast< pj::VideoWindowInfo * >(argp1);
  res2 = SWIG_ConvertPtr(swig_obj[1], &argp2,SWIGTYPE_p_pj__VideoWindowHandle, 0 |  0 );
  if (!SWIG_IsOK(res2)) {
    SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "VideoWindowInfo_winHandle_set" "', argument " "2"" of type '" "pj::VideoWindowHandle *""'"); 
  }
  arg2 = reinterpret_cast< pj::VideoWindowHandle * >(argp2);
  if (arg1) (arg1)->winHandle = *arg2;
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_VideoWindowInfo_winHandle_get(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::VideoWindowInfo *arg1 = (pj::VideoWindowInfo *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  pj::VideoWindowHandle *result = 0 ;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__VideoWindowInfo, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "VideoWindowInfo_winHandle_get" "', argument " "1"" of type '" "pj::VideoWindowInfo *""'"); 
  }
  arg1 = reinterpret_cast< pj::VideoWindowInfo * >(argp1);
  result = (pj::VideoWindowHandle *)& ((arg1)->winHandle);
  resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(result), SWIGTYPE_p_pj__VideoWindowHandle, 0 |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_VideoWindowInfo_renderDeviceId_set(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::VideoWindowInfo *arg1 = (pj::VideoWindowInfo *) 0 ;
  int arg2 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  int val2 ;
  int ecode2 = 0 ;
  PyObject *swig_obj[2] ;
  
  if (!SWIG_Python_UnpackTuple(args, "VideoWindowInfo_renderDeviceId_set", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__VideoWindowInfo, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "VideoWindowInfo_renderDeviceId_set" "', argument " "1"" of type '" "pj::VideoWindowInfo *""'"); 
  }
  arg1 = reinterpret_cast< pj::VideoWindowInfo * >(argp1);
  ecode2 = SWIG_AsVal_int(swig_obj[1], &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "VideoWindowInfo_renderDeviceId_set" "', argument " "2"" of type '" "int""'");
  } 
  arg2 = static_cast< int >(val2);
  if (arg1) (arg1)->renderDeviceId = arg2;
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_VideoWindowInfo_renderDeviceId_get(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::VideoWindowInfo *arg1 = (pj::VideoWindowInfo *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  int result;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__VideoWindowInfo, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "VideoWindowInfo_renderDeviceId_get" "', argument " "1"" of type '" "pj::VideoWindowInfo *""'"); 
  }
  arg1 = reinterpret_cast< pj::VideoWindowInfo * >(argp1);
  result = (int) ((arg1)->renderDeviceId);
  resultobj = SWIG_From_int(static_cast< int >(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_VideoWindowInfo_show_set(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::VideoWindowInfo *arg1 = (pj::VideoWindowInfo *) 0 ;
  bool arg2 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  bool val2 ;
  int ecode2 = 0 ;
  PyObject *swig_obj[2] ;
  
  if (!SWIG_Python_UnpackTuple(args, "VideoWindowInfo_show_set", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__VideoWindowInfo, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "VideoWindowInfo_show_set" "', argument " "1"" of type '" "pj::VideoWindowInfo *""'"); 
  }
  arg1 = reinterpret_cast< pj::VideoWindowInfo * >(argp1);
  ecode2 = SWIG_AsVal_bool(swig_obj[1], &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "VideoWindowInfo_show_set" "', argument " "2"" of type '" "bool""'");
  } 
  arg2 = static_cast< bool >(val2);
  if (arg1) (arg1)->show = arg2;
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_VideoWindowInfo_show_get(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::VideoWindowInfo *arg1 = (pj::VideoWindowInfo *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  bool result;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__VideoWindowInfo, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "VideoWindowInfo_show_get" "', argument " "1"" of type '" "pj::VideoWindowInfo *""'"); 
  }
  arg1 = reinterpret_cast< pj::VideoWindowInfo * >(argp1);
  result = (bool) ((arg1)->show);
  resultobj = SWIG_From_bool(static_cast< bool >(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_VideoWindowInfo_pos_set(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::VideoWindowInfo *arg1 = (pj::VideoWindowInfo *) 0 ;
  pj::MediaCoordinate *arg2 = (pj::MediaCoordinate *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  void *argp2 = 0 ;
  int res2 = 0 ;
  PyObject *swig_obj[2] ;
  
  if (!SWIG_Python_UnpackTuple(args, "VideoWindowInfo_pos_set", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__VideoWindowInfo, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "VideoWindowInfo_pos_set" "', argument " "1"" of type '" "pj::VideoWindowInfo *""'"); 
  }
  arg1 = reinterpret_cast< pj::VideoWindowInfo * >(argp1);
  res2 = SWIG_ConvertPtr(swig_obj[1], &argp2,SWIGTYPE_p_pj__MediaCoordinate, 0 |  0 );
  if (!SWIG_IsOK(res2)) {
    SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "VideoWindowInfo_pos_set" "', argument " "2"" of type '" "pj::MediaCoordinate *""'"); 
  }
  arg2 = reinterpret_cast< pj::MediaCoordinate * >(argp2);
  if (arg1) (arg1)->pos = *arg2;
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_VideoWindowInfo_pos_get(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::VideoWindowInfo *arg1 = (pj::VideoWindowInfo *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  pj::MediaCoordinate *result = 0 ;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__VideoWindowInfo, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "VideoWindowInfo_pos_get" "', argument " "1"" of type '" "pj::VideoWindowInfo *""'"); 
  }
  arg1 = reinterpret_cast< pj::VideoWindowInfo * >(argp1);
  result = (pj::MediaCoordinate *)& ((arg1)->pos);
  resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(result), SWIGTYPE_p_pj__MediaCoordinate, 0 |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_VideoWindowInfo_size_set(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::VideoWindowInfo *arg1 = (pj::VideoWindowInfo *) 0 ;
  pj::MediaSize *arg2 = (pj::MediaSize *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  void *argp2 = 0 ;
  int res2 = 0 ;
  PyObject *swig_obj[2] ;
  
  if (!SWIG_Python_UnpackTuple(args, "VideoWindowInfo_size_set", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__VideoWindowInfo, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "VideoWindowInfo_size_set" "', argument " "1"" of type '" "pj::VideoWindowInfo *""'"); 
  }
  arg1 = reinterpret_cast< pj::VideoWindowInfo * >(argp1);
  res2 = SWIG_ConvertPtr(swig_obj[1], &argp2,SWIGTYPE_p_pj__MediaSize, 0 |  0 );
  if (!SWIG_IsOK(res2)) {
    SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "VideoWindowInfo_size_set" "', argument " "2"" of type '" "pj::MediaSize *""'"); 
  }
  arg2 = reinterpret_cast< pj::MediaSize * >(argp2);
  if (arg1) (arg1)->size = *arg2;
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_VideoWindowInfo_size_get(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::VideoWindowInfo *arg1 = (pj::VideoWindowInfo *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  pj::MediaSize *result = 0 ;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__VideoWindowInfo, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "VideoWindowInfo_size_get" "', argument " "1"" of type '" "pj::VideoWindowInfo *""'"); 
  }
  arg1 = reinterpret_cast< pj::VideoWindowInfo * >(argp1);
  result = (pj::MediaSize *)& ((arg1)->size);
  resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(result), SWIGTYPE_p_pj__MediaSize, 0 |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_new_VideoWindowInfo(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::VideoWindowInfo *result = 0 ;
  
  if (!SWIG_Python_UnpackTuple(args, "new_VideoWindowInfo", 0, 0, 0)) SWIG_fail;
  result = (pj::VideoWindowInfo *)new pj::VideoWindowInfo();
  resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(result), SWIGTYPE_p_pj__VideoWindowInfo, SWIG_POINTER_NEW |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_delete_VideoWindowInfo(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::VideoWindowInfo *arg1 = (pj::VideoWindowInfo *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__VideoWindowInfo, SWIG_POINTER_DISOWN |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "delete_VideoWindowInfo" "', argument " "1"" of type '" "pj::VideoWindowInfo *""'"); 
  }
  arg1 = reinterpret_cast< pj::VideoWindowInfo * >(argp1);
  delete arg1;
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *VideoWindowInfo_swigregister(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *obj;
  if (!SWIG_Python_UnpackTuple(args, "swigregister", 1, 1, &obj)) return NULL;
  SWIG_TypeNewClientData(SWIGTYPE_p_pj__VideoWindowInfo, SWIG_NewClientData(obj));
  return SWIG_Py_Void();
}

SWIGINTERN PyObject *VideoWindowInfo_swiginit(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  return SWIG_Python_InitShadowInstance(args);
}

SWIGINTERN PyObject *_wrap_new_VideoWindow(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  int arg1 ;
  int val1 ;
  int ecode1 = 0 ;
  PyObject *swig_obj[1] ;
  pj::VideoWindow *result = 0 ;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  ecode1 = SWIG_AsVal_int(swig_obj[0], &val1);
  if (!SWIG_IsOK(ecode1)) {
    SWIG_exception_fail(SWIG_ArgError(ecode1), "in method '" "new_VideoWindow" "', argument " "1"" of type '" "int""'");
  } 
  arg1 = static_cast< int >(val1);
  result = (pj::VideoWindow *)new pj::VideoWindow(arg1);
  resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(result), SWIGTYPE_p_pj__VideoWindow, SWIG_POINTER_NEW |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_VideoWindow_getInfo(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::VideoWindow *arg1 = (pj::VideoWindow *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  pj::VideoWindowInfo result;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__VideoWindow, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "VideoWindow_getInfo" "', argument " "1"" of type '" "pj::VideoWindow const *""'"); 
  }
  arg1 = reinterpret_cast< pj::VideoWindow * >(argp1);
  try {
    result = ((pj::VideoWindow const *)arg1)->getInfo();
  } catch(pj::Error &_e) {
    SWIG_Python_Raise(SWIG_NewPointerObj((new pj::Error(static_cast< const pj::Error& >(_e))),SWIGTYPE_p_pj__Error,SWIG_POINTER_OWN), "pj::Error", SWIGTYPE_p_pj__Error); SWIG_fail;
  }
  resultobj = SWIG_NewPointerObj((new pj::VideoWindowInfo(static_cast< const pj::VideoWindowInfo& >(result))), SWIGTYPE_p_pj__VideoWindowInfo, SWIG_POINTER_OWN |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_VideoWindow_getVideoMedia(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::VideoWindow *arg1 = (pj::VideoWindow *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  pj::VideoMedia result;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__VideoWindow, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "VideoWindow_getVideoMedia" "', argument " "1"" of type '" "pj::VideoWindow *""'"); 
  }
  arg1 = reinterpret_cast< pj::VideoWindow * >(argp1);
  try {
    result = (arg1)->getVideoMedia();
  } catch(pj::Error &_e) {
    SWIG_Python_Raise(SWIG_NewPointerObj((new pj::Error(static_cast< const pj::Error& >(_e))),SWIGTYPE_p_pj__Error,SWIG_POINTER_OWN), "pj::Error", SWIGTYPE_p_pj__Error); SWIG_fail;
  }
  resultobj = SWIG_NewPointerObj((new pj::VideoMedia(static_cast< const pj::VideoMedia& >(result))), SWIGTYPE_p_pj__VideoMedia, SWIG_POINTER_OWN |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_VideoWindow_Show(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::VideoWindow *arg1 = (pj::VideoWindow *) 0 ;
  bool arg2 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  bool val2 ;
  int ecode2 = 0 ;
  PyObject *swig_obj[2] ;
  
  if (!SWIG_Python_UnpackTuple(args, "VideoWindow_Show", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__VideoWindow, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "VideoWindow_Show" "', argument " "1"" of type '" "pj::VideoWindow *""'"); 
  }
  arg1 = reinterpret_cast< pj::VideoWindow * >(argp1);
  ecode2 = SWIG_AsVal_bool(swig_obj[1], &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "VideoWindow_Show" "', argument " "2"" of type '" "bool""'");
  } 
  arg2 = static_cast< bool >(val2);
  try {
    (arg1)->Show(arg2);
  } catch(pj::Error &_e) {
    SWIG_Python_Raise(SWIG_NewPointerObj((new pj::Error(static_cast< const pj::Error& >(_e))),SWIGTYPE_p_pj__Error,SWIG_POINTER_OWN), "pj::Error", SWIGTYPE_p_pj__Error); SWIG_fail;
  }
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_VideoWindow_setPos(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::VideoWindow *arg1 = (pj::VideoWindow *) 0 ;
  pj::MediaCoordinate *arg2 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  void *argp2 = 0 ;
  int res2 = 0 ;
  PyObject *swig_obj[2] ;
  
  if (!SWIG_Python_UnpackTuple(args, "VideoWindow_setPos", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__VideoWindow, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "VideoWindow_setPos" "', argument " "1"" of type '" "pj::VideoWindow *""'"); 
  }
  arg1 = reinterpret_cast< pj::VideoWindow * >(argp1);
  res2 = SWIG_ConvertPtr(swig_obj[1], &argp2, SWIGTYPE_p_pj__MediaCoordinate,  0  | 0);
  if (!SWIG_IsOK(res2)) {
    SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "VideoWindow_setPos" "', argument " "2"" of type '" "pj::MediaCoordinate const &""'"); 
  }
  if (!argp2) {
    SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "VideoWindow_setPos" "', argument " "2"" of type '" "pj::MediaCoordinate const &""'"); 
  }
  arg2 = reinterpret_cast< pj::MediaCoordinate * >(argp2);
  try {
    (arg1)->setPos((pj::MediaCoordinate const &)*arg2);
  } catch(pj::Error &_e) {
    SWIG_Python_Raise(SWIG_NewPointerObj((new pj::Error(static_cast< const pj::Error& >(_e))),SWIGTYPE_p_pj__Error,SWIG_POINTER_OWN), "pj::Error", SWIGTYPE_p_pj__Error); SWIG_fail;
  }
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_VideoWindow_setSize(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::VideoWindow *arg1 = (pj::VideoWindow *) 0 ;
  pj::MediaSize *arg2 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  void *argp2 = 0 ;
  int res2 = 0 ;
  PyObject *swig_obj[2] ;
  
  if (!SWIG_Python_UnpackTuple(args, "VideoWindow_setSize", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__VideoWindow, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "VideoWindow_setSize" "', argument " "1"" of type '" "pj::VideoWindow *""'"); 
  }
  arg1 = reinterpret_cast< pj::VideoWindow * >(argp1);
  res2 = SWIG_ConvertPtr(swig_obj[1], &argp2, SWIGTYPE_p_pj__MediaSize,  0  | 0);
  if (!SWIG_IsOK(res2)) {
    SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "VideoWindow_setSize" "', argument " "2"" of type '" "pj::MediaSize const &""'"); 
  }
  if (!argp2) {
    SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "VideoWindow_setSize" "', argument " "2"" of type '" "pj::MediaSize const &""'"); 
  }
  arg2 = reinterpret_cast< pj::MediaSize * >(argp2);
  try {
    (arg1)->setSize((pj::MediaSize const &)*arg2);
  } catch(pj::Error &_e) {
    SWIG_Python_Raise(SWIG_NewPointerObj((new pj::Error(static_cast< const pj::Error& >(_e))),SWIGTYPE_p_pj__Error,SWIG_POINTER_OWN), "pj::Error", SWIGTYPE_p_pj__Error); SWIG_fail;
  }
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_VideoWindow_rotate(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::VideoWindow *arg1 = (pj::VideoWindow *) 0 ;
  int arg2 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  int val2 ;
  int ecode2 = 0 ;
  PyObject *swig_obj[2] ;
  
  if (!SWIG_Python_UnpackTuple(args, "VideoWindow_rotate", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__VideoWindow, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "VideoWindow_rotate" "', argument " "1"" of type '" "pj::VideoWindow *""'"); 
  }
  arg1 = reinterpret_cast< pj::VideoWindow * >(argp1);
  ecode2 = SWIG_AsVal_int(swig_obj[1], &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "VideoWindow_rotate" "', argument " "2"" of type '" "int""'");
  } 
  arg2 = static_cast< int >(val2);
  try {
    (arg1)->rotate(arg2);
  } catch(pj::Error &_e) {
    SWIG_Python_Raise(SWIG_NewPointerObj((new pj::Error(static_cast< const pj::Error& >(_e))),SWIGTYPE_p_pj__Error,SWIG_POINTER_OWN), "pj::Error", SWIGTYPE_p_pj__Error); SWIG_fail;
  }
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_VideoWindow_setWindow(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::VideoWindow *arg1 = (pj::VideoWindow *) 0 ;
  pj::VideoWindowHandle *arg2 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  void *argp2 = 0 ;
  int res2 = 0 ;
  PyObject *swig_obj[2] ;
  
  if (!SWIG_Python_UnpackTuple(args, "VideoWindow_setWindow", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__VideoWindow, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "VideoWindow_setWindow" "', argument " "1"" of type '" "pj::VideoWindow *""'"); 
  }
  arg1 = reinterpret_cast< pj::VideoWindow * >(argp1);
  res2 = SWIG_ConvertPtr(swig_obj[1], &argp2, SWIGTYPE_p_pj__VideoWindowHandle,  0  | 0);
  if (!SWIG_IsOK(res2)) {
    SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "VideoWindow_setWindow" "', argument " "2"" of type '" "pj::VideoWindowHandle const &""'"); 
  }
  if (!argp2) {
    SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "VideoWindow_setWindow" "', argument " "2"" of type '" "pj::VideoWindowHandle const &""'"); 
  }
  arg2 = reinterpret_cast< pj::VideoWindowHandle * >(argp2);
  try {
    (arg1)->setWindow((pj::VideoWindowHandle const &)*arg2);
  } catch(pj::Error &_e) {
    SWIG_Python_Raise(SWIG_NewPointerObj((new pj::Error(static_cast< const pj::Error& >(_e))),SWIGTYPE_p_pj__Error,SWIG_POINTER_OWN), "pj::Error", SWIGTYPE_p_pj__Error); SWIG_fail;
  }
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_VideoWindow_setFullScreen(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::VideoWindow *arg1 = (pj::VideoWindow *) 0 ;
  bool arg2 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  bool val2 ;
  int ecode2 = 0 ;
  PyObject *swig_obj[2] ;
  
  if (!SWIG_Python_UnpackTuple(args, "VideoWindow_setFullScreen", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__VideoWindow, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "VideoWindow_setFullScreen" "', argument " "1"" of type '" "pj::VideoWindow *""'"); 
  }
  arg1 = reinterpret_cast< pj::VideoWindow * >(argp1);
  ecode2 = SWIG_AsVal_bool(swig_obj[1], &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "VideoWindow_setFullScreen" "', argument " "2"" of type '" "bool""'");
  } 
  arg2 = static_cast< bool >(val2);
  try {
    (arg1)->setFullScreen(arg2);
  } catch(pj::Error &_e) {
    SWIG_Python_Raise(SWIG_NewPointerObj((new pj::Error(static_cast< const pj::Error& >(_e))),SWIGTYPE_p_pj__Error,SWIG_POINTER_OWN), "pj::Error", SWIGTYPE_p_pj__Error); SWIG_fail;
  }
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_VideoWindow_setFullScreen2(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::VideoWindow *arg1 = (pj::VideoWindow *) 0 ;
  pjmedia_vid_dev_fullscreen_flag arg2 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  int val2 ;
  int ecode2 = 0 ;
  PyObject *swig_obj[2] ;
  
  if (!SWIG_Python_UnpackTuple(args, "VideoWindow_setFullScreen2", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__VideoWindow, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "VideoWindow_setFullScreen2" "', argument " "1"" of type '" "pj::VideoWindow *""'"); 
  }
  arg1 = reinterpret_cast< pj::VideoWindow * >(argp1);
  ecode2 = SWIG_AsVal_int(swig_obj[1], &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "VideoWindow_setFullScreen2" "', argument " "2"" of type '" "pjmedia_vid_dev_fullscreen_flag""'");
  } 
  arg2 = static_cast< pjmedia_vid_dev_fullscreen_flag >(val2);
  try {
    (arg1)->setFullScreen2(arg2);
  } catch(pj::Error &_e) {
    SWIG_Python_Raise(SWIG_NewPointerObj((new pj::Error(static_cast< const pj::Error& >(_e))),SWIGTYPE_p_pj__Error,SWIG_POINTER_OWN), "pj::Error", SWIGTYPE_p_pj__Error); SWIG_fail;
  }
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_delete_VideoWindow(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::VideoWindow *arg1 = (pj::VideoWindow *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__VideoWindow, SWIG_POINTER_DISOWN |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "delete_VideoWindow" "', argument " "1"" of type '" "pj::VideoWindow *""'"); 
  }
  arg1 = reinterpret_cast< pj::VideoWindow * >(argp1);
  delete arg1;
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *VideoWindow_swigregister(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *obj;
  if (!SWIG_Python_UnpackTuple(args, "swigregister", 1, 1, &obj)) return NULL;
  SWIG_TypeNewClientData(SWIGTYPE_p_pj__VideoWindow, SWIG_NewClientData(obj));
  return SWIG_Py_Void();
}

SWIGINTERN PyObject *VideoWindow_swiginit(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  return SWIG_Python_InitShadowInstance(args);
}

SWIGINTERN PyObject *_wrap_VideoPreviewOpParam_rendId_set(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::VideoPreviewOpParam *arg1 = (pj::VideoPreviewOpParam *) 0 ;
  pjmedia_vid_dev_index arg2 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  int val2 ;
  int ecode2 = 0 ;
  PyObject *swig_obj[2] ;
  
  if (!SWIG_Python_UnpackTuple(args, "VideoPreviewOpParam_rendId_set", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__VideoPreviewOpParam, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "VideoPreviewOpParam_rendId_set" "', argument " "1"" of type '" "pj::VideoPreviewOpParam *""'"); 
  }
  arg1 = reinterpret_cast< pj::VideoPreviewOpParam * >(argp1);
  ecode2 = SWIG_AsVal_int(swig_obj[1], &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "VideoPreviewOpParam_rendId_set" "', argument " "2"" of type '" "pjmedia_vid_dev_index""'");
  } 
  arg2 = static_cast< pjmedia_vid_dev_index >(val2);
  if (arg1) (arg1)->rendId = arg2;
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_VideoPreviewOpParam_rendId_get(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::VideoPreviewOpParam *arg1 = (pj::VideoPreviewOpParam *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  pjmedia_vid_dev_index result;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__VideoPreviewOpParam, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "VideoPreviewOpParam_rendId_get" "', argument " "1"" of type '" "pj::VideoPreviewOpParam *""'"); 
  }
  arg1 = reinterpret_cast< pj::VideoPreviewOpParam * >(argp1);
  result = (pjmedia_vid_dev_index) ((arg1)->rendId);
  resultobj = SWIG_From_int(static_cast< int >(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_VideoPreviewOpParam_show_set(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::VideoPreviewOpParam *arg1 = (pj::VideoPreviewOpParam *) 0 ;
  bool arg2 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  bool val2 ;
  int ecode2 = 0 ;
  PyObject *swig_obj[2] ;
  
  if (!SWIG_Python_UnpackTuple(args, "VideoPreviewOpParam_show_set", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__VideoPreviewOpParam, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "VideoPreviewOpParam_show_set" "', argument " "1"" of type '" "pj::VideoPreviewOpParam *""'"); 
  }
  arg1 = reinterpret_cast< pj::VideoPreviewOpParam * >(argp1);
  ecode2 = SWIG_AsVal_bool(swig_obj[1], &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "VideoPreviewOpParam_show_set" "', argument " "2"" of type '" "bool""'");
  } 
  arg2 = static_cast< bool >(val2);
  if (arg1) (arg1)->show = arg2;
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_VideoPreviewOpParam_show_get(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::VideoPreviewOpParam *arg1 = (pj::VideoPreviewOpParam *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  bool result;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__VideoPreviewOpParam, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "VideoPreviewOpParam_show_get" "', argument " "1"" of type '" "pj::VideoPreviewOpParam *""'"); 
  }
  arg1 = reinterpret_cast< pj::VideoPreviewOpParam * >(argp1);
  result = (bool) ((arg1)->show);
  resultobj = SWIG_From_bool(static_cast< bool >(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_VideoPreviewOpParam_windowFlags_set(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::VideoPreviewOpParam *arg1 = (pj::VideoPreviewOpParam *) 0 ;
  unsigned int arg2 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  unsigned int val2 ;
  int ecode2 = 0 ;
  PyObject *swig_obj[2] ;
  
  if (!SWIG_Python_UnpackTuple(args, "VideoPreviewOpParam_windowFlags_set", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__VideoPreviewOpParam, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "VideoPreviewOpParam_windowFlags_set" "', argument " "1"" of type '" "pj::VideoPreviewOpParam *""'"); 
  }
  arg1 = reinterpret_cast< pj::VideoPreviewOpParam * >(argp1);
  ecode2 = SWIG_AsVal_unsigned_SS_int(swig_obj[1], &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "VideoPreviewOpParam_windowFlags_set" "', argument " "2"" of type '" "unsigned int""'");
  } 
  arg2 = static_cast< unsigned int >(val2);
  if (arg1) (arg1)->windowFlags = arg2;
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_VideoPreviewOpParam_windowFlags_get(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::VideoPreviewOpParam *arg1 = (pj::VideoPreviewOpParam *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  unsigned int result;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__VideoPreviewOpParam, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "VideoPreviewOpParam_windowFlags_get" "', argument " "1"" of type '" "pj::VideoPreviewOpParam *""'"); 
  }
  arg1 = reinterpret_cast< pj::VideoPreviewOpParam * >(argp1);
  result = (unsigned int) ((arg1)->windowFlags);
  resultobj = SWIG_From_unsigned_SS_int(static_cast< unsigned int >(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_VideoPreviewOpParam_format_set(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::VideoPreviewOpParam *arg1 = (pj::VideoPreviewOpParam *) 0 ;
  pj::MediaFormat *arg2 = (pj::MediaFormat *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  void *argp2 = 0 ;
  int res2 = 0 ;
  PyObject *swig_obj[2] ;
  
  if (!SWIG_Python_UnpackTuple(args, "VideoPreviewOpParam_format_set", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__VideoPreviewOpParam, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "VideoPreviewOpParam_format_set" "', argument " "1"" of type '" "pj::VideoPreviewOpParam *""'"); 
  }
  arg1 = reinterpret_cast< pj::VideoPreviewOpParam * >(argp1);
  res2 = SWIG_ConvertPtr(swig_obj[1], &argp2,SWIGTYPE_p_pj__MediaFormat, 0 |  0 );
  if (!SWIG_IsOK(res2)) {
    SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "VideoPreviewOpParam_format_set" "', argument " "2"" of type '" "pj::MediaFormat *""'"); 
  }
  arg2 = reinterpret_cast< pj::MediaFormat * >(argp2);
  if (arg1) (arg1)->format = *arg2;
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_VideoPreviewOpParam_format_get(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::VideoPreviewOpParam *arg1 = (pj::VideoPreviewOpParam *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  pj::MediaFormat *result = 0 ;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__VideoPreviewOpParam, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "VideoPreviewOpParam_format_get" "', argument " "1"" of type '" "pj::VideoPreviewOpParam *""'"); 
  }
  arg1 = reinterpret_cast< pj::VideoPreviewOpParam * >(argp1);
  result = (pj::MediaFormat *)& ((arg1)->format);
  resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(result), SWIGTYPE_p_pj__MediaFormat, 0 |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_VideoPreviewOpParam_window_set(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::VideoPreviewOpParam *arg1 = (pj::VideoPreviewOpParam *) 0 ;
  pj::VideoWindowHandle *arg2 = (pj::VideoWindowHandle *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  void *argp2 = 0 ;
  int res2 = 0 ;
  PyObject *swig_obj[2] ;
  
  if (!SWIG_Python_UnpackTuple(args, "VideoPreviewOpParam_window_set", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__VideoPreviewOpParam, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "VideoPreviewOpParam_window_set" "', argument " "1"" of type '" "pj::VideoPreviewOpParam *""'"); 
  }
  arg1 = reinterpret_cast< pj::VideoPreviewOpParam * >(argp1);
  res2 = SWIG_ConvertPtr(swig_obj[1], &argp2,SWIGTYPE_p_pj__VideoWindowHandle, 0 |  0 );
  if (!SWIG_IsOK(res2)) {
    SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "VideoPreviewOpParam_window_set" "', argument " "2"" of type '" "pj::VideoWindowHandle *""'"); 
  }
  arg2 = reinterpret_cast< pj::VideoWindowHandle * >(argp2);
  if (arg1) (arg1)->window = *arg2;
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_VideoPreviewOpParam_window_get(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::VideoPreviewOpParam *arg1 = (pj::VideoPreviewOpParam *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  pj::VideoWindowHandle *result = 0 ;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__VideoPreviewOpParam, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "VideoPreviewOpParam_window_get" "', argument " "1"" of type '" "pj::VideoPreviewOpParam *""'"); 
  }
  arg1 = reinterpret_cast< pj::VideoPreviewOpParam * >(argp1);
  result = (pj::VideoWindowHandle *)& ((arg1)->window);
  resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(result), SWIGTYPE_p_pj__VideoWindowHandle, 0 |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_new_VideoPreviewOpParam(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::VideoPreviewOpParam *result = 0 ;
  
  if (!SWIG_Python_UnpackTuple(args, "new_VideoPreviewOpParam", 0, 0, 0)) SWIG_fail;
  result = (pj::VideoPreviewOpParam *)new pj::VideoPreviewOpParam();
  resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(result), SWIGTYPE_p_pj__VideoPreviewOpParam, SWIG_POINTER_NEW |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_delete_VideoPreviewOpParam(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::VideoPreviewOpParam *arg1 = (pj::VideoPreviewOpParam *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__VideoPreviewOpParam, SWIG_POINTER_DISOWN |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "delete_VideoPreviewOpParam" "', argument " "1"" of type '" "pj::VideoPreviewOpParam *""'"); 
  }
  arg1 = reinterpret_cast< pj::VideoPreviewOpParam * >(argp1);
  delete arg1;
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *VideoPreviewOpParam_swigregister(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *obj;
  if (!SWIG_Python_UnpackTuple(args, "swigregister", 1, 1, &obj)) return NULL;
  SWIG_TypeNewClientData(SWIGTYPE_p_pj__VideoPreviewOpParam, SWIG_NewClientData(obj));
  return SWIG_Py_Void();
}

SWIGINTERN PyObject *VideoPreviewOpParam_swiginit(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  return SWIG_Python_InitShadowInstance(args);
}

SWIGINTERN PyObject *_wrap_new_VideoPreview(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  int arg1 ;
  int val1 ;
  int ecode1 = 0 ;
  PyObject *swig_obj[1] ;
  pj::VideoPreview *result = 0 ;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  ecode1 = SWIG_AsVal_int(swig_obj[0], &val1);
  if (!SWIG_IsOK(ecode1)) {
    SWIG_exception_fail(SWIG_ArgError(ecode1), "in method '" "new_VideoPreview" "', argument " "1"" of type '" "int""'");
  } 
  arg1 = static_cast< int >(val1);
  result = (pj::VideoPreview *)new pj::VideoPreview(arg1);
  resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(result), SWIGTYPE_p_pj__VideoPreview, SWIG_POINTER_NEW |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_VideoPreview_hasNative(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::VideoPreview *arg1 = (pj::VideoPreview *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  bool result;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__VideoPreview, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "VideoPreview_hasNative" "', argument " "1"" of type '" "pj::VideoPreview *""'"); 
  }
  arg1 = reinterpret_cast< pj::VideoPreview * >(argp1);
  result = (bool)(arg1)->hasNative();
  resultobj = SWIG_From_bool(static_cast< bool >(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_VideoPreview_start(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::VideoPreview *arg1 = (pj::VideoPreview *) 0 ;
  pj::VideoPreviewOpParam *arg2 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  void *argp2 = 0 ;
  int res2 = 0 ;
  PyObject *swig_obj[2] ;
  
  if (!SWIG_Python_UnpackTuple(args, "VideoPreview_start", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__VideoPreview, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "VideoPreview_start" "', argument " "1"" of type '" "pj::VideoPreview *""'"); 
  }
  arg1 = reinterpret_cast< pj::VideoPreview * >(argp1);
  res2 = SWIG_ConvertPtr(swig_obj[1], &argp2, SWIGTYPE_p_pj__VideoPreviewOpParam,  0  | 0);
  if (!SWIG_IsOK(res2)) {
    SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "VideoPreview_start" "', argument " "2"" of type '" "pj::VideoPreviewOpParam const &""'"); 
  }
  if (!argp2) {
    SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "VideoPreview_start" "', argument " "2"" of type '" "pj::VideoPreviewOpParam const &""'"); 
  }
  arg2 = reinterpret_cast< pj::VideoPreviewOpParam * >(argp2);
  try {
    (arg1)->start((pj::VideoPreviewOpParam const &)*arg2);
  } catch(pj::Error &_e) {
    SWIG_Python_Raise(SWIG_NewPointerObj((new pj::Error(static_cast< const pj::Error& >(_e))),SWIGTYPE_p_pj__Error,SWIG_POINTER_OWN), "pj::Error", SWIGTYPE_p_pj__Error); SWIG_fail;
  }
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_VideoPreview_stop(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::VideoPreview *arg1 = (pj::VideoPreview *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__VideoPreview, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "VideoPreview_stop" "', argument " "1"" of type '" "pj::VideoPreview *""'"); 
  }
  arg1 = reinterpret_cast< pj::VideoPreview * >(argp1);
  try {
    (arg1)->stop();
  } catch(pj::Error &_e) {
    SWIG_Python_Raise(SWIG_NewPointerObj((new pj::Error(static_cast< const pj::Error& >(_e))),SWIGTYPE_p_pj__Error,SWIG_POINTER_OWN), "pj::Error", SWIGTYPE_p_pj__Error); SWIG_fail;
  }
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_VideoPreview_getVideoWindow(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::VideoPreview *arg1 = (pj::VideoPreview *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  SwigValueWrapper< pj::VideoWindow > result;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__VideoPreview, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "VideoPreview_getVideoWindow" "', argument " "1"" of type '" "pj::VideoPreview *""'"); 
  }
  arg1 = reinterpret_cast< pj::VideoPreview * >(argp1);
  result = (arg1)->getVideoWindow();
  resultobj = SWIG_NewPointerObj((new pj::VideoWindow(static_cast< const pj::VideoWindow& >(result))), SWIGTYPE_p_pj__VideoWindow, SWIG_POINTER_OWN |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_VideoPreview_getVideoMedia(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::VideoPreview *arg1 = (pj::VideoPreview *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  pj::VideoMedia result;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__VideoPreview, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "VideoPreview_getVideoMedia" "', argument " "1"" of type '" "pj::VideoPreview *""'"); 
  }
  arg1 = reinterpret_cast< pj::VideoPreview * >(argp1);
  try {
    result = (arg1)->getVideoMedia();
  } catch(pj::Error &_e) {
    SWIG_Python_Raise(SWIG_NewPointerObj((new pj::Error(static_cast< const pj::Error& >(_e))),SWIGTYPE_p_pj__Error,SWIG_POINTER_OWN), "pj::Error", SWIGTYPE_p_pj__Error); SWIG_fail;
  }
  resultobj = SWIG_NewPointerObj((new pj::VideoMedia(static_cast< const pj::VideoMedia& >(result))), SWIGTYPE_p_pj__VideoMedia, SWIG_POINTER_OWN |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_delete_VideoPreview(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::VideoPreview *arg1 = (pj::VideoPreview *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__VideoPreview, SWIG_POINTER_DISOWN |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "delete_VideoPreview" "', argument " "1"" of type '" "pj::VideoPreview *""'"); 
  }
  arg1 = reinterpret_cast< pj::VideoPreview * >(argp1);
  delete arg1;
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *VideoPreview_swigregister(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *obj;
  if (!SWIG_Python_UnpackTuple(args, "swigregister", 1, 1, &obj)) return NULL;
  SWIG_TypeNewClientData(SWIGTYPE_p_pj__VideoPreview, SWIG_NewClientData(obj));
  return SWIG_Py_Void();
}

SWIGINTERN PyObject *VideoPreview_swiginit(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  return SWIG_Python_InitShadowInstance(args);
}

SWIGINTERN PyObject *_wrap_VideoDevInfo_id_set(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::VideoDevInfo *arg1 = (pj::VideoDevInfo *) 0 ;
  pjmedia_vid_dev_index arg2 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  int val2 ;
  int ecode2 = 0 ;
  PyObject *swig_obj[2] ;
  
  if (!SWIG_Python_UnpackTuple(args, "VideoDevInfo_id_set", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__VideoDevInfo, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "VideoDevInfo_id_set" "', argument " "1"" of type '" "pj::VideoDevInfo *""'"); 
  }
  arg1 = reinterpret_cast< pj::VideoDevInfo * >(argp1);
  ecode2 = SWIG_AsVal_int(swig_obj[1], &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "VideoDevInfo_id_set" "', argument " "2"" of type '" "pjmedia_vid_dev_index""'");
  } 
  arg2 = static_cast< pjmedia_vid_dev_index >(val2);
  if (arg1) (arg1)->id = arg2;
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_VideoDevInfo_id_get(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::VideoDevInfo *arg1 = (pj::VideoDevInfo *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  pjmedia_vid_dev_index result;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__VideoDevInfo, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "VideoDevInfo_id_get" "', argument " "1"" of type '" "pj::VideoDevInfo *""'"); 
  }
  arg1 = reinterpret_cast< pj::VideoDevInfo * >(argp1);
  result = (pjmedia_vid_dev_index) ((arg1)->id);
  resultobj = SWIG_From_int(static_cast< int >(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_VideoDevInfo_name_set(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::VideoDevInfo *arg1 = (pj::VideoDevInfo *) 0 ;
  pj::string *arg2 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  int res2 = SWIG_OLDOBJ ;
  PyObject *swig_obj[2] ;
  
  if (!SWIG_Python_UnpackTuple(args, "VideoDevInfo_name_set", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__VideoDevInfo, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "VideoDevInfo_name_set" "', argument " "1"" of type '" "pj::VideoDevInfo *""'"); 
  }
  arg1 = reinterpret_cast< pj::VideoDevInfo * >(argp1);
  {
    std::string *ptr = (std::string *)0;
    res2 = SWIG_AsPtr_std_string(swig_obj[1], &ptr);
    if (!SWIG_IsOK(res2)) {
      SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "VideoDevInfo_name_set" "', argument " "2"" of type '" "pj::string const &""'"); 
    }
    if (!ptr) {
      SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "VideoDevInfo_name_set" "', argument " "2"" of type '" "pj::string const &""'"); 
    }
    arg2 = ptr;
  }
  if (arg1) (arg1)->name = *arg2;
  resultobj = SWIG_Py_Void();
  if (SWIG_IsNewObj(res2)) delete arg2;
  return resultobj;
fail:
  if (SWIG_IsNewObj(res2)) delete arg2;
  return NULL;
}


SWIGINTERN PyObject *_wrap_VideoDevInfo_name_get(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::VideoDevInfo *arg1 = (pj::VideoDevInfo *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  pj::string *result = 0 ;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__VideoDevInfo, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "VideoDevInfo_name_get" "', argument " "1"" of type '" "pj::VideoDevInfo *""'"); 
  }
  arg1 = reinterpret_cast< pj::VideoDevInfo * >(argp1);
  result = (pj::string *) & ((arg1)->name);
  resultobj = SWIG_From_std_string(static_cast< std::string >(*result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_VideoDevInfo_driver_set(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::VideoDevInfo *arg1 = (pj::VideoDevInfo *) 0 ;
  pj::string *arg2 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  int res2 = SWIG_OLDOBJ ;
  PyObject *swig_obj[2] ;
  
  if (!SWIG_Python_UnpackTuple(args, "VideoDevInfo_driver_set", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__VideoDevInfo, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "VideoDevInfo_driver_set" "', argument " "1"" of type '" "pj::VideoDevInfo *""'"); 
  }
  arg1 = reinterpret_cast< pj::VideoDevInfo * >(argp1);
  {
    std::string *ptr = (std::string *)0;
    res2 = SWIG_AsPtr_std_string(swig_obj[1], &ptr);
    if (!SWIG_IsOK(res2)) {
      SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "VideoDevInfo_driver_set" "', argument " "2"" of type '" "pj::string const &""'"); 
    }
    if (!ptr) {
      SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "VideoDevInfo_driver_set" "', argument " "2"" of type '" "pj::string const &""'"); 
    }
    arg2 = ptr;
  }
  if (arg1) (arg1)->driver = *arg2;
  resultobj = SWIG_Py_Void();
  if (SWIG_IsNewObj(res2)) delete arg2;
  return resultobj;
fail:
  if (SWIG_IsNewObj(res2)) delete arg2;
  return NULL;
}


SWIGINTERN PyObject *_wrap_VideoDevInfo_driver_get(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::VideoDevInfo *arg1 = (pj::VideoDevInfo *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  pj::string *result = 0 ;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__VideoDevInfo, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "VideoDevInfo_driver_get" "', argument " "1"" of type '" "pj::VideoDevInfo *""'"); 
  }
  arg1 = reinterpret_cast< pj::VideoDevInfo * >(argp1);
  result = (pj::string *) & ((arg1)->driver);
  resultobj = SWIG_From_std_string(static_cast< std::string >(*result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_VideoDevInfo_dir_set(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::VideoDevInfo *arg1 = (pj::VideoDevInfo *) 0 ;
  pjmedia_dir arg2 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  int val2 ;
  int ecode2 = 0 ;
  PyObject *swig_obj[2] ;
  
  if (!SWIG_Python_UnpackTuple(args, "VideoDevInfo_dir_set", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__VideoDevInfo, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "VideoDevInfo_dir_set" "', argument " "1"" of type '" "pj::VideoDevInfo *""'"); 
  }
  arg1 = reinterpret_cast< pj::VideoDevInfo * >(argp1);
  ecode2 = SWIG_AsVal_int(swig_obj[1], &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "VideoDevInfo_dir_set" "', argument " "2"" of type '" "pjmedia_dir""'");
  } 
  arg2 = static_cast< pjmedia_dir >(val2);
  if (arg1) (arg1)->dir = arg2;
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_VideoDevInfo_dir_get(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::VideoDevInfo *arg1 = (pj::VideoDevInfo *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  pjmedia_dir result;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__VideoDevInfo, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "VideoDevInfo_dir_get" "', argument " "1"" of type '" "pj::VideoDevInfo *""'"); 
  }
  arg1 = reinterpret_cast< pj::VideoDevInfo * >(argp1);
  result = (pjmedia_dir) ((arg1)->dir);
  resultobj = SWIG_From_int(static_cast< int >(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_VideoDevInfo_caps_set(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::VideoDevInfo *arg1 = (pj::VideoDevInfo *) 0 ;
  unsigned int arg2 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  unsigned int val2 ;
  int ecode2 = 0 ;
  PyObject *swig_obj[2] ;
  
  if (!SWIG_Python_UnpackTuple(args, "VideoDevInfo_caps_set", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__VideoDevInfo, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "VideoDevInfo_caps_set" "', argument " "1"" of type '" "pj::VideoDevInfo *""'"); 
  }
  arg1 = reinterpret_cast< pj::VideoDevInfo * >(argp1);
  ecode2 = SWIG_AsVal_unsigned_SS_int(swig_obj[1], &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "VideoDevInfo_caps_set" "', argument " "2"" of type '" "unsigned int""'");
  } 
  arg2 = static_cast< unsigned int >(val2);
  if (arg1) (arg1)->caps = arg2;
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_VideoDevInfo_caps_get(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::VideoDevInfo *arg1 = (pj::VideoDevInfo *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  unsigned int result;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__VideoDevInfo, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "VideoDevInfo_caps_get" "', argument " "1"" of type '" "pj::VideoDevInfo *""'"); 
  }
  arg1 = reinterpret_cast< pj::VideoDevInfo * >(argp1);
  result = (unsigned int) ((arg1)->caps);
  resultobj = SWIG_From_unsigned_SS_int(static_cast< unsigned int >(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_VideoDevInfo_fmt_set(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::VideoDevInfo *arg1 = (pj::VideoDevInfo *) 0 ;
  pj::MediaFormatVideoVector *arg2 = (pj::MediaFormatVideoVector *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  void *argp2 = 0 ;
  int res2 = 0 ;
  PyObject *swig_obj[2] ;
  
  if (!SWIG_Python_UnpackTuple(args, "VideoDevInfo_fmt_set", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__VideoDevInfo, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "VideoDevInfo_fmt_set" "', argument " "1"" of type '" "pj::VideoDevInfo *""'"); 
  }
  arg1 = reinterpret_cast< pj::VideoDevInfo * >(argp1);
  res2 = SWIG_ConvertPtr(swig_obj[1], &argp2,SWIGTYPE_p_std__vectorT_pj__MediaFormatVideo_std__allocatorT_pj__MediaFormatVideo_t_t, 0 |  0 );
  if (!SWIG_IsOK(res2)) {
    SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "VideoDevInfo_fmt_set" "', argument " "2"" of type '" "pj::MediaFormatVideoVector *""'"); 
  }
  arg2 = reinterpret_cast< pj::MediaFormatVideoVector * >(argp2);
  if (arg1) (arg1)->fmt = *arg2;
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_VideoDevInfo_fmt_get(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::VideoDevInfo *arg1 = (pj::VideoDevInfo *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  pj::MediaFormatVideoVector *result = 0 ;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__VideoDevInfo, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "VideoDevInfo_fmt_get" "', argument " "1"" of type '" "pj::VideoDevInfo *""'"); 
  }
  arg1 = reinterpret_cast< pj::VideoDevInfo * >(argp1);
  result = (pj::MediaFormatVideoVector *)& ((arg1)->fmt);
  resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(result), SWIGTYPE_p_std__vectorT_pj__MediaFormatVideo_std__allocatorT_pj__MediaFormatVideo_t_t, 0 |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_new_VideoDevInfo(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::VideoDevInfo *result = 0 ;
  
  if (!SWIG_Python_UnpackTuple(args, "new_VideoDevInfo", 0, 0, 0)) SWIG_fail;
  result = (pj::VideoDevInfo *)new pj::VideoDevInfo();
  resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(result), SWIGTYPE_p_pj__VideoDevInfo, SWIG_POINTER_NEW |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_delete_VideoDevInfo(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::VideoDevInfo *arg1 = (pj::VideoDevInfo *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__VideoDevInfo, SWIG_POINTER_DISOWN |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "delete_VideoDevInfo" "', argument " "1"" of type '" "pj::VideoDevInfo *""'"); 
  }
  arg1 = reinterpret_cast< pj::VideoDevInfo * >(argp1);
  delete arg1;
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *VideoDevInfo_swigregister(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *obj;
  if (!SWIG_Python_UnpackTuple(args, "swigregister", 1, 1, &obj)) return NULL;
  SWIG_TypeNewClientData(SWIGTYPE_p_pj__VideoDevInfo, SWIG_NewClientData(obj));
  return SWIG_Py_Void();
}

SWIGINTERN PyObject *VideoDevInfo_swiginit(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  return SWIG_Python_InitShadowInstance(args);
}

SWIGINTERN PyObject *_wrap_VideoSwitchParam_target_id_set(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::VideoSwitchParam *arg1 = (pj::VideoSwitchParam *) 0 ;
  pjmedia_vid_dev_index arg2 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  int val2 ;
  int ecode2 = 0 ;
  PyObject *swig_obj[2] ;
  
  if (!SWIG_Python_UnpackTuple(args, "VideoSwitchParam_target_id_set", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__VideoSwitchParam, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "VideoSwitchParam_target_id_set" "', argument " "1"" of type '" "pj::VideoSwitchParam *""'"); 
  }
  arg1 = reinterpret_cast< pj::VideoSwitchParam * >(argp1);
  ecode2 = SWIG_AsVal_int(swig_obj[1], &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "VideoSwitchParam_target_id_set" "', argument " "2"" of type '" "pjmedia_vid_dev_index""'");
  } 
  arg2 = static_cast< pjmedia_vid_dev_index >(val2);
  if (arg1) (arg1)->target_id = arg2;
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_VideoSwitchParam_target_id_get(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::VideoSwitchParam *arg1 = (pj::VideoSwitchParam *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  pjmedia_vid_dev_index result;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__VideoSwitchParam, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "VideoSwitchParam_target_id_get" "', argument " "1"" of type '" "pj::VideoSwitchParam *""'"); 
  }
  arg1 = reinterpret_cast< pj::VideoSwitchParam * >(argp1);
  result = (pjmedia_vid_dev_index) ((arg1)->target_id);
  resultobj = SWIG_From_int(static_cast< int >(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_new_VideoSwitchParam(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::VideoSwitchParam *result = 0 ;
  
  if (!SWIG_Python_UnpackTuple(args, "new_VideoSwitchParam", 0, 0, 0)) SWIG_fail;
  result = (pj::VideoSwitchParam *)new pj::VideoSwitchParam();
  resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(result), SWIGTYPE_p_pj__VideoSwitchParam, SWIG_POINTER_NEW |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_delete_VideoSwitchParam(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::VideoSwitchParam *arg1 = (pj::VideoSwitchParam *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__VideoSwitchParam, SWIG_POINTER_DISOWN |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "delete_VideoSwitchParam" "', argument " "1"" of type '" "pj::VideoSwitchParam *""'"); 
  }
  arg1 = reinterpret_cast< pj::VideoSwitchParam * >(argp1);
  delete arg1;
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *VideoSwitchParam_swigregister(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *obj;
  if (!SWIG_Python_UnpackTuple(args, "swigregister", 1, 1, &obj)) return NULL;
  SWIG_TypeNewClientData(SWIGTYPE_p_pj__VideoSwitchParam, SWIG_NewClientData(obj));
  return SWIG_Py_Void();
}

SWIGINTERN PyObject *VideoSwitchParam_swiginit(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  return SWIG_Python_InitShadowInstance(args);
}

SWIGINTERN PyObject *_wrap_VidDevManager_initSubsys(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::VidDevManager *arg1 = (pj::VidDevManager *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__VidDevManager, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "VidDevManager_initSubsys" "', argument " "1"" of type '" "pj::VidDevManager *""'"); 
  }
  arg1 = reinterpret_cast< pj::VidDevManager * >(argp1);
  try {
    (arg1)->initSubsys();
  } catch(pj::Error &_e) {
    SWIG_Python_Raise(SWIG_NewPointerObj((new pj::Error(static_cast< const pj::Error& >(_e))),SWIGTYPE_p_pj__Error,SWIG_POINTER_OWN), "pj::Error", SWIGTYPE_p_pj__Error); SWIG_fail;
  }
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_VidDevManager_refreshDevs(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::VidDevManager *arg1 = (pj::VidDevManager *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__VidDevManager, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "VidDevManager_refreshDevs" "', argument " "1"" of type '" "pj::VidDevManager *""'"); 
  }
  arg1 = reinterpret_cast< pj::VidDevManager * >(argp1);
  try {
    (arg1)->refreshDevs();
  } catch(pj::Error &_e) {
    SWIG_Python_Raise(SWIG_NewPointerObj((new pj::Error(static_cast< const pj::Error& >(_e))),SWIGTYPE_p_pj__Error,SWIG_POINTER_OWN), "pj::Error", SWIGTYPE_p_pj__Error); SWIG_fail;
  }
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_VidDevManager_getDevCount(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::VidDevManager *arg1 = (pj::VidDevManager *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  unsigned int result;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__VidDevManager, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "VidDevManager_getDevCount" "', argument " "1"" of type '" "pj::VidDevManager *""'"); 
  }
  arg1 = reinterpret_cast< pj::VidDevManager * >(argp1);
  result = (unsigned int)(arg1)->getDevCount();
  resultobj = SWIG_From_unsigned_SS_int(static_cast< unsigned int >(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_VidDevManager_getDevInfo(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::VidDevManager *arg1 = (pj::VidDevManager *) 0 ;
  int arg2 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  int val2 ;
  int ecode2 = 0 ;
  PyObject *swig_obj[2] ;
  pj::VideoDevInfo result;
  
  if (!SWIG_Python_UnpackTuple(args, "VidDevManager_getDevInfo", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__VidDevManager, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "VidDevManager_getDevInfo" "', argument " "1"" of type '" "pj::VidDevManager const *""'"); 
  }
  arg1 = reinterpret_cast< pj::VidDevManager * >(argp1);
  ecode2 = SWIG_AsVal_int(swig_obj[1], &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "VidDevManager_getDevInfo" "', argument " "2"" of type '" "int""'");
  } 
  arg2 = static_cast< int >(val2);
  try {
    result = ((pj::VidDevManager const *)arg1)->getDevInfo(arg2);
  } catch(pj::Error &_e) {
    SWIG_Python_Raise(SWIG_NewPointerObj((new pj::Error(static_cast< const pj::Error& >(_e))),SWIGTYPE_p_pj__Error,SWIG_POINTER_OWN), "pj::Error", SWIGTYPE_p_pj__Error); SWIG_fail;
  }
  resultobj = SWIG_NewPointerObj((new pj::VideoDevInfo(static_cast< const pj::VideoDevInfo& >(result))), SWIGTYPE_p_pj__VideoDevInfo, SWIG_POINTER_OWN |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_VidDevManager_enumDev2(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::VidDevManager *arg1 = (pj::VidDevManager *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  pj::VideoDevInfoVector2 result;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__VidDevManager, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "VidDevManager_enumDev2" "', argument " "1"" of type '" "pj::VidDevManager const *""'"); 
  }
  arg1 = reinterpret_cast< pj::VidDevManager * >(argp1);
  try {
    result = ((pj::VidDevManager const *)arg1)->enumDev2();
  } catch(pj::Error &_e) {
    SWIG_Python_Raise(SWIG_NewPointerObj((new pj::Error(static_cast< const pj::Error& >(_e))),SWIGTYPE_p_pj__Error,SWIG_POINTER_OWN), "pj::Error", SWIGTYPE_p_pj__Error); SWIG_fail;
  }
  resultobj = swig::from(static_cast< std::vector< pj::VideoDevInfo,std::allocator< pj::VideoDevInfo > > >(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_VidDevManager_lookupDev(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::VidDevManager *arg1 = (pj::VidDevManager *) 0 ;
  pj::string *arg2 = 0 ;
  pj::string *arg3 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  int res2 = SWIG_OLDOBJ ;
  int res3 = SWIG_OLDOBJ ;
  PyObject *swig_obj[3] ;
  int result;
  
  if (!SWIG_Python_UnpackTuple(args, "VidDevManager_lookupDev", 3, 3, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__VidDevManager, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "VidDevManager_lookupDev" "', argument " "1"" of type '" "pj::VidDevManager const *""'"); 
  }
  arg1 = reinterpret_cast< pj::VidDevManager * >(argp1);
  {
    std::string *ptr = (std::string *)0;
    res2 = SWIG_AsPtr_std_string(swig_obj[1], &ptr);
    if (!SWIG_IsOK(res2)) {
      SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "VidDevManager_lookupDev" "', argument " "2"" of type '" "pj::string const &""'"); 
    }
    if (!ptr) {
      SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "VidDevManager_lookupDev" "', argument " "2"" of type '" "pj::string const &""'"); 
    }
    arg2 = ptr;
  }
  {
    std::string *ptr = (std::string *)0;
    res3 = SWIG_AsPtr_std_string(swig_obj[2], &ptr);
    if (!SWIG_IsOK(res3)) {
      SWIG_exception_fail(SWIG_ArgError(res3), "in method '" "VidDevManager_lookupDev" "', argument " "3"" of type '" "pj::string const &""'"); 
    }
    if (!ptr) {
      SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "VidDevManager_lookupDev" "', argument " "3"" of type '" "pj::string const &""'"); 
    }
    arg3 = ptr;
  }
  try {
    result = (int)((pj::VidDevManager const *)arg1)->lookupDev((pj::string const &)*arg2,(pj::string const &)*arg3);
  } catch(pj::Error &_e) {
    SWIG_Python_Raise(SWIG_NewPointerObj((new pj::Error(static_cast< const pj::Error& >(_e))),SWIGTYPE_p_pj__Error,SWIG_POINTER_OWN), "pj::Error", SWIGTYPE_p_pj__Error); SWIG_fail;
  }
  resultobj = SWIG_From_int(static_cast< int >(result));
  if (SWIG_IsNewObj(res2)) delete arg2;
  if (SWIG_IsNewObj(res3)) delete arg3;
  return resultobj;
fail:
  if (SWIG_IsNewObj(res2)) delete arg2;
  if (SWIG_IsNewObj(res3)) delete arg3;
  return NULL;
}


SWIGINTERN PyObject *_wrap_VidDevManager_capName(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::VidDevManager *arg1 = (pj::VidDevManager *) 0 ;
  pjmedia_vid_dev_cap arg2 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  int val2 ;
  int ecode2 = 0 ;
  PyObject *swig_obj[2] ;
  pj::string result;
  
  if (!SWIG_Python_UnpackTuple(args, "VidDevManager_capName", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__VidDevManager, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "VidDevManager_capName" "', argument " "1"" of type '" "pj::VidDevManager const *""'"); 
  }
  arg1 = reinterpret_cast< pj::VidDevManager * >(argp1);
  ecode2 = SWIG_AsVal_int(swig_obj[1], &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "VidDevManager_capName" "', argument " "2"" of type '" "pjmedia_vid_dev_cap""'");
  } 
  arg2 = static_cast< pjmedia_vid_dev_cap >(val2);
  result = ((pj::VidDevManager const *)arg1)->capName(arg2);
  resultobj = SWIG_From_std_string(static_cast< std::string >(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_VidDevManager_setFormat(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::VidDevManager *arg1 = (pj::VidDevManager *) 0 ;
  int arg2 ;
  pj::MediaFormatVideo *arg3 = 0 ;
  bool arg4 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  int val2 ;
  int ecode2 = 0 ;
  void *argp3 = 0 ;
  int res3 = 0 ;
  bool val4 ;
  int ecode4 = 0 ;
  PyObject *swig_obj[4] ;
  
  if (!SWIG_Python_UnpackTuple(args, "VidDevManager_setFormat", 4, 4, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__VidDevManager, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "VidDevManager_setFormat" "', argument " "1"" of type '" "pj::VidDevManager *""'"); 
  }
  arg1 = reinterpret_cast< pj::VidDevManager * >(argp1);
  ecode2 = SWIG_AsVal_int(swig_obj[1], &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "VidDevManager_setFormat" "', argument " "2"" of type '" "int""'");
  } 
  arg2 = static_cast< int >(val2);
  res3 = SWIG_ConvertPtr(swig_obj[2], &argp3, SWIGTYPE_p_pj__MediaFormatVideo,  0  | 0);
  if (!SWIG_IsOK(res3)) {
    SWIG_exception_fail(SWIG_ArgError(res3), "in method '" "VidDevManager_setFormat" "', argument " "3"" of type '" "pj::MediaFormatVideo const &""'"); 
  }
  if (!argp3) {
    SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "VidDevManager_setFormat" "', argument " "3"" of type '" "pj::MediaFormatVideo const &""'"); 
  }
  arg3 = reinterpret_cast< pj::MediaFormatVideo * >(argp3);
  ecode4 = SWIG_AsVal_bool(swig_obj[3], &val4);
  if (!SWIG_IsOK(ecode4)) {
    SWIG_exception_fail(SWIG_ArgError(ecode4), "in method '" "VidDevManager_setFormat" "', argument " "4"" of type '" "bool""'");
  } 
  arg4 = static_cast< bool >(val4);
  try {
    (arg1)->setFormat(arg2,(pj::MediaFormatVideo const &)*arg3,arg4);
  } catch(pj::Error &_e) {
    SWIG_Python_Raise(SWIG_NewPointerObj((new pj::Error(static_cast< const pj::Error& >(_e))),SWIGTYPE_p_pj__Error,SWIG_POINTER_OWN), "pj::Error", SWIGTYPE_p_pj__Error); SWIG_fail;
  }
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_VidDevManager_getFormat(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::VidDevManager *arg1 = (pj::VidDevManager *) 0 ;
  int arg2 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  int val2 ;
  int ecode2 = 0 ;
  PyObject *swig_obj[2] ;
  pj::MediaFormatVideo result;
  
  if (!SWIG_Python_UnpackTuple(args, "VidDevManager_getFormat", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__VidDevManager, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "VidDevManager_getFormat" "', argument " "1"" of type '" "pj::VidDevManager const *""'"); 
  }
  arg1 = reinterpret_cast< pj::VidDevManager * >(argp1);
  ecode2 = SWIG_AsVal_int(swig_obj[1], &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "VidDevManager_getFormat" "', argument " "2"" of type '" "int""'");
  } 
  arg2 = static_cast< int >(val2);
  try {
    result = ((pj::VidDevManager const *)arg1)->getFormat(arg2);
  } catch(pj::Error &_e) {
    SWIG_Python_Raise(SWIG_NewPointerObj((new pj::Error(static_cast< const pj::Error& >(_e))),SWIGTYPE_p_pj__Error,SWIG_POINTER_OWN), "pj::Error", SWIGTYPE_p_pj__Error); SWIG_fail;
  }
  resultobj = SWIG_NewPointerObj((new pj::MediaFormatVideo(static_cast< const pj::MediaFormatVideo& >(result))), SWIGTYPE_p_pj__MediaFormatVideo, SWIG_POINTER_OWN |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_VidDevManager_setInputScale(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::VidDevManager *arg1 = (pj::VidDevManager *) 0 ;
  int arg2 ;
  pj::MediaSize *arg3 = 0 ;
  bool arg4 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  int val2 ;
  int ecode2 = 0 ;
  void *argp3 = 0 ;
  int res3 = 0 ;
  bool val4 ;
  int ecode4 = 0 ;
  PyObject *swig_obj[4] ;
  
  if (!SWIG_Python_UnpackTuple(args, "VidDevManager_setInputScale", 4, 4, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__VidDevManager, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "VidDevManager_setInputScale" "', argument " "1"" of type '" "pj::VidDevManager *""'"); 
  }
  arg1 = reinterpret_cast< pj::VidDevManager * >(argp1);
  ecode2 = SWIG_AsVal_int(swig_obj[1], &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "VidDevManager_setInputScale" "', argument " "2"" of type '" "int""'");
  } 
  arg2 = static_cast< int >(val2);
  res3 = SWIG_ConvertPtr(swig_obj[2], &argp3, SWIGTYPE_p_pj__MediaSize,  0  | 0);
  if (!SWIG_IsOK(res3)) {
    SWIG_exception_fail(SWIG_ArgError(res3), "in method '" "VidDevManager_setInputScale" "', argument " "3"" of type '" "pj::MediaSize const &""'"); 
  }
  if (!argp3) {
    SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "VidDevManager_setInputScale" "', argument " "3"" of type '" "pj::MediaSize const &""'"); 
  }
  arg3 = reinterpret_cast< pj::MediaSize * >(argp3);
  ecode4 = SWIG_AsVal_bool(swig_obj[3], &val4);
  if (!SWIG_IsOK(ecode4)) {
    SWIG_exception_fail(SWIG_ArgError(ecode4), "in method '" "VidDevManager_setInputScale" "', argument " "4"" of type '" "bool""'");
  } 
  arg4 = static_cast< bool >(val4);
  try {
    (arg1)->setInputScale(arg2,(pj::MediaSize const &)*arg3,arg4);
  } catch(pj::Error &_e) {
    SWIG_Python_Raise(SWIG_NewPointerObj((new pj::Error(static_cast< const pj::Error& >(_e))),SWIGTYPE_p_pj__Error,SWIG_POINTER_OWN), "pj::Error", SWIGTYPE_p_pj__Error); SWIG_fail;
  }
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_VidDevManager_getInputScale(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::VidDevManager *arg1 = (pj::VidDevManager *) 0 ;
  int arg2 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  int val2 ;
  int ecode2 = 0 ;
  PyObject *swig_obj[2] ;
  pj::MediaSize result;
  
  if (!SWIG_Python_UnpackTuple(args, "VidDevManager_getInputScale", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__VidDevManager, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "VidDevManager_getInputScale" "', argument " "1"" of type '" "pj::VidDevManager const *""'"); 
  }
  arg1 = reinterpret_cast< pj::VidDevManager * >(argp1);
  ecode2 = SWIG_AsVal_int(swig_obj[1], &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "VidDevManager_getInputScale" "', argument " "2"" of type '" "int""'");
  } 
  arg2 = static_cast< int >(val2);
  try {
    result = ((pj::VidDevManager const *)arg1)->getInputScale(arg2);
  } catch(pj::Error &_e) {
    SWIG_Python_Raise(SWIG_NewPointerObj((new pj::Error(static_cast< const pj::Error& >(_e))),SWIGTYPE_p_pj__Error,SWIG_POINTER_OWN), "pj::Error", SWIGTYPE_p_pj__Error); SWIG_fail;
  }
  resultobj = SWIG_NewPointerObj((new pj::MediaSize(static_cast< const pj::MediaSize& >(result))), SWIGTYPE_p_pj__MediaSize, SWIG_POINTER_OWN |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_VidDevManager_setOutputWindowFlags(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::VidDevManager *arg1 = (pj::VidDevManager *) 0 ;
  int arg2 ;
  int arg3 ;
  bool arg4 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  int val2 ;
  int ecode2 = 0 ;
  int val3 ;
  int ecode3 = 0 ;
  bool val4 ;
  int ecode4 = 0 ;
  PyObject *swig_obj[4] ;
  
  if (!SWIG_Python_UnpackTuple(args, "VidDevManager_setOutputWindowFlags", 4, 4, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__VidDevManager, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "VidDevManager_setOutputWindowFlags" "', argument " "1"" of type '" "pj::VidDevManager *""'"); 
  }
  arg1 = reinterpret_cast< pj::VidDevManager * >(argp1);
  ecode2 = SWIG_AsVal_int(swig_obj[1], &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "VidDevManager_setOutputWindowFlags" "', argument " "2"" of type '" "int""'");
  } 
  arg2 = static_cast< int >(val2);
  ecode3 = SWIG_AsVal_int(swig_obj[2], &val3);
  if (!SWIG_IsOK(ecode3)) {
    SWIG_exception_fail(SWIG_ArgError(ecode3), "in method '" "VidDevManager_setOutputWindowFlags" "', argument " "3"" of type '" "int""'");
  } 
  arg3 = static_cast< int >(val3);
  ecode4 = SWIG_AsVal_bool(swig_obj[3], &val4);
  if (!SWIG_IsOK(ecode4)) {
    SWIG_exception_fail(SWIG_ArgError(ecode4), "in method '" "VidDevManager_setOutputWindowFlags" "', argument " "4"" of type '" "bool""'");
  } 
  arg4 = static_cast< bool >(val4);
  try {
    (arg1)->setOutputWindowFlags(arg2,arg3,arg4);
  } catch(pj::Error &_e) {
    SWIG_Python_Raise(SWIG_NewPointerObj((new pj::Error(static_cast< const pj::Error& >(_e))),SWIGTYPE_p_pj__Error,SWIG_POINTER_OWN), "pj::Error", SWIGTYPE_p_pj__Error); SWIG_fail;
  }
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_VidDevManager_getOutputWindowFlags(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::VidDevManager *arg1 = (pj::VidDevManager *) 0 ;
  int arg2 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  int val2 ;
  int ecode2 = 0 ;
  PyObject *swig_obj[2] ;
  int result;
  
  if (!SWIG_Python_UnpackTuple(args, "VidDevManager_getOutputWindowFlags", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__VidDevManager, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "VidDevManager_getOutputWindowFlags" "', argument " "1"" of type '" "pj::VidDevManager *""'"); 
  }
  arg1 = reinterpret_cast< pj::VidDevManager * >(argp1);
  ecode2 = SWIG_AsVal_int(swig_obj[1], &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "VidDevManager_getOutputWindowFlags" "', argument " "2"" of type '" "int""'");
  } 
  arg2 = static_cast< int >(val2);
  try {
    result = (int)(arg1)->getOutputWindowFlags(arg2);
  } catch(pj::Error &_e) {
    SWIG_Python_Raise(SWIG_NewPointerObj((new pj::Error(static_cast< const pj::Error& >(_e))),SWIGTYPE_p_pj__Error,SWIG_POINTER_OWN), "pj::Error", SWIGTYPE_p_pj__Error); SWIG_fail;
  }
  resultobj = SWIG_From_int(static_cast< int >(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_VidDevManager_switchDev(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::VidDevManager *arg1 = (pj::VidDevManager *) 0 ;
  int arg2 ;
  pj::VideoSwitchParam *arg3 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  int val2 ;
  int ecode2 = 0 ;
  void *argp3 = 0 ;
  int res3 = 0 ;
  PyObject *swig_obj[3] ;
  
  if (!SWIG_Python_UnpackTuple(args, "VidDevManager_switchDev", 3, 3, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__VidDevManager, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "VidDevManager_switchDev" "', argument " "1"" of type '" "pj::VidDevManager *""'"); 
  }
  arg1 = reinterpret_cast< pj::VidDevManager * >(argp1);
  ecode2 = SWIG_AsVal_int(swig_obj[1], &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "VidDevManager_switchDev" "', argument " "2"" of type '" "int""'");
  } 
  arg2 = static_cast< int >(val2);
  res3 = SWIG_ConvertPtr(swig_obj[2], &argp3, SWIGTYPE_p_pj__VideoSwitchParam,  0  | 0);
  if (!SWIG_IsOK(res3)) {
    SWIG_exception_fail(SWIG_ArgError(res3), "in method '" "VidDevManager_switchDev" "', argument " "3"" of type '" "pj::VideoSwitchParam const &""'"); 
  }
  if (!argp3) {
    SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "VidDevManager_switchDev" "', argument " "3"" of type '" "pj::VideoSwitchParam const &""'"); 
  }
  arg3 = reinterpret_cast< pj::VideoSwitchParam * >(argp3);
  try {
    (arg1)->switchDev(arg2,(pj::VideoSwitchParam const &)*arg3);
  } catch(pj::Error &_e) {
    SWIG_Python_Raise(SWIG_NewPointerObj((new pj::Error(static_cast< const pj::Error& >(_e))),SWIGTYPE_p_pj__Error,SWIG_POINTER_OWN), "pj::Error", SWIGTYPE_p_pj__Error); SWIG_fail;
  }
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_VidDevManager_isCaptureActive(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::VidDevManager *arg1 = (pj::VidDevManager *) 0 ;
  int arg2 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  int val2 ;
  int ecode2 = 0 ;
  PyObject *swig_obj[2] ;
  bool result;
  
  if (!SWIG_Python_UnpackTuple(args, "VidDevManager_isCaptureActive", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__VidDevManager, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "VidDevManager_isCaptureActive" "', argument " "1"" of type '" "pj::VidDevManager const *""'"); 
  }
  arg1 = reinterpret_cast< pj::VidDevManager * >(argp1);
  ecode2 = SWIG_AsVal_int(swig_obj[1], &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "VidDevManager_isCaptureActive" "', argument " "2"" of type '" "int""'");
  } 
  arg2 = static_cast< int >(val2);
  result = (bool)((pj::VidDevManager const *)arg1)->isCaptureActive(arg2);
  resultobj = SWIG_From_bool(static_cast< bool >(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_VidDevManager_setCaptureOrient__SWIG_0(PyObject *SWIGUNUSEDPARM(self), Py_ssize_t nobjs, PyObject **swig_obj) {
  PyObject *resultobj = 0;
  pj::VidDevManager *arg1 = (pj::VidDevManager *) 0 ;
  pjmedia_vid_dev_index arg2 ;
  pjmedia_orient arg3 ;
  bool arg4 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  int val2 ;
  int ecode2 = 0 ;
  int val3 ;
  int ecode3 = 0 ;
  bool val4 ;
  int ecode4 = 0 ;
  
  if ((nobjs < 4) || (nobjs > 4)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__VidDevManager, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "VidDevManager_setCaptureOrient" "', argument " "1"" of type '" "pj::VidDevManager *""'"); 
  }
  arg1 = reinterpret_cast< pj::VidDevManager * >(argp1);
  ecode2 = SWIG_AsVal_int(swig_obj[1], &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "VidDevManager_setCaptureOrient" "', argument " "2"" of type '" "pjmedia_vid_dev_index""'");
  } 
  arg2 = static_cast< pjmedia_vid_dev_index >(val2);
  ecode3 = SWIG_AsVal_int(swig_obj[2], &val3);
  if (!SWIG_IsOK(ecode3)) {
    SWIG_exception_fail(SWIG_ArgError(ecode3), "in method '" "VidDevManager_setCaptureOrient" "', argument " "3"" of type '" "pjmedia_orient""'");
  } 
  arg3 = static_cast< pjmedia_orient >(val3);
  ecode4 = SWIG_AsVal_bool(swig_obj[3], &val4);
  if (!SWIG_IsOK(ecode4)) {
    SWIG_exception_fail(SWIG_ArgError(ecode4), "in method '" "VidDevManager_setCaptureOrient" "', argument " "4"" of type '" "bool""'");
  } 
  arg4 = static_cast< bool >(val4);
  try {
    (arg1)->setCaptureOrient(arg2,arg3,arg4);
  } catch(pj::Error &_e) {
    SWIG_Python_Raise(SWIG_NewPointerObj((new pj::Error(static_cast< const pj::Error& >(_e))),SWIGTYPE_p_pj__Error,SWIG_POINTER_OWN), "pj::Error", SWIGTYPE_p_pj__Error); SWIG_fail;
  }
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_VidDevManager_setCaptureOrient__SWIG_1(PyObject *SWIGUNUSEDPARM(self), Py_ssize_t nobjs, PyObject **swig_obj) {
  PyObject *resultobj = 0;
  pj::VidDevManager *arg1 = (pj::VidDevManager *) 0 ;
  pjmedia_vid_dev_index arg2 ;
  pjmedia_orient arg3 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  int val2 ;
  int ecode2 = 0 ;
  int val3 ;
  int ecode3 = 0 ;
  
  if ((nobjs < 3) || (nobjs > 3)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__VidDevManager, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "VidDevManager_setCaptureOrient" "', argument " "1"" of type '" "pj::VidDevManager *""'"); 
  }
  arg1 = reinterpret_cast< pj::VidDevManager * >(argp1);
  ecode2 = SWIG_AsVal_int(swig_obj[1], &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "VidDevManager_setCaptureOrient" "', argument " "2"" of type '" "pjmedia_vid_dev_index""'");
  } 
  arg2 = static_cast< pjmedia_vid_dev_index >(val2);
  ecode3 = SWIG_AsVal_int(swig_obj[2], &val3);
  if (!SWIG_IsOK(ecode3)) {
    SWIG_exception_fail(SWIG_ArgError(ecode3), "in method '" "VidDevManager_setCaptureOrient" "', argument " "3"" of type '" "pjmedia_orient""'");
  } 
  arg3 = static_cast< pjmedia_orient >(val3);
  try {
    (arg1)->setCaptureOrient(arg2,arg3);
  } catch(pj::Error &_e) {
    SWIG_Python_Raise(SWIG_NewPointerObj((new pj::Error(static_cast< const pj::Error& >(_e))),SWIGTYPE_p_pj__Error,SWIG_POINTER_OWN), "pj::Error", SWIGTYPE_p_pj__Error); SWIG_fail;
  }
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_VidDevManager_setCaptureOrient(PyObject *self, PyObject *args) {
  Py_ssize_t argc;
  PyObject *argv[5] = {
    0
  };
  
  if (!(argc = SWIG_Python_UnpackTuple(args, "VidDevManager_setCaptureOrient", 0, 4, argv))) SWIG_fail;
  --argc;
  if (argc == 3) {
    int _v;
    void *vptr = 0;
    int res = SWIG_ConvertPtr(argv[0], &vptr, SWIGTYPE_p_pj__VidDevManager, 0);
    _v = SWIG_CheckState(res);
    if (_v) {
      {
        int res = SWIG_AsVal_int(argv[1], NULL);
        _v = SWIG_CheckState(res);
      }
      if (_v) {
        {
          int res = SWIG_AsVal_int(argv[2], NULL);
          _v = SWIG_CheckState(res);
        }
        if (_v) {
          return _wrap_VidDevManager_setCaptureOrient__SWIG_1(self, argc, argv);
        }
      }
    }
  }
  if (argc == 4) {
    int _v;
    void *vptr = 0;
    int res = SWIG_ConvertPtr(argv[0], &vptr, SWIGTYPE_p_pj__VidDevManager, 0);
    _v = SWIG_CheckState(res);
    if (_v) {
      {
        int res = SWIG_AsVal_int(argv[1], NULL);
        _v = SWIG_CheckState(res);
      }
      if (_v) {
        {
          int res = SWIG_AsVal_int(argv[2], NULL);
          _v = SWIG_CheckState(res);
        }
        if (_v) {
          {
            int res = SWIG_AsVal_bool(argv[3], NULL);
            _v = SWIG_CheckState(res);
          }
          if (_v) {
            return _wrap_VidDevManager_setCaptureOrient__SWIG_0(self, argc, argv);
          }
        }
      }
    }
  }
  
fail:
  SWIG_Python_RaiseOrModifyTypeError("Wrong number or type of arguments for overloaded function 'VidDevManager_setCaptureOrient'.\n"
    "  Possible C/C++ prototypes are:\n"
    "    pj::VidDevManager::setCaptureOrient(pjmedia_vid_dev_index,pjmedia_orient,bool)\n"
    "    pj::VidDevManager::setCaptureOrient(pjmedia_vid_dev_index,pjmedia_orient)\n");
  return 0;
}


SWIGINTERN PyObject *VidDevManager_swigregister(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *obj;
  if (!SWIG_Python_UnpackTuple(args, "swigregister", 1, 1, &obj)) return NULL;
  SWIG_TypeNewClientData(SWIGTYPE_p_pj__VidDevManager, SWIG_NewClientData(obj));
  return SWIG_Py_Void();
}

SWIGINTERN PyObject *_wrap_CodecInfo_codecId_set(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::CodecInfo *arg1 = (pj::CodecInfo *) 0 ;
  pj::string *arg2 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  int res2 = SWIG_OLDOBJ ;
  PyObject *swig_obj[2] ;
  
  if (!SWIG_Python_UnpackTuple(args, "CodecInfo_codecId_set", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__CodecInfo, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "CodecInfo_codecId_set" "', argument " "1"" of type '" "pj::CodecInfo *""'"); 
  }
  arg1 = reinterpret_cast< pj::CodecInfo * >(argp1);
  {
    std::string *ptr = (std::string *)0;
    res2 = SWIG_AsPtr_std_string(swig_obj[1], &ptr);
    if (!SWIG_IsOK(res2)) {
      SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "CodecInfo_codecId_set" "', argument " "2"" of type '" "pj::string const &""'"); 
    }
    if (!ptr) {
      SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "CodecInfo_codecId_set" "', argument " "2"" of type '" "pj::string const &""'"); 
    }
    arg2 = ptr;
  }
  if (arg1) (arg1)->codecId = *arg2;
  resultobj = SWIG_Py_Void();
  if (SWIG_IsNewObj(res2)) delete arg2;
  return resultobj;
fail:
  if (SWIG_IsNewObj(res2)) delete arg2;
  return NULL;
}


SWIGINTERN PyObject *_wrap_CodecInfo_codecId_get(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::CodecInfo *arg1 = (pj::CodecInfo *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  pj::string *result = 0 ;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__CodecInfo, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "CodecInfo_codecId_get" "', argument " "1"" of type '" "pj::CodecInfo *""'"); 
  }
  arg1 = reinterpret_cast< pj::CodecInfo * >(argp1);
  result = (pj::string *) & ((arg1)->codecId);
  resultobj = SWIG_From_std_string(static_cast< std::string >(*result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_CodecInfo_priority_set(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::CodecInfo *arg1 = (pj::CodecInfo *) 0 ;
  pj_uint8_t arg2 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  unsigned char val2 ;
  int ecode2 = 0 ;
  PyObject *swig_obj[2] ;
  
  if (!SWIG_Python_UnpackTuple(args, "CodecInfo_priority_set", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__CodecInfo, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "CodecInfo_priority_set" "', argument " "1"" of type '" "pj::CodecInfo *""'"); 
  }
  arg1 = reinterpret_cast< pj::CodecInfo * >(argp1);
  ecode2 = SWIG_AsVal_unsigned_SS_char(swig_obj[1], &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "CodecInfo_priority_set" "', argument " "2"" of type '" "pj_uint8_t""'");
  } 
  arg2 = static_cast< pj_uint8_t >(val2);
  if (arg1) (arg1)->priority = arg2;
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_CodecInfo_priority_get(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::CodecInfo *arg1 = (pj::CodecInfo *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  pj_uint8_t result;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__CodecInfo, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "CodecInfo_priority_get" "', argument " "1"" of type '" "pj::CodecInfo *""'"); 
  }
  arg1 = reinterpret_cast< pj::CodecInfo * >(argp1);
  result = (pj_uint8_t) ((arg1)->priority);
  resultobj = SWIG_From_unsigned_SS_char(static_cast< unsigned char >(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_CodecInfo_desc_set(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::CodecInfo *arg1 = (pj::CodecInfo *) 0 ;
  pj::string *arg2 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  int res2 = SWIG_OLDOBJ ;
  PyObject *swig_obj[2] ;
  
  if (!SWIG_Python_UnpackTuple(args, "CodecInfo_desc_set", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__CodecInfo, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "CodecInfo_desc_set" "', argument " "1"" of type '" "pj::CodecInfo *""'"); 
  }
  arg1 = reinterpret_cast< pj::CodecInfo * >(argp1);
  {
    std::string *ptr = (std::string *)0;
    res2 = SWIG_AsPtr_std_string(swig_obj[1], &ptr);
    if (!SWIG_IsOK(res2)) {
      SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "CodecInfo_desc_set" "', argument " "2"" of type '" "pj::string const &""'"); 
    }
    if (!ptr) {
      SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "CodecInfo_desc_set" "', argument " "2"" of type '" "pj::string const &""'"); 
    }
    arg2 = ptr;
  }
  if (arg1) (arg1)->desc = *arg2;
  resultobj = SWIG_Py_Void();
  if (SWIG_IsNewObj(res2)) delete arg2;
  return resultobj;
fail:
  if (SWIG_IsNewObj(res2)) delete arg2;
  return NULL;
}


SWIGINTERN PyObject *_wrap_CodecInfo_desc_get(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::CodecInfo *arg1 = (pj::CodecInfo *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  pj::string *result = 0 ;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__CodecInfo, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "CodecInfo_desc_get" "', argument " "1"" of type '" "pj::CodecInfo *""'"); 
  }
  arg1 = reinterpret_cast< pj::CodecInfo * >(argp1);
  result = (pj::string *) & ((arg1)->desc);
  resultobj = SWIG_From_std_string(static_cast< std::string >(*result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_new_CodecInfo(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::CodecInfo *result = 0 ;
  
  if (!SWIG_Python_UnpackTuple(args, "new_CodecInfo", 0, 0, 0)) SWIG_fail;
  result = (pj::CodecInfo *)new pj::CodecInfo();
  resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(result), SWIGTYPE_p_pj__CodecInfo, SWIG_POINTER_NEW |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_delete_CodecInfo(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::CodecInfo *arg1 = (pj::CodecInfo *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__CodecInfo, SWIG_POINTER_DISOWN |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "delete_CodecInfo" "', argument " "1"" of type '" "pj::CodecInfo *""'"); 
  }
  arg1 = reinterpret_cast< pj::CodecInfo * >(argp1);
  delete arg1;
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *CodecInfo_swigregister(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *obj;
  if (!SWIG_Python_UnpackTuple(args, "swigregister", 1, 1, &obj)) return NULL;
  SWIG_TypeNewClientData(SWIGTYPE_p_pj__CodecInfo, SWIG_NewClientData(obj));
  return SWIG_Py_Void();
}

SWIGINTERN PyObject *CodecInfo_swiginit(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  return SWIG_Python_InitShadowInstance(args);
}

SWIGINTERN PyObject *_wrap_CodecFmtp_name_set(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::CodecFmtp *arg1 = (pj::CodecFmtp *) 0 ;
  pj::string *arg2 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  int res2 = SWIG_OLDOBJ ;
  PyObject *swig_obj[2] ;
  
  if (!SWIG_Python_UnpackTuple(args, "CodecFmtp_name_set", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__CodecFmtp, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "CodecFmtp_name_set" "', argument " "1"" of type '" "pj::CodecFmtp *""'"); 
  }
  arg1 = reinterpret_cast< pj::CodecFmtp * >(argp1);
  {
    std::string *ptr = (std::string *)0;
    res2 = SWIG_AsPtr_std_string(swig_obj[1], &ptr);
    if (!SWIG_IsOK(res2)) {
      SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "CodecFmtp_name_set" "', argument " "2"" of type '" "pj::string const &""'"); 
    }
    if (!ptr) {
      SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "CodecFmtp_name_set" "', argument " "2"" of type '" "pj::string const &""'"); 
    }
    arg2 = ptr;
  }
  if (arg1) (arg1)->name = *arg2;
  resultobj = SWIG_Py_Void();
  if (SWIG_IsNewObj(res2)) delete arg2;
  return resultobj;
fail:
  if (SWIG_IsNewObj(res2)) delete arg2;
  return NULL;
}


SWIGINTERN PyObject *_wrap_CodecFmtp_name_get(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::CodecFmtp *arg1 = (pj::CodecFmtp *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  pj::string *result = 0 ;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__CodecFmtp, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "CodecFmtp_name_get" "', argument " "1"" of type '" "pj::CodecFmtp *""'"); 
  }
  arg1 = reinterpret_cast< pj::CodecFmtp * >(argp1);
  result = (pj::string *) & ((arg1)->name);
  resultobj = SWIG_From_std_string(static_cast< std::string >(*result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_CodecFmtp_val_set(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::CodecFmtp *arg1 = (pj::CodecFmtp *) 0 ;
  pj::string *arg2 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  int res2 = SWIG_OLDOBJ ;
  PyObject *swig_obj[2] ;
  
  if (!SWIG_Python_UnpackTuple(args, "CodecFmtp_val_set", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__CodecFmtp, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "CodecFmtp_val_set" "', argument " "1"" of type '" "pj::CodecFmtp *""'"); 
  }
  arg1 = reinterpret_cast< pj::CodecFmtp * >(argp1);
  {
    std::string *ptr = (std::string *)0;
    res2 = SWIG_AsPtr_std_string(swig_obj[1], &ptr);
    if (!SWIG_IsOK(res2)) {
      SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "CodecFmtp_val_set" "', argument " "2"" of type '" "pj::string const &""'"); 
    }
    if (!ptr) {
      SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "CodecFmtp_val_set" "', argument " "2"" of type '" "pj::string const &""'"); 
    }
    arg2 = ptr;
  }
  if (arg1) (arg1)->val = *arg2;
  resultobj = SWIG_Py_Void();
  if (SWIG_IsNewObj(res2)) delete arg2;
  return resultobj;
fail:
  if (SWIG_IsNewObj(res2)) delete arg2;
  return NULL;
}


SWIGINTERN PyObject *_wrap_CodecFmtp_val_get(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::CodecFmtp *arg1 = (pj::CodecFmtp *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  pj::string *result = 0 ;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__CodecFmtp, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "CodecFmtp_val_get" "', argument " "1"" of type '" "pj::CodecFmtp *""'"); 
  }
  arg1 = reinterpret_cast< pj::CodecFmtp * >(argp1);
  result = (pj::string *) & ((arg1)->val);
  resultobj = SWIG_From_std_string(static_cast< std::string >(*result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_new_CodecFmtp(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::CodecFmtp *result = 0 ;
  
  if (!SWIG_Python_UnpackTuple(args, "new_CodecFmtp", 0, 0, 0)) SWIG_fail;
  result = (pj::CodecFmtp *)new pj::CodecFmtp();
  resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(result), SWIGTYPE_p_pj__CodecFmtp, SWIG_POINTER_NEW |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_delete_CodecFmtp(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::CodecFmtp *arg1 = (pj::CodecFmtp *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__CodecFmtp, SWIG_POINTER_DISOWN |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "delete_CodecFmtp" "', argument " "1"" of type '" "pj::CodecFmtp *""'"); 
  }
  arg1 = reinterpret_cast< pj::CodecFmtp * >(argp1);
  delete arg1;
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *CodecFmtp_swigregister(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *obj;
  if (!SWIG_Python_UnpackTuple(args, "swigregister", 1, 1, &obj)) return NULL;
  SWIG_TypeNewClientData(SWIGTYPE_p_pj__CodecFmtp, SWIG_NewClientData(obj));
  return SWIG_Py_Void();
}

SWIGINTERN PyObject *CodecFmtp_swiginit(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  return SWIG_Python_InitShadowInstance(args);
}

SWIGINTERN PyObject *_wrap_CodecParamInfo_clockRate_set(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::CodecParamInfo *arg1 = (pj::CodecParamInfo *) 0 ;
  unsigned int arg2 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  unsigned int val2 ;
  int ecode2 = 0 ;
  PyObject *swig_obj[2] ;
  
  if (!SWIG_Python_UnpackTuple(args, "CodecParamInfo_clockRate_set", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__CodecParamInfo, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "CodecParamInfo_clockRate_set" "', argument " "1"" of type '" "pj::CodecParamInfo *""'"); 
  }
  arg1 = reinterpret_cast< pj::CodecParamInfo * >(argp1);
  ecode2 = SWIG_AsVal_unsigned_SS_int(swig_obj[1], &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "CodecParamInfo_clockRate_set" "', argument " "2"" of type '" "unsigned int""'");
  } 
  arg2 = static_cast< unsigned int >(val2);
  if (arg1) (arg1)->clockRate = arg2;
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_CodecParamInfo_clockRate_get(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::CodecParamInfo *arg1 = (pj::CodecParamInfo *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  unsigned int result;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__CodecParamInfo, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "CodecParamInfo_clockRate_get" "', argument " "1"" of type '" "pj::CodecParamInfo *""'"); 
  }
  arg1 = reinterpret_cast< pj::CodecParamInfo * >(argp1);
  result = (unsigned int) ((arg1)->clockRate);
  resultobj = SWIG_From_unsigned_SS_int(static_cast< unsigned int >(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_CodecParamInfo_channelCnt_set(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::CodecParamInfo *arg1 = (pj::CodecParamInfo *) 0 ;
  unsigned int arg2 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  unsigned int val2 ;
  int ecode2 = 0 ;
  PyObject *swig_obj[2] ;
  
  if (!SWIG_Python_UnpackTuple(args, "CodecParamInfo_channelCnt_set", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__CodecParamInfo, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "CodecParamInfo_channelCnt_set" "', argument " "1"" of type '" "pj::CodecParamInfo *""'"); 
  }
  arg1 = reinterpret_cast< pj::CodecParamInfo * >(argp1);
  ecode2 = SWIG_AsVal_unsigned_SS_int(swig_obj[1], &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "CodecParamInfo_channelCnt_set" "', argument " "2"" of type '" "unsigned int""'");
  } 
  arg2 = static_cast< unsigned int >(val2);
  if (arg1) (arg1)->channelCnt = arg2;
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_CodecParamInfo_channelCnt_get(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::CodecParamInfo *arg1 = (pj::CodecParamInfo *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  unsigned int result;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__CodecParamInfo, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "CodecParamInfo_channelCnt_get" "', argument " "1"" of type '" "pj::CodecParamInfo *""'"); 
  }
  arg1 = reinterpret_cast< pj::CodecParamInfo * >(argp1);
  result = (unsigned int) ((arg1)->channelCnt);
  resultobj = SWIG_From_unsigned_SS_int(static_cast< unsigned int >(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_CodecParamInfo_avgBps_set(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::CodecParamInfo *arg1 = (pj::CodecParamInfo *) 0 ;
  unsigned int arg2 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  unsigned int val2 ;
  int ecode2 = 0 ;
  PyObject *swig_obj[2] ;
  
  if (!SWIG_Python_UnpackTuple(args, "CodecParamInfo_avgBps_set", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__CodecParamInfo, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "CodecParamInfo_avgBps_set" "', argument " "1"" of type '" "pj::CodecParamInfo *""'"); 
  }
  arg1 = reinterpret_cast< pj::CodecParamInfo * >(argp1);
  ecode2 = SWIG_AsVal_unsigned_SS_int(swig_obj[1], &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "CodecParamInfo_avgBps_set" "', argument " "2"" of type '" "unsigned int""'");
  } 
  arg2 = static_cast< unsigned int >(val2);
  if (arg1) (arg1)->avgBps = arg2;
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_CodecParamInfo_avgBps_get(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::CodecParamInfo *arg1 = (pj::CodecParamInfo *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  unsigned int result;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__CodecParamInfo, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "CodecParamInfo_avgBps_get" "', argument " "1"" of type '" "pj::CodecParamInfo *""'"); 
  }
  arg1 = reinterpret_cast< pj::CodecParamInfo * >(argp1);
  result = (unsigned int) ((arg1)->avgBps);
  resultobj = SWIG_From_unsigned_SS_int(static_cast< unsigned int >(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_CodecParamInfo_maxBps_set(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::CodecParamInfo *arg1 = (pj::CodecParamInfo *) 0 ;
  unsigned int arg2 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  unsigned int val2 ;
  int ecode2 = 0 ;
  PyObject *swig_obj[2] ;
  
  if (!SWIG_Python_UnpackTuple(args, "CodecParamInfo_maxBps_set", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__CodecParamInfo, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "CodecParamInfo_maxBps_set" "', argument " "1"" of type '" "pj::CodecParamInfo *""'"); 
  }
  arg1 = reinterpret_cast< pj::CodecParamInfo * >(argp1);
  ecode2 = SWIG_AsVal_unsigned_SS_int(swig_obj[1], &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "CodecParamInfo_maxBps_set" "', argument " "2"" of type '" "unsigned int""'");
  } 
  arg2 = static_cast< unsigned int >(val2);
  if (arg1) (arg1)->maxBps = arg2;
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_CodecParamInfo_maxBps_get(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::CodecParamInfo *arg1 = (pj::CodecParamInfo *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  unsigned int result;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__CodecParamInfo, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "CodecParamInfo_maxBps_get" "', argument " "1"" of type '" "pj::CodecParamInfo *""'"); 
  }
  arg1 = reinterpret_cast< pj::CodecParamInfo * >(argp1);
  result = (unsigned int) ((arg1)->maxBps);
  resultobj = SWIG_From_unsigned_SS_int(static_cast< unsigned int >(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_CodecParamInfo_maxRxFrameSize_set(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::CodecParamInfo *arg1 = (pj::CodecParamInfo *) 0 ;
  unsigned int arg2 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  unsigned int val2 ;
  int ecode2 = 0 ;
  PyObject *swig_obj[2] ;
  
  if (!SWIG_Python_UnpackTuple(args, "CodecParamInfo_maxRxFrameSize_set", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__CodecParamInfo, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "CodecParamInfo_maxRxFrameSize_set" "', argument " "1"" of type '" "pj::CodecParamInfo *""'"); 
  }
  arg1 = reinterpret_cast< pj::CodecParamInfo * >(argp1);
  ecode2 = SWIG_AsVal_unsigned_SS_int(swig_obj[1], &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "CodecParamInfo_maxRxFrameSize_set" "', argument " "2"" of type '" "unsigned int""'");
  } 
  arg2 = static_cast< unsigned int >(val2);
  if (arg1) (arg1)->maxRxFrameSize = arg2;
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_CodecParamInfo_maxRxFrameSize_get(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::CodecParamInfo *arg1 = (pj::CodecParamInfo *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  unsigned int result;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__CodecParamInfo, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "CodecParamInfo_maxRxFrameSize_get" "', argument " "1"" of type '" "pj::CodecParamInfo *""'"); 
  }
  arg1 = reinterpret_cast< pj::CodecParamInfo * >(argp1);
  result = (unsigned int) ((arg1)->maxRxFrameSize);
  resultobj = SWIG_From_unsigned_SS_int(static_cast< unsigned int >(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_CodecParamInfo_frameLen_set(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::CodecParamInfo *arg1 = (pj::CodecParamInfo *) 0 ;
  unsigned int arg2 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  unsigned int val2 ;
  int ecode2 = 0 ;
  PyObject *swig_obj[2] ;
  
  if (!SWIG_Python_UnpackTuple(args, "CodecParamInfo_frameLen_set", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__CodecParamInfo, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "CodecParamInfo_frameLen_set" "', argument " "1"" of type '" "pj::CodecParamInfo *""'"); 
  }
  arg1 = reinterpret_cast< pj::CodecParamInfo * >(argp1);
  ecode2 = SWIG_AsVal_unsigned_SS_int(swig_obj[1], &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "CodecParamInfo_frameLen_set" "', argument " "2"" of type '" "unsigned int""'");
  } 
  arg2 = static_cast< unsigned int >(val2);
  if (arg1) (arg1)->frameLen = arg2;
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_CodecParamInfo_frameLen_get(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::CodecParamInfo *arg1 = (pj::CodecParamInfo *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  unsigned int result;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__CodecParamInfo, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "CodecParamInfo_frameLen_get" "', argument " "1"" of type '" "pj::CodecParamInfo *""'"); 
  }
  arg1 = reinterpret_cast< pj::CodecParamInfo * >(argp1);
  result = (unsigned int) ((arg1)->frameLen);
  resultobj = SWIG_From_unsigned_SS_int(static_cast< unsigned int >(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_CodecParamInfo_pcmBitsPerSample_set(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::CodecParamInfo *arg1 = (pj::CodecParamInfo *) 0 ;
  unsigned int arg2 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  unsigned int val2 ;
  int ecode2 = 0 ;
  PyObject *swig_obj[2] ;
  
  if (!SWIG_Python_UnpackTuple(args, "CodecParamInfo_pcmBitsPerSample_set", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__CodecParamInfo, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "CodecParamInfo_pcmBitsPerSample_set" "', argument " "1"" of type '" "pj::CodecParamInfo *""'"); 
  }
  arg1 = reinterpret_cast< pj::CodecParamInfo * >(argp1);
  ecode2 = SWIG_AsVal_unsigned_SS_int(swig_obj[1], &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "CodecParamInfo_pcmBitsPerSample_set" "', argument " "2"" of type '" "unsigned int""'");
  } 
  arg2 = static_cast< unsigned int >(val2);
  if (arg1) (arg1)->pcmBitsPerSample = arg2;
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_CodecParamInfo_pcmBitsPerSample_get(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::CodecParamInfo *arg1 = (pj::CodecParamInfo *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  unsigned int result;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__CodecParamInfo, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "CodecParamInfo_pcmBitsPerSample_get" "', argument " "1"" of type '" "pj::CodecParamInfo *""'"); 
  }
  arg1 = reinterpret_cast< pj::CodecParamInfo * >(argp1);
  result = (unsigned int) ((arg1)->pcmBitsPerSample);
  resultobj = SWIG_From_unsigned_SS_int(static_cast< unsigned int >(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_CodecParamInfo_pt_set(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::CodecParamInfo *arg1 = (pj::CodecParamInfo *) 0 ;
  unsigned int arg2 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  unsigned int val2 ;
  int ecode2 = 0 ;
  PyObject *swig_obj[2] ;
  
  if (!SWIG_Python_UnpackTuple(args, "CodecParamInfo_pt_set", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__CodecParamInfo, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "CodecParamInfo_pt_set" "', argument " "1"" of type '" "pj::CodecParamInfo *""'"); 
  }
  arg1 = reinterpret_cast< pj::CodecParamInfo * >(argp1);
  ecode2 = SWIG_AsVal_unsigned_SS_int(swig_obj[1], &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "CodecParamInfo_pt_set" "', argument " "2"" of type '" "unsigned int""'");
  } 
  arg2 = static_cast< unsigned int >(val2);
  if (arg1) (arg1)->pt = arg2;
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_CodecParamInfo_pt_get(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::CodecParamInfo *arg1 = (pj::CodecParamInfo *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  unsigned int result;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__CodecParamInfo, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "CodecParamInfo_pt_get" "', argument " "1"" of type '" "pj::CodecParamInfo *""'"); 
  }
  arg1 = reinterpret_cast< pj::CodecParamInfo * >(argp1);
  result = (unsigned int) ((arg1)->pt);
  resultobj = SWIG_From_unsigned_SS_int(static_cast< unsigned int >(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_CodecParamInfo_fmtId_set(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::CodecParamInfo *arg1 = (pj::CodecParamInfo *) 0 ;
  pjmedia_format_id arg2 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  int val2 ;
  int ecode2 = 0 ;
  PyObject *swig_obj[2] ;
  
  if (!SWIG_Python_UnpackTuple(args, "CodecParamInfo_fmtId_set", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__CodecParamInfo, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "CodecParamInfo_fmtId_set" "', argument " "1"" of type '" "pj::CodecParamInfo *""'"); 
  }
  arg1 = reinterpret_cast< pj::CodecParamInfo * >(argp1);
  ecode2 = SWIG_AsVal_int(swig_obj[1], &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "CodecParamInfo_fmtId_set" "', argument " "2"" of type '" "pjmedia_format_id""'");
  } 
  arg2 = static_cast< pjmedia_format_id >(val2);
  if (arg1) (arg1)->fmtId = arg2;
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_CodecParamInfo_fmtId_get(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::CodecParamInfo *arg1 = (pj::CodecParamInfo *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  pjmedia_format_id result;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__CodecParamInfo, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "CodecParamInfo_fmtId_get" "', argument " "1"" of type '" "pj::CodecParamInfo *""'"); 
  }
  arg1 = reinterpret_cast< pj::CodecParamInfo * >(argp1);
  result = (pjmedia_format_id) ((arg1)->fmtId);
  resultobj = SWIG_From_int(static_cast< int >(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_new_CodecParamInfo(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::CodecParamInfo *result = 0 ;
  
  if (!SWIG_Python_UnpackTuple(args, "new_CodecParamInfo", 0, 0, 0)) SWIG_fail;
  result = (pj::CodecParamInfo *)new pj::CodecParamInfo();
  resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(result), SWIGTYPE_p_pj__CodecParamInfo, SWIG_POINTER_NEW |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_delete_CodecParamInfo(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::CodecParamInfo *arg1 = (pj::CodecParamInfo *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__CodecParamInfo, SWIG_POINTER_DISOWN |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "delete_CodecParamInfo" "', argument " "1"" of type '" "pj::CodecParamInfo *""'"); 
  }
  arg1 = reinterpret_cast< pj::CodecParamInfo * >(argp1);
  delete arg1;
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *CodecParamInfo_swigregister(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *obj;
  if (!SWIG_Python_UnpackTuple(args, "swigregister", 1, 1, &obj)) return NULL;
  SWIG_TypeNewClientData(SWIGTYPE_p_pj__CodecParamInfo, SWIG_NewClientData(obj));
  return SWIG_Py_Void();
}

SWIGINTERN PyObject *CodecParamInfo_swiginit(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  return SWIG_Python_InitShadowInstance(args);
}

SWIGINTERN PyObject *_wrap_CodecParamSetting_frmPerPkt_set(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::CodecParamSetting *arg1 = (pj::CodecParamSetting *) 0 ;
  unsigned int arg2 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  unsigned int val2 ;
  int ecode2 = 0 ;
  PyObject *swig_obj[2] ;
  
  if (!SWIG_Python_UnpackTuple(args, "CodecParamSetting_frmPerPkt_set", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__CodecParamSetting, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "CodecParamSetting_frmPerPkt_set" "', argument " "1"" of type '" "pj::CodecParamSetting *""'"); 
  }
  arg1 = reinterpret_cast< pj::CodecParamSetting * >(argp1);
  ecode2 = SWIG_AsVal_unsigned_SS_int(swig_obj[1], &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "CodecParamSetting_frmPerPkt_set" "', argument " "2"" of type '" "unsigned int""'");
  } 
  arg2 = static_cast< unsigned int >(val2);
  if (arg1) (arg1)->frmPerPkt = arg2;
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_CodecParamSetting_frmPerPkt_get(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::CodecParamSetting *arg1 = (pj::CodecParamSetting *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  unsigned int result;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__CodecParamSetting, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "CodecParamSetting_frmPerPkt_get" "', argument " "1"" of type '" "pj::CodecParamSetting *""'"); 
  }
  arg1 = reinterpret_cast< pj::CodecParamSetting * >(argp1);
  result = (unsigned int) ((arg1)->frmPerPkt);
  resultobj = SWIG_From_unsigned_SS_int(static_cast< unsigned int >(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_CodecParamSetting_vad_set(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::CodecParamSetting *arg1 = (pj::CodecParamSetting *) 0 ;
  bool arg2 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  bool val2 ;
  int ecode2 = 0 ;
  PyObject *swig_obj[2] ;
  
  if (!SWIG_Python_UnpackTuple(args, "CodecParamSetting_vad_set", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__CodecParamSetting, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "CodecParamSetting_vad_set" "', argument " "1"" of type '" "pj::CodecParamSetting *""'"); 
  }
  arg1 = reinterpret_cast< pj::CodecParamSetting * >(argp1);
  ecode2 = SWIG_AsVal_bool(swig_obj[1], &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "CodecParamSetting_vad_set" "', argument " "2"" of type '" "bool""'");
  } 
  arg2 = static_cast< bool >(val2);
  if (arg1) (arg1)->vad = arg2;
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_CodecParamSetting_vad_get(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::CodecParamSetting *arg1 = (pj::CodecParamSetting *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  bool result;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__CodecParamSetting, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "CodecParamSetting_vad_get" "', argument " "1"" of type '" "pj::CodecParamSetting *""'"); 
  }
  arg1 = reinterpret_cast< pj::CodecParamSetting * >(argp1);
  result = (bool) ((arg1)->vad);
  resultobj = SWIG_From_bool(static_cast< bool >(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_CodecParamSetting_cng_set(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::CodecParamSetting *arg1 = (pj::CodecParamSetting *) 0 ;
  bool arg2 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  bool val2 ;
  int ecode2 = 0 ;
  PyObject *swig_obj[2] ;
  
  if (!SWIG_Python_UnpackTuple(args, "CodecParamSetting_cng_set", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__CodecParamSetting, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "CodecParamSetting_cng_set" "', argument " "1"" of type '" "pj::CodecParamSetting *""'"); 
  }
  arg1 = reinterpret_cast< pj::CodecParamSetting * >(argp1);
  ecode2 = SWIG_AsVal_bool(swig_obj[1], &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "CodecParamSetting_cng_set" "', argument " "2"" of type '" "bool""'");
  } 
  arg2 = static_cast< bool >(val2);
  if (arg1) (arg1)->cng = arg2;
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_CodecParamSetting_cng_get(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::CodecParamSetting *arg1 = (pj::CodecParamSetting *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  bool result;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__CodecParamSetting, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "CodecParamSetting_cng_get" "', argument " "1"" of type '" "pj::CodecParamSetting *""'"); 
  }
  arg1 = reinterpret_cast< pj::CodecParamSetting * >(argp1);
  result = (bool) ((arg1)->cng);
  resultobj = SWIG_From_bool(static_cast< bool >(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_CodecParamSetting_penh_set(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::CodecParamSetting *arg1 = (pj::CodecParamSetting *) 0 ;
  bool arg2 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  bool val2 ;
  int ecode2 = 0 ;
  PyObject *swig_obj[2] ;
  
  if (!SWIG_Python_UnpackTuple(args, "CodecParamSetting_penh_set", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__CodecParamSetting, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "CodecParamSetting_penh_set" "', argument " "1"" of type '" "pj::CodecParamSetting *""'"); 
  }
  arg1 = reinterpret_cast< pj::CodecParamSetting * >(argp1);
  ecode2 = SWIG_AsVal_bool(swig_obj[1], &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "CodecParamSetting_penh_set" "', argument " "2"" of type '" "bool""'");
  } 
  arg2 = static_cast< bool >(val2);
  if (arg1) (arg1)->penh = arg2;
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_CodecParamSetting_penh_get(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::CodecParamSetting *arg1 = (pj::CodecParamSetting *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  bool result;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__CodecParamSetting, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "CodecParamSetting_penh_get" "', argument " "1"" of type '" "pj::CodecParamSetting *""'"); 
  }
  arg1 = reinterpret_cast< pj::CodecParamSetting * >(argp1);
  result = (bool) ((arg1)->penh);
  resultobj = SWIG_From_bool(static_cast< bool >(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_CodecParamSetting_plc_set(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::CodecParamSetting *arg1 = (pj::CodecParamSetting *) 0 ;
  bool arg2 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  bool val2 ;
  int ecode2 = 0 ;
  PyObject *swig_obj[2] ;
  
  if (!SWIG_Python_UnpackTuple(args, "CodecParamSetting_plc_set", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__CodecParamSetting, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "CodecParamSetting_plc_set" "', argument " "1"" of type '" "pj::CodecParamSetting *""'"); 
  }
  arg1 = reinterpret_cast< pj::CodecParamSetting * >(argp1);
  ecode2 = SWIG_AsVal_bool(swig_obj[1], &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "CodecParamSetting_plc_set" "', argument " "2"" of type '" "bool""'");
  } 
  arg2 = static_cast< bool >(val2);
  if (arg1) (arg1)->plc = arg2;
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_CodecParamSetting_plc_get(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::CodecParamSetting *arg1 = (pj::CodecParamSetting *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  bool result;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__CodecParamSetting, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "CodecParamSetting_plc_get" "', argument " "1"" of type '" "pj::CodecParamSetting *""'"); 
  }
  arg1 = reinterpret_cast< pj::CodecParamSetting * >(argp1);
  result = (bool) ((arg1)->plc);
  resultobj = SWIG_From_bool(static_cast< bool >(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_CodecParamSetting_reserved_set(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::CodecParamSetting *arg1 = (pj::CodecParamSetting *) 0 ;
  bool arg2 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  bool val2 ;
  int ecode2 = 0 ;
  PyObject *swig_obj[2] ;
  
  if (!SWIG_Python_UnpackTuple(args, "CodecParamSetting_reserved_set", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__CodecParamSetting, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "CodecParamSetting_reserved_set" "', argument " "1"" of type '" "pj::CodecParamSetting *""'"); 
  }
  arg1 = reinterpret_cast< pj::CodecParamSetting * >(argp1);
  ecode2 = SWIG_AsVal_bool(swig_obj[1], &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "CodecParamSetting_reserved_set" "', argument " "2"" of type '" "bool""'");
  } 
  arg2 = static_cast< bool >(val2);
  if (arg1) (arg1)->reserved = arg2;
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_CodecParamSetting_reserved_get(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::CodecParamSetting *arg1 = (pj::CodecParamSetting *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  bool result;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__CodecParamSetting, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "CodecParamSetting_reserved_get" "', argument " "1"" of type '" "pj::CodecParamSetting *""'"); 
  }
  arg1 = reinterpret_cast< pj::CodecParamSetting * >(argp1);
  result = (bool) ((arg1)->reserved);
  resultobj = SWIG_From_bool(static_cast< bool >(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_CodecParamSetting_encFmtp_set(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::CodecParamSetting *arg1 = (pj::CodecParamSetting *) 0 ;
  pj::CodecFmtpVector *arg2 = (pj::CodecFmtpVector *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  void *argp2 = 0 ;
  int res2 = 0 ;
  PyObject *swig_obj[2] ;
  
  if (!SWIG_Python_UnpackTuple(args, "CodecParamSetting_encFmtp_set", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__CodecParamSetting, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "CodecParamSetting_encFmtp_set" "', argument " "1"" of type '" "pj::CodecParamSetting *""'"); 
  }
  arg1 = reinterpret_cast< pj::CodecParamSetting * >(argp1);
  res2 = SWIG_ConvertPtr(swig_obj[1], &argp2,SWIGTYPE_p_std__vectorT_pj__CodecFmtp_std__allocatorT_pj__CodecFmtp_t_t, 0 |  0 );
  if (!SWIG_IsOK(res2)) {
    SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "CodecParamSetting_encFmtp_set" "', argument " "2"" of type '" "pj::CodecFmtpVector *""'"); 
  }
  arg2 = reinterpret_cast< pj::CodecFmtpVector * >(argp2);
  if (arg1) (arg1)->encFmtp = *arg2;
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_CodecParamSetting_encFmtp_get(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::CodecParamSetting *arg1 = (pj::CodecParamSetting *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  pj::CodecFmtpVector *result = 0 ;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__CodecParamSetting, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "CodecParamSetting_encFmtp_get" "', argument " "1"" of type '" "pj::CodecParamSetting *""'"); 
  }
  arg1 = reinterpret_cast< pj::CodecParamSetting * >(argp1);
  result = (pj::CodecFmtpVector *)& ((arg1)->encFmtp);
  resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(result), SWIGTYPE_p_std__vectorT_pj__CodecFmtp_std__allocatorT_pj__CodecFmtp_t_t, 0 |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_CodecParamSetting_decFmtp_set(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::CodecParamSetting *arg1 = (pj::CodecParamSetting *) 0 ;
  pj::CodecFmtpVector *arg2 = (pj::CodecFmtpVector *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  void *argp2 = 0 ;
  int res2 = 0 ;
  PyObject *swig_obj[2] ;
  
  if (!SWIG_Python_UnpackTuple(args, "CodecParamSetting_decFmtp_set", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__CodecParamSetting, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "CodecParamSetting_decFmtp_set" "', argument " "1"" of type '" "pj::CodecParamSetting *""'"); 
  }
  arg1 = reinterpret_cast< pj::CodecParamSetting * >(argp1);
  res2 = SWIG_ConvertPtr(swig_obj[1], &argp2,SWIGTYPE_p_std__vectorT_pj__CodecFmtp_std__allocatorT_pj__CodecFmtp_t_t, 0 |  0 );
  if (!SWIG_IsOK(res2)) {
    SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "CodecParamSetting_decFmtp_set" "', argument " "2"" of type '" "pj::CodecFmtpVector *""'"); 
  }
  arg2 = reinterpret_cast< pj::CodecFmtpVector * >(argp2);
  if (arg1) (arg1)->decFmtp = *arg2;
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_CodecParamSetting_decFmtp_get(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::CodecParamSetting *arg1 = (pj::CodecParamSetting *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  pj::CodecFmtpVector *result = 0 ;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__CodecParamSetting, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "CodecParamSetting_decFmtp_get" "', argument " "1"" of type '" "pj::CodecParamSetting *""'"); 
  }
  arg1 = reinterpret_cast< pj::CodecParamSetting * >(argp1);
  result = (pj::CodecFmtpVector *)& ((arg1)->decFmtp);
  resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(result), SWIGTYPE_p_std__vectorT_pj__CodecFmtp_std__allocatorT_pj__CodecFmtp_t_t, 0 |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_new_CodecParamSetting(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::CodecParamSetting *result = 0 ;
  
  if (!SWIG_Python_UnpackTuple(args, "new_CodecParamSetting", 0, 0, 0)) SWIG_fail;
  result = (pj::CodecParamSetting *)new pj::CodecParamSetting();
  resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(result), SWIGTYPE_p_pj__CodecParamSetting, SWIG_POINTER_NEW |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_delete_CodecParamSetting(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::CodecParamSetting *arg1 = (pj::CodecParamSetting *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__CodecParamSetting, SWIG_POINTER_DISOWN |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "delete_CodecParamSetting" "', argument " "1"" of type '" "pj::CodecParamSetting *""'"); 
  }
  arg1 = reinterpret_cast< pj::CodecParamSetting * >(argp1);
  delete arg1;
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *CodecParamSetting_swigregister(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *obj;
  if (!SWIG_Python_UnpackTuple(args, "swigregister", 1, 1, &obj)) return NULL;
  SWIG_TypeNewClientData(SWIGTYPE_p_pj__CodecParamSetting, SWIG_NewClientData(obj));
  return SWIG_Py_Void();
}

SWIGINTERN PyObject *CodecParamSetting_swiginit(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  return SWIG_Python_InitShadowInstance(args);
}

SWIGINTERN PyObject *_wrap_CodecParam_info_set(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::CodecParam *arg1 = (pj::CodecParam *) 0 ;
  pj::CodecParamInfo *arg2 = (pj::CodecParamInfo *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  void *argp2 = 0 ;
  int res2 = 0 ;
  PyObject *swig_obj[2] ;
  
  if (!SWIG_Python_UnpackTuple(args, "CodecParam_info_set", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__CodecParam, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "CodecParam_info_set" "', argument " "1"" of type '" "pj::CodecParam *""'"); 
  }
  arg1 = reinterpret_cast< pj::CodecParam * >(argp1);
  res2 = SWIG_ConvertPtr(swig_obj[1], &argp2,SWIGTYPE_p_pj__CodecParamInfo, 0 |  0 );
  if (!SWIG_IsOK(res2)) {
    SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "CodecParam_info_set" "', argument " "2"" of type '" "pj::CodecParamInfo *""'"); 
  }
  arg2 = reinterpret_cast< pj::CodecParamInfo * >(argp2);
  if (arg1) (arg1)->info = *arg2;
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_CodecParam_info_get(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::CodecParam *arg1 = (pj::CodecParam *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  pj::CodecParamInfo *result = 0 ;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__CodecParam, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "CodecParam_info_get" "', argument " "1"" of type '" "pj::CodecParam *""'"); 
  }
  arg1 = reinterpret_cast< pj::CodecParam * >(argp1);
  result = (pj::CodecParamInfo *)& ((arg1)->info);
  resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(result), SWIGTYPE_p_pj__CodecParamInfo, 0 |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_CodecParam_setting_set(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::CodecParam *arg1 = (pj::CodecParam *) 0 ;
  pj::CodecParamSetting *arg2 = (pj::CodecParamSetting *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  void *argp2 = 0 ;
  int res2 = 0 ;
  PyObject *swig_obj[2] ;
  
  if (!SWIG_Python_UnpackTuple(args, "CodecParam_setting_set", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__CodecParam, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "CodecParam_setting_set" "', argument " "1"" of type '" "pj::CodecParam *""'"); 
  }
  arg1 = reinterpret_cast< pj::CodecParam * >(argp1);
  res2 = SWIG_ConvertPtr(swig_obj[1], &argp2,SWIGTYPE_p_pj__CodecParamSetting, 0 |  0 );
  if (!SWIG_IsOK(res2)) {
    SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "CodecParam_setting_set" "', argument " "2"" of type '" "pj::CodecParamSetting *""'"); 
  }
  arg2 = reinterpret_cast< pj::CodecParamSetting * >(argp2);
  if (arg1) (arg1)->setting = *arg2;
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_CodecParam_setting_get(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::CodecParam *arg1 = (pj::CodecParam *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  pj::CodecParamSetting *result = 0 ;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__CodecParam, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "CodecParam_setting_get" "', argument " "1"" of type '" "pj::CodecParam *""'"); 
  }
  arg1 = reinterpret_cast< pj::CodecParam * >(argp1);
  result = (pj::CodecParamSetting *)& ((arg1)->setting);
  resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(result), SWIGTYPE_p_pj__CodecParamSetting, 0 |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_new_CodecParam(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::CodecParam *result = 0 ;
  
  if (!SWIG_Python_UnpackTuple(args, "new_CodecParam", 0, 0, 0)) SWIG_fail;
  result = (pj::CodecParam *)new pj::CodecParam();
  resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(result), SWIGTYPE_p_pj__CodecParam, SWIG_POINTER_NEW |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_delete_CodecParam(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::CodecParam *arg1 = (pj::CodecParam *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__CodecParam, SWIG_POINTER_DISOWN |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "delete_CodecParam" "', argument " "1"" of type '" "pj::CodecParam *""'"); 
  }
  arg1 = reinterpret_cast< pj::CodecParam * >(argp1);
  delete arg1;
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *CodecParam_swigregister(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *obj;
  if (!SWIG_Python_UnpackTuple(args, "swigregister", 1, 1, &obj)) return NULL;
  SWIG_TypeNewClientData(SWIGTYPE_p_pj__CodecParam, SWIG_NewClientData(obj));
  return SWIG_Py_Void();
}

SWIGINTERN PyObject *CodecParam_swiginit(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  return SWIG_Python_InitShadowInstance(args);
}

SWIGINTERN PyObject *_wrap_CodecOpusConfig_sample_rate_set(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::CodecOpusConfig *arg1 = (pj::CodecOpusConfig *) 0 ;
  unsigned int arg2 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  unsigned int val2 ;
  int ecode2 = 0 ;
  PyObject *swig_obj[2] ;
  
  if (!SWIG_Python_UnpackTuple(args, "CodecOpusConfig_sample_rate_set", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__CodecOpusConfig, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "CodecOpusConfig_sample_rate_set" "', argument " "1"" of type '" "pj::CodecOpusConfig *""'"); 
  }
  arg1 = reinterpret_cast< pj::CodecOpusConfig * >(argp1);
  ecode2 = SWIG_AsVal_unsigned_SS_int(swig_obj[1], &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "CodecOpusConfig_sample_rate_set" "', argument " "2"" of type '" "unsigned int""'");
  } 
  arg2 = static_cast< unsigned int >(val2);
  if (arg1) (arg1)->sample_rate = arg2;
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_CodecOpusConfig_sample_rate_get(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::CodecOpusConfig *arg1 = (pj::CodecOpusConfig *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  unsigned int result;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__CodecOpusConfig, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "CodecOpusConfig_sample_rate_get" "', argument " "1"" of type '" "pj::CodecOpusConfig *""'"); 
  }
  arg1 = reinterpret_cast< pj::CodecOpusConfig * >(argp1);
  result = (unsigned int) ((arg1)->sample_rate);
  resultobj = SWIG_From_unsigned_SS_int(static_cast< unsigned int >(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_CodecOpusConfig_channel_cnt_set(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::CodecOpusConfig *arg1 = (pj::CodecOpusConfig *) 0 ;
  unsigned int arg2 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  unsigned int val2 ;
  int ecode2 = 0 ;
  PyObject *swig_obj[2] ;
  
  if (!SWIG_Python_UnpackTuple(args, "CodecOpusConfig_channel_cnt_set", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__CodecOpusConfig, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "CodecOpusConfig_channel_cnt_set" "', argument " "1"" of type '" "pj::CodecOpusConfig *""'"); 
  }
  arg1 = reinterpret_cast< pj::CodecOpusConfig * >(argp1);
  ecode2 = SWIG_AsVal_unsigned_SS_int(swig_obj[1], &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "CodecOpusConfig_channel_cnt_set" "', argument " "2"" of type '" "unsigned int""'");
  } 
  arg2 = static_cast< unsigned int >(val2);
  if (arg1) (arg1)->channel_cnt = arg2;
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_CodecOpusConfig_channel_cnt_get(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::CodecOpusConfig *arg1 = (pj::CodecOpusConfig *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  unsigned int result;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__CodecOpusConfig, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "CodecOpusConfig_channel_cnt_get" "', argument " "1"" of type '" "pj::CodecOpusConfig *""'"); 
  }
  arg1 = reinterpret_cast< pj::CodecOpusConfig * >(argp1);
  result = (unsigned int) ((arg1)->channel_cnt);
  resultobj = SWIG_From_unsigned_SS_int(static_cast< unsigned int >(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_CodecOpusConfig_frm_ptime_set(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::CodecOpusConfig *arg1 = (pj::CodecOpusConfig *) 0 ;
  unsigned int arg2 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  unsigned int val2 ;
  int ecode2 = 0 ;
  PyObject *swig_obj[2] ;
  
  if (!SWIG_Python_UnpackTuple(args, "CodecOpusConfig_frm_ptime_set", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__CodecOpusConfig, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "CodecOpusConfig_frm_ptime_set" "', argument " "1"" of type '" "pj::CodecOpusConfig *""'"); 
  }
  arg1 = reinterpret_cast< pj::CodecOpusConfig * >(argp1);
  ecode2 = SWIG_AsVal_unsigned_SS_int(swig_obj[1], &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "CodecOpusConfig_frm_ptime_set" "', argument " "2"" of type '" "unsigned int""'");
  } 
  arg2 = static_cast< unsigned int >(val2);
  if (arg1) (arg1)->frm_ptime = arg2;
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_CodecOpusConfig_frm_ptime_get(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::CodecOpusConfig *arg1 = (pj::CodecOpusConfig *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  unsigned int result;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__CodecOpusConfig, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "CodecOpusConfig_frm_ptime_get" "', argument " "1"" of type '" "pj::CodecOpusConfig *""'"); 
  }
  arg1 = reinterpret_cast< pj::CodecOpusConfig * >(argp1);
  result = (unsigned int) ((arg1)->frm_ptime);
  resultobj = SWIG_From_unsigned_SS_int(static_cast< unsigned int >(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_CodecOpusConfig_bit_rate_set(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::CodecOpusConfig *arg1 = (pj::CodecOpusConfig *) 0 ;
  unsigned int arg2 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  unsigned int val2 ;
  int ecode2 = 0 ;
  PyObject *swig_obj[2] ;
  
  if (!SWIG_Python_UnpackTuple(args, "CodecOpusConfig_bit_rate_set", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__CodecOpusConfig, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "CodecOpusConfig_bit_rate_set" "', argument " "1"" of type '" "pj::CodecOpusConfig *""'"); 
  }
  arg1 = reinterpret_cast< pj::CodecOpusConfig * >(argp1);
  ecode2 = SWIG_AsVal_unsigned_SS_int(swig_obj[1], &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "CodecOpusConfig_bit_rate_set" "', argument " "2"" of type '" "unsigned int""'");
  } 
  arg2 = static_cast< unsigned int >(val2);
  if (arg1) (arg1)->bit_rate = arg2;
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_CodecOpusConfig_bit_rate_get(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::CodecOpusConfig *arg1 = (pj::CodecOpusConfig *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  unsigned int result;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__CodecOpusConfig, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "CodecOpusConfig_bit_rate_get" "', argument " "1"" of type '" "pj::CodecOpusConfig *""'"); 
  }
  arg1 = reinterpret_cast< pj::CodecOpusConfig * >(argp1);
  result = (unsigned int) ((arg1)->bit_rate);
  resultobj = SWIG_From_unsigned_SS_int(static_cast< unsigned int >(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_CodecOpusConfig_packet_loss_set(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::CodecOpusConfig *arg1 = (pj::CodecOpusConfig *) 0 ;
  unsigned int arg2 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  unsigned int val2 ;
  int ecode2 = 0 ;
  PyObject *swig_obj[2] ;
  
  if (!SWIG_Python_UnpackTuple(args, "CodecOpusConfig_packet_loss_set", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__CodecOpusConfig, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "CodecOpusConfig_packet_loss_set" "', argument " "1"" of type '" "pj::CodecOpusConfig *""'"); 
  }
  arg1 = reinterpret_cast< pj::CodecOpusConfig * >(argp1);
  ecode2 = SWIG_AsVal_unsigned_SS_int(swig_obj[1], &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "CodecOpusConfig_packet_loss_set" "', argument " "2"" of type '" "unsigned int""'");
  } 
  arg2 = static_cast< unsigned int >(val2);
  if (arg1) (arg1)->packet_loss = arg2;
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_CodecOpusConfig_packet_loss_get(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::CodecOpusConfig *arg1 = (pj::CodecOpusConfig *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  unsigned int result;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__CodecOpusConfig, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "CodecOpusConfig_packet_loss_get" "', argument " "1"" of type '" "pj::CodecOpusConfig *""'"); 
  }
  arg1 = reinterpret_cast< pj::CodecOpusConfig * >(argp1);
  result = (unsigned int) ((arg1)->packet_loss);
  resultobj = SWIG_From_unsigned_SS_int(static_cast< unsigned int >(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_CodecOpusConfig_complexity_set(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::CodecOpusConfig *arg1 = (pj::CodecOpusConfig *) 0 ;
  unsigned int arg2 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  unsigned int val2 ;
  int ecode2 = 0 ;
  PyObject *swig_obj[2] ;
  
  if (!SWIG_Python_UnpackTuple(args, "CodecOpusConfig_complexity_set", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__CodecOpusConfig, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "CodecOpusConfig_complexity_set" "', argument " "1"" of type '" "pj::CodecOpusConfig *""'"); 
  }
  arg1 = reinterpret_cast< pj::CodecOpusConfig * >(argp1);
  ecode2 = SWIG_AsVal_unsigned_SS_int(swig_obj[1], &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "CodecOpusConfig_complexity_set" "', argument " "2"" of type '" "unsigned int""'");
  } 
  arg2 = static_cast< unsigned int >(val2);
  if (arg1) (arg1)->complexity = arg2;
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_CodecOpusConfig_complexity_get(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::CodecOpusConfig *arg1 = (pj::CodecOpusConfig *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  unsigned int result;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__CodecOpusConfig, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "CodecOpusConfig_complexity_get" "', argument " "1"" of type '" "pj::CodecOpusConfig *""'"); 
  }
  arg1 = reinterpret_cast< pj::CodecOpusConfig * >(argp1);
  result = (unsigned int) ((arg1)->complexity);
  resultobj = SWIG_From_unsigned_SS_int(static_cast< unsigned int >(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_CodecOpusConfig_cbr_set(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::CodecOpusConfig *arg1 = (pj::CodecOpusConfig *) 0 ;
  bool arg2 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  bool val2 ;
  int ecode2 = 0 ;
  PyObject *swig_obj[2] ;
  
  if (!SWIG_Python_UnpackTuple(args, "CodecOpusConfig_cbr_set", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__CodecOpusConfig, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "CodecOpusConfig_cbr_set" "', argument " "1"" of type '" "pj::CodecOpusConfig *""'"); 
  }
  arg1 = reinterpret_cast< pj::CodecOpusConfig * >(argp1);
  ecode2 = SWIG_AsVal_bool(swig_obj[1], &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "CodecOpusConfig_cbr_set" "', argument " "2"" of type '" "bool""'");
  } 
  arg2 = static_cast< bool >(val2);
  if (arg1) (arg1)->cbr = arg2;
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_CodecOpusConfig_cbr_get(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::CodecOpusConfig *arg1 = (pj::CodecOpusConfig *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  bool result;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__CodecOpusConfig, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "CodecOpusConfig_cbr_get" "', argument " "1"" of type '" "pj::CodecOpusConfig *""'"); 
  }
  arg1 = reinterpret_cast< pj::CodecOpusConfig * >(argp1);
  result = (bool) ((arg1)->cbr);
  resultobj = SWIG_From_bool(static_cast< bool >(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_new_CodecOpusConfig(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::CodecOpusConfig *result = 0 ;
  
  if (!SWIG_Python_UnpackTuple(args, "new_CodecOpusConfig", 0, 0, 0)) SWIG_fail;
  result = (pj::CodecOpusConfig *)new pj::CodecOpusConfig();
  resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(result), SWIGTYPE_p_pj__CodecOpusConfig, SWIG_POINTER_NEW |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_delete_CodecOpusConfig(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::CodecOpusConfig *arg1 = (pj::CodecOpusConfig *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__CodecOpusConfig, SWIG_POINTER_DISOWN |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "delete_CodecOpusConfig" "', argument " "1"" of type '" "pj::CodecOpusConfig *""'"); 
  }
  arg1 = reinterpret_cast< pj::CodecOpusConfig * >(argp1);
  delete arg1;
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *CodecOpusConfig_swigregister(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *obj;
  if (!SWIG_Python_UnpackTuple(args, "swigregister", 1, 1, &obj)) return NULL;
  SWIG_TypeNewClientData(SWIGTYPE_p_pj__CodecOpusConfig, SWIG_NewClientData(obj));
  return SWIG_Py_Void();
}

SWIGINTERN PyObject *CodecOpusConfig_swiginit(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  return SWIG_Python_InitShadowInstance(args);
}

SWIGINTERN PyObject *_wrap_VidCodecParam_dir_set(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::VidCodecParam *arg1 = (pj::VidCodecParam *) 0 ;
  pjmedia_dir arg2 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  int val2 ;
  int ecode2 = 0 ;
  PyObject *swig_obj[2] ;
  
  if (!SWIG_Python_UnpackTuple(args, "VidCodecParam_dir_set", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__VidCodecParam, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "VidCodecParam_dir_set" "', argument " "1"" of type '" "pj::VidCodecParam *""'"); 
  }
  arg1 = reinterpret_cast< pj::VidCodecParam * >(argp1);
  ecode2 = SWIG_AsVal_int(swig_obj[1], &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "VidCodecParam_dir_set" "', argument " "2"" of type '" "pjmedia_dir""'");
  } 
  arg2 = static_cast< pjmedia_dir >(val2);
  if (arg1) (arg1)->dir = arg2;
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_VidCodecParam_dir_get(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::VidCodecParam *arg1 = (pj::VidCodecParam *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  pjmedia_dir result;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__VidCodecParam, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "VidCodecParam_dir_get" "', argument " "1"" of type '" "pj::VidCodecParam *""'"); 
  }
  arg1 = reinterpret_cast< pj::VidCodecParam * >(argp1);
  result = (pjmedia_dir) ((arg1)->dir);
  resultobj = SWIG_From_int(static_cast< int >(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_VidCodecParam_packing_set(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::VidCodecParam *arg1 = (pj::VidCodecParam *) 0 ;
  pjmedia_vid_packing arg2 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  int val2 ;
  int ecode2 = 0 ;
  PyObject *swig_obj[2] ;
  
  if (!SWIG_Python_UnpackTuple(args, "VidCodecParam_packing_set", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__VidCodecParam, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "VidCodecParam_packing_set" "', argument " "1"" of type '" "pj::VidCodecParam *""'"); 
  }
  arg1 = reinterpret_cast< pj::VidCodecParam * >(argp1);
  ecode2 = SWIG_AsVal_int(swig_obj[1], &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "VidCodecParam_packing_set" "', argument " "2"" of type '" "pjmedia_vid_packing""'");
  } 
  arg2 = static_cast< pjmedia_vid_packing >(val2);
  if (arg1) (arg1)->packing = arg2;
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_VidCodecParam_packing_get(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::VidCodecParam *arg1 = (pj::VidCodecParam *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  pjmedia_vid_packing result;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__VidCodecParam, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "VidCodecParam_packing_get" "', argument " "1"" of type '" "pj::VidCodecParam *""'"); 
  }
  arg1 = reinterpret_cast< pj::VidCodecParam * >(argp1);
  result = (pjmedia_vid_packing) ((arg1)->packing);
  resultobj = SWIG_From_int(static_cast< int >(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_VidCodecParam_encFmt_set(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::VidCodecParam *arg1 = (pj::VidCodecParam *) 0 ;
  pj::MediaFormatVideo *arg2 = (pj::MediaFormatVideo *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  void *argp2 = 0 ;
  int res2 = 0 ;
  PyObject *swig_obj[2] ;
  
  if (!SWIG_Python_UnpackTuple(args, "VidCodecParam_encFmt_set", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__VidCodecParam, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "VidCodecParam_encFmt_set" "', argument " "1"" of type '" "pj::VidCodecParam *""'"); 
  }
  arg1 = reinterpret_cast< pj::VidCodecParam * >(argp1);
  res2 = SWIG_ConvertPtr(swig_obj[1], &argp2,SWIGTYPE_p_pj__MediaFormatVideo, 0 |  0 );
  if (!SWIG_IsOK(res2)) {
    SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "VidCodecParam_encFmt_set" "', argument " "2"" of type '" "pj::MediaFormatVideo *""'"); 
  }
  arg2 = reinterpret_cast< pj::MediaFormatVideo * >(argp2);
  if (arg1) (arg1)->encFmt = *arg2;
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_VidCodecParam_encFmt_get(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::VidCodecParam *arg1 = (pj::VidCodecParam *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  pj::MediaFormatVideo *result = 0 ;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__VidCodecParam, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "VidCodecParam_encFmt_get" "', argument " "1"" of type '" "pj::VidCodecParam *""'"); 
  }
  arg1 = reinterpret_cast< pj::VidCodecParam * >(argp1);
  result = (pj::MediaFormatVideo *)& ((arg1)->encFmt);
  resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(result), SWIGTYPE_p_pj__MediaFormatVideo, 0 |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_VidCodecParam_encFmtp_set(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::VidCodecParam *arg1 = (pj::VidCodecParam *) 0 ;
  pj::CodecFmtpVector *arg2 = (pj::CodecFmtpVector *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  void *argp2 = 0 ;
  int res2 = 0 ;
  PyObject *swig_obj[2] ;
  
  if (!SWIG_Python_UnpackTuple(args, "VidCodecParam_encFmtp_set", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__VidCodecParam, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "VidCodecParam_encFmtp_set" "', argument " "1"" of type '" "pj::VidCodecParam *""'"); 
  }
  arg1 = reinterpret_cast< pj::VidCodecParam * >(argp1);
  res2 = SWIG_ConvertPtr(swig_obj[1], &argp2,SWIGTYPE_p_std__vectorT_pj__CodecFmtp_std__allocatorT_pj__CodecFmtp_t_t, 0 |  0 );
  if (!SWIG_IsOK(res2)) {
    SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "VidCodecParam_encFmtp_set" "', argument " "2"" of type '" "pj::CodecFmtpVector *""'"); 
  }
  arg2 = reinterpret_cast< pj::CodecFmtpVector * >(argp2);
  if (arg1) (arg1)->encFmtp = *arg2;
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_VidCodecParam_encFmtp_get(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::VidCodecParam *arg1 = (pj::VidCodecParam *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  pj::CodecFmtpVector *result = 0 ;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__VidCodecParam, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "VidCodecParam_encFmtp_get" "', argument " "1"" of type '" "pj::VidCodecParam *""'"); 
  }
  arg1 = reinterpret_cast< pj::VidCodecParam * >(argp1);
  result = (pj::CodecFmtpVector *)& ((arg1)->encFmtp);
  resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(result), SWIGTYPE_p_std__vectorT_pj__CodecFmtp_std__allocatorT_pj__CodecFmtp_t_t, 0 |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_VidCodecParam_encMtu_set(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::VidCodecParam *arg1 = (pj::VidCodecParam *) 0 ;
  unsigned int arg2 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  unsigned int val2 ;
  int ecode2 = 0 ;
  PyObject *swig_obj[2] ;
  
  if (!SWIG_Python_UnpackTuple(args, "VidCodecParam_encMtu_set", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__VidCodecParam, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "VidCodecParam_encMtu_set" "', argument " "1"" of type '" "pj::VidCodecParam *""'"); 
  }
  arg1 = reinterpret_cast< pj::VidCodecParam * >(argp1);
  ecode2 = SWIG_AsVal_unsigned_SS_int(swig_obj[1], &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "VidCodecParam_encMtu_set" "', argument " "2"" of type '" "unsigned int""'");
  } 
  arg2 = static_cast< unsigned int >(val2);
  if (arg1) (arg1)->encMtu = arg2;
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_VidCodecParam_encMtu_get(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::VidCodecParam *arg1 = (pj::VidCodecParam *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  unsigned int result;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__VidCodecParam, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "VidCodecParam_encMtu_get" "', argument " "1"" of type '" "pj::VidCodecParam *""'"); 
  }
  arg1 = reinterpret_cast< pj::VidCodecParam * >(argp1);
  result = (unsigned int) ((arg1)->encMtu);
  resultobj = SWIG_From_unsigned_SS_int(static_cast< unsigned int >(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_VidCodecParam_decFmt_set(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::VidCodecParam *arg1 = (pj::VidCodecParam *) 0 ;
  pj::MediaFormatVideo *arg2 = (pj::MediaFormatVideo *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  void *argp2 = 0 ;
  int res2 = 0 ;
  PyObject *swig_obj[2] ;
  
  if (!SWIG_Python_UnpackTuple(args, "VidCodecParam_decFmt_set", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__VidCodecParam, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "VidCodecParam_decFmt_set" "', argument " "1"" of type '" "pj::VidCodecParam *""'"); 
  }
  arg1 = reinterpret_cast< pj::VidCodecParam * >(argp1);
  res2 = SWIG_ConvertPtr(swig_obj[1], &argp2,SWIGTYPE_p_pj__MediaFormatVideo, 0 |  0 );
  if (!SWIG_IsOK(res2)) {
    SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "VidCodecParam_decFmt_set" "', argument " "2"" of type '" "pj::MediaFormatVideo *""'"); 
  }
  arg2 = reinterpret_cast< pj::MediaFormatVideo * >(argp2);
  if (arg1) (arg1)->decFmt = *arg2;
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_VidCodecParam_decFmt_get(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::VidCodecParam *arg1 = (pj::VidCodecParam *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  pj::MediaFormatVideo *result = 0 ;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__VidCodecParam, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "VidCodecParam_decFmt_get" "', argument " "1"" of type '" "pj::VidCodecParam *""'"); 
  }
  arg1 = reinterpret_cast< pj::VidCodecParam * >(argp1);
  result = (pj::MediaFormatVideo *)& ((arg1)->decFmt);
  resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(result), SWIGTYPE_p_pj__MediaFormatVideo, 0 |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_VidCodecParam_decFmtp_set(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::VidCodecParam *arg1 = (pj::VidCodecParam *) 0 ;
  pj::CodecFmtpVector *arg2 = (pj::CodecFmtpVector *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  void *argp2 = 0 ;
  int res2 = 0 ;
  PyObject *swig_obj[2] ;
  
  if (!SWIG_Python_UnpackTuple(args, "VidCodecParam_decFmtp_set", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__VidCodecParam, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "VidCodecParam_decFmtp_set" "', argument " "1"" of type '" "pj::VidCodecParam *""'"); 
  }
  arg1 = reinterpret_cast< pj::VidCodecParam * >(argp1);
  res2 = SWIG_ConvertPtr(swig_obj[1], &argp2,SWIGTYPE_p_std__vectorT_pj__CodecFmtp_std__allocatorT_pj__CodecFmtp_t_t, 0 |  0 );
  if (!SWIG_IsOK(res2)) {
    SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "VidCodecParam_decFmtp_set" "', argument " "2"" of type '" "pj::CodecFmtpVector *""'"); 
  }
  arg2 = reinterpret_cast< pj::CodecFmtpVector * >(argp2);
  if (arg1) (arg1)->decFmtp = *arg2;
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_VidCodecParam_decFmtp_get(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::VidCodecParam *arg1 = (pj::VidCodecParam *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  pj::CodecFmtpVector *result = 0 ;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__VidCodecParam, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "VidCodecParam_decFmtp_get" "', argument " "1"" of type '" "pj::VidCodecParam *""'"); 
  }
  arg1 = reinterpret_cast< pj::VidCodecParam * >(argp1);
  result = (pj::CodecFmtpVector *)& ((arg1)->decFmtp);
  resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(result), SWIGTYPE_p_std__vectorT_pj__CodecFmtp_std__allocatorT_pj__CodecFmtp_t_t, 0 |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_VidCodecParam_ignoreFmtp_set(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::VidCodecParam *arg1 = (pj::VidCodecParam *) 0 ;
  bool arg2 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  bool val2 ;
  int ecode2 = 0 ;
  PyObject *swig_obj[2] ;
  
  if (!SWIG_Python_UnpackTuple(args, "VidCodecParam_ignoreFmtp_set", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__VidCodecParam, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "VidCodecParam_ignoreFmtp_set" "', argument " "1"" of type '" "pj::VidCodecParam *""'"); 
  }
  arg1 = reinterpret_cast< pj::VidCodecParam * >(argp1);
  ecode2 = SWIG_AsVal_bool(swig_obj[1], &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "VidCodecParam_ignoreFmtp_set" "', argument " "2"" of type '" "bool""'");
  } 
  arg2 = static_cast< bool >(val2);
  if (arg1) (arg1)->ignoreFmtp = arg2;
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_VidCodecParam_ignoreFmtp_get(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::VidCodecParam *arg1 = (pj::VidCodecParam *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  bool result;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__VidCodecParam, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "VidCodecParam_ignoreFmtp_get" "', argument " "1"" of type '" "pj::VidCodecParam *""'"); 
  }
  arg1 = reinterpret_cast< pj::VidCodecParam * >(argp1);
  result = (bool) ((arg1)->ignoreFmtp);
  resultobj = SWIG_From_bool(static_cast< bool >(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_new_VidCodecParam(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::VidCodecParam *result = 0 ;
  
  if (!SWIG_Python_UnpackTuple(args, "new_VidCodecParam", 0, 0, 0)) SWIG_fail;
  result = (pj::VidCodecParam *)new pj::VidCodecParam();
  resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(result), SWIGTYPE_p_pj__VidCodecParam, SWIG_POINTER_NEW |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_delete_VidCodecParam(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::VidCodecParam *arg1 = (pj::VidCodecParam *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__VidCodecParam, SWIG_POINTER_DISOWN |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "delete_VidCodecParam" "', argument " "1"" of type '" "pj::VidCodecParam *""'"); 
  }
  arg1 = reinterpret_cast< pj::VidCodecParam * >(argp1);
  delete arg1;
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *VidCodecParam_swigregister(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *obj;
  if (!SWIG_Python_UnpackTuple(args, "swigregister", 1, 1, &obj)) return NULL;
  SWIG_TypeNewClientData(SWIGTYPE_p_pj__VidCodecParam, SWIG_NewClientData(obj));
  return SWIG_Py_Void();
}

SWIGINTERN PyObject *VidCodecParam_swiginit(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  return SWIG_Python_InitShadowInstance(args);
}

SWIGINTERN PyObject *_wrap_MediaFmtChangedEvent_newWidth_set(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::MediaFmtChangedEvent *arg1 = (pj::MediaFmtChangedEvent *) 0 ;
  unsigned int arg2 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  unsigned int val2 ;
  int ecode2 = 0 ;
  PyObject *swig_obj[2] ;
  
  if (!SWIG_Python_UnpackTuple(args, "MediaFmtChangedEvent_newWidth_set", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__MediaFmtChangedEvent, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "MediaFmtChangedEvent_newWidth_set" "', argument " "1"" of type '" "pj::MediaFmtChangedEvent *""'"); 
  }
  arg1 = reinterpret_cast< pj::MediaFmtChangedEvent * >(argp1);
  ecode2 = SWIG_AsVal_unsigned_SS_int(swig_obj[1], &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "MediaFmtChangedEvent_newWidth_set" "', argument " "2"" of type '" "unsigned int""'");
  } 
  arg2 = static_cast< unsigned int >(val2);
  if (arg1) (arg1)->newWidth = arg2;
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_MediaFmtChangedEvent_newWidth_get(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::MediaFmtChangedEvent *arg1 = (pj::MediaFmtChangedEvent *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  unsigned int result;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__MediaFmtChangedEvent, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "MediaFmtChangedEvent_newWidth_get" "', argument " "1"" of type '" "pj::MediaFmtChangedEvent *""'"); 
  }
  arg1 = reinterpret_cast< pj::MediaFmtChangedEvent * >(argp1);
  result = (unsigned int) ((arg1)->newWidth);
  resultobj = SWIG_From_unsigned_SS_int(static_cast< unsigned int >(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_MediaFmtChangedEvent_newHeight_set(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::MediaFmtChangedEvent *arg1 = (pj::MediaFmtChangedEvent *) 0 ;
  unsigned int arg2 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  unsigned int val2 ;
  int ecode2 = 0 ;
  PyObject *swig_obj[2] ;
  
  if (!SWIG_Python_UnpackTuple(args, "MediaFmtChangedEvent_newHeight_set", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__MediaFmtChangedEvent, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "MediaFmtChangedEvent_newHeight_set" "', argument " "1"" of type '" "pj::MediaFmtChangedEvent *""'"); 
  }
  arg1 = reinterpret_cast< pj::MediaFmtChangedEvent * >(argp1);
  ecode2 = SWIG_AsVal_unsigned_SS_int(swig_obj[1], &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "MediaFmtChangedEvent_newHeight_set" "', argument " "2"" of type '" "unsigned int""'");
  } 
  arg2 = static_cast< unsigned int >(val2);
  if (arg1) (arg1)->newHeight = arg2;
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_MediaFmtChangedEvent_newHeight_get(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::MediaFmtChangedEvent *arg1 = (pj::MediaFmtChangedEvent *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  unsigned int result;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__MediaFmtChangedEvent, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "MediaFmtChangedEvent_newHeight_get" "', argument " "1"" of type '" "pj::MediaFmtChangedEvent *""'"); 
  }
  arg1 = reinterpret_cast< pj::MediaFmtChangedEvent * >(argp1);
  result = (unsigned int) ((arg1)->newHeight);
  resultobj = SWIG_From_unsigned_SS_int(static_cast< unsigned int >(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_new_MediaFmtChangedEvent(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::MediaFmtChangedEvent *result = 0 ;
  
  if (!SWIG_Python_UnpackTuple(args, "new_MediaFmtChangedEvent", 0, 0, 0)) SWIG_fail;
  result = (pj::MediaFmtChangedEvent *)new pj::MediaFmtChangedEvent();
  resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(result), SWIGTYPE_p_pj__MediaFmtChangedEvent, SWIG_POINTER_NEW |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_delete_MediaFmtChangedEvent(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::MediaFmtChangedEvent *arg1 = (pj::MediaFmtChangedEvent *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__MediaFmtChangedEvent, SWIG_POINTER_DISOWN |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "delete_MediaFmtChangedEvent" "', argument " "1"" of type '" "pj::MediaFmtChangedEvent *""'"); 
  }
  arg1 = reinterpret_cast< pj::MediaFmtChangedEvent * >(argp1);
  delete arg1;
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *MediaFmtChangedEvent_swigregister(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *obj;
  if (!SWIG_Python_UnpackTuple(args, "swigregister", 1, 1, &obj)) return NULL;
  SWIG_TypeNewClientData(SWIGTYPE_p_pj__MediaFmtChangedEvent, SWIG_NewClientData(obj));
  return SWIG_Py_Void();
}

SWIGINTERN PyObject *MediaFmtChangedEvent_swiginit(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  return SWIG_Python_InitShadowInstance(args);
}

SWIGINTERN PyObject *_wrap_AudDevErrorEvent_dir_set(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::AudDevErrorEvent *arg1 = (pj::AudDevErrorEvent *) 0 ;
  pjmedia_dir arg2 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  int val2 ;
  int ecode2 = 0 ;
  PyObject *swig_obj[2] ;
  
  if (!SWIG_Python_UnpackTuple(args, "AudDevErrorEvent_dir_set", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__AudDevErrorEvent, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "AudDevErrorEvent_dir_set" "', argument " "1"" of type '" "pj::AudDevErrorEvent *""'"); 
  }
  arg1 = reinterpret_cast< pj::AudDevErrorEvent * >(argp1);
  ecode2 = SWIG_AsVal_int(swig_obj[1], &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "AudDevErrorEvent_dir_set" "', argument " "2"" of type '" "pjmedia_dir""'");
  } 
  arg2 = static_cast< pjmedia_dir >(val2);
  if (arg1) (arg1)->dir = arg2;
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_AudDevErrorEvent_dir_get(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::AudDevErrorEvent *arg1 = (pj::AudDevErrorEvent *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  pjmedia_dir result;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__AudDevErrorEvent, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "AudDevErrorEvent_dir_get" "', argument " "1"" of type '" "pj::AudDevErrorEvent *""'"); 
  }
  arg1 = reinterpret_cast< pj::AudDevErrorEvent * >(argp1);
  result = (pjmedia_dir) ((arg1)->dir);
  resultobj = SWIG_From_int(static_cast< int >(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_AudDevErrorEvent_id_set(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::AudDevErrorEvent *arg1 = (pj::AudDevErrorEvent *) 0 ;
  int arg2 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  int val2 ;
  int ecode2 = 0 ;
  PyObject *swig_obj[2] ;
  
  if (!SWIG_Python_UnpackTuple(args, "AudDevErrorEvent_id_set", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__AudDevErrorEvent, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "AudDevErrorEvent_id_set" "', argument " "1"" of type '" "pj::AudDevErrorEvent *""'"); 
  }
  arg1 = reinterpret_cast< pj::AudDevErrorEvent * >(argp1);
  ecode2 = SWIG_AsVal_int(swig_obj[1], &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "AudDevErrorEvent_id_set" "', argument " "2"" of type '" "int""'");
  } 
  arg2 = static_cast< int >(val2);
  if (arg1) (arg1)->id = arg2;
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_AudDevErrorEvent_id_get(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::AudDevErrorEvent *arg1 = (pj::AudDevErrorEvent *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  int result;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__AudDevErrorEvent, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "AudDevErrorEvent_id_get" "', argument " "1"" of type '" "pj::AudDevErrorEvent *""'"); 
  }
  arg1 = reinterpret_cast< pj::AudDevErrorEvent * >(argp1);
  result = (int) ((arg1)->id);
  resultobj = SWIG_From_int(static_cast< int >(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_AudDevErrorEvent_status_set(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::AudDevErrorEvent *arg1 = (pj::AudDevErrorEvent *) 0 ;
  pj_status_t arg2 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  int val2 ;
  int ecode2 = 0 ;
  PyObject *swig_obj[2] ;
  
  if (!SWIG_Python_UnpackTuple(args, "AudDevErrorEvent_status_set", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__AudDevErrorEvent, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "AudDevErrorEvent_status_set" "', argument " "1"" of type '" "pj::AudDevErrorEvent *""'"); 
  }
  arg1 = reinterpret_cast< pj::AudDevErrorEvent * >(argp1);
  ecode2 = SWIG_AsVal_int(swig_obj[1], &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "AudDevErrorEvent_status_set" "', argument " "2"" of type '" "pj_status_t""'");
  } 
  arg2 = static_cast< pj_status_t >(val2);
  if (arg1) (arg1)->status = arg2;
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_AudDevErrorEvent_status_get(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::AudDevErrorEvent *arg1 = (pj::AudDevErrorEvent *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  pj_status_t result;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__AudDevErrorEvent, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "AudDevErrorEvent_status_get" "', argument " "1"" of type '" "pj::AudDevErrorEvent *""'"); 
  }
  arg1 = reinterpret_cast< pj::AudDevErrorEvent * >(argp1);
  result = (pj_status_t) ((arg1)->status);
  resultobj = SWIG_From_int(static_cast< int >(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_new_AudDevErrorEvent(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::AudDevErrorEvent *result = 0 ;
  
  if (!SWIG_Python_UnpackTuple(args, "new_AudDevErrorEvent", 0, 0, 0)) SWIG_fail;
  result = (pj::AudDevErrorEvent *)new pj::AudDevErrorEvent();
  resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(result), SWIGTYPE_p_pj__AudDevErrorEvent, SWIG_POINTER_NEW |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_delete_AudDevErrorEvent(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::AudDevErrorEvent *arg1 = (pj::AudDevErrorEvent *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__AudDevErrorEvent, SWIG_POINTER_DISOWN |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "delete_AudDevErrorEvent" "', argument " "1"" of type '" "pj::AudDevErrorEvent *""'"); 
  }
  arg1 = reinterpret_cast< pj::AudDevErrorEvent * >(argp1);
  delete arg1;
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *AudDevErrorEvent_swigregister(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *obj;
  if (!SWIG_Python_UnpackTuple(args, "swigregister", 1, 1, &obj)) return NULL;
  SWIG_TypeNewClientData(SWIGTYPE_p_pj__AudDevErrorEvent, SWIG_NewClientData(obj));
  return SWIG_Py_Void();
}

SWIGINTERN PyObject *AudDevErrorEvent_swiginit(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  return SWIG_Python_InitShadowInstance(args);
}

SWIGINTERN PyObject *_wrap_MediaEventData_fmtChanged_set(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::MediaEventData *arg1 = (pj::MediaEventData *) 0 ;
  pj::MediaFmtChangedEvent *arg2 = (pj::MediaFmtChangedEvent *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  void *argp2 = 0 ;
  int res2 = 0 ;
  PyObject *swig_obj[2] ;
  
  if (!SWIG_Python_UnpackTuple(args, "MediaEventData_fmtChanged_set", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__MediaEventData, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "MediaEventData_fmtChanged_set" "', argument " "1"" of type '" "pj::MediaEventData *""'"); 
  }
  arg1 = reinterpret_cast< pj::MediaEventData * >(argp1);
  res2 = SWIG_ConvertPtr(swig_obj[1], &argp2,SWIGTYPE_p_pj__MediaFmtChangedEvent, 0 |  0 );
  if (!SWIG_IsOK(res2)) {
    SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "MediaEventData_fmtChanged_set" "', argument " "2"" of type '" "pj::MediaFmtChangedEvent *""'"); 
  }
  arg2 = reinterpret_cast< pj::MediaFmtChangedEvent * >(argp2);
  if (arg1) (arg1)->fmtChanged = *arg2;
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_MediaEventData_fmtChanged_get(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::MediaEventData *arg1 = (pj::MediaEventData *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  pj::MediaFmtChangedEvent *result = 0 ;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__MediaEventData, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "MediaEventData_fmtChanged_get" "', argument " "1"" of type '" "pj::MediaEventData *""'"); 
  }
  arg1 = reinterpret_cast< pj::MediaEventData * >(argp1);
  result = (pj::MediaFmtChangedEvent *)& ((arg1)->fmtChanged);
  resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(result), SWIGTYPE_p_pj__MediaFmtChangedEvent, 0 |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_MediaEventData_audDevError_set(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::MediaEventData *arg1 = (pj::MediaEventData *) 0 ;
  pj::AudDevErrorEvent *arg2 = (pj::AudDevErrorEvent *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  void *argp2 = 0 ;
  int res2 = 0 ;
  PyObject *swig_obj[2] ;
  
  if (!SWIG_Python_UnpackTuple(args, "MediaEventData_audDevError_set", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__MediaEventData, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "MediaEventData_audDevError_set" "', argument " "1"" of type '" "pj::MediaEventData *""'"); 
  }
  arg1 = reinterpret_cast< pj::MediaEventData * >(argp1);
  res2 = SWIG_ConvertPtr(swig_obj[1], &argp2,SWIGTYPE_p_pj__AudDevErrorEvent, 0 |  0 );
  if (!SWIG_IsOK(res2)) {
    SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "MediaEventData_audDevError_set" "', argument " "2"" of type '" "pj::AudDevErrorEvent *""'"); 
  }
  arg2 = reinterpret_cast< pj::AudDevErrorEvent * >(argp2);
  if (arg1) (arg1)->audDevError = *arg2;
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_MediaEventData_audDevError_get(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::MediaEventData *arg1 = (pj::MediaEventData *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  pj::AudDevErrorEvent *result = 0 ;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__MediaEventData, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "MediaEventData_audDevError_get" "', argument " "1"" of type '" "pj::MediaEventData *""'"); 
  }
  arg1 = reinterpret_cast< pj::MediaEventData * >(argp1);
  result = (pj::AudDevErrorEvent *)& ((arg1)->audDevError);
  resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(result), SWIGTYPE_p_pj__AudDevErrorEvent, 0 |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_MediaEventData_ptr_set(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::MediaEventData *arg1 = (pj::MediaEventData *) 0 ;
  pj::GenericData arg2 = (pj::GenericData) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  int res2 ;
  PyObject *swig_obj[2] ;
  
  if (!SWIG_Python_UnpackTuple(args, "MediaEventData_ptr_set", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__MediaEventData, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "MediaEventData_ptr_set" "', argument " "1"" of type '" "pj::MediaEventData *""'"); 
  }
  arg1 = reinterpret_cast< pj::MediaEventData * >(argp1);
  res2 = SWIG_ConvertPtr(swig_obj[1],SWIG_as_voidptrptr(&arg2), 0, SWIG_POINTER_DISOWN);
  if (!SWIG_IsOK(res2)) {
    SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "MediaEventData_ptr_set" "', argument " "2"" of type '" "pj::GenericData""'"); 
  }
  if (arg1) (arg1)->ptr = arg2;
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_MediaEventData_ptr_get(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::MediaEventData *arg1 = (pj::MediaEventData *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  pj::GenericData result;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__MediaEventData, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "MediaEventData_ptr_get" "', argument " "1"" of type '" "pj::MediaEventData *""'"); 
  }
  arg1 = reinterpret_cast< pj::MediaEventData * >(argp1);
  result = (pj::GenericData) ((arg1)->ptr);
  resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(result), SWIGTYPE_p_void, 0 |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_new_MediaEventData(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::MediaEventData *result = 0 ;
  
  if (!SWIG_Python_UnpackTuple(args, "new_MediaEventData", 0, 0, 0)) SWIG_fail;
  result = (pj::MediaEventData *)new pj::MediaEventData();
  resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(result), SWIGTYPE_p_pj__MediaEventData, SWIG_POINTER_NEW |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_delete_MediaEventData(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::MediaEventData *arg1 = (pj::MediaEventData *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__MediaEventData, SWIG_POINTER_DISOWN |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "delete_MediaEventData" "', argument " "1"" of type '" "pj::MediaEventData *""'"); 
  }
  arg1 = reinterpret_cast< pj::MediaEventData * >(argp1);
  delete arg1;
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *MediaEventData_swigregister(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *obj;
  if (!SWIG_Python_UnpackTuple(args, "swigregister", 1, 1, &obj)) return NULL;
  SWIG_TypeNewClientData(SWIGTYPE_p_pj__MediaEventData, SWIG_NewClientData(obj));
  return SWIG_Py_Void();
}

SWIGINTERN PyObject *MediaEventData_swiginit(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  return SWIG_Python_InitShadowInstance(args);
}

SWIGINTERN PyObject *_wrap_MediaEvent_type_set(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::MediaEvent *arg1 = (pj::MediaEvent *) 0 ;
  pjmedia_event_type arg2 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  int val2 ;
  int ecode2 = 0 ;
  PyObject *swig_obj[2] ;
  
  if (!SWIG_Python_UnpackTuple(args, "MediaEvent_type_set", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__MediaEvent, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "MediaEvent_type_set" "', argument " "1"" of type '" "pj::MediaEvent *""'"); 
  }
  arg1 = reinterpret_cast< pj::MediaEvent * >(argp1);
  ecode2 = SWIG_AsVal_int(swig_obj[1], &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "MediaEvent_type_set" "', argument " "2"" of type '" "pjmedia_event_type""'");
  } 
  arg2 = static_cast< pjmedia_event_type >(val2);
  if (arg1) (arg1)->type = arg2;
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_MediaEvent_type_get(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::MediaEvent *arg1 = (pj::MediaEvent *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  pjmedia_event_type result;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__MediaEvent, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "MediaEvent_type_get" "', argument " "1"" of type '" "pj::MediaEvent *""'"); 
  }
  arg1 = reinterpret_cast< pj::MediaEvent * >(argp1);
  result = (pjmedia_event_type) ((arg1)->type);
  resultobj = SWIG_From_int(static_cast< int >(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_MediaEvent_data_set(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::MediaEvent *arg1 = (pj::MediaEvent *) 0 ;
  pj::MediaEventData *arg2 = (pj::MediaEventData *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  void *argp2 = 0 ;
  int res2 = 0 ;
  PyObject *swig_obj[2] ;
  
  if (!SWIG_Python_UnpackTuple(args, "MediaEvent_data_set", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__MediaEvent, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "MediaEvent_data_set" "', argument " "1"" of type '" "pj::MediaEvent *""'"); 
  }
  arg1 = reinterpret_cast< pj::MediaEvent * >(argp1);
  res2 = SWIG_ConvertPtr(swig_obj[1], &argp2,SWIGTYPE_p_pj__MediaEventData, 0 |  0 );
  if (!SWIG_IsOK(res2)) {
    SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "MediaEvent_data_set" "', argument " "2"" of type '" "pj::MediaEventData *""'"); 
  }
  arg2 = reinterpret_cast< pj::MediaEventData * >(argp2);
  if (arg1) (arg1)->data = *arg2;
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_MediaEvent_data_get(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::MediaEvent *arg1 = (pj::MediaEvent *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  pj::MediaEventData *result = 0 ;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__MediaEvent, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "MediaEvent_data_get" "', argument " "1"" of type '" "pj::MediaEvent *""'"); 
  }
  arg1 = reinterpret_cast< pj::MediaEvent * >(argp1);
  result = (pj::MediaEventData *)& ((arg1)->data);
  resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(result), SWIGTYPE_p_pj__MediaEventData, 0 |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_MediaEvent_pjMediaEvent_set(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::MediaEvent *arg1 = (pj::MediaEvent *) 0 ;
  void *arg2 = (void *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  int res2 ;
  PyObject *swig_obj[2] ;
  
  if (!SWIG_Python_UnpackTuple(args, "MediaEvent_pjMediaEvent_set", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__MediaEvent, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "MediaEvent_pjMediaEvent_set" "', argument " "1"" of type '" "pj::MediaEvent *""'"); 
  }
  arg1 = reinterpret_cast< pj::MediaEvent * >(argp1);
  res2 = SWIG_ConvertPtr(swig_obj[1],SWIG_as_voidptrptr(&arg2), 0, SWIG_POINTER_DISOWN);
  if (!SWIG_IsOK(res2)) {
    SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "MediaEvent_pjMediaEvent_set" "', argument " "2"" of type '" "void *""'"); 
  }
  if (arg1) (arg1)->pjMediaEvent = arg2;
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_MediaEvent_pjMediaEvent_get(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::MediaEvent *arg1 = (pj::MediaEvent *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  void *result = 0 ;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__MediaEvent, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "MediaEvent_pjMediaEvent_get" "', argument " "1"" of type '" "pj::MediaEvent *""'"); 
  }
  arg1 = reinterpret_cast< pj::MediaEvent * >(argp1);
  result = (void *) ((arg1)->pjMediaEvent);
  resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(result), SWIGTYPE_p_void, 0 |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_new_MediaEvent(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::MediaEvent *result = 0 ;
  
  if (!SWIG_Python_UnpackTuple(args, "new_MediaEvent", 0, 0, 0)) SWIG_fail;
  result = (pj::MediaEvent *)new pj::MediaEvent();
  resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(result), SWIGTYPE_p_pj__MediaEvent, SWIG_POINTER_NEW |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_delete_MediaEvent(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::MediaEvent *arg1 = (pj::MediaEvent *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__MediaEvent, SWIG_POINTER_DISOWN |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "delete_MediaEvent" "', argument " "1"" of type '" "pj::MediaEvent *""'"); 
  }
  arg1 = reinterpret_cast< pj::MediaEvent * >(argp1);
  delete arg1;
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *MediaEvent_swigregister(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *obj;
  if (!SWIG_Python_UnpackTuple(args, "swigregister", 1, 1, &obj)) return NULL;
  SWIG_TypeNewClientData(SWIGTYPE_p_pj__MediaEvent, SWIG_NewClientData(obj));
  return SWIG_Py_Void();
}

SWIGINTERN PyObject *MediaEvent_swiginit(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  return SWIG_Python_InitShadowInstance(args);
}

SWIGINTERN PyObject *_wrap_PresenceStatus_status_set(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::PresenceStatus *arg1 = (pj::PresenceStatus *) 0 ;
  pjsua_buddy_status arg2 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  int val2 ;
  int ecode2 = 0 ;
  PyObject *swig_obj[2] ;
  
  if (!SWIG_Python_UnpackTuple(args, "PresenceStatus_status_set", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__PresenceStatus, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "PresenceStatus_status_set" "', argument " "1"" of type '" "pj::PresenceStatus *""'"); 
  }
  arg1 = reinterpret_cast< pj::PresenceStatus * >(argp1);
  ecode2 = SWIG_AsVal_int(swig_obj[1], &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "PresenceStatus_status_set" "', argument " "2"" of type '" "pjsua_buddy_status""'");
  } 
  arg2 = static_cast< pjsua_buddy_status >(val2);
  if (arg1) (arg1)->status = arg2;
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_PresenceStatus_status_get(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::PresenceStatus *arg1 = (pj::PresenceStatus *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  pjsua_buddy_status result;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__PresenceStatus, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "PresenceStatus_status_get" "', argument " "1"" of type '" "pj::PresenceStatus *""'"); 
  }
  arg1 = reinterpret_cast< pj::PresenceStatus * >(argp1);
  result = (pjsua_buddy_status) ((arg1)->status);
  resultobj = SWIG_From_int(static_cast< int >(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_PresenceStatus_statusText_set(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::PresenceStatus *arg1 = (pj::PresenceStatus *) 0 ;
  pj::string *arg2 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  int res2 = SWIG_OLDOBJ ;
  PyObject *swig_obj[2] ;
  
  if (!SWIG_Python_UnpackTuple(args, "PresenceStatus_statusText_set", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__PresenceStatus, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "PresenceStatus_statusText_set" "', argument " "1"" of type '" "pj::PresenceStatus *""'"); 
  }
  arg1 = reinterpret_cast< pj::PresenceStatus * >(argp1);
  {
    std::string *ptr = (std::string *)0;
    res2 = SWIG_AsPtr_std_string(swig_obj[1], &ptr);
    if (!SWIG_IsOK(res2)) {
      SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "PresenceStatus_statusText_set" "', argument " "2"" of type '" "pj::string const &""'"); 
    }
    if (!ptr) {
      SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "PresenceStatus_statusText_set" "', argument " "2"" of type '" "pj::string const &""'"); 
    }
    arg2 = ptr;
  }
  if (arg1) (arg1)->statusText = *arg2;
  resultobj = SWIG_Py_Void();
  if (SWIG_IsNewObj(res2)) delete arg2;
  return resultobj;
fail:
  if (SWIG_IsNewObj(res2)) delete arg2;
  return NULL;
}


SWIGINTERN PyObject *_wrap_PresenceStatus_statusText_get(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::PresenceStatus *arg1 = (pj::PresenceStatus *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  pj::string *result = 0 ;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__PresenceStatus, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "PresenceStatus_statusText_get" "', argument " "1"" of type '" "pj::PresenceStatus *""'"); 
  }
  arg1 = reinterpret_cast< pj::PresenceStatus * >(argp1);
  result = (pj::string *) & ((arg1)->statusText);
  resultobj = SWIG_From_std_string(static_cast< std::string >(*result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_PresenceStatus_activity_set(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::PresenceStatus *arg1 = (pj::PresenceStatus *) 0 ;
  pjrpid_activity arg2 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  int val2 ;
  int ecode2 = 0 ;
  PyObject *swig_obj[2] ;
  
  if (!SWIG_Python_UnpackTuple(args, "PresenceStatus_activity_set", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__PresenceStatus, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "PresenceStatus_activity_set" "', argument " "1"" of type '" "pj::PresenceStatus *""'"); 
  }
  arg1 = reinterpret_cast< pj::PresenceStatus * >(argp1);
  ecode2 = SWIG_AsVal_int(swig_obj[1], &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "PresenceStatus_activity_set" "', argument " "2"" of type '" "pjrpid_activity""'");
  } 
  arg2 = static_cast< pjrpid_activity >(val2);
  if (arg1) (arg1)->activity = arg2;
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_PresenceStatus_activity_get(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::PresenceStatus *arg1 = (pj::PresenceStatus *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  pjrpid_activity result;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__PresenceStatus, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "PresenceStatus_activity_get" "', argument " "1"" of type '" "pj::PresenceStatus *""'"); 
  }
  arg1 = reinterpret_cast< pj::PresenceStatus * >(argp1);
  result = (pjrpid_activity) ((arg1)->activity);
  resultobj = SWIG_From_int(static_cast< int >(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_PresenceStatus_note_set(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::PresenceStatus *arg1 = (pj::PresenceStatus *) 0 ;
  pj::string *arg2 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  int res2 = SWIG_OLDOBJ ;
  PyObject *swig_obj[2] ;
  
  if (!SWIG_Python_UnpackTuple(args, "PresenceStatus_note_set", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__PresenceStatus, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "PresenceStatus_note_set" "', argument " "1"" of type '" "pj::PresenceStatus *""'"); 
  }
  arg1 = reinterpret_cast< pj::PresenceStatus * >(argp1);
  {
    std::string *ptr = (std::string *)0;
    res2 = SWIG_AsPtr_std_string(swig_obj[1], &ptr);
    if (!SWIG_IsOK(res2)) {
      SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "PresenceStatus_note_set" "', argument " "2"" of type '" "pj::string const &""'"); 
    }
    if (!ptr) {
      SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "PresenceStatus_note_set" "', argument " "2"" of type '" "pj::string const &""'"); 
    }
    arg2 = ptr;
  }
  if (arg1) (arg1)->note = *arg2;
  resultobj = SWIG_Py_Void();
  if (SWIG_IsNewObj(res2)) delete arg2;
  return resultobj;
fail:
  if (SWIG_IsNewObj(res2)) delete arg2;
  return NULL;
}


SWIGINTERN PyObject *_wrap_PresenceStatus_note_get(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::PresenceStatus *arg1 = (pj::PresenceStatus *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  pj::string *result = 0 ;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__PresenceStatus, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "PresenceStatus_note_get" "', argument " "1"" of type '" "pj::PresenceStatus *""'"); 
  }
  arg1 = reinterpret_cast< pj::PresenceStatus * >(argp1);
  result = (pj::string *) & ((arg1)->note);
  resultobj = SWIG_From_std_string(static_cast< std::string >(*result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_PresenceStatus_rpidId_set(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::PresenceStatus *arg1 = (pj::PresenceStatus *) 0 ;
  pj::string *arg2 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  int res2 = SWIG_OLDOBJ ;
  PyObject *swig_obj[2] ;
  
  if (!SWIG_Python_UnpackTuple(args, "PresenceStatus_rpidId_set", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__PresenceStatus, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "PresenceStatus_rpidId_set" "', argument " "1"" of type '" "pj::PresenceStatus *""'"); 
  }
  arg1 = reinterpret_cast< pj::PresenceStatus * >(argp1);
  {
    std::string *ptr = (std::string *)0;
    res2 = SWIG_AsPtr_std_string(swig_obj[1], &ptr);
    if (!SWIG_IsOK(res2)) {
      SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "PresenceStatus_rpidId_set" "', argument " "2"" of type '" "pj::string const &""'"); 
    }
    if (!ptr) {
      SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "PresenceStatus_rpidId_set" "', argument " "2"" of type '" "pj::string const &""'"); 
    }
    arg2 = ptr;
  }
  if (arg1) (arg1)->rpidId = *arg2;
  resultobj = SWIG_Py_Void();
  if (SWIG_IsNewObj(res2)) delete arg2;
  return resultobj;
fail:
  if (SWIG_IsNewObj(res2)) delete arg2;
  return NULL;
}


SWIGINTERN PyObject *_wrap_PresenceStatus_rpidId_get(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::PresenceStatus *arg1 = (pj::PresenceStatus *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  pj::string *result = 0 ;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__PresenceStatus, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "PresenceStatus_rpidId_get" "', argument " "1"" of type '" "pj::PresenceStatus *""'"); 
  }
  arg1 = reinterpret_cast< pj::PresenceStatus * >(argp1);
  result = (pj::string *) & ((arg1)->rpidId);
  resultobj = SWIG_From_std_string(static_cast< std::string >(*result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_new_PresenceStatus(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::PresenceStatus *result = 0 ;
  
  if (!SWIG_Python_UnpackTuple(args, "new_PresenceStatus", 0, 0, 0)) SWIG_fail;
  result = (pj::PresenceStatus *)new pj::PresenceStatus();
  resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(result), SWIGTYPE_p_pj__PresenceStatus, SWIG_POINTER_NEW |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_delete_PresenceStatus(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::PresenceStatus *arg1 = (pj::PresenceStatus *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__PresenceStatus, SWIG_POINTER_DISOWN |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "delete_PresenceStatus" "', argument " "1"" of type '" "pj::PresenceStatus *""'"); 
  }
  arg1 = reinterpret_cast< pj::PresenceStatus * >(argp1);
  delete arg1;
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *PresenceStatus_swigregister(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *obj;
  if (!SWIG_Python_UnpackTuple(args, "swigregister", 1, 1, &obj)) return NULL;
  SWIG_TypeNewClientData(SWIGTYPE_p_pj__PresenceStatus, SWIG_NewClientData(obj));
  return SWIG_Py_Void();
}

SWIGINTERN PyObject *PresenceStatus_swiginit(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  return SWIG_Python_InitShadowInstance(args);
}

SWIGINTERN PyObject *_wrap_BuddyConfig_uri_set(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::BuddyConfig *arg1 = (pj::BuddyConfig *) 0 ;
  pj::string *arg2 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  int res2 = SWIG_OLDOBJ ;
  PyObject *swig_obj[2] ;
  
  if (!SWIG_Python_UnpackTuple(args, "BuddyConfig_uri_set", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__BuddyConfig, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "BuddyConfig_uri_set" "', argument " "1"" of type '" "pj::BuddyConfig *""'"); 
  }
  arg1 = reinterpret_cast< pj::BuddyConfig * >(argp1);
  {
    std::string *ptr = (std::string *)0;
    res2 = SWIG_AsPtr_std_string(swig_obj[1], &ptr);
    if (!SWIG_IsOK(res2)) {
      SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "BuddyConfig_uri_set" "', argument " "2"" of type '" "pj::string const &""'"); 
    }
    if (!ptr) {
      SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "BuddyConfig_uri_set" "', argument " "2"" of type '" "pj::string const &""'"); 
    }
    arg2 = ptr;
  }
  if (arg1) (arg1)->uri = *arg2;
  resultobj = SWIG_Py_Void();
  if (SWIG_IsNewObj(res2)) delete arg2;
  return resultobj;
fail:
  if (SWIG_IsNewObj(res2)) delete arg2;
  return NULL;
}


SWIGINTERN PyObject *_wrap_BuddyConfig_uri_get(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::BuddyConfig *arg1 = (pj::BuddyConfig *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  pj::string *result = 0 ;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__BuddyConfig, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "BuddyConfig_uri_get" "', argument " "1"" of type '" "pj::BuddyConfig *""'"); 
  }
  arg1 = reinterpret_cast< pj::BuddyConfig * >(argp1);
  result = (pj::string *) & ((arg1)->uri);
  resultobj = SWIG_From_std_string(static_cast< std::string >(*result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_BuddyConfig_subscribe_set(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::BuddyConfig *arg1 = (pj::BuddyConfig *) 0 ;
  bool arg2 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  bool val2 ;
  int ecode2 = 0 ;
  PyObject *swig_obj[2] ;
  
  if (!SWIG_Python_UnpackTuple(args, "BuddyConfig_subscribe_set", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__BuddyConfig, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "BuddyConfig_subscribe_set" "', argument " "1"" of type '" "pj::BuddyConfig *""'"); 
  }
  arg1 = reinterpret_cast< pj::BuddyConfig * >(argp1);
  ecode2 = SWIG_AsVal_bool(swig_obj[1], &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "BuddyConfig_subscribe_set" "', argument " "2"" of type '" "bool""'");
  } 
  arg2 = static_cast< bool >(val2);
  if (arg1) (arg1)->subscribe = arg2;
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_BuddyConfig_subscribe_get(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::BuddyConfig *arg1 = (pj::BuddyConfig *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  bool result;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__BuddyConfig, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "BuddyConfig_subscribe_get" "', argument " "1"" of type '" "pj::BuddyConfig *""'"); 
  }
  arg1 = reinterpret_cast< pj::BuddyConfig * >(argp1);
  result = (bool) ((arg1)->subscribe);
  resultobj = SWIG_From_bool(static_cast< bool >(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_BuddyConfig_readObject(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::BuddyConfig *arg1 = (pj::BuddyConfig *) 0 ;
  pj::ContainerNode *arg2 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  void *argp2 = 0 ;
  int res2 = 0 ;
  PyObject *swig_obj[2] ;
  
  if (!SWIG_Python_UnpackTuple(args, "BuddyConfig_readObject", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__BuddyConfig, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "BuddyConfig_readObject" "', argument " "1"" of type '" "pj::BuddyConfig *""'"); 
  }
  arg1 = reinterpret_cast< pj::BuddyConfig * >(argp1);
  res2 = SWIG_ConvertPtr(swig_obj[1], &argp2, SWIGTYPE_p_pj__ContainerNode,  0  | 0);
  if (!SWIG_IsOK(res2)) {
    SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "BuddyConfig_readObject" "', argument " "2"" of type '" "pj::ContainerNode const &""'"); 
  }
  if (!argp2) {
    SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "BuddyConfig_readObject" "', argument " "2"" of type '" "pj::ContainerNode const &""'"); 
  }
  arg2 = reinterpret_cast< pj::ContainerNode * >(argp2);
  try {
    (arg1)->readObject((pj::ContainerNode const &)*arg2);
  } catch(pj::Error &_e) {
    SWIG_Python_Raise(SWIG_NewPointerObj((new pj::Error(static_cast< const pj::Error& >(_e))),SWIGTYPE_p_pj__Error,SWIG_POINTER_OWN), "pj::Error", SWIGTYPE_p_pj__Error); SWIG_fail;
  }
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_BuddyConfig_writeObject(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::BuddyConfig *arg1 = (pj::BuddyConfig *) 0 ;
  pj::ContainerNode *arg2 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  void *argp2 = 0 ;
  int res2 = 0 ;
  PyObject *swig_obj[2] ;
  
  if (!SWIG_Python_UnpackTuple(args, "BuddyConfig_writeObject", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__BuddyConfig, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "BuddyConfig_writeObject" "', argument " "1"" of type '" "pj::BuddyConfig const *""'"); 
  }
  arg1 = reinterpret_cast< pj::BuddyConfig * >(argp1);
  res2 = SWIG_ConvertPtr(swig_obj[1], &argp2, SWIGTYPE_p_pj__ContainerNode,  0 );
  if (!SWIG_IsOK(res2)) {
    SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "BuddyConfig_writeObject" "', argument " "2"" of type '" "pj::ContainerNode &""'"); 
  }
  if (!argp2) {
    SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "BuddyConfig_writeObject" "', argument " "2"" of type '" "pj::ContainerNode &""'"); 
  }
  arg2 = reinterpret_cast< pj::ContainerNode * >(argp2);
  try {
    ((pj::BuddyConfig const *)arg1)->writeObject(*arg2);
  } catch(pj::Error &_e) {
    SWIG_Python_Raise(SWIG_NewPointerObj((new pj::Error(static_cast< const pj::Error& >(_e))),SWIGTYPE_p_pj__Error,SWIG_POINTER_OWN), "pj::Error", SWIGTYPE_p_pj__Error); SWIG_fail;
  }
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_new_BuddyConfig(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::BuddyConfig *result = 0 ;
  
  if (!SWIG_Python_UnpackTuple(args, "new_BuddyConfig", 0, 0, 0)) SWIG_fail;
  result = (pj::BuddyConfig *)new pj::BuddyConfig();
  resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(result), SWIGTYPE_p_pj__BuddyConfig, SWIG_POINTER_NEW |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_delete_BuddyConfig(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::BuddyConfig *arg1 = (pj::BuddyConfig *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__BuddyConfig, SWIG_POINTER_DISOWN |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "delete_BuddyConfig" "', argument " "1"" of type '" "pj::BuddyConfig *""'"); 
  }
  arg1 = reinterpret_cast< pj::BuddyConfig * >(argp1);
  delete arg1;
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *BuddyConfig_swigregister(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *obj;
  if (!SWIG_Python_UnpackTuple(args, "swigregister", 1, 1, &obj)) return NULL;
  SWIG_TypeNewClientData(SWIGTYPE_p_pj__BuddyConfig, SWIG_NewClientData(obj));
  return SWIG_Py_Void();
}

SWIGINTERN PyObject *BuddyConfig_swiginit(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  return SWIG_Python_InitShadowInstance(args);
}

SWIGINTERN PyObject *_wrap_BuddyInfo_uri_set(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::BuddyInfo *arg1 = (pj::BuddyInfo *) 0 ;
  pj::string *arg2 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  int res2 = SWIG_OLDOBJ ;
  PyObject *swig_obj[2] ;
  
  if (!SWIG_Python_UnpackTuple(args, "BuddyInfo_uri_set", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__BuddyInfo, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "BuddyInfo_uri_set" "', argument " "1"" of type '" "pj::BuddyInfo *""'"); 
  }
  arg1 = reinterpret_cast< pj::BuddyInfo * >(argp1);
  {
    std::string *ptr = (std::string *)0;
    res2 = SWIG_AsPtr_std_string(swig_obj[1], &ptr);
    if (!SWIG_IsOK(res2)) {
      SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "BuddyInfo_uri_set" "', argument " "2"" of type '" "pj::string const &""'"); 
    }
    if (!ptr) {
      SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "BuddyInfo_uri_set" "', argument " "2"" of type '" "pj::string const &""'"); 
    }
    arg2 = ptr;
  }
  if (arg1) (arg1)->uri = *arg2;
  resultobj = SWIG_Py_Void();
  if (SWIG_IsNewObj(res2)) delete arg2;
  return resultobj;
fail:
  if (SWIG_IsNewObj(res2)) delete arg2;
  return NULL;
}


SWIGINTERN PyObject *_wrap_BuddyInfo_uri_get(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::BuddyInfo *arg1 = (pj::BuddyInfo *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  pj::string *result = 0 ;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__BuddyInfo, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "BuddyInfo_uri_get" "', argument " "1"" of type '" "pj::BuddyInfo *""'"); 
  }
  arg1 = reinterpret_cast< pj::BuddyInfo * >(argp1);
  result = (pj::string *) & ((arg1)->uri);
  resultobj = SWIG_From_std_string(static_cast< std::string >(*result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_BuddyInfo_contact_set(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::BuddyInfo *arg1 = (pj::BuddyInfo *) 0 ;
  pj::string *arg2 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  int res2 = SWIG_OLDOBJ ;
  PyObject *swig_obj[2] ;
  
  if (!SWIG_Python_UnpackTuple(args, "BuddyInfo_contact_set", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__BuddyInfo, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "BuddyInfo_contact_set" "', argument " "1"" of type '" "pj::BuddyInfo *""'"); 
  }
  arg1 = reinterpret_cast< pj::BuddyInfo * >(argp1);
  {
    std::string *ptr = (std::string *)0;
    res2 = SWIG_AsPtr_std_string(swig_obj[1], &ptr);
    if (!SWIG_IsOK(res2)) {
      SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "BuddyInfo_contact_set" "', argument " "2"" of type '" "pj::string const &""'"); 
    }
    if (!ptr) {
      SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "BuddyInfo_contact_set" "', argument " "2"" of type '" "pj::string const &""'"); 
    }
    arg2 = ptr;
  }
  if (arg1) (arg1)->contact = *arg2;
  resultobj = SWIG_Py_Void();
  if (SWIG_IsNewObj(res2)) delete arg2;
  return resultobj;
fail:
  if (SWIG_IsNewObj(res2)) delete arg2;
  return NULL;
}


SWIGINTERN PyObject *_wrap_BuddyInfo_contact_get(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::BuddyInfo *arg1 = (pj::BuddyInfo *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  pj::string *result = 0 ;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__BuddyInfo, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "BuddyInfo_contact_get" "', argument " "1"" of type '" "pj::BuddyInfo *""'"); 
  }
  arg1 = reinterpret_cast< pj::BuddyInfo * >(argp1);
  result = (pj::string *) & ((arg1)->contact);
  resultobj = SWIG_From_std_string(static_cast< std::string >(*result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_BuddyInfo_presMonitorEnabled_set(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::BuddyInfo *arg1 = (pj::BuddyInfo *) 0 ;
  bool arg2 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  bool val2 ;
  int ecode2 = 0 ;
  PyObject *swig_obj[2] ;
  
  if (!SWIG_Python_UnpackTuple(args, "BuddyInfo_presMonitorEnabled_set", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__BuddyInfo, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "BuddyInfo_presMonitorEnabled_set" "', argument " "1"" of type '" "pj::BuddyInfo *""'"); 
  }
  arg1 = reinterpret_cast< pj::BuddyInfo * >(argp1);
  ecode2 = SWIG_AsVal_bool(swig_obj[1], &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "BuddyInfo_presMonitorEnabled_set" "', argument " "2"" of type '" "bool""'");
  } 
  arg2 = static_cast< bool >(val2);
  if (arg1) (arg1)->presMonitorEnabled = arg2;
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_BuddyInfo_presMonitorEnabled_get(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::BuddyInfo *arg1 = (pj::BuddyInfo *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  bool result;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__BuddyInfo, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "BuddyInfo_presMonitorEnabled_get" "', argument " "1"" of type '" "pj::BuddyInfo *""'"); 
  }
  arg1 = reinterpret_cast< pj::BuddyInfo * >(argp1);
  result = (bool) ((arg1)->presMonitorEnabled);
  resultobj = SWIG_From_bool(static_cast< bool >(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_BuddyInfo_subState_set(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::BuddyInfo *arg1 = (pj::BuddyInfo *) 0 ;
  pjsip_evsub_state arg2 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  int val2 ;
  int ecode2 = 0 ;
  PyObject *swig_obj[2] ;
  
  if (!SWIG_Python_UnpackTuple(args, "BuddyInfo_subState_set", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__BuddyInfo, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "BuddyInfo_subState_set" "', argument " "1"" of type '" "pj::BuddyInfo *""'"); 
  }
  arg1 = reinterpret_cast< pj::BuddyInfo * >(argp1);
  ecode2 = SWIG_AsVal_int(swig_obj[1], &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "BuddyInfo_subState_set" "', argument " "2"" of type '" "pjsip_evsub_state""'");
  } 
  arg2 = static_cast< pjsip_evsub_state >(val2);
  if (arg1) (arg1)->subState = arg2;
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_BuddyInfo_subState_get(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::BuddyInfo *arg1 = (pj::BuddyInfo *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  pjsip_evsub_state result;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__BuddyInfo, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "BuddyInfo_subState_get" "', argument " "1"" of type '" "pj::BuddyInfo *""'"); 
  }
  arg1 = reinterpret_cast< pj::BuddyInfo * >(argp1);
  result = (pjsip_evsub_state) ((arg1)->subState);
  resultobj = SWIG_From_int(static_cast< int >(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_BuddyInfo_subStateName_set(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::BuddyInfo *arg1 = (pj::BuddyInfo *) 0 ;
  pj::string *arg2 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  int res2 = SWIG_OLDOBJ ;
  PyObject *swig_obj[2] ;
  
  if (!SWIG_Python_UnpackTuple(args, "BuddyInfo_subStateName_set", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__BuddyInfo, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "BuddyInfo_subStateName_set" "', argument " "1"" of type '" "pj::BuddyInfo *""'"); 
  }
  arg1 = reinterpret_cast< pj::BuddyInfo * >(argp1);
  {
    std::string *ptr = (std::string *)0;
    res2 = SWIG_AsPtr_std_string(swig_obj[1], &ptr);
    if (!SWIG_IsOK(res2)) {
      SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "BuddyInfo_subStateName_set" "', argument " "2"" of type '" "pj::string const &""'"); 
    }
    if (!ptr) {
      SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "BuddyInfo_subStateName_set" "', argument " "2"" of type '" "pj::string const &""'"); 
    }
    arg2 = ptr;
  }
  if (arg1) (arg1)->subStateName = *arg2;
  resultobj = SWIG_Py_Void();
  if (SWIG_IsNewObj(res2)) delete arg2;
  return resultobj;
fail:
  if (SWIG_IsNewObj(res2)) delete arg2;
  return NULL;
}


SWIGINTERN PyObject *_wrap_BuddyInfo_subStateName_get(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::BuddyInfo *arg1 = (pj::BuddyInfo *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  pj::string *result = 0 ;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__BuddyInfo, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "BuddyInfo_subStateName_get" "', argument " "1"" of type '" "pj::BuddyInfo *""'"); 
  }
  arg1 = reinterpret_cast< pj::BuddyInfo * >(argp1);
  result = (pj::string *) & ((arg1)->subStateName);
  resultobj = SWIG_From_std_string(static_cast< std::string >(*result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_BuddyInfo_subTermCode_set(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::BuddyInfo *arg1 = (pj::BuddyInfo *) 0 ;
  pjsip_status_code arg2 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  int val2 ;
  int ecode2 = 0 ;
  PyObject *swig_obj[2] ;
  
  if (!SWIG_Python_UnpackTuple(args, "BuddyInfo_subTermCode_set", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__BuddyInfo, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "BuddyInfo_subTermCode_set" "', argument " "1"" of type '" "pj::BuddyInfo *""'"); 
  }
  arg1 = reinterpret_cast< pj::BuddyInfo * >(argp1);
  ecode2 = SWIG_AsVal_int(swig_obj[1], &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "BuddyInfo_subTermCode_set" "', argument " "2"" of type '" "pjsip_status_code""'");
  } 
  arg2 = static_cast< pjsip_status_code >(val2);
  if (arg1) (arg1)->subTermCode = arg2;
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_BuddyInfo_subTermCode_get(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::BuddyInfo *arg1 = (pj::BuddyInfo *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  pjsip_status_code result;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__BuddyInfo, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "BuddyInfo_subTermCode_get" "', argument " "1"" of type '" "pj::BuddyInfo *""'"); 
  }
  arg1 = reinterpret_cast< pj::BuddyInfo * >(argp1);
  result = (pjsip_status_code) ((arg1)->subTermCode);
  resultobj = SWIG_From_int(static_cast< int >(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_BuddyInfo_subTermReason_set(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::BuddyInfo *arg1 = (pj::BuddyInfo *) 0 ;
  pj::string *arg2 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  int res2 = SWIG_OLDOBJ ;
  PyObject *swig_obj[2] ;
  
  if (!SWIG_Python_UnpackTuple(args, "BuddyInfo_subTermReason_set", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__BuddyInfo, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "BuddyInfo_subTermReason_set" "', argument " "1"" of type '" "pj::BuddyInfo *""'"); 
  }
  arg1 = reinterpret_cast< pj::BuddyInfo * >(argp1);
  {
    std::string *ptr = (std::string *)0;
    res2 = SWIG_AsPtr_std_string(swig_obj[1], &ptr);
    if (!SWIG_IsOK(res2)) {
      SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "BuddyInfo_subTermReason_set" "', argument " "2"" of type '" "pj::string const &""'"); 
    }
    if (!ptr) {
      SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "BuddyInfo_subTermReason_set" "', argument " "2"" of type '" "pj::string const &""'"); 
    }
    arg2 = ptr;
  }
  if (arg1) (arg1)->subTermReason = *arg2;
  resultobj = SWIG_Py_Void();
  if (SWIG_IsNewObj(res2)) delete arg2;
  return resultobj;
fail:
  if (SWIG_IsNewObj(res2)) delete arg2;
  return NULL;
}


SWIGINTERN PyObject *_wrap_BuddyInfo_subTermReason_get(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::BuddyInfo *arg1 = (pj::BuddyInfo *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  pj::string *result = 0 ;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__BuddyInfo, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "BuddyInfo_subTermReason_get" "', argument " "1"" of type '" "pj::BuddyInfo *""'"); 
  }
  arg1 = reinterpret_cast< pj::BuddyInfo * >(argp1);
  result = (pj::string *) & ((arg1)->subTermReason);
  resultobj = SWIG_From_std_string(static_cast< std::string >(*result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_BuddyInfo_presStatus_set(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::BuddyInfo *arg1 = (pj::BuddyInfo *) 0 ;
  pj::PresenceStatus *arg2 = (pj::PresenceStatus *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  void *argp2 = 0 ;
  int res2 = 0 ;
  PyObject *swig_obj[2] ;
  
  if (!SWIG_Python_UnpackTuple(args, "BuddyInfo_presStatus_set", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__BuddyInfo, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "BuddyInfo_presStatus_set" "', argument " "1"" of type '" "pj::BuddyInfo *""'"); 
  }
  arg1 = reinterpret_cast< pj::BuddyInfo * >(argp1);
  res2 = SWIG_ConvertPtr(swig_obj[1], &argp2,SWIGTYPE_p_pj__PresenceStatus, 0 |  0 );
  if (!SWIG_IsOK(res2)) {
    SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "BuddyInfo_presStatus_set" "', argument " "2"" of type '" "pj::PresenceStatus *""'"); 
  }
  arg2 = reinterpret_cast< pj::PresenceStatus * >(argp2);
  if (arg1) (arg1)->presStatus = *arg2;
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_BuddyInfo_presStatus_get(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::BuddyInfo *arg1 = (pj::BuddyInfo *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  pj::PresenceStatus *result = 0 ;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__BuddyInfo, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "BuddyInfo_presStatus_get" "', argument " "1"" of type '" "pj::BuddyInfo *""'"); 
  }
  arg1 = reinterpret_cast< pj::BuddyInfo * >(argp1);
  result = (pj::PresenceStatus *)& ((arg1)->presStatus);
  resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(result), SWIGTYPE_p_pj__PresenceStatus, 0 |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_new_BuddyInfo(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::BuddyInfo *result = 0 ;
  
  if (!SWIG_Python_UnpackTuple(args, "new_BuddyInfo", 0, 0, 0)) SWIG_fail;
  result = (pj::BuddyInfo *)new pj::BuddyInfo();
  resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(result), SWIGTYPE_p_pj__BuddyInfo, SWIG_POINTER_NEW |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_delete_BuddyInfo(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::BuddyInfo *arg1 = (pj::BuddyInfo *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__BuddyInfo, SWIG_POINTER_DISOWN |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "delete_BuddyInfo" "', argument " "1"" of type '" "pj::BuddyInfo *""'"); 
  }
  arg1 = reinterpret_cast< pj::BuddyInfo * >(argp1);
  delete arg1;
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *BuddyInfo_swigregister(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *obj;
  if (!SWIG_Python_UnpackTuple(args, "swigregister", 1, 1, &obj)) return NULL;
  SWIG_TypeNewClientData(SWIGTYPE_p_pj__BuddyInfo, SWIG_NewClientData(obj));
  return SWIG_Py_Void();
}

SWIGINTERN PyObject *BuddyInfo_swiginit(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  return SWIG_Python_InitShadowInstance(args);
}

SWIGINTERN PyObject *_wrap_OnBuddyEvSubStateParam_e_set(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::OnBuddyEvSubStateParam *arg1 = (pj::OnBuddyEvSubStateParam *) 0 ;
  pj::SipEvent *arg2 = (pj::SipEvent *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  void *argp2 = 0 ;
  int res2 = 0 ;
  PyObject *swig_obj[2] ;
  
  if (!SWIG_Python_UnpackTuple(args, "OnBuddyEvSubStateParam_e_set", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__OnBuddyEvSubStateParam, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "OnBuddyEvSubStateParam_e_set" "', argument " "1"" of type '" "pj::OnBuddyEvSubStateParam *""'"); 
  }
  arg1 = reinterpret_cast< pj::OnBuddyEvSubStateParam * >(argp1);
  res2 = SWIG_ConvertPtr(swig_obj[1], &argp2,SWIGTYPE_p_pj__SipEvent, 0 |  0 );
  if (!SWIG_IsOK(res2)) {
    SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "OnBuddyEvSubStateParam_e_set" "', argument " "2"" of type '" "pj::SipEvent *""'"); 
  }
  arg2 = reinterpret_cast< pj::SipEvent * >(argp2);
  if (arg1) (arg1)->e = *arg2;
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_OnBuddyEvSubStateParam_e_get(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::OnBuddyEvSubStateParam *arg1 = (pj::OnBuddyEvSubStateParam *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  pj::SipEvent *result = 0 ;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__OnBuddyEvSubStateParam, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "OnBuddyEvSubStateParam_e_get" "', argument " "1"" of type '" "pj::OnBuddyEvSubStateParam *""'"); 
  }
  arg1 = reinterpret_cast< pj::OnBuddyEvSubStateParam * >(argp1);
  result = (pj::SipEvent *)& ((arg1)->e);
  resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(result), SWIGTYPE_p_pj__SipEvent, 0 |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_new_OnBuddyEvSubStateParam(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::OnBuddyEvSubStateParam *result = 0 ;
  
  if (!SWIG_Python_UnpackTuple(args, "new_OnBuddyEvSubStateParam", 0, 0, 0)) SWIG_fail;
  result = (pj::OnBuddyEvSubStateParam *)new pj::OnBuddyEvSubStateParam();
  resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(result), SWIGTYPE_p_pj__OnBuddyEvSubStateParam, SWIG_POINTER_NEW |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_delete_OnBuddyEvSubStateParam(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::OnBuddyEvSubStateParam *arg1 = (pj::OnBuddyEvSubStateParam *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__OnBuddyEvSubStateParam, SWIG_POINTER_DISOWN |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "delete_OnBuddyEvSubStateParam" "', argument " "1"" of type '" "pj::OnBuddyEvSubStateParam *""'"); 
  }
  arg1 = reinterpret_cast< pj::OnBuddyEvSubStateParam * >(argp1);
  delete arg1;
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *OnBuddyEvSubStateParam_swigregister(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *obj;
  if (!SWIG_Python_UnpackTuple(args, "swigregister", 1, 1, &obj)) return NULL;
  SWIG_TypeNewClientData(SWIGTYPE_p_pj__OnBuddyEvSubStateParam, SWIG_NewClientData(obj));
  return SWIG_Py_Void();
}

SWIGINTERN PyObject *OnBuddyEvSubStateParam_swiginit(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  return SWIG_Python_InitShadowInstance(args);
}

SWIGINTERN PyObject *_wrap_new_Buddy(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  PyObject *arg1 = (PyObject *) 0 ;
  PyObject *swig_obj[1] ;
  pj::Buddy *result = 0 ;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  arg1 = swig_obj[0];
  if ( arg1 != Py_None ) {
    /* subclassed */
    result = (pj::Buddy *)new SwigDirector_Buddy(arg1); 
  } else {
    result = (pj::Buddy *)new pj::Buddy(); 
  }
  
  resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(result), SWIGTYPE_p_pj__Buddy, SWIG_POINTER_NEW |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_delete_Buddy(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::Buddy *arg1 = (pj::Buddy *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__Buddy, SWIG_POINTER_DISOWN |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "delete_Buddy" "', argument " "1"" of type '" "pj::Buddy *""'"); 
  }
  arg1 = reinterpret_cast< pj::Buddy * >(argp1);
  delete arg1;
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_Buddy_create(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::Buddy *arg1 = (pj::Buddy *) 0 ;
  pj::Account *arg2 = 0 ;
  pj::BuddyConfig *arg3 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  void *argp2 = 0 ;
  int res2 = 0 ;
  void *argp3 = 0 ;
  int res3 = 0 ;
  PyObject *swig_obj[3] ;
  
  if (!SWIG_Python_UnpackTuple(args, "Buddy_create", 3, 3, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__Buddy, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "Buddy_create" "', argument " "1"" of type '" "pj::Buddy *""'"); 
  }
  arg1 = reinterpret_cast< pj::Buddy * >(argp1);
  res2 = SWIG_ConvertPtr(swig_obj[1], &argp2, SWIGTYPE_p_pj__Account,  0 );
  if (!SWIG_IsOK(res2)) {
    SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "Buddy_create" "', argument " "2"" of type '" "pj::Account &""'"); 
  }
  if (!argp2) {
    SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "Buddy_create" "', argument " "2"" of type '" "pj::Account &""'"); 
  }
  arg2 = reinterpret_cast< pj::Account * >(argp2);
  res3 = SWIG_ConvertPtr(swig_obj[2], &argp3, SWIGTYPE_p_pj__BuddyConfig,  0  | 0);
  if (!SWIG_IsOK(res3)) {
    SWIG_exception_fail(SWIG_ArgError(res3), "in method '" "Buddy_create" "', argument " "3"" of type '" "pj::BuddyConfig const &""'"); 
  }
  if (!argp3) {
    SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "Buddy_create" "', argument " "3"" of type '" "pj::BuddyConfig const &""'"); 
  }
  arg3 = reinterpret_cast< pj::BuddyConfig * >(argp3);
  try {
    (arg1)->create(*arg2,(pj::BuddyConfig const &)*arg3);
  } catch(pj::Error &_e) {
    SWIG_Python_Raise(SWIG_NewPointerObj((new pj::Error(static_cast< const pj::Error& >(_e))),SWIGTYPE_p_pj__Error,SWIG_POINTER_OWN), "pj::Error", SWIGTYPE_p_pj__Error); SWIG_fail;
  }
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_Buddy_isValid(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::Buddy *arg1 = (pj::Buddy *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  bool result;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__Buddy, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "Buddy_isValid" "', argument " "1"" of type '" "pj::Buddy const *""'"); 
  }
  arg1 = reinterpret_cast< pj::Buddy * >(argp1);
  result = (bool)((pj::Buddy const *)arg1)->isValid();
  resultobj = SWIG_From_bool(static_cast< bool >(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_Buddy_getId(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::Buddy *arg1 = (pj::Buddy *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  int result;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__Buddy, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "Buddy_getId" "', argument " "1"" of type '" "pj::Buddy const *""'"); 
  }
  arg1 = reinterpret_cast< pj::Buddy * >(argp1);
  result = (int)((pj::Buddy const *)arg1)->getId();
  resultobj = SWIG_From_int(static_cast< int >(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_Buddy_getInfo(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::Buddy *arg1 = (pj::Buddy *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  pj::BuddyInfo result;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__Buddy, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "Buddy_getInfo" "', argument " "1"" of type '" "pj::Buddy const *""'"); 
  }
  arg1 = reinterpret_cast< pj::Buddy * >(argp1);
  try {
    result = ((pj::Buddy const *)arg1)->getInfo();
  } catch(pj::Error &_e) {
    SWIG_Python_Raise(SWIG_NewPointerObj((new pj::Error(static_cast< const pj::Error& >(_e))),SWIGTYPE_p_pj__Error,SWIG_POINTER_OWN), "pj::Error", SWIGTYPE_p_pj__Error); SWIG_fail;
  }
  resultobj = SWIG_NewPointerObj((new pj::BuddyInfo(static_cast< const pj::BuddyInfo& >(result))), SWIGTYPE_p_pj__BuddyInfo, SWIG_POINTER_OWN |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_Buddy_subscribePresence(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::Buddy *arg1 = (pj::Buddy *) 0 ;
  bool arg2 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  bool val2 ;
  int ecode2 = 0 ;
  PyObject *swig_obj[2] ;
  
  if (!SWIG_Python_UnpackTuple(args, "Buddy_subscribePresence", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__Buddy, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "Buddy_subscribePresence" "', argument " "1"" of type '" "pj::Buddy *""'"); 
  }
  arg1 = reinterpret_cast< pj::Buddy * >(argp1);
  ecode2 = SWIG_AsVal_bool(swig_obj[1], &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "Buddy_subscribePresence" "', argument " "2"" of type '" "bool""'");
  } 
  arg2 = static_cast< bool >(val2);
  try {
    (arg1)->subscribePresence(arg2);
  } catch(pj::Error &_e) {
    SWIG_Python_Raise(SWIG_NewPointerObj((new pj::Error(static_cast< const pj::Error& >(_e))),SWIGTYPE_p_pj__Error,SWIG_POINTER_OWN), "pj::Error", SWIGTYPE_p_pj__Error); SWIG_fail;
  }
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_Buddy_updatePresence(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::Buddy *arg1 = (pj::Buddy *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__Buddy, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "Buddy_updatePresence" "', argument " "1"" of type '" "pj::Buddy *""'"); 
  }
  arg1 = reinterpret_cast< pj::Buddy * >(argp1);
  try {
    (arg1)->updatePresence();
  } catch(pj::Error &_e) {
    SWIG_Python_Raise(SWIG_NewPointerObj((new pj::Error(static_cast< const pj::Error& >(_e))),SWIGTYPE_p_pj__Error,SWIG_POINTER_OWN), "pj::Error", SWIGTYPE_p_pj__Error); SWIG_fail;
  }
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_Buddy_sendInstantMessage(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::Buddy *arg1 = (pj::Buddy *) 0 ;
  pj::SendInstantMessageParam *arg2 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  void *argp2 = 0 ;
  int res2 = 0 ;
  PyObject *swig_obj[2] ;
  
  if (!SWIG_Python_UnpackTuple(args, "Buddy_sendInstantMessage", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__Buddy, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "Buddy_sendInstantMessage" "', argument " "1"" of type '" "pj::Buddy *""'"); 
  }
  arg1 = reinterpret_cast< pj::Buddy * >(argp1);
  res2 = SWIG_ConvertPtr(swig_obj[1], &argp2, SWIGTYPE_p_pj__SendInstantMessageParam,  0  | 0);
  if (!SWIG_IsOK(res2)) {
    SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "Buddy_sendInstantMessage" "', argument " "2"" of type '" "pj::SendInstantMessageParam const &""'"); 
  }
  if (!argp2) {
    SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "Buddy_sendInstantMessage" "', argument " "2"" of type '" "pj::SendInstantMessageParam const &""'"); 
  }
  arg2 = reinterpret_cast< pj::SendInstantMessageParam * >(argp2);
  try {
    (arg1)->sendInstantMessage((pj::SendInstantMessageParam const &)*arg2);
  } catch(pj::Error &_e) {
    SWIG_Python_Raise(SWIG_NewPointerObj((new pj::Error(static_cast< const pj::Error& >(_e))),SWIGTYPE_p_pj__Error,SWIG_POINTER_OWN), "pj::Error", SWIGTYPE_p_pj__Error); SWIG_fail;
  }
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_Buddy_sendTypingIndication(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::Buddy *arg1 = (pj::Buddy *) 0 ;
  pj::SendTypingIndicationParam *arg2 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  void *argp2 = 0 ;
  int res2 = 0 ;
  PyObject *swig_obj[2] ;
  
  if (!SWIG_Python_UnpackTuple(args, "Buddy_sendTypingIndication", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__Buddy, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "Buddy_sendTypingIndication" "', argument " "1"" of type '" "pj::Buddy *""'"); 
  }
  arg1 = reinterpret_cast< pj::Buddy * >(argp1);
  res2 = SWIG_ConvertPtr(swig_obj[1], &argp2, SWIGTYPE_p_pj__SendTypingIndicationParam,  0  | 0);
  if (!SWIG_IsOK(res2)) {
    SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "Buddy_sendTypingIndication" "', argument " "2"" of type '" "pj::SendTypingIndicationParam const &""'"); 
  }
  if (!argp2) {
    SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "Buddy_sendTypingIndication" "', argument " "2"" of type '" "pj::SendTypingIndicationParam const &""'"); 
  }
  arg2 = reinterpret_cast< pj::SendTypingIndicationParam * >(argp2);
  try {
    (arg1)->sendTypingIndication((pj::SendTypingIndicationParam const &)*arg2);
  } catch(pj::Error &_e) {
    SWIG_Python_Raise(SWIG_NewPointerObj((new pj::Error(static_cast< const pj::Error& >(_e))),SWIGTYPE_p_pj__Error,SWIG_POINTER_OWN), "pj::Error", SWIGTYPE_p_pj__Error); SWIG_fail;
  }
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_Buddy_onBuddyState(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::Buddy *arg1 = (pj::Buddy *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  Swig::Director *director = 0;
  bool upcall = false;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__Buddy, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "Buddy_onBuddyState" "', argument " "1"" of type '" "pj::Buddy *""'"); 
  }
  arg1 = reinterpret_cast< pj::Buddy * >(argp1);
  director = SWIG_DIRECTOR_CAST(arg1);
  upcall = (director && (director->swig_get_self()==swig_obj[0]));
  try {
    if (upcall) {
      (arg1)->pj::Buddy::onBuddyState();
    } else {
      (arg1)->onBuddyState();
    }
  } catch (Swig::DirectorException&) {
    SWIG_fail;
  }
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_Buddy_onBuddyEvSubState(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::Buddy *arg1 = (pj::Buddy *) 0 ;
  pj::OnBuddyEvSubStateParam *arg2 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  void *argp2 = 0 ;
  int res2 = 0 ;
  PyObject *swig_obj[2] ;
  Swig::Director *director = 0;
  bool upcall = false;
  
  if (!SWIG_Python_UnpackTuple(args, "Buddy_onBuddyEvSubState", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__Buddy, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "Buddy_onBuddyEvSubState" "', argument " "1"" of type '" "pj::Buddy *""'"); 
  }
  arg1 = reinterpret_cast< pj::Buddy * >(argp1);
  res2 = SWIG_ConvertPtr(swig_obj[1], &argp2, SWIGTYPE_p_pj__OnBuddyEvSubStateParam,  0 );
  if (!SWIG_IsOK(res2)) {
    SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "Buddy_onBuddyEvSubState" "', argument " "2"" of type '" "pj::OnBuddyEvSubStateParam &""'"); 
  }
  if (!argp2) {
    SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "Buddy_onBuddyEvSubState" "', argument " "2"" of type '" "pj::OnBuddyEvSubStateParam &""'"); 
  }
  arg2 = reinterpret_cast< pj::OnBuddyEvSubStateParam * >(argp2);
  director = SWIG_DIRECTOR_CAST(arg1);
  upcall = (director && (director->swig_get_self()==swig_obj[0]));
  try {
    if (upcall) {
      (arg1)->pj::Buddy::onBuddyEvSubState(*arg2);
    } else {
      (arg1)->onBuddyEvSubState(*arg2);
    }
  } catch (Swig::DirectorException&) {
    SWIG_fail;
  }
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_disown_Buddy(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::Buddy *arg1 = (pj::Buddy *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__Buddy, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "disown_Buddy" "', argument " "1"" of type '" "pj::Buddy *""'"); 
  }
  arg1 = reinterpret_cast< pj::Buddy * >(argp1);
  {
    Swig::Director *director = SWIG_DIRECTOR_CAST(arg1);
    if (director) director->swig_disown();
  }
  
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *Buddy_swigregister(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *obj;
  if (!SWIG_Python_UnpackTuple(args, "swigregister", 1, 1, &obj)) return NULL;
  SWIG_TypeNewClientData(SWIGTYPE_p_pj__Buddy, SWIG_NewClientData(obj));
  return SWIG_Py_Void();
}

SWIGINTERN PyObject *Buddy_swiginit(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  return SWIG_Python_InitShadowInstance(args);
}

SWIGINTERN PyObject *_wrap_AccountRegConfig_registrarUri_set(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::AccountRegConfig *arg1 = (pj::AccountRegConfig *) 0 ;
  pj::string *arg2 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  int res2 = SWIG_OLDOBJ ;
  PyObject *swig_obj[2] ;
  
  if (!SWIG_Python_UnpackTuple(args, "AccountRegConfig_registrarUri_set", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__AccountRegConfig, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "AccountRegConfig_registrarUri_set" "', argument " "1"" of type '" "pj::AccountRegConfig *""'"); 
  }
  arg1 = reinterpret_cast< pj::AccountRegConfig * >(argp1);
  {
    std::string *ptr = (std::string *)0;
    res2 = SWIG_AsPtr_std_string(swig_obj[1], &ptr);
    if (!SWIG_IsOK(res2)) {
      SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "AccountRegConfig_registrarUri_set" "', argument " "2"" of type '" "pj::string const &""'"); 
    }
    if (!ptr) {
      SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "AccountRegConfig_registrarUri_set" "', argument " "2"" of type '" "pj::string const &""'"); 
    }
    arg2 = ptr;
  }
  if (arg1) (arg1)->registrarUri = *arg2;
  resultobj = SWIG_Py_Void();
  if (SWIG_IsNewObj(res2)) delete arg2;
  return resultobj;
fail:
  if (SWIG_IsNewObj(res2)) delete arg2;
  return NULL;
}


SWIGINTERN PyObject *_wrap_AccountRegConfig_registrarUri_get(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::AccountRegConfig *arg1 = (pj::AccountRegConfig *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  pj::string *result = 0 ;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__AccountRegConfig, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "AccountRegConfig_registrarUri_get" "', argument " "1"" of type '" "pj::AccountRegConfig *""'"); 
  }
  arg1 = reinterpret_cast< pj::AccountRegConfig * >(argp1);
  result = (pj::string *) & ((arg1)->registrarUri);
  resultobj = SWIG_From_std_string(static_cast< std::string >(*result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_AccountRegConfig_registerOnAdd_set(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::AccountRegConfig *arg1 = (pj::AccountRegConfig *) 0 ;
  bool arg2 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  bool val2 ;
  int ecode2 = 0 ;
  PyObject *swig_obj[2] ;
  
  if (!SWIG_Python_UnpackTuple(args, "AccountRegConfig_registerOnAdd_set", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__AccountRegConfig, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "AccountRegConfig_registerOnAdd_set" "', argument " "1"" of type '" "pj::AccountRegConfig *""'"); 
  }
  arg1 = reinterpret_cast< pj::AccountRegConfig * >(argp1);
  ecode2 = SWIG_AsVal_bool(swig_obj[1], &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "AccountRegConfig_registerOnAdd_set" "', argument " "2"" of type '" "bool""'");
  } 
  arg2 = static_cast< bool >(val2);
  if (arg1) (arg1)->registerOnAdd = arg2;
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_AccountRegConfig_registerOnAdd_get(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::AccountRegConfig *arg1 = (pj::AccountRegConfig *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  bool result;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__AccountRegConfig, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "AccountRegConfig_registerOnAdd_get" "', argument " "1"" of type '" "pj::AccountRegConfig *""'"); 
  }
  arg1 = reinterpret_cast< pj::AccountRegConfig * >(argp1);
  result = (bool) ((arg1)->registerOnAdd);
  resultobj = SWIG_From_bool(static_cast< bool >(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_AccountRegConfig_headers_set(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::AccountRegConfig *arg1 = (pj::AccountRegConfig *) 0 ;
  pj::SipHeaderVector *arg2 = (pj::SipHeaderVector *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  void *argp2 = 0 ;
  int res2 = 0 ;
  PyObject *swig_obj[2] ;
  
  if (!SWIG_Python_UnpackTuple(args, "AccountRegConfig_headers_set", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__AccountRegConfig, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "AccountRegConfig_headers_set" "', argument " "1"" of type '" "pj::AccountRegConfig *""'"); 
  }
  arg1 = reinterpret_cast< pj::AccountRegConfig * >(argp1);
  res2 = SWIG_ConvertPtr(swig_obj[1], &argp2,SWIGTYPE_p_std__vectorT_pj__SipHeader_std__allocatorT_pj__SipHeader_t_t, 0 |  0 );
  if (!SWIG_IsOK(res2)) {
    SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "AccountRegConfig_headers_set" "', argument " "2"" of type '" "pj::SipHeaderVector *""'"); 
  }
  arg2 = reinterpret_cast< pj::SipHeaderVector * >(argp2);
  if (arg1) (arg1)->headers = *arg2;
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_AccountRegConfig_headers_get(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::AccountRegConfig *arg1 = (pj::AccountRegConfig *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  pj::SipHeaderVector *result = 0 ;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__AccountRegConfig, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "AccountRegConfig_headers_get" "', argument " "1"" of type '" "pj::AccountRegConfig *""'"); 
  }
  arg1 = reinterpret_cast< pj::AccountRegConfig * >(argp1);
  result = (pj::SipHeaderVector *)& ((arg1)->headers);
  resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(result), SWIGTYPE_p_std__vectorT_pj__SipHeader_std__allocatorT_pj__SipHeader_t_t, 0 |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_AccountRegConfig_contactParams_set(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::AccountRegConfig *arg1 = (pj::AccountRegConfig *) 0 ;
  pj::string *arg2 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  int res2 = SWIG_OLDOBJ ;
  PyObject *swig_obj[2] ;
  
  if (!SWIG_Python_UnpackTuple(args, "AccountRegConfig_contactParams_set", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__AccountRegConfig, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "AccountRegConfig_contactParams_set" "', argument " "1"" of type '" "pj::AccountRegConfig *""'"); 
  }
  arg1 = reinterpret_cast< pj::AccountRegConfig * >(argp1);
  {
    std::string *ptr = (std::string *)0;
    res2 = SWIG_AsPtr_std_string(swig_obj[1], &ptr);
    if (!SWIG_IsOK(res2)) {
      SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "AccountRegConfig_contactParams_set" "', argument " "2"" of type '" "pj::string const &""'"); 
    }
    if (!ptr) {
      SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "AccountRegConfig_contactParams_set" "', argument " "2"" of type '" "pj::string const &""'"); 
    }
    arg2 = ptr;
  }
  if (arg1) (arg1)->contactParams = *arg2;
  resultobj = SWIG_Py_Void();
  if (SWIG_IsNewObj(res2)) delete arg2;
  return resultobj;
fail:
  if (SWIG_IsNewObj(res2)) delete arg2;
  return NULL;
}


SWIGINTERN PyObject *_wrap_AccountRegConfig_contactParams_get(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::AccountRegConfig *arg1 = (pj::AccountRegConfig *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  pj::string *result = 0 ;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__AccountRegConfig, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "AccountRegConfig_contactParams_get" "', argument " "1"" of type '" "pj::AccountRegConfig *""'"); 
  }
  arg1 = reinterpret_cast< pj::AccountRegConfig * >(argp1);
  result = (pj::string *) & ((arg1)->contactParams);
  resultobj = SWIG_From_std_string(static_cast< std::string >(*result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_AccountRegConfig_contactUriParams_set(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::AccountRegConfig *arg1 = (pj::AccountRegConfig *) 0 ;
  pj::string *arg2 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  int res2 = SWIG_OLDOBJ ;
  PyObject *swig_obj[2] ;
  
  if (!SWIG_Python_UnpackTuple(args, "AccountRegConfig_contactUriParams_set", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__AccountRegConfig, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "AccountRegConfig_contactUriParams_set" "', argument " "1"" of type '" "pj::AccountRegConfig *""'"); 
  }
  arg1 = reinterpret_cast< pj::AccountRegConfig * >(argp1);
  {
    std::string *ptr = (std::string *)0;
    res2 = SWIG_AsPtr_std_string(swig_obj[1], &ptr);
    if (!SWIG_IsOK(res2)) {
      SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "AccountRegConfig_contactUriParams_set" "', argument " "2"" of type '" "pj::string const &""'"); 
    }
    if (!ptr) {
      SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "AccountRegConfig_contactUriParams_set" "', argument " "2"" of type '" "pj::string const &""'"); 
    }
    arg2 = ptr;
  }
  if (arg1) (arg1)->contactUriParams = *arg2;
  resultobj = SWIG_Py_Void();
  if (SWIG_IsNewObj(res2)) delete arg2;
  return resultobj;
fail:
  if (SWIG_IsNewObj(res2)) delete arg2;
  return NULL;
}


SWIGINTERN PyObject *_wrap_AccountRegConfig_contactUriParams_get(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::AccountRegConfig *arg1 = (pj::AccountRegConfig *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  pj::string *result = 0 ;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__AccountRegConfig, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "AccountRegConfig_contactUriParams_get" "', argument " "1"" of type '" "pj::AccountRegConfig *""'"); 
  }
  arg1 = reinterpret_cast< pj::AccountRegConfig * >(argp1);
  result = (pj::string *) & ((arg1)->contactUriParams);
  resultobj = SWIG_From_std_string(static_cast< std::string >(*result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_AccountRegConfig_timeoutSec_set(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::AccountRegConfig *arg1 = (pj::AccountRegConfig *) 0 ;
  unsigned int arg2 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  unsigned int val2 ;
  int ecode2 = 0 ;
  PyObject *swig_obj[2] ;
  
  if (!SWIG_Python_UnpackTuple(args, "AccountRegConfig_timeoutSec_set", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__AccountRegConfig, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "AccountRegConfig_timeoutSec_set" "', argument " "1"" of type '" "pj::AccountRegConfig *""'"); 
  }
  arg1 = reinterpret_cast< pj::AccountRegConfig * >(argp1);
  ecode2 = SWIG_AsVal_unsigned_SS_int(swig_obj[1], &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "AccountRegConfig_timeoutSec_set" "', argument " "2"" of type '" "unsigned int""'");
  } 
  arg2 = static_cast< unsigned int >(val2);
  if (arg1) (arg1)->timeoutSec = arg2;
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_AccountRegConfig_timeoutSec_get(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::AccountRegConfig *arg1 = (pj::AccountRegConfig *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  unsigned int result;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__AccountRegConfig, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "AccountRegConfig_timeoutSec_get" "', argument " "1"" of type '" "pj::AccountRegConfig *""'"); 
  }
  arg1 = reinterpret_cast< pj::AccountRegConfig * >(argp1);
  result = (unsigned int) ((arg1)->timeoutSec);
  resultobj = SWIG_From_unsigned_SS_int(static_cast< unsigned int >(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_AccountRegConfig_retryIntervalSec_set(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::AccountRegConfig *arg1 = (pj::AccountRegConfig *) 0 ;
  unsigned int arg2 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  unsigned int val2 ;
  int ecode2 = 0 ;
  PyObject *swig_obj[2] ;
  
  if (!SWIG_Python_UnpackTuple(args, "AccountRegConfig_retryIntervalSec_set", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__AccountRegConfig, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "AccountRegConfig_retryIntervalSec_set" "', argument " "1"" of type '" "pj::AccountRegConfig *""'"); 
  }
  arg1 = reinterpret_cast< pj::AccountRegConfig * >(argp1);
  ecode2 = SWIG_AsVal_unsigned_SS_int(swig_obj[1], &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "AccountRegConfig_retryIntervalSec_set" "', argument " "2"" of type '" "unsigned int""'");
  } 
  arg2 = static_cast< unsigned int >(val2);
  if (arg1) (arg1)->retryIntervalSec = arg2;
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_AccountRegConfig_retryIntervalSec_get(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::AccountRegConfig *arg1 = (pj::AccountRegConfig *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  unsigned int result;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__AccountRegConfig, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "AccountRegConfig_retryIntervalSec_get" "', argument " "1"" of type '" "pj::AccountRegConfig *""'"); 
  }
  arg1 = reinterpret_cast< pj::AccountRegConfig * >(argp1);
  result = (unsigned int) ((arg1)->retryIntervalSec);
  resultobj = SWIG_From_unsigned_SS_int(static_cast< unsigned int >(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_AccountRegConfig_firstRetryIntervalSec_set(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::AccountRegConfig *arg1 = (pj::AccountRegConfig *) 0 ;
  unsigned int arg2 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  unsigned int val2 ;
  int ecode2 = 0 ;
  PyObject *swig_obj[2] ;
  
  if (!SWIG_Python_UnpackTuple(args, "AccountRegConfig_firstRetryIntervalSec_set", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__AccountRegConfig, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "AccountRegConfig_firstRetryIntervalSec_set" "', argument " "1"" of type '" "pj::AccountRegConfig *""'"); 
  }
  arg1 = reinterpret_cast< pj::AccountRegConfig * >(argp1);
  ecode2 = SWIG_AsVal_unsigned_SS_int(swig_obj[1], &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "AccountRegConfig_firstRetryIntervalSec_set" "', argument " "2"" of type '" "unsigned int""'");
  } 
  arg2 = static_cast< unsigned int >(val2);
  if (arg1) (arg1)->firstRetryIntervalSec = arg2;
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_AccountRegConfig_firstRetryIntervalSec_get(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::AccountRegConfig *arg1 = (pj::AccountRegConfig *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  unsigned int result;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__AccountRegConfig, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "AccountRegConfig_firstRetryIntervalSec_get" "', argument " "1"" of type '" "pj::AccountRegConfig *""'"); 
  }
  arg1 = reinterpret_cast< pj::AccountRegConfig * >(argp1);
  result = (unsigned int) ((arg1)->firstRetryIntervalSec);
  resultobj = SWIG_From_unsigned_SS_int(static_cast< unsigned int >(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_AccountRegConfig_randomRetryIntervalSec_set(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::AccountRegConfig *arg1 = (pj::AccountRegConfig *) 0 ;
  unsigned int arg2 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  unsigned int val2 ;
  int ecode2 = 0 ;
  PyObject *swig_obj[2] ;
  
  if (!SWIG_Python_UnpackTuple(args, "AccountRegConfig_randomRetryIntervalSec_set", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__AccountRegConfig, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "AccountRegConfig_randomRetryIntervalSec_set" "', argument " "1"" of type '" "pj::AccountRegConfig *""'"); 
  }
  arg1 = reinterpret_cast< pj::AccountRegConfig * >(argp1);
  ecode2 = SWIG_AsVal_unsigned_SS_int(swig_obj[1], &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "AccountRegConfig_randomRetryIntervalSec_set" "', argument " "2"" of type '" "unsigned int""'");
  } 
  arg2 = static_cast< unsigned int >(val2);
  if (arg1) (arg1)->randomRetryIntervalSec = arg2;
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_AccountRegConfig_randomRetryIntervalSec_get(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::AccountRegConfig *arg1 = (pj::AccountRegConfig *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  unsigned int result;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__AccountRegConfig, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "AccountRegConfig_randomRetryIntervalSec_get" "', argument " "1"" of type '" "pj::AccountRegConfig *""'"); 
  }
  arg1 = reinterpret_cast< pj::AccountRegConfig * >(argp1);
  result = (unsigned int) ((arg1)->randomRetryIntervalSec);
  resultobj = SWIG_From_unsigned_SS_int(static_cast< unsigned int >(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_AccountRegConfig_delayBeforeRefreshSec_set(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::AccountRegConfig *arg1 = (pj::AccountRegConfig *) 0 ;
  unsigned int arg2 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  unsigned int val2 ;
  int ecode2 = 0 ;
  PyObject *swig_obj[2] ;
  
  if (!SWIG_Python_UnpackTuple(args, "AccountRegConfig_delayBeforeRefreshSec_set", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__AccountRegConfig, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "AccountRegConfig_delayBeforeRefreshSec_set" "', argument " "1"" of type '" "pj::AccountRegConfig *""'"); 
  }
  arg1 = reinterpret_cast< pj::AccountRegConfig * >(argp1);
  ecode2 = SWIG_AsVal_unsigned_SS_int(swig_obj[1], &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "AccountRegConfig_delayBeforeRefreshSec_set" "', argument " "2"" of type '" "unsigned int""'");
  } 
  arg2 = static_cast< unsigned int >(val2);
  if (arg1) (arg1)->delayBeforeRefreshSec = arg2;
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_AccountRegConfig_delayBeforeRefreshSec_get(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::AccountRegConfig *arg1 = (pj::AccountRegConfig *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  unsigned int result;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__AccountRegConfig, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "AccountRegConfig_delayBeforeRefreshSec_get" "', argument " "1"" of type '" "pj::AccountRegConfig *""'"); 
  }
  arg1 = reinterpret_cast< pj::AccountRegConfig * >(argp1);
  result = (unsigned int) ((arg1)->delayBeforeRefreshSec);
  resultobj = SWIG_From_unsigned_SS_int(static_cast< unsigned int >(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_AccountRegConfig_dropCallsOnFail_set(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::AccountRegConfig *arg1 = (pj::AccountRegConfig *) 0 ;
  bool arg2 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  bool val2 ;
  int ecode2 = 0 ;
  PyObject *swig_obj[2] ;
  
  if (!SWIG_Python_UnpackTuple(args, "AccountRegConfig_dropCallsOnFail_set", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__AccountRegConfig, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "AccountRegConfig_dropCallsOnFail_set" "', argument " "1"" of type '" "pj::AccountRegConfig *""'"); 
  }
  arg1 = reinterpret_cast< pj::AccountRegConfig * >(argp1);
  ecode2 = SWIG_AsVal_bool(swig_obj[1], &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "AccountRegConfig_dropCallsOnFail_set" "', argument " "2"" of type '" "bool""'");
  } 
  arg2 = static_cast< bool >(val2);
  if (arg1) (arg1)->dropCallsOnFail = arg2;
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_AccountRegConfig_dropCallsOnFail_get(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::AccountRegConfig *arg1 = (pj::AccountRegConfig *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  bool result;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__AccountRegConfig, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "AccountRegConfig_dropCallsOnFail_get" "', argument " "1"" of type '" "pj::AccountRegConfig *""'"); 
  }
  arg1 = reinterpret_cast< pj::AccountRegConfig * >(argp1);
  result = (bool) ((arg1)->dropCallsOnFail);
  resultobj = SWIG_From_bool(static_cast< bool >(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_AccountRegConfig_unregWaitMsec_set(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::AccountRegConfig *arg1 = (pj::AccountRegConfig *) 0 ;
  unsigned int arg2 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  unsigned int val2 ;
  int ecode2 = 0 ;
  PyObject *swig_obj[2] ;
  
  if (!SWIG_Python_UnpackTuple(args, "AccountRegConfig_unregWaitMsec_set", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__AccountRegConfig, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "AccountRegConfig_unregWaitMsec_set" "', argument " "1"" of type '" "pj::AccountRegConfig *""'"); 
  }
  arg1 = reinterpret_cast< pj::AccountRegConfig * >(argp1);
  ecode2 = SWIG_AsVal_unsigned_SS_int(swig_obj[1], &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "AccountRegConfig_unregWaitMsec_set" "', argument " "2"" of type '" "unsigned int""'");
  } 
  arg2 = static_cast< unsigned int >(val2);
  if (arg1) (arg1)->unregWaitMsec = arg2;
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_AccountRegConfig_unregWaitMsec_get(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::AccountRegConfig *arg1 = (pj::AccountRegConfig *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  unsigned int result;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__AccountRegConfig, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "AccountRegConfig_unregWaitMsec_get" "', argument " "1"" of type '" "pj::AccountRegConfig *""'"); 
  }
  arg1 = reinterpret_cast< pj::AccountRegConfig * >(argp1);
  result = (unsigned int) ((arg1)->unregWaitMsec);
  resultobj = SWIG_From_unsigned_SS_int(static_cast< unsigned int >(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_AccountRegConfig_proxyUse_set(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::AccountRegConfig *arg1 = (pj::AccountRegConfig *) 0 ;
  unsigned int arg2 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  unsigned int val2 ;
  int ecode2 = 0 ;
  PyObject *swig_obj[2] ;
  
  if (!SWIG_Python_UnpackTuple(args, "AccountRegConfig_proxyUse_set", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__AccountRegConfig, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "AccountRegConfig_proxyUse_set" "', argument " "1"" of type '" "pj::AccountRegConfig *""'"); 
  }
  arg1 = reinterpret_cast< pj::AccountRegConfig * >(argp1);
  ecode2 = SWIG_AsVal_unsigned_SS_int(swig_obj[1], &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "AccountRegConfig_proxyUse_set" "', argument " "2"" of type '" "unsigned int""'");
  } 
  arg2 = static_cast< unsigned int >(val2);
  if (arg1) (arg1)->proxyUse = arg2;
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_AccountRegConfig_proxyUse_get(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::AccountRegConfig *arg1 = (pj::AccountRegConfig *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  unsigned int result;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__AccountRegConfig, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "AccountRegConfig_proxyUse_get" "', argument " "1"" of type '" "pj::AccountRegConfig *""'"); 
  }
  arg1 = reinterpret_cast< pj::AccountRegConfig * >(argp1);
  result = (unsigned int) ((arg1)->proxyUse);
  resultobj = SWIG_From_unsigned_SS_int(static_cast< unsigned int >(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_AccountRegConfig_readObject(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::AccountRegConfig *arg1 = (pj::AccountRegConfig *) 0 ;
  pj::ContainerNode *arg2 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  void *argp2 = 0 ;
  int res2 = 0 ;
  PyObject *swig_obj[2] ;
  
  if (!SWIG_Python_UnpackTuple(args, "AccountRegConfig_readObject", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__AccountRegConfig, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "AccountRegConfig_readObject" "', argument " "1"" of type '" "pj::AccountRegConfig *""'"); 
  }
  arg1 = reinterpret_cast< pj::AccountRegConfig * >(argp1);
  res2 = SWIG_ConvertPtr(swig_obj[1], &argp2, SWIGTYPE_p_pj__ContainerNode,  0  | 0);
  if (!SWIG_IsOK(res2)) {
    SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "AccountRegConfig_readObject" "', argument " "2"" of type '" "pj::ContainerNode const &""'"); 
  }
  if (!argp2) {
    SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "AccountRegConfig_readObject" "', argument " "2"" of type '" "pj::ContainerNode const &""'"); 
  }
  arg2 = reinterpret_cast< pj::ContainerNode * >(argp2);
  try {
    (arg1)->readObject((pj::ContainerNode const &)*arg2);
  } catch(pj::Error &_e) {
    SWIG_Python_Raise(SWIG_NewPointerObj((new pj::Error(static_cast< const pj::Error& >(_e))),SWIGTYPE_p_pj__Error,SWIG_POINTER_OWN), "pj::Error", SWIGTYPE_p_pj__Error); SWIG_fail;
  }
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_AccountRegConfig_writeObject(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::AccountRegConfig *arg1 = (pj::AccountRegConfig *) 0 ;
  pj::ContainerNode *arg2 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  void *argp2 = 0 ;
  int res2 = 0 ;
  PyObject *swig_obj[2] ;
  
  if (!SWIG_Python_UnpackTuple(args, "AccountRegConfig_writeObject", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__AccountRegConfig, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "AccountRegConfig_writeObject" "', argument " "1"" of type '" "pj::AccountRegConfig const *""'"); 
  }
  arg1 = reinterpret_cast< pj::AccountRegConfig * >(argp1);
  res2 = SWIG_ConvertPtr(swig_obj[1], &argp2, SWIGTYPE_p_pj__ContainerNode,  0 );
  if (!SWIG_IsOK(res2)) {
    SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "AccountRegConfig_writeObject" "', argument " "2"" of type '" "pj::ContainerNode &""'"); 
  }
  if (!argp2) {
    SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "AccountRegConfig_writeObject" "', argument " "2"" of type '" "pj::ContainerNode &""'"); 
  }
  arg2 = reinterpret_cast< pj::ContainerNode * >(argp2);
  try {
    ((pj::AccountRegConfig const *)arg1)->writeObject(*arg2);
  } catch(pj::Error &_e) {
    SWIG_Python_Raise(SWIG_NewPointerObj((new pj::Error(static_cast< const pj::Error& >(_e))),SWIGTYPE_p_pj__Error,SWIG_POINTER_OWN), "pj::Error", SWIGTYPE_p_pj__Error); SWIG_fail;
  }
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_new_AccountRegConfig(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::AccountRegConfig *result = 0 ;
  
  if (!SWIG_Python_UnpackTuple(args, "new_AccountRegConfig", 0, 0, 0)) SWIG_fail;
  result = (pj::AccountRegConfig *)new pj::AccountRegConfig();
  resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(result), SWIGTYPE_p_pj__AccountRegConfig, SWIG_POINTER_NEW |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_delete_AccountRegConfig(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::AccountRegConfig *arg1 = (pj::AccountRegConfig *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__AccountRegConfig, SWIG_POINTER_DISOWN |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "delete_AccountRegConfig" "', argument " "1"" of type '" "pj::AccountRegConfig *""'"); 
  }
  arg1 = reinterpret_cast< pj::AccountRegConfig * >(argp1);
  delete arg1;
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *AccountRegConfig_swigregister(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *obj;
  if (!SWIG_Python_UnpackTuple(args, "swigregister", 1, 1, &obj)) return NULL;
  SWIG_TypeNewClientData(SWIGTYPE_p_pj__AccountRegConfig, SWIG_NewClientData(obj));
  return SWIG_Py_Void();
}

SWIGINTERN PyObject *AccountRegConfig_swiginit(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  return SWIG_Python_InitShadowInstance(args);
}

SWIGINTERN PyObject *_wrap_AccountSipConfig_authCreds_set(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::AccountSipConfig *arg1 = (pj::AccountSipConfig *) 0 ;
  pj::AuthCredInfoVector *arg2 = (pj::AuthCredInfoVector *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  void *argp2 = 0 ;
  int res2 = 0 ;
  PyObject *swig_obj[2] ;
  
  if (!SWIG_Python_UnpackTuple(args, "AccountSipConfig_authCreds_set", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__AccountSipConfig, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "AccountSipConfig_authCreds_set" "', argument " "1"" of type '" "pj::AccountSipConfig *""'"); 
  }
  arg1 = reinterpret_cast< pj::AccountSipConfig * >(argp1);
  res2 = SWIG_ConvertPtr(swig_obj[1], &argp2,SWIGTYPE_p_std__vectorT_pj__AuthCredInfo_std__allocatorT_pj__AuthCredInfo_t_t, 0 |  0 );
  if (!SWIG_IsOK(res2)) {
    SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "AccountSipConfig_authCreds_set" "', argument " "2"" of type '" "pj::AuthCredInfoVector *""'"); 
  }
  arg2 = reinterpret_cast< pj::AuthCredInfoVector * >(argp2);
  if (arg1) (arg1)->authCreds = *arg2;
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_AccountSipConfig_authCreds_get(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::AccountSipConfig *arg1 = (pj::AccountSipConfig *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  pj::AuthCredInfoVector *result = 0 ;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__AccountSipConfig, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "AccountSipConfig_authCreds_get" "', argument " "1"" of type '" "pj::AccountSipConfig *""'"); 
  }
  arg1 = reinterpret_cast< pj::AccountSipConfig * >(argp1);
  result = (pj::AuthCredInfoVector *)& ((arg1)->authCreds);
  resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(result), SWIGTYPE_p_std__vectorT_pj__AuthCredInfo_std__allocatorT_pj__AuthCredInfo_t_t, 0 |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_AccountSipConfig_proxies_set(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::AccountSipConfig *arg1 = (pj::AccountSipConfig *) 0 ;
  pj::StringVector *arg2 = (pj::StringVector *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  void *argp2 = 0 ;
  int res2 = 0 ;
  PyObject *swig_obj[2] ;
  
  if (!SWIG_Python_UnpackTuple(args, "AccountSipConfig_proxies_set", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__AccountSipConfig, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "AccountSipConfig_proxies_set" "', argument " "1"" of type '" "pj::AccountSipConfig *""'"); 
  }
  arg1 = reinterpret_cast< pj::AccountSipConfig * >(argp1);
  res2 = SWIG_ConvertPtr(swig_obj[1], &argp2,SWIGTYPE_p_std__vectorT_std__string_std__allocatorT_std__string_t_t, 0 |  0 );
  if (!SWIG_IsOK(res2)) {
    SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "AccountSipConfig_proxies_set" "', argument " "2"" of type '" "pj::StringVector *""'"); 
  }
  arg2 = reinterpret_cast< pj::StringVector * >(argp2);
  if (arg1) (arg1)->proxies = *arg2;
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_AccountSipConfig_proxies_get(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::AccountSipConfig *arg1 = (pj::AccountSipConfig *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  pj::StringVector *result = 0 ;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__AccountSipConfig, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "AccountSipConfig_proxies_get" "', argument " "1"" of type '" "pj::AccountSipConfig *""'"); 
  }
  arg1 = reinterpret_cast< pj::AccountSipConfig * >(argp1);
  result = (pj::StringVector *)& ((arg1)->proxies);
  resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(result), SWIGTYPE_p_std__vectorT_std__string_std__allocatorT_std__string_t_t, 0 |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_AccountSipConfig_contactForced_set(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::AccountSipConfig *arg1 = (pj::AccountSipConfig *) 0 ;
  pj::string *arg2 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  int res2 = SWIG_OLDOBJ ;
  PyObject *swig_obj[2] ;
  
  if (!SWIG_Python_UnpackTuple(args, "AccountSipConfig_contactForced_set", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__AccountSipConfig, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "AccountSipConfig_contactForced_set" "', argument " "1"" of type '" "pj::AccountSipConfig *""'"); 
  }
  arg1 = reinterpret_cast< pj::AccountSipConfig * >(argp1);
  {
    std::string *ptr = (std::string *)0;
    res2 = SWIG_AsPtr_std_string(swig_obj[1], &ptr);
    if (!SWIG_IsOK(res2)) {
      SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "AccountSipConfig_contactForced_set" "', argument " "2"" of type '" "pj::string const &""'"); 
    }
    if (!ptr) {
      SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "AccountSipConfig_contactForced_set" "', argument " "2"" of type '" "pj::string const &""'"); 
    }
    arg2 = ptr;
  }
  if (arg1) (arg1)->contactForced = *arg2;
  resultobj = SWIG_Py_Void();
  if (SWIG_IsNewObj(res2)) delete arg2;
  return resultobj;
fail:
  if (SWIG_IsNewObj(res2)) delete arg2;
  return NULL;
}


SWIGINTERN PyObject *_wrap_AccountSipConfig_contactForced_get(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::AccountSipConfig *arg1 = (pj::AccountSipConfig *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  pj::string *result = 0 ;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__AccountSipConfig, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "AccountSipConfig_contactForced_get" "', argument " "1"" of type '" "pj::AccountSipConfig *""'"); 
  }
  arg1 = reinterpret_cast< pj::AccountSipConfig * >(argp1);
  result = (pj::string *) & ((arg1)->contactForced);
  resultobj = SWIG_From_std_string(static_cast< std::string >(*result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_AccountSipConfig_contactParams_set(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::AccountSipConfig *arg1 = (pj::AccountSipConfig *) 0 ;
  pj::string *arg2 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  int res2 = SWIG_OLDOBJ ;
  PyObject *swig_obj[2] ;
  
  if (!SWIG_Python_UnpackTuple(args, "AccountSipConfig_contactParams_set", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__AccountSipConfig, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "AccountSipConfig_contactParams_set" "', argument " "1"" of type '" "pj::AccountSipConfig *""'"); 
  }
  arg1 = reinterpret_cast< pj::AccountSipConfig * >(argp1);
  {
    std::string *ptr = (std::string *)0;
    res2 = SWIG_AsPtr_std_string(swig_obj[1], &ptr);
    if (!SWIG_IsOK(res2)) {
      SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "AccountSipConfig_contactParams_set" "', argument " "2"" of type '" "pj::string const &""'"); 
    }
    if (!ptr) {
      SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "AccountSipConfig_contactParams_set" "', argument " "2"" of type '" "pj::string const &""'"); 
    }
    arg2 = ptr;
  }
  if (arg1) (arg1)->contactParams = *arg2;
  resultobj = SWIG_Py_Void();
  if (SWIG_IsNewObj(res2)) delete arg2;
  return resultobj;
fail:
  if (SWIG_IsNewObj(res2)) delete arg2;
  return NULL;
}


SWIGINTERN PyObject *_wrap_AccountSipConfig_contactParams_get(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::AccountSipConfig *arg1 = (pj::AccountSipConfig *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  pj::string *result = 0 ;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__AccountSipConfig, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "AccountSipConfig_contactParams_get" "', argument " "1"" of type '" "pj::AccountSipConfig *""'"); 
  }
  arg1 = reinterpret_cast< pj::AccountSipConfig * >(argp1);
  result = (pj::string *) & ((arg1)->contactParams);
  resultobj = SWIG_From_std_string(static_cast< std::string >(*result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_AccountSipConfig_contactUriParams_set(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::AccountSipConfig *arg1 = (pj::AccountSipConfig *) 0 ;
  pj::string *arg2 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  int res2 = SWIG_OLDOBJ ;
  PyObject *swig_obj[2] ;
  
  if (!SWIG_Python_UnpackTuple(args, "AccountSipConfig_contactUriParams_set", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__AccountSipConfig, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "AccountSipConfig_contactUriParams_set" "', argument " "1"" of type '" "pj::AccountSipConfig *""'"); 
  }
  arg1 = reinterpret_cast< pj::AccountSipConfig * >(argp1);
  {
    std::string *ptr = (std::string *)0;
    res2 = SWIG_AsPtr_std_string(swig_obj[1], &ptr);
    if (!SWIG_IsOK(res2)) {
      SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "AccountSipConfig_contactUriParams_set" "', argument " "2"" of type '" "pj::string const &""'"); 
    }
    if (!ptr) {
      SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "AccountSipConfig_contactUriParams_set" "', argument " "2"" of type '" "pj::string const &""'"); 
    }
    arg2 = ptr;
  }
  if (arg1) (arg1)->contactUriParams = *arg2;
  resultobj = SWIG_Py_Void();
  if (SWIG_IsNewObj(res2)) delete arg2;
  return resultobj;
fail:
  if (SWIG_IsNewObj(res2)) delete arg2;
  return NULL;
}


SWIGINTERN PyObject *_wrap_AccountSipConfig_contactUriParams_get(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::AccountSipConfig *arg1 = (pj::AccountSipConfig *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  pj::string *result = 0 ;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__AccountSipConfig, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "AccountSipConfig_contactUriParams_get" "', argument " "1"" of type '" "pj::AccountSipConfig *""'"); 
  }
  arg1 = reinterpret_cast< pj::AccountSipConfig * >(argp1);
  result = (pj::string *) & ((arg1)->contactUriParams);
  resultobj = SWIG_From_std_string(static_cast< std::string >(*result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_AccountSipConfig_authInitialEmpty_set(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::AccountSipConfig *arg1 = (pj::AccountSipConfig *) 0 ;
  bool arg2 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  bool val2 ;
  int ecode2 = 0 ;
  PyObject *swig_obj[2] ;
  
  if (!SWIG_Python_UnpackTuple(args, "AccountSipConfig_authInitialEmpty_set", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__AccountSipConfig, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "AccountSipConfig_authInitialEmpty_set" "', argument " "1"" of type '" "pj::AccountSipConfig *""'"); 
  }
  arg1 = reinterpret_cast< pj::AccountSipConfig * >(argp1);
  ecode2 = SWIG_AsVal_bool(swig_obj[1], &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "AccountSipConfig_authInitialEmpty_set" "', argument " "2"" of type '" "bool""'");
  } 
  arg2 = static_cast< bool >(val2);
  if (arg1) (arg1)->authInitialEmpty = arg2;
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_AccountSipConfig_authInitialEmpty_get(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::AccountSipConfig *arg1 = (pj::AccountSipConfig *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  bool result;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__AccountSipConfig, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "AccountSipConfig_authInitialEmpty_get" "', argument " "1"" of type '" "pj::AccountSipConfig *""'"); 
  }
  arg1 = reinterpret_cast< pj::AccountSipConfig * >(argp1);
  result = (bool) ((arg1)->authInitialEmpty);
  resultobj = SWIG_From_bool(static_cast< bool >(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_AccountSipConfig_authInitialAlgorithm_set(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::AccountSipConfig *arg1 = (pj::AccountSipConfig *) 0 ;
  pj::string *arg2 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  int res2 = SWIG_OLDOBJ ;
  PyObject *swig_obj[2] ;
  
  if (!SWIG_Python_UnpackTuple(args, "AccountSipConfig_authInitialAlgorithm_set", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__AccountSipConfig, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "AccountSipConfig_authInitialAlgorithm_set" "', argument " "1"" of type '" "pj::AccountSipConfig *""'"); 
  }
  arg1 = reinterpret_cast< pj::AccountSipConfig * >(argp1);
  {
    std::string *ptr = (std::string *)0;
    res2 = SWIG_AsPtr_std_string(swig_obj[1], &ptr);
    if (!SWIG_IsOK(res2)) {
      SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "AccountSipConfig_authInitialAlgorithm_set" "', argument " "2"" of type '" "pj::string const &""'"); 
    }
    if (!ptr) {
      SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "AccountSipConfig_authInitialAlgorithm_set" "', argument " "2"" of type '" "pj::string const &""'"); 
    }
    arg2 = ptr;
  }
  if (arg1) (arg1)->authInitialAlgorithm = *arg2;
  resultobj = SWIG_Py_Void();
  if (SWIG_IsNewObj(res2)) delete arg2;
  return resultobj;
fail:
  if (SWIG_IsNewObj(res2)) delete arg2;
  return NULL;
}


SWIGINTERN PyObject *_wrap_AccountSipConfig_authInitialAlgorithm_get(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::AccountSipConfig *arg1 = (pj::AccountSipConfig *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  pj::string *result = 0 ;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__AccountSipConfig, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "AccountSipConfig_authInitialAlgorithm_get" "', argument " "1"" of type '" "pj::AccountSipConfig *""'"); 
  }
  arg1 = reinterpret_cast< pj::AccountSipConfig * >(argp1);
  result = (pj::string *) & ((arg1)->authInitialAlgorithm);
  resultobj = SWIG_From_std_string(static_cast< std::string >(*result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_AccountSipConfig_transportId_set(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::AccountSipConfig *arg1 = (pj::AccountSipConfig *) 0 ;
  pj::TransportId arg2 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  int val2 ;
  int ecode2 = 0 ;
  PyObject *swig_obj[2] ;
  
  if (!SWIG_Python_UnpackTuple(args, "AccountSipConfig_transportId_set", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__AccountSipConfig, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "AccountSipConfig_transportId_set" "', argument " "1"" of type '" "pj::AccountSipConfig *""'"); 
  }
  arg1 = reinterpret_cast< pj::AccountSipConfig * >(argp1);
  ecode2 = SWIG_AsVal_int(swig_obj[1], &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "AccountSipConfig_transportId_set" "', argument " "2"" of type '" "pj::TransportId""'");
  } 
  arg2 = static_cast< pj::TransportId >(val2);
  if (arg1) (arg1)->transportId = arg2;
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_AccountSipConfig_transportId_get(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::AccountSipConfig *arg1 = (pj::AccountSipConfig *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  pj::TransportId result;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__AccountSipConfig, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "AccountSipConfig_transportId_get" "', argument " "1"" of type '" "pj::AccountSipConfig *""'"); 
  }
  arg1 = reinterpret_cast< pj::AccountSipConfig * >(argp1);
  result = (pj::TransportId) ((arg1)->transportId);
  resultobj = SWIG_From_int(static_cast< int >(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_AccountSipConfig_readObject(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::AccountSipConfig *arg1 = (pj::AccountSipConfig *) 0 ;
  pj::ContainerNode *arg2 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  void *argp2 = 0 ;
  int res2 = 0 ;
  PyObject *swig_obj[2] ;
  
  if (!SWIG_Python_UnpackTuple(args, "AccountSipConfig_readObject", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__AccountSipConfig, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "AccountSipConfig_readObject" "', argument " "1"" of type '" "pj::AccountSipConfig *""'"); 
  }
  arg1 = reinterpret_cast< pj::AccountSipConfig * >(argp1);
  res2 = SWIG_ConvertPtr(swig_obj[1], &argp2, SWIGTYPE_p_pj__ContainerNode,  0  | 0);
  if (!SWIG_IsOK(res2)) {
    SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "AccountSipConfig_readObject" "', argument " "2"" of type '" "pj::ContainerNode const &""'"); 
  }
  if (!argp2) {
    SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "AccountSipConfig_readObject" "', argument " "2"" of type '" "pj::ContainerNode const &""'"); 
  }
  arg2 = reinterpret_cast< pj::ContainerNode * >(argp2);
  try {
    (arg1)->readObject((pj::ContainerNode const &)*arg2);
  } catch(pj::Error &_e) {
    SWIG_Python_Raise(SWIG_NewPointerObj((new pj::Error(static_cast< const pj::Error& >(_e))),SWIGTYPE_p_pj__Error,SWIG_POINTER_OWN), "pj::Error", SWIGTYPE_p_pj__Error); SWIG_fail;
  }
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_AccountSipConfig_writeObject(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::AccountSipConfig *arg1 = (pj::AccountSipConfig *) 0 ;
  pj::ContainerNode *arg2 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  void *argp2 = 0 ;
  int res2 = 0 ;
  PyObject *swig_obj[2] ;
  
  if (!SWIG_Python_UnpackTuple(args, "AccountSipConfig_writeObject", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__AccountSipConfig, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "AccountSipConfig_writeObject" "', argument " "1"" of type '" "pj::AccountSipConfig const *""'"); 
  }
  arg1 = reinterpret_cast< pj::AccountSipConfig * >(argp1);
  res2 = SWIG_ConvertPtr(swig_obj[1], &argp2, SWIGTYPE_p_pj__ContainerNode,  0 );
  if (!SWIG_IsOK(res2)) {
    SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "AccountSipConfig_writeObject" "', argument " "2"" of type '" "pj::ContainerNode &""'"); 
  }
  if (!argp2) {
    SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "AccountSipConfig_writeObject" "', argument " "2"" of type '" "pj::ContainerNode &""'"); 
  }
  arg2 = reinterpret_cast< pj::ContainerNode * >(argp2);
  try {
    ((pj::AccountSipConfig const *)arg1)->writeObject(*arg2);
  } catch(pj::Error &_e) {
    SWIG_Python_Raise(SWIG_NewPointerObj((new pj::Error(static_cast< const pj::Error& >(_e))),SWIGTYPE_p_pj__Error,SWIG_POINTER_OWN), "pj::Error", SWIGTYPE_p_pj__Error); SWIG_fail;
  }
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_new_AccountSipConfig(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::AccountSipConfig *result = 0 ;
  
  if (!SWIG_Python_UnpackTuple(args, "new_AccountSipConfig", 0, 0, 0)) SWIG_fail;
  result = (pj::AccountSipConfig *)new pj::AccountSipConfig();
  resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(result), SWIGTYPE_p_pj__AccountSipConfig, SWIG_POINTER_NEW |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_delete_AccountSipConfig(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::AccountSipConfig *arg1 = (pj::AccountSipConfig *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__AccountSipConfig, SWIG_POINTER_DISOWN |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "delete_AccountSipConfig" "', argument " "1"" of type '" "pj::AccountSipConfig *""'"); 
  }
  arg1 = reinterpret_cast< pj::AccountSipConfig * >(argp1);
  delete arg1;
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *AccountSipConfig_swigregister(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *obj;
  if (!SWIG_Python_UnpackTuple(args, "swigregister", 1, 1, &obj)) return NULL;
  SWIG_TypeNewClientData(SWIGTYPE_p_pj__AccountSipConfig, SWIG_NewClientData(obj));
  return SWIG_Py_Void();
}

SWIGINTERN PyObject *AccountSipConfig_swiginit(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  return SWIG_Python_InitShadowInstance(args);
}

SWIGINTERN PyObject *_wrap_AccountCallConfig_holdType_set(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::AccountCallConfig *arg1 = (pj::AccountCallConfig *) 0 ;
  pjsua_call_hold_type arg2 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  int val2 ;
  int ecode2 = 0 ;
  PyObject *swig_obj[2] ;
  
  if (!SWIG_Python_UnpackTuple(args, "AccountCallConfig_holdType_set", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__AccountCallConfig, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "AccountCallConfig_holdType_set" "', argument " "1"" of type '" "pj::AccountCallConfig *""'"); 
  }
  arg1 = reinterpret_cast< pj::AccountCallConfig * >(argp1);
  ecode2 = SWIG_AsVal_int(swig_obj[1], &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "AccountCallConfig_holdType_set" "', argument " "2"" of type '" "pjsua_call_hold_type""'");
  } 
  arg2 = static_cast< pjsua_call_hold_type >(val2);
  if (arg1) (arg1)->holdType = arg2;
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_AccountCallConfig_holdType_get(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::AccountCallConfig *arg1 = (pj::AccountCallConfig *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  pjsua_call_hold_type result;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__AccountCallConfig, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "AccountCallConfig_holdType_get" "', argument " "1"" of type '" "pj::AccountCallConfig *""'"); 
  }
  arg1 = reinterpret_cast< pj::AccountCallConfig * >(argp1);
  result = (pjsua_call_hold_type) ((arg1)->holdType);
  resultobj = SWIG_From_int(static_cast< int >(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_AccountCallConfig_prackUse_set(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::AccountCallConfig *arg1 = (pj::AccountCallConfig *) 0 ;
  pjsua_100rel_use arg2 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  int val2 ;
  int ecode2 = 0 ;
  PyObject *swig_obj[2] ;
  
  if (!SWIG_Python_UnpackTuple(args, "AccountCallConfig_prackUse_set", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__AccountCallConfig, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "AccountCallConfig_prackUse_set" "', argument " "1"" of type '" "pj::AccountCallConfig *""'"); 
  }
  arg1 = reinterpret_cast< pj::AccountCallConfig * >(argp1);
  ecode2 = SWIG_AsVal_int(swig_obj[1], &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "AccountCallConfig_prackUse_set" "', argument " "2"" of type '" "pjsua_100rel_use""'");
  } 
  arg2 = static_cast< pjsua_100rel_use >(val2);
  if (arg1) (arg1)->prackUse = arg2;
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_AccountCallConfig_prackUse_get(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::AccountCallConfig *arg1 = (pj::AccountCallConfig *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  pjsua_100rel_use result;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__AccountCallConfig, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "AccountCallConfig_prackUse_get" "', argument " "1"" of type '" "pj::AccountCallConfig *""'"); 
  }
  arg1 = reinterpret_cast< pj::AccountCallConfig * >(argp1);
  result = (pjsua_100rel_use) ((arg1)->prackUse);
  resultobj = SWIG_From_int(static_cast< int >(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_AccountCallConfig_timerUse_set(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::AccountCallConfig *arg1 = (pj::AccountCallConfig *) 0 ;
  pjsua_sip_timer_use arg2 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  int val2 ;
  int ecode2 = 0 ;
  PyObject *swig_obj[2] ;
  
  if (!SWIG_Python_UnpackTuple(args, "AccountCallConfig_timerUse_set", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__AccountCallConfig, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "AccountCallConfig_timerUse_set" "', argument " "1"" of type '" "pj::AccountCallConfig *""'"); 
  }
  arg1 = reinterpret_cast< pj::AccountCallConfig * >(argp1);
  ecode2 = SWIG_AsVal_int(swig_obj[1], &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "AccountCallConfig_timerUse_set" "', argument " "2"" of type '" "pjsua_sip_timer_use""'");
  } 
  arg2 = static_cast< pjsua_sip_timer_use >(val2);
  if (arg1) (arg1)->timerUse = arg2;
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_AccountCallConfig_timerUse_get(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::AccountCallConfig *arg1 = (pj::AccountCallConfig *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  pjsua_sip_timer_use result;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__AccountCallConfig, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "AccountCallConfig_timerUse_get" "', argument " "1"" of type '" "pj::AccountCallConfig *""'"); 
  }
  arg1 = reinterpret_cast< pj::AccountCallConfig * >(argp1);
  result = (pjsua_sip_timer_use) ((arg1)->timerUse);
  resultobj = SWIG_From_int(static_cast< int >(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_AccountCallConfig_timerMinSESec_set(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::AccountCallConfig *arg1 = (pj::AccountCallConfig *) 0 ;
  unsigned int arg2 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  unsigned int val2 ;
  int ecode2 = 0 ;
  PyObject *swig_obj[2] ;
  
  if (!SWIG_Python_UnpackTuple(args, "AccountCallConfig_timerMinSESec_set", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__AccountCallConfig, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "AccountCallConfig_timerMinSESec_set" "', argument " "1"" of type '" "pj::AccountCallConfig *""'"); 
  }
  arg1 = reinterpret_cast< pj::AccountCallConfig * >(argp1);
  ecode2 = SWIG_AsVal_unsigned_SS_int(swig_obj[1], &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "AccountCallConfig_timerMinSESec_set" "', argument " "2"" of type '" "unsigned int""'");
  } 
  arg2 = static_cast< unsigned int >(val2);
  if (arg1) (arg1)->timerMinSESec = arg2;
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_AccountCallConfig_timerMinSESec_get(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::AccountCallConfig *arg1 = (pj::AccountCallConfig *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  unsigned int result;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__AccountCallConfig, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "AccountCallConfig_timerMinSESec_get" "', argument " "1"" of type '" "pj::AccountCallConfig *""'"); 
  }
  arg1 = reinterpret_cast< pj::AccountCallConfig * >(argp1);
  result = (unsigned int) ((arg1)->timerMinSESec);
  resultobj = SWIG_From_unsigned_SS_int(static_cast< unsigned int >(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_AccountCallConfig_timerSessExpiresSec_set(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::AccountCallConfig *arg1 = (pj::AccountCallConfig *) 0 ;
  unsigned int arg2 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  unsigned int val2 ;
  int ecode2 = 0 ;
  PyObject *swig_obj[2] ;
  
  if (!SWIG_Python_UnpackTuple(args, "AccountCallConfig_timerSessExpiresSec_set", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__AccountCallConfig, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "AccountCallConfig_timerSessExpiresSec_set" "', argument " "1"" of type '" "pj::AccountCallConfig *""'"); 
  }
  arg1 = reinterpret_cast< pj::AccountCallConfig * >(argp1);
  ecode2 = SWIG_AsVal_unsigned_SS_int(swig_obj[1], &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "AccountCallConfig_timerSessExpiresSec_set" "', argument " "2"" of type '" "unsigned int""'");
  } 
  arg2 = static_cast< unsigned int >(val2);
  if (arg1) (arg1)->timerSessExpiresSec = arg2;
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_AccountCallConfig_timerSessExpiresSec_get(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::AccountCallConfig *arg1 = (pj::AccountCallConfig *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  unsigned int result;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__AccountCallConfig, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "AccountCallConfig_timerSessExpiresSec_get" "', argument " "1"" of type '" "pj::AccountCallConfig *""'"); 
  }
  arg1 = reinterpret_cast< pj::AccountCallConfig * >(argp1);
  result = (unsigned int) ((arg1)->timerSessExpiresSec);
  resultobj = SWIG_From_unsigned_SS_int(static_cast< unsigned int >(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_new_AccountCallConfig(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::AccountCallConfig *result = 0 ;
  
  if (!SWIG_Python_UnpackTuple(args, "new_AccountCallConfig", 0, 0, 0)) SWIG_fail;
  result = (pj::AccountCallConfig *)new pj::AccountCallConfig();
  resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(result), SWIGTYPE_p_pj__AccountCallConfig, SWIG_POINTER_NEW |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_AccountCallConfig_readObject(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::AccountCallConfig *arg1 = (pj::AccountCallConfig *) 0 ;
  pj::ContainerNode *arg2 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  void *argp2 = 0 ;
  int res2 = 0 ;
  PyObject *swig_obj[2] ;
  
  if (!SWIG_Python_UnpackTuple(args, "AccountCallConfig_readObject", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__AccountCallConfig, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "AccountCallConfig_readObject" "', argument " "1"" of type '" "pj::AccountCallConfig *""'"); 
  }
  arg1 = reinterpret_cast< pj::AccountCallConfig * >(argp1);
  res2 = SWIG_ConvertPtr(swig_obj[1], &argp2, SWIGTYPE_p_pj__ContainerNode,  0  | 0);
  if (!SWIG_IsOK(res2)) {
    SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "AccountCallConfig_readObject" "', argument " "2"" of type '" "pj::ContainerNode const &""'"); 
  }
  if (!argp2) {
    SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "AccountCallConfig_readObject" "', argument " "2"" of type '" "pj::ContainerNode const &""'"); 
  }
  arg2 = reinterpret_cast< pj::ContainerNode * >(argp2);
  try {
    (arg1)->readObject((pj::ContainerNode const &)*arg2);
  } catch(pj::Error &_e) {
    SWIG_Python_Raise(SWIG_NewPointerObj((new pj::Error(static_cast< const pj::Error& >(_e))),SWIGTYPE_p_pj__Error,SWIG_POINTER_OWN), "pj::Error", SWIGTYPE_p_pj__Error); SWIG_fail;
  }
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_AccountCallConfig_writeObject(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::AccountCallConfig *arg1 = (pj::AccountCallConfig *) 0 ;
  pj::ContainerNode *arg2 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  void *argp2 = 0 ;
  int res2 = 0 ;
  PyObject *swig_obj[2] ;
  
  if (!SWIG_Python_UnpackTuple(args, "AccountCallConfig_writeObject", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__AccountCallConfig, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "AccountCallConfig_writeObject" "', argument " "1"" of type '" "pj::AccountCallConfig const *""'"); 
  }
  arg1 = reinterpret_cast< pj::AccountCallConfig * >(argp1);
  res2 = SWIG_ConvertPtr(swig_obj[1], &argp2, SWIGTYPE_p_pj__ContainerNode,  0 );
  if (!SWIG_IsOK(res2)) {
    SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "AccountCallConfig_writeObject" "', argument " "2"" of type '" "pj::ContainerNode &""'"); 
  }
  if (!argp2) {
    SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "AccountCallConfig_writeObject" "', argument " "2"" of type '" "pj::ContainerNode &""'"); 
  }
  arg2 = reinterpret_cast< pj::ContainerNode * >(argp2);
  try {
    ((pj::AccountCallConfig const *)arg1)->writeObject(*arg2);
  } catch(pj::Error &_e) {
    SWIG_Python_Raise(SWIG_NewPointerObj((new pj::Error(static_cast< const pj::Error& >(_e))),SWIGTYPE_p_pj__Error,SWIG_POINTER_OWN), "pj::Error", SWIGTYPE_p_pj__Error); SWIG_fail;
  }
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_delete_AccountCallConfig(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::AccountCallConfig *arg1 = (pj::AccountCallConfig *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__AccountCallConfig, SWIG_POINTER_DISOWN |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "delete_AccountCallConfig" "', argument " "1"" of type '" "pj::AccountCallConfig *""'"); 
  }
  arg1 = reinterpret_cast< pj::AccountCallConfig * >(argp1);
  delete arg1;
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *AccountCallConfig_swigregister(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *obj;
  if (!SWIG_Python_UnpackTuple(args, "swigregister", 1, 1, &obj)) return NULL;
  SWIG_TypeNewClientData(SWIGTYPE_p_pj__AccountCallConfig, SWIG_NewClientData(obj));
  return SWIG_Py_Void();
}

SWIGINTERN PyObject *AccountCallConfig_swiginit(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  return SWIG_Python_InitShadowInstance(args);
}

SWIGINTERN PyObject *_wrap_AccountPresConfig_headers_set(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::AccountPresConfig *arg1 = (pj::AccountPresConfig *) 0 ;
  pj::SipHeaderVector *arg2 = (pj::SipHeaderVector *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  void *argp2 = 0 ;
  int res2 = 0 ;
  PyObject *swig_obj[2] ;
  
  if (!SWIG_Python_UnpackTuple(args, "AccountPresConfig_headers_set", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__AccountPresConfig, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "AccountPresConfig_headers_set" "', argument " "1"" of type '" "pj::AccountPresConfig *""'"); 
  }
  arg1 = reinterpret_cast< pj::AccountPresConfig * >(argp1);
  res2 = SWIG_ConvertPtr(swig_obj[1], &argp2,SWIGTYPE_p_std__vectorT_pj__SipHeader_std__allocatorT_pj__SipHeader_t_t, 0 |  0 );
  if (!SWIG_IsOK(res2)) {
    SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "AccountPresConfig_headers_set" "', argument " "2"" of type '" "pj::SipHeaderVector *""'"); 
  }
  arg2 = reinterpret_cast< pj::SipHeaderVector * >(argp2);
  if (arg1) (arg1)->headers = *arg2;
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_AccountPresConfig_headers_get(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::AccountPresConfig *arg1 = (pj::AccountPresConfig *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  pj::SipHeaderVector *result = 0 ;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__AccountPresConfig, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "AccountPresConfig_headers_get" "', argument " "1"" of type '" "pj::AccountPresConfig *""'"); 
  }
  arg1 = reinterpret_cast< pj::AccountPresConfig * >(argp1);
  result = (pj::SipHeaderVector *)& ((arg1)->headers);
  resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(result), SWIGTYPE_p_std__vectorT_pj__SipHeader_std__allocatorT_pj__SipHeader_t_t, 0 |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_AccountPresConfig_publishEnabled_set(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::AccountPresConfig *arg1 = (pj::AccountPresConfig *) 0 ;
  bool arg2 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  bool val2 ;
  int ecode2 = 0 ;
  PyObject *swig_obj[2] ;
  
  if (!SWIG_Python_UnpackTuple(args, "AccountPresConfig_publishEnabled_set", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__AccountPresConfig, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "AccountPresConfig_publishEnabled_set" "', argument " "1"" of type '" "pj::AccountPresConfig *""'"); 
  }
  arg1 = reinterpret_cast< pj::AccountPresConfig * >(argp1);
  ecode2 = SWIG_AsVal_bool(swig_obj[1], &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "AccountPresConfig_publishEnabled_set" "', argument " "2"" of type '" "bool""'");
  } 
  arg2 = static_cast< bool >(val2);
  if (arg1) (arg1)->publishEnabled = arg2;
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_AccountPresConfig_publishEnabled_get(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::AccountPresConfig *arg1 = (pj::AccountPresConfig *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  bool result;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__AccountPresConfig, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "AccountPresConfig_publishEnabled_get" "', argument " "1"" of type '" "pj::AccountPresConfig *""'"); 
  }
  arg1 = reinterpret_cast< pj::AccountPresConfig * >(argp1);
  result = (bool) ((arg1)->publishEnabled);
  resultobj = SWIG_From_bool(static_cast< bool >(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_AccountPresConfig_publishQueue_set(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::AccountPresConfig *arg1 = (pj::AccountPresConfig *) 0 ;
  bool arg2 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  bool val2 ;
  int ecode2 = 0 ;
  PyObject *swig_obj[2] ;
  
  if (!SWIG_Python_UnpackTuple(args, "AccountPresConfig_publishQueue_set", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__AccountPresConfig, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "AccountPresConfig_publishQueue_set" "', argument " "1"" of type '" "pj::AccountPresConfig *""'"); 
  }
  arg1 = reinterpret_cast< pj::AccountPresConfig * >(argp1);
  ecode2 = SWIG_AsVal_bool(swig_obj[1], &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "AccountPresConfig_publishQueue_set" "', argument " "2"" of type '" "bool""'");
  } 
  arg2 = static_cast< bool >(val2);
  if (arg1) (arg1)->publishQueue = arg2;
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_AccountPresConfig_publishQueue_get(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::AccountPresConfig *arg1 = (pj::AccountPresConfig *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  bool result;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__AccountPresConfig, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "AccountPresConfig_publishQueue_get" "', argument " "1"" of type '" "pj::AccountPresConfig *""'"); 
  }
  arg1 = reinterpret_cast< pj::AccountPresConfig * >(argp1);
  result = (bool) ((arg1)->publishQueue);
  resultobj = SWIG_From_bool(static_cast< bool >(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_AccountPresConfig_publishShutdownWaitMsec_set(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::AccountPresConfig *arg1 = (pj::AccountPresConfig *) 0 ;
  unsigned int arg2 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  unsigned int val2 ;
  int ecode2 = 0 ;
  PyObject *swig_obj[2] ;
  
  if (!SWIG_Python_UnpackTuple(args, "AccountPresConfig_publishShutdownWaitMsec_set", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__AccountPresConfig, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "AccountPresConfig_publishShutdownWaitMsec_set" "', argument " "1"" of type '" "pj::AccountPresConfig *""'"); 
  }
  arg1 = reinterpret_cast< pj::AccountPresConfig * >(argp1);
  ecode2 = SWIG_AsVal_unsigned_SS_int(swig_obj[1], &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "AccountPresConfig_publishShutdownWaitMsec_set" "', argument " "2"" of type '" "unsigned int""'");
  } 
  arg2 = static_cast< unsigned int >(val2);
  if (arg1) (arg1)->publishShutdownWaitMsec = arg2;
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_AccountPresConfig_publishShutdownWaitMsec_get(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::AccountPresConfig *arg1 = (pj::AccountPresConfig *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  unsigned int result;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__AccountPresConfig, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "AccountPresConfig_publishShutdownWaitMsec_get" "', argument " "1"" of type '" "pj::AccountPresConfig *""'"); 
  }
  arg1 = reinterpret_cast< pj::AccountPresConfig * >(argp1);
  result = (unsigned int) ((arg1)->publishShutdownWaitMsec);
  resultobj = SWIG_From_unsigned_SS_int(static_cast< unsigned int >(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_AccountPresConfig_pidfTupleId_set(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::AccountPresConfig *arg1 = (pj::AccountPresConfig *) 0 ;
  pj::string *arg2 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  int res2 = SWIG_OLDOBJ ;
  PyObject *swig_obj[2] ;
  
  if (!SWIG_Python_UnpackTuple(args, "AccountPresConfig_pidfTupleId_set", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__AccountPresConfig, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "AccountPresConfig_pidfTupleId_set" "', argument " "1"" of type '" "pj::AccountPresConfig *""'"); 
  }
  arg1 = reinterpret_cast< pj::AccountPresConfig * >(argp1);
  {
    std::string *ptr = (std::string *)0;
    res2 = SWIG_AsPtr_std_string(swig_obj[1], &ptr);
    if (!SWIG_IsOK(res2)) {
      SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "AccountPresConfig_pidfTupleId_set" "', argument " "2"" of type '" "pj::string const &""'"); 
    }
    if (!ptr) {
      SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "AccountPresConfig_pidfTupleId_set" "', argument " "2"" of type '" "pj::string const &""'"); 
    }
    arg2 = ptr;
  }
  if (arg1) (arg1)->pidfTupleId = *arg2;
  resultobj = SWIG_Py_Void();
  if (SWIG_IsNewObj(res2)) delete arg2;
  return resultobj;
fail:
  if (SWIG_IsNewObj(res2)) delete arg2;
  return NULL;
}


SWIGINTERN PyObject *_wrap_AccountPresConfig_pidfTupleId_get(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::AccountPresConfig *arg1 = (pj::AccountPresConfig *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  pj::string *result = 0 ;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__AccountPresConfig, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "AccountPresConfig_pidfTupleId_get" "', argument " "1"" of type '" "pj::AccountPresConfig *""'"); 
  }
  arg1 = reinterpret_cast< pj::AccountPresConfig * >(argp1);
  result = (pj::string *) & ((arg1)->pidfTupleId);
  resultobj = SWIG_From_std_string(static_cast< std::string >(*result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_AccountPresConfig_readObject(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::AccountPresConfig *arg1 = (pj::AccountPresConfig *) 0 ;
  pj::ContainerNode *arg2 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  void *argp2 = 0 ;
  int res2 = 0 ;
  PyObject *swig_obj[2] ;
  
  if (!SWIG_Python_UnpackTuple(args, "AccountPresConfig_readObject", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__AccountPresConfig, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "AccountPresConfig_readObject" "', argument " "1"" of type '" "pj::AccountPresConfig *""'"); 
  }
  arg1 = reinterpret_cast< pj::AccountPresConfig * >(argp1);
  res2 = SWIG_ConvertPtr(swig_obj[1], &argp2, SWIGTYPE_p_pj__ContainerNode,  0  | 0);
  if (!SWIG_IsOK(res2)) {
    SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "AccountPresConfig_readObject" "', argument " "2"" of type '" "pj::ContainerNode const &""'"); 
  }
  if (!argp2) {
    SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "AccountPresConfig_readObject" "', argument " "2"" of type '" "pj::ContainerNode const &""'"); 
  }
  arg2 = reinterpret_cast< pj::ContainerNode * >(argp2);
  try {
    (arg1)->readObject((pj::ContainerNode const &)*arg2);
  } catch(pj::Error &_e) {
    SWIG_Python_Raise(SWIG_NewPointerObj((new pj::Error(static_cast< const pj::Error& >(_e))),SWIGTYPE_p_pj__Error,SWIG_POINTER_OWN), "pj::Error", SWIGTYPE_p_pj__Error); SWIG_fail;
  }
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_AccountPresConfig_writeObject(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::AccountPresConfig *arg1 = (pj::AccountPresConfig *) 0 ;
  pj::ContainerNode *arg2 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  void *argp2 = 0 ;
  int res2 = 0 ;
  PyObject *swig_obj[2] ;
  
  if (!SWIG_Python_UnpackTuple(args, "AccountPresConfig_writeObject", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__AccountPresConfig, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "AccountPresConfig_writeObject" "', argument " "1"" of type '" "pj::AccountPresConfig const *""'"); 
  }
  arg1 = reinterpret_cast< pj::AccountPresConfig * >(argp1);
  res2 = SWIG_ConvertPtr(swig_obj[1], &argp2, SWIGTYPE_p_pj__ContainerNode,  0 );
  if (!SWIG_IsOK(res2)) {
    SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "AccountPresConfig_writeObject" "', argument " "2"" of type '" "pj::ContainerNode &""'"); 
  }
  if (!argp2) {
    SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "AccountPresConfig_writeObject" "', argument " "2"" of type '" "pj::ContainerNode &""'"); 
  }
  arg2 = reinterpret_cast< pj::ContainerNode * >(argp2);
  try {
    ((pj::AccountPresConfig const *)arg1)->writeObject(*arg2);
  } catch(pj::Error &_e) {
    SWIG_Python_Raise(SWIG_NewPointerObj((new pj::Error(static_cast< const pj::Error& >(_e))),SWIGTYPE_p_pj__Error,SWIG_POINTER_OWN), "pj::Error", SWIGTYPE_p_pj__Error); SWIG_fail;
  }
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_new_AccountPresConfig(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::AccountPresConfig *result = 0 ;
  
  if (!SWIG_Python_UnpackTuple(args, "new_AccountPresConfig", 0, 0, 0)) SWIG_fail;
  result = (pj::AccountPresConfig *)new pj::AccountPresConfig();
  resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(result), SWIGTYPE_p_pj__AccountPresConfig, SWIG_POINTER_NEW |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_delete_AccountPresConfig(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::AccountPresConfig *arg1 = (pj::AccountPresConfig *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__AccountPresConfig, SWIG_POINTER_DISOWN |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "delete_AccountPresConfig" "', argument " "1"" of type '" "pj::AccountPresConfig *""'"); 
  }
  arg1 = reinterpret_cast< pj::AccountPresConfig * >(argp1);
  delete arg1;
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *AccountPresConfig_swigregister(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *obj;
  if (!SWIG_Python_UnpackTuple(args, "swigregister", 1, 1, &obj)) return NULL;
  SWIG_TypeNewClientData(SWIGTYPE_p_pj__AccountPresConfig, SWIG_NewClientData(obj));
  return SWIG_Py_Void();
}

SWIGINTERN PyObject *AccountPresConfig_swiginit(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  return SWIG_Python_InitShadowInstance(args);
}

SWIGINTERN PyObject *_wrap_AccountMwiConfig_enabled_set(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::AccountMwiConfig *arg1 = (pj::AccountMwiConfig *) 0 ;
  bool arg2 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  bool val2 ;
  int ecode2 = 0 ;
  PyObject *swig_obj[2] ;
  
  if (!SWIG_Python_UnpackTuple(args, "AccountMwiConfig_enabled_set", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__AccountMwiConfig, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "AccountMwiConfig_enabled_set" "', argument " "1"" of type '" "pj::AccountMwiConfig *""'"); 
  }
  arg1 = reinterpret_cast< pj::AccountMwiConfig * >(argp1);
  ecode2 = SWIG_AsVal_bool(swig_obj[1], &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "AccountMwiConfig_enabled_set" "', argument " "2"" of type '" "bool""'");
  } 
  arg2 = static_cast< bool >(val2);
  if (arg1) (arg1)->enabled = arg2;
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_AccountMwiConfig_enabled_get(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::AccountMwiConfig *arg1 = (pj::AccountMwiConfig *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  bool result;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__AccountMwiConfig, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "AccountMwiConfig_enabled_get" "', argument " "1"" of type '" "pj::AccountMwiConfig *""'"); 
  }
  arg1 = reinterpret_cast< pj::AccountMwiConfig * >(argp1);
  result = (bool) ((arg1)->enabled);
  resultobj = SWIG_From_bool(static_cast< bool >(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_AccountMwiConfig_expirationSec_set(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::AccountMwiConfig *arg1 = (pj::AccountMwiConfig *) 0 ;
  unsigned int arg2 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  unsigned int val2 ;
  int ecode2 = 0 ;
  PyObject *swig_obj[2] ;
  
  if (!SWIG_Python_UnpackTuple(args, "AccountMwiConfig_expirationSec_set", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__AccountMwiConfig, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "AccountMwiConfig_expirationSec_set" "', argument " "1"" of type '" "pj::AccountMwiConfig *""'"); 
  }
  arg1 = reinterpret_cast< pj::AccountMwiConfig * >(argp1);
  ecode2 = SWIG_AsVal_unsigned_SS_int(swig_obj[1], &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "AccountMwiConfig_expirationSec_set" "', argument " "2"" of type '" "unsigned int""'");
  } 
  arg2 = static_cast< unsigned int >(val2);
  if (arg1) (arg1)->expirationSec = arg2;
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_AccountMwiConfig_expirationSec_get(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::AccountMwiConfig *arg1 = (pj::AccountMwiConfig *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  unsigned int result;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__AccountMwiConfig, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "AccountMwiConfig_expirationSec_get" "', argument " "1"" of type '" "pj::AccountMwiConfig *""'"); 
  }
  arg1 = reinterpret_cast< pj::AccountMwiConfig * >(argp1);
  result = (unsigned int) ((arg1)->expirationSec);
  resultobj = SWIG_From_unsigned_SS_int(static_cast< unsigned int >(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_AccountMwiConfig_readObject(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::AccountMwiConfig *arg1 = (pj::AccountMwiConfig *) 0 ;
  pj::ContainerNode *arg2 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  void *argp2 = 0 ;
  int res2 = 0 ;
  PyObject *swig_obj[2] ;
  
  if (!SWIG_Python_UnpackTuple(args, "AccountMwiConfig_readObject", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__AccountMwiConfig, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "AccountMwiConfig_readObject" "', argument " "1"" of type '" "pj::AccountMwiConfig *""'"); 
  }
  arg1 = reinterpret_cast< pj::AccountMwiConfig * >(argp1);
  res2 = SWIG_ConvertPtr(swig_obj[1], &argp2, SWIGTYPE_p_pj__ContainerNode,  0  | 0);
  if (!SWIG_IsOK(res2)) {
    SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "AccountMwiConfig_readObject" "', argument " "2"" of type '" "pj::ContainerNode const &""'"); 
  }
  if (!argp2) {
    SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "AccountMwiConfig_readObject" "', argument " "2"" of type '" "pj::ContainerNode const &""'"); 
  }
  arg2 = reinterpret_cast< pj::ContainerNode * >(argp2);
  try {
    (arg1)->readObject((pj::ContainerNode const &)*arg2);
  } catch(pj::Error &_e) {
    SWIG_Python_Raise(SWIG_NewPointerObj((new pj::Error(static_cast< const pj::Error& >(_e))),SWIGTYPE_p_pj__Error,SWIG_POINTER_OWN), "pj::Error", SWIGTYPE_p_pj__Error); SWIG_fail;
  }
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_AccountMwiConfig_writeObject(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::AccountMwiConfig *arg1 = (pj::AccountMwiConfig *) 0 ;
  pj::ContainerNode *arg2 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  void *argp2 = 0 ;
  int res2 = 0 ;
  PyObject *swig_obj[2] ;
  
  if (!SWIG_Python_UnpackTuple(args, "AccountMwiConfig_writeObject", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__AccountMwiConfig, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "AccountMwiConfig_writeObject" "', argument " "1"" of type '" "pj::AccountMwiConfig const *""'"); 
  }
  arg1 = reinterpret_cast< pj::AccountMwiConfig * >(argp1);
  res2 = SWIG_ConvertPtr(swig_obj[1], &argp2, SWIGTYPE_p_pj__ContainerNode,  0 );
  if (!SWIG_IsOK(res2)) {
    SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "AccountMwiConfig_writeObject" "', argument " "2"" of type '" "pj::ContainerNode &""'"); 
  }
  if (!argp2) {
    SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "AccountMwiConfig_writeObject" "', argument " "2"" of type '" "pj::ContainerNode &""'"); 
  }
  arg2 = reinterpret_cast< pj::ContainerNode * >(argp2);
  try {
    ((pj::AccountMwiConfig const *)arg1)->writeObject(*arg2);
  } catch(pj::Error &_e) {
    SWIG_Python_Raise(SWIG_NewPointerObj((new pj::Error(static_cast< const pj::Error& >(_e))),SWIGTYPE_p_pj__Error,SWIG_POINTER_OWN), "pj::Error", SWIGTYPE_p_pj__Error); SWIG_fail;
  }
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_new_AccountMwiConfig(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::AccountMwiConfig *result = 0 ;
  
  if (!SWIG_Python_UnpackTuple(args, "new_AccountMwiConfig", 0, 0, 0)) SWIG_fail;
  result = (pj::AccountMwiConfig *)new pj::AccountMwiConfig();
  resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(result), SWIGTYPE_p_pj__AccountMwiConfig, SWIG_POINTER_NEW |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_delete_AccountMwiConfig(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::AccountMwiConfig *arg1 = (pj::AccountMwiConfig *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__AccountMwiConfig, SWIG_POINTER_DISOWN |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "delete_AccountMwiConfig" "', argument " "1"" of type '" "pj::AccountMwiConfig *""'"); 
  }
  arg1 = reinterpret_cast< pj::AccountMwiConfig * >(argp1);
  delete arg1;
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *AccountMwiConfig_swigregister(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *obj;
  if (!SWIG_Python_UnpackTuple(args, "swigregister", 1, 1, &obj)) return NULL;
  SWIG_TypeNewClientData(SWIGTYPE_p_pj__AccountMwiConfig, SWIG_NewClientData(obj));
  return SWIG_Py_Void();
}

SWIGINTERN PyObject *AccountMwiConfig_swiginit(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  return SWIG_Python_InitShadowInstance(args);
}

SWIGINTERN PyObject *_wrap_AccountNatConfig_sipStunUse_set(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::AccountNatConfig *arg1 = (pj::AccountNatConfig *) 0 ;
  pjsua_stun_use arg2 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  int val2 ;
  int ecode2 = 0 ;
  PyObject *swig_obj[2] ;
  
  if (!SWIG_Python_UnpackTuple(args, "AccountNatConfig_sipStunUse_set", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__AccountNatConfig, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "AccountNatConfig_sipStunUse_set" "', argument " "1"" of type '" "pj::AccountNatConfig *""'"); 
  }
  arg1 = reinterpret_cast< pj::AccountNatConfig * >(argp1);
  ecode2 = SWIG_AsVal_int(swig_obj[1], &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "AccountNatConfig_sipStunUse_set" "', argument " "2"" of type '" "pjsua_stun_use""'");
  } 
  arg2 = static_cast< pjsua_stun_use >(val2);
  if (arg1) (arg1)->sipStunUse = arg2;
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_AccountNatConfig_sipStunUse_get(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::AccountNatConfig *arg1 = (pj::AccountNatConfig *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  pjsua_stun_use result;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__AccountNatConfig, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "AccountNatConfig_sipStunUse_get" "', argument " "1"" of type '" "pj::AccountNatConfig *""'"); 
  }
  arg1 = reinterpret_cast< pj::AccountNatConfig * >(argp1);
  result = (pjsua_stun_use) ((arg1)->sipStunUse);
  resultobj = SWIG_From_int(static_cast< int >(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_AccountNatConfig_mediaStunUse_set(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::AccountNatConfig *arg1 = (pj::AccountNatConfig *) 0 ;
  pjsua_stun_use arg2 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  int val2 ;
  int ecode2 = 0 ;
  PyObject *swig_obj[2] ;
  
  if (!SWIG_Python_UnpackTuple(args, "AccountNatConfig_mediaStunUse_set", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__AccountNatConfig, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "AccountNatConfig_mediaStunUse_set" "', argument " "1"" of type '" "pj::AccountNatConfig *""'"); 
  }
  arg1 = reinterpret_cast< pj::AccountNatConfig * >(argp1);
  ecode2 = SWIG_AsVal_int(swig_obj[1], &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "AccountNatConfig_mediaStunUse_set" "', argument " "2"" of type '" "pjsua_stun_use""'");
  } 
  arg2 = static_cast< pjsua_stun_use >(val2);
  if (arg1) (arg1)->mediaStunUse = arg2;
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_AccountNatConfig_mediaStunUse_get(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::AccountNatConfig *arg1 = (pj::AccountNatConfig *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  pjsua_stun_use result;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__AccountNatConfig, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "AccountNatConfig_mediaStunUse_get" "', argument " "1"" of type '" "pj::AccountNatConfig *""'"); 
  }
  arg1 = reinterpret_cast< pj::AccountNatConfig * >(argp1);
  result = (pjsua_stun_use) ((arg1)->mediaStunUse);
  resultobj = SWIG_From_int(static_cast< int >(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_AccountNatConfig_nat64Opt_set(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::AccountNatConfig *arg1 = (pj::AccountNatConfig *) 0 ;
  pjsua_nat64_opt arg2 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  int val2 ;
  int ecode2 = 0 ;
  PyObject *swig_obj[2] ;
  
  if (!SWIG_Python_UnpackTuple(args, "AccountNatConfig_nat64Opt_set", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__AccountNatConfig, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "AccountNatConfig_nat64Opt_set" "', argument " "1"" of type '" "pj::AccountNatConfig *""'"); 
  }
  arg1 = reinterpret_cast< pj::AccountNatConfig * >(argp1);
  ecode2 = SWIG_AsVal_int(swig_obj[1], &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "AccountNatConfig_nat64Opt_set" "', argument " "2"" of type '" "pjsua_nat64_opt""'");
  } 
  arg2 = static_cast< pjsua_nat64_opt >(val2);
  if (arg1) (arg1)->nat64Opt = arg2;
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_AccountNatConfig_nat64Opt_get(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::AccountNatConfig *arg1 = (pj::AccountNatConfig *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  pjsua_nat64_opt result;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__AccountNatConfig, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "AccountNatConfig_nat64Opt_get" "', argument " "1"" of type '" "pj::AccountNatConfig *""'"); 
  }
  arg1 = reinterpret_cast< pj::AccountNatConfig * >(argp1);
  result = (pjsua_nat64_opt) ((arg1)->nat64Opt);
  resultobj = SWIG_From_int(static_cast< int >(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_AccountNatConfig_iceEnabled_set(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::AccountNatConfig *arg1 = (pj::AccountNatConfig *) 0 ;
  bool arg2 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  bool val2 ;
  int ecode2 = 0 ;
  PyObject *swig_obj[2] ;
  
  if (!SWIG_Python_UnpackTuple(args, "AccountNatConfig_iceEnabled_set", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__AccountNatConfig, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "AccountNatConfig_iceEnabled_set" "', argument " "1"" of type '" "pj::AccountNatConfig *""'"); 
  }
  arg1 = reinterpret_cast< pj::AccountNatConfig * >(argp1);
  ecode2 = SWIG_AsVal_bool(swig_obj[1], &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "AccountNatConfig_iceEnabled_set" "', argument " "2"" of type '" "bool""'");
  } 
  arg2 = static_cast< bool >(val2);
  if (arg1) (arg1)->iceEnabled = arg2;
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_AccountNatConfig_iceEnabled_get(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::AccountNatConfig *arg1 = (pj::AccountNatConfig *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  bool result;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__AccountNatConfig, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "AccountNatConfig_iceEnabled_get" "', argument " "1"" of type '" "pj::AccountNatConfig *""'"); 
  }
  arg1 = reinterpret_cast< pj::AccountNatConfig * >(argp1);
  result = (bool) ((arg1)->iceEnabled);
  resultobj = SWIG_From_bool(static_cast< bool >(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_AccountNatConfig_iceTrickle_set(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::AccountNatConfig *arg1 = (pj::AccountNatConfig *) 0 ;
  pj_ice_sess_trickle arg2 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  int val2 ;
  int ecode2 = 0 ;
  PyObject *swig_obj[2] ;
  
  if (!SWIG_Python_UnpackTuple(args, "AccountNatConfig_iceTrickle_set", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__AccountNatConfig, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "AccountNatConfig_iceTrickle_set" "', argument " "1"" of type '" "pj::AccountNatConfig *""'"); 
  }
  arg1 = reinterpret_cast< pj::AccountNatConfig * >(argp1);
  ecode2 = SWIG_AsVal_int(swig_obj[1], &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "AccountNatConfig_iceTrickle_set" "', argument " "2"" of type '" "pj_ice_sess_trickle""'");
  } 
  arg2 = static_cast< pj_ice_sess_trickle >(val2);
  if (arg1) (arg1)->iceTrickle = arg2;
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_AccountNatConfig_iceTrickle_get(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::AccountNatConfig *arg1 = (pj::AccountNatConfig *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  pj_ice_sess_trickle result;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__AccountNatConfig, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "AccountNatConfig_iceTrickle_get" "', argument " "1"" of type '" "pj::AccountNatConfig *""'"); 
  }
  arg1 = reinterpret_cast< pj::AccountNatConfig * >(argp1);
  result = (pj_ice_sess_trickle) ((arg1)->iceTrickle);
  resultobj = SWIG_From_int(static_cast< int >(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_AccountNatConfig_iceMaxHostCands_set(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::AccountNatConfig *arg1 = (pj::AccountNatConfig *) 0 ;
  int arg2 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  int val2 ;
  int ecode2 = 0 ;
  PyObject *swig_obj[2] ;
  
  if (!SWIG_Python_UnpackTuple(args, "AccountNatConfig_iceMaxHostCands_set", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__AccountNatConfig, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "AccountNatConfig_iceMaxHostCands_set" "', argument " "1"" of type '" "pj::AccountNatConfig *""'"); 
  }
  arg1 = reinterpret_cast< pj::AccountNatConfig * >(argp1);
  ecode2 = SWIG_AsVal_int(swig_obj[1], &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "AccountNatConfig_iceMaxHostCands_set" "', argument " "2"" of type '" "int""'");
  } 
  arg2 = static_cast< int >(val2);
  if (arg1) (arg1)->iceMaxHostCands = arg2;
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_AccountNatConfig_iceMaxHostCands_get(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::AccountNatConfig *arg1 = (pj::AccountNatConfig *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  int result;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__AccountNatConfig, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "AccountNatConfig_iceMaxHostCands_get" "', argument " "1"" of type '" "pj::AccountNatConfig *""'"); 
  }
  arg1 = reinterpret_cast< pj::AccountNatConfig * >(argp1);
  result = (int) ((arg1)->iceMaxHostCands);
  resultobj = SWIG_From_int(static_cast< int >(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_AccountNatConfig_iceAggressiveNomination_set(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::AccountNatConfig *arg1 = (pj::AccountNatConfig *) 0 ;
  bool arg2 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  bool val2 ;
  int ecode2 = 0 ;
  PyObject *swig_obj[2] ;
  
  if (!SWIG_Python_UnpackTuple(args, "AccountNatConfig_iceAggressiveNomination_set", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__AccountNatConfig, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "AccountNatConfig_iceAggressiveNomination_set" "', argument " "1"" of type '" "pj::AccountNatConfig *""'"); 
  }
  arg1 = reinterpret_cast< pj::AccountNatConfig * >(argp1);
  ecode2 = SWIG_AsVal_bool(swig_obj[1], &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "AccountNatConfig_iceAggressiveNomination_set" "', argument " "2"" of type '" "bool""'");
  } 
  arg2 = static_cast< bool >(val2);
  if (arg1) (arg1)->iceAggressiveNomination = arg2;
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_AccountNatConfig_iceAggressiveNomination_get(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::AccountNatConfig *arg1 = (pj::AccountNatConfig *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  bool result;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__AccountNatConfig, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "AccountNatConfig_iceAggressiveNomination_get" "', argument " "1"" of type '" "pj::AccountNatConfig *""'"); 
  }
  arg1 = reinterpret_cast< pj::AccountNatConfig * >(argp1);
  result = (bool) ((arg1)->iceAggressiveNomination);
  resultobj = SWIG_From_bool(static_cast< bool >(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_AccountNatConfig_iceNominatedCheckDelayMsec_set(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::AccountNatConfig *arg1 = (pj::AccountNatConfig *) 0 ;
  unsigned int arg2 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  unsigned int val2 ;
  int ecode2 = 0 ;
  PyObject *swig_obj[2] ;
  
  if (!SWIG_Python_UnpackTuple(args, "AccountNatConfig_iceNominatedCheckDelayMsec_set", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__AccountNatConfig, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "AccountNatConfig_iceNominatedCheckDelayMsec_set" "', argument " "1"" of type '" "pj::AccountNatConfig *""'"); 
  }
  arg1 = reinterpret_cast< pj::AccountNatConfig * >(argp1);
  ecode2 = SWIG_AsVal_unsigned_SS_int(swig_obj[1], &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "AccountNatConfig_iceNominatedCheckDelayMsec_set" "', argument " "2"" of type '" "unsigned int""'");
  } 
  arg2 = static_cast< unsigned int >(val2);
  if (arg1) (arg1)->iceNominatedCheckDelayMsec = arg2;
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_AccountNatConfig_iceNominatedCheckDelayMsec_get(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::AccountNatConfig *arg1 = (pj::AccountNatConfig *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  unsigned int result;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__AccountNatConfig, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "AccountNatConfig_iceNominatedCheckDelayMsec_get" "', argument " "1"" of type '" "pj::AccountNatConfig *""'"); 
  }
  arg1 = reinterpret_cast< pj::AccountNatConfig * >(argp1);
  result = (unsigned int) ((arg1)->iceNominatedCheckDelayMsec);
  resultobj = SWIG_From_unsigned_SS_int(static_cast< unsigned int >(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_AccountNatConfig_iceWaitNominationTimeoutMsec_set(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::AccountNatConfig *arg1 = (pj::AccountNatConfig *) 0 ;
  int arg2 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  int val2 ;
  int ecode2 = 0 ;
  PyObject *swig_obj[2] ;
  
  if (!SWIG_Python_UnpackTuple(args, "AccountNatConfig_iceWaitNominationTimeoutMsec_set", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__AccountNatConfig, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "AccountNatConfig_iceWaitNominationTimeoutMsec_set" "', argument " "1"" of type '" "pj::AccountNatConfig *""'"); 
  }
  arg1 = reinterpret_cast< pj::AccountNatConfig * >(argp1);
  ecode2 = SWIG_AsVal_int(swig_obj[1], &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "AccountNatConfig_iceWaitNominationTimeoutMsec_set" "', argument " "2"" of type '" "int""'");
  } 
  arg2 = static_cast< int >(val2);
  if (arg1) (arg1)->iceWaitNominationTimeoutMsec = arg2;
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_AccountNatConfig_iceWaitNominationTimeoutMsec_get(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::AccountNatConfig *arg1 = (pj::AccountNatConfig *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  int result;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__AccountNatConfig, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "AccountNatConfig_iceWaitNominationTimeoutMsec_get" "', argument " "1"" of type '" "pj::AccountNatConfig *""'"); 
  }
  arg1 = reinterpret_cast< pj::AccountNatConfig * >(argp1);
  result = (int) ((arg1)->iceWaitNominationTimeoutMsec);
  resultobj = SWIG_From_int(static_cast< int >(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_AccountNatConfig_iceNoRtcp_set(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::AccountNatConfig *arg1 = (pj::AccountNatConfig *) 0 ;
  bool arg2 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  bool val2 ;
  int ecode2 = 0 ;
  PyObject *swig_obj[2] ;
  
  if (!SWIG_Python_UnpackTuple(args, "AccountNatConfig_iceNoRtcp_set", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__AccountNatConfig, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "AccountNatConfig_iceNoRtcp_set" "', argument " "1"" of type '" "pj::AccountNatConfig *""'"); 
  }
  arg1 = reinterpret_cast< pj::AccountNatConfig * >(argp1);
  ecode2 = SWIG_AsVal_bool(swig_obj[1], &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "AccountNatConfig_iceNoRtcp_set" "', argument " "2"" of type '" "bool""'");
  } 
  arg2 = static_cast< bool >(val2);
  if (arg1) (arg1)->iceNoRtcp = arg2;
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_AccountNatConfig_iceNoRtcp_get(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::AccountNatConfig *arg1 = (pj::AccountNatConfig *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  bool result;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__AccountNatConfig, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "AccountNatConfig_iceNoRtcp_get" "', argument " "1"" of type '" "pj::AccountNatConfig *""'"); 
  }
  arg1 = reinterpret_cast< pj::AccountNatConfig * >(argp1);
  result = (bool) ((arg1)->iceNoRtcp);
  resultobj = SWIG_From_bool(static_cast< bool >(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_AccountNatConfig_iceAlwaysUpdate_set(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::AccountNatConfig *arg1 = (pj::AccountNatConfig *) 0 ;
  bool arg2 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  bool val2 ;
  int ecode2 = 0 ;
  PyObject *swig_obj[2] ;
  
  if (!SWIG_Python_UnpackTuple(args, "AccountNatConfig_iceAlwaysUpdate_set", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__AccountNatConfig, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "AccountNatConfig_iceAlwaysUpdate_set" "', argument " "1"" of type '" "pj::AccountNatConfig *""'"); 
  }
  arg1 = reinterpret_cast< pj::AccountNatConfig * >(argp1);
  ecode2 = SWIG_AsVal_bool(swig_obj[1], &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "AccountNatConfig_iceAlwaysUpdate_set" "', argument " "2"" of type '" "bool""'");
  } 
  arg2 = static_cast< bool >(val2);
  if (arg1) (arg1)->iceAlwaysUpdate = arg2;
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_AccountNatConfig_iceAlwaysUpdate_get(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::AccountNatConfig *arg1 = (pj::AccountNatConfig *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  bool result;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__AccountNatConfig, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "AccountNatConfig_iceAlwaysUpdate_get" "', argument " "1"" of type '" "pj::AccountNatConfig *""'"); 
  }
  arg1 = reinterpret_cast< pj::AccountNatConfig * >(argp1);
  result = (bool) ((arg1)->iceAlwaysUpdate);
  resultobj = SWIG_From_bool(static_cast< bool >(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_AccountNatConfig_turnEnabled_set(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::AccountNatConfig *arg1 = (pj::AccountNatConfig *) 0 ;
  bool arg2 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  bool val2 ;
  int ecode2 = 0 ;
  PyObject *swig_obj[2] ;
  
  if (!SWIG_Python_UnpackTuple(args, "AccountNatConfig_turnEnabled_set", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__AccountNatConfig, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "AccountNatConfig_turnEnabled_set" "', argument " "1"" of type '" "pj::AccountNatConfig *""'"); 
  }
  arg1 = reinterpret_cast< pj::AccountNatConfig * >(argp1);
  ecode2 = SWIG_AsVal_bool(swig_obj[1], &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "AccountNatConfig_turnEnabled_set" "', argument " "2"" of type '" "bool""'");
  } 
  arg2 = static_cast< bool >(val2);
  if (arg1) (arg1)->turnEnabled = arg2;
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_AccountNatConfig_turnEnabled_get(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::AccountNatConfig *arg1 = (pj::AccountNatConfig *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  bool result;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__AccountNatConfig, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "AccountNatConfig_turnEnabled_get" "', argument " "1"" of type '" "pj::AccountNatConfig *""'"); 
  }
  arg1 = reinterpret_cast< pj::AccountNatConfig * >(argp1);
  result = (bool) ((arg1)->turnEnabled);
  resultobj = SWIG_From_bool(static_cast< bool >(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_AccountNatConfig_turnServer_set(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::AccountNatConfig *arg1 = (pj::AccountNatConfig *) 0 ;
  pj::string *arg2 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  int res2 = SWIG_OLDOBJ ;
  PyObject *swig_obj[2] ;
  
  if (!SWIG_Python_UnpackTuple(args, "AccountNatConfig_turnServer_set", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__AccountNatConfig, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "AccountNatConfig_turnServer_set" "', argument " "1"" of type '" "pj::AccountNatConfig *""'"); 
  }
  arg1 = reinterpret_cast< pj::AccountNatConfig * >(argp1);
  {
    std::string *ptr = (std::string *)0;
    res2 = SWIG_AsPtr_std_string(swig_obj[1], &ptr);
    if (!SWIG_IsOK(res2)) {
      SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "AccountNatConfig_turnServer_set" "', argument " "2"" of type '" "pj::string const &""'"); 
    }
    if (!ptr) {
      SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "AccountNatConfig_turnServer_set" "', argument " "2"" of type '" "pj::string const &""'"); 
    }
    arg2 = ptr;
  }
  if (arg1) (arg1)->turnServer = *arg2;
  resultobj = SWIG_Py_Void();
  if (SWIG_IsNewObj(res2)) delete arg2;
  return resultobj;
fail:
  if (SWIG_IsNewObj(res2)) delete arg2;
  return NULL;
}


SWIGINTERN PyObject *_wrap_AccountNatConfig_turnServer_get(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::AccountNatConfig *arg1 = (pj::AccountNatConfig *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  pj::string *result = 0 ;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__AccountNatConfig, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "AccountNatConfig_turnServer_get" "', argument " "1"" of type '" "pj::AccountNatConfig *""'"); 
  }
  arg1 = reinterpret_cast< pj::AccountNatConfig * >(argp1);
  result = (pj::string *) & ((arg1)->turnServer);
  resultobj = SWIG_From_std_string(static_cast< std::string >(*result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_AccountNatConfig_turnConnType_set(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::AccountNatConfig *arg1 = (pj::AccountNatConfig *) 0 ;
  pj_turn_tp_type arg2 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  int val2 ;
  int ecode2 = 0 ;
  PyObject *swig_obj[2] ;
  
  if (!SWIG_Python_UnpackTuple(args, "AccountNatConfig_turnConnType_set", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__AccountNatConfig, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "AccountNatConfig_turnConnType_set" "', argument " "1"" of type '" "pj::AccountNatConfig *""'"); 
  }
  arg1 = reinterpret_cast< pj::AccountNatConfig * >(argp1);
  ecode2 = SWIG_AsVal_int(swig_obj[1], &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "AccountNatConfig_turnConnType_set" "', argument " "2"" of type '" "pj_turn_tp_type""'");
  } 
  arg2 = static_cast< pj_turn_tp_type >(val2);
  if (arg1) (arg1)->turnConnType = arg2;
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_AccountNatConfig_turnConnType_get(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::AccountNatConfig *arg1 = (pj::AccountNatConfig *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  pj_turn_tp_type result;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__AccountNatConfig, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "AccountNatConfig_turnConnType_get" "', argument " "1"" of type '" "pj::AccountNatConfig *""'"); 
  }
  arg1 = reinterpret_cast< pj::AccountNatConfig * >(argp1);
  result = (pj_turn_tp_type) ((arg1)->turnConnType);
  resultobj = SWIG_From_int(static_cast< int >(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_AccountNatConfig_turnUserName_set(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::AccountNatConfig *arg1 = (pj::AccountNatConfig *) 0 ;
  pj::string *arg2 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  int res2 = SWIG_OLDOBJ ;
  PyObject *swig_obj[2] ;
  
  if (!SWIG_Python_UnpackTuple(args, "AccountNatConfig_turnUserName_set", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__AccountNatConfig, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "AccountNatConfig_turnUserName_set" "', argument " "1"" of type '" "pj::AccountNatConfig *""'"); 
  }
  arg1 = reinterpret_cast< pj::AccountNatConfig * >(argp1);
  {
    std::string *ptr = (std::string *)0;
    res2 = SWIG_AsPtr_std_string(swig_obj[1], &ptr);
    if (!SWIG_IsOK(res2)) {
      SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "AccountNatConfig_turnUserName_set" "', argument " "2"" of type '" "pj::string const &""'"); 
    }
    if (!ptr) {
      SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "AccountNatConfig_turnUserName_set" "', argument " "2"" of type '" "pj::string const &""'"); 
    }
    arg2 = ptr;
  }
  if (arg1) (arg1)->turnUserName = *arg2;
  resultobj = SWIG_Py_Void();
  if (SWIG_IsNewObj(res2)) delete arg2;
  return resultobj;
fail:
  if (SWIG_IsNewObj(res2)) delete arg2;
  return NULL;
}


SWIGINTERN PyObject *_wrap_AccountNatConfig_turnUserName_get(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::AccountNatConfig *arg1 = (pj::AccountNatConfig *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  pj::string *result = 0 ;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__AccountNatConfig, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "AccountNatConfig_turnUserName_get" "', argument " "1"" of type '" "pj::AccountNatConfig *""'"); 
  }
  arg1 = reinterpret_cast< pj::AccountNatConfig * >(argp1);
  result = (pj::string *) & ((arg1)->turnUserName);
  resultobj = SWIG_From_std_string(static_cast< std::string >(*result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_AccountNatConfig_turnPasswordType_set(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::AccountNatConfig *arg1 = (pj::AccountNatConfig *) 0 ;
  int arg2 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  int val2 ;
  int ecode2 = 0 ;
  PyObject *swig_obj[2] ;
  
  if (!SWIG_Python_UnpackTuple(args, "AccountNatConfig_turnPasswordType_set", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__AccountNatConfig, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "AccountNatConfig_turnPasswordType_set" "', argument " "1"" of type '" "pj::AccountNatConfig *""'"); 
  }
  arg1 = reinterpret_cast< pj::AccountNatConfig * >(argp1);
  ecode2 = SWIG_AsVal_int(swig_obj[1], &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "AccountNatConfig_turnPasswordType_set" "', argument " "2"" of type '" "int""'");
  } 
  arg2 = static_cast< int >(val2);
  if (arg1) (arg1)->turnPasswordType = arg2;
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_AccountNatConfig_turnPasswordType_get(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::AccountNatConfig *arg1 = (pj::AccountNatConfig *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  int result;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__AccountNatConfig, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "AccountNatConfig_turnPasswordType_get" "', argument " "1"" of type '" "pj::AccountNatConfig *""'"); 
  }
  arg1 = reinterpret_cast< pj::AccountNatConfig * >(argp1);
  result = (int) ((arg1)->turnPasswordType);
  resultobj = SWIG_From_int(static_cast< int >(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_AccountNatConfig_turnPassword_set(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::AccountNatConfig *arg1 = (pj::AccountNatConfig *) 0 ;
  pj::string *arg2 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  int res2 = SWIG_OLDOBJ ;
  PyObject *swig_obj[2] ;
  
  if (!SWIG_Python_UnpackTuple(args, "AccountNatConfig_turnPassword_set", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__AccountNatConfig, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "AccountNatConfig_turnPassword_set" "', argument " "1"" of type '" "pj::AccountNatConfig *""'"); 
  }
  arg1 = reinterpret_cast< pj::AccountNatConfig * >(argp1);
  {
    std::string *ptr = (std::string *)0;
    res2 = SWIG_AsPtr_std_string(swig_obj[1], &ptr);
    if (!SWIG_IsOK(res2)) {
      SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "AccountNatConfig_turnPassword_set" "', argument " "2"" of type '" "pj::string const &""'"); 
    }
    if (!ptr) {
      SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "AccountNatConfig_turnPassword_set" "', argument " "2"" of type '" "pj::string const &""'"); 
    }
    arg2 = ptr;
  }
  if (arg1) (arg1)->turnPassword = *arg2;
  resultobj = SWIG_Py_Void();
  if (SWIG_IsNewObj(res2)) delete arg2;
  return resultobj;
fail:
  if (SWIG_IsNewObj(res2)) delete arg2;
  return NULL;
}


SWIGINTERN PyObject *_wrap_AccountNatConfig_turnPassword_get(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::AccountNatConfig *arg1 = (pj::AccountNatConfig *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  pj::string *result = 0 ;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__AccountNatConfig, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "AccountNatConfig_turnPassword_get" "', argument " "1"" of type '" "pj::AccountNatConfig *""'"); 
  }
  arg1 = reinterpret_cast< pj::AccountNatConfig * >(argp1);
  result = (pj::string *) & ((arg1)->turnPassword);
  resultobj = SWIG_From_std_string(static_cast< std::string >(*result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_AccountNatConfig_contactRewriteUse_set(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::AccountNatConfig *arg1 = (pj::AccountNatConfig *) 0 ;
  int arg2 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  int val2 ;
  int ecode2 = 0 ;
  PyObject *swig_obj[2] ;
  
  if (!SWIG_Python_UnpackTuple(args, "AccountNatConfig_contactRewriteUse_set", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__AccountNatConfig, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "AccountNatConfig_contactRewriteUse_set" "', argument " "1"" of type '" "pj::AccountNatConfig *""'"); 
  }
  arg1 = reinterpret_cast< pj::AccountNatConfig * >(argp1);
  ecode2 = SWIG_AsVal_int(swig_obj[1], &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "AccountNatConfig_contactRewriteUse_set" "', argument " "2"" of type '" "int""'");
  } 
  arg2 = static_cast< int >(val2);
  if (arg1) (arg1)->contactRewriteUse = arg2;
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_AccountNatConfig_contactRewriteUse_get(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::AccountNatConfig *arg1 = (pj::AccountNatConfig *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  int result;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__AccountNatConfig, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "AccountNatConfig_contactRewriteUse_get" "', argument " "1"" of type '" "pj::AccountNatConfig *""'"); 
  }
  arg1 = reinterpret_cast< pj::AccountNatConfig * >(argp1);
  result = (int) ((arg1)->contactRewriteUse);
  resultobj = SWIG_From_int(static_cast< int >(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_AccountNatConfig_contactRewriteMethod_set(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::AccountNatConfig *arg1 = (pj::AccountNatConfig *) 0 ;
  int arg2 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  int val2 ;
  int ecode2 = 0 ;
  PyObject *swig_obj[2] ;
  
  if (!SWIG_Python_UnpackTuple(args, "AccountNatConfig_contactRewriteMethod_set", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__AccountNatConfig, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "AccountNatConfig_contactRewriteMethod_set" "', argument " "1"" of type '" "pj::AccountNatConfig *""'"); 
  }
  arg1 = reinterpret_cast< pj::AccountNatConfig * >(argp1);
  ecode2 = SWIG_AsVal_int(swig_obj[1], &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "AccountNatConfig_contactRewriteMethod_set" "', argument " "2"" of type '" "int""'");
  } 
  arg2 = static_cast< int >(val2);
  if (arg1) (arg1)->contactRewriteMethod = arg2;
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_AccountNatConfig_contactRewriteMethod_get(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::AccountNatConfig *arg1 = (pj::AccountNatConfig *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  int result;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__AccountNatConfig, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "AccountNatConfig_contactRewriteMethod_get" "', argument " "1"" of type '" "pj::AccountNatConfig *""'"); 
  }
  arg1 = reinterpret_cast< pj::AccountNatConfig * >(argp1);
  result = (int) ((arg1)->contactRewriteMethod);
  resultobj = SWIG_From_int(static_cast< int >(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_AccountNatConfig_contactUseSrcPort_set(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::AccountNatConfig *arg1 = (pj::AccountNatConfig *) 0 ;
  int arg2 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  int val2 ;
  int ecode2 = 0 ;
  PyObject *swig_obj[2] ;
  
  if (!SWIG_Python_UnpackTuple(args, "AccountNatConfig_contactUseSrcPort_set", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__AccountNatConfig, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "AccountNatConfig_contactUseSrcPort_set" "', argument " "1"" of type '" "pj::AccountNatConfig *""'"); 
  }
  arg1 = reinterpret_cast< pj::AccountNatConfig * >(argp1);
  ecode2 = SWIG_AsVal_int(swig_obj[1], &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "AccountNatConfig_contactUseSrcPort_set" "', argument " "2"" of type '" "int""'");
  } 
  arg2 = static_cast< int >(val2);
  if (arg1) (arg1)->contactUseSrcPort = arg2;
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_AccountNatConfig_contactUseSrcPort_get(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::AccountNatConfig *arg1 = (pj::AccountNatConfig *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  int result;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__AccountNatConfig, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "AccountNatConfig_contactUseSrcPort_get" "', argument " "1"" of type '" "pj::AccountNatConfig *""'"); 
  }
  arg1 = reinterpret_cast< pj::AccountNatConfig * >(argp1);
  result = (int) ((arg1)->contactUseSrcPort);
  resultobj = SWIG_From_int(static_cast< int >(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_AccountNatConfig_viaRewriteUse_set(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::AccountNatConfig *arg1 = (pj::AccountNatConfig *) 0 ;
  int arg2 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  int val2 ;
  int ecode2 = 0 ;
  PyObject *swig_obj[2] ;
  
  if (!SWIG_Python_UnpackTuple(args, "AccountNatConfig_viaRewriteUse_set", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__AccountNatConfig, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "AccountNatConfig_viaRewriteUse_set" "', argument " "1"" of type '" "pj::AccountNatConfig *""'"); 
  }
  arg1 = reinterpret_cast< pj::AccountNatConfig * >(argp1);
  ecode2 = SWIG_AsVal_int(swig_obj[1], &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "AccountNatConfig_viaRewriteUse_set" "', argument " "2"" of type '" "int""'");
  } 
  arg2 = static_cast< int >(val2);
  if (arg1) (arg1)->viaRewriteUse = arg2;
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_AccountNatConfig_viaRewriteUse_get(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::AccountNatConfig *arg1 = (pj::AccountNatConfig *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  int result;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__AccountNatConfig, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "AccountNatConfig_viaRewriteUse_get" "', argument " "1"" of type '" "pj::AccountNatConfig *""'"); 
  }
  arg1 = reinterpret_cast< pj::AccountNatConfig * >(argp1);
  result = (int) ((arg1)->viaRewriteUse);
  resultobj = SWIG_From_int(static_cast< int >(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_AccountNatConfig_sdpNatRewriteUse_set(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::AccountNatConfig *arg1 = (pj::AccountNatConfig *) 0 ;
  int arg2 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  int val2 ;
  int ecode2 = 0 ;
  PyObject *swig_obj[2] ;
  
  if (!SWIG_Python_UnpackTuple(args, "AccountNatConfig_sdpNatRewriteUse_set", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__AccountNatConfig, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "AccountNatConfig_sdpNatRewriteUse_set" "', argument " "1"" of type '" "pj::AccountNatConfig *""'"); 
  }
  arg1 = reinterpret_cast< pj::AccountNatConfig * >(argp1);
  ecode2 = SWIG_AsVal_int(swig_obj[1], &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "AccountNatConfig_sdpNatRewriteUse_set" "', argument " "2"" of type '" "int""'");
  } 
  arg2 = static_cast< int >(val2);
  if (arg1) (arg1)->sdpNatRewriteUse = arg2;
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_AccountNatConfig_sdpNatRewriteUse_get(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::AccountNatConfig *arg1 = (pj::AccountNatConfig *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  int result;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__AccountNatConfig, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "AccountNatConfig_sdpNatRewriteUse_get" "', argument " "1"" of type '" "pj::AccountNatConfig *""'"); 
  }
  arg1 = reinterpret_cast< pj::AccountNatConfig * >(argp1);
  result = (int) ((arg1)->sdpNatRewriteUse);
  resultobj = SWIG_From_int(static_cast< int >(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_AccountNatConfig_sipOutboundUse_set(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::AccountNatConfig *arg1 = (pj::AccountNatConfig *) 0 ;
  int arg2 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  int val2 ;
  int ecode2 = 0 ;
  PyObject *swig_obj[2] ;
  
  if (!SWIG_Python_UnpackTuple(args, "AccountNatConfig_sipOutboundUse_set", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__AccountNatConfig, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "AccountNatConfig_sipOutboundUse_set" "', argument " "1"" of type '" "pj::AccountNatConfig *""'"); 
  }
  arg1 = reinterpret_cast< pj::AccountNatConfig * >(argp1);
  ecode2 = SWIG_AsVal_int(swig_obj[1], &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "AccountNatConfig_sipOutboundUse_set" "', argument " "2"" of type '" "int""'");
  } 
  arg2 = static_cast< int >(val2);
  if (arg1) (arg1)->sipOutboundUse = arg2;
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_AccountNatConfig_sipOutboundUse_get(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::AccountNatConfig *arg1 = (pj::AccountNatConfig *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  int result;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__AccountNatConfig, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "AccountNatConfig_sipOutboundUse_get" "', argument " "1"" of type '" "pj::AccountNatConfig *""'"); 
  }
  arg1 = reinterpret_cast< pj::AccountNatConfig * >(argp1);
  result = (int) ((arg1)->sipOutboundUse);
  resultobj = SWIG_From_int(static_cast< int >(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_AccountNatConfig_sipOutboundInstanceId_set(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::AccountNatConfig *arg1 = (pj::AccountNatConfig *) 0 ;
  pj::string *arg2 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  int res2 = SWIG_OLDOBJ ;
  PyObject *swig_obj[2] ;
  
  if (!SWIG_Python_UnpackTuple(args, "AccountNatConfig_sipOutboundInstanceId_set", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__AccountNatConfig, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "AccountNatConfig_sipOutboundInstanceId_set" "', argument " "1"" of type '" "pj::AccountNatConfig *""'"); 
  }
  arg1 = reinterpret_cast< pj::AccountNatConfig * >(argp1);
  {
    std::string *ptr = (std::string *)0;
    res2 = SWIG_AsPtr_std_string(swig_obj[1], &ptr);
    if (!SWIG_IsOK(res2)) {
      SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "AccountNatConfig_sipOutboundInstanceId_set" "', argument " "2"" of type '" "pj::string const &""'"); 
    }
    if (!ptr) {
      SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "AccountNatConfig_sipOutboundInstanceId_set" "', argument " "2"" of type '" "pj::string const &""'"); 
    }
    arg2 = ptr;
  }
  if (arg1) (arg1)->sipOutboundInstanceId = *arg2;
  resultobj = SWIG_Py_Void();
  if (SWIG_IsNewObj(res2)) delete arg2;
  return resultobj;
fail:
  if (SWIG_IsNewObj(res2)) delete arg2;
  return NULL;
}


SWIGINTERN PyObject *_wrap_AccountNatConfig_sipOutboundInstanceId_get(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::AccountNatConfig *arg1 = (pj::AccountNatConfig *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  pj::string *result = 0 ;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__AccountNatConfig, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "AccountNatConfig_sipOutboundInstanceId_get" "', argument " "1"" of type '" "pj::AccountNatConfig *""'"); 
  }
  arg1 = reinterpret_cast< pj::AccountNatConfig * >(argp1);
  result = (pj::string *) & ((arg1)->sipOutboundInstanceId);
  resultobj = SWIG_From_std_string(static_cast< std::string >(*result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_AccountNatConfig_sipOutboundRegId_set(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::AccountNatConfig *arg1 = (pj::AccountNatConfig *) 0 ;
  pj::string *arg2 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  int res2 = SWIG_OLDOBJ ;
  PyObject *swig_obj[2] ;
  
  if (!SWIG_Python_UnpackTuple(args, "AccountNatConfig_sipOutboundRegId_set", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__AccountNatConfig, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "AccountNatConfig_sipOutboundRegId_set" "', argument " "1"" of type '" "pj::AccountNatConfig *""'"); 
  }
  arg1 = reinterpret_cast< pj::AccountNatConfig * >(argp1);
  {
    std::string *ptr = (std::string *)0;
    res2 = SWIG_AsPtr_std_string(swig_obj[1], &ptr);
    if (!SWIG_IsOK(res2)) {
      SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "AccountNatConfig_sipOutboundRegId_set" "', argument " "2"" of type '" "pj::string const &""'"); 
    }
    if (!ptr) {
      SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "AccountNatConfig_sipOutboundRegId_set" "', argument " "2"" of type '" "pj::string const &""'"); 
    }
    arg2 = ptr;
  }
  if (arg1) (arg1)->sipOutboundRegId = *arg2;
  resultobj = SWIG_Py_Void();
  if (SWIG_IsNewObj(res2)) delete arg2;
  return resultobj;
fail:
  if (SWIG_IsNewObj(res2)) delete arg2;
  return NULL;
}


SWIGINTERN PyObject *_wrap_AccountNatConfig_sipOutboundRegId_get(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::AccountNatConfig *arg1 = (pj::AccountNatConfig *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  pj::string *result = 0 ;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__AccountNatConfig, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "AccountNatConfig_sipOutboundRegId_get" "', argument " "1"" of type '" "pj::AccountNatConfig *""'"); 
  }
  arg1 = reinterpret_cast< pj::AccountNatConfig * >(argp1);
  result = (pj::string *) & ((arg1)->sipOutboundRegId);
  resultobj = SWIG_From_std_string(static_cast< std::string >(*result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_AccountNatConfig_udpKaIntervalSec_set(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::AccountNatConfig *arg1 = (pj::AccountNatConfig *) 0 ;
  unsigned int arg2 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  unsigned int val2 ;
  int ecode2 = 0 ;
  PyObject *swig_obj[2] ;
  
  if (!SWIG_Python_UnpackTuple(args, "AccountNatConfig_udpKaIntervalSec_set", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__AccountNatConfig, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "AccountNatConfig_udpKaIntervalSec_set" "', argument " "1"" of type '" "pj::AccountNatConfig *""'"); 
  }
  arg1 = reinterpret_cast< pj::AccountNatConfig * >(argp1);
  ecode2 = SWIG_AsVal_unsigned_SS_int(swig_obj[1], &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "AccountNatConfig_udpKaIntervalSec_set" "', argument " "2"" of type '" "unsigned int""'");
  } 
  arg2 = static_cast< unsigned int >(val2);
  if (arg1) (arg1)->udpKaIntervalSec = arg2;
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_AccountNatConfig_udpKaIntervalSec_get(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::AccountNatConfig *arg1 = (pj::AccountNatConfig *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  unsigned int result;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__AccountNatConfig, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "AccountNatConfig_udpKaIntervalSec_get" "', argument " "1"" of type '" "pj::AccountNatConfig *""'"); 
  }
  arg1 = reinterpret_cast< pj::AccountNatConfig * >(argp1);
  result = (unsigned int) ((arg1)->udpKaIntervalSec);
  resultobj = SWIG_From_unsigned_SS_int(static_cast< unsigned int >(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_AccountNatConfig_udpKaData_set(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::AccountNatConfig *arg1 = (pj::AccountNatConfig *) 0 ;
  pj::string *arg2 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  int res2 = SWIG_OLDOBJ ;
  PyObject *swig_obj[2] ;
  
  if (!SWIG_Python_UnpackTuple(args, "AccountNatConfig_udpKaData_set", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__AccountNatConfig, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "AccountNatConfig_udpKaData_set" "', argument " "1"" of type '" "pj::AccountNatConfig *""'"); 
  }
  arg1 = reinterpret_cast< pj::AccountNatConfig * >(argp1);
  {
    std::string *ptr = (std::string *)0;
    res2 = SWIG_AsPtr_std_string(swig_obj[1], &ptr);
    if (!SWIG_IsOK(res2)) {
      SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "AccountNatConfig_udpKaData_set" "', argument " "2"" of type '" "pj::string const &""'"); 
    }
    if (!ptr) {
      SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "AccountNatConfig_udpKaData_set" "', argument " "2"" of type '" "pj::string const &""'"); 
    }
    arg2 = ptr;
  }
  if (arg1) (arg1)->udpKaData = *arg2;
  resultobj = SWIG_Py_Void();
  if (SWIG_IsNewObj(res2)) delete arg2;
  return resultobj;
fail:
  if (SWIG_IsNewObj(res2)) delete arg2;
  return NULL;
}


SWIGINTERN PyObject *_wrap_AccountNatConfig_udpKaData_get(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::AccountNatConfig *arg1 = (pj::AccountNatConfig *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  pj::string *result = 0 ;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__AccountNatConfig, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "AccountNatConfig_udpKaData_get" "', argument " "1"" of type '" "pj::AccountNatConfig *""'"); 
  }
  arg1 = reinterpret_cast< pj::AccountNatConfig * >(argp1);
  result = (pj::string *) & ((arg1)->udpKaData);
  resultobj = SWIG_From_std_string(static_cast< std::string >(*result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_new_AccountNatConfig(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::AccountNatConfig *result = 0 ;
  
  if (!SWIG_Python_UnpackTuple(args, "new_AccountNatConfig", 0, 0, 0)) SWIG_fail;
  result = (pj::AccountNatConfig *)new pj::AccountNatConfig();
  resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(result), SWIGTYPE_p_pj__AccountNatConfig, SWIG_POINTER_NEW |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_AccountNatConfig_readObject(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::AccountNatConfig *arg1 = (pj::AccountNatConfig *) 0 ;
  pj::ContainerNode *arg2 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  void *argp2 = 0 ;
  int res2 = 0 ;
  PyObject *swig_obj[2] ;
  
  if (!SWIG_Python_UnpackTuple(args, "AccountNatConfig_readObject", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__AccountNatConfig, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "AccountNatConfig_readObject" "', argument " "1"" of type '" "pj::AccountNatConfig *""'"); 
  }
  arg1 = reinterpret_cast< pj::AccountNatConfig * >(argp1);
  res2 = SWIG_ConvertPtr(swig_obj[1], &argp2, SWIGTYPE_p_pj__ContainerNode,  0  | 0);
  if (!SWIG_IsOK(res2)) {
    SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "AccountNatConfig_readObject" "', argument " "2"" of type '" "pj::ContainerNode const &""'"); 
  }
  if (!argp2) {
    SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "AccountNatConfig_readObject" "', argument " "2"" of type '" "pj::ContainerNode const &""'"); 
  }
  arg2 = reinterpret_cast< pj::ContainerNode * >(argp2);
  try {
    (arg1)->readObject((pj::ContainerNode const &)*arg2);
  } catch(pj::Error &_e) {
    SWIG_Python_Raise(SWIG_NewPointerObj((new pj::Error(static_cast< const pj::Error& >(_e))),SWIGTYPE_p_pj__Error,SWIG_POINTER_OWN), "pj::Error", SWIGTYPE_p_pj__Error); SWIG_fail;
  }
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_AccountNatConfig_writeObject(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::AccountNatConfig *arg1 = (pj::AccountNatConfig *) 0 ;
  pj::ContainerNode *arg2 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  void *argp2 = 0 ;
  int res2 = 0 ;
  PyObject *swig_obj[2] ;
  
  if (!SWIG_Python_UnpackTuple(args, "AccountNatConfig_writeObject", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__AccountNatConfig, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "AccountNatConfig_writeObject" "', argument " "1"" of type '" "pj::AccountNatConfig const *""'"); 
  }
  arg1 = reinterpret_cast< pj::AccountNatConfig * >(argp1);
  res2 = SWIG_ConvertPtr(swig_obj[1], &argp2, SWIGTYPE_p_pj__ContainerNode,  0 );
  if (!SWIG_IsOK(res2)) {
    SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "AccountNatConfig_writeObject" "', argument " "2"" of type '" "pj::ContainerNode &""'"); 
  }
  if (!argp2) {
    SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "AccountNatConfig_writeObject" "', argument " "2"" of type '" "pj::ContainerNode &""'"); 
  }
  arg2 = reinterpret_cast< pj::ContainerNode * >(argp2);
  try {
    ((pj::AccountNatConfig const *)arg1)->writeObject(*arg2);
  } catch(pj::Error &_e) {
    SWIG_Python_Raise(SWIG_NewPointerObj((new pj::Error(static_cast< const pj::Error& >(_e))),SWIGTYPE_p_pj__Error,SWIG_POINTER_OWN), "pj::Error", SWIGTYPE_p_pj__Error); SWIG_fail;
  }
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_delete_AccountNatConfig(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::AccountNatConfig *arg1 = (pj::AccountNatConfig *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__AccountNatConfig, SWIG_POINTER_DISOWN |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "delete_AccountNatConfig" "', argument " "1"" of type '" "pj::AccountNatConfig *""'"); 
  }
  arg1 = reinterpret_cast< pj::AccountNatConfig * >(argp1);
  delete arg1;
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *AccountNatConfig_swigregister(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *obj;
  if (!SWIG_Python_UnpackTuple(args, "swigregister", 1, 1, &obj)) return NULL;
  SWIG_TypeNewClientData(SWIGTYPE_p_pj__AccountNatConfig, SWIG_NewClientData(obj));
  return SWIG_Py_Void();
}

SWIGINTERN PyObject *AccountNatConfig_swiginit(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  return SWIG_Python_InitShadowInstance(args);
}

SWIGINTERN PyObject *_wrap_SrtpCrypto_key_set(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::SrtpCrypto *arg1 = (pj::SrtpCrypto *) 0 ;
  pj::string *arg2 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  int res2 = SWIG_OLDOBJ ;
  PyObject *swig_obj[2] ;
  
  if (!SWIG_Python_UnpackTuple(args, "SrtpCrypto_key_set", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__SrtpCrypto, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "SrtpCrypto_key_set" "', argument " "1"" of type '" "pj::SrtpCrypto *""'"); 
  }
  arg1 = reinterpret_cast< pj::SrtpCrypto * >(argp1);
  {
    std::string *ptr = (std::string *)0;
    res2 = SWIG_AsPtr_std_string(swig_obj[1], &ptr);
    if (!SWIG_IsOK(res2)) {
      SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "SrtpCrypto_key_set" "', argument " "2"" of type '" "pj::string const &""'"); 
    }
    if (!ptr) {
      SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "SrtpCrypto_key_set" "', argument " "2"" of type '" "pj::string const &""'"); 
    }
    arg2 = ptr;
  }
  if (arg1) (arg1)->key = *arg2;
  resultobj = SWIG_Py_Void();
  if (SWIG_IsNewObj(res2)) delete arg2;
  return resultobj;
fail:
  if (SWIG_IsNewObj(res2)) delete arg2;
  return NULL;
}


SWIGINTERN PyObject *_wrap_SrtpCrypto_key_get(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::SrtpCrypto *arg1 = (pj::SrtpCrypto *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  pj::string *result = 0 ;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__SrtpCrypto, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "SrtpCrypto_key_get" "', argument " "1"" of type '" "pj::SrtpCrypto *""'"); 
  }
  arg1 = reinterpret_cast< pj::SrtpCrypto * >(argp1);
  result = (pj::string *) & ((arg1)->key);
  resultobj = SWIG_From_std_string(static_cast< std::string >(*result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_SrtpCrypto_name_set(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::SrtpCrypto *arg1 = (pj::SrtpCrypto *) 0 ;
  pj::string *arg2 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  int res2 = SWIG_OLDOBJ ;
  PyObject *swig_obj[2] ;
  
  if (!SWIG_Python_UnpackTuple(args, "SrtpCrypto_name_set", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__SrtpCrypto, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "SrtpCrypto_name_set" "', argument " "1"" of type '" "pj::SrtpCrypto *""'"); 
  }
  arg1 = reinterpret_cast< pj::SrtpCrypto * >(argp1);
  {
    std::string *ptr = (std::string *)0;
    res2 = SWIG_AsPtr_std_string(swig_obj[1], &ptr);
    if (!SWIG_IsOK(res2)) {
      SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "SrtpCrypto_name_set" "', argument " "2"" of type '" "pj::string const &""'"); 
    }
    if (!ptr) {
      SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "SrtpCrypto_name_set" "', argument " "2"" of type '" "pj::string const &""'"); 
    }
    arg2 = ptr;
  }
  if (arg1) (arg1)->name = *arg2;
  resultobj = SWIG_Py_Void();
  if (SWIG_IsNewObj(res2)) delete arg2;
  return resultobj;
fail:
  if (SWIG_IsNewObj(res2)) delete arg2;
  return NULL;
}


SWIGINTERN PyObject *_wrap_SrtpCrypto_name_get(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::SrtpCrypto *arg1 = (pj::SrtpCrypto *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  pj::string *result = 0 ;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__SrtpCrypto, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "SrtpCrypto_name_get" "', argument " "1"" of type '" "pj::SrtpCrypto *""'"); 
  }
  arg1 = reinterpret_cast< pj::SrtpCrypto * >(argp1);
  result = (pj::string *) & ((arg1)->name);
  resultobj = SWIG_From_std_string(static_cast< std::string >(*result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_SrtpCrypto_flags_set(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::SrtpCrypto *arg1 = (pj::SrtpCrypto *) 0 ;
  unsigned int arg2 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  unsigned int val2 ;
  int ecode2 = 0 ;
  PyObject *swig_obj[2] ;
  
  if (!SWIG_Python_UnpackTuple(args, "SrtpCrypto_flags_set", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__SrtpCrypto, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "SrtpCrypto_flags_set" "', argument " "1"" of type '" "pj::SrtpCrypto *""'"); 
  }
  arg1 = reinterpret_cast< pj::SrtpCrypto * >(argp1);
  ecode2 = SWIG_AsVal_unsigned_SS_int(swig_obj[1], &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "SrtpCrypto_flags_set" "', argument " "2"" of type '" "unsigned int""'");
  } 
  arg2 = static_cast< unsigned int >(val2);
  if (arg1) (arg1)->flags = arg2;
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_SrtpCrypto_flags_get(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::SrtpCrypto *arg1 = (pj::SrtpCrypto *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  unsigned int result;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__SrtpCrypto, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "SrtpCrypto_flags_get" "', argument " "1"" of type '" "pj::SrtpCrypto *""'"); 
  }
  arg1 = reinterpret_cast< pj::SrtpCrypto * >(argp1);
  result = (unsigned int) ((arg1)->flags);
  resultobj = SWIG_From_unsigned_SS_int(static_cast< unsigned int >(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_new_SrtpCrypto(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::SrtpCrypto *result = 0 ;
  
  if (!SWIG_Python_UnpackTuple(args, "new_SrtpCrypto", 0, 0, 0)) SWIG_fail;
  result = (pj::SrtpCrypto *)new pj::SrtpCrypto();
  resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(result), SWIGTYPE_p_pj__SrtpCrypto, SWIG_POINTER_NEW |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_delete_SrtpCrypto(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::SrtpCrypto *arg1 = (pj::SrtpCrypto *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__SrtpCrypto, SWIG_POINTER_DISOWN |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "delete_SrtpCrypto" "', argument " "1"" of type '" "pj::SrtpCrypto *""'"); 
  }
  arg1 = reinterpret_cast< pj::SrtpCrypto * >(argp1);
  delete arg1;
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *SrtpCrypto_swigregister(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *obj;
  if (!SWIG_Python_UnpackTuple(args, "swigregister", 1, 1, &obj)) return NULL;
  SWIG_TypeNewClientData(SWIGTYPE_p_pj__SrtpCrypto, SWIG_NewClientData(obj));
  return SWIG_Py_Void();
}

SWIGINTERN PyObject *SrtpCrypto_swiginit(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  return SWIG_Python_InitShadowInstance(args);
}

SWIGINTERN PyObject *_wrap_SrtpOpt_cryptos_set(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::SrtpOpt *arg1 = (pj::SrtpOpt *) 0 ;
  pj::SrtpCryptoVector *arg2 = (pj::SrtpCryptoVector *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  void *argp2 = 0 ;
  int res2 = 0 ;
  PyObject *swig_obj[2] ;
  
  if (!SWIG_Python_UnpackTuple(args, "SrtpOpt_cryptos_set", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__SrtpOpt, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "SrtpOpt_cryptos_set" "', argument " "1"" of type '" "pj::SrtpOpt *""'"); 
  }
  arg1 = reinterpret_cast< pj::SrtpOpt * >(argp1);
  res2 = SWIG_ConvertPtr(swig_obj[1], &argp2,SWIGTYPE_p_std__vectorT_pj__SrtpCrypto_std__allocatorT_pj__SrtpCrypto_t_t, 0 |  0 );
  if (!SWIG_IsOK(res2)) {
    SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "SrtpOpt_cryptos_set" "', argument " "2"" of type '" "pj::SrtpCryptoVector *""'"); 
  }
  arg2 = reinterpret_cast< pj::SrtpCryptoVector * >(argp2);
  if (arg1) (arg1)->cryptos = *arg2;
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_SrtpOpt_cryptos_get(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::SrtpOpt *arg1 = (pj::SrtpOpt *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  pj::SrtpCryptoVector *result = 0 ;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__SrtpOpt, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "SrtpOpt_cryptos_get" "', argument " "1"" of type '" "pj::SrtpOpt *""'"); 
  }
  arg1 = reinterpret_cast< pj::SrtpOpt * >(argp1);
  result = (pj::SrtpCryptoVector *)& ((arg1)->cryptos);
  resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(result), SWIGTYPE_p_std__vectorT_pj__SrtpCrypto_std__allocatorT_pj__SrtpCrypto_t_t, 0 |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_SrtpOpt_keyings_set(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::SrtpOpt *arg1 = (pj::SrtpOpt *) 0 ;
  pj::IntVector *arg2 = (pj::IntVector *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  void *argp2 = 0 ;
  int res2 = 0 ;
  PyObject *swig_obj[2] ;
  
  if (!SWIG_Python_UnpackTuple(args, "SrtpOpt_keyings_set", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__SrtpOpt, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "SrtpOpt_keyings_set" "', argument " "1"" of type '" "pj::SrtpOpt *""'"); 
  }
  arg1 = reinterpret_cast< pj::SrtpOpt * >(argp1);
  res2 = SWIG_ConvertPtr(swig_obj[1], &argp2,SWIGTYPE_p_std__vectorT_int_std__allocatorT_int_t_t, 0 |  0 );
  if (!SWIG_IsOK(res2)) {
    SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "SrtpOpt_keyings_set" "', argument " "2"" of type '" "pj::IntVector *""'"); 
  }
  arg2 = reinterpret_cast< pj::IntVector * >(argp2);
  if (arg1) (arg1)->keyings = *arg2;
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_SrtpOpt_keyings_get(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::SrtpOpt *arg1 = (pj::SrtpOpt *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  pj::IntVector *result = 0 ;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__SrtpOpt, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "SrtpOpt_keyings_get" "', argument " "1"" of type '" "pj::SrtpOpt *""'"); 
  }
  arg1 = reinterpret_cast< pj::SrtpOpt * >(argp1);
  result = (pj::IntVector *)& ((arg1)->keyings);
  resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(result), SWIGTYPE_p_std__vectorT_int_std__allocatorT_int_t_t, 0 |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_new_SrtpOpt(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::SrtpOpt *result = 0 ;
  
  if (!SWIG_Python_UnpackTuple(args, "new_SrtpOpt", 0, 0, 0)) SWIG_fail;
  result = (pj::SrtpOpt *)new pj::SrtpOpt();
  resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(result), SWIGTYPE_p_pj__SrtpOpt, SWIG_POINTER_NEW |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_SrtpOpt_readObject(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::SrtpOpt *arg1 = (pj::SrtpOpt *) 0 ;
  pj::ContainerNode *arg2 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  void *argp2 = 0 ;
  int res2 = 0 ;
  PyObject *swig_obj[2] ;
  
  if (!SWIG_Python_UnpackTuple(args, "SrtpOpt_readObject", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__SrtpOpt, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "SrtpOpt_readObject" "', argument " "1"" of type '" "pj::SrtpOpt *""'"); 
  }
  arg1 = reinterpret_cast< pj::SrtpOpt * >(argp1);
  res2 = SWIG_ConvertPtr(swig_obj[1], &argp2, SWIGTYPE_p_pj__ContainerNode,  0  | 0);
  if (!SWIG_IsOK(res2)) {
    SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "SrtpOpt_readObject" "', argument " "2"" of type '" "pj::ContainerNode const &""'"); 
  }
  if (!argp2) {
    SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "SrtpOpt_readObject" "', argument " "2"" of type '" "pj::ContainerNode const &""'"); 
  }
  arg2 = reinterpret_cast< pj::ContainerNode * >(argp2);
  try {
    (arg1)->readObject((pj::ContainerNode const &)*arg2);
  } catch(pj::Error &_e) {
    SWIG_Python_Raise(SWIG_NewPointerObj((new pj::Error(static_cast< const pj::Error& >(_e))),SWIGTYPE_p_pj__Error,SWIG_POINTER_OWN), "pj::Error", SWIGTYPE_p_pj__Error); SWIG_fail;
  }
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_SrtpOpt_writeObject(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::SrtpOpt *arg1 = (pj::SrtpOpt *) 0 ;
  pj::ContainerNode *arg2 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  void *argp2 = 0 ;
  int res2 = 0 ;
  PyObject *swig_obj[2] ;
  
  if (!SWIG_Python_UnpackTuple(args, "SrtpOpt_writeObject", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__SrtpOpt, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "SrtpOpt_writeObject" "', argument " "1"" of type '" "pj::SrtpOpt const *""'"); 
  }
  arg1 = reinterpret_cast< pj::SrtpOpt * >(argp1);
  res2 = SWIG_ConvertPtr(swig_obj[1], &argp2, SWIGTYPE_p_pj__ContainerNode,  0 );
  if (!SWIG_IsOK(res2)) {
    SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "SrtpOpt_writeObject" "', argument " "2"" of type '" "pj::ContainerNode &""'"); 
  }
  if (!argp2) {
    SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "SrtpOpt_writeObject" "', argument " "2"" of type '" "pj::ContainerNode &""'"); 
  }
  arg2 = reinterpret_cast< pj::ContainerNode * >(argp2);
  try {
    ((pj::SrtpOpt const *)arg1)->writeObject(*arg2);
  } catch(pj::Error &_e) {
    SWIG_Python_Raise(SWIG_NewPointerObj((new pj::Error(static_cast< const pj::Error& >(_e))),SWIGTYPE_p_pj__Error,SWIG_POINTER_OWN), "pj::Error", SWIGTYPE_p_pj__Error); SWIG_fail;
  }
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_delete_SrtpOpt(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::SrtpOpt *arg1 = (pj::SrtpOpt *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__SrtpOpt, SWIG_POINTER_DISOWN |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "delete_SrtpOpt" "', argument " "1"" of type '" "pj::SrtpOpt *""'"); 
  }
  arg1 = reinterpret_cast< pj::SrtpOpt * >(argp1);
  delete arg1;
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *SrtpOpt_swigregister(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *obj;
  if (!SWIG_Python_UnpackTuple(args, "swigregister", 1, 1, &obj)) return NULL;
  SWIG_TypeNewClientData(SWIGTYPE_p_pj__SrtpOpt, SWIG_NewClientData(obj));
  return SWIG_Py_Void();
}

SWIGINTERN PyObject *SrtpOpt_swiginit(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  return SWIG_Python_InitShadowInstance(args);
}

SWIGINTERN PyObject *_wrap_RtcpFbCap_codecId_set(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::RtcpFbCap *arg1 = (pj::RtcpFbCap *) 0 ;
  pj::string *arg2 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  int res2 = SWIG_OLDOBJ ;
  PyObject *swig_obj[2] ;
  
  if (!SWIG_Python_UnpackTuple(args, "RtcpFbCap_codecId_set", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__RtcpFbCap, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "RtcpFbCap_codecId_set" "', argument " "1"" of type '" "pj::RtcpFbCap *""'"); 
  }
  arg1 = reinterpret_cast< pj::RtcpFbCap * >(argp1);
  {
    std::string *ptr = (std::string *)0;
    res2 = SWIG_AsPtr_std_string(swig_obj[1], &ptr);
    if (!SWIG_IsOK(res2)) {
      SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "RtcpFbCap_codecId_set" "', argument " "2"" of type '" "pj::string const &""'"); 
    }
    if (!ptr) {
      SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "RtcpFbCap_codecId_set" "', argument " "2"" of type '" "pj::string const &""'"); 
    }
    arg2 = ptr;
  }
  if (arg1) (arg1)->codecId = *arg2;
  resultobj = SWIG_Py_Void();
  if (SWIG_IsNewObj(res2)) delete arg2;
  return resultobj;
fail:
  if (SWIG_IsNewObj(res2)) delete arg2;
  return NULL;
}


SWIGINTERN PyObject *_wrap_RtcpFbCap_codecId_get(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::RtcpFbCap *arg1 = (pj::RtcpFbCap *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  pj::string *result = 0 ;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__RtcpFbCap, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "RtcpFbCap_codecId_get" "', argument " "1"" of type '" "pj::RtcpFbCap *""'"); 
  }
  arg1 = reinterpret_cast< pj::RtcpFbCap * >(argp1);
  result = (pj::string *) & ((arg1)->codecId);
  resultobj = SWIG_From_std_string(static_cast< std::string >(*result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_RtcpFbCap_type_set(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::RtcpFbCap *arg1 = (pj::RtcpFbCap *) 0 ;
  pjmedia_rtcp_fb_type arg2 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  int val2 ;
  int ecode2 = 0 ;
  PyObject *swig_obj[2] ;
  
  if (!SWIG_Python_UnpackTuple(args, "RtcpFbCap_type_set", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__RtcpFbCap, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "RtcpFbCap_type_set" "', argument " "1"" of type '" "pj::RtcpFbCap *""'"); 
  }
  arg1 = reinterpret_cast< pj::RtcpFbCap * >(argp1);
  ecode2 = SWIG_AsVal_int(swig_obj[1], &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "RtcpFbCap_type_set" "', argument " "2"" of type '" "pjmedia_rtcp_fb_type""'");
  } 
  arg2 = static_cast< pjmedia_rtcp_fb_type >(val2);
  if (arg1) (arg1)->type = arg2;
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_RtcpFbCap_type_get(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::RtcpFbCap *arg1 = (pj::RtcpFbCap *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  pjmedia_rtcp_fb_type result;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__RtcpFbCap, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "RtcpFbCap_type_get" "', argument " "1"" of type '" "pj::RtcpFbCap *""'"); 
  }
  arg1 = reinterpret_cast< pj::RtcpFbCap * >(argp1);
  result = (pjmedia_rtcp_fb_type) ((arg1)->type);
  resultobj = SWIG_From_int(static_cast< int >(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_RtcpFbCap_typeName_set(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::RtcpFbCap *arg1 = (pj::RtcpFbCap *) 0 ;
  pj::string *arg2 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  int res2 = SWIG_OLDOBJ ;
  PyObject *swig_obj[2] ;
  
  if (!SWIG_Python_UnpackTuple(args, "RtcpFbCap_typeName_set", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__RtcpFbCap, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "RtcpFbCap_typeName_set" "', argument " "1"" of type '" "pj::RtcpFbCap *""'"); 
  }
  arg1 = reinterpret_cast< pj::RtcpFbCap * >(argp1);
  {
    std::string *ptr = (std::string *)0;
    res2 = SWIG_AsPtr_std_string(swig_obj[1], &ptr);
    if (!SWIG_IsOK(res2)) {
      SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "RtcpFbCap_typeName_set" "', argument " "2"" of type '" "pj::string const &""'"); 
    }
    if (!ptr) {
      SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "RtcpFbCap_typeName_set" "', argument " "2"" of type '" "pj::string const &""'"); 
    }
    arg2 = ptr;
  }
  if (arg1) (arg1)->typeName = *arg2;
  resultobj = SWIG_Py_Void();
  if (SWIG_IsNewObj(res2)) delete arg2;
  return resultobj;
fail:
  if (SWIG_IsNewObj(res2)) delete arg2;
  return NULL;
}


SWIGINTERN PyObject *_wrap_RtcpFbCap_typeName_get(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::RtcpFbCap *arg1 = (pj::RtcpFbCap *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  pj::string *result = 0 ;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__RtcpFbCap, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "RtcpFbCap_typeName_get" "', argument " "1"" of type '" "pj::RtcpFbCap *""'"); 
  }
  arg1 = reinterpret_cast< pj::RtcpFbCap * >(argp1);
  result = (pj::string *) & ((arg1)->typeName);
  resultobj = SWIG_From_std_string(static_cast< std::string >(*result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_RtcpFbCap_param_set(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::RtcpFbCap *arg1 = (pj::RtcpFbCap *) 0 ;
  pj::string *arg2 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  int res2 = SWIG_OLDOBJ ;
  PyObject *swig_obj[2] ;
  
  if (!SWIG_Python_UnpackTuple(args, "RtcpFbCap_param_set", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__RtcpFbCap, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "RtcpFbCap_param_set" "', argument " "1"" of type '" "pj::RtcpFbCap *""'"); 
  }
  arg1 = reinterpret_cast< pj::RtcpFbCap * >(argp1);
  {
    std::string *ptr = (std::string *)0;
    res2 = SWIG_AsPtr_std_string(swig_obj[1], &ptr);
    if (!SWIG_IsOK(res2)) {
      SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "RtcpFbCap_param_set" "', argument " "2"" of type '" "pj::string const &""'"); 
    }
    if (!ptr) {
      SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "RtcpFbCap_param_set" "', argument " "2"" of type '" "pj::string const &""'"); 
    }
    arg2 = ptr;
  }
  if (arg1) (arg1)->param = *arg2;
  resultobj = SWIG_Py_Void();
  if (SWIG_IsNewObj(res2)) delete arg2;
  return resultobj;
fail:
  if (SWIG_IsNewObj(res2)) delete arg2;
  return NULL;
}


SWIGINTERN PyObject *_wrap_RtcpFbCap_param_get(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::RtcpFbCap *arg1 = (pj::RtcpFbCap *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  pj::string *result = 0 ;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__RtcpFbCap, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "RtcpFbCap_param_get" "', argument " "1"" of type '" "pj::RtcpFbCap *""'"); 
  }
  arg1 = reinterpret_cast< pj::RtcpFbCap * >(argp1);
  result = (pj::string *) & ((arg1)->param);
  resultobj = SWIG_From_std_string(static_cast< std::string >(*result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_new_RtcpFbCap(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::RtcpFbCap *result = 0 ;
  
  if (!SWIG_Python_UnpackTuple(args, "new_RtcpFbCap", 0, 0, 0)) SWIG_fail;
  result = (pj::RtcpFbCap *)new pj::RtcpFbCap();
  resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(result), SWIGTYPE_p_pj__RtcpFbCap, SWIG_POINTER_NEW |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_delete_RtcpFbCap(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::RtcpFbCap *arg1 = (pj::RtcpFbCap *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__RtcpFbCap, SWIG_POINTER_DISOWN |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "delete_RtcpFbCap" "', argument " "1"" of type '" "pj::RtcpFbCap *""'"); 
  }
  arg1 = reinterpret_cast< pj::RtcpFbCap * >(argp1);
  delete arg1;
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *RtcpFbCap_swigregister(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *obj;
  if (!SWIG_Python_UnpackTuple(args, "swigregister", 1, 1, &obj)) return NULL;
  SWIG_TypeNewClientData(SWIGTYPE_p_pj__RtcpFbCap, SWIG_NewClientData(obj));
  return SWIG_Py_Void();
}

SWIGINTERN PyObject *RtcpFbCap_swiginit(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  return SWIG_Python_InitShadowInstance(args);
}

SWIGINTERN PyObject *_wrap_RtcpFbConfig_dontUseAvpf_set(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::RtcpFbConfig *arg1 = (pj::RtcpFbConfig *) 0 ;
  bool arg2 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  bool val2 ;
  int ecode2 = 0 ;
  PyObject *swig_obj[2] ;
  
  if (!SWIG_Python_UnpackTuple(args, "RtcpFbConfig_dontUseAvpf_set", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__RtcpFbConfig, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "RtcpFbConfig_dontUseAvpf_set" "', argument " "1"" of type '" "pj::RtcpFbConfig *""'"); 
  }
  arg1 = reinterpret_cast< pj::RtcpFbConfig * >(argp1);
  ecode2 = SWIG_AsVal_bool(swig_obj[1], &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "RtcpFbConfig_dontUseAvpf_set" "', argument " "2"" of type '" "bool""'");
  } 
  arg2 = static_cast< bool >(val2);
  if (arg1) (arg1)->dontUseAvpf = arg2;
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_RtcpFbConfig_dontUseAvpf_get(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::RtcpFbConfig *arg1 = (pj::RtcpFbConfig *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  bool result;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__RtcpFbConfig, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "RtcpFbConfig_dontUseAvpf_get" "', argument " "1"" of type '" "pj::RtcpFbConfig *""'"); 
  }
  arg1 = reinterpret_cast< pj::RtcpFbConfig * >(argp1);
  result = (bool) ((arg1)->dontUseAvpf);
  resultobj = SWIG_From_bool(static_cast< bool >(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_RtcpFbConfig_caps_set(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::RtcpFbConfig *arg1 = (pj::RtcpFbConfig *) 0 ;
  pj::RtcpFbCapVector *arg2 = (pj::RtcpFbCapVector *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  void *argp2 = 0 ;
  int res2 = 0 ;
  PyObject *swig_obj[2] ;
  
  if (!SWIG_Python_UnpackTuple(args, "RtcpFbConfig_caps_set", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__RtcpFbConfig, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "RtcpFbConfig_caps_set" "', argument " "1"" of type '" "pj::RtcpFbConfig *""'"); 
  }
  arg1 = reinterpret_cast< pj::RtcpFbConfig * >(argp1);
  res2 = SWIG_ConvertPtr(swig_obj[1], &argp2,SWIGTYPE_p_std__vectorT_pj__RtcpFbCap_std__allocatorT_pj__RtcpFbCap_t_t, 0 |  0 );
  if (!SWIG_IsOK(res2)) {
    SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "RtcpFbConfig_caps_set" "', argument " "2"" of type '" "pj::RtcpFbCapVector *""'"); 
  }
  arg2 = reinterpret_cast< pj::RtcpFbCapVector * >(argp2);
  if (arg1) (arg1)->caps = *arg2;
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_RtcpFbConfig_caps_get(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::RtcpFbConfig *arg1 = (pj::RtcpFbConfig *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  pj::RtcpFbCapVector *result = 0 ;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__RtcpFbConfig, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "RtcpFbConfig_caps_get" "', argument " "1"" of type '" "pj::RtcpFbConfig *""'"); 
  }
  arg1 = reinterpret_cast< pj::RtcpFbConfig * >(argp1);
  result = (pj::RtcpFbCapVector *)& ((arg1)->caps);
  resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(result), SWIGTYPE_p_std__vectorT_pj__RtcpFbCap_std__allocatorT_pj__RtcpFbCap_t_t, 0 |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_new_RtcpFbConfig(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::RtcpFbConfig *result = 0 ;
  
  if (!SWIG_Python_UnpackTuple(args, "new_RtcpFbConfig", 0, 0, 0)) SWIG_fail;
  result = (pj::RtcpFbConfig *)new pj::RtcpFbConfig();
  resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(result), SWIGTYPE_p_pj__RtcpFbConfig, SWIG_POINTER_NEW |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_RtcpFbConfig_readObject(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::RtcpFbConfig *arg1 = (pj::RtcpFbConfig *) 0 ;
  pj::ContainerNode *arg2 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  void *argp2 = 0 ;
  int res2 = 0 ;
  PyObject *swig_obj[2] ;
  
  if (!SWIG_Python_UnpackTuple(args, "RtcpFbConfig_readObject", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__RtcpFbConfig, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "RtcpFbConfig_readObject" "', argument " "1"" of type '" "pj::RtcpFbConfig *""'"); 
  }
  arg1 = reinterpret_cast< pj::RtcpFbConfig * >(argp1);
  res2 = SWIG_ConvertPtr(swig_obj[1], &argp2, SWIGTYPE_p_pj__ContainerNode,  0  | 0);
  if (!SWIG_IsOK(res2)) {
    SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "RtcpFbConfig_readObject" "', argument " "2"" of type '" "pj::ContainerNode const &""'"); 
  }
  if (!argp2) {
    SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "RtcpFbConfig_readObject" "', argument " "2"" of type '" "pj::ContainerNode const &""'"); 
  }
  arg2 = reinterpret_cast< pj::ContainerNode * >(argp2);
  try {
    (arg1)->readObject((pj::ContainerNode const &)*arg2);
  } catch(pj::Error &_e) {
    SWIG_Python_Raise(SWIG_NewPointerObj((new pj::Error(static_cast< const pj::Error& >(_e))),SWIGTYPE_p_pj__Error,SWIG_POINTER_OWN), "pj::Error", SWIGTYPE_p_pj__Error); SWIG_fail;
  }
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_RtcpFbConfig_writeObject(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::RtcpFbConfig *arg1 = (pj::RtcpFbConfig *) 0 ;
  pj::ContainerNode *arg2 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  void *argp2 = 0 ;
  int res2 = 0 ;
  PyObject *swig_obj[2] ;
  
  if (!SWIG_Python_UnpackTuple(args, "RtcpFbConfig_writeObject", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__RtcpFbConfig, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "RtcpFbConfig_writeObject" "', argument " "1"" of type '" "pj::RtcpFbConfig const *""'"); 
  }
  arg1 = reinterpret_cast< pj::RtcpFbConfig * >(argp1);
  res2 = SWIG_ConvertPtr(swig_obj[1], &argp2, SWIGTYPE_p_pj__ContainerNode,  0 );
  if (!SWIG_IsOK(res2)) {
    SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "RtcpFbConfig_writeObject" "', argument " "2"" of type '" "pj::ContainerNode &""'"); 
  }
  if (!argp2) {
    SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "RtcpFbConfig_writeObject" "', argument " "2"" of type '" "pj::ContainerNode &""'"); 
  }
  arg2 = reinterpret_cast< pj::ContainerNode * >(argp2);
  try {
    ((pj::RtcpFbConfig const *)arg1)->writeObject(*arg2);
  } catch(pj::Error &_e) {
    SWIG_Python_Raise(SWIG_NewPointerObj((new pj::Error(static_cast< const pj::Error& >(_e))),SWIGTYPE_p_pj__Error,SWIG_POINTER_OWN), "pj::Error", SWIGTYPE_p_pj__Error); SWIG_fail;
  }
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_delete_RtcpFbConfig(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::RtcpFbConfig *arg1 = (pj::RtcpFbConfig *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__RtcpFbConfig, SWIG_POINTER_DISOWN |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "delete_RtcpFbConfig" "', argument " "1"" of type '" "pj::RtcpFbConfig *""'"); 
  }
  arg1 = reinterpret_cast< pj::RtcpFbConfig * >(argp1);
  delete arg1;
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *RtcpFbConfig_swigregister(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *obj;
  if (!SWIG_Python_UnpackTuple(args, "swigregister", 1, 1, &obj)) return NULL;
  SWIG_TypeNewClientData(SWIGTYPE_p_pj__RtcpFbConfig, SWIG_NewClientData(obj));
  return SWIG_Py_Void();
}

SWIGINTERN PyObject *RtcpFbConfig_swiginit(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  return SWIG_Python_InitShadowInstance(args);
}

SWIGINTERN PyObject *_wrap_AccountMediaConfig_transportConfig_set(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::AccountMediaConfig *arg1 = (pj::AccountMediaConfig *) 0 ;
  pj::TransportConfig *arg2 = (pj::TransportConfig *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  void *argp2 = 0 ;
  int res2 = 0 ;
  PyObject *swig_obj[2] ;
  
  if (!SWIG_Python_UnpackTuple(args, "AccountMediaConfig_transportConfig_set", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__AccountMediaConfig, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "AccountMediaConfig_transportConfig_set" "', argument " "1"" of type '" "pj::AccountMediaConfig *""'"); 
  }
  arg1 = reinterpret_cast< pj::AccountMediaConfig * >(argp1);
  res2 = SWIG_ConvertPtr(swig_obj[1], &argp2,SWIGTYPE_p_pj__TransportConfig, 0 |  0 );
  if (!SWIG_IsOK(res2)) {
    SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "AccountMediaConfig_transportConfig_set" "', argument " "2"" of type '" "pj::TransportConfig *""'"); 
  }
  arg2 = reinterpret_cast< pj::TransportConfig * >(argp2);
  if (arg1) (arg1)->transportConfig = *arg2;
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_AccountMediaConfig_transportConfig_get(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::AccountMediaConfig *arg1 = (pj::AccountMediaConfig *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  pj::TransportConfig *result = 0 ;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__AccountMediaConfig, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "AccountMediaConfig_transportConfig_get" "', argument " "1"" of type '" "pj::AccountMediaConfig *""'"); 
  }
  arg1 = reinterpret_cast< pj::AccountMediaConfig * >(argp1);
  result = (pj::TransportConfig *)& ((arg1)->transportConfig);
  resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(result), SWIGTYPE_p_pj__TransportConfig, 0 |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_AccountMediaConfig_lockCodecEnabled_set(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::AccountMediaConfig *arg1 = (pj::AccountMediaConfig *) 0 ;
  bool arg2 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  bool val2 ;
  int ecode2 = 0 ;
  PyObject *swig_obj[2] ;
  
  if (!SWIG_Python_UnpackTuple(args, "AccountMediaConfig_lockCodecEnabled_set", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__AccountMediaConfig, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "AccountMediaConfig_lockCodecEnabled_set" "', argument " "1"" of type '" "pj::AccountMediaConfig *""'"); 
  }
  arg1 = reinterpret_cast< pj::AccountMediaConfig * >(argp1);
  ecode2 = SWIG_AsVal_bool(swig_obj[1], &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "AccountMediaConfig_lockCodecEnabled_set" "', argument " "2"" of type '" "bool""'");
  } 
  arg2 = static_cast< bool >(val2);
  if (arg1) (arg1)->lockCodecEnabled = arg2;
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_AccountMediaConfig_lockCodecEnabled_get(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::AccountMediaConfig *arg1 = (pj::AccountMediaConfig *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  bool result;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__AccountMediaConfig, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "AccountMediaConfig_lockCodecEnabled_get" "', argument " "1"" of type '" "pj::AccountMediaConfig *""'"); 
  }
  arg1 = reinterpret_cast< pj::AccountMediaConfig * >(argp1);
  result = (bool) ((arg1)->lockCodecEnabled);
  resultobj = SWIG_From_bool(static_cast< bool >(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_AccountMediaConfig_streamKaEnabled_set(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::AccountMediaConfig *arg1 = (pj::AccountMediaConfig *) 0 ;
  bool arg2 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  bool val2 ;
  int ecode2 = 0 ;
  PyObject *swig_obj[2] ;
  
  if (!SWIG_Python_UnpackTuple(args, "AccountMediaConfig_streamKaEnabled_set", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__AccountMediaConfig, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "AccountMediaConfig_streamKaEnabled_set" "', argument " "1"" of type '" "pj::AccountMediaConfig *""'"); 
  }
  arg1 = reinterpret_cast< pj::AccountMediaConfig * >(argp1);
  ecode2 = SWIG_AsVal_bool(swig_obj[1], &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "AccountMediaConfig_streamKaEnabled_set" "', argument " "2"" of type '" "bool""'");
  } 
  arg2 = static_cast< bool >(val2);
  if (arg1) (arg1)->streamKaEnabled = arg2;
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_AccountMediaConfig_streamKaEnabled_get(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::AccountMediaConfig *arg1 = (pj::AccountMediaConfig *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  bool result;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__AccountMediaConfig, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "AccountMediaConfig_streamKaEnabled_get" "', argument " "1"" of type '" "pj::AccountMediaConfig *""'"); 
  }
  arg1 = reinterpret_cast< pj::AccountMediaConfig * >(argp1);
  result = (bool) ((arg1)->streamKaEnabled);
  resultobj = SWIG_From_bool(static_cast< bool >(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_AccountMediaConfig_srtpUse_set(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::AccountMediaConfig *arg1 = (pj::AccountMediaConfig *) 0 ;
  pjmedia_srtp_use arg2 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  int val2 ;
  int ecode2 = 0 ;
  PyObject *swig_obj[2] ;
  
  if (!SWIG_Python_UnpackTuple(args, "AccountMediaConfig_srtpUse_set", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__AccountMediaConfig, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "AccountMediaConfig_srtpUse_set" "', argument " "1"" of type '" "pj::AccountMediaConfig *""'"); 
  }
  arg1 = reinterpret_cast< pj::AccountMediaConfig * >(argp1);
  ecode2 = SWIG_AsVal_int(swig_obj[1], &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "AccountMediaConfig_srtpUse_set" "', argument " "2"" of type '" "pjmedia_srtp_use""'");
  } 
  arg2 = static_cast< pjmedia_srtp_use >(val2);
  if (arg1) (arg1)->srtpUse = arg2;
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_AccountMediaConfig_srtpUse_get(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::AccountMediaConfig *arg1 = (pj::AccountMediaConfig *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  pjmedia_srtp_use result;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__AccountMediaConfig, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "AccountMediaConfig_srtpUse_get" "', argument " "1"" of type '" "pj::AccountMediaConfig *""'"); 
  }
  arg1 = reinterpret_cast< pj::AccountMediaConfig * >(argp1);
  result = (pjmedia_srtp_use) ((arg1)->srtpUse);
  resultobj = SWIG_From_int(static_cast< int >(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_AccountMediaConfig_srtpSecureSignaling_set(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::AccountMediaConfig *arg1 = (pj::AccountMediaConfig *) 0 ;
  int arg2 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  int val2 ;
  int ecode2 = 0 ;
  PyObject *swig_obj[2] ;
  
  if (!SWIG_Python_UnpackTuple(args, "AccountMediaConfig_srtpSecureSignaling_set", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__AccountMediaConfig, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "AccountMediaConfig_srtpSecureSignaling_set" "', argument " "1"" of type '" "pj::AccountMediaConfig *""'"); 
  }
  arg1 = reinterpret_cast< pj::AccountMediaConfig * >(argp1);
  ecode2 = SWIG_AsVal_int(swig_obj[1], &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "AccountMediaConfig_srtpSecureSignaling_set" "', argument " "2"" of type '" "int""'");
  } 
  arg2 = static_cast< int >(val2);
  if (arg1) (arg1)->srtpSecureSignaling = arg2;
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_AccountMediaConfig_srtpSecureSignaling_get(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::AccountMediaConfig *arg1 = (pj::AccountMediaConfig *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  int result;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__AccountMediaConfig, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "AccountMediaConfig_srtpSecureSignaling_get" "', argument " "1"" of type '" "pj::AccountMediaConfig *""'"); 
  }
  arg1 = reinterpret_cast< pj::AccountMediaConfig * >(argp1);
  result = (int) ((arg1)->srtpSecureSignaling);
  resultobj = SWIG_From_int(static_cast< int >(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_AccountMediaConfig_srtpOpt_set(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::AccountMediaConfig *arg1 = (pj::AccountMediaConfig *) 0 ;
  pj::SrtpOpt *arg2 = (pj::SrtpOpt *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  void *argp2 = 0 ;
  int res2 = 0 ;
  PyObject *swig_obj[2] ;
  
  if (!SWIG_Python_UnpackTuple(args, "AccountMediaConfig_srtpOpt_set", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__AccountMediaConfig, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "AccountMediaConfig_srtpOpt_set" "', argument " "1"" of type '" "pj::AccountMediaConfig *""'"); 
  }
  arg1 = reinterpret_cast< pj::AccountMediaConfig * >(argp1);
  res2 = SWIG_ConvertPtr(swig_obj[1], &argp2,SWIGTYPE_p_pj__SrtpOpt, 0 |  0 );
  if (!SWIG_IsOK(res2)) {
    SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "AccountMediaConfig_srtpOpt_set" "', argument " "2"" of type '" "pj::SrtpOpt *""'"); 
  }
  arg2 = reinterpret_cast< pj::SrtpOpt * >(argp2);
  if (arg1) (arg1)->srtpOpt = *arg2;
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_AccountMediaConfig_srtpOpt_get(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::AccountMediaConfig *arg1 = (pj::AccountMediaConfig *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  pj::SrtpOpt *result = 0 ;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__AccountMediaConfig, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "AccountMediaConfig_srtpOpt_get" "', argument " "1"" of type '" "pj::AccountMediaConfig *""'"); 
  }
  arg1 = reinterpret_cast< pj::AccountMediaConfig * >(argp1);
  result = (pj::SrtpOpt *)& ((arg1)->srtpOpt);
  resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(result), SWIGTYPE_p_pj__SrtpOpt, 0 |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_AccountMediaConfig_ipv6Use_set(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::AccountMediaConfig *arg1 = (pj::AccountMediaConfig *) 0 ;
  pjsua_ipv6_use arg2 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  int val2 ;
  int ecode2 = 0 ;
  PyObject *swig_obj[2] ;
  
  if (!SWIG_Python_UnpackTuple(args, "AccountMediaConfig_ipv6Use_set", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__AccountMediaConfig, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "AccountMediaConfig_ipv6Use_set" "', argument " "1"" of type '" "pj::AccountMediaConfig *""'"); 
  }
  arg1 = reinterpret_cast< pj::AccountMediaConfig * >(argp1);
  ecode2 = SWIG_AsVal_int(swig_obj[1], &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "AccountMediaConfig_ipv6Use_set" "', argument " "2"" of type '" "pjsua_ipv6_use""'");
  } 
  arg2 = static_cast< pjsua_ipv6_use >(val2);
  if (arg1) (arg1)->ipv6Use = arg2;
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_AccountMediaConfig_ipv6Use_get(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::AccountMediaConfig *arg1 = (pj::AccountMediaConfig *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  pjsua_ipv6_use result;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__AccountMediaConfig, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "AccountMediaConfig_ipv6Use_get" "', argument " "1"" of type '" "pj::AccountMediaConfig *""'"); 
  }
  arg1 = reinterpret_cast< pj::AccountMediaConfig * >(argp1);
  result = (pjsua_ipv6_use) ((arg1)->ipv6Use);
  resultobj = SWIG_From_int(static_cast< int >(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_AccountMediaConfig_rtcpMuxEnabled_set(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::AccountMediaConfig *arg1 = (pj::AccountMediaConfig *) 0 ;
  bool arg2 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  bool val2 ;
  int ecode2 = 0 ;
  PyObject *swig_obj[2] ;
  
  if (!SWIG_Python_UnpackTuple(args, "AccountMediaConfig_rtcpMuxEnabled_set", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__AccountMediaConfig, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "AccountMediaConfig_rtcpMuxEnabled_set" "', argument " "1"" of type '" "pj::AccountMediaConfig *""'"); 
  }
  arg1 = reinterpret_cast< pj::AccountMediaConfig * >(argp1);
  ecode2 = SWIG_AsVal_bool(swig_obj[1], &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "AccountMediaConfig_rtcpMuxEnabled_set" "', argument " "2"" of type '" "bool""'");
  } 
  arg2 = static_cast< bool >(val2);
  if (arg1) (arg1)->rtcpMuxEnabled = arg2;
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_AccountMediaConfig_rtcpMuxEnabled_get(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::AccountMediaConfig *arg1 = (pj::AccountMediaConfig *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  bool result;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__AccountMediaConfig, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "AccountMediaConfig_rtcpMuxEnabled_get" "', argument " "1"" of type '" "pj::AccountMediaConfig *""'"); 
  }
  arg1 = reinterpret_cast< pj::AccountMediaConfig * >(argp1);
  result = (bool) ((arg1)->rtcpMuxEnabled);
  resultobj = SWIG_From_bool(static_cast< bool >(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_AccountMediaConfig_rtcpFbConfig_set(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::AccountMediaConfig *arg1 = (pj::AccountMediaConfig *) 0 ;
  pj::RtcpFbConfig *arg2 = (pj::RtcpFbConfig *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  void *argp2 = 0 ;
  int res2 = 0 ;
  PyObject *swig_obj[2] ;
  
  if (!SWIG_Python_UnpackTuple(args, "AccountMediaConfig_rtcpFbConfig_set", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__AccountMediaConfig, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "AccountMediaConfig_rtcpFbConfig_set" "', argument " "1"" of type '" "pj::AccountMediaConfig *""'"); 
  }
  arg1 = reinterpret_cast< pj::AccountMediaConfig * >(argp1);
  res2 = SWIG_ConvertPtr(swig_obj[1], &argp2,SWIGTYPE_p_pj__RtcpFbConfig, 0 |  0 );
  if (!SWIG_IsOK(res2)) {
    SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "AccountMediaConfig_rtcpFbConfig_set" "', argument " "2"" of type '" "pj::RtcpFbConfig *""'"); 
  }
  arg2 = reinterpret_cast< pj::RtcpFbConfig * >(argp2);
  if (arg1) (arg1)->rtcpFbConfig = *arg2;
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_AccountMediaConfig_rtcpFbConfig_get(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::AccountMediaConfig *arg1 = (pj::AccountMediaConfig *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  pj::RtcpFbConfig *result = 0 ;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__AccountMediaConfig, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "AccountMediaConfig_rtcpFbConfig_get" "', argument " "1"" of type '" "pj::AccountMediaConfig *""'"); 
  }
  arg1 = reinterpret_cast< pj::AccountMediaConfig * >(argp1);
  result = (pj::RtcpFbConfig *)& ((arg1)->rtcpFbConfig);
  resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(result), SWIGTYPE_p_pj__RtcpFbConfig, 0 |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_AccountMediaConfig_useLoopMedTp_set(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::AccountMediaConfig *arg1 = (pj::AccountMediaConfig *) 0 ;
  bool arg2 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  bool val2 ;
  int ecode2 = 0 ;
  PyObject *swig_obj[2] ;
  
  if (!SWIG_Python_UnpackTuple(args, "AccountMediaConfig_useLoopMedTp_set", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__AccountMediaConfig, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "AccountMediaConfig_useLoopMedTp_set" "', argument " "1"" of type '" "pj::AccountMediaConfig *""'"); 
  }
  arg1 = reinterpret_cast< pj::AccountMediaConfig * >(argp1);
  ecode2 = SWIG_AsVal_bool(swig_obj[1], &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "AccountMediaConfig_useLoopMedTp_set" "', argument " "2"" of type '" "bool""'");
  } 
  arg2 = static_cast< bool >(val2);
  if (arg1) (arg1)->useLoopMedTp = arg2;
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_AccountMediaConfig_useLoopMedTp_get(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::AccountMediaConfig *arg1 = (pj::AccountMediaConfig *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  bool result;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__AccountMediaConfig, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "AccountMediaConfig_useLoopMedTp_get" "', argument " "1"" of type '" "pj::AccountMediaConfig *""'"); 
  }
  arg1 = reinterpret_cast< pj::AccountMediaConfig * >(argp1);
  result = (bool) ((arg1)->useLoopMedTp);
  resultobj = SWIG_From_bool(static_cast< bool >(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_AccountMediaConfig_enableLoopback_set(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::AccountMediaConfig *arg1 = (pj::AccountMediaConfig *) 0 ;
  bool arg2 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  bool val2 ;
  int ecode2 = 0 ;
  PyObject *swig_obj[2] ;
  
  if (!SWIG_Python_UnpackTuple(args, "AccountMediaConfig_enableLoopback_set", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__AccountMediaConfig, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "AccountMediaConfig_enableLoopback_set" "', argument " "1"" of type '" "pj::AccountMediaConfig *""'"); 
  }
  arg1 = reinterpret_cast< pj::AccountMediaConfig * >(argp1);
  ecode2 = SWIG_AsVal_bool(swig_obj[1], &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "AccountMediaConfig_enableLoopback_set" "', argument " "2"" of type '" "bool""'");
  } 
  arg2 = static_cast< bool >(val2);
  if (arg1) (arg1)->enableLoopback = arg2;
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_AccountMediaConfig_enableLoopback_get(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::AccountMediaConfig *arg1 = (pj::AccountMediaConfig *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  bool result;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__AccountMediaConfig, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "AccountMediaConfig_enableLoopback_get" "', argument " "1"" of type '" "pj::AccountMediaConfig *""'"); 
  }
  arg1 = reinterpret_cast< pj::AccountMediaConfig * >(argp1);
  result = (bool) ((arg1)->enableLoopback);
  resultobj = SWIG_From_bool(static_cast< bool >(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_new_AccountMediaConfig(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::AccountMediaConfig *result = 0 ;
  
  if (!SWIG_Python_UnpackTuple(args, "new_AccountMediaConfig", 0, 0, 0)) SWIG_fail;
  result = (pj::AccountMediaConfig *)new pj::AccountMediaConfig();
  resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(result), SWIGTYPE_p_pj__AccountMediaConfig, SWIG_POINTER_NEW |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_AccountMediaConfig_readObject(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::AccountMediaConfig *arg1 = (pj::AccountMediaConfig *) 0 ;
  pj::ContainerNode *arg2 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  void *argp2 = 0 ;
  int res2 = 0 ;
  PyObject *swig_obj[2] ;
  
  if (!SWIG_Python_UnpackTuple(args, "AccountMediaConfig_readObject", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__AccountMediaConfig, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "AccountMediaConfig_readObject" "', argument " "1"" of type '" "pj::AccountMediaConfig *""'"); 
  }
  arg1 = reinterpret_cast< pj::AccountMediaConfig * >(argp1);
  res2 = SWIG_ConvertPtr(swig_obj[1], &argp2, SWIGTYPE_p_pj__ContainerNode,  0  | 0);
  if (!SWIG_IsOK(res2)) {
    SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "AccountMediaConfig_readObject" "', argument " "2"" of type '" "pj::ContainerNode const &""'"); 
  }
  if (!argp2) {
    SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "AccountMediaConfig_readObject" "', argument " "2"" of type '" "pj::ContainerNode const &""'"); 
  }
  arg2 = reinterpret_cast< pj::ContainerNode * >(argp2);
  try {
    (arg1)->readObject((pj::ContainerNode const &)*arg2);
  } catch(pj::Error &_e) {
    SWIG_Python_Raise(SWIG_NewPointerObj((new pj::Error(static_cast< const pj::Error& >(_e))),SWIGTYPE_p_pj__Error,SWIG_POINTER_OWN), "pj::Error", SWIGTYPE_p_pj__Error); SWIG_fail;
  }
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_AccountMediaConfig_writeObject(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::AccountMediaConfig *arg1 = (pj::AccountMediaConfig *) 0 ;
  pj::ContainerNode *arg2 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  void *argp2 = 0 ;
  int res2 = 0 ;
  PyObject *swig_obj[2] ;
  
  if (!SWIG_Python_UnpackTuple(args, "AccountMediaConfig_writeObject", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__AccountMediaConfig, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "AccountMediaConfig_writeObject" "', argument " "1"" of type '" "pj::AccountMediaConfig const *""'"); 
  }
  arg1 = reinterpret_cast< pj::AccountMediaConfig * >(argp1);
  res2 = SWIG_ConvertPtr(swig_obj[1], &argp2, SWIGTYPE_p_pj__ContainerNode,  0 );
  if (!SWIG_IsOK(res2)) {
    SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "AccountMediaConfig_writeObject" "', argument " "2"" of type '" "pj::ContainerNode &""'"); 
  }
  if (!argp2) {
    SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "AccountMediaConfig_writeObject" "', argument " "2"" of type '" "pj::ContainerNode &""'"); 
  }
  arg2 = reinterpret_cast< pj::ContainerNode * >(argp2);
  try {
    ((pj::AccountMediaConfig const *)arg1)->writeObject(*arg2);
  } catch(pj::Error &_e) {
    SWIG_Python_Raise(SWIG_NewPointerObj((new pj::Error(static_cast< const pj::Error& >(_e))),SWIGTYPE_p_pj__Error,SWIG_POINTER_OWN), "pj::Error", SWIGTYPE_p_pj__Error); SWIG_fail;
  }
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_delete_AccountMediaConfig(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::AccountMediaConfig *arg1 = (pj::AccountMediaConfig *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__AccountMediaConfig, SWIG_POINTER_DISOWN |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "delete_AccountMediaConfig" "', argument " "1"" of type '" "pj::AccountMediaConfig *""'"); 
  }
  arg1 = reinterpret_cast< pj::AccountMediaConfig * >(argp1);
  delete arg1;
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *AccountMediaConfig_swigregister(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *obj;
  if (!SWIG_Python_UnpackTuple(args, "swigregister", 1, 1, &obj)) return NULL;
  SWIG_TypeNewClientData(SWIGTYPE_p_pj__AccountMediaConfig, SWIG_NewClientData(obj));
  return SWIG_Py_Void();
}

SWIGINTERN PyObject *AccountMediaConfig_swiginit(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  return SWIG_Python_InitShadowInstance(args);
}

SWIGINTERN PyObject *_wrap_AccountVideoConfig_autoShowIncoming_set(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::AccountVideoConfig *arg1 = (pj::AccountVideoConfig *) 0 ;
  bool arg2 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  bool val2 ;
  int ecode2 = 0 ;
  PyObject *swig_obj[2] ;
  
  if (!SWIG_Python_UnpackTuple(args, "AccountVideoConfig_autoShowIncoming_set", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__AccountVideoConfig, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "AccountVideoConfig_autoShowIncoming_set" "', argument " "1"" of type '" "pj::AccountVideoConfig *""'"); 
  }
  arg1 = reinterpret_cast< pj::AccountVideoConfig * >(argp1);
  ecode2 = SWIG_AsVal_bool(swig_obj[1], &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "AccountVideoConfig_autoShowIncoming_set" "', argument " "2"" of type '" "bool""'");
  } 
  arg2 = static_cast< bool >(val2);
  if (arg1) (arg1)->autoShowIncoming = arg2;
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_AccountVideoConfig_autoShowIncoming_get(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::AccountVideoConfig *arg1 = (pj::AccountVideoConfig *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  bool result;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__AccountVideoConfig, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "AccountVideoConfig_autoShowIncoming_get" "', argument " "1"" of type '" "pj::AccountVideoConfig *""'"); 
  }
  arg1 = reinterpret_cast< pj::AccountVideoConfig * >(argp1);
  result = (bool) ((arg1)->autoShowIncoming);
  resultobj = SWIG_From_bool(static_cast< bool >(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_AccountVideoConfig_autoTransmitOutgoing_set(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::AccountVideoConfig *arg1 = (pj::AccountVideoConfig *) 0 ;
  bool arg2 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  bool val2 ;
  int ecode2 = 0 ;
  PyObject *swig_obj[2] ;
  
  if (!SWIG_Python_UnpackTuple(args, "AccountVideoConfig_autoTransmitOutgoing_set", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__AccountVideoConfig, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "AccountVideoConfig_autoTransmitOutgoing_set" "', argument " "1"" of type '" "pj::AccountVideoConfig *""'"); 
  }
  arg1 = reinterpret_cast< pj::AccountVideoConfig * >(argp1);
  ecode2 = SWIG_AsVal_bool(swig_obj[1], &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "AccountVideoConfig_autoTransmitOutgoing_set" "', argument " "2"" of type '" "bool""'");
  } 
  arg2 = static_cast< bool >(val2);
  if (arg1) (arg1)->autoTransmitOutgoing = arg2;
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_AccountVideoConfig_autoTransmitOutgoing_get(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::AccountVideoConfig *arg1 = (pj::AccountVideoConfig *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  bool result;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__AccountVideoConfig, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "AccountVideoConfig_autoTransmitOutgoing_get" "', argument " "1"" of type '" "pj::AccountVideoConfig *""'"); 
  }
  arg1 = reinterpret_cast< pj::AccountVideoConfig * >(argp1);
  result = (bool) ((arg1)->autoTransmitOutgoing);
  resultobj = SWIG_From_bool(static_cast< bool >(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_AccountVideoConfig_windowFlags_set(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::AccountVideoConfig *arg1 = (pj::AccountVideoConfig *) 0 ;
  unsigned int arg2 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  unsigned int val2 ;
  int ecode2 = 0 ;
  PyObject *swig_obj[2] ;
  
  if (!SWIG_Python_UnpackTuple(args, "AccountVideoConfig_windowFlags_set", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__AccountVideoConfig, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "AccountVideoConfig_windowFlags_set" "', argument " "1"" of type '" "pj::AccountVideoConfig *""'"); 
  }
  arg1 = reinterpret_cast< pj::AccountVideoConfig * >(argp1);
  ecode2 = SWIG_AsVal_unsigned_SS_int(swig_obj[1], &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "AccountVideoConfig_windowFlags_set" "', argument " "2"" of type '" "unsigned int""'");
  } 
  arg2 = static_cast< unsigned int >(val2);
  if (arg1) (arg1)->windowFlags = arg2;
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_AccountVideoConfig_windowFlags_get(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::AccountVideoConfig *arg1 = (pj::AccountVideoConfig *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  unsigned int result;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__AccountVideoConfig, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "AccountVideoConfig_windowFlags_get" "', argument " "1"" of type '" "pj::AccountVideoConfig *""'"); 
  }
  arg1 = reinterpret_cast< pj::AccountVideoConfig * >(argp1);
  result = (unsigned int) ((arg1)->windowFlags);
  resultobj = SWIG_From_unsigned_SS_int(static_cast< unsigned int >(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_AccountVideoConfig_defaultCaptureDevice_set(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::AccountVideoConfig *arg1 = (pj::AccountVideoConfig *) 0 ;
  pjmedia_vid_dev_index arg2 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  int val2 ;
  int ecode2 = 0 ;
  PyObject *swig_obj[2] ;
  
  if (!SWIG_Python_UnpackTuple(args, "AccountVideoConfig_defaultCaptureDevice_set", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__AccountVideoConfig, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "AccountVideoConfig_defaultCaptureDevice_set" "', argument " "1"" of type '" "pj::AccountVideoConfig *""'"); 
  }
  arg1 = reinterpret_cast< pj::AccountVideoConfig * >(argp1);
  ecode2 = SWIG_AsVal_int(swig_obj[1], &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "AccountVideoConfig_defaultCaptureDevice_set" "', argument " "2"" of type '" "pjmedia_vid_dev_index""'");
  } 
  arg2 = static_cast< pjmedia_vid_dev_index >(val2);
  if (arg1) (arg1)->defaultCaptureDevice = arg2;
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_AccountVideoConfig_defaultCaptureDevice_get(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::AccountVideoConfig *arg1 = (pj::AccountVideoConfig *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  pjmedia_vid_dev_index result;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__AccountVideoConfig, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "AccountVideoConfig_defaultCaptureDevice_get" "', argument " "1"" of type '" "pj::AccountVideoConfig *""'"); 
  }
  arg1 = reinterpret_cast< pj::AccountVideoConfig * >(argp1);
  result = (pjmedia_vid_dev_index) ((arg1)->defaultCaptureDevice);
  resultobj = SWIG_From_int(static_cast< int >(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_AccountVideoConfig_defaultRenderDevice_set(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::AccountVideoConfig *arg1 = (pj::AccountVideoConfig *) 0 ;
  pjmedia_vid_dev_index arg2 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  int val2 ;
  int ecode2 = 0 ;
  PyObject *swig_obj[2] ;
  
  if (!SWIG_Python_UnpackTuple(args, "AccountVideoConfig_defaultRenderDevice_set", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__AccountVideoConfig, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "AccountVideoConfig_defaultRenderDevice_set" "', argument " "1"" of type '" "pj::AccountVideoConfig *""'"); 
  }
  arg1 = reinterpret_cast< pj::AccountVideoConfig * >(argp1);
  ecode2 = SWIG_AsVal_int(swig_obj[1], &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "AccountVideoConfig_defaultRenderDevice_set" "', argument " "2"" of type '" "pjmedia_vid_dev_index""'");
  } 
  arg2 = static_cast< pjmedia_vid_dev_index >(val2);
  if (arg1) (arg1)->defaultRenderDevice = arg2;
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_AccountVideoConfig_defaultRenderDevice_get(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::AccountVideoConfig *arg1 = (pj::AccountVideoConfig *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  pjmedia_vid_dev_index result;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__AccountVideoConfig, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "AccountVideoConfig_defaultRenderDevice_get" "', argument " "1"" of type '" "pj::AccountVideoConfig *""'"); 
  }
  arg1 = reinterpret_cast< pj::AccountVideoConfig * >(argp1);
  result = (pjmedia_vid_dev_index) ((arg1)->defaultRenderDevice);
  resultobj = SWIG_From_int(static_cast< int >(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_AccountVideoConfig_rateControlMethod_set(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::AccountVideoConfig *arg1 = (pj::AccountVideoConfig *) 0 ;
  pjmedia_vid_stream_rc_method arg2 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  int val2 ;
  int ecode2 = 0 ;
  PyObject *swig_obj[2] ;
  
  if (!SWIG_Python_UnpackTuple(args, "AccountVideoConfig_rateControlMethod_set", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__AccountVideoConfig, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "AccountVideoConfig_rateControlMethod_set" "', argument " "1"" of type '" "pj::AccountVideoConfig *""'"); 
  }
  arg1 = reinterpret_cast< pj::AccountVideoConfig * >(argp1);
  ecode2 = SWIG_AsVal_int(swig_obj[1], &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "AccountVideoConfig_rateControlMethod_set" "', argument " "2"" of type '" "pjmedia_vid_stream_rc_method""'");
  } 
  arg2 = static_cast< pjmedia_vid_stream_rc_method >(val2);
  if (arg1) (arg1)->rateControlMethod = arg2;
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_AccountVideoConfig_rateControlMethod_get(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::AccountVideoConfig *arg1 = (pj::AccountVideoConfig *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  pjmedia_vid_stream_rc_method result;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__AccountVideoConfig, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "AccountVideoConfig_rateControlMethod_get" "', argument " "1"" of type '" "pj::AccountVideoConfig *""'"); 
  }
  arg1 = reinterpret_cast< pj::AccountVideoConfig * >(argp1);
  result = (pjmedia_vid_stream_rc_method) ((arg1)->rateControlMethod);
  resultobj = SWIG_From_int(static_cast< int >(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_AccountVideoConfig_rateControlBandwidth_set(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::AccountVideoConfig *arg1 = (pj::AccountVideoConfig *) 0 ;
  unsigned int arg2 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  unsigned int val2 ;
  int ecode2 = 0 ;
  PyObject *swig_obj[2] ;
  
  if (!SWIG_Python_UnpackTuple(args, "AccountVideoConfig_rateControlBandwidth_set", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__AccountVideoConfig, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "AccountVideoConfig_rateControlBandwidth_set" "', argument " "1"" of type '" "pj::AccountVideoConfig *""'"); 
  }
  arg1 = reinterpret_cast< pj::AccountVideoConfig * >(argp1);
  ecode2 = SWIG_AsVal_unsigned_SS_int(swig_obj[1], &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "AccountVideoConfig_rateControlBandwidth_set" "', argument " "2"" of type '" "unsigned int""'");
  } 
  arg2 = static_cast< unsigned int >(val2);
  if (arg1) (arg1)->rateControlBandwidth = arg2;
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_AccountVideoConfig_rateControlBandwidth_get(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::AccountVideoConfig *arg1 = (pj::AccountVideoConfig *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  unsigned int result;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__AccountVideoConfig, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "AccountVideoConfig_rateControlBandwidth_get" "', argument " "1"" of type '" "pj::AccountVideoConfig *""'"); 
  }
  arg1 = reinterpret_cast< pj::AccountVideoConfig * >(argp1);
  result = (unsigned int) ((arg1)->rateControlBandwidth);
  resultobj = SWIG_From_unsigned_SS_int(static_cast< unsigned int >(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_AccountVideoConfig_startKeyframeCount_set(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::AccountVideoConfig *arg1 = (pj::AccountVideoConfig *) 0 ;
  unsigned int arg2 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  unsigned int val2 ;
  int ecode2 = 0 ;
  PyObject *swig_obj[2] ;
  
  if (!SWIG_Python_UnpackTuple(args, "AccountVideoConfig_startKeyframeCount_set", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__AccountVideoConfig, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "AccountVideoConfig_startKeyframeCount_set" "', argument " "1"" of type '" "pj::AccountVideoConfig *""'"); 
  }
  arg1 = reinterpret_cast< pj::AccountVideoConfig * >(argp1);
  ecode2 = SWIG_AsVal_unsigned_SS_int(swig_obj[1], &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "AccountVideoConfig_startKeyframeCount_set" "', argument " "2"" of type '" "unsigned int""'");
  } 
  arg2 = static_cast< unsigned int >(val2);
  if (arg1) (arg1)->startKeyframeCount = arg2;
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_AccountVideoConfig_startKeyframeCount_get(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::AccountVideoConfig *arg1 = (pj::AccountVideoConfig *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  unsigned int result;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__AccountVideoConfig, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "AccountVideoConfig_startKeyframeCount_get" "', argument " "1"" of type '" "pj::AccountVideoConfig *""'"); 
  }
  arg1 = reinterpret_cast< pj::AccountVideoConfig * >(argp1);
  result = (unsigned int) ((arg1)->startKeyframeCount);
  resultobj = SWIG_From_unsigned_SS_int(static_cast< unsigned int >(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_AccountVideoConfig_startKeyframeInterval_set(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::AccountVideoConfig *arg1 = (pj::AccountVideoConfig *) 0 ;
  unsigned int arg2 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  unsigned int val2 ;
  int ecode2 = 0 ;
  PyObject *swig_obj[2] ;
  
  if (!SWIG_Python_UnpackTuple(args, "AccountVideoConfig_startKeyframeInterval_set", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__AccountVideoConfig, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "AccountVideoConfig_startKeyframeInterval_set" "', argument " "1"" of type '" "pj::AccountVideoConfig *""'"); 
  }
  arg1 = reinterpret_cast< pj::AccountVideoConfig * >(argp1);
  ecode2 = SWIG_AsVal_unsigned_SS_int(swig_obj[1], &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "AccountVideoConfig_startKeyframeInterval_set" "', argument " "2"" of type '" "unsigned int""'");
  } 
  arg2 = static_cast< unsigned int >(val2);
  if (arg1) (arg1)->startKeyframeInterval = arg2;
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_AccountVideoConfig_startKeyframeInterval_get(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::AccountVideoConfig *arg1 = (pj::AccountVideoConfig *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  unsigned int result;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__AccountVideoConfig, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "AccountVideoConfig_startKeyframeInterval_get" "', argument " "1"" of type '" "pj::AccountVideoConfig *""'"); 
  }
  arg1 = reinterpret_cast< pj::AccountVideoConfig * >(argp1);
  result = (unsigned int) ((arg1)->startKeyframeInterval);
  resultobj = SWIG_From_unsigned_SS_int(static_cast< unsigned int >(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_new_AccountVideoConfig(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::AccountVideoConfig *result = 0 ;
  
  if (!SWIG_Python_UnpackTuple(args, "new_AccountVideoConfig", 0, 0, 0)) SWIG_fail;
  result = (pj::AccountVideoConfig *)new pj::AccountVideoConfig();
  resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(result), SWIGTYPE_p_pj__AccountVideoConfig, SWIG_POINTER_NEW |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_AccountVideoConfig_readObject(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::AccountVideoConfig *arg1 = (pj::AccountVideoConfig *) 0 ;
  pj::ContainerNode *arg2 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  void *argp2 = 0 ;
  int res2 = 0 ;
  PyObject *swig_obj[2] ;
  
  if (!SWIG_Python_UnpackTuple(args, "AccountVideoConfig_readObject", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__AccountVideoConfig, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "AccountVideoConfig_readObject" "', argument " "1"" of type '" "pj::AccountVideoConfig *""'"); 
  }
  arg1 = reinterpret_cast< pj::AccountVideoConfig * >(argp1);
  res2 = SWIG_ConvertPtr(swig_obj[1], &argp2, SWIGTYPE_p_pj__ContainerNode,  0  | 0);
  if (!SWIG_IsOK(res2)) {
    SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "AccountVideoConfig_readObject" "', argument " "2"" of type '" "pj::ContainerNode const &""'"); 
  }
  if (!argp2) {
    SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "AccountVideoConfig_readObject" "', argument " "2"" of type '" "pj::ContainerNode const &""'"); 
  }
  arg2 = reinterpret_cast< pj::ContainerNode * >(argp2);
  try {
    (arg1)->readObject((pj::ContainerNode const &)*arg2);
  } catch(pj::Error &_e) {
    SWIG_Python_Raise(SWIG_NewPointerObj((new pj::Error(static_cast< const pj::Error& >(_e))),SWIGTYPE_p_pj__Error,SWIG_POINTER_OWN), "pj::Error", SWIGTYPE_p_pj__Error); SWIG_fail;
  }
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_AccountVideoConfig_writeObject(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::AccountVideoConfig *arg1 = (pj::AccountVideoConfig *) 0 ;
  pj::ContainerNode *arg2 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  void *argp2 = 0 ;
  int res2 = 0 ;
  PyObject *swig_obj[2] ;
  
  if (!SWIG_Python_UnpackTuple(args, "AccountVideoConfig_writeObject", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__AccountVideoConfig, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "AccountVideoConfig_writeObject" "', argument " "1"" of type '" "pj::AccountVideoConfig const *""'"); 
  }
  arg1 = reinterpret_cast< pj::AccountVideoConfig * >(argp1);
  res2 = SWIG_ConvertPtr(swig_obj[1], &argp2, SWIGTYPE_p_pj__ContainerNode,  0 );
  if (!SWIG_IsOK(res2)) {
    SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "AccountVideoConfig_writeObject" "', argument " "2"" of type '" "pj::ContainerNode &""'"); 
  }
  if (!argp2) {
    SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "AccountVideoConfig_writeObject" "', argument " "2"" of type '" "pj::ContainerNode &""'"); 
  }
  arg2 = reinterpret_cast< pj::ContainerNode * >(argp2);
  try {
    ((pj::AccountVideoConfig const *)arg1)->writeObject(*arg2);
  } catch(pj::Error &_e) {
    SWIG_Python_Raise(SWIG_NewPointerObj((new pj::Error(static_cast< const pj::Error& >(_e))),SWIGTYPE_p_pj__Error,SWIG_POINTER_OWN), "pj::Error", SWIGTYPE_p_pj__Error); SWIG_fail;
  }
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_delete_AccountVideoConfig(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::AccountVideoConfig *arg1 = (pj::AccountVideoConfig *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__AccountVideoConfig, SWIG_POINTER_DISOWN |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "delete_AccountVideoConfig" "', argument " "1"" of type '" "pj::AccountVideoConfig *""'"); 
  }
  arg1 = reinterpret_cast< pj::AccountVideoConfig * >(argp1);
  delete arg1;
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *AccountVideoConfig_swigregister(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *obj;
  if (!SWIG_Python_UnpackTuple(args, "swigregister", 1, 1, &obj)) return NULL;
  SWIG_TypeNewClientData(SWIGTYPE_p_pj__AccountVideoConfig, SWIG_NewClientData(obj));
  return SWIG_Py_Void();
}

SWIGINTERN PyObject *AccountVideoConfig_swiginit(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  return SWIG_Python_InitShadowInstance(args);
}

SWIGINTERN PyObject *_wrap_AccountIpChangeConfig_shutdownTp_set(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::AccountIpChangeConfig *arg1 = (pj::AccountIpChangeConfig *) 0 ;
  bool arg2 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  bool val2 ;
  int ecode2 = 0 ;
  PyObject *swig_obj[2] ;
  
  if (!SWIG_Python_UnpackTuple(args, "AccountIpChangeConfig_shutdownTp_set", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__AccountIpChangeConfig, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "AccountIpChangeConfig_shutdownTp_set" "', argument " "1"" of type '" "pj::AccountIpChangeConfig *""'"); 
  }
  arg1 = reinterpret_cast< pj::AccountIpChangeConfig * >(argp1);
  ecode2 = SWIG_AsVal_bool(swig_obj[1], &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "AccountIpChangeConfig_shutdownTp_set" "', argument " "2"" of type '" "bool""'");
  } 
  arg2 = static_cast< bool >(val2);
  if (arg1) (arg1)->shutdownTp = arg2;
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_AccountIpChangeConfig_shutdownTp_get(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::AccountIpChangeConfig *arg1 = (pj::AccountIpChangeConfig *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  bool result;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__AccountIpChangeConfig, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "AccountIpChangeConfig_shutdownTp_get" "', argument " "1"" of type '" "pj::AccountIpChangeConfig *""'"); 
  }
  arg1 = reinterpret_cast< pj::AccountIpChangeConfig * >(argp1);
  result = (bool) ((arg1)->shutdownTp);
  resultobj = SWIG_From_bool(static_cast< bool >(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_AccountIpChangeConfig_hangupCalls_set(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::AccountIpChangeConfig *arg1 = (pj::AccountIpChangeConfig *) 0 ;
  bool arg2 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  bool val2 ;
  int ecode2 = 0 ;
  PyObject *swig_obj[2] ;
  
  if (!SWIG_Python_UnpackTuple(args, "AccountIpChangeConfig_hangupCalls_set", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__AccountIpChangeConfig, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "AccountIpChangeConfig_hangupCalls_set" "', argument " "1"" of type '" "pj::AccountIpChangeConfig *""'"); 
  }
  arg1 = reinterpret_cast< pj::AccountIpChangeConfig * >(argp1);
  ecode2 = SWIG_AsVal_bool(swig_obj[1], &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "AccountIpChangeConfig_hangupCalls_set" "', argument " "2"" of type '" "bool""'");
  } 
  arg2 = static_cast< bool >(val2);
  if (arg1) (arg1)->hangupCalls = arg2;
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_AccountIpChangeConfig_hangupCalls_get(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::AccountIpChangeConfig *arg1 = (pj::AccountIpChangeConfig *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  bool result;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__AccountIpChangeConfig, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "AccountIpChangeConfig_hangupCalls_get" "', argument " "1"" of type '" "pj::AccountIpChangeConfig *""'"); 
  }
  arg1 = reinterpret_cast< pj::AccountIpChangeConfig * >(argp1);
  result = (bool) ((arg1)->hangupCalls);
  resultobj = SWIG_From_bool(static_cast< bool >(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_AccountIpChangeConfig_reinviteFlags_set(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::AccountIpChangeConfig *arg1 = (pj::AccountIpChangeConfig *) 0 ;
  unsigned int arg2 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  unsigned int val2 ;
  int ecode2 = 0 ;
  PyObject *swig_obj[2] ;
  
  if (!SWIG_Python_UnpackTuple(args, "AccountIpChangeConfig_reinviteFlags_set", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__AccountIpChangeConfig, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "AccountIpChangeConfig_reinviteFlags_set" "', argument " "1"" of type '" "pj::AccountIpChangeConfig *""'"); 
  }
  arg1 = reinterpret_cast< pj::AccountIpChangeConfig * >(argp1);
  ecode2 = SWIG_AsVal_unsigned_SS_int(swig_obj[1], &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "AccountIpChangeConfig_reinviteFlags_set" "', argument " "2"" of type '" "unsigned int""'");
  } 
  arg2 = static_cast< unsigned int >(val2);
  if (arg1) (arg1)->reinviteFlags = arg2;
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_AccountIpChangeConfig_reinviteFlags_get(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::AccountIpChangeConfig *arg1 = (pj::AccountIpChangeConfig *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  unsigned int result;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__AccountIpChangeConfig, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "AccountIpChangeConfig_reinviteFlags_get" "', argument " "1"" of type '" "pj::AccountIpChangeConfig *""'"); 
  }
  arg1 = reinterpret_cast< pj::AccountIpChangeConfig * >(argp1);
  result = (unsigned int) ((arg1)->reinviteFlags);
  resultobj = SWIG_From_unsigned_SS_int(static_cast< unsigned int >(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_delete_AccountIpChangeConfig(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::AccountIpChangeConfig *arg1 = (pj::AccountIpChangeConfig *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__AccountIpChangeConfig, SWIG_POINTER_DISOWN |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "delete_AccountIpChangeConfig" "', argument " "1"" of type '" "pj::AccountIpChangeConfig *""'"); 
  }
  arg1 = reinterpret_cast< pj::AccountIpChangeConfig * >(argp1);
  delete arg1;
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_AccountIpChangeConfig_readObject(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::AccountIpChangeConfig *arg1 = (pj::AccountIpChangeConfig *) 0 ;
  pj::ContainerNode *arg2 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  void *argp2 = 0 ;
  int res2 = 0 ;
  PyObject *swig_obj[2] ;
  
  if (!SWIG_Python_UnpackTuple(args, "AccountIpChangeConfig_readObject", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__AccountIpChangeConfig, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "AccountIpChangeConfig_readObject" "', argument " "1"" of type '" "pj::AccountIpChangeConfig *""'"); 
  }
  arg1 = reinterpret_cast< pj::AccountIpChangeConfig * >(argp1);
  res2 = SWIG_ConvertPtr(swig_obj[1], &argp2, SWIGTYPE_p_pj__ContainerNode,  0  | 0);
  if (!SWIG_IsOK(res2)) {
    SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "AccountIpChangeConfig_readObject" "', argument " "2"" of type '" "pj::ContainerNode const &""'"); 
  }
  if (!argp2) {
    SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "AccountIpChangeConfig_readObject" "', argument " "2"" of type '" "pj::ContainerNode const &""'"); 
  }
  arg2 = reinterpret_cast< pj::ContainerNode * >(argp2);
  try {
    (arg1)->readObject((pj::ContainerNode const &)*arg2);
  } catch(pj::Error &_e) {
    SWIG_Python_Raise(SWIG_NewPointerObj((new pj::Error(static_cast< const pj::Error& >(_e))),SWIGTYPE_p_pj__Error,SWIG_POINTER_OWN), "pj::Error", SWIGTYPE_p_pj__Error); SWIG_fail;
  }
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_AccountIpChangeConfig_writeObject(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::AccountIpChangeConfig *arg1 = (pj::AccountIpChangeConfig *) 0 ;
  pj::ContainerNode *arg2 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  void *argp2 = 0 ;
  int res2 = 0 ;
  PyObject *swig_obj[2] ;
  
  if (!SWIG_Python_UnpackTuple(args, "AccountIpChangeConfig_writeObject", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__AccountIpChangeConfig, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "AccountIpChangeConfig_writeObject" "', argument " "1"" of type '" "pj::AccountIpChangeConfig const *""'"); 
  }
  arg1 = reinterpret_cast< pj::AccountIpChangeConfig * >(argp1);
  res2 = SWIG_ConvertPtr(swig_obj[1], &argp2, SWIGTYPE_p_pj__ContainerNode,  0 );
  if (!SWIG_IsOK(res2)) {
    SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "AccountIpChangeConfig_writeObject" "', argument " "2"" of type '" "pj::ContainerNode &""'"); 
  }
  if (!argp2) {
    SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "AccountIpChangeConfig_writeObject" "', argument " "2"" of type '" "pj::ContainerNode &""'"); 
  }
  arg2 = reinterpret_cast< pj::ContainerNode * >(argp2);
  try {
    ((pj::AccountIpChangeConfig const *)arg1)->writeObject(*arg2);
  } catch(pj::Error &_e) {
    SWIG_Python_Raise(SWIG_NewPointerObj((new pj::Error(static_cast< const pj::Error& >(_e))),SWIGTYPE_p_pj__Error,SWIG_POINTER_OWN), "pj::Error", SWIGTYPE_p_pj__Error); SWIG_fail;
  }
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_new_AccountIpChangeConfig(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::AccountIpChangeConfig *result = 0 ;
  
  if (!SWIG_Python_UnpackTuple(args, "new_AccountIpChangeConfig", 0, 0, 0)) SWIG_fail;
  result = (pj::AccountIpChangeConfig *)new pj::AccountIpChangeConfig();
  resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(result), SWIGTYPE_p_pj__AccountIpChangeConfig, SWIG_POINTER_NEW |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *AccountIpChangeConfig_swigregister(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *obj;
  if (!SWIG_Python_UnpackTuple(args, "swigregister", 1, 1, &obj)) return NULL;
  SWIG_TypeNewClientData(SWIGTYPE_p_pj__AccountIpChangeConfig, SWIG_NewClientData(obj));
  return SWIG_Py_Void();
}

SWIGINTERN PyObject *AccountIpChangeConfig_swiginit(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  return SWIG_Python_InitShadowInstance(args);
}

SWIGINTERN PyObject *_wrap_AccountConfig_priority_set(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::AccountConfig *arg1 = (pj::AccountConfig *) 0 ;
  int arg2 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  int val2 ;
  int ecode2 = 0 ;
  PyObject *swig_obj[2] ;
  
  if (!SWIG_Python_UnpackTuple(args, "AccountConfig_priority_set", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__AccountConfig, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "AccountConfig_priority_set" "', argument " "1"" of type '" "pj::AccountConfig *""'"); 
  }
  arg1 = reinterpret_cast< pj::AccountConfig * >(argp1);
  ecode2 = SWIG_AsVal_int(swig_obj[1], &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "AccountConfig_priority_set" "', argument " "2"" of type '" "int""'");
  } 
  arg2 = static_cast< int >(val2);
  if (arg1) (arg1)->priority = arg2;
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_AccountConfig_priority_get(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::AccountConfig *arg1 = (pj::AccountConfig *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  int result;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__AccountConfig, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "AccountConfig_priority_get" "', argument " "1"" of type '" "pj::AccountConfig *""'"); 
  }
  arg1 = reinterpret_cast< pj::AccountConfig * >(argp1);
  result = (int) ((arg1)->priority);
  resultobj = SWIG_From_int(static_cast< int >(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_AccountConfig_idUri_set(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::AccountConfig *arg1 = (pj::AccountConfig *) 0 ;
  pj::string *arg2 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  int res2 = SWIG_OLDOBJ ;
  PyObject *swig_obj[2] ;
  
  if (!SWIG_Python_UnpackTuple(args, "AccountConfig_idUri_set", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__AccountConfig, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "AccountConfig_idUri_set" "', argument " "1"" of type '" "pj::AccountConfig *""'"); 
  }
  arg1 = reinterpret_cast< pj::AccountConfig * >(argp1);
  {
    std::string *ptr = (std::string *)0;
    res2 = SWIG_AsPtr_std_string(swig_obj[1], &ptr);
    if (!SWIG_IsOK(res2)) {
      SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "AccountConfig_idUri_set" "', argument " "2"" of type '" "pj::string const &""'"); 
    }
    if (!ptr) {
      SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "AccountConfig_idUri_set" "', argument " "2"" of type '" "pj::string const &""'"); 
    }
    arg2 = ptr;
  }
  if (arg1) (arg1)->idUri = *arg2;
  resultobj = SWIG_Py_Void();
  if (SWIG_IsNewObj(res2)) delete arg2;
  return resultobj;
fail:
  if (SWIG_IsNewObj(res2)) delete arg2;
  return NULL;
}


SWIGINTERN PyObject *_wrap_AccountConfig_idUri_get(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::AccountConfig *arg1 = (pj::AccountConfig *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  pj::string *result = 0 ;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__AccountConfig, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "AccountConfig_idUri_get" "', argument " "1"" of type '" "pj::AccountConfig *""'"); 
  }
  arg1 = reinterpret_cast< pj::AccountConfig * >(argp1);
  result = (pj::string *) & ((arg1)->idUri);
  resultobj = SWIG_From_std_string(static_cast< std::string >(*result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_AccountConfig_regConfig_set(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::AccountConfig *arg1 = (pj::AccountConfig *) 0 ;
  pj::AccountRegConfig *arg2 = (pj::AccountRegConfig *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  void *argp2 = 0 ;
  int res2 = 0 ;
  PyObject *swig_obj[2] ;
  
  if (!SWIG_Python_UnpackTuple(args, "AccountConfig_regConfig_set", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__AccountConfig, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "AccountConfig_regConfig_set" "', argument " "1"" of type '" "pj::AccountConfig *""'"); 
  }
  arg1 = reinterpret_cast< pj::AccountConfig * >(argp1);
  res2 = SWIG_ConvertPtr(swig_obj[1], &argp2,SWIGTYPE_p_pj__AccountRegConfig, 0 |  0 );
  if (!SWIG_IsOK(res2)) {
    SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "AccountConfig_regConfig_set" "', argument " "2"" of type '" "pj::AccountRegConfig *""'"); 
  }
  arg2 = reinterpret_cast< pj::AccountRegConfig * >(argp2);
  if (arg1) (arg1)->regConfig = *arg2;
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_AccountConfig_regConfig_get(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::AccountConfig *arg1 = (pj::AccountConfig *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  pj::AccountRegConfig *result = 0 ;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__AccountConfig, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "AccountConfig_regConfig_get" "', argument " "1"" of type '" "pj::AccountConfig *""'"); 
  }
  arg1 = reinterpret_cast< pj::AccountConfig * >(argp1);
  result = (pj::AccountRegConfig *)& ((arg1)->regConfig);
  resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(result), SWIGTYPE_p_pj__AccountRegConfig, 0 |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_AccountConfig_sipConfig_set(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::AccountConfig *arg1 = (pj::AccountConfig *) 0 ;
  pj::AccountSipConfig *arg2 = (pj::AccountSipConfig *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  void *argp2 = 0 ;
  int res2 = 0 ;
  PyObject *swig_obj[2] ;
  
  if (!SWIG_Python_UnpackTuple(args, "AccountConfig_sipConfig_set", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__AccountConfig, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "AccountConfig_sipConfig_set" "', argument " "1"" of type '" "pj::AccountConfig *""'"); 
  }
  arg1 = reinterpret_cast< pj::AccountConfig * >(argp1);
  res2 = SWIG_ConvertPtr(swig_obj[1], &argp2,SWIGTYPE_p_pj__AccountSipConfig, 0 |  0 );
  if (!SWIG_IsOK(res2)) {
    SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "AccountConfig_sipConfig_set" "', argument " "2"" of type '" "pj::AccountSipConfig *""'"); 
  }
  arg2 = reinterpret_cast< pj::AccountSipConfig * >(argp2);
  if (arg1) (arg1)->sipConfig = *arg2;
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_AccountConfig_sipConfig_get(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::AccountConfig *arg1 = (pj::AccountConfig *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  pj::AccountSipConfig *result = 0 ;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__AccountConfig, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "AccountConfig_sipConfig_get" "', argument " "1"" of type '" "pj::AccountConfig *""'"); 
  }
  arg1 = reinterpret_cast< pj::AccountConfig * >(argp1);
  result = (pj::AccountSipConfig *)& ((arg1)->sipConfig);
  resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(result), SWIGTYPE_p_pj__AccountSipConfig, 0 |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_AccountConfig_callConfig_set(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::AccountConfig *arg1 = (pj::AccountConfig *) 0 ;
  pj::AccountCallConfig *arg2 = (pj::AccountCallConfig *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  void *argp2 = 0 ;
  int res2 = 0 ;
  PyObject *swig_obj[2] ;
  
  if (!SWIG_Python_UnpackTuple(args, "AccountConfig_callConfig_set", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__AccountConfig, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "AccountConfig_callConfig_set" "', argument " "1"" of type '" "pj::AccountConfig *""'"); 
  }
  arg1 = reinterpret_cast< pj::AccountConfig * >(argp1);
  res2 = SWIG_ConvertPtr(swig_obj[1], &argp2,SWIGTYPE_p_pj__AccountCallConfig, 0 |  0 );
  if (!SWIG_IsOK(res2)) {
    SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "AccountConfig_callConfig_set" "', argument " "2"" of type '" "pj::AccountCallConfig *""'"); 
  }
  arg2 = reinterpret_cast< pj::AccountCallConfig * >(argp2);
  if (arg1) (arg1)->callConfig = *arg2;
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_AccountConfig_callConfig_get(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::AccountConfig *arg1 = (pj::AccountConfig *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  pj::AccountCallConfig *result = 0 ;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__AccountConfig, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "AccountConfig_callConfig_get" "', argument " "1"" of type '" "pj::AccountConfig *""'"); 
  }
  arg1 = reinterpret_cast< pj::AccountConfig * >(argp1);
  result = (pj::AccountCallConfig *)& ((arg1)->callConfig);
  resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(result), SWIGTYPE_p_pj__AccountCallConfig, 0 |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_AccountConfig_presConfig_set(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::AccountConfig *arg1 = (pj::AccountConfig *) 0 ;
  pj::AccountPresConfig *arg2 = (pj::AccountPresConfig *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  void *argp2 = 0 ;
  int res2 = 0 ;
  PyObject *swig_obj[2] ;
  
  if (!SWIG_Python_UnpackTuple(args, "AccountConfig_presConfig_set", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__AccountConfig, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "AccountConfig_presConfig_set" "', argument " "1"" of type '" "pj::AccountConfig *""'"); 
  }
  arg1 = reinterpret_cast< pj::AccountConfig * >(argp1);
  res2 = SWIG_ConvertPtr(swig_obj[1], &argp2,SWIGTYPE_p_pj__AccountPresConfig, 0 |  0 );
  if (!SWIG_IsOK(res2)) {
    SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "AccountConfig_presConfig_set" "', argument " "2"" of type '" "pj::AccountPresConfig *""'"); 
  }
  arg2 = reinterpret_cast< pj::AccountPresConfig * >(argp2);
  if (arg1) (arg1)->presConfig = *arg2;
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_AccountConfig_presConfig_get(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::AccountConfig *arg1 = (pj::AccountConfig *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  pj::AccountPresConfig *result = 0 ;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__AccountConfig, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "AccountConfig_presConfig_get" "', argument " "1"" of type '" "pj::AccountConfig *""'"); 
  }
  arg1 = reinterpret_cast< pj::AccountConfig * >(argp1);
  result = (pj::AccountPresConfig *)& ((arg1)->presConfig);
  resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(result), SWIGTYPE_p_pj__AccountPresConfig, 0 |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_AccountConfig_mwiConfig_set(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::AccountConfig *arg1 = (pj::AccountConfig *) 0 ;
  pj::AccountMwiConfig *arg2 = (pj::AccountMwiConfig *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  void *argp2 = 0 ;
  int res2 = 0 ;
  PyObject *swig_obj[2] ;
  
  if (!SWIG_Python_UnpackTuple(args, "AccountConfig_mwiConfig_set", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__AccountConfig, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "AccountConfig_mwiConfig_set" "', argument " "1"" of type '" "pj::AccountConfig *""'"); 
  }
  arg1 = reinterpret_cast< pj::AccountConfig * >(argp1);
  res2 = SWIG_ConvertPtr(swig_obj[1], &argp2,SWIGTYPE_p_pj__AccountMwiConfig, 0 |  0 );
  if (!SWIG_IsOK(res2)) {
    SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "AccountConfig_mwiConfig_set" "', argument " "2"" of type '" "pj::AccountMwiConfig *""'"); 
  }
  arg2 = reinterpret_cast< pj::AccountMwiConfig * >(argp2);
  if (arg1) (arg1)->mwiConfig = *arg2;
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_AccountConfig_mwiConfig_get(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::AccountConfig *arg1 = (pj::AccountConfig *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  pj::AccountMwiConfig *result = 0 ;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__AccountConfig, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "AccountConfig_mwiConfig_get" "', argument " "1"" of type '" "pj::AccountConfig *""'"); 
  }
  arg1 = reinterpret_cast< pj::AccountConfig * >(argp1);
  result = (pj::AccountMwiConfig *)& ((arg1)->mwiConfig);
  resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(result), SWIGTYPE_p_pj__AccountMwiConfig, 0 |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_AccountConfig_natConfig_set(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::AccountConfig *arg1 = (pj::AccountConfig *) 0 ;
  pj::AccountNatConfig *arg2 = (pj::AccountNatConfig *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  void *argp2 = 0 ;
  int res2 = 0 ;
  PyObject *swig_obj[2] ;
  
  if (!SWIG_Python_UnpackTuple(args, "AccountConfig_natConfig_set", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__AccountConfig, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "AccountConfig_natConfig_set" "', argument " "1"" of type '" "pj::AccountConfig *""'"); 
  }
  arg1 = reinterpret_cast< pj::AccountConfig * >(argp1);
  res2 = SWIG_ConvertPtr(swig_obj[1], &argp2,SWIGTYPE_p_pj__AccountNatConfig, 0 |  0 );
  if (!SWIG_IsOK(res2)) {
    SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "AccountConfig_natConfig_set" "', argument " "2"" of type '" "pj::AccountNatConfig *""'"); 
  }
  arg2 = reinterpret_cast< pj::AccountNatConfig * >(argp2);
  if (arg1) (arg1)->natConfig = *arg2;
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_AccountConfig_natConfig_get(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::AccountConfig *arg1 = (pj::AccountConfig *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  pj::AccountNatConfig *result = 0 ;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__AccountConfig, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "AccountConfig_natConfig_get" "', argument " "1"" of type '" "pj::AccountConfig *""'"); 
  }
  arg1 = reinterpret_cast< pj::AccountConfig * >(argp1);
  result = (pj::AccountNatConfig *)& ((arg1)->natConfig);
  resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(result), SWIGTYPE_p_pj__AccountNatConfig, 0 |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_AccountConfig_mediaConfig_set(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::AccountConfig *arg1 = (pj::AccountConfig *) 0 ;
  pj::AccountMediaConfig *arg2 = (pj::AccountMediaConfig *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  void *argp2 = 0 ;
  int res2 = 0 ;
  PyObject *swig_obj[2] ;
  
  if (!SWIG_Python_UnpackTuple(args, "AccountConfig_mediaConfig_set", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__AccountConfig, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "AccountConfig_mediaConfig_set" "', argument " "1"" of type '" "pj::AccountConfig *""'"); 
  }
  arg1 = reinterpret_cast< pj::AccountConfig * >(argp1);
  res2 = SWIG_ConvertPtr(swig_obj[1], &argp2,SWIGTYPE_p_pj__AccountMediaConfig, 0 |  0 );
  if (!SWIG_IsOK(res2)) {
    SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "AccountConfig_mediaConfig_set" "', argument " "2"" of type '" "pj::AccountMediaConfig *""'"); 
  }
  arg2 = reinterpret_cast< pj::AccountMediaConfig * >(argp2);
  if (arg1) (arg1)->mediaConfig = *arg2;
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_AccountConfig_mediaConfig_get(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::AccountConfig *arg1 = (pj::AccountConfig *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  pj::AccountMediaConfig *result = 0 ;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__AccountConfig, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "AccountConfig_mediaConfig_get" "', argument " "1"" of type '" "pj::AccountConfig *""'"); 
  }
  arg1 = reinterpret_cast< pj::AccountConfig * >(argp1);
  result = (pj::AccountMediaConfig *)& ((arg1)->mediaConfig);
  resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(result), SWIGTYPE_p_pj__AccountMediaConfig, 0 |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_AccountConfig_videoConfig_set(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::AccountConfig *arg1 = (pj::AccountConfig *) 0 ;
  pj::AccountVideoConfig *arg2 = (pj::AccountVideoConfig *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  void *argp2 = 0 ;
  int res2 = 0 ;
  PyObject *swig_obj[2] ;
  
  if (!SWIG_Python_UnpackTuple(args, "AccountConfig_videoConfig_set", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__AccountConfig, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "AccountConfig_videoConfig_set" "', argument " "1"" of type '" "pj::AccountConfig *""'"); 
  }
  arg1 = reinterpret_cast< pj::AccountConfig * >(argp1);
  res2 = SWIG_ConvertPtr(swig_obj[1], &argp2,SWIGTYPE_p_pj__AccountVideoConfig, 0 |  0 );
  if (!SWIG_IsOK(res2)) {
    SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "AccountConfig_videoConfig_set" "', argument " "2"" of type '" "pj::AccountVideoConfig *""'"); 
  }
  arg2 = reinterpret_cast< pj::AccountVideoConfig * >(argp2);
  if (arg1) (arg1)->videoConfig = *arg2;
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_AccountConfig_videoConfig_get(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::AccountConfig *arg1 = (pj::AccountConfig *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  pj::AccountVideoConfig *result = 0 ;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__AccountConfig, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "AccountConfig_videoConfig_get" "', argument " "1"" of type '" "pj::AccountConfig *""'"); 
  }
  arg1 = reinterpret_cast< pj::AccountConfig * >(argp1);
  result = (pj::AccountVideoConfig *)& ((arg1)->videoConfig);
  resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(result), SWIGTYPE_p_pj__AccountVideoConfig, 0 |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_AccountConfig_ipChangeConfig_set(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::AccountConfig *arg1 = (pj::AccountConfig *) 0 ;
  pj::AccountIpChangeConfig *arg2 = (pj::AccountIpChangeConfig *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  void *argp2 = 0 ;
  int res2 = 0 ;
  PyObject *swig_obj[2] ;
  
  if (!SWIG_Python_UnpackTuple(args, "AccountConfig_ipChangeConfig_set", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__AccountConfig, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "AccountConfig_ipChangeConfig_set" "', argument " "1"" of type '" "pj::AccountConfig *""'"); 
  }
  arg1 = reinterpret_cast< pj::AccountConfig * >(argp1);
  res2 = SWIG_ConvertPtr(swig_obj[1], &argp2,SWIGTYPE_p_pj__AccountIpChangeConfig, 0 |  0 );
  if (!SWIG_IsOK(res2)) {
    SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "AccountConfig_ipChangeConfig_set" "', argument " "2"" of type '" "pj::AccountIpChangeConfig *""'"); 
  }
  arg2 = reinterpret_cast< pj::AccountIpChangeConfig * >(argp2);
  if (arg1) (arg1)->ipChangeConfig = *arg2;
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_AccountConfig_ipChangeConfig_get(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::AccountConfig *arg1 = (pj::AccountConfig *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  pj::AccountIpChangeConfig *result = 0 ;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__AccountConfig, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "AccountConfig_ipChangeConfig_get" "', argument " "1"" of type '" "pj::AccountConfig *""'"); 
  }
  arg1 = reinterpret_cast< pj::AccountConfig * >(argp1);
  result = (pj::AccountIpChangeConfig *)& ((arg1)->ipChangeConfig);
  resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(result), SWIGTYPE_p_pj__AccountIpChangeConfig, 0 |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_new_AccountConfig(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::AccountConfig *result = 0 ;
  
  if (!SWIG_Python_UnpackTuple(args, "new_AccountConfig", 0, 0, 0)) SWIG_fail;
  result = (pj::AccountConfig *)new pj::AccountConfig();
  resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(result), SWIGTYPE_p_pj__AccountConfig, SWIG_POINTER_NEW |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_AccountConfig_readObject(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::AccountConfig *arg1 = (pj::AccountConfig *) 0 ;
  pj::ContainerNode *arg2 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  void *argp2 = 0 ;
  int res2 = 0 ;
  PyObject *swig_obj[2] ;
  
  if (!SWIG_Python_UnpackTuple(args, "AccountConfig_readObject", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__AccountConfig, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "AccountConfig_readObject" "', argument " "1"" of type '" "pj::AccountConfig *""'"); 
  }
  arg1 = reinterpret_cast< pj::AccountConfig * >(argp1);
  res2 = SWIG_ConvertPtr(swig_obj[1], &argp2, SWIGTYPE_p_pj__ContainerNode,  0  | 0);
  if (!SWIG_IsOK(res2)) {
    SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "AccountConfig_readObject" "', argument " "2"" of type '" "pj::ContainerNode const &""'"); 
  }
  if (!argp2) {
    SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "AccountConfig_readObject" "', argument " "2"" of type '" "pj::ContainerNode const &""'"); 
  }
  arg2 = reinterpret_cast< pj::ContainerNode * >(argp2);
  try {
    (arg1)->readObject((pj::ContainerNode const &)*arg2);
  } catch(pj::Error &_e) {
    SWIG_Python_Raise(SWIG_NewPointerObj((new pj::Error(static_cast< const pj::Error& >(_e))),SWIGTYPE_p_pj__Error,SWIG_POINTER_OWN), "pj::Error", SWIGTYPE_p_pj__Error); SWIG_fail;
  }
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_AccountConfig_writeObject(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::AccountConfig *arg1 = (pj::AccountConfig *) 0 ;
  pj::ContainerNode *arg2 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  void *argp2 = 0 ;
  int res2 = 0 ;
  PyObject *swig_obj[2] ;
  
  if (!SWIG_Python_UnpackTuple(args, "AccountConfig_writeObject", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__AccountConfig, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "AccountConfig_writeObject" "', argument " "1"" of type '" "pj::AccountConfig const *""'"); 
  }
  arg1 = reinterpret_cast< pj::AccountConfig * >(argp1);
  res2 = SWIG_ConvertPtr(swig_obj[1], &argp2, SWIGTYPE_p_pj__ContainerNode,  0 );
  if (!SWIG_IsOK(res2)) {
    SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "AccountConfig_writeObject" "', argument " "2"" of type '" "pj::ContainerNode &""'"); 
  }
  if (!argp2) {
    SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "AccountConfig_writeObject" "', argument " "2"" of type '" "pj::ContainerNode &""'"); 
  }
  arg2 = reinterpret_cast< pj::ContainerNode * >(argp2);
  try {
    ((pj::AccountConfig const *)arg1)->writeObject(*arg2);
  } catch(pj::Error &_e) {
    SWIG_Python_Raise(SWIG_NewPointerObj((new pj::Error(static_cast< const pj::Error& >(_e))),SWIGTYPE_p_pj__Error,SWIG_POINTER_OWN), "pj::Error", SWIGTYPE_p_pj__Error); SWIG_fail;
  }
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_delete_AccountConfig(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::AccountConfig *arg1 = (pj::AccountConfig *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__AccountConfig, SWIG_POINTER_DISOWN |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "delete_AccountConfig" "', argument " "1"" of type '" "pj::AccountConfig *""'"); 
  }
  arg1 = reinterpret_cast< pj::AccountConfig * >(argp1);
  delete arg1;
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *AccountConfig_swigregister(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *obj;
  if (!SWIG_Python_UnpackTuple(args, "swigregister", 1, 1, &obj)) return NULL;
  SWIG_TypeNewClientData(SWIGTYPE_p_pj__AccountConfig, SWIG_NewClientData(obj));
  return SWIG_Py_Void();
}

SWIGINTERN PyObject *AccountConfig_swiginit(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  return SWIG_Python_InitShadowInstance(args);
}

SWIGINTERN PyObject *_wrap_AccountInfo_id_set(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::AccountInfo *arg1 = (pj::AccountInfo *) 0 ;
  pjsua_acc_id arg2 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  int val2 ;
  int ecode2 = 0 ;
  PyObject *swig_obj[2] ;
  
  if (!SWIG_Python_UnpackTuple(args, "AccountInfo_id_set", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__AccountInfo, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "AccountInfo_id_set" "', argument " "1"" of type '" "pj::AccountInfo *""'"); 
  }
  arg1 = reinterpret_cast< pj::AccountInfo * >(argp1);
  ecode2 = SWIG_AsVal_int(swig_obj[1], &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "AccountInfo_id_set" "', argument " "2"" of type '" "pjsua_acc_id""'");
  } 
  arg2 = static_cast< pjsua_acc_id >(val2);
  if (arg1) (arg1)->id = arg2;
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_AccountInfo_id_get(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::AccountInfo *arg1 = (pj::AccountInfo *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  pjsua_acc_id result;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__AccountInfo, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "AccountInfo_id_get" "', argument " "1"" of type '" "pj::AccountInfo *""'"); 
  }
  arg1 = reinterpret_cast< pj::AccountInfo * >(argp1);
  result = (pjsua_acc_id) ((arg1)->id);
  resultobj = SWIG_From_int(static_cast< int >(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_AccountInfo_isDefault_set(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::AccountInfo *arg1 = (pj::AccountInfo *) 0 ;
  bool arg2 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  bool val2 ;
  int ecode2 = 0 ;
  PyObject *swig_obj[2] ;
  
  if (!SWIG_Python_UnpackTuple(args, "AccountInfo_isDefault_set", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__AccountInfo, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "AccountInfo_isDefault_set" "', argument " "1"" of type '" "pj::AccountInfo *""'"); 
  }
  arg1 = reinterpret_cast< pj::AccountInfo * >(argp1);
  ecode2 = SWIG_AsVal_bool(swig_obj[1], &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "AccountInfo_isDefault_set" "', argument " "2"" of type '" "bool""'");
  } 
  arg2 = static_cast< bool >(val2);
  if (arg1) (arg1)->isDefault = arg2;
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_AccountInfo_isDefault_get(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::AccountInfo *arg1 = (pj::AccountInfo *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  bool result;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__AccountInfo, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "AccountInfo_isDefault_get" "', argument " "1"" of type '" "pj::AccountInfo *""'"); 
  }
  arg1 = reinterpret_cast< pj::AccountInfo * >(argp1);
  result = (bool) ((arg1)->isDefault);
  resultobj = SWIG_From_bool(static_cast< bool >(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_AccountInfo_uri_set(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::AccountInfo *arg1 = (pj::AccountInfo *) 0 ;
  pj::string *arg2 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  int res2 = SWIG_OLDOBJ ;
  PyObject *swig_obj[2] ;
  
  if (!SWIG_Python_UnpackTuple(args, "AccountInfo_uri_set", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__AccountInfo, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "AccountInfo_uri_set" "', argument " "1"" of type '" "pj::AccountInfo *""'"); 
  }
  arg1 = reinterpret_cast< pj::AccountInfo * >(argp1);
  {
    std::string *ptr = (std::string *)0;
    res2 = SWIG_AsPtr_std_string(swig_obj[1], &ptr);
    if (!SWIG_IsOK(res2)) {
      SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "AccountInfo_uri_set" "', argument " "2"" of type '" "pj::string const &""'"); 
    }
    if (!ptr) {
      SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "AccountInfo_uri_set" "', argument " "2"" of type '" "pj::string const &""'"); 
    }
    arg2 = ptr;
  }
  if (arg1) (arg1)->uri = *arg2;
  resultobj = SWIG_Py_Void();
  if (SWIG_IsNewObj(res2)) delete arg2;
  return resultobj;
fail:
  if (SWIG_IsNewObj(res2)) delete arg2;
  return NULL;
}


SWIGINTERN PyObject *_wrap_AccountInfo_uri_get(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::AccountInfo *arg1 = (pj::AccountInfo *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  pj::string *result = 0 ;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__AccountInfo, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "AccountInfo_uri_get" "', argument " "1"" of type '" "pj::AccountInfo *""'"); 
  }
  arg1 = reinterpret_cast< pj::AccountInfo * >(argp1);
  result = (pj::string *) & ((arg1)->uri);
  resultobj = SWIG_From_std_string(static_cast< std::string >(*result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_AccountInfo_regIsConfigured_set(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::AccountInfo *arg1 = (pj::AccountInfo *) 0 ;
  bool arg2 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  bool val2 ;
  int ecode2 = 0 ;
  PyObject *swig_obj[2] ;
  
  if (!SWIG_Python_UnpackTuple(args, "AccountInfo_regIsConfigured_set", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__AccountInfo, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "AccountInfo_regIsConfigured_set" "', argument " "1"" of type '" "pj::AccountInfo *""'"); 
  }
  arg1 = reinterpret_cast< pj::AccountInfo * >(argp1);
  ecode2 = SWIG_AsVal_bool(swig_obj[1], &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "AccountInfo_regIsConfigured_set" "', argument " "2"" of type '" "bool""'");
  } 
  arg2 = static_cast< bool >(val2);
  if (arg1) (arg1)->regIsConfigured = arg2;
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_AccountInfo_regIsConfigured_get(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::AccountInfo *arg1 = (pj::AccountInfo *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  bool result;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__AccountInfo, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "AccountInfo_regIsConfigured_get" "', argument " "1"" of type '" "pj::AccountInfo *""'"); 
  }
  arg1 = reinterpret_cast< pj::AccountInfo * >(argp1);
  result = (bool) ((arg1)->regIsConfigured);
  resultobj = SWIG_From_bool(static_cast< bool >(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_AccountInfo_regIsActive_set(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::AccountInfo *arg1 = (pj::AccountInfo *) 0 ;
  bool arg2 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  bool val2 ;
  int ecode2 = 0 ;
  PyObject *swig_obj[2] ;
  
  if (!SWIG_Python_UnpackTuple(args, "AccountInfo_regIsActive_set", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__AccountInfo, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "AccountInfo_regIsActive_set" "', argument " "1"" of type '" "pj::AccountInfo *""'"); 
  }
  arg1 = reinterpret_cast< pj::AccountInfo * >(argp1);
  ecode2 = SWIG_AsVal_bool(swig_obj[1], &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "AccountInfo_regIsActive_set" "', argument " "2"" of type '" "bool""'");
  } 
  arg2 = static_cast< bool >(val2);
  if (arg1) (arg1)->regIsActive = arg2;
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_AccountInfo_regIsActive_get(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::AccountInfo *arg1 = (pj::AccountInfo *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  bool result;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__AccountInfo, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "AccountInfo_regIsActive_get" "', argument " "1"" of type '" "pj::AccountInfo *""'"); 
  }
  arg1 = reinterpret_cast< pj::AccountInfo * >(argp1);
  result = (bool) ((arg1)->regIsActive);
  resultobj = SWIG_From_bool(static_cast< bool >(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_AccountInfo_regExpiresSec_set(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::AccountInfo *arg1 = (pj::AccountInfo *) 0 ;
  unsigned int arg2 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  unsigned int val2 ;
  int ecode2 = 0 ;
  PyObject *swig_obj[2] ;
  
  if (!SWIG_Python_UnpackTuple(args, "AccountInfo_regExpiresSec_set", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__AccountInfo, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "AccountInfo_regExpiresSec_set" "', argument " "1"" of type '" "pj::AccountInfo *""'"); 
  }
  arg1 = reinterpret_cast< pj::AccountInfo * >(argp1);
  ecode2 = SWIG_AsVal_unsigned_SS_int(swig_obj[1], &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "AccountInfo_regExpiresSec_set" "', argument " "2"" of type '" "unsigned int""'");
  } 
  arg2 = static_cast< unsigned int >(val2);
  if (arg1) (arg1)->regExpiresSec = arg2;
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_AccountInfo_regExpiresSec_get(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::AccountInfo *arg1 = (pj::AccountInfo *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  unsigned int result;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__AccountInfo, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "AccountInfo_regExpiresSec_get" "', argument " "1"" of type '" "pj::AccountInfo *""'"); 
  }
  arg1 = reinterpret_cast< pj::AccountInfo * >(argp1);
  result = (unsigned int) ((arg1)->regExpiresSec);
  resultobj = SWIG_From_unsigned_SS_int(static_cast< unsigned int >(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_AccountInfo_regStatus_set(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::AccountInfo *arg1 = (pj::AccountInfo *) 0 ;
  pjsip_status_code arg2 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  int val2 ;
  int ecode2 = 0 ;
  PyObject *swig_obj[2] ;
  
  if (!SWIG_Python_UnpackTuple(args, "AccountInfo_regStatus_set", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__AccountInfo, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "AccountInfo_regStatus_set" "', argument " "1"" of type '" "pj::AccountInfo *""'"); 
  }
  arg1 = reinterpret_cast< pj::AccountInfo * >(argp1);
  ecode2 = SWIG_AsVal_int(swig_obj[1], &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "AccountInfo_regStatus_set" "', argument " "2"" of type '" "pjsip_status_code""'");
  } 
  arg2 = static_cast< pjsip_status_code >(val2);
  if (arg1) (arg1)->regStatus = arg2;
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_AccountInfo_regStatus_get(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::AccountInfo *arg1 = (pj::AccountInfo *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  pjsip_status_code result;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__AccountInfo, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "AccountInfo_regStatus_get" "', argument " "1"" of type '" "pj::AccountInfo *""'"); 
  }
  arg1 = reinterpret_cast< pj::AccountInfo * >(argp1);
  result = (pjsip_status_code) ((arg1)->regStatus);
  resultobj = SWIG_From_int(static_cast< int >(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_AccountInfo_regStatusText_set(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::AccountInfo *arg1 = (pj::AccountInfo *) 0 ;
  pj::string *arg2 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  int res2 = SWIG_OLDOBJ ;
  PyObject *swig_obj[2] ;
  
  if (!SWIG_Python_UnpackTuple(args, "AccountInfo_regStatusText_set", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__AccountInfo, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "AccountInfo_regStatusText_set" "', argument " "1"" of type '" "pj::AccountInfo *""'"); 
  }
  arg1 = reinterpret_cast< pj::AccountInfo * >(argp1);
  {
    std::string *ptr = (std::string *)0;
    res2 = SWIG_AsPtr_std_string(swig_obj[1], &ptr);
    if (!SWIG_IsOK(res2)) {
      SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "AccountInfo_regStatusText_set" "', argument " "2"" of type '" "pj::string const &""'"); 
    }
    if (!ptr) {
      SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "AccountInfo_regStatusText_set" "', argument " "2"" of type '" "pj::string const &""'"); 
    }
    arg2 = ptr;
  }
  if (arg1) (arg1)->regStatusText = *arg2;
  resultobj = SWIG_Py_Void();
  if (SWIG_IsNewObj(res2)) delete arg2;
  return resultobj;
fail:
  if (SWIG_IsNewObj(res2)) delete arg2;
  return NULL;
}


SWIGINTERN PyObject *_wrap_AccountInfo_regStatusText_get(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::AccountInfo *arg1 = (pj::AccountInfo *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  pj::string *result = 0 ;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__AccountInfo, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "AccountInfo_regStatusText_get" "', argument " "1"" of type '" "pj::AccountInfo *""'"); 
  }
  arg1 = reinterpret_cast< pj::AccountInfo * >(argp1);
  result = (pj::string *) & ((arg1)->regStatusText);
  resultobj = SWIG_From_std_string(static_cast< std::string >(*result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_AccountInfo_regLastErr_set(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::AccountInfo *arg1 = (pj::AccountInfo *) 0 ;
  pj_status_t arg2 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  int val2 ;
  int ecode2 = 0 ;
  PyObject *swig_obj[2] ;
  
  if (!SWIG_Python_UnpackTuple(args, "AccountInfo_regLastErr_set", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__AccountInfo, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "AccountInfo_regLastErr_set" "', argument " "1"" of type '" "pj::AccountInfo *""'"); 
  }
  arg1 = reinterpret_cast< pj::AccountInfo * >(argp1);
  ecode2 = SWIG_AsVal_int(swig_obj[1], &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "AccountInfo_regLastErr_set" "', argument " "2"" of type '" "pj_status_t""'");
  } 
  arg2 = static_cast< pj_status_t >(val2);
  if (arg1) (arg1)->regLastErr = arg2;
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_AccountInfo_regLastErr_get(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::AccountInfo *arg1 = (pj::AccountInfo *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  pj_status_t result;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__AccountInfo, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "AccountInfo_regLastErr_get" "', argument " "1"" of type '" "pj::AccountInfo *""'"); 
  }
  arg1 = reinterpret_cast< pj::AccountInfo * >(argp1);
  result = (pj_status_t) ((arg1)->regLastErr);
  resultobj = SWIG_From_int(static_cast< int >(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_AccountInfo_onlineStatus_set(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::AccountInfo *arg1 = (pj::AccountInfo *) 0 ;
  bool arg2 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  bool val2 ;
  int ecode2 = 0 ;
  PyObject *swig_obj[2] ;
  
  if (!SWIG_Python_UnpackTuple(args, "AccountInfo_onlineStatus_set", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__AccountInfo, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "AccountInfo_onlineStatus_set" "', argument " "1"" of type '" "pj::AccountInfo *""'"); 
  }
  arg1 = reinterpret_cast< pj::AccountInfo * >(argp1);
  ecode2 = SWIG_AsVal_bool(swig_obj[1], &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "AccountInfo_onlineStatus_set" "', argument " "2"" of type '" "bool""'");
  } 
  arg2 = static_cast< bool >(val2);
  if (arg1) (arg1)->onlineStatus = arg2;
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_AccountInfo_onlineStatus_get(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::AccountInfo *arg1 = (pj::AccountInfo *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  bool result;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__AccountInfo, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "AccountInfo_onlineStatus_get" "', argument " "1"" of type '" "pj::AccountInfo *""'"); 
  }
  arg1 = reinterpret_cast< pj::AccountInfo * >(argp1);
  result = (bool) ((arg1)->onlineStatus);
  resultobj = SWIG_From_bool(static_cast< bool >(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_AccountInfo_onlineStatusText_set(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::AccountInfo *arg1 = (pj::AccountInfo *) 0 ;
  pj::string *arg2 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  int res2 = SWIG_OLDOBJ ;
  PyObject *swig_obj[2] ;
  
  if (!SWIG_Python_UnpackTuple(args, "AccountInfo_onlineStatusText_set", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__AccountInfo, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "AccountInfo_onlineStatusText_set" "', argument " "1"" of type '" "pj::AccountInfo *""'"); 
  }
  arg1 = reinterpret_cast< pj::AccountInfo * >(argp1);
  {
    std::string *ptr = (std::string *)0;
    res2 = SWIG_AsPtr_std_string(swig_obj[1], &ptr);
    if (!SWIG_IsOK(res2)) {
      SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "AccountInfo_onlineStatusText_set" "', argument " "2"" of type '" "pj::string const &""'"); 
    }
    if (!ptr) {
      SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "AccountInfo_onlineStatusText_set" "', argument " "2"" of type '" "pj::string const &""'"); 
    }
    arg2 = ptr;
  }
  if (arg1) (arg1)->onlineStatusText = *arg2;
  resultobj = SWIG_Py_Void();
  if (SWIG_IsNewObj(res2)) delete arg2;
  return resultobj;
fail:
  if (SWIG_IsNewObj(res2)) delete arg2;
  return NULL;
}


SWIGINTERN PyObject *_wrap_AccountInfo_onlineStatusText_get(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::AccountInfo *arg1 = (pj::AccountInfo *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  pj::string *result = 0 ;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__AccountInfo, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "AccountInfo_onlineStatusText_get" "', argument " "1"" of type '" "pj::AccountInfo *""'"); 
  }
  arg1 = reinterpret_cast< pj::AccountInfo * >(argp1);
  result = (pj::string *) & ((arg1)->onlineStatusText);
  resultobj = SWIG_From_std_string(static_cast< std::string >(*result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_new_AccountInfo(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::AccountInfo *result = 0 ;
  
  if (!SWIG_Python_UnpackTuple(args, "new_AccountInfo", 0, 0, 0)) SWIG_fail;
  result = (pj::AccountInfo *)new pj::AccountInfo();
  resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(result), SWIGTYPE_p_pj__AccountInfo, SWIG_POINTER_NEW |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_delete_AccountInfo(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::AccountInfo *arg1 = (pj::AccountInfo *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__AccountInfo, SWIG_POINTER_DISOWN |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "delete_AccountInfo" "', argument " "1"" of type '" "pj::AccountInfo *""'"); 
  }
  arg1 = reinterpret_cast< pj::AccountInfo * >(argp1);
  delete arg1;
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *AccountInfo_swigregister(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *obj;
  if (!SWIG_Python_UnpackTuple(args, "swigregister", 1, 1, &obj)) return NULL;
  SWIG_TypeNewClientData(SWIGTYPE_p_pj__AccountInfo, SWIG_NewClientData(obj));
  return SWIG_Py_Void();
}

SWIGINTERN PyObject *AccountInfo_swiginit(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  return SWIG_Python_InitShadowInstance(args);
}

SWIGINTERN PyObject *_wrap_OnIncomingCallParam_callId_set(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::OnIncomingCallParam *arg1 = (pj::OnIncomingCallParam *) 0 ;
  int arg2 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  int val2 ;
  int ecode2 = 0 ;
  PyObject *swig_obj[2] ;
  
  if (!SWIG_Python_UnpackTuple(args, "OnIncomingCallParam_callId_set", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__OnIncomingCallParam, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "OnIncomingCallParam_callId_set" "', argument " "1"" of type '" "pj::OnIncomingCallParam *""'"); 
  }
  arg1 = reinterpret_cast< pj::OnIncomingCallParam * >(argp1);
  ecode2 = SWIG_AsVal_int(swig_obj[1], &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "OnIncomingCallParam_callId_set" "', argument " "2"" of type '" "int""'");
  } 
  arg2 = static_cast< int >(val2);
  if (arg1) (arg1)->callId = arg2;
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_OnIncomingCallParam_callId_get(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::OnIncomingCallParam *arg1 = (pj::OnIncomingCallParam *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  int result;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__OnIncomingCallParam, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "OnIncomingCallParam_callId_get" "', argument " "1"" of type '" "pj::OnIncomingCallParam *""'"); 
  }
  arg1 = reinterpret_cast< pj::OnIncomingCallParam * >(argp1);
  result = (int) ((arg1)->callId);
  resultobj = SWIG_From_int(static_cast< int >(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_OnIncomingCallParam_rdata_set(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::OnIncomingCallParam *arg1 = (pj::OnIncomingCallParam *) 0 ;
  pj::SipRxData *arg2 = (pj::SipRxData *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  void *argp2 = 0 ;
  int res2 = 0 ;
  PyObject *swig_obj[2] ;
  
  if (!SWIG_Python_UnpackTuple(args, "OnIncomingCallParam_rdata_set", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__OnIncomingCallParam, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "OnIncomingCallParam_rdata_set" "', argument " "1"" of type '" "pj::OnIncomingCallParam *""'"); 
  }
  arg1 = reinterpret_cast< pj::OnIncomingCallParam * >(argp1);
  res2 = SWIG_ConvertPtr(swig_obj[1], &argp2,SWIGTYPE_p_pj__SipRxData, 0 |  0 );
  if (!SWIG_IsOK(res2)) {
    SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "OnIncomingCallParam_rdata_set" "', argument " "2"" of type '" "pj::SipRxData *""'"); 
  }
  arg2 = reinterpret_cast< pj::SipRxData * >(argp2);
  if (arg1) (arg1)->rdata = *arg2;
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_OnIncomingCallParam_rdata_get(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::OnIncomingCallParam *arg1 = (pj::OnIncomingCallParam *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  pj::SipRxData *result = 0 ;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__OnIncomingCallParam, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "OnIncomingCallParam_rdata_get" "', argument " "1"" of type '" "pj::OnIncomingCallParam *""'"); 
  }
  arg1 = reinterpret_cast< pj::OnIncomingCallParam * >(argp1);
  result = (pj::SipRxData *)& ((arg1)->rdata);
  resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(result), SWIGTYPE_p_pj__SipRxData, 0 |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_new_OnIncomingCallParam(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::OnIncomingCallParam *result = 0 ;
  
  if (!SWIG_Python_UnpackTuple(args, "new_OnIncomingCallParam", 0, 0, 0)) SWIG_fail;
  result = (pj::OnIncomingCallParam *)new pj::OnIncomingCallParam();
  resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(result), SWIGTYPE_p_pj__OnIncomingCallParam, SWIG_POINTER_NEW |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_delete_OnIncomingCallParam(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::OnIncomingCallParam *arg1 = (pj::OnIncomingCallParam *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__OnIncomingCallParam, SWIG_POINTER_DISOWN |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "delete_OnIncomingCallParam" "', argument " "1"" of type '" "pj::OnIncomingCallParam *""'"); 
  }
  arg1 = reinterpret_cast< pj::OnIncomingCallParam * >(argp1);
  delete arg1;
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *OnIncomingCallParam_swigregister(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *obj;
  if (!SWIG_Python_UnpackTuple(args, "swigregister", 1, 1, &obj)) return NULL;
  SWIG_TypeNewClientData(SWIGTYPE_p_pj__OnIncomingCallParam, SWIG_NewClientData(obj));
  return SWIG_Py_Void();
}

SWIGINTERN PyObject *OnIncomingCallParam_swiginit(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  return SWIG_Python_InitShadowInstance(args);
}

SWIGINTERN PyObject *_wrap_OnRegStartedParam_renew_set(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::OnRegStartedParam *arg1 = (pj::OnRegStartedParam *) 0 ;
  bool arg2 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  bool val2 ;
  int ecode2 = 0 ;
  PyObject *swig_obj[2] ;
  
  if (!SWIG_Python_UnpackTuple(args, "OnRegStartedParam_renew_set", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__OnRegStartedParam, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "OnRegStartedParam_renew_set" "', argument " "1"" of type '" "pj::OnRegStartedParam *""'"); 
  }
  arg1 = reinterpret_cast< pj::OnRegStartedParam * >(argp1);
  ecode2 = SWIG_AsVal_bool(swig_obj[1], &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "OnRegStartedParam_renew_set" "', argument " "2"" of type '" "bool""'");
  } 
  arg2 = static_cast< bool >(val2);
  if (arg1) (arg1)->renew = arg2;
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_OnRegStartedParam_renew_get(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::OnRegStartedParam *arg1 = (pj::OnRegStartedParam *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  bool result;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__OnRegStartedParam, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "OnRegStartedParam_renew_get" "', argument " "1"" of type '" "pj::OnRegStartedParam *""'"); 
  }
  arg1 = reinterpret_cast< pj::OnRegStartedParam * >(argp1);
  result = (bool) ((arg1)->renew);
  resultobj = SWIG_From_bool(static_cast< bool >(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_new_OnRegStartedParam(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::OnRegStartedParam *result = 0 ;
  
  if (!SWIG_Python_UnpackTuple(args, "new_OnRegStartedParam", 0, 0, 0)) SWIG_fail;
  result = (pj::OnRegStartedParam *)new pj::OnRegStartedParam();
  resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(result), SWIGTYPE_p_pj__OnRegStartedParam, SWIG_POINTER_NEW |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_delete_OnRegStartedParam(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::OnRegStartedParam *arg1 = (pj::OnRegStartedParam *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__OnRegStartedParam, SWIG_POINTER_DISOWN |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "delete_OnRegStartedParam" "', argument " "1"" of type '" "pj::OnRegStartedParam *""'"); 
  }
  arg1 = reinterpret_cast< pj::OnRegStartedParam * >(argp1);
  delete arg1;
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *OnRegStartedParam_swigregister(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *obj;
  if (!SWIG_Python_UnpackTuple(args, "swigregister", 1, 1, &obj)) return NULL;
  SWIG_TypeNewClientData(SWIGTYPE_p_pj__OnRegStartedParam, SWIG_NewClientData(obj));
  return SWIG_Py_Void();
}

SWIGINTERN PyObject *OnRegStartedParam_swiginit(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  return SWIG_Python_InitShadowInstance(args);
}

SWIGINTERN PyObject *_wrap_OnRegStateParam_status_set(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::OnRegStateParam *arg1 = (pj::OnRegStateParam *) 0 ;
  pj_status_t arg2 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  int val2 ;
  int ecode2 = 0 ;
  PyObject *swig_obj[2] ;
  
  if (!SWIG_Python_UnpackTuple(args, "OnRegStateParam_status_set", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__OnRegStateParam, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "OnRegStateParam_status_set" "', argument " "1"" of type '" "pj::OnRegStateParam *""'"); 
  }
  arg1 = reinterpret_cast< pj::OnRegStateParam * >(argp1);
  ecode2 = SWIG_AsVal_int(swig_obj[1], &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "OnRegStateParam_status_set" "', argument " "2"" of type '" "pj_status_t""'");
  } 
  arg2 = static_cast< pj_status_t >(val2);
  if (arg1) (arg1)->status = arg2;
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_OnRegStateParam_status_get(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::OnRegStateParam *arg1 = (pj::OnRegStateParam *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  pj_status_t result;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__OnRegStateParam, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "OnRegStateParam_status_get" "', argument " "1"" of type '" "pj::OnRegStateParam *""'"); 
  }
  arg1 = reinterpret_cast< pj::OnRegStateParam * >(argp1);
  result = (pj_status_t) ((arg1)->status);
  resultobj = SWIG_From_int(static_cast< int >(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_OnRegStateParam_code_set(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::OnRegStateParam *arg1 = (pj::OnRegStateParam *) 0 ;
  pjsip_status_code arg2 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  int val2 ;
  int ecode2 = 0 ;
  PyObject *swig_obj[2] ;
  
  if (!SWIG_Python_UnpackTuple(args, "OnRegStateParam_code_set", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__OnRegStateParam, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "OnRegStateParam_code_set" "', argument " "1"" of type '" "pj::OnRegStateParam *""'"); 
  }
  arg1 = reinterpret_cast< pj::OnRegStateParam * >(argp1);
  ecode2 = SWIG_AsVal_int(swig_obj[1], &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "OnRegStateParam_code_set" "', argument " "2"" of type '" "pjsip_status_code""'");
  } 
  arg2 = static_cast< pjsip_status_code >(val2);
  if (arg1) (arg1)->code = arg2;
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_OnRegStateParam_code_get(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::OnRegStateParam *arg1 = (pj::OnRegStateParam *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  pjsip_status_code result;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__OnRegStateParam, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "OnRegStateParam_code_get" "', argument " "1"" of type '" "pj::OnRegStateParam *""'"); 
  }
  arg1 = reinterpret_cast< pj::OnRegStateParam * >(argp1);
  result = (pjsip_status_code) ((arg1)->code);
  resultobj = SWIG_From_int(static_cast< int >(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_OnRegStateParam_reason_set(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::OnRegStateParam *arg1 = (pj::OnRegStateParam *) 0 ;
  pj::string *arg2 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  int res2 = SWIG_OLDOBJ ;
  PyObject *swig_obj[2] ;
  
  if (!SWIG_Python_UnpackTuple(args, "OnRegStateParam_reason_set", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__OnRegStateParam, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "OnRegStateParam_reason_set" "', argument " "1"" of type '" "pj::OnRegStateParam *""'"); 
  }
  arg1 = reinterpret_cast< pj::OnRegStateParam * >(argp1);
  {
    std::string *ptr = (std::string *)0;
    res2 = SWIG_AsPtr_std_string(swig_obj[1], &ptr);
    if (!SWIG_IsOK(res2)) {
      SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "OnRegStateParam_reason_set" "', argument " "2"" of type '" "pj::string const &""'"); 
    }
    if (!ptr) {
      SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "OnRegStateParam_reason_set" "', argument " "2"" of type '" "pj::string const &""'"); 
    }
    arg2 = ptr;
  }
  if (arg1) (arg1)->reason = *arg2;
  resultobj = SWIG_Py_Void();
  if (SWIG_IsNewObj(res2)) delete arg2;
  return resultobj;
fail:
  if (SWIG_IsNewObj(res2)) delete arg2;
  return NULL;
}


SWIGINTERN PyObject *_wrap_OnRegStateParam_reason_get(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::OnRegStateParam *arg1 = (pj::OnRegStateParam *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  pj::string *result = 0 ;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__OnRegStateParam, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "OnRegStateParam_reason_get" "', argument " "1"" of type '" "pj::OnRegStateParam *""'"); 
  }
  arg1 = reinterpret_cast< pj::OnRegStateParam * >(argp1);
  result = (pj::string *) & ((arg1)->reason);
  resultobj = SWIG_From_std_string(static_cast< std::string >(*result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_OnRegStateParam_rdata_set(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::OnRegStateParam *arg1 = (pj::OnRegStateParam *) 0 ;
  pj::SipRxData *arg2 = (pj::SipRxData *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  void *argp2 = 0 ;
  int res2 = 0 ;
  PyObject *swig_obj[2] ;
  
  if (!SWIG_Python_UnpackTuple(args, "OnRegStateParam_rdata_set", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__OnRegStateParam, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "OnRegStateParam_rdata_set" "', argument " "1"" of type '" "pj::OnRegStateParam *""'"); 
  }
  arg1 = reinterpret_cast< pj::OnRegStateParam * >(argp1);
  res2 = SWIG_ConvertPtr(swig_obj[1], &argp2,SWIGTYPE_p_pj__SipRxData, 0 |  0 );
  if (!SWIG_IsOK(res2)) {
    SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "OnRegStateParam_rdata_set" "', argument " "2"" of type '" "pj::SipRxData *""'"); 
  }
  arg2 = reinterpret_cast< pj::SipRxData * >(argp2);
  if (arg1) (arg1)->rdata = *arg2;
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_OnRegStateParam_rdata_get(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::OnRegStateParam *arg1 = (pj::OnRegStateParam *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  pj::SipRxData *result = 0 ;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__OnRegStateParam, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "OnRegStateParam_rdata_get" "', argument " "1"" of type '" "pj::OnRegStateParam *""'"); 
  }
  arg1 = reinterpret_cast< pj::OnRegStateParam * >(argp1);
  result = (pj::SipRxData *)& ((arg1)->rdata);
  resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(result), SWIGTYPE_p_pj__SipRxData, 0 |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_OnRegStateParam_expiration_set(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::OnRegStateParam *arg1 = (pj::OnRegStateParam *) 0 ;
  unsigned int arg2 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  unsigned int val2 ;
  int ecode2 = 0 ;
  PyObject *swig_obj[2] ;
  
  if (!SWIG_Python_UnpackTuple(args, "OnRegStateParam_expiration_set", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__OnRegStateParam, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "OnRegStateParam_expiration_set" "', argument " "1"" of type '" "pj::OnRegStateParam *""'"); 
  }
  arg1 = reinterpret_cast< pj::OnRegStateParam * >(argp1);
  ecode2 = SWIG_AsVal_unsigned_SS_int(swig_obj[1], &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "OnRegStateParam_expiration_set" "', argument " "2"" of type '" "unsigned int""'");
  } 
  arg2 = static_cast< unsigned int >(val2);
  if (arg1) (arg1)->expiration = arg2;
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_OnRegStateParam_expiration_get(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::OnRegStateParam *arg1 = (pj::OnRegStateParam *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  unsigned int result;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__OnRegStateParam, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "OnRegStateParam_expiration_get" "', argument " "1"" of type '" "pj::OnRegStateParam *""'"); 
  }
  arg1 = reinterpret_cast< pj::OnRegStateParam * >(argp1);
  result = (unsigned int) ((arg1)->expiration);
  resultobj = SWIG_From_unsigned_SS_int(static_cast< unsigned int >(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_new_OnRegStateParam(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::OnRegStateParam *result = 0 ;
  
  if (!SWIG_Python_UnpackTuple(args, "new_OnRegStateParam", 0, 0, 0)) SWIG_fail;
  result = (pj::OnRegStateParam *)new pj::OnRegStateParam();
  resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(result), SWIGTYPE_p_pj__OnRegStateParam, SWIG_POINTER_NEW |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_delete_OnRegStateParam(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::OnRegStateParam *arg1 = (pj::OnRegStateParam *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__OnRegStateParam, SWIG_POINTER_DISOWN |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "delete_OnRegStateParam" "', argument " "1"" of type '" "pj::OnRegStateParam *""'"); 
  }
  arg1 = reinterpret_cast< pj::OnRegStateParam * >(argp1);
  delete arg1;
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *OnRegStateParam_swigregister(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *obj;
  if (!SWIG_Python_UnpackTuple(args, "swigregister", 1, 1, &obj)) return NULL;
  SWIG_TypeNewClientData(SWIGTYPE_p_pj__OnRegStateParam, SWIG_NewClientData(obj));
  return SWIG_Py_Void();
}

SWIGINTERN PyObject *OnRegStateParam_swiginit(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  return SWIG_Python_InitShadowInstance(args);
}

SWIGINTERN PyObject *_wrap_OnIncomingSubscribeParam_srvPres_set(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::OnIncomingSubscribeParam *arg1 = (pj::OnIncomingSubscribeParam *) 0 ;
  void *arg2 = (void *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  int res2 ;
  PyObject *swig_obj[2] ;
  
  if (!SWIG_Python_UnpackTuple(args, "OnIncomingSubscribeParam_srvPres_set", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__OnIncomingSubscribeParam, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "OnIncomingSubscribeParam_srvPres_set" "', argument " "1"" of type '" "pj::OnIncomingSubscribeParam *""'"); 
  }
  arg1 = reinterpret_cast< pj::OnIncomingSubscribeParam * >(argp1);
  res2 = SWIG_ConvertPtr(swig_obj[1],SWIG_as_voidptrptr(&arg2), 0, SWIG_POINTER_DISOWN);
  if (!SWIG_IsOK(res2)) {
    SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "OnIncomingSubscribeParam_srvPres_set" "', argument " "2"" of type '" "void *""'"); 
  }
  if (arg1) (arg1)->srvPres = arg2;
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_OnIncomingSubscribeParam_srvPres_get(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::OnIncomingSubscribeParam *arg1 = (pj::OnIncomingSubscribeParam *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  void *result = 0 ;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__OnIncomingSubscribeParam, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "OnIncomingSubscribeParam_srvPres_get" "', argument " "1"" of type '" "pj::OnIncomingSubscribeParam *""'"); 
  }
  arg1 = reinterpret_cast< pj::OnIncomingSubscribeParam * >(argp1);
  result = (void *) ((arg1)->srvPres);
  resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(result), SWIGTYPE_p_void, 0 |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_OnIncomingSubscribeParam_fromUri_set(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::OnIncomingSubscribeParam *arg1 = (pj::OnIncomingSubscribeParam *) 0 ;
  pj::string *arg2 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  int res2 = SWIG_OLDOBJ ;
  PyObject *swig_obj[2] ;
  
  if (!SWIG_Python_UnpackTuple(args, "OnIncomingSubscribeParam_fromUri_set", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__OnIncomingSubscribeParam, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "OnIncomingSubscribeParam_fromUri_set" "', argument " "1"" of type '" "pj::OnIncomingSubscribeParam *""'"); 
  }
  arg1 = reinterpret_cast< pj::OnIncomingSubscribeParam * >(argp1);
  {
    std::string *ptr = (std::string *)0;
    res2 = SWIG_AsPtr_std_string(swig_obj[1], &ptr);
    if (!SWIG_IsOK(res2)) {
      SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "OnIncomingSubscribeParam_fromUri_set" "', argument " "2"" of type '" "pj::string const &""'"); 
    }
    if (!ptr) {
      SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "OnIncomingSubscribeParam_fromUri_set" "', argument " "2"" of type '" "pj::string const &""'"); 
    }
    arg2 = ptr;
  }
  if (arg1) (arg1)->fromUri = *arg2;
  resultobj = SWIG_Py_Void();
  if (SWIG_IsNewObj(res2)) delete arg2;
  return resultobj;
fail:
  if (SWIG_IsNewObj(res2)) delete arg2;
  return NULL;
}


SWIGINTERN PyObject *_wrap_OnIncomingSubscribeParam_fromUri_get(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::OnIncomingSubscribeParam *arg1 = (pj::OnIncomingSubscribeParam *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  pj::string *result = 0 ;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__OnIncomingSubscribeParam, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "OnIncomingSubscribeParam_fromUri_get" "', argument " "1"" of type '" "pj::OnIncomingSubscribeParam *""'"); 
  }
  arg1 = reinterpret_cast< pj::OnIncomingSubscribeParam * >(argp1);
  result = (pj::string *) & ((arg1)->fromUri);
  resultobj = SWIG_From_std_string(static_cast< std::string >(*result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_OnIncomingSubscribeParam_rdata_set(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::OnIncomingSubscribeParam *arg1 = (pj::OnIncomingSubscribeParam *) 0 ;
  pj::SipRxData *arg2 = (pj::SipRxData *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  void *argp2 = 0 ;
  int res2 = 0 ;
  PyObject *swig_obj[2] ;
  
  if (!SWIG_Python_UnpackTuple(args, "OnIncomingSubscribeParam_rdata_set", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__OnIncomingSubscribeParam, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "OnIncomingSubscribeParam_rdata_set" "', argument " "1"" of type '" "pj::OnIncomingSubscribeParam *""'"); 
  }
  arg1 = reinterpret_cast< pj::OnIncomingSubscribeParam * >(argp1);
  res2 = SWIG_ConvertPtr(swig_obj[1], &argp2,SWIGTYPE_p_pj__SipRxData, 0 |  0 );
  if (!SWIG_IsOK(res2)) {
    SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "OnIncomingSubscribeParam_rdata_set" "', argument " "2"" of type '" "pj::SipRxData *""'"); 
  }
  arg2 = reinterpret_cast< pj::SipRxData * >(argp2);
  if (arg1) (arg1)->rdata = *arg2;
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_OnIncomingSubscribeParam_rdata_get(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::OnIncomingSubscribeParam *arg1 = (pj::OnIncomingSubscribeParam *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  pj::SipRxData *result = 0 ;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__OnIncomingSubscribeParam, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "OnIncomingSubscribeParam_rdata_get" "', argument " "1"" of type '" "pj::OnIncomingSubscribeParam *""'"); 
  }
  arg1 = reinterpret_cast< pj::OnIncomingSubscribeParam * >(argp1);
  result = (pj::SipRxData *)& ((arg1)->rdata);
  resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(result), SWIGTYPE_p_pj__SipRxData, 0 |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_OnIncomingSubscribeParam_code_set(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::OnIncomingSubscribeParam *arg1 = (pj::OnIncomingSubscribeParam *) 0 ;
  pjsip_status_code arg2 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  int val2 ;
  int ecode2 = 0 ;
  PyObject *swig_obj[2] ;
  
  if (!SWIG_Python_UnpackTuple(args, "OnIncomingSubscribeParam_code_set", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__OnIncomingSubscribeParam, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "OnIncomingSubscribeParam_code_set" "', argument " "1"" of type '" "pj::OnIncomingSubscribeParam *""'"); 
  }
  arg1 = reinterpret_cast< pj::OnIncomingSubscribeParam * >(argp1);
  ecode2 = SWIG_AsVal_int(swig_obj[1], &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "OnIncomingSubscribeParam_code_set" "', argument " "2"" of type '" "pjsip_status_code""'");
  } 
  arg2 = static_cast< pjsip_status_code >(val2);
  if (arg1) (arg1)->code = arg2;
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_OnIncomingSubscribeParam_code_get(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::OnIncomingSubscribeParam *arg1 = (pj::OnIncomingSubscribeParam *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  pjsip_status_code result;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__OnIncomingSubscribeParam, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "OnIncomingSubscribeParam_code_get" "', argument " "1"" of type '" "pj::OnIncomingSubscribeParam *""'"); 
  }
  arg1 = reinterpret_cast< pj::OnIncomingSubscribeParam * >(argp1);
  result = (pjsip_status_code) ((arg1)->code);
  resultobj = SWIG_From_int(static_cast< int >(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_OnIncomingSubscribeParam_reason_set(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::OnIncomingSubscribeParam *arg1 = (pj::OnIncomingSubscribeParam *) 0 ;
  pj::string *arg2 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  int res2 = SWIG_OLDOBJ ;
  PyObject *swig_obj[2] ;
  
  if (!SWIG_Python_UnpackTuple(args, "OnIncomingSubscribeParam_reason_set", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__OnIncomingSubscribeParam, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "OnIncomingSubscribeParam_reason_set" "', argument " "1"" of type '" "pj::OnIncomingSubscribeParam *""'"); 
  }
  arg1 = reinterpret_cast< pj::OnIncomingSubscribeParam * >(argp1);
  {
    std::string *ptr = (std::string *)0;
    res2 = SWIG_AsPtr_std_string(swig_obj[1], &ptr);
    if (!SWIG_IsOK(res2)) {
      SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "OnIncomingSubscribeParam_reason_set" "', argument " "2"" of type '" "pj::string const &""'"); 
    }
    if (!ptr) {
      SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "OnIncomingSubscribeParam_reason_set" "', argument " "2"" of type '" "pj::string const &""'"); 
    }
    arg2 = ptr;
  }
  if (arg1) (arg1)->reason = *arg2;
  resultobj = SWIG_Py_Void();
  if (SWIG_IsNewObj(res2)) delete arg2;
  return resultobj;
fail:
  if (SWIG_IsNewObj(res2)) delete arg2;
  return NULL;
}


SWIGINTERN PyObject *_wrap_OnIncomingSubscribeParam_reason_get(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::OnIncomingSubscribeParam *arg1 = (pj::OnIncomingSubscribeParam *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  pj::string *result = 0 ;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__OnIncomingSubscribeParam, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "OnIncomingSubscribeParam_reason_get" "', argument " "1"" of type '" "pj::OnIncomingSubscribeParam *""'"); 
  }
  arg1 = reinterpret_cast< pj::OnIncomingSubscribeParam * >(argp1);
  result = (pj::string *) & ((arg1)->reason);
  resultobj = SWIG_From_std_string(static_cast< std::string >(*result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_OnIncomingSubscribeParam_txOption_set(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::OnIncomingSubscribeParam *arg1 = (pj::OnIncomingSubscribeParam *) 0 ;
  pj::SipTxOption *arg2 = (pj::SipTxOption *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  void *argp2 = 0 ;
  int res2 = 0 ;
  PyObject *swig_obj[2] ;
  
  if (!SWIG_Python_UnpackTuple(args, "OnIncomingSubscribeParam_txOption_set", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__OnIncomingSubscribeParam, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "OnIncomingSubscribeParam_txOption_set" "', argument " "1"" of type '" "pj::OnIncomingSubscribeParam *""'"); 
  }
  arg1 = reinterpret_cast< pj::OnIncomingSubscribeParam * >(argp1);
  res2 = SWIG_ConvertPtr(swig_obj[1], &argp2,SWIGTYPE_p_pj__SipTxOption, 0 |  0 );
  if (!SWIG_IsOK(res2)) {
    SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "OnIncomingSubscribeParam_txOption_set" "', argument " "2"" of type '" "pj::SipTxOption *""'"); 
  }
  arg2 = reinterpret_cast< pj::SipTxOption * >(argp2);
  if (arg1) (arg1)->txOption = *arg2;
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_OnIncomingSubscribeParam_txOption_get(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::OnIncomingSubscribeParam *arg1 = (pj::OnIncomingSubscribeParam *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  pj::SipTxOption *result = 0 ;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__OnIncomingSubscribeParam, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "OnIncomingSubscribeParam_txOption_get" "', argument " "1"" of type '" "pj::OnIncomingSubscribeParam *""'"); 
  }
  arg1 = reinterpret_cast< pj::OnIncomingSubscribeParam * >(argp1);
  result = (pj::SipTxOption *)& ((arg1)->txOption);
  resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(result), SWIGTYPE_p_pj__SipTxOption, 0 |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_new_OnIncomingSubscribeParam(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::OnIncomingSubscribeParam *result = 0 ;
  
  if (!SWIG_Python_UnpackTuple(args, "new_OnIncomingSubscribeParam", 0, 0, 0)) SWIG_fail;
  result = (pj::OnIncomingSubscribeParam *)new pj::OnIncomingSubscribeParam();
  resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(result), SWIGTYPE_p_pj__OnIncomingSubscribeParam, SWIG_POINTER_NEW |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_delete_OnIncomingSubscribeParam(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::OnIncomingSubscribeParam *arg1 = (pj::OnIncomingSubscribeParam *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__OnIncomingSubscribeParam, SWIG_POINTER_DISOWN |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "delete_OnIncomingSubscribeParam" "', argument " "1"" of type '" "pj::OnIncomingSubscribeParam *""'"); 
  }
  arg1 = reinterpret_cast< pj::OnIncomingSubscribeParam * >(argp1);
  delete arg1;
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *OnIncomingSubscribeParam_swigregister(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *obj;
  if (!SWIG_Python_UnpackTuple(args, "swigregister", 1, 1, &obj)) return NULL;
  SWIG_TypeNewClientData(SWIGTYPE_p_pj__OnIncomingSubscribeParam, SWIG_NewClientData(obj));
  return SWIG_Py_Void();
}

SWIGINTERN PyObject *OnIncomingSubscribeParam_swiginit(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  return SWIG_Python_InitShadowInstance(args);
}

SWIGINTERN PyObject *_wrap_OnInstantMessageParam_fromUri_set(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::OnInstantMessageParam *arg1 = (pj::OnInstantMessageParam *) 0 ;
  pj::string *arg2 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  int res2 = SWIG_OLDOBJ ;
  PyObject *swig_obj[2] ;
  
  if (!SWIG_Python_UnpackTuple(args, "OnInstantMessageParam_fromUri_set", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__OnInstantMessageParam, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "OnInstantMessageParam_fromUri_set" "', argument " "1"" of type '" "pj::OnInstantMessageParam *""'"); 
  }
  arg1 = reinterpret_cast< pj::OnInstantMessageParam * >(argp1);
  {
    std::string *ptr = (std::string *)0;
    res2 = SWIG_AsPtr_std_string(swig_obj[1], &ptr);
    if (!SWIG_IsOK(res2)) {
      SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "OnInstantMessageParam_fromUri_set" "', argument " "2"" of type '" "pj::string const &""'"); 
    }
    if (!ptr) {
      SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "OnInstantMessageParam_fromUri_set" "', argument " "2"" of type '" "pj::string const &""'"); 
    }
    arg2 = ptr;
  }
  if (arg1) (arg1)->fromUri = *arg2;
  resultobj = SWIG_Py_Void();
  if (SWIG_IsNewObj(res2)) delete arg2;
  return resultobj;
fail:
  if (SWIG_IsNewObj(res2)) delete arg2;
  return NULL;
}


SWIGINTERN PyObject *_wrap_OnInstantMessageParam_fromUri_get(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::OnInstantMessageParam *arg1 = (pj::OnInstantMessageParam *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  pj::string *result = 0 ;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__OnInstantMessageParam, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "OnInstantMessageParam_fromUri_get" "', argument " "1"" of type '" "pj::OnInstantMessageParam *""'"); 
  }
  arg1 = reinterpret_cast< pj::OnInstantMessageParam * >(argp1);
  result = (pj::string *) & ((arg1)->fromUri);
  resultobj = SWIG_From_std_string(static_cast< std::string >(*result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_OnInstantMessageParam_toUri_set(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::OnInstantMessageParam *arg1 = (pj::OnInstantMessageParam *) 0 ;
  pj::string *arg2 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  int res2 = SWIG_OLDOBJ ;
  PyObject *swig_obj[2] ;
  
  if (!SWIG_Python_UnpackTuple(args, "OnInstantMessageParam_toUri_set", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__OnInstantMessageParam, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "OnInstantMessageParam_toUri_set" "', argument " "1"" of type '" "pj::OnInstantMessageParam *""'"); 
  }
  arg1 = reinterpret_cast< pj::OnInstantMessageParam * >(argp1);
  {
    std::string *ptr = (std::string *)0;
    res2 = SWIG_AsPtr_std_string(swig_obj[1], &ptr);
    if (!SWIG_IsOK(res2)) {
      SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "OnInstantMessageParam_toUri_set" "', argument " "2"" of type '" "pj::string const &""'"); 
    }
    if (!ptr) {
      SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "OnInstantMessageParam_toUri_set" "', argument " "2"" of type '" "pj::string const &""'"); 
    }
    arg2 = ptr;
  }
  if (arg1) (arg1)->toUri = *arg2;
  resultobj = SWIG_Py_Void();
  if (SWIG_IsNewObj(res2)) delete arg2;
  return resultobj;
fail:
  if (SWIG_IsNewObj(res2)) delete arg2;
  return NULL;
}


SWIGINTERN PyObject *_wrap_OnInstantMessageParam_toUri_get(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::OnInstantMessageParam *arg1 = (pj::OnInstantMessageParam *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  pj::string *result = 0 ;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__OnInstantMessageParam, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "OnInstantMessageParam_toUri_get" "', argument " "1"" of type '" "pj::OnInstantMessageParam *""'"); 
  }
  arg1 = reinterpret_cast< pj::OnInstantMessageParam * >(argp1);
  result = (pj::string *) & ((arg1)->toUri);
  resultobj = SWIG_From_std_string(static_cast< std::string >(*result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_OnInstantMessageParam_contactUri_set(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::OnInstantMessageParam *arg1 = (pj::OnInstantMessageParam *) 0 ;
  pj::string *arg2 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  int res2 = SWIG_OLDOBJ ;
  PyObject *swig_obj[2] ;
  
  if (!SWIG_Python_UnpackTuple(args, "OnInstantMessageParam_contactUri_set", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__OnInstantMessageParam, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "OnInstantMessageParam_contactUri_set" "', argument " "1"" of type '" "pj::OnInstantMessageParam *""'"); 
  }
  arg1 = reinterpret_cast< pj::OnInstantMessageParam * >(argp1);
  {
    std::string *ptr = (std::string *)0;
    res2 = SWIG_AsPtr_std_string(swig_obj[1], &ptr);
    if (!SWIG_IsOK(res2)) {
      SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "OnInstantMessageParam_contactUri_set" "', argument " "2"" of type '" "pj::string const &""'"); 
    }
    if (!ptr) {
      SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "OnInstantMessageParam_contactUri_set" "', argument " "2"" of type '" "pj::string const &""'"); 
    }
    arg2 = ptr;
  }
  if (arg1) (arg1)->contactUri = *arg2;
  resultobj = SWIG_Py_Void();
  if (SWIG_IsNewObj(res2)) delete arg2;
  return resultobj;
fail:
  if (SWIG_IsNewObj(res2)) delete arg2;
  return NULL;
}


SWIGINTERN PyObject *_wrap_OnInstantMessageParam_contactUri_get(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::OnInstantMessageParam *arg1 = (pj::OnInstantMessageParam *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  pj::string *result = 0 ;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__OnInstantMessageParam, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "OnInstantMessageParam_contactUri_get" "', argument " "1"" of type '" "pj::OnInstantMessageParam *""'"); 
  }
  arg1 = reinterpret_cast< pj::OnInstantMessageParam * >(argp1);
  result = (pj::string *) & ((arg1)->contactUri);
  resultobj = SWIG_From_std_string(static_cast< std::string >(*result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_OnInstantMessageParam_contentType_set(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::OnInstantMessageParam *arg1 = (pj::OnInstantMessageParam *) 0 ;
  pj::string *arg2 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  int res2 = SWIG_OLDOBJ ;
  PyObject *swig_obj[2] ;
  
  if (!SWIG_Python_UnpackTuple(args, "OnInstantMessageParam_contentType_set", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__OnInstantMessageParam, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "OnInstantMessageParam_contentType_set" "', argument " "1"" of type '" "pj::OnInstantMessageParam *""'"); 
  }
  arg1 = reinterpret_cast< pj::OnInstantMessageParam * >(argp1);
  {
    std::string *ptr = (std::string *)0;
    res2 = SWIG_AsPtr_std_string(swig_obj[1], &ptr);
    if (!SWIG_IsOK(res2)) {
      SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "OnInstantMessageParam_contentType_set" "', argument " "2"" of type '" "pj::string const &""'"); 
    }
    if (!ptr) {
      SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "OnInstantMessageParam_contentType_set" "', argument " "2"" of type '" "pj::string const &""'"); 
    }
    arg2 = ptr;
  }
  if (arg1) (arg1)->contentType = *arg2;
  resultobj = SWIG_Py_Void();
  if (SWIG_IsNewObj(res2)) delete arg2;
  return resultobj;
fail:
  if (SWIG_IsNewObj(res2)) delete arg2;
  return NULL;
}


SWIGINTERN PyObject *_wrap_OnInstantMessageParam_contentType_get(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::OnInstantMessageParam *arg1 = (pj::OnInstantMessageParam *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  pj::string *result = 0 ;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__OnInstantMessageParam, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "OnInstantMessageParam_contentType_get" "', argument " "1"" of type '" "pj::OnInstantMessageParam *""'"); 
  }
  arg1 = reinterpret_cast< pj::OnInstantMessageParam * >(argp1);
  result = (pj::string *) & ((arg1)->contentType);
  resultobj = SWIG_From_std_string(static_cast< std::string >(*result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_OnInstantMessageParam_msgBody_set(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::OnInstantMessageParam *arg1 = (pj::OnInstantMessageParam *) 0 ;
  pj::string *arg2 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  int res2 = SWIG_OLDOBJ ;
  PyObject *swig_obj[2] ;
  
  if (!SWIG_Python_UnpackTuple(args, "OnInstantMessageParam_msgBody_set", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__OnInstantMessageParam, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "OnInstantMessageParam_msgBody_set" "', argument " "1"" of type '" "pj::OnInstantMessageParam *""'"); 
  }
  arg1 = reinterpret_cast< pj::OnInstantMessageParam * >(argp1);
  {
    std::string *ptr = (std::string *)0;
    res2 = SWIG_AsPtr_std_string(swig_obj[1], &ptr);
    if (!SWIG_IsOK(res2)) {
      SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "OnInstantMessageParam_msgBody_set" "', argument " "2"" of type '" "pj::string const &""'"); 
    }
    if (!ptr) {
      SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "OnInstantMessageParam_msgBody_set" "', argument " "2"" of type '" "pj::string const &""'"); 
    }
    arg2 = ptr;
  }
  if (arg1) (arg1)->msgBody = *arg2;
  resultobj = SWIG_Py_Void();
  if (SWIG_IsNewObj(res2)) delete arg2;
  return resultobj;
fail:
  if (SWIG_IsNewObj(res2)) delete arg2;
  return NULL;
}


SWIGINTERN PyObject *_wrap_OnInstantMessageParam_msgBody_get(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::OnInstantMessageParam *arg1 = (pj::OnInstantMessageParam *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  pj::string *result = 0 ;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__OnInstantMessageParam, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "OnInstantMessageParam_msgBody_get" "', argument " "1"" of type '" "pj::OnInstantMessageParam *""'"); 
  }
  arg1 = reinterpret_cast< pj::OnInstantMessageParam * >(argp1);
  result = (pj::string *) & ((arg1)->msgBody);
  resultobj = SWIG_From_std_string(static_cast< std::string >(*result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_OnInstantMessageParam_rdata_set(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::OnInstantMessageParam *arg1 = (pj::OnInstantMessageParam *) 0 ;
  pj::SipRxData *arg2 = (pj::SipRxData *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  void *argp2 = 0 ;
  int res2 = 0 ;
  PyObject *swig_obj[2] ;
  
  if (!SWIG_Python_UnpackTuple(args, "OnInstantMessageParam_rdata_set", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__OnInstantMessageParam, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "OnInstantMessageParam_rdata_set" "', argument " "1"" of type '" "pj::OnInstantMessageParam *""'"); 
  }
  arg1 = reinterpret_cast< pj::OnInstantMessageParam * >(argp1);
  res2 = SWIG_ConvertPtr(swig_obj[1], &argp2,SWIGTYPE_p_pj__SipRxData, 0 |  0 );
  if (!SWIG_IsOK(res2)) {
    SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "OnInstantMessageParam_rdata_set" "', argument " "2"" of type '" "pj::SipRxData *""'"); 
  }
  arg2 = reinterpret_cast< pj::SipRxData * >(argp2);
  if (arg1) (arg1)->rdata = *arg2;
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_OnInstantMessageParam_rdata_get(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::OnInstantMessageParam *arg1 = (pj::OnInstantMessageParam *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  pj::SipRxData *result = 0 ;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__OnInstantMessageParam, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "OnInstantMessageParam_rdata_get" "', argument " "1"" of type '" "pj::OnInstantMessageParam *""'"); 
  }
  arg1 = reinterpret_cast< pj::OnInstantMessageParam * >(argp1);
  result = (pj::SipRxData *)& ((arg1)->rdata);
  resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(result), SWIGTYPE_p_pj__SipRxData, 0 |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_new_OnInstantMessageParam(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::OnInstantMessageParam *result = 0 ;
  
  if (!SWIG_Python_UnpackTuple(args, "new_OnInstantMessageParam", 0, 0, 0)) SWIG_fail;
  result = (pj::OnInstantMessageParam *)new pj::OnInstantMessageParam();
  resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(result), SWIGTYPE_p_pj__OnInstantMessageParam, SWIG_POINTER_NEW |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_delete_OnInstantMessageParam(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::OnInstantMessageParam *arg1 = (pj::OnInstantMessageParam *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__OnInstantMessageParam, SWIG_POINTER_DISOWN |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "delete_OnInstantMessageParam" "', argument " "1"" of type '" "pj::OnInstantMessageParam *""'"); 
  }
  arg1 = reinterpret_cast< pj::OnInstantMessageParam * >(argp1);
  delete arg1;
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *OnInstantMessageParam_swigregister(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *obj;
  if (!SWIG_Python_UnpackTuple(args, "swigregister", 1, 1, &obj)) return NULL;
  SWIG_TypeNewClientData(SWIGTYPE_p_pj__OnInstantMessageParam, SWIG_NewClientData(obj));
  return SWIG_Py_Void();
}

SWIGINTERN PyObject *OnInstantMessageParam_swiginit(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  return SWIG_Python_InitShadowInstance(args);
}

SWIGINTERN PyObject *_wrap_OnInstantMessageStatusParam_userData_set(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::OnInstantMessageStatusParam *arg1 = (pj::OnInstantMessageStatusParam *) 0 ;
  pj::Token arg2 = (pj::Token) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  int res2 ;
  PyObject *swig_obj[2] ;
  
  if (!SWIG_Python_UnpackTuple(args, "OnInstantMessageStatusParam_userData_set", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__OnInstantMessageStatusParam, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "OnInstantMessageStatusParam_userData_set" "', argument " "1"" of type '" "pj::OnInstantMessageStatusParam *""'"); 
  }
  arg1 = reinterpret_cast< pj::OnInstantMessageStatusParam * >(argp1);
  res2 = SWIG_ConvertPtr(swig_obj[1],SWIG_as_voidptrptr(&arg2), 0, SWIG_POINTER_DISOWN);
  if (!SWIG_IsOK(res2)) {
    SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "OnInstantMessageStatusParam_userData_set" "', argument " "2"" of type '" "pj::Token""'"); 
  }
  if (arg1) (arg1)->userData = arg2;
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_OnInstantMessageStatusParam_userData_get(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::OnInstantMessageStatusParam *arg1 = (pj::OnInstantMessageStatusParam *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  pj::Token result;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__OnInstantMessageStatusParam, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "OnInstantMessageStatusParam_userData_get" "', argument " "1"" of type '" "pj::OnInstantMessageStatusParam *""'"); 
  }
  arg1 = reinterpret_cast< pj::OnInstantMessageStatusParam * >(argp1);
  result = (pj::Token) ((arg1)->userData);
  resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(result), SWIGTYPE_p_void, 0 |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_OnInstantMessageStatusParam_toUri_set(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::OnInstantMessageStatusParam *arg1 = (pj::OnInstantMessageStatusParam *) 0 ;
  pj::string *arg2 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  int res2 = SWIG_OLDOBJ ;
  PyObject *swig_obj[2] ;
  
  if (!SWIG_Python_UnpackTuple(args, "OnInstantMessageStatusParam_toUri_set", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__OnInstantMessageStatusParam, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "OnInstantMessageStatusParam_toUri_set" "', argument " "1"" of type '" "pj::OnInstantMessageStatusParam *""'"); 
  }
  arg1 = reinterpret_cast< pj::OnInstantMessageStatusParam * >(argp1);
  {
    std::string *ptr = (std::string *)0;
    res2 = SWIG_AsPtr_std_string(swig_obj[1], &ptr);
    if (!SWIG_IsOK(res2)) {
      SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "OnInstantMessageStatusParam_toUri_set" "', argument " "2"" of type '" "pj::string const &""'"); 
    }
    if (!ptr) {
      SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "OnInstantMessageStatusParam_toUri_set" "', argument " "2"" of type '" "pj::string const &""'"); 
    }
    arg2 = ptr;
  }
  if (arg1) (arg1)->toUri = *arg2;
  resultobj = SWIG_Py_Void();
  if (SWIG_IsNewObj(res2)) delete arg2;
  return resultobj;
fail:
  if (SWIG_IsNewObj(res2)) delete arg2;
  return NULL;
}


SWIGINTERN PyObject *_wrap_OnInstantMessageStatusParam_toUri_get(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::OnInstantMessageStatusParam *arg1 = (pj::OnInstantMessageStatusParam *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  pj::string *result = 0 ;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__OnInstantMessageStatusParam, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "OnInstantMessageStatusParam_toUri_get" "', argument " "1"" of type '" "pj::OnInstantMessageStatusParam *""'"); 
  }
  arg1 = reinterpret_cast< pj::OnInstantMessageStatusParam * >(argp1);
  result = (pj::string *) & ((arg1)->toUri);
  resultobj = SWIG_From_std_string(static_cast< std::string >(*result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_OnInstantMessageStatusParam_msgBody_set(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::OnInstantMessageStatusParam *arg1 = (pj::OnInstantMessageStatusParam *) 0 ;
  pj::string *arg2 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  int res2 = SWIG_OLDOBJ ;
  PyObject *swig_obj[2] ;
  
  if (!SWIG_Python_UnpackTuple(args, "OnInstantMessageStatusParam_msgBody_set", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__OnInstantMessageStatusParam, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "OnInstantMessageStatusParam_msgBody_set" "', argument " "1"" of type '" "pj::OnInstantMessageStatusParam *""'"); 
  }
  arg1 = reinterpret_cast< pj::OnInstantMessageStatusParam * >(argp1);
  {
    std::string *ptr = (std::string *)0;
    res2 = SWIG_AsPtr_std_string(swig_obj[1], &ptr);
    if (!SWIG_IsOK(res2)) {
      SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "OnInstantMessageStatusParam_msgBody_set" "', argument " "2"" of type '" "pj::string const &""'"); 
    }
    if (!ptr) {
      SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "OnInstantMessageStatusParam_msgBody_set" "', argument " "2"" of type '" "pj::string const &""'"); 
    }
    arg2 = ptr;
  }
  if (arg1) (arg1)->msgBody = *arg2;
  resultobj = SWIG_Py_Void();
  if (SWIG_IsNewObj(res2)) delete arg2;
  return resultobj;
fail:
  if (SWIG_IsNewObj(res2)) delete arg2;
  return NULL;
}


SWIGINTERN PyObject *_wrap_OnInstantMessageStatusParam_msgBody_get(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::OnInstantMessageStatusParam *arg1 = (pj::OnInstantMessageStatusParam *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  pj::string *result = 0 ;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__OnInstantMessageStatusParam, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "OnInstantMessageStatusParam_msgBody_get" "', argument " "1"" of type '" "pj::OnInstantMessageStatusParam *""'"); 
  }
  arg1 = reinterpret_cast< pj::OnInstantMessageStatusParam * >(argp1);
  result = (pj::string *) & ((arg1)->msgBody);
  resultobj = SWIG_From_std_string(static_cast< std::string >(*result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_OnInstantMessageStatusParam_code_set(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::OnInstantMessageStatusParam *arg1 = (pj::OnInstantMessageStatusParam *) 0 ;
  pjsip_status_code arg2 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  int val2 ;
  int ecode2 = 0 ;
  PyObject *swig_obj[2] ;
  
  if (!SWIG_Python_UnpackTuple(args, "OnInstantMessageStatusParam_code_set", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__OnInstantMessageStatusParam, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "OnInstantMessageStatusParam_code_set" "', argument " "1"" of type '" "pj::OnInstantMessageStatusParam *""'"); 
  }
  arg1 = reinterpret_cast< pj::OnInstantMessageStatusParam * >(argp1);
  ecode2 = SWIG_AsVal_int(swig_obj[1], &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "OnInstantMessageStatusParam_code_set" "', argument " "2"" of type '" "pjsip_status_code""'");
  } 
  arg2 = static_cast< pjsip_status_code >(val2);
  if (arg1) (arg1)->code = arg2;
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_OnInstantMessageStatusParam_code_get(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::OnInstantMessageStatusParam *arg1 = (pj::OnInstantMessageStatusParam *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  pjsip_status_code result;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__OnInstantMessageStatusParam, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "OnInstantMessageStatusParam_code_get" "', argument " "1"" of type '" "pj::OnInstantMessageStatusParam *""'"); 
  }
  arg1 = reinterpret_cast< pj::OnInstantMessageStatusParam * >(argp1);
  result = (pjsip_status_code) ((arg1)->code);
  resultobj = SWIG_From_int(static_cast< int >(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_OnInstantMessageStatusParam_reason_set(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::OnInstantMessageStatusParam *arg1 = (pj::OnInstantMessageStatusParam *) 0 ;
  pj::string *arg2 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  int res2 = SWIG_OLDOBJ ;
  PyObject *swig_obj[2] ;
  
  if (!SWIG_Python_UnpackTuple(args, "OnInstantMessageStatusParam_reason_set", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__OnInstantMessageStatusParam, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "OnInstantMessageStatusParam_reason_set" "', argument " "1"" of type '" "pj::OnInstantMessageStatusParam *""'"); 
  }
  arg1 = reinterpret_cast< pj::OnInstantMessageStatusParam * >(argp1);
  {
    std::string *ptr = (std::string *)0;
    res2 = SWIG_AsPtr_std_string(swig_obj[1], &ptr);
    if (!SWIG_IsOK(res2)) {
      SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "OnInstantMessageStatusParam_reason_set" "', argument " "2"" of type '" "pj::string const &""'"); 
    }
    if (!ptr) {
      SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "OnInstantMessageStatusParam_reason_set" "', argument " "2"" of type '" "pj::string const &""'"); 
    }
    arg2 = ptr;
  }
  if (arg1) (arg1)->reason = *arg2;
  resultobj = SWIG_Py_Void();
  if (SWIG_IsNewObj(res2)) delete arg2;
  return resultobj;
fail:
  if (SWIG_IsNewObj(res2)) delete arg2;
  return NULL;
}


SWIGINTERN PyObject *_wrap_OnInstantMessageStatusParam_reason_get(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::OnInstantMessageStatusParam *arg1 = (pj::OnInstantMessageStatusParam *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  pj::string *result = 0 ;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__OnInstantMessageStatusParam, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "OnInstantMessageStatusParam_reason_get" "', argument " "1"" of type '" "pj::OnInstantMessageStatusParam *""'"); 
  }
  arg1 = reinterpret_cast< pj::OnInstantMessageStatusParam * >(argp1);
  result = (pj::string *) & ((arg1)->reason);
  resultobj = SWIG_From_std_string(static_cast< std::string >(*result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_OnInstantMessageStatusParam_rdata_set(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::OnInstantMessageStatusParam *arg1 = (pj::OnInstantMessageStatusParam *) 0 ;
  pj::SipRxData *arg2 = (pj::SipRxData *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  void *argp2 = 0 ;
  int res2 = 0 ;
  PyObject *swig_obj[2] ;
  
  if (!SWIG_Python_UnpackTuple(args, "OnInstantMessageStatusParam_rdata_set", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__OnInstantMessageStatusParam, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "OnInstantMessageStatusParam_rdata_set" "', argument " "1"" of type '" "pj::OnInstantMessageStatusParam *""'"); 
  }
  arg1 = reinterpret_cast< pj::OnInstantMessageStatusParam * >(argp1);
  res2 = SWIG_ConvertPtr(swig_obj[1], &argp2,SWIGTYPE_p_pj__SipRxData, 0 |  0 );
  if (!SWIG_IsOK(res2)) {
    SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "OnInstantMessageStatusParam_rdata_set" "', argument " "2"" of type '" "pj::SipRxData *""'"); 
  }
  arg2 = reinterpret_cast< pj::SipRxData * >(argp2);
  if (arg1) (arg1)->rdata = *arg2;
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_OnInstantMessageStatusParam_rdata_get(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::OnInstantMessageStatusParam *arg1 = (pj::OnInstantMessageStatusParam *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  pj::SipRxData *result = 0 ;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__OnInstantMessageStatusParam, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "OnInstantMessageStatusParam_rdata_get" "', argument " "1"" of type '" "pj::OnInstantMessageStatusParam *""'"); 
  }
  arg1 = reinterpret_cast< pj::OnInstantMessageStatusParam * >(argp1);
  result = (pj::SipRxData *)& ((arg1)->rdata);
  resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(result), SWIGTYPE_p_pj__SipRxData, 0 |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_new_OnInstantMessageStatusParam(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::OnInstantMessageStatusParam *result = 0 ;
  
  if (!SWIG_Python_UnpackTuple(args, "new_OnInstantMessageStatusParam", 0, 0, 0)) SWIG_fail;
  result = (pj::OnInstantMessageStatusParam *)new pj::OnInstantMessageStatusParam();
  resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(result), SWIGTYPE_p_pj__OnInstantMessageStatusParam, SWIG_POINTER_NEW |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_delete_OnInstantMessageStatusParam(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::OnInstantMessageStatusParam *arg1 = (pj::OnInstantMessageStatusParam *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__OnInstantMessageStatusParam, SWIG_POINTER_DISOWN |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "delete_OnInstantMessageStatusParam" "', argument " "1"" of type '" "pj::OnInstantMessageStatusParam *""'"); 
  }
  arg1 = reinterpret_cast< pj::OnInstantMessageStatusParam * >(argp1);
  delete arg1;
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *OnInstantMessageStatusParam_swigregister(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *obj;
  if (!SWIG_Python_UnpackTuple(args, "swigregister", 1, 1, &obj)) return NULL;
  SWIG_TypeNewClientData(SWIGTYPE_p_pj__OnInstantMessageStatusParam, SWIG_NewClientData(obj));
  return SWIG_Py_Void();
}

SWIGINTERN PyObject *OnInstantMessageStatusParam_swiginit(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  return SWIG_Python_InitShadowInstance(args);
}

SWIGINTERN PyObject *_wrap_OnTypingIndicationParam_fromUri_set(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::OnTypingIndicationParam *arg1 = (pj::OnTypingIndicationParam *) 0 ;
  pj::string *arg2 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  int res2 = SWIG_OLDOBJ ;
  PyObject *swig_obj[2] ;
  
  if (!SWIG_Python_UnpackTuple(args, "OnTypingIndicationParam_fromUri_set", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__OnTypingIndicationParam, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "OnTypingIndicationParam_fromUri_set" "', argument " "1"" of type '" "pj::OnTypingIndicationParam *""'"); 
  }
  arg1 = reinterpret_cast< pj::OnTypingIndicationParam * >(argp1);
  {
    std::string *ptr = (std::string *)0;
    res2 = SWIG_AsPtr_std_string(swig_obj[1], &ptr);
    if (!SWIG_IsOK(res2)) {
      SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "OnTypingIndicationParam_fromUri_set" "', argument " "2"" of type '" "pj::string const &""'"); 
    }
    if (!ptr) {
      SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "OnTypingIndicationParam_fromUri_set" "', argument " "2"" of type '" "pj::string const &""'"); 
    }
    arg2 = ptr;
  }
  if (arg1) (arg1)->fromUri = *arg2;
  resultobj = SWIG_Py_Void();
  if (SWIG_IsNewObj(res2)) delete arg2;
  return resultobj;
fail:
  if (SWIG_IsNewObj(res2)) delete arg2;
  return NULL;
}


SWIGINTERN PyObject *_wrap_OnTypingIndicationParam_fromUri_get(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::OnTypingIndicationParam *arg1 = (pj::OnTypingIndicationParam *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  pj::string *result = 0 ;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__OnTypingIndicationParam, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "OnTypingIndicationParam_fromUri_get" "', argument " "1"" of type '" "pj::OnTypingIndicationParam *""'"); 
  }
  arg1 = reinterpret_cast< pj::OnTypingIndicationParam * >(argp1);
  result = (pj::string *) & ((arg1)->fromUri);
  resultobj = SWIG_From_std_string(static_cast< std::string >(*result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_OnTypingIndicationParam_toUri_set(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::OnTypingIndicationParam *arg1 = (pj::OnTypingIndicationParam *) 0 ;
  pj::string *arg2 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  int res2 = SWIG_OLDOBJ ;
  PyObject *swig_obj[2] ;
  
  if (!SWIG_Python_UnpackTuple(args, "OnTypingIndicationParam_toUri_set", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__OnTypingIndicationParam, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "OnTypingIndicationParam_toUri_set" "', argument " "1"" of type '" "pj::OnTypingIndicationParam *""'"); 
  }
  arg1 = reinterpret_cast< pj::OnTypingIndicationParam * >(argp1);
  {
    std::string *ptr = (std::string *)0;
    res2 = SWIG_AsPtr_std_string(swig_obj[1], &ptr);
    if (!SWIG_IsOK(res2)) {
      SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "OnTypingIndicationParam_toUri_set" "', argument " "2"" of type '" "pj::string const &""'"); 
    }
    if (!ptr) {
      SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "OnTypingIndicationParam_toUri_set" "', argument " "2"" of type '" "pj::string const &""'"); 
    }
    arg2 = ptr;
  }
  if (arg1) (arg1)->toUri = *arg2;
  resultobj = SWIG_Py_Void();
  if (SWIG_IsNewObj(res2)) delete arg2;
  return resultobj;
fail:
  if (SWIG_IsNewObj(res2)) delete arg2;
  return NULL;
}


SWIGINTERN PyObject *_wrap_OnTypingIndicationParam_toUri_get(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::OnTypingIndicationParam *arg1 = (pj::OnTypingIndicationParam *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  pj::string *result = 0 ;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__OnTypingIndicationParam, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "OnTypingIndicationParam_toUri_get" "', argument " "1"" of type '" "pj::OnTypingIndicationParam *""'"); 
  }
  arg1 = reinterpret_cast< pj::OnTypingIndicationParam * >(argp1);
  result = (pj::string *) & ((arg1)->toUri);
  resultobj = SWIG_From_std_string(static_cast< std::string >(*result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_OnTypingIndicationParam_contactUri_set(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::OnTypingIndicationParam *arg1 = (pj::OnTypingIndicationParam *) 0 ;
  pj::string *arg2 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  int res2 = SWIG_OLDOBJ ;
  PyObject *swig_obj[2] ;
  
  if (!SWIG_Python_UnpackTuple(args, "OnTypingIndicationParam_contactUri_set", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__OnTypingIndicationParam, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "OnTypingIndicationParam_contactUri_set" "', argument " "1"" of type '" "pj::OnTypingIndicationParam *""'"); 
  }
  arg1 = reinterpret_cast< pj::OnTypingIndicationParam * >(argp1);
  {
    std::string *ptr = (std::string *)0;
    res2 = SWIG_AsPtr_std_string(swig_obj[1], &ptr);
    if (!SWIG_IsOK(res2)) {
      SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "OnTypingIndicationParam_contactUri_set" "', argument " "2"" of type '" "pj::string const &""'"); 
    }
    if (!ptr) {
      SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "OnTypingIndicationParam_contactUri_set" "', argument " "2"" of type '" "pj::string const &""'"); 
    }
    arg2 = ptr;
  }
  if (arg1) (arg1)->contactUri = *arg2;
  resultobj = SWIG_Py_Void();
  if (SWIG_IsNewObj(res2)) delete arg2;
  return resultobj;
fail:
  if (SWIG_IsNewObj(res2)) delete arg2;
  return NULL;
}


SWIGINTERN PyObject *_wrap_OnTypingIndicationParam_contactUri_get(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::OnTypingIndicationParam *arg1 = (pj::OnTypingIndicationParam *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  pj::string *result = 0 ;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__OnTypingIndicationParam, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "OnTypingIndicationParam_contactUri_get" "', argument " "1"" of type '" "pj::OnTypingIndicationParam *""'"); 
  }
  arg1 = reinterpret_cast< pj::OnTypingIndicationParam * >(argp1);
  result = (pj::string *) & ((arg1)->contactUri);
  resultobj = SWIG_From_std_string(static_cast< std::string >(*result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_OnTypingIndicationParam_isTyping_set(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::OnTypingIndicationParam *arg1 = (pj::OnTypingIndicationParam *) 0 ;
  bool arg2 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  bool val2 ;
  int ecode2 = 0 ;
  PyObject *swig_obj[2] ;
  
  if (!SWIG_Python_UnpackTuple(args, "OnTypingIndicationParam_isTyping_set", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__OnTypingIndicationParam, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "OnTypingIndicationParam_isTyping_set" "', argument " "1"" of type '" "pj::OnTypingIndicationParam *""'"); 
  }
  arg1 = reinterpret_cast< pj::OnTypingIndicationParam * >(argp1);
  ecode2 = SWIG_AsVal_bool(swig_obj[1], &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "OnTypingIndicationParam_isTyping_set" "', argument " "2"" of type '" "bool""'");
  } 
  arg2 = static_cast< bool >(val2);
  if (arg1) (arg1)->isTyping = arg2;
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_OnTypingIndicationParam_isTyping_get(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::OnTypingIndicationParam *arg1 = (pj::OnTypingIndicationParam *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  bool result;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__OnTypingIndicationParam, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "OnTypingIndicationParam_isTyping_get" "', argument " "1"" of type '" "pj::OnTypingIndicationParam *""'"); 
  }
  arg1 = reinterpret_cast< pj::OnTypingIndicationParam * >(argp1);
  result = (bool) ((arg1)->isTyping);
  resultobj = SWIG_From_bool(static_cast< bool >(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_OnTypingIndicationParam_rdata_set(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::OnTypingIndicationParam *arg1 = (pj::OnTypingIndicationParam *) 0 ;
  pj::SipRxData *arg2 = (pj::SipRxData *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  void *argp2 = 0 ;
  int res2 = 0 ;
  PyObject *swig_obj[2] ;
  
  if (!SWIG_Python_UnpackTuple(args, "OnTypingIndicationParam_rdata_set", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__OnTypingIndicationParam, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "OnTypingIndicationParam_rdata_set" "', argument " "1"" of type '" "pj::OnTypingIndicationParam *""'"); 
  }
  arg1 = reinterpret_cast< pj::OnTypingIndicationParam * >(argp1);
  res2 = SWIG_ConvertPtr(swig_obj[1], &argp2,SWIGTYPE_p_pj__SipRxData, 0 |  0 );
  if (!SWIG_IsOK(res2)) {
    SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "OnTypingIndicationParam_rdata_set" "', argument " "2"" of type '" "pj::SipRxData *""'"); 
  }
  arg2 = reinterpret_cast< pj::SipRxData * >(argp2);
  if (arg1) (arg1)->rdata = *arg2;
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_OnTypingIndicationParam_rdata_get(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::OnTypingIndicationParam *arg1 = (pj::OnTypingIndicationParam *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  pj::SipRxData *result = 0 ;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__OnTypingIndicationParam, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "OnTypingIndicationParam_rdata_get" "', argument " "1"" of type '" "pj::OnTypingIndicationParam *""'"); 
  }
  arg1 = reinterpret_cast< pj::OnTypingIndicationParam * >(argp1);
  result = (pj::SipRxData *)& ((arg1)->rdata);
  resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(result), SWIGTYPE_p_pj__SipRxData, 0 |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_new_OnTypingIndicationParam(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::OnTypingIndicationParam *result = 0 ;
  
  if (!SWIG_Python_UnpackTuple(args, "new_OnTypingIndicationParam", 0, 0, 0)) SWIG_fail;
  result = (pj::OnTypingIndicationParam *)new pj::OnTypingIndicationParam();
  resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(result), SWIGTYPE_p_pj__OnTypingIndicationParam, SWIG_POINTER_NEW |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_delete_OnTypingIndicationParam(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::OnTypingIndicationParam *arg1 = (pj::OnTypingIndicationParam *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__OnTypingIndicationParam, SWIG_POINTER_DISOWN |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "delete_OnTypingIndicationParam" "', argument " "1"" of type '" "pj::OnTypingIndicationParam *""'"); 
  }
  arg1 = reinterpret_cast< pj::OnTypingIndicationParam * >(argp1);
  delete arg1;
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *OnTypingIndicationParam_swigregister(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *obj;
  if (!SWIG_Python_UnpackTuple(args, "swigregister", 1, 1, &obj)) return NULL;
  SWIG_TypeNewClientData(SWIGTYPE_p_pj__OnTypingIndicationParam, SWIG_NewClientData(obj));
  return SWIG_Py_Void();
}

SWIGINTERN PyObject *OnTypingIndicationParam_swiginit(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  return SWIG_Python_InitShadowInstance(args);
}

SWIGINTERN PyObject *_wrap_OnMwiInfoParam_state_set(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::OnMwiInfoParam *arg1 = (pj::OnMwiInfoParam *) 0 ;
  pjsip_evsub_state arg2 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  int val2 ;
  int ecode2 = 0 ;
  PyObject *swig_obj[2] ;
  
  if (!SWIG_Python_UnpackTuple(args, "OnMwiInfoParam_state_set", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__OnMwiInfoParam, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "OnMwiInfoParam_state_set" "', argument " "1"" of type '" "pj::OnMwiInfoParam *""'"); 
  }
  arg1 = reinterpret_cast< pj::OnMwiInfoParam * >(argp1);
  ecode2 = SWIG_AsVal_int(swig_obj[1], &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "OnMwiInfoParam_state_set" "', argument " "2"" of type '" "pjsip_evsub_state""'");
  } 
  arg2 = static_cast< pjsip_evsub_state >(val2);
  if (arg1) (arg1)->state = arg2;
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_OnMwiInfoParam_state_get(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::OnMwiInfoParam *arg1 = (pj::OnMwiInfoParam *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  pjsip_evsub_state result;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__OnMwiInfoParam, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "OnMwiInfoParam_state_get" "', argument " "1"" of type '" "pj::OnMwiInfoParam *""'"); 
  }
  arg1 = reinterpret_cast< pj::OnMwiInfoParam * >(argp1);
  result = (pjsip_evsub_state) ((arg1)->state);
  resultobj = SWIG_From_int(static_cast< int >(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_OnMwiInfoParam_rdata_set(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::OnMwiInfoParam *arg1 = (pj::OnMwiInfoParam *) 0 ;
  pj::SipRxData *arg2 = (pj::SipRxData *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  void *argp2 = 0 ;
  int res2 = 0 ;
  PyObject *swig_obj[2] ;
  
  if (!SWIG_Python_UnpackTuple(args, "OnMwiInfoParam_rdata_set", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__OnMwiInfoParam, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "OnMwiInfoParam_rdata_set" "', argument " "1"" of type '" "pj::OnMwiInfoParam *""'"); 
  }
  arg1 = reinterpret_cast< pj::OnMwiInfoParam * >(argp1);
  res2 = SWIG_ConvertPtr(swig_obj[1], &argp2,SWIGTYPE_p_pj__SipRxData, 0 |  0 );
  if (!SWIG_IsOK(res2)) {
    SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "OnMwiInfoParam_rdata_set" "', argument " "2"" of type '" "pj::SipRxData *""'"); 
  }
  arg2 = reinterpret_cast< pj::SipRxData * >(argp2);
  if (arg1) (arg1)->rdata = *arg2;
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_OnMwiInfoParam_rdata_get(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::OnMwiInfoParam *arg1 = (pj::OnMwiInfoParam *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  pj::SipRxData *result = 0 ;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__OnMwiInfoParam, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "OnMwiInfoParam_rdata_get" "', argument " "1"" of type '" "pj::OnMwiInfoParam *""'"); 
  }
  arg1 = reinterpret_cast< pj::OnMwiInfoParam * >(argp1);
  result = (pj::SipRxData *)& ((arg1)->rdata);
  resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(result), SWIGTYPE_p_pj__SipRxData, 0 |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_new_OnMwiInfoParam(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::OnMwiInfoParam *result = 0 ;
  
  if (!SWIG_Python_UnpackTuple(args, "new_OnMwiInfoParam", 0, 0, 0)) SWIG_fail;
  result = (pj::OnMwiInfoParam *)new pj::OnMwiInfoParam();
  resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(result), SWIGTYPE_p_pj__OnMwiInfoParam, SWIG_POINTER_NEW |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_delete_OnMwiInfoParam(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::OnMwiInfoParam *arg1 = (pj::OnMwiInfoParam *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__OnMwiInfoParam, SWIG_POINTER_DISOWN |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "delete_OnMwiInfoParam" "', argument " "1"" of type '" "pj::OnMwiInfoParam *""'"); 
  }
  arg1 = reinterpret_cast< pj::OnMwiInfoParam * >(argp1);
  delete arg1;
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *OnMwiInfoParam_swigregister(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *obj;
  if (!SWIG_Python_UnpackTuple(args, "swigregister", 1, 1, &obj)) return NULL;
  SWIG_TypeNewClientData(SWIGTYPE_p_pj__OnMwiInfoParam, SWIG_NewClientData(obj));
  return SWIG_Py_Void();
}

SWIGINTERN PyObject *OnMwiInfoParam_swiginit(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  return SWIG_Python_InitShadowInstance(args);
}

SWIGINTERN PyObject *_wrap_PresNotifyParam_srvPres_set(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::PresNotifyParam *arg1 = (pj::PresNotifyParam *) 0 ;
  void *arg2 = (void *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  int res2 ;
  PyObject *swig_obj[2] ;
  
  if (!SWIG_Python_UnpackTuple(args, "PresNotifyParam_srvPres_set", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__PresNotifyParam, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "PresNotifyParam_srvPres_set" "', argument " "1"" of type '" "pj::PresNotifyParam *""'"); 
  }
  arg1 = reinterpret_cast< pj::PresNotifyParam * >(argp1);
  res2 = SWIG_ConvertPtr(swig_obj[1],SWIG_as_voidptrptr(&arg2), 0, SWIG_POINTER_DISOWN);
  if (!SWIG_IsOK(res2)) {
    SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "PresNotifyParam_srvPres_set" "', argument " "2"" of type '" "void *""'"); 
  }
  if (arg1) (arg1)->srvPres = arg2;
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_PresNotifyParam_srvPres_get(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::PresNotifyParam *arg1 = (pj::PresNotifyParam *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  void *result = 0 ;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__PresNotifyParam, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "PresNotifyParam_srvPres_get" "', argument " "1"" of type '" "pj::PresNotifyParam *""'"); 
  }
  arg1 = reinterpret_cast< pj::PresNotifyParam * >(argp1);
  result = (void *) ((arg1)->srvPres);
  resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(result), SWIGTYPE_p_void, 0 |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_PresNotifyParam_state_set(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::PresNotifyParam *arg1 = (pj::PresNotifyParam *) 0 ;
  pjsip_evsub_state arg2 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  int val2 ;
  int ecode2 = 0 ;
  PyObject *swig_obj[2] ;
  
  if (!SWIG_Python_UnpackTuple(args, "PresNotifyParam_state_set", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__PresNotifyParam, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "PresNotifyParam_state_set" "', argument " "1"" of type '" "pj::PresNotifyParam *""'"); 
  }
  arg1 = reinterpret_cast< pj::PresNotifyParam * >(argp1);
  ecode2 = SWIG_AsVal_int(swig_obj[1], &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "PresNotifyParam_state_set" "', argument " "2"" of type '" "pjsip_evsub_state""'");
  } 
  arg2 = static_cast< pjsip_evsub_state >(val2);
  if (arg1) (arg1)->state = arg2;
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_PresNotifyParam_state_get(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::PresNotifyParam *arg1 = (pj::PresNotifyParam *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  pjsip_evsub_state result;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__PresNotifyParam, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "PresNotifyParam_state_get" "', argument " "1"" of type '" "pj::PresNotifyParam *""'"); 
  }
  arg1 = reinterpret_cast< pj::PresNotifyParam * >(argp1);
  result = (pjsip_evsub_state) ((arg1)->state);
  resultobj = SWIG_From_int(static_cast< int >(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_PresNotifyParam_stateStr_set(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::PresNotifyParam *arg1 = (pj::PresNotifyParam *) 0 ;
  pj::string *arg2 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  int res2 = SWIG_OLDOBJ ;
  PyObject *swig_obj[2] ;
  
  if (!SWIG_Python_UnpackTuple(args, "PresNotifyParam_stateStr_set", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__PresNotifyParam, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "PresNotifyParam_stateStr_set" "', argument " "1"" of type '" "pj::PresNotifyParam *""'"); 
  }
  arg1 = reinterpret_cast< pj::PresNotifyParam * >(argp1);
  {
    std::string *ptr = (std::string *)0;
    res2 = SWIG_AsPtr_std_string(swig_obj[1], &ptr);
    if (!SWIG_IsOK(res2)) {
      SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "PresNotifyParam_stateStr_set" "', argument " "2"" of type '" "pj::string const &""'"); 
    }
    if (!ptr) {
      SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "PresNotifyParam_stateStr_set" "', argument " "2"" of type '" "pj::string const &""'"); 
    }
    arg2 = ptr;
  }
  if (arg1) (arg1)->stateStr = *arg2;
  resultobj = SWIG_Py_Void();
  if (SWIG_IsNewObj(res2)) delete arg2;
  return resultobj;
fail:
  if (SWIG_IsNewObj(res2)) delete arg2;
  return NULL;
}


SWIGINTERN PyObject *_wrap_PresNotifyParam_stateStr_get(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::PresNotifyParam *arg1 = (pj::PresNotifyParam *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  pj::string *result = 0 ;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__PresNotifyParam, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "PresNotifyParam_stateStr_get" "', argument " "1"" of type '" "pj::PresNotifyParam *""'"); 
  }
  arg1 = reinterpret_cast< pj::PresNotifyParam * >(argp1);
  result = (pj::string *) & ((arg1)->stateStr);
  resultobj = SWIG_From_std_string(static_cast< std::string >(*result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_PresNotifyParam_reason_set(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::PresNotifyParam *arg1 = (pj::PresNotifyParam *) 0 ;
  pj::string *arg2 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  int res2 = SWIG_OLDOBJ ;
  PyObject *swig_obj[2] ;
  
  if (!SWIG_Python_UnpackTuple(args, "PresNotifyParam_reason_set", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__PresNotifyParam, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "PresNotifyParam_reason_set" "', argument " "1"" of type '" "pj::PresNotifyParam *""'"); 
  }
  arg1 = reinterpret_cast< pj::PresNotifyParam * >(argp1);
  {
    std::string *ptr = (std::string *)0;
    res2 = SWIG_AsPtr_std_string(swig_obj[1], &ptr);
    if (!SWIG_IsOK(res2)) {
      SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "PresNotifyParam_reason_set" "', argument " "2"" of type '" "pj::string const &""'"); 
    }
    if (!ptr) {
      SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "PresNotifyParam_reason_set" "', argument " "2"" of type '" "pj::string const &""'"); 
    }
    arg2 = ptr;
  }
  if (arg1) (arg1)->reason = *arg2;
  resultobj = SWIG_Py_Void();
  if (SWIG_IsNewObj(res2)) delete arg2;
  return resultobj;
fail:
  if (SWIG_IsNewObj(res2)) delete arg2;
  return NULL;
}


SWIGINTERN PyObject *_wrap_PresNotifyParam_reason_get(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::PresNotifyParam *arg1 = (pj::PresNotifyParam *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  pj::string *result = 0 ;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__PresNotifyParam, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "PresNotifyParam_reason_get" "', argument " "1"" of type '" "pj::PresNotifyParam *""'"); 
  }
  arg1 = reinterpret_cast< pj::PresNotifyParam * >(argp1);
  result = (pj::string *) & ((arg1)->reason);
  resultobj = SWIG_From_std_string(static_cast< std::string >(*result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_PresNotifyParam_withBody_set(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::PresNotifyParam *arg1 = (pj::PresNotifyParam *) 0 ;
  bool arg2 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  bool val2 ;
  int ecode2 = 0 ;
  PyObject *swig_obj[2] ;
  
  if (!SWIG_Python_UnpackTuple(args, "PresNotifyParam_withBody_set", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__PresNotifyParam, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "PresNotifyParam_withBody_set" "', argument " "1"" of type '" "pj::PresNotifyParam *""'"); 
  }
  arg1 = reinterpret_cast< pj::PresNotifyParam * >(argp1);
  ecode2 = SWIG_AsVal_bool(swig_obj[1], &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "PresNotifyParam_withBody_set" "', argument " "2"" of type '" "bool""'");
  } 
  arg2 = static_cast< bool >(val2);
  if (arg1) (arg1)->withBody = arg2;
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_PresNotifyParam_withBody_get(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::PresNotifyParam *arg1 = (pj::PresNotifyParam *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  bool result;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__PresNotifyParam, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "PresNotifyParam_withBody_get" "', argument " "1"" of type '" "pj::PresNotifyParam *""'"); 
  }
  arg1 = reinterpret_cast< pj::PresNotifyParam * >(argp1);
  result = (bool) ((arg1)->withBody);
  resultobj = SWIG_From_bool(static_cast< bool >(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_PresNotifyParam_txOption_set(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::PresNotifyParam *arg1 = (pj::PresNotifyParam *) 0 ;
  pj::SipTxOption *arg2 = (pj::SipTxOption *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  void *argp2 = 0 ;
  int res2 = 0 ;
  PyObject *swig_obj[2] ;
  
  if (!SWIG_Python_UnpackTuple(args, "PresNotifyParam_txOption_set", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__PresNotifyParam, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "PresNotifyParam_txOption_set" "', argument " "1"" of type '" "pj::PresNotifyParam *""'"); 
  }
  arg1 = reinterpret_cast< pj::PresNotifyParam * >(argp1);
  res2 = SWIG_ConvertPtr(swig_obj[1], &argp2,SWIGTYPE_p_pj__SipTxOption, 0 |  0 );
  if (!SWIG_IsOK(res2)) {
    SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "PresNotifyParam_txOption_set" "', argument " "2"" of type '" "pj::SipTxOption *""'"); 
  }
  arg2 = reinterpret_cast< pj::SipTxOption * >(argp2);
  if (arg1) (arg1)->txOption = *arg2;
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_PresNotifyParam_txOption_get(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::PresNotifyParam *arg1 = (pj::PresNotifyParam *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  pj::SipTxOption *result = 0 ;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__PresNotifyParam, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "PresNotifyParam_txOption_get" "', argument " "1"" of type '" "pj::PresNotifyParam *""'"); 
  }
  arg1 = reinterpret_cast< pj::PresNotifyParam * >(argp1);
  result = (pj::SipTxOption *)& ((arg1)->txOption);
  resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(result), SWIGTYPE_p_pj__SipTxOption, 0 |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_new_PresNotifyParam(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::PresNotifyParam *result = 0 ;
  
  if (!SWIG_Python_UnpackTuple(args, "new_PresNotifyParam", 0, 0, 0)) SWIG_fail;
  result = (pj::PresNotifyParam *)new pj::PresNotifyParam();
  resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(result), SWIGTYPE_p_pj__PresNotifyParam, SWIG_POINTER_NEW |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_delete_PresNotifyParam(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::PresNotifyParam *arg1 = (pj::PresNotifyParam *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__PresNotifyParam, SWIG_POINTER_DISOWN |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "delete_PresNotifyParam" "', argument " "1"" of type '" "pj::PresNotifyParam *""'"); 
  }
  arg1 = reinterpret_cast< pj::PresNotifyParam * >(argp1);
  delete arg1;
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *PresNotifyParam_swigregister(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *obj;
  if (!SWIG_Python_UnpackTuple(args, "swigregister", 1, 1, &obj)) return NULL;
  SWIG_TypeNewClientData(SWIGTYPE_p_pj__PresNotifyParam, SWIG_NewClientData(obj));
  return SWIG_Py_Void();
}

SWIGINTERN PyObject *PresNotifyParam_swiginit(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  return SWIG_Python_InitShadowInstance(args);
}

SWIGINTERN PyObject *_wrap_FindBuddyMatch_match(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::FindBuddyMatch *arg1 = (pj::FindBuddyMatch *) 0 ;
  pj::string *arg2 = 0 ;
  pj::Buddy *arg3 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  int res2 = SWIG_OLDOBJ ;
  void *argp3 = 0 ;
  int res3 = 0 ;
  PyObject *swig_obj[3] ;
  Swig::Director *director = 0;
  bool upcall = false;
  bool result;
  
  if (!SWIG_Python_UnpackTuple(args, "FindBuddyMatch_match", 3, 3, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__FindBuddyMatch, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "FindBuddyMatch_match" "', argument " "1"" of type '" "pj::FindBuddyMatch *""'"); 
  }
  arg1 = reinterpret_cast< pj::FindBuddyMatch * >(argp1);
  {
    std::string *ptr = (std::string *)0;
    res2 = SWIG_AsPtr_std_string(swig_obj[1], &ptr);
    if (!SWIG_IsOK(res2)) {
      SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "FindBuddyMatch_match" "', argument " "2"" of type '" "pj::string const &""'"); 
    }
    if (!ptr) {
      SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "FindBuddyMatch_match" "', argument " "2"" of type '" "pj::string const &""'"); 
    }
    arg2 = ptr;
  }
  res3 = SWIG_ConvertPtr(swig_obj[2], &argp3, SWIGTYPE_p_pj__Buddy,  0  | 0);
  if (!SWIG_IsOK(res3)) {
    SWIG_exception_fail(SWIG_ArgError(res3), "in method '" "FindBuddyMatch_match" "', argument " "3"" of type '" "pj::Buddy const &""'"); 
  }
  if (!argp3) {
    SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "FindBuddyMatch_match" "', argument " "3"" of type '" "pj::Buddy const &""'"); 
  }
  arg3 = reinterpret_cast< pj::Buddy * >(argp3);
  director = SWIG_DIRECTOR_CAST(arg1);
  upcall = (director && (director->swig_get_self()==swig_obj[0]));
  try {
    if (upcall) {
      result = (bool)(arg1)->pj::FindBuddyMatch::match((pj::string const &)*arg2,(pj::Buddy const &)*arg3);
    } else {
      result = (bool)(arg1)->match((pj::string const &)*arg2,(pj::Buddy const &)*arg3);
    }
  } catch (Swig::DirectorException&) {
    SWIG_fail;
  }
  resultobj = SWIG_From_bool(static_cast< bool >(result));
  if (SWIG_IsNewObj(res2)) delete arg2;
  return resultobj;
fail:
  if (SWIG_IsNewObj(res2)) delete arg2;
  return NULL;
}


SWIGINTERN PyObject *_wrap_delete_FindBuddyMatch(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::FindBuddyMatch *arg1 = (pj::FindBuddyMatch *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__FindBuddyMatch, SWIG_POINTER_DISOWN |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "delete_FindBuddyMatch" "', argument " "1"" of type '" "pj::FindBuddyMatch *""'"); 
  }
  arg1 = reinterpret_cast< pj::FindBuddyMatch * >(argp1);
  delete arg1;
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_new_FindBuddyMatch(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  PyObject *arg1 = (PyObject *) 0 ;
  PyObject *swig_obj[1] ;
  pj::FindBuddyMatch *result = 0 ;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  arg1 = swig_obj[0];
  if ( arg1 != Py_None ) {
    /* subclassed */
    result = (pj::FindBuddyMatch *)new SwigDirector_FindBuddyMatch(arg1); 
  } else {
    result = (pj::FindBuddyMatch *)new pj::FindBuddyMatch(); 
  }
  
  resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(result), SWIGTYPE_p_pj__FindBuddyMatch, SWIG_POINTER_NEW |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_disown_FindBuddyMatch(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::FindBuddyMatch *arg1 = (pj::FindBuddyMatch *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__FindBuddyMatch, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "disown_FindBuddyMatch" "', argument " "1"" of type '" "pj::FindBuddyMatch *""'"); 
  }
  arg1 = reinterpret_cast< pj::FindBuddyMatch * >(argp1);
  {
    Swig::Director *director = SWIG_DIRECTOR_CAST(arg1);
    if (director) director->swig_disown();
  }
  
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *FindBuddyMatch_swigregister(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *obj;
  if (!SWIG_Python_UnpackTuple(args, "swigregister", 1, 1, &obj)) return NULL;
  SWIG_TypeNewClientData(SWIGTYPE_p_pj__FindBuddyMatch, SWIG_NewClientData(obj));
  return SWIG_Py_Void();
}

SWIGINTERN PyObject *FindBuddyMatch_swiginit(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  return SWIG_Python_InitShadowInstance(args);
}

SWIGINTERN PyObject *_wrap_new_Account(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  PyObject *arg1 = (PyObject *) 0 ;
  PyObject *swig_obj[1] ;
  pj::Account *result = 0 ;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  arg1 = swig_obj[0];
  if ( arg1 != Py_None ) {
    /* subclassed */
    result = (pj::Account *)new SwigDirector_Account(arg1); 
  } else {
    result = (pj::Account *)new pj::Account(); 
  }
  
  resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(result), SWIGTYPE_p_pj__Account, SWIG_POINTER_NEW |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_delete_Account(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::Account *arg1 = (pj::Account *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__Account, SWIG_POINTER_DISOWN |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "delete_Account" "', argument " "1"" of type '" "pj::Account *""'"); 
  }
  arg1 = reinterpret_cast< pj::Account * >(argp1);
  delete arg1;
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_Account_create__SWIG_0(PyObject *SWIGUNUSEDPARM(self), Py_ssize_t nobjs, PyObject **swig_obj) {
  PyObject *resultobj = 0;
  pj::Account *arg1 = (pj::Account *) 0 ;
  pj::AccountConfig *arg2 = 0 ;
  bool arg3 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  void *argp2 = 0 ;
  int res2 = 0 ;
  bool val3 ;
  int ecode3 = 0 ;
  
  if ((nobjs < 3) || (nobjs > 3)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__Account, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "Account_create" "', argument " "1"" of type '" "pj::Account *""'"); 
  }
  arg1 = reinterpret_cast< pj::Account * >(argp1);
  res2 = SWIG_ConvertPtr(swig_obj[1], &argp2, SWIGTYPE_p_pj__AccountConfig,  0  | 0);
  if (!SWIG_IsOK(res2)) {
    SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "Account_create" "', argument " "2"" of type '" "pj::AccountConfig const &""'"); 
  }
  if (!argp2) {
    SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "Account_create" "', argument " "2"" of type '" "pj::AccountConfig const &""'"); 
  }
  arg2 = reinterpret_cast< pj::AccountConfig * >(argp2);
  ecode3 = SWIG_AsVal_bool(swig_obj[2], &val3);
  if (!SWIG_IsOK(ecode3)) {
    SWIG_exception_fail(SWIG_ArgError(ecode3), "in method '" "Account_create" "', argument " "3"" of type '" "bool""'");
  } 
  arg3 = static_cast< bool >(val3);
  try {
    (arg1)->create((pj::AccountConfig const &)*arg2,arg3);
  } catch(pj::Error &_e) {
    SWIG_Python_Raise(SWIG_NewPointerObj((new pj::Error(static_cast< const pj::Error& >(_e))),SWIGTYPE_p_pj__Error,SWIG_POINTER_OWN), "pj::Error", SWIGTYPE_p_pj__Error); SWIG_fail;
  }
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_Account_create__SWIG_1(PyObject *SWIGUNUSEDPARM(self), Py_ssize_t nobjs, PyObject **swig_obj) {
  PyObject *resultobj = 0;
  pj::Account *arg1 = (pj::Account *) 0 ;
  pj::AccountConfig *arg2 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  void *argp2 = 0 ;
  int res2 = 0 ;
  
  if ((nobjs < 2) || (nobjs > 2)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__Account, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "Account_create" "', argument " "1"" of type '" "pj::Account *""'"); 
  }
  arg1 = reinterpret_cast< pj::Account * >(argp1);
  res2 = SWIG_ConvertPtr(swig_obj[1], &argp2, SWIGTYPE_p_pj__AccountConfig,  0  | 0);
  if (!SWIG_IsOK(res2)) {
    SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "Account_create" "', argument " "2"" of type '" "pj::AccountConfig const &""'"); 
  }
  if (!argp2) {
    SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "Account_create" "', argument " "2"" of type '" "pj::AccountConfig const &""'"); 
  }
  arg2 = reinterpret_cast< pj::AccountConfig * >(argp2);
  try {
    (arg1)->create((pj::AccountConfig const &)*arg2);
  } catch(pj::Error &_e) {
    SWIG_Python_Raise(SWIG_NewPointerObj((new pj::Error(static_cast< const pj::Error& >(_e))),SWIGTYPE_p_pj__Error,SWIG_POINTER_OWN), "pj::Error", SWIGTYPE_p_pj__Error); SWIG_fail;
  }
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_Account_create(PyObject *self, PyObject *args) {
  Py_ssize_t argc;
  PyObject *argv[4] = {
    0
  };
  
  if (!(argc = SWIG_Python_UnpackTuple(args, "Account_create", 0, 3, argv))) SWIG_fail;
  --argc;
  if (argc == 2) {
    int _v;
    void *vptr = 0;
    int res = SWIG_ConvertPtr(argv[0], &vptr, SWIGTYPE_p_pj__Account, 0);
    _v = SWIG_CheckState(res);
    if (_v) {
      int res = SWIG_ConvertPtr(argv[1], 0, SWIGTYPE_p_pj__AccountConfig, SWIG_POINTER_NO_NULL | 0);
      _v = SWIG_CheckState(res);
      if (_v) {
        return _wrap_Account_create__SWIG_1(self, argc, argv);
      }
    }
  }
  if (argc == 3) {
    int _v;
    void *vptr = 0;
    int res = SWIG_ConvertPtr(argv[0], &vptr, SWIGTYPE_p_pj__Account, 0);
    _v = SWIG_CheckState(res);
    if (_v) {
      int res = SWIG_ConvertPtr(argv[1], 0, SWIGTYPE_p_pj__AccountConfig, SWIG_POINTER_NO_NULL | 0);
      _v = SWIG_CheckState(res);
      if (_v) {
        {
          int res = SWIG_AsVal_bool(argv[2], NULL);
          _v = SWIG_CheckState(res);
        }
        if (_v) {
          return _wrap_Account_create__SWIG_0(self, argc, argv);
        }
      }
    }
  }
  
fail:
  SWIG_Python_RaiseOrModifyTypeError("Wrong number or type of arguments for overloaded function 'Account_create'.\n"
    "  Possible C/C++ prototypes are:\n"
    "    pj::Account::create(pj::AccountConfig const &,bool)\n"
    "    pj::Account::create(pj::AccountConfig const &)\n");
  return 0;
}


SWIGINTERN PyObject *_wrap_Account_shutdown(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::Account *arg1 = (pj::Account *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__Account, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "Account_shutdown" "', argument " "1"" of type '" "pj::Account *""'"); 
  }
  arg1 = reinterpret_cast< pj::Account * >(argp1);
  (arg1)->shutdown();
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_Account_modify(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::Account *arg1 = (pj::Account *) 0 ;
  pj::AccountConfig *arg2 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  void *argp2 = 0 ;
  int res2 = 0 ;
  PyObject *swig_obj[2] ;
  
  if (!SWIG_Python_UnpackTuple(args, "Account_modify", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__Account, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "Account_modify" "', argument " "1"" of type '" "pj::Account *""'"); 
  }
  arg1 = reinterpret_cast< pj::Account * >(argp1);
  res2 = SWIG_ConvertPtr(swig_obj[1], &argp2, SWIGTYPE_p_pj__AccountConfig,  0  | 0);
  if (!SWIG_IsOK(res2)) {
    SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "Account_modify" "', argument " "2"" of type '" "pj::AccountConfig const &""'"); 
  }
  if (!argp2) {
    SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "Account_modify" "', argument " "2"" of type '" "pj::AccountConfig const &""'"); 
  }
  arg2 = reinterpret_cast< pj::AccountConfig * >(argp2);
  try {
    (arg1)->modify((pj::AccountConfig const &)*arg2);
  } catch(pj::Error &_e) {
    SWIG_Python_Raise(SWIG_NewPointerObj((new pj::Error(static_cast< const pj::Error& >(_e))),SWIGTYPE_p_pj__Error,SWIG_POINTER_OWN), "pj::Error", SWIGTYPE_p_pj__Error); SWIG_fail;
  }
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_Account_isValid(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::Account *arg1 = (pj::Account *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  bool result;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__Account, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "Account_isValid" "', argument " "1"" of type '" "pj::Account const *""'"); 
  }
  arg1 = reinterpret_cast< pj::Account * >(argp1);
  result = (bool)((pj::Account const *)arg1)->isValid();
  resultobj = SWIG_From_bool(static_cast< bool >(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_Account_setDefault(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::Account *arg1 = (pj::Account *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__Account, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "Account_setDefault" "', argument " "1"" of type '" "pj::Account *""'"); 
  }
  arg1 = reinterpret_cast< pj::Account * >(argp1);
  try {
    (arg1)->setDefault();
  } catch(pj::Error &_e) {
    SWIG_Python_Raise(SWIG_NewPointerObj((new pj::Error(static_cast< const pj::Error& >(_e))),SWIGTYPE_p_pj__Error,SWIG_POINTER_OWN), "pj::Error", SWIGTYPE_p_pj__Error); SWIG_fail;
  }
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_Account_isDefault(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::Account *arg1 = (pj::Account *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  bool result;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__Account, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "Account_isDefault" "', argument " "1"" of type '" "pj::Account const *""'"); 
  }
  arg1 = reinterpret_cast< pj::Account * >(argp1);
  result = (bool)((pj::Account const *)arg1)->isDefault();
  resultobj = SWIG_From_bool(static_cast< bool >(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_Account_getId(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::Account *arg1 = (pj::Account *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  int result;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__Account, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "Account_getId" "', argument " "1"" of type '" "pj::Account const *""'"); 
  }
  arg1 = reinterpret_cast< pj::Account * >(argp1);
  result = (int)((pj::Account const *)arg1)->getId();
  resultobj = SWIG_From_int(static_cast< int >(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_Account_lookup(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  int arg1 ;
  int val1 ;
  int ecode1 = 0 ;
  PyObject *swig_obj[1] ;
  Swig::Director *director = 0;
  pj::Account *result = 0 ;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  ecode1 = SWIG_AsVal_int(swig_obj[0], &val1);
  if (!SWIG_IsOK(ecode1)) {
    SWIG_exception_fail(SWIG_ArgError(ecode1), "in method '" "Account_lookup" "', argument " "1"" of type '" "int""'");
  } 
  arg1 = static_cast< int >(val1);
  result = (pj::Account *)pj::Account::lookup(arg1);
  director = SWIG_DIRECTOR_CAST(result);
  if (director) {
    resultobj = director->swig_get_self();
    Py_INCREF(resultobj);
  } else {
    resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(result), SWIGTYPE_p_pj__Account, 0 |  0 );
  }
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_Account_getInfo(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::Account *arg1 = (pj::Account *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  pj::AccountInfo result;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__Account, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "Account_getInfo" "', argument " "1"" of type '" "pj::Account const *""'"); 
  }
  arg1 = reinterpret_cast< pj::Account * >(argp1);
  try {
    result = ((pj::Account const *)arg1)->getInfo();
  } catch(pj::Error &_e) {
    SWIG_Python_Raise(SWIG_NewPointerObj((new pj::Error(static_cast< const pj::Error& >(_e))),SWIGTYPE_p_pj__Error,SWIG_POINTER_OWN), "pj::Error", SWIGTYPE_p_pj__Error); SWIG_fail;
  }
  resultobj = SWIG_NewPointerObj((new pj::AccountInfo(static_cast< const pj::AccountInfo& >(result))), SWIGTYPE_p_pj__AccountInfo, SWIG_POINTER_OWN |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_Account_setRegistration(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::Account *arg1 = (pj::Account *) 0 ;
  bool arg2 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  bool val2 ;
  int ecode2 = 0 ;
  PyObject *swig_obj[2] ;
  
  if (!SWIG_Python_UnpackTuple(args, "Account_setRegistration", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__Account, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "Account_setRegistration" "', argument " "1"" of type '" "pj::Account *""'"); 
  }
  arg1 = reinterpret_cast< pj::Account * >(argp1);
  ecode2 = SWIG_AsVal_bool(swig_obj[1], &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "Account_setRegistration" "', argument " "2"" of type '" "bool""'");
  } 
  arg2 = static_cast< bool >(val2);
  try {
    (arg1)->setRegistration(arg2);
  } catch(pj::Error &_e) {
    SWIG_Python_Raise(SWIG_NewPointerObj((new pj::Error(static_cast< const pj::Error& >(_e))),SWIGTYPE_p_pj__Error,SWIG_POINTER_OWN), "pj::Error", SWIGTYPE_p_pj__Error); SWIG_fail;
  }
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_Account_setOnlineStatus(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::Account *arg1 = (pj::Account *) 0 ;
  pj::PresenceStatus *arg2 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  void *argp2 = 0 ;
  int res2 = 0 ;
  PyObject *swig_obj[2] ;
  
  if (!SWIG_Python_UnpackTuple(args, "Account_setOnlineStatus", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__Account, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "Account_setOnlineStatus" "', argument " "1"" of type '" "pj::Account *""'"); 
  }
  arg1 = reinterpret_cast< pj::Account * >(argp1);
  res2 = SWIG_ConvertPtr(swig_obj[1], &argp2, SWIGTYPE_p_pj__PresenceStatus,  0  | 0);
  if (!SWIG_IsOK(res2)) {
    SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "Account_setOnlineStatus" "', argument " "2"" of type '" "pj::PresenceStatus const &""'"); 
  }
  if (!argp2) {
    SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "Account_setOnlineStatus" "', argument " "2"" of type '" "pj::PresenceStatus const &""'"); 
  }
  arg2 = reinterpret_cast< pj::PresenceStatus * >(argp2);
  try {
    (arg1)->setOnlineStatus((pj::PresenceStatus const &)*arg2);
  } catch(pj::Error &_e) {
    SWIG_Python_Raise(SWIG_NewPointerObj((new pj::Error(static_cast< const pj::Error& >(_e))),SWIGTYPE_p_pj__Error,SWIG_POINTER_OWN), "pj::Error", SWIGTYPE_p_pj__Error); SWIG_fail;
  }
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_Account_setTransport(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::Account *arg1 = (pj::Account *) 0 ;
  pj::TransportId arg2 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  int val2 ;
  int ecode2 = 0 ;
  PyObject *swig_obj[2] ;
  
  if (!SWIG_Python_UnpackTuple(args, "Account_setTransport", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__Account, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "Account_setTransport" "', argument " "1"" of type '" "pj::Account *""'"); 
  }
  arg1 = reinterpret_cast< pj::Account * >(argp1);
  ecode2 = SWIG_AsVal_int(swig_obj[1], &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "Account_setTransport" "', argument " "2"" of type '" "pj::TransportId""'");
  } 
  arg2 = static_cast< pj::TransportId >(val2);
  try {
    (arg1)->setTransport(arg2);
  } catch(pj::Error &_e) {
    SWIG_Python_Raise(SWIG_NewPointerObj((new pj::Error(static_cast< const pj::Error& >(_e))),SWIGTYPE_p_pj__Error,SWIG_POINTER_OWN), "pj::Error", SWIGTYPE_p_pj__Error); SWIG_fail;
  }
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_Account_presNotify(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::Account *arg1 = (pj::Account *) 0 ;
  pj::PresNotifyParam *arg2 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  void *argp2 = 0 ;
  int res2 = 0 ;
  PyObject *swig_obj[2] ;
  
  if (!SWIG_Python_UnpackTuple(args, "Account_presNotify", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__Account, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "Account_presNotify" "', argument " "1"" of type '" "pj::Account *""'"); 
  }
  arg1 = reinterpret_cast< pj::Account * >(argp1);
  res2 = SWIG_ConvertPtr(swig_obj[1], &argp2, SWIGTYPE_p_pj__PresNotifyParam,  0  | 0);
  if (!SWIG_IsOK(res2)) {
    SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "Account_presNotify" "', argument " "2"" of type '" "pj::PresNotifyParam const &""'"); 
  }
  if (!argp2) {
    SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "Account_presNotify" "', argument " "2"" of type '" "pj::PresNotifyParam const &""'"); 
  }
  arg2 = reinterpret_cast< pj::PresNotifyParam * >(argp2);
  try {
    (arg1)->presNotify((pj::PresNotifyParam const &)*arg2);
  } catch(pj::Error &_e) {
    SWIG_Python_Raise(SWIG_NewPointerObj((new pj::Error(static_cast< const pj::Error& >(_e))),SWIGTYPE_p_pj__Error,SWIG_POINTER_OWN), "pj::Error", SWIGTYPE_p_pj__Error); SWIG_fail;
  }
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_Account_enumBuddies2(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::Account *arg1 = (pj::Account *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  pj::BuddyVector2 result;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__Account, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "Account_enumBuddies2" "', argument " "1"" of type '" "pj::Account const *""'"); 
  }
  arg1 = reinterpret_cast< pj::Account * >(argp1);
  try {
    result = ((pj::Account const *)arg1)->enumBuddies2();
  } catch(pj::Error &_e) {
    SWIG_Python_Raise(SWIG_NewPointerObj((new pj::Error(static_cast< const pj::Error& >(_e))),SWIGTYPE_p_pj__Error,SWIG_POINTER_OWN), "pj::Error", SWIGTYPE_p_pj__Error); SWIG_fail;
  }
  resultobj = swig::from(static_cast< std::vector< pj::Buddy,std::allocator< pj::Buddy > > >(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_Account_findBuddy2(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::Account *arg1 = (pj::Account *) 0 ;
  pj::string arg2 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[2] ;
  pj::Buddy result;
  
  if (!SWIG_Python_UnpackTuple(args, "Account_findBuddy2", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__Account, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "Account_findBuddy2" "', argument " "1"" of type '" "pj::Account const *""'"); 
  }
  arg1 = reinterpret_cast< pj::Account * >(argp1);
  {
    std::string *ptr = (std::string *)0;
    int res = SWIG_AsPtr_std_string(swig_obj[1], &ptr);
    if (!SWIG_IsOK(res) || !ptr) {
      SWIG_exception_fail(SWIG_ArgError((ptr ? res : SWIG_TypeError)), "in method '" "Account_findBuddy2" "', argument " "2"" of type '" "pj::string""'"); 
    }
    arg2 = *ptr;
    if (SWIG_IsNewObj(res)) delete ptr;
  }
  try {
    result = ((pj::Account const *)arg1)->findBuddy2(arg2);
  } catch(pj::Error &_e) {
    SWIG_Python_Raise(SWIG_NewPointerObj((new pj::Error(static_cast< const pj::Error& >(_e))),SWIGTYPE_p_pj__Error,SWIG_POINTER_OWN), "pj::Error", SWIGTYPE_p_pj__Error); SWIG_fail;
  }
  resultobj = SWIG_NewPointerObj((new pj::Buddy(static_cast< const pj::Buddy& >(result))), SWIGTYPE_p_pj__Buddy, SWIG_POINTER_OWN |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_Account_onIncomingCall(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::Account *arg1 = (pj::Account *) 0 ;
  pj::OnIncomingCallParam *arg2 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  void *argp2 = 0 ;
  int res2 = 0 ;
  PyObject *swig_obj[2] ;
  Swig::Director *director = 0;
  bool upcall = false;
  
  if (!SWIG_Python_UnpackTuple(args, "Account_onIncomingCall", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__Account, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "Account_onIncomingCall" "', argument " "1"" of type '" "pj::Account *""'"); 
  }
  arg1 = reinterpret_cast< pj::Account * >(argp1);
  res2 = SWIG_ConvertPtr(swig_obj[1], &argp2, SWIGTYPE_p_pj__OnIncomingCallParam,  0 );
  if (!SWIG_IsOK(res2)) {
    SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "Account_onIncomingCall" "', argument " "2"" of type '" "pj::OnIncomingCallParam &""'"); 
  }
  if (!argp2) {
    SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "Account_onIncomingCall" "', argument " "2"" of type '" "pj::OnIncomingCallParam &""'"); 
  }
  arg2 = reinterpret_cast< pj::OnIncomingCallParam * >(argp2);
  director = SWIG_DIRECTOR_CAST(arg1);
  upcall = (director && (director->swig_get_self()==swig_obj[0]));
  try {
    if (upcall) {
      (arg1)->pj::Account::onIncomingCall(*arg2);
    } else {
      (arg1)->onIncomingCall(*arg2);
    }
  } catch (Swig::DirectorException&) {
    SWIG_fail;
  }
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_Account_onRegStarted(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::Account *arg1 = (pj::Account *) 0 ;
  pj::OnRegStartedParam *arg2 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  void *argp2 = 0 ;
  int res2 = 0 ;
  PyObject *swig_obj[2] ;
  Swig::Director *director = 0;
  bool upcall = false;
  
  if (!SWIG_Python_UnpackTuple(args, "Account_onRegStarted", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__Account, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "Account_onRegStarted" "', argument " "1"" of type '" "pj::Account *""'"); 
  }
  arg1 = reinterpret_cast< pj::Account * >(argp1);
  res2 = SWIG_ConvertPtr(swig_obj[1], &argp2, SWIGTYPE_p_pj__OnRegStartedParam,  0 );
  if (!SWIG_IsOK(res2)) {
    SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "Account_onRegStarted" "', argument " "2"" of type '" "pj::OnRegStartedParam &""'"); 
  }
  if (!argp2) {
    SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "Account_onRegStarted" "', argument " "2"" of type '" "pj::OnRegStartedParam &""'"); 
  }
  arg2 = reinterpret_cast< pj::OnRegStartedParam * >(argp2);
  director = SWIG_DIRECTOR_CAST(arg1);
  upcall = (director && (director->swig_get_self()==swig_obj[0]));
  try {
    if (upcall) {
      (arg1)->pj::Account::onRegStarted(*arg2);
    } else {
      (arg1)->onRegStarted(*arg2);
    }
  } catch (Swig::DirectorException&) {
    SWIG_fail;
  }
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_Account_onRegState(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::Account *arg1 = (pj::Account *) 0 ;
  pj::OnRegStateParam *arg2 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  void *argp2 = 0 ;
  int res2 = 0 ;
  PyObject *swig_obj[2] ;
  Swig::Director *director = 0;
  bool upcall = false;
  
  if (!SWIG_Python_UnpackTuple(args, "Account_onRegState", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__Account, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "Account_onRegState" "', argument " "1"" of type '" "pj::Account *""'"); 
  }
  arg1 = reinterpret_cast< pj::Account * >(argp1);
  res2 = SWIG_ConvertPtr(swig_obj[1], &argp2, SWIGTYPE_p_pj__OnRegStateParam,  0 );
  if (!SWIG_IsOK(res2)) {
    SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "Account_onRegState" "', argument " "2"" of type '" "pj::OnRegStateParam &""'"); 
  }
  if (!argp2) {
    SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "Account_onRegState" "', argument " "2"" of type '" "pj::OnRegStateParam &""'"); 
  }
  arg2 = reinterpret_cast< pj::OnRegStateParam * >(argp2);
  director = SWIG_DIRECTOR_CAST(arg1);
  upcall = (director && (director->swig_get_self()==swig_obj[0]));
  try {
    if (upcall) {
      (arg1)->pj::Account::onRegState(*arg2);
    } else {
      (arg1)->onRegState(*arg2);
    }
  } catch (Swig::DirectorException&) {
    SWIG_fail;
  }
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_Account_onIncomingSubscribe(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::Account *arg1 = (pj::Account *) 0 ;
  pj::OnIncomingSubscribeParam *arg2 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  void *argp2 = 0 ;
  int res2 = 0 ;
  PyObject *swig_obj[2] ;
  Swig::Director *director = 0;
  bool upcall = false;
  
  if (!SWIG_Python_UnpackTuple(args, "Account_onIncomingSubscribe", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__Account, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "Account_onIncomingSubscribe" "', argument " "1"" of type '" "pj::Account *""'"); 
  }
  arg1 = reinterpret_cast< pj::Account * >(argp1);
  res2 = SWIG_ConvertPtr(swig_obj[1], &argp2, SWIGTYPE_p_pj__OnIncomingSubscribeParam,  0 );
  if (!SWIG_IsOK(res2)) {
    SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "Account_onIncomingSubscribe" "', argument " "2"" of type '" "pj::OnIncomingSubscribeParam &""'"); 
  }
  if (!argp2) {
    SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "Account_onIncomingSubscribe" "', argument " "2"" of type '" "pj::OnIncomingSubscribeParam &""'"); 
  }
  arg2 = reinterpret_cast< pj::OnIncomingSubscribeParam * >(argp2);
  director = SWIG_DIRECTOR_CAST(arg1);
  upcall = (director && (director->swig_get_self()==swig_obj[0]));
  try {
    if (upcall) {
      (arg1)->pj::Account::onIncomingSubscribe(*arg2);
    } else {
      (arg1)->onIncomingSubscribe(*arg2);
    }
  } catch (Swig::DirectorException&) {
    SWIG_fail;
  }
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_Account_onInstantMessage(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::Account *arg1 = (pj::Account *) 0 ;
  pj::OnInstantMessageParam *arg2 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  void *argp2 = 0 ;
  int res2 = 0 ;
  PyObject *swig_obj[2] ;
  Swig::Director *director = 0;
  bool upcall = false;
  
  if (!SWIG_Python_UnpackTuple(args, "Account_onInstantMessage", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__Account, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "Account_onInstantMessage" "', argument " "1"" of type '" "pj::Account *""'"); 
  }
  arg1 = reinterpret_cast< pj::Account * >(argp1);
  res2 = SWIG_ConvertPtr(swig_obj[1], &argp2, SWIGTYPE_p_pj__OnInstantMessageParam,  0 );
  if (!SWIG_IsOK(res2)) {
    SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "Account_onInstantMessage" "', argument " "2"" of type '" "pj::OnInstantMessageParam &""'"); 
  }
  if (!argp2) {
    SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "Account_onInstantMessage" "', argument " "2"" of type '" "pj::OnInstantMessageParam &""'"); 
  }
  arg2 = reinterpret_cast< pj::OnInstantMessageParam * >(argp2);
  director = SWIG_DIRECTOR_CAST(arg1);
  upcall = (director && (director->swig_get_self()==swig_obj[0]));
  try {
    if (upcall) {
      (arg1)->pj::Account::onInstantMessage(*arg2);
    } else {
      (arg1)->onInstantMessage(*arg2);
    }
  } catch (Swig::DirectorException&) {
    SWIG_fail;
  }
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_Account_onInstantMessageStatus(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::Account *arg1 = (pj::Account *) 0 ;
  pj::OnInstantMessageStatusParam *arg2 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  void *argp2 = 0 ;
  int res2 = 0 ;
  PyObject *swig_obj[2] ;
  Swig::Director *director = 0;
  bool upcall = false;
  
  if (!SWIG_Python_UnpackTuple(args, "Account_onInstantMessageStatus", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__Account, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "Account_onInstantMessageStatus" "', argument " "1"" of type '" "pj::Account *""'"); 
  }
  arg1 = reinterpret_cast< pj::Account * >(argp1);
  res2 = SWIG_ConvertPtr(swig_obj[1], &argp2, SWIGTYPE_p_pj__OnInstantMessageStatusParam,  0 );
  if (!SWIG_IsOK(res2)) {
    SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "Account_onInstantMessageStatus" "', argument " "2"" of type '" "pj::OnInstantMessageStatusParam &""'"); 
  }
  if (!argp2) {
    SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "Account_onInstantMessageStatus" "', argument " "2"" of type '" "pj::OnInstantMessageStatusParam &""'"); 
  }
  arg2 = reinterpret_cast< pj::OnInstantMessageStatusParam * >(argp2);
  director = SWIG_DIRECTOR_CAST(arg1);
  upcall = (director && (director->swig_get_self()==swig_obj[0]));
  try {
    if (upcall) {
      (arg1)->pj::Account::onInstantMessageStatus(*arg2);
    } else {
      (arg1)->onInstantMessageStatus(*arg2);
    }
  } catch (Swig::DirectorException&) {
    SWIG_fail;
  }
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_Account_onTypingIndication(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::Account *arg1 = (pj::Account *) 0 ;
  pj::OnTypingIndicationParam *arg2 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  void *argp2 = 0 ;
  int res2 = 0 ;
  PyObject *swig_obj[2] ;
  Swig::Director *director = 0;
  bool upcall = false;
  
  if (!SWIG_Python_UnpackTuple(args, "Account_onTypingIndication", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__Account, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "Account_onTypingIndication" "', argument " "1"" of type '" "pj::Account *""'"); 
  }
  arg1 = reinterpret_cast< pj::Account * >(argp1);
  res2 = SWIG_ConvertPtr(swig_obj[1], &argp2, SWIGTYPE_p_pj__OnTypingIndicationParam,  0 );
  if (!SWIG_IsOK(res2)) {
    SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "Account_onTypingIndication" "', argument " "2"" of type '" "pj::OnTypingIndicationParam &""'"); 
  }
  if (!argp2) {
    SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "Account_onTypingIndication" "', argument " "2"" of type '" "pj::OnTypingIndicationParam &""'"); 
  }
  arg2 = reinterpret_cast< pj::OnTypingIndicationParam * >(argp2);
  director = SWIG_DIRECTOR_CAST(arg1);
  upcall = (director && (director->swig_get_self()==swig_obj[0]));
  try {
    if (upcall) {
      (arg1)->pj::Account::onTypingIndication(*arg2);
    } else {
      (arg1)->onTypingIndication(*arg2);
    }
  } catch (Swig::DirectorException&) {
    SWIG_fail;
  }
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_Account_onMwiInfo(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::Account *arg1 = (pj::Account *) 0 ;
  pj::OnMwiInfoParam *arg2 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  void *argp2 = 0 ;
  int res2 = 0 ;
  PyObject *swig_obj[2] ;
  Swig::Director *director = 0;
  bool upcall = false;
  
  if (!SWIG_Python_UnpackTuple(args, "Account_onMwiInfo", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__Account, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "Account_onMwiInfo" "', argument " "1"" of type '" "pj::Account *""'"); 
  }
  arg1 = reinterpret_cast< pj::Account * >(argp1);
  res2 = SWIG_ConvertPtr(swig_obj[1], &argp2, SWIGTYPE_p_pj__OnMwiInfoParam,  0 );
  if (!SWIG_IsOK(res2)) {
    SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "Account_onMwiInfo" "', argument " "2"" of type '" "pj::OnMwiInfoParam &""'"); 
  }
  if (!argp2) {
    SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "Account_onMwiInfo" "', argument " "2"" of type '" "pj::OnMwiInfoParam &""'"); 
  }
  arg2 = reinterpret_cast< pj::OnMwiInfoParam * >(argp2);
  director = SWIG_DIRECTOR_CAST(arg1);
  upcall = (director && (director->swig_get_self()==swig_obj[0]));
  try {
    if (upcall) {
      (arg1)->pj::Account::onMwiInfo(*arg2);
    } else {
      (arg1)->onMwiInfo(*arg2);
    }
  } catch (Swig::DirectorException&) {
    SWIG_fail;
  }
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_disown_Account(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::Account *arg1 = (pj::Account *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__Account, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "disown_Account" "', argument " "1"" of type '" "pj::Account *""'"); 
  }
  arg1 = reinterpret_cast< pj::Account * >(argp1);
  {
    Swig::Director *director = SWIG_DIRECTOR_CAST(arg1);
    if (director) director->swig_disown();
  }
  
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *Account_swigregister(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *obj;
  if (!SWIG_Python_UnpackTuple(args, "swigregister", 1, 1, &obj)) return NULL;
  SWIG_TypeNewClientData(SWIGTYPE_p_pj__Account, SWIG_NewClientData(obj));
  return SWIG_Py_Void();
}

SWIGINTERN PyObject *Account_swiginit(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  return SWIG_Python_InitShadowInstance(args);
}

SWIGINTERN PyObject *_wrap_MathStat_n_set(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::MathStat *arg1 = (pj::MathStat *) 0 ;
  int arg2 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  int val2 ;
  int ecode2 = 0 ;
  PyObject *swig_obj[2] ;
  
  if (!SWIG_Python_UnpackTuple(args, "MathStat_n_set", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__MathStat, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "MathStat_n_set" "', argument " "1"" of type '" "pj::MathStat *""'"); 
  }
  arg1 = reinterpret_cast< pj::MathStat * >(argp1);
  ecode2 = SWIG_AsVal_int(swig_obj[1], &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "MathStat_n_set" "', argument " "2"" of type '" "int""'");
  } 
  arg2 = static_cast< int >(val2);
  if (arg1) (arg1)->n = arg2;
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_MathStat_n_get(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::MathStat *arg1 = (pj::MathStat *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  int result;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__MathStat, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "MathStat_n_get" "', argument " "1"" of type '" "pj::MathStat *""'"); 
  }
  arg1 = reinterpret_cast< pj::MathStat * >(argp1);
  result = (int) ((arg1)->n);
  resultobj = SWIG_From_int(static_cast< int >(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_MathStat_max_set(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::MathStat *arg1 = (pj::MathStat *) 0 ;
  int arg2 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  int val2 ;
  int ecode2 = 0 ;
  PyObject *swig_obj[2] ;
  
  if (!SWIG_Python_UnpackTuple(args, "MathStat_max_set", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__MathStat, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "MathStat_max_set" "', argument " "1"" of type '" "pj::MathStat *""'"); 
  }
  arg1 = reinterpret_cast< pj::MathStat * >(argp1);
  ecode2 = SWIG_AsVal_int(swig_obj[1], &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "MathStat_max_set" "', argument " "2"" of type '" "int""'");
  } 
  arg2 = static_cast< int >(val2);
  if (arg1) (arg1)->max = arg2;
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_MathStat_max_get(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::MathStat *arg1 = (pj::MathStat *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  int result;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__MathStat, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "MathStat_max_get" "', argument " "1"" of type '" "pj::MathStat *""'"); 
  }
  arg1 = reinterpret_cast< pj::MathStat * >(argp1);
  result = (int) ((arg1)->max);
  resultobj = SWIG_From_int(static_cast< int >(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_MathStat_min_set(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::MathStat *arg1 = (pj::MathStat *) 0 ;
  int arg2 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  int val2 ;
  int ecode2 = 0 ;
  PyObject *swig_obj[2] ;
  
  if (!SWIG_Python_UnpackTuple(args, "MathStat_min_set", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__MathStat, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "MathStat_min_set" "', argument " "1"" of type '" "pj::MathStat *""'"); 
  }
  arg1 = reinterpret_cast< pj::MathStat * >(argp1);
  ecode2 = SWIG_AsVal_int(swig_obj[1], &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "MathStat_min_set" "', argument " "2"" of type '" "int""'");
  } 
  arg2 = static_cast< int >(val2);
  if (arg1) (arg1)->min = arg2;
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_MathStat_min_get(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::MathStat *arg1 = (pj::MathStat *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  int result;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__MathStat, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "MathStat_min_get" "', argument " "1"" of type '" "pj::MathStat *""'"); 
  }
  arg1 = reinterpret_cast< pj::MathStat * >(argp1);
  result = (int) ((arg1)->min);
  resultobj = SWIG_From_int(static_cast< int >(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_MathStat_last_set(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::MathStat *arg1 = (pj::MathStat *) 0 ;
  int arg2 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  int val2 ;
  int ecode2 = 0 ;
  PyObject *swig_obj[2] ;
  
  if (!SWIG_Python_UnpackTuple(args, "MathStat_last_set", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__MathStat, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "MathStat_last_set" "', argument " "1"" of type '" "pj::MathStat *""'"); 
  }
  arg1 = reinterpret_cast< pj::MathStat * >(argp1);
  ecode2 = SWIG_AsVal_int(swig_obj[1], &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "MathStat_last_set" "', argument " "2"" of type '" "int""'");
  } 
  arg2 = static_cast< int >(val2);
  if (arg1) (arg1)->last = arg2;
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_MathStat_last_get(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::MathStat *arg1 = (pj::MathStat *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  int result;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__MathStat, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "MathStat_last_get" "', argument " "1"" of type '" "pj::MathStat *""'"); 
  }
  arg1 = reinterpret_cast< pj::MathStat * >(argp1);
  result = (int) ((arg1)->last);
  resultobj = SWIG_From_int(static_cast< int >(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_MathStat_mean_set(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::MathStat *arg1 = (pj::MathStat *) 0 ;
  int arg2 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  int val2 ;
  int ecode2 = 0 ;
  PyObject *swig_obj[2] ;
  
  if (!SWIG_Python_UnpackTuple(args, "MathStat_mean_set", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__MathStat, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "MathStat_mean_set" "', argument " "1"" of type '" "pj::MathStat *""'"); 
  }
  arg1 = reinterpret_cast< pj::MathStat * >(argp1);
  ecode2 = SWIG_AsVal_int(swig_obj[1], &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "MathStat_mean_set" "', argument " "2"" of type '" "int""'");
  } 
  arg2 = static_cast< int >(val2);
  if (arg1) (arg1)->mean = arg2;
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_MathStat_mean_get(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::MathStat *arg1 = (pj::MathStat *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  int result;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__MathStat, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "MathStat_mean_get" "', argument " "1"" of type '" "pj::MathStat *""'"); 
  }
  arg1 = reinterpret_cast< pj::MathStat * >(argp1);
  result = (int) ((arg1)->mean);
  resultobj = SWIG_From_int(static_cast< int >(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_new_MathStat(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::MathStat *result = 0 ;
  
  if (!SWIG_Python_UnpackTuple(args, "new_MathStat", 0, 0, 0)) SWIG_fail;
  result = (pj::MathStat *)new pj::MathStat();
  resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(result), SWIGTYPE_p_pj__MathStat, SWIG_POINTER_NEW |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_delete_MathStat(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::MathStat *arg1 = (pj::MathStat *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__MathStat, SWIG_POINTER_DISOWN |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "delete_MathStat" "', argument " "1"" of type '" "pj::MathStat *""'"); 
  }
  arg1 = reinterpret_cast< pj::MathStat * >(argp1);
  delete arg1;
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *MathStat_swigregister(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *obj;
  if (!SWIG_Python_UnpackTuple(args, "swigregister", 1, 1, &obj)) return NULL;
  SWIG_TypeNewClientData(SWIGTYPE_p_pj__MathStat, SWIG_NewClientData(obj));
  return SWIG_Py_Void();
}

SWIGINTERN PyObject *MathStat_swiginit(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  return SWIG_Python_InitShadowInstance(args);
}

SWIGINTERN PyObject *_wrap_LossType_burst_set(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::LossType *arg1 = (pj::LossType *) 0 ;
  unsigned int arg2 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  unsigned int val2 ;
  int ecode2 = 0 ;
  PyObject *swig_obj[2] ;
  
  if (!SWIG_Python_UnpackTuple(args, "LossType_burst_set", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__LossType, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "LossType_burst_set" "', argument " "1"" of type '" "pj::LossType *""'"); 
  }
  arg1 = reinterpret_cast< pj::LossType * >(argp1);
  ecode2 = SWIG_AsVal_unsigned_SS_int(swig_obj[1], &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "LossType_burst_set" "', argument " "2"" of type '" "unsigned int""'");
  } 
  arg2 = static_cast< unsigned int >(val2);
  if (arg1) (arg1)->burst = arg2;
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_LossType_burst_get(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::LossType *arg1 = (pj::LossType *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  unsigned int result;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__LossType, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "LossType_burst_get" "', argument " "1"" of type '" "pj::LossType *""'"); 
  }
  arg1 = reinterpret_cast< pj::LossType * >(argp1);
  result = (unsigned int) ((arg1)->burst);
  resultobj = SWIG_From_unsigned_SS_int(static_cast< unsigned int >(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_LossType_random_set(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::LossType *arg1 = (pj::LossType *) 0 ;
  unsigned int arg2 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  unsigned int val2 ;
  int ecode2 = 0 ;
  PyObject *swig_obj[2] ;
  
  if (!SWIG_Python_UnpackTuple(args, "LossType_random_set", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__LossType, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "LossType_random_set" "', argument " "1"" of type '" "pj::LossType *""'"); 
  }
  arg1 = reinterpret_cast< pj::LossType * >(argp1);
  ecode2 = SWIG_AsVal_unsigned_SS_int(swig_obj[1], &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "LossType_random_set" "', argument " "2"" of type '" "unsigned int""'");
  } 
  arg2 = static_cast< unsigned int >(val2);
  if (arg1) (arg1)->random = arg2;
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_LossType_random_get(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::LossType *arg1 = (pj::LossType *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  unsigned int result;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__LossType, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "LossType_random_get" "', argument " "1"" of type '" "pj::LossType *""'"); 
  }
  arg1 = reinterpret_cast< pj::LossType * >(argp1);
  result = (unsigned int) ((arg1)->random);
  resultobj = SWIG_From_unsigned_SS_int(static_cast< unsigned int >(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_new_LossType(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::LossType *result = 0 ;
  
  if (!SWIG_Python_UnpackTuple(args, "new_LossType", 0, 0, 0)) SWIG_fail;
  result = (pj::LossType *)new pj::LossType();
  resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(result), SWIGTYPE_p_pj__LossType, SWIG_POINTER_NEW |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_delete_LossType(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::LossType *arg1 = (pj::LossType *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__LossType, SWIG_POINTER_DISOWN |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "delete_LossType" "', argument " "1"" of type '" "pj::LossType *""'"); 
  }
  arg1 = reinterpret_cast< pj::LossType * >(argp1);
  delete arg1;
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *LossType_swigregister(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *obj;
  if (!SWIG_Python_UnpackTuple(args, "swigregister", 1, 1, &obj)) return NULL;
  SWIG_TypeNewClientData(SWIGTYPE_p_pj__LossType, SWIG_NewClientData(obj));
  return SWIG_Py_Void();
}

SWIGINTERN PyObject *LossType_swiginit(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  return SWIG_Python_InitShadowInstance(args);
}

SWIGINTERN PyObject *_wrap_RtcpStreamStat_update_set(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::RtcpStreamStat *arg1 = (pj::RtcpStreamStat *) 0 ;
  pj::TimeVal *arg2 = (pj::TimeVal *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  void *argp2 = 0 ;
  int res2 = 0 ;
  PyObject *swig_obj[2] ;
  
  if (!SWIG_Python_UnpackTuple(args, "RtcpStreamStat_update_set", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__RtcpStreamStat, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "RtcpStreamStat_update_set" "', argument " "1"" of type '" "pj::RtcpStreamStat *""'"); 
  }
  arg1 = reinterpret_cast< pj::RtcpStreamStat * >(argp1);
  res2 = SWIG_ConvertPtr(swig_obj[1], &argp2,SWIGTYPE_p_pj__TimeVal, 0 |  0 );
  if (!SWIG_IsOK(res2)) {
    SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "RtcpStreamStat_update_set" "', argument " "2"" of type '" "pj::TimeVal *""'"); 
  }
  arg2 = reinterpret_cast< pj::TimeVal * >(argp2);
  if (arg1) (arg1)->update = *arg2;
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_RtcpStreamStat_update_get(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::RtcpStreamStat *arg1 = (pj::RtcpStreamStat *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  pj::TimeVal *result = 0 ;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__RtcpStreamStat, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "RtcpStreamStat_update_get" "', argument " "1"" of type '" "pj::RtcpStreamStat *""'"); 
  }
  arg1 = reinterpret_cast< pj::RtcpStreamStat * >(argp1);
  result = (pj::TimeVal *)& ((arg1)->update);
  resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(result), SWIGTYPE_p_pj__TimeVal, 0 |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_RtcpStreamStat_updateCount_set(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::RtcpStreamStat *arg1 = (pj::RtcpStreamStat *) 0 ;
  unsigned int arg2 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  unsigned int val2 ;
  int ecode2 = 0 ;
  PyObject *swig_obj[2] ;
  
  if (!SWIG_Python_UnpackTuple(args, "RtcpStreamStat_updateCount_set", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__RtcpStreamStat, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "RtcpStreamStat_updateCount_set" "', argument " "1"" of type '" "pj::RtcpStreamStat *""'"); 
  }
  arg1 = reinterpret_cast< pj::RtcpStreamStat * >(argp1);
  ecode2 = SWIG_AsVal_unsigned_SS_int(swig_obj[1], &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "RtcpStreamStat_updateCount_set" "', argument " "2"" of type '" "unsigned int""'");
  } 
  arg2 = static_cast< unsigned int >(val2);
  if (arg1) (arg1)->updateCount = arg2;
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_RtcpStreamStat_updateCount_get(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::RtcpStreamStat *arg1 = (pj::RtcpStreamStat *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  unsigned int result;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__RtcpStreamStat, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "RtcpStreamStat_updateCount_get" "', argument " "1"" of type '" "pj::RtcpStreamStat *""'"); 
  }
  arg1 = reinterpret_cast< pj::RtcpStreamStat * >(argp1);
  result = (unsigned int) ((arg1)->updateCount);
  resultobj = SWIG_From_unsigned_SS_int(static_cast< unsigned int >(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_RtcpStreamStat_pkt_set(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::RtcpStreamStat *arg1 = (pj::RtcpStreamStat *) 0 ;
  unsigned int arg2 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  unsigned int val2 ;
  int ecode2 = 0 ;
  PyObject *swig_obj[2] ;
  
  if (!SWIG_Python_UnpackTuple(args, "RtcpStreamStat_pkt_set", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__RtcpStreamStat, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "RtcpStreamStat_pkt_set" "', argument " "1"" of type '" "pj::RtcpStreamStat *""'"); 
  }
  arg1 = reinterpret_cast< pj::RtcpStreamStat * >(argp1);
  ecode2 = SWIG_AsVal_unsigned_SS_int(swig_obj[1], &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "RtcpStreamStat_pkt_set" "', argument " "2"" of type '" "unsigned int""'");
  } 
  arg2 = static_cast< unsigned int >(val2);
  if (arg1) (arg1)->pkt = arg2;
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_RtcpStreamStat_pkt_get(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::RtcpStreamStat *arg1 = (pj::RtcpStreamStat *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  unsigned int result;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__RtcpStreamStat, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "RtcpStreamStat_pkt_get" "', argument " "1"" of type '" "pj::RtcpStreamStat *""'"); 
  }
  arg1 = reinterpret_cast< pj::RtcpStreamStat * >(argp1);
  result = (unsigned int) ((arg1)->pkt);
  resultobj = SWIG_From_unsigned_SS_int(static_cast< unsigned int >(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_RtcpStreamStat_bytes_set(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::RtcpStreamStat *arg1 = (pj::RtcpStreamStat *) 0 ;
  unsigned int arg2 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  unsigned int val2 ;
  int ecode2 = 0 ;
  PyObject *swig_obj[2] ;
  
  if (!SWIG_Python_UnpackTuple(args, "RtcpStreamStat_bytes_set", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__RtcpStreamStat, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "RtcpStreamStat_bytes_set" "', argument " "1"" of type '" "pj::RtcpStreamStat *""'"); 
  }
  arg1 = reinterpret_cast< pj::RtcpStreamStat * >(argp1);
  ecode2 = SWIG_AsVal_unsigned_SS_int(swig_obj[1], &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "RtcpStreamStat_bytes_set" "', argument " "2"" of type '" "unsigned int""'");
  } 
  arg2 = static_cast< unsigned int >(val2);
  if (arg1) (arg1)->bytes = arg2;
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_RtcpStreamStat_bytes_get(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::RtcpStreamStat *arg1 = (pj::RtcpStreamStat *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  unsigned int result;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__RtcpStreamStat, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "RtcpStreamStat_bytes_get" "', argument " "1"" of type '" "pj::RtcpStreamStat *""'"); 
  }
  arg1 = reinterpret_cast< pj::RtcpStreamStat * >(argp1);
  result = (unsigned int) ((arg1)->bytes);
  resultobj = SWIG_From_unsigned_SS_int(static_cast< unsigned int >(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_RtcpStreamStat_discard_set(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::RtcpStreamStat *arg1 = (pj::RtcpStreamStat *) 0 ;
  unsigned int arg2 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  unsigned int val2 ;
  int ecode2 = 0 ;
  PyObject *swig_obj[2] ;
  
  if (!SWIG_Python_UnpackTuple(args, "RtcpStreamStat_discard_set", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__RtcpStreamStat, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "RtcpStreamStat_discard_set" "', argument " "1"" of type '" "pj::RtcpStreamStat *""'"); 
  }
  arg1 = reinterpret_cast< pj::RtcpStreamStat * >(argp1);
  ecode2 = SWIG_AsVal_unsigned_SS_int(swig_obj[1], &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "RtcpStreamStat_discard_set" "', argument " "2"" of type '" "unsigned int""'");
  } 
  arg2 = static_cast< unsigned int >(val2);
  if (arg1) (arg1)->discard = arg2;
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_RtcpStreamStat_discard_get(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::RtcpStreamStat *arg1 = (pj::RtcpStreamStat *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  unsigned int result;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__RtcpStreamStat, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "RtcpStreamStat_discard_get" "', argument " "1"" of type '" "pj::RtcpStreamStat *""'"); 
  }
  arg1 = reinterpret_cast< pj::RtcpStreamStat * >(argp1);
  result = (unsigned int) ((arg1)->discard);
  resultobj = SWIG_From_unsigned_SS_int(static_cast< unsigned int >(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_RtcpStreamStat_loss_set(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::RtcpStreamStat *arg1 = (pj::RtcpStreamStat *) 0 ;
  unsigned int arg2 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  unsigned int val2 ;
  int ecode2 = 0 ;
  PyObject *swig_obj[2] ;
  
  if (!SWIG_Python_UnpackTuple(args, "RtcpStreamStat_loss_set", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__RtcpStreamStat, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "RtcpStreamStat_loss_set" "', argument " "1"" of type '" "pj::RtcpStreamStat *""'"); 
  }
  arg1 = reinterpret_cast< pj::RtcpStreamStat * >(argp1);
  ecode2 = SWIG_AsVal_unsigned_SS_int(swig_obj[1], &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "RtcpStreamStat_loss_set" "', argument " "2"" of type '" "unsigned int""'");
  } 
  arg2 = static_cast< unsigned int >(val2);
  if (arg1) (arg1)->loss = arg2;
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_RtcpStreamStat_loss_get(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::RtcpStreamStat *arg1 = (pj::RtcpStreamStat *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  unsigned int result;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__RtcpStreamStat, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "RtcpStreamStat_loss_get" "', argument " "1"" of type '" "pj::RtcpStreamStat *""'"); 
  }
  arg1 = reinterpret_cast< pj::RtcpStreamStat * >(argp1);
  result = (unsigned int) ((arg1)->loss);
  resultobj = SWIG_From_unsigned_SS_int(static_cast< unsigned int >(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_RtcpStreamStat_reorder_set(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::RtcpStreamStat *arg1 = (pj::RtcpStreamStat *) 0 ;
  unsigned int arg2 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  unsigned int val2 ;
  int ecode2 = 0 ;
  PyObject *swig_obj[2] ;
  
  if (!SWIG_Python_UnpackTuple(args, "RtcpStreamStat_reorder_set", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__RtcpStreamStat, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "RtcpStreamStat_reorder_set" "', argument " "1"" of type '" "pj::RtcpStreamStat *""'"); 
  }
  arg1 = reinterpret_cast< pj::RtcpStreamStat * >(argp1);
  ecode2 = SWIG_AsVal_unsigned_SS_int(swig_obj[1], &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "RtcpStreamStat_reorder_set" "', argument " "2"" of type '" "unsigned int""'");
  } 
  arg2 = static_cast< unsigned int >(val2);
  if (arg1) (arg1)->reorder = arg2;
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_RtcpStreamStat_reorder_get(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::RtcpStreamStat *arg1 = (pj::RtcpStreamStat *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  unsigned int result;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__RtcpStreamStat, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "RtcpStreamStat_reorder_get" "', argument " "1"" of type '" "pj::RtcpStreamStat *""'"); 
  }
  arg1 = reinterpret_cast< pj::RtcpStreamStat * >(argp1);
  result = (unsigned int) ((arg1)->reorder);
  resultobj = SWIG_From_unsigned_SS_int(static_cast< unsigned int >(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_RtcpStreamStat_dup_set(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::RtcpStreamStat *arg1 = (pj::RtcpStreamStat *) 0 ;
  unsigned int arg2 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  unsigned int val2 ;
  int ecode2 = 0 ;
  PyObject *swig_obj[2] ;
  
  if (!SWIG_Python_UnpackTuple(args, "RtcpStreamStat_dup_set", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__RtcpStreamStat, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "RtcpStreamStat_dup_set" "', argument " "1"" of type '" "pj::RtcpStreamStat *""'"); 
  }
  arg1 = reinterpret_cast< pj::RtcpStreamStat * >(argp1);
  ecode2 = SWIG_AsVal_unsigned_SS_int(swig_obj[1], &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "RtcpStreamStat_dup_set" "', argument " "2"" of type '" "unsigned int""'");
  } 
  arg2 = static_cast< unsigned int >(val2);
  if (arg1) (arg1)->dup = arg2;
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_RtcpStreamStat_dup_get(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::RtcpStreamStat *arg1 = (pj::RtcpStreamStat *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  unsigned int result;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__RtcpStreamStat, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "RtcpStreamStat_dup_get" "', argument " "1"" of type '" "pj::RtcpStreamStat *""'"); 
  }
  arg1 = reinterpret_cast< pj::RtcpStreamStat * >(argp1);
  result = (unsigned int) ((arg1)->dup);
  resultobj = SWIG_From_unsigned_SS_int(static_cast< unsigned int >(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_RtcpStreamStat_lossPeriodUsec_set(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::RtcpStreamStat *arg1 = (pj::RtcpStreamStat *) 0 ;
  pj::MathStat *arg2 = (pj::MathStat *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  void *argp2 = 0 ;
  int res2 = 0 ;
  PyObject *swig_obj[2] ;
  
  if (!SWIG_Python_UnpackTuple(args, "RtcpStreamStat_lossPeriodUsec_set", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__RtcpStreamStat, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "RtcpStreamStat_lossPeriodUsec_set" "', argument " "1"" of type '" "pj::RtcpStreamStat *""'"); 
  }
  arg1 = reinterpret_cast< pj::RtcpStreamStat * >(argp1);
  res2 = SWIG_ConvertPtr(swig_obj[1], &argp2,SWIGTYPE_p_pj__MathStat, 0 |  0 );
  if (!SWIG_IsOK(res2)) {
    SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "RtcpStreamStat_lossPeriodUsec_set" "', argument " "2"" of type '" "pj::MathStat *""'"); 
  }
  arg2 = reinterpret_cast< pj::MathStat * >(argp2);
  if (arg1) (arg1)->lossPeriodUsec = *arg2;
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_RtcpStreamStat_lossPeriodUsec_get(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::RtcpStreamStat *arg1 = (pj::RtcpStreamStat *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  pj::MathStat *result = 0 ;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__RtcpStreamStat, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "RtcpStreamStat_lossPeriodUsec_get" "', argument " "1"" of type '" "pj::RtcpStreamStat *""'"); 
  }
  arg1 = reinterpret_cast< pj::RtcpStreamStat * >(argp1);
  result = (pj::MathStat *)& ((arg1)->lossPeriodUsec);
  resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(result), SWIGTYPE_p_pj__MathStat, 0 |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_RtcpStreamStat_lossType_set(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::RtcpStreamStat *arg1 = (pj::RtcpStreamStat *) 0 ;
  pj::LossType *arg2 = (pj::LossType *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  void *argp2 = 0 ;
  int res2 = 0 ;
  PyObject *swig_obj[2] ;
  
  if (!SWIG_Python_UnpackTuple(args, "RtcpStreamStat_lossType_set", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__RtcpStreamStat, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "RtcpStreamStat_lossType_set" "', argument " "1"" of type '" "pj::RtcpStreamStat *""'"); 
  }
  arg1 = reinterpret_cast< pj::RtcpStreamStat * >(argp1);
  res2 = SWIG_ConvertPtr(swig_obj[1], &argp2,SWIGTYPE_p_pj__LossType, 0 |  0 );
  if (!SWIG_IsOK(res2)) {
    SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "RtcpStreamStat_lossType_set" "', argument " "2"" of type '" "pj::LossType *""'"); 
  }
  arg2 = reinterpret_cast< pj::LossType * >(argp2);
  if (arg1) (arg1)->lossType = *arg2;
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_RtcpStreamStat_lossType_get(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::RtcpStreamStat *arg1 = (pj::RtcpStreamStat *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  pj::LossType *result = 0 ;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__RtcpStreamStat, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "RtcpStreamStat_lossType_get" "', argument " "1"" of type '" "pj::RtcpStreamStat *""'"); 
  }
  arg1 = reinterpret_cast< pj::RtcpStreamStat * >(argp1);
  result = (pj::LossType *)& ((arg1)->lossType);
  resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(result), SWIGTYPE_p_pj__LossType, 0 |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_RtcpStreamStat_jitterUsec_set(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::RtcpStreamStat *arg1 = (pj::RtcpStreamStat *) 0 ;
  pj::MathStat *arg2 = (pj::MathStat *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  void *argp2 = 0 ;
  int res2 = 0 ;
  PyObject *swig_obj[2] ;
  
  if (!SWIG_Python_UnpackTuple(args, "RtcpStreamStat_jitterUsec_set", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__RtcpStreamStat, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "RtcpStreamStat_jitterUsec_set" "', argument " "1"" of type '" "pj::RtcpStreamStat *""'"); 
  }
  arg1 = reinterpret_cast< pj::RtcpStreamStat * >(argp1);
  res2 = SWIG_ConvertPtr(swig_obj[1], &argp2,SWIGTYPE_p_pj__MathStat, 0 |  0 );
  if (!SWIG_IsOK(res2)) {
    SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "RtcpStreamStat_jitterUsec_set" "', argument " "2"" of type '" "pj::MathStat *""'"); 
  }
  arg2 = reinterpret_cast< pj::MathStat * >(argp2);
  if (arg1) (arg1)->jitterUsec = *arg2;
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_RtcpStreamStat_jitterUsec_get(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::RtcpStreamStat *arg1 = (pj::RtcpStreamStat *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  pj::MathStat *result = 0 ;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__RtcpStreamStat, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "RtcpStreamStat_jitterUsec_get" "', argument " "1"" of type '" "pj::RtcpStreamStat *""'"); 
  }
  arg1 = reinterpret_cast< pj::RtcpStreamStat * >(argp1);
  result = (pj::MathStat *)& ((arg1)->jitterUsec);
  resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(result), SWIGTYPE_p_pj__MathStat, 0 |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_new_RtcpStreamStat(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::RtcpStreamStat *result = 0 ;
  
  if (!SWIG_Python_UnpackTuple(args, "new_RtcpStreamStat", 0, 0, 0)) SWIG_fail;
  result = (pj::RtcpStreamStat *)new pj::RtcpStreamStat();
  resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(result), SWIGTYPE_p_pj__RtcpStreamStat, SWIG_POINTER_NEW |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_delete_RtcpStreamStat(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::RtcpStreamStat *arg1 = (pj::RtcpStreamStat *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__RtcpStreamStat, SWIG_POINTER_DISOWN |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "delete_RtcpStreamStat" "', argument " "1"" of type '" "pj::RtcpStreamStat *""'"); 
  }
  arg1 = reinterpret_cast< pj::RtcpStreamStat * >(argp1);
  delete arg1;
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *RtcpStreamStat_swigregister(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *obj;
  if (!SWIG_Python_UnpackTuple(args, "swigregister", 1, 1, &obj)) return NULL;
  SWIG_TypeNewClientData(SWIGTYPE_p_pj__RtcpStreamStat, SWIG_NewClientData(obj));
  return SWIG_Py_Void();
}

SWIGINTERN PyObject *RtcpStreamStat_swiginit(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  return SWIG_Python_InitShadowInstance(args);
}

SWIGINTERN PyObject *_wrap_RtcpSdes_cname_set(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::RtcpSdes *arg1 = (pj::RtcpSdes *) 0 ;
  pj::string *arg2 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  int res2 = SWIG_OLDOBJ ;
  PyObject *swig_obj[2] ;
  
  if (!SWIG_Python_UnpackTuple(args, "RtcpSdes_cname_set", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__RtcpSdes, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "RtcpSdes_cname_set" "', argument " "1"" of type '" "pj::RtcpSdes *""'"); 
  }
  arg1 = reinterpret_cast< pj::RtcpSdes * >(argp1);
  {
    std::string *ptr = (std::string *)0;
    res2 = SWIG_AsPtr_std_string(swig_obj[1], &ptr);
    if (!SWIG_IsOK(res2)) {
      SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "RtcpSdes_cname_set" "', argument " "2"" of type '" "pj::string const &""'"); 
    }
    if (!ptr) {
      SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "RtcpSdes_cname_set" "', argument " "2"" of type '" "pj::string const &""'"); 
    }
    arg2 = ptr;
  }
  if (arg1) (arg1)->cname = *arg2;
  resultobj = SWIG_Py_Void();
  if (SWIG_IsNewObj(res2)) delete arg2;
  return resultobj;
fail:
  if (SWIG_IsNewObj(res2)) delete arg2;
  return NULL;
}


SWIGINTERN PyObject *_wrap_RtcpSdes_cname_get(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::RtcpSdes *arg1 = (pj::RtcpSdes *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  pj::string *result = 0 ;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__RtcpSdes, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "RtcpSdes_cname_get" "', argument " "1"" of type '" "pj::RtcpSdes *""'"); 
  }
  arg1 = reinterpret_cast< pj::RtcpSdes * >(argp1);
  result = (pj::string *) & ((arg1)->cname);
  resultobj = SWIG_From_std_string(static_cast< std::string >(*result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_RtcpSdes_name_set(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::RtcpSdes *arg1 = (pj::RtcpSdes *) 0 ;
  pj::string *arg2 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  int res2 = SWIG_OLDOBJ ;
  PyObject *swig_obj[2] ;
  
  if (!SWIG_Python_UnpackTuple(args, "RtcpSdes_name_set", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__RtcpSdes, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "RtcpSdes_name_set" "', argument " "1"" of type '" "pj::RtcpSdes *""'"); 
  }
  arg1 = reinterpret_cast< pj::RtcpSdes * >(argp1);
  {
    std::string *ptr = (std::string *)0;
    res2 = SWIG_AsPtr_std_string(swig_obj[1], &ptr);
    if (!SWIG_IsOK(res2)) {
      SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "RtcpSdes_name_set" "', argument " "2"" of type '" "pj::string const &""'"); 
    }
    if (!ptr) {
      SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "RtcpSdes_name_set" "', argument " "2"" of type '" "pj::string const &""'"); 
    }
    arg2 = ptr;
  }
  if (arg1) (arg1)->name = *arg2;
  resultobj = SWIG_Py_Void();
  if (SWIG_IsNewObj(res2)) delete arg2;
  return resultobj;
fail:
  if (SWIG_IsNewObj(res2)) delete arg2;
  return NULL;
}


SWIGINTERN PyObject *_wrap_RtcpSdes_name_get(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::RtcpSdes *arg1 = (pj::RtcpSdes *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  pj::string *result = 0 ;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__RtcpSdes, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "RtcpSdes_name_get" "', argument " "1"" of type '" "pj::RtcpSdes *""'"); 
  }
  arg1 = reinterpret_cast< pj::RtcpSdes * >(argp1);
  result = (pj::string *) & ((arg1)->name);
  resultobj = SWIG_From_std_string(static_cast< std::string >(*result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_RtcpSdes_email_set(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::RtcpSdes *arg1 = (pj::RtcpSdes *) 0 ;
  pj::string *arg2 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  int res2 = SWIG_OLDOBJ ;
  PyObject *swig_obj[2] ;
  
  if (!SWIG_Python_UnpackTuple(args, "RtcpSdes_email_set", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__RtcpSdes, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "RtcpSdes_email_set" "', argument " "1"" of type '" "pj::RtcpSdes *""'"); 
  }
  arg1 = reinterpret_cast< pj::RtcpSdes * >(argp1);
  {
    std::string *ptr = (std::string *)0;
    res2 = SWIG_AsPtr_std_string(swig_obj[1], &ptr);
    if (!SWIG_IsOK(res2)) {
      SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "RtcpSdes_email_set" "', argument " "2"" of type '" "pj::string const &""'"); 
    }
    if (!ptr) {
      SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "RtcpSdes_email_set" "', argument " "2"" of type '" "pj::string const &""'"); 
    }
    arg2 = ptr;
  }
  if (arg1) (arg1)->email = *arg2;
  resultobj = SWIG_Py_Void();
  if (SWIG_IsNewObj(res2)) delete arg2;
  return resultobj;
fail:
  if (SWIG_IsNewObj(res2)) delete arg2;
  return NULL;
}


SWIGINTERN PyObject *_wrap_RtcpSdes_email_get(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::RtcpSdes *arg1 = (pj::RtcpSdes *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  pj::string *result = 0 ;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__RtcpSdes, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "RtcpSdes_email_get" "', argument " "1"" of type '" "pj::RtcpSdes *""'"); 
  }
  arg1 = reinterpret_cast< pj::RtcpSdes * >(argp1);
  result = (pj::string *) & ((arg1)->email);
  resultobj = SWIG_From_std_string(static_cast< std::string >(*result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_RtcpSdes_phone_set(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::RtcpSdes *arg1 = (pj::RtcpSdes *) 0 ;
  pj::string *arg2 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  int res2 = SWIG_OLDOBJ ;
  PyObject *swig_obj[2] ;
  
  if (!SWIG_Python_UnpackTuple(args, "RtcpSdes_phone_set", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__RtcpSdes, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "RtcpSdes_phone_set" "', argument " "1"" of type '" "pj::RtcpSdes *""'"); 
  }
  arg1 = reinterpret_cast< pj::RtcpSdes * >(argp1);
  {
    std::string *ptr = (std::string *)0;
    res2 = SWIG_AsPtr_std_string(swig_obj[1], &ptr);
    if (!SWIG_IsOK(res2)) {
      SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "RtcpSdes_phone_set" "', argument " "2"" of type '" "pj::string const &""'"); 
    }
    if (!ptr) {
      SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "RtcpSdes_phone_set" "', argument " "2"" of type '" "pj::string const &""'"); 
    }
    arg2 = ptr;
  }
  if (arg1) (arg1)->phone = *arg2;
  resultobj = SWIG_Py_Void();
  if (SWIG_IsNewObj(res2)) delete arg2;
  return resultobj;
fail:
  if (SWIG_IsNewObj(res2)) delete arg2;
  return NULL;
}


SWIGINTERN PyObject *_wrap_RtcpSdes_phone_get(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::RtcpSdes *arg1 = (pj::RtcpSdes *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  pj::string *result = 0 ;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__RtcpSdes, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "RtcpSdes_phone_get" "', argument " "1"" of type '" "pj::RtcpSdes *""'"); 
  }
  arg1 = reinterpret_cast< pj::RtcpSdes * >(argp1);
  result = (pj::string *) & ((arg1)->phone);
  resultobj = SWIG_From_std_string(static_cast< std::string >(*result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_RtcpSdes_loc_set(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::RtcpSdes *arg1 = (pj::RtcpSdes *) 0 ;
  pj::string *arg2 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  int res2 = SWIG_OLDOBJ ;
  PyObject *swig_obj[2] ;
  
  if (!SWIG_Python_UnpackTuple(args, "RtcpSdes_loc_set", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__RtcpSdes, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "RtcpSdes_loc_set" "', argument " "1"" of type '" "pj::RtcpSdes *""'"); 
  }
  arg1 = reinterpret_cast< pj::RtcpSdes * >(argp1);
  {
    std::string *ptr = (std::string *)0;
    res2 = SWIG_AsPtr_std_string(swig_obj[1], &ptr);
    if (!SWIG_IsOK(res2)) {
      SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "RtcpSdes_loc_set" "', argument " "2"" of type '" "pj::string const &""'"); 
    }
    if (!ptr) {
      SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "RtcpSdes_loc_set" "', argument " "2"" of type '" "pj::string const &""'"); 
    }
    arg2 = ptr;
  }
  if (arg1) (arg1)->loc = *arg2;
  resultobj = SWIG_Py_Void();
  if (SWIG_IsNewObj(res2)) delete arg2;
  return resultobj;
fail:
  if (SWIG_IsNewObj(res2)) delete arg2;
  return NULL;
}


SWIGINTERN PyObject *_wrap_RtcpSdes_loc_get(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::RtcpSdes *arg1 = (pj::RtcpSdes *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  pj::string *result = 0 ;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__RtcpSdes, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "RtcpSdes_loc_get" "', argument " "1"" of type '" "pj::RtcpSdes *""'"); 
  }
  arg1 = reinterpret_cast< pj::RtcpSdes * >(argp1);
  result = (pj::string *) & ((arg1)->loc);
  resultobj = SWIG_From_std_string(static_cast< std::string >(*result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_RtcpSdes_tool_set(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::RtcpSdes *arg1 = (pj::RtcpSdes *) 0 ;
  pj::string *arg2 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  int res2 = SWIG_OLDOBJ ;
  PyObject *swig_obj[2] ;
  
  if (!SWIG_Python_UnpackTuple(args, "RtcpSdes_tool_set", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__RtcpSdes, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "RtcpSdes_tool_set" "', argument " "1"" of type '" "pj::RtcpSdes *""'"); 
  }
  arg1 = reinterpret_cast< pj::RtcpSdes * >(argp1);
  {
    std::string *ptr = (std::string *)0;
    res2 = SWIG_AsPtr_std_string(swig_obj[1], &ptr);
    if (!SWIG_IsOK(res2)) {
      SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "RtcpSdes_tool_set" "', argument " "2"" of type '" "pj::string const &""'"); 
    }
    if (!ptr) {
      SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "RtcpSdes_tool_set" "', argument " "2"" of type '" "pj::string const &""'"); 
    }
    arg2 = ptr;
  }
  if (arg1) (arg1)->tool = *arg2;
  resultobj = SWIG_Py_Void();
  if (SWIG_IsNewObj(res2)) delete arg2;
  return resultobj;
fail:
  if (SWIG_IsNewObj(res2)) delete arg2;
  return NULL;
}


SWIGINTERN PyObject *_wrap_RtcpSdes_tool_get(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::RtcpSdes *arg1 = (pj::RtcpSdes *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  pj::string *result = 0 ;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__RtcpSdes, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "RtcpSdes_tool_get" "', argument " "1"" of type '" "pj::RtcpSdes *""'"); 
  }
  arg1 = reinterpret_cast< pj::RtcpSdes * >(argp1);
  result = (pj::string *) & ((arg1)->tool);
  resultobj = SWIG_From_std_string(static_cast< std::string >(*result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_RtcpSdes_note_set(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::RtcpSdes *arg1 = (pj::RtcpSdes *) 0 ;
  pj::string *arg2 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  int res2 = SWIG_OLDOBJ ;
  PyObject *swig_obj[2] ;
  
  if (!SWIG_Python_UnpackTuple(args, "RtcpSdes_note_set", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__RtcpSdes, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "RtcpSdes_note_set" "', argument " "1"" of type '" "pj::RtcpSdes *""'"); 
  }
  arg1 = reinterpret_cast< pj::RtcpSdes * >(argp1);
  {
    std::string *ptr = (std::string *)0;
    res2 = SWIG_AsPtr_std_string(swig_obj[1], &ptr);
    if (!SWIG_IsOK(res2)) {
      SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "RtcpSdes_note_set" "', argument " "2"" of type '" "pj::string const &""'"); 
    }
    if (!ptr) {
      SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "RtcpSdes_note_set" "', argument " "2"" of type '" "pj::string const &""'"); 
    }
    arg2 = ptr;
  }
  if (arg1) (arg1)->note = *arg2;
  resultobj = SWIG_Py_Void();
  if (SWIG_IsNewObj(res2)) delete arg2;
  return resultobj;
fail:
  if (SWIG_IsNewObj(res2)) delete arg2;
  return NULL;
}


SWIGINTERN PyObject *_wrap_RtcpSdes_note_get(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::RtcpSdes *arg1 = (pj::RtcpSdes *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  pj::string *result = 0 ;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__RtcpSdes, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "RtcpSdes_note_get" "', argument " "1"" of type '" "pj::RtcpSdes *""'"); 
  }
  arg1 = reinterpret_cast< pj::RtcpSdes * >(argp1);
  result = (pj::string *) & ((arg1)->note);
  resultobj = SWIG_From_std_string(static_cast< std::string >(*result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_new_RtcpSdes(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::RtcpSdes *result = 0 ;
  
  if (!SWIG_Python_UnpackTuple(args, "new_RtcpSdes", 0, 0, 0)) SWIG_fail;
  result = (pj::RtcpSdes *)new pj::RtcpSdes();
  resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(result), SWIGTYPE_p_pj__RtcpSdes, SWIG_POINTER_NEW |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_delete_RtcpSdes(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::RtcpSdes *arg1 = (pj::RtcpSdes *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__RtcpSdes, SWIG_POINTER_DISOWN |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "delete_RtcpSdes" "', argument " "1"" of type '" "pj::RtcpSdes *""'"); 
  }
  arg1 = reinterpret_cast< pj::RtcpSdes * >(argp1);
  delete arg1;
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *RtcpSdes_swigregister(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *obj;
  if (!SWIG_Python_UnpackTuple(args, "swigregister", 1, 1, &obj)) return NULL;
  SWIG_TypeNewClientData(SWIGTYPE_p_pj__RtcpSdes, SWIG_NewClientData(obj));
  return SWIG_Py_Void();
}

SWIGINTERN PyObject *RtcpSdes_swiginit(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  return SWIG_Python_InitShadowInstance(args);
}

SWIGINTERN PyObject *_wrap_RtcpStat_start_set(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::RtcpStat *arg1 = (pj::RtcpStat *) 0 ;
  pj::TimeVal *arg2 = (pj::TimeVal *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  void *argp2 = 0 ;
  int res2 = 0 ;
  PyObject *swig_obj[2] ;
  
  if (!SWIG_Python_UnpackTuple(args, "RtcpStat_start_set", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__RtcpStat, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "RtcpStat_start_set" "', argument " "1"" of type '" "pj::RtcpStat *""'"); 
  }
  arg1 = reinterpret_cast< pj::RtcpStat * >(argp1);
  res2 = SWIG_ConvertPtr(swig_obj[1], &argp2,SWIGTYPE_p_pj__TimeVal, 0 |  0 );
  if (!SWIG_IsOK(res2)) {
    SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "RtcpStat_start_set" "', argument " "2"" of type '" "pj::TimeVal *""'"); 
  }
  arg2 = reinterpret_cast< pj::TimeVal * >(argp2);
  if (arg1) (arg1)->start = *arg2;
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_RtcpStat_start_get(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::RtcpStat *arg1 = (pj::RtcpStat *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  pj::TimeVal *result = 0 ;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__RtcpStat, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "RtcpStat_start_get" "', argument " "1"" of type '" "pj::RtcpStat *""'"); 
  }
  arg1 = reinterpret_cast< pj::RtcpStat * >(argp1);
  result = (pj::TimeVal *)& ((arg1)->start);
  resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(result), SWIGTYPE_p_pj__TimeVal, 0 |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_RtcpStat_txStat_set(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::RtcpStat *arg1 = (pj::RtcpStat *) 0 ;
  pj::RtcpStreamStat *arg2 = (pj::RtcpStreamStat *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  void *argp2 = 0 ;
  int res2 = 0 ;
  PyObject *swig_obj[2] ;
  
  if (!SWIG_Python_UnpackTuple(args, "RtcpStat_txStat_set", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__RtcpStat, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "RtcpStat_txStat_set" "', argument " "1"" of type '" "pj::RtcpStat *""'"); 
  }
  arg1 = reinterpret_cast< pj::RtcpStat * >(argp1);
  res2 = SWIG_ConvertPtr(swig_obj[1], &argp2,SWIGTYPE_p_pj__RtcpStreamStat, 0 |  0 );
  if (!SWIG_IsOK(res2)) {
    SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "RtcpStat_txStat_set" "', argument " "2"" of type '" "pj::RtcpStreamStat *""'"); 
  }
  arg2 = reinterpret_cast< pj::RtcpStreamStat * >(argp2);
  if (arg1) (arg1)->txStat = *arg2;
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_RtcpStat_txStat_get(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::RtcpStat *arg1 = (pj::RtcpStat *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  pj::RtcpStreamStat *result = 0 ;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__RtcpStat, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "RtcpStat_txStat_get" "', argument " "1"" of type '" "pj::RtcpStat *""'"); 
  }
  arg1 = reinterpret_cast< pj::RtcpStat * >(argp1);
  result = (pj::RtcpStreamStat *)& ((arg1)->txStat);
  resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(result), SWIGTYPE_p_pj__RtcpStreamStat, 0 |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_RtcpStat_rxStat_set(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::RtcpStat *arg1 = (pj::RtcpStat *) 0 ;
  pj::RtcpStreamStat *arg2 = (pj::RtcpStreamStat *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  void *argp2 = 0 ;
  int res2 = 0 ;
  PyObject *swig_obj[2] ;
  
  if (!SWIG_Python_UnpackTuple(args, "RtcpStat_rxStat_set", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__RtcpStat, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "RtcpStat_rxStat_set" "', argument " "1"" of type '" "pj::RtcpStat *""'"); 
  }
  arg1 = reinterpret_cast< pj::RtcpStat * >(argp1);
  res2 = SWIG_ConvertPtr(swig_obj[1], &argp2,SWIGTYPE_p_pj__RtcpStreamStat, 0 |  0 );
  if (!SWIG_IsOK(res2)) {
    SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "RtcpStat_rxStat_set" "', argument " "2"" of type '" "pj::RtcpStreamStat *""'"); 
  }
  arg2 = reinterpret_cast< pj::RtcpStreamStat * >(argp2);
  if (arg1) (arg1)->rxStat = *arg2;
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_RtcpStat_rxStat_get(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::RtcpStat *arg1 = (pj::RtcpStat *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  pj::RtcpStreamStat *result = 0 ;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__RtcpStat, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "RtcpStat_rxStat_get" "', argument " "1"" of type '" "pj::RtcpStat *""'"); 
  }
  arg1 = reinterpret_cast< pj::RtcpStat * >(argp1);
  result = (pj::RtcpStreamStat *)& ((arg1)->rxStat);
  resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(result), SWIGTYPE_p_pj__RtcpStreamStat, 0 |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_RtcpStat_rttUsec_set(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::RtcpStat *arg1 = (pj::RtcpStat *) 0 ;
  pj::MathStat *arg2 = (pj::MathStat *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  void *argp2 = 0 ;
  int res2 = 0 ;
  PyObject *swig_obj[2] ;
  
  if (!SWIG_Python_UnpackTuple(args, "RtcpStat_rttUsec_set", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__RtcpStat, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "RtcpStat_rttUsec_set" "', argument " "1"" of type '" "pj::RtcpStat *""'"); 
  }
  arg1 = reinterpret_cast< pj::RtcpStat * >(argp1);
  res2 = SWIG_ConvertPtr(swig_obj[1], &argp2,SWIGTYPE_p_pj__MathStat, 0 |  0 );
  if (!SWIG_IsOK(res2)) {
    SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "RtcpStat_rttUsec_set" "', argument " "2"" of type '" "pj::MathStat *""'"); 
  }
  arg2 = reinterpret_cast< pj::MathStat * >(argp2);
  if (arg1) (arg1)->rttUsec = *arg2;
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_RtcpStat_rttUsec_get(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::RtcpStat *arg1 = (pj::RtcpStat *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  pj::MathStat *result = 0 ;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__RtcpStat, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "RtcpStat_rttUsec_get" "', argument " "1"" of type '" "pj::RtcpStat *""'"); 
  }
  arg1 = reinterpret_cast< pj::RtcpStat * >(argp1);
  result = (pj::MathStat *)& ((arg1)->rttUsec);
  resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(result), SWIGTYPE_p_pj__MathStat, 0 |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_RtcpStat_rtpTxLastTs_set(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::RtcpStat *arg1 = (pj::RtcpStat *) 0 ;
  pj_uint32_t arg2 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  unsigned int val2 ;
  int ecode2 = 0 ;
  PyObject *swig_obj[2] ;
  
  if (!SWIG_Python_UnpackTuple(args, "RtcpStat_rtpTxLastTs_set", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__RtcpStat, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "RtcpStat_rtpTxLastTs_set" "', argument " "1"" of type '" "pj::RtcpStat *""'"); 
  }
  arg1 = reinterpret_cast< pj::RtcpStat * >(argp1);
  ecode2 = SWIG_AsVal_unsigned_SS_int(swig_obj[1], &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "RtcpStat_rtpTxLastTs_set" "', argument " "2"" of type '" "pj_uint32_t""'");
  } 
  arg2 = static_cast< pj_uint32_t >(val2);
  if (arg1) (arg1)->rtpTxLastTs = arg2;
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_RtcpStat_rtpTxLastTs_get(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::RtcpStat *arg1 = (pj::RtcpStat *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  pj_uint32_t result;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__RtcpStat, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "RtcpStat_rtpTxLastTs_get" "', argument " "1"" of type '" "pj::RtcpStat *""'"); 
  }
  arg1 = reinterpret_cast< pj::RtcpStat * >(argp1);
  result = (pj_uint32_t) ((arg1)->rtpTxLastTs);
  resultobj = SWIG_From_unsigned_SS_int(static_cast< unsigned int >(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_RtcpStat_rtpTxLastSeq_set(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::RtcpStat *arg1 = (pj::RtcpStat *) 0 ;
  pj_uint16_t arg2 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  unsigned short val2 ;
  int ecode2 = 0 ;
  PyObject *swig_obj[2] ;
  
  if (!SWIG_Python_UnpackTuple(args, "RtcpStat_rtpTxLastSeq_set", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__RtcpStat, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "RtcpStat_rtpTxLastSeq_set" "', argument " "1"" of type '" "pj::RtcpStat *""'"); 
  }
  arg1 = reinterpret_cast< pj::RtcpStat * >(argp1);
  ecode2 = SWIG_AsVal_unsigned_SS_short(swig_obj[1], &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "RtcpStat_rtpTxLastSeq_set" "', argument " "2"" of type '" "pj_uint16_t""'");
  } 
  arg2 = static_cast< pj_uint16_t >(val2);
  if (arg1) (arg1)->rtpTxLastSeq = arg2;
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_RtcpStat_rtpTxLastSeq_get(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::RtcpStat *arg1 = (pj::RtcpStat *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  pj_uint16_t result;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__RtcpStat, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "RtcpStat_rtpTxLastSeq_get" "', argument " "1"" of type '" "pj::RtcpStat *""'"); 
  }
  arg1 = reinterpret_cast< pj::RtcpStat * >(argp1);
  result = (pj_uint16_t) ((arg1)->rtpTxLastSeq);
  resultobj = SWIG_From_unsigned_SS_short(static_cast< unsigned short >(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_RtcpStat_rxIpdvUsec_set(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::RtcpStat *arg1 = (pj::RtcpStat *) 0 ;
  pj::MathStat *arg2 = (pj::MathStat *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  void *argp2 = 0 ;
  int res2 = 0 ;
  PyObject *swig_obj[2] ;
  
  if (!SWIG_Python_UnpackTuple(args, "RtcpStat_rxIpdvUsec_set", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__RtcpStat, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "RtcpStat_rxIpdvUsec_set" "', argument " "1"" of type '" "pj::RtcpStat *""'"); 
  }
  arg1 = reinterpret_cast< pj::RtcpStat * >(argp1);
  res2 = SWIG_ConvertPtr(swig_obj[1], &argp2,SWIGTYPE_p_pj__MathStat, 0 |  0 );
  if (!SWIG_IsOK(res2)) {
    SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "RtcpStat_rxIpdvUsec_set" "', argument " "2"" of type '" "pj::MathStat *""'"); 
  }
  arg2 = reinterpret_cast< pj::MathStat * >(argp2);
  if (arg1) (arg1)->rxIpdvUsec = *arg2;
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_RtcpStat_rxIpdvUsec_get(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::RtcpStat *arg1 = (pj::RtcpStat *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  pj::MathStat *result = 0 ;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__RtcpStat, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "RtcpStat_rxIpdvUsec_get" "', argument " "1"" of type '" "pj::RtcpStat *""'"); 
  }
  arg1 = reinterpret_cast< pj::RtcpStat * >(argp1);
  result = (pj::MathStat *)& ((arg1)->rxIpdvUsec);
  resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(result), SWIGTYPE_p_pj__MathStat, 0 |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_RtcpStat_rxRawJitterUsec_set(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::RtcpStat *arg1 = (pj::RtcpStat *) 0 ;
  pj::MathStat *arg2 = (pj::MathStat *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  void *argp2 = 0 ;
  int res2 = 0 ;
  PyObject *swig_obj[2] ;
  
  if (!SWIG_Python_UnpackTuple(args, "RtcpStat_rxRawJitterUsec_set", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__RtcpStat, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "RtcpStat_rxRawJitterUsec_set" "', argument " "1"" of type '" "pj::RtcpStat *""'"); 
  }
  arg1 = reinterpret_cast< pj::RtcpStat * >(argp1);
  res2 = SWIG_ConvertPtr(swig_obj[1], &argp2,SWIGTYPE_p_pj__MathStat, 0 |  0 );
  if (!SWIG_IsOK(res2)) {
    SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "RtcpStat_rxRawJitterUsec_set" "', argument " "2"" of type '" "pj::MathStat *""'"); 
  }
  arg2 = reinterpret_cast< pj::MathStat * >(argp2);
  if (arg1) (arg1)->rxRawJitterUsec = *arg2;
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_RtcpStat_rxRawJitterUsec_get(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::RtcpStat *arg1 = (pj::RtcpStat *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  pj::MathStat *result = 0 ;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__RtcpStat, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "RtcpStat_rxRawJitterUsec_get" "', argument " "1"" of type '" "pj::RtcpStat *""'"); 
  }
  arg1 = reinterpret_cast< pj::RtcpStat * >(argp1);
  result = (pj::MathStat *)& ((arg1)->rxRawJitterUsec);
  resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(result), SWIGTYPE_p_pj__MathStat, 0 |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_RtcpStat_peerSdes_set(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::RtcpStat *arg1 = (pj::RtcpStat *) 0 ;
  pj::RtcpSdes *arg2 = (pj::RtcpSdes *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  void *argp2 = 0 ;
  int res2 = 0 ;
  PyObject *swig_obj[2] ;
  
  if (!SWIG_Python_UnpackTuple(args, "RtcpStat_peerSdes_set", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__RtcpStat, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "RtcpStat_peerSdes_set" "', argument " "1"" of type '" "pj::RtcpStat *""'"); 
  }
  arg1 = reinterpret_cast< pj::RtcpStat * >(argp1);
  res2 = SWIG_ConvertPtr(swig_obj[1], &argp2,SWIGTYPE_p_pj__RtcpSdes, 0 |  0 );
  if (!SWIG_IsOK(res2)) {
    SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "RtcpStat_peerSdes_set" "', argument " "2"" of type '" "pj::RtcpSdes *""'"); 
  }
  arg2 = reinterpret_cast< pj::RtcpSdes * >(argp2);
  if (arg1) (arg1)->peerSdes = *arg2;
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_RtcpStat_peerSdes_get(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::RtcpStat *arg1 = (pj::RtcpStat *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  pj::RtcpSdes *result = 0 ;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__RtcpStat, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "RtcpStat_peerSdes_get" "', argument " "1"" of type '" "pj::RtcpStat *""'"); 
  }
  arg1 = reinterpret_cast< pj::RtcpStat * >(argp1);
  result = (pj::RtcpSdes *)& ((arg1)->peerSdes);
  resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(result), SWIGTYPE_p_pj__RtcpSdes, 0 |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_new_RtcpStat(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::RtcpStat *result = 0 ;
  
  if (!SWIG_Python_UnpackTuple(args, "new_RtcpStat", 0, 0, 0)) SWIG_fail;
  result = (pj::RtcpStat *)new pj::RtcpStat();
  resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(result), SWIGTYPE_p_pj__RtcpStat, SWIG_POINTER_NEW |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_delete_RtcpStat(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::RtcpStat *arg1 = (pj::RtcpStat *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__RtcpStat, SWIG_POINTER_DISOWN |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "delete_RtcpStat" "', argument " "1"" of type '" "pj::RtcpStat *""'"); 
  }
  arg1 = reinterpret_cast< pj::RtcpStat * >(argp1);
  delete arg1;
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *RtcpStat_swigregister(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *obj;
  if (!SWIG_Python_UnpackTuple(args, "swigregister", 1, 1, &obj)) return NULL;
  SWIG_TypeNewClientData(SWIGTYPE_p_pj__RtcpStat, SWIG_NewClientData(obj));
  return SWIG_Py_Void();
}

SWIGINTERN PyObject *RtcpStat_swiginit(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  return SWIG_Python_InitShadowInstance(args);
}

SWIGINTERN PyObject *_wrap_JbufState_frameSize_set(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::JbufState *arg1 = (pj::JbufState *) 0 ;
  unsigned int arg2 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  unsigned int val2 ;
  int ecode2 = 0 ;
  PyObject *swig_obj[2] ;
  
  if (!SWIG_Python_UnpackTuple(args, "JbufState_frameSize_set", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__JbufState, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "JbufState_frameSize_set" "', argument " "1"" of type '" "pj::JbufState *""'"); 
  }
  arg1 = reinterpret_cast< pj::JbufState * >(argp1);
  ecode2 = SWIG_AsVal_unsigned_SS_int(swig_obj[1], &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "JbufState_frameSize_set" "', argument " "2"" of type '" "unsigned int""'");
  } 
  arg2 = static_cast< unsigned int >(val2);
  if (arg1) (arg1)->frameSize = arg2;
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_JbufState_frameSize_get(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::JbufState *arg1 = (pj::JbufState *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  unsigned int result;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__JbufState, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "JbufState_frameSize_get" "', argument " "1"" of type '" "pj::JbufState *""'"); 
  }
  arg1 = reinterpret_cast< pj::JbufState * >(argp1);
  result = (unsigned int) ((arg1)->frameSize);
  resultobj = SWIG_From_unsigned_SS_int(static_cast< unsigned int >(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_JbufState_minPrefetch_set(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::JbufState *arg1 = (pj::JbufState *) 0 ;
  unsigned int arg2 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  unsigned int val2 ;
  int ecode2 = 0 ;
  PyObject *swig_obj[2] ;
  
  if (!SWIG_Python_UnpackTuple(args, "JbufState_minPrefetch_set", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__JbufState, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "JbufState_minPrefetch_set" "', argument " "1"" of type '" "pj::JbufState *""'"); 
  }
  arg1 = reinterpret_cast< pj::JbufState * >(argp1);
  ecode2 = SWIG_AsVal_unsigned_SS_int(swig_obj[1], &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "JbufState_minPrefetch_set" "', argument " "2"" of type '" "unsigned int""'");
  } 
  arg2 = static_cast< unsigned int >(val2);
  if (arg1) (arg1)->minPrefetch = arg2;
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_JbufState_minPrefetch_get(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::JbufState *arg1 = (pj::JbufState *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  unsigned int result;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__JbufState, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "JbufState_minPrefetch_get" "', argument " "1"" of type '" "pj::JbufState *""'"); 
  }
  arg1 = reinterpret_cast< pj::JbufState * >(argp1);
  result = (unsigned int) ((arg1)->minPrefetch);
  resultobj = SWIG_From_unsigned_SS_int(static_cast< unsigned int >(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_JbufState_maxPrefetch_set(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::JbufState *arg1 = (pj::JbufState *) 0 ;
  unsigned int arg2 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  unsigned int val2 ;
  int ecode2 = 0 ;
  PyObject *swig_obj[2] ;
  
  if (!SWIG_Python_UnpackTuple(args, "JbufState_maxPrefetch_set", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__JbufState, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "JbufState_maxPrefetch_set" "', argument " "1"" of type '" "pj::JbufState *""'"); 
  }
  arg1 = reinterpret_cast< pj::JbufState * >(argp1);
  ecode2 = SWIG_AsVal_unsigned_SS_int(swig_obj[1], &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "JbufState_maxPrefetch_set" "', argument " "2"" of type '" "unsigned int""'");
  } 
  arg2 = static_cast< unsigned int >(val2);
  if (arg1) (arg1)->maxPrefetch = arg2;
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_JbufState_maxPrefetch_get(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::JbufState *arg1 = (pj::JbufState *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  unsigned int result;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__JbufState, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "JbufState_maxPrefetch_get" "', argument " "1"" of type '" "pj::JbufState *""'"); 
  }
  arg1 = reinterpret_cast< pj::JbufState * >(argp1);
  result = (unsigned int) ((arg1)->maxPrefetch);
  resultobj = SWIG_From_unsigned_SS_int(static_cast< unsigned int >(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_JbufState_burst_set(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::JbufState *arg1 = (pj::JbufState *) 0 ;
  unsigned int arg2 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  unsigned int val2 ;
  int ecode2 = 0 ;
  PyObject *swig_obj[2] ;
  
  if (!SWIG_Python_UnpackTuple(args, "JbufState_burst_set", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__JbufState, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "JbufState_burst_set" "', argument " "1"" of type '" "pj::JbufState *""'"); 
  }
  arg1 = reinterpret_cast< pj::JbufState * >(argp1);
  ecode2 = SWIG_AsVal_unsigned_SS_int(swig_obj[1], &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "JbufState_burst_set" "', argument " "2"" of type '" "unsigned int""'");
  } 
  arg2 = static_cast< unsigned int >(val2);
  if (arg1) (arg1)->burst = arg2;
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_JbufState_burst_get(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::JbufState *arg1 = (pj::JbufState *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  unsigned int result;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__JbufState, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "JbufState_burst_get" "', argument " "1"" of type '" "pj::JbufState *""'"); 
  }
  arg1 = reinterpret_cast< pj::JbufState * >(argp1);
  result = (unsigned int) ((arg1)->burst);
  resultobj = SWIG_From_unsigned_SS_int(static_cast< unsigned int >(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_JbufState_prefetch_set(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::JbufState *arg1 = (pj::JbufState *) 0 ;
  unsigned int arg2 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  unsigned int val2 ;
  int ecode2 = 0 ;
  PyObject *swig_obj[2] ;
  
  if (!SWIG_Python_UnpackTuple(args, "JbufState_prefetch_set", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__JbufState, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "JbufState_prefetch_set" "', argument " "1"" of type '" "pj::JbufState *""'"); 
  }
  arg1 = reinterpret_cast< pj::JbufState * >(argp1);
  ecode2 = SWIG_AsVal_unsigned_SS_int(swig_obj[1], &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "JbufState_prefetch_set" "', argument " "2"" of type '" "unsigned int""'");
  } 
  arg2 = static_cast< unsigned int >(val2);
  if (arg1) (arg1)->prefetch = arg2;
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_JbufState_prefetch_get(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::JbufState *arg1 = (pj::JbufState *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  unsigned int result;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__JbufState, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "JbufState_prefetch_get" "', argument " "1"" of type '" "pj::JbufState *""'"); 
  }
  arg1 = reinterpret_cast< pj::JbufState * >(argp1);
  result = (unsigned int) ((arg1)->prefetch);
  resultobj = SWIG_From_unsigned_SS_int(static_cast< unsigned int >(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_JbufState_size_set(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::JbufState *arg1 = (pj::JbufState *) 0 ;
  unsigned int arg2 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  unsigned int val2 ;
  int ecode2 = 0 ;
  PyObject *swig_obj[2] ;
  
  if (!SWIG_Python_UnpackTuple(args, "JbufState_size_set", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__JbufState, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "JbufState_size_set" "', argument " "1"" of type '" "pj::JbufState *""'"); 
  }
  arg1 = reinterpret_cast< pj::JbufState * >(argp1);
  ecode2 = SWIG_AsVal_unsigned_SS_int(swig_obj[1], &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "JbufState_size_set" "', argument " "2"" of type '" "unsigned int""'");
  } 
  arg2 = static_cast< unsigned int >(val2);
  if (arg1) (arg1)->size = arg2;
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_JbufState_size_get(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::JbufState *arg1 = (pj::JbufState *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  unsigned int result;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__JbufState, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "JbufState_size_get" "', argument " "1"" of type '" "pj::JbufState *""'"); 
  }
  arg1 = reinterpret_cast< pj::JbufState * >(argp1);
  result = (unsigned int) ((arg1)->size);
  resultobj = SWIG_From_unsigned_SS_int(static_cast< unsigned int >(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_JbufState_avgDelayMsec_set(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::JbufState *arg1 = (pj::JbufState *) 0 ;
  unsigned int arg2 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  unsigned int val2 ;
  int ecode2 = 0 ;
  PyObject *swig_obj[2] ;
  
  if (!SWIG_Python_UnpackTuple(args, "JbufState_avgDelayMsec_set", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__JbufState, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "JbufState_avgDelayMsec_set" "', argument " "1"" of type '" "pj::JbufState *""'"); 
  }
  arg1 = reinterpret_cast< pj::JbufState * >(argp1);
  ecode2 = SWIG_AsVal_unsigned_SS_int(swig_obj[1], &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "JbufState_avgDelayMsec_set" "', argument " "2"" of type '" "unsigned int""'");
  } 
  arg2 = static_cast< unsigned int >(val2);
  if (arg1) (arg1)->avgDelayMsec = arg2;
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_JbufState_avgDelayMsec_get(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::JbufState *arg1 = (pj::JbufState *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  unsigned int result;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__JbufState, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "JbufState_avgDelayMsec_get" "', argument " "1"" of type '" "pj::JbufState *""'"); 
  }
  arg1 = reinterpret_cast< pj::JbufState * >(argp1);
  result = (unsigned int) ((arg1)->avgDelayMsec);
  resultobj = SWIG_From_unsigned_SS_int(static_cast< unsigned int >(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_JbufState_minDelayMsec_set(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::JbufState *arg1 = (pj::JbufState *) 0 ;
  unsigned int arg2 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  unsigned int val2 ;
  int ecode2 = 0 ;
  PyObject *swig_obj[2] ;
  
  if (!SWIG_Python_UnpackTuple(args, "JbufState_minDelayMsec_set", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__JbufState, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "JbufState_minDelayMsec_set" "', argument " "1"" of type '" "pj::JbufState *""'"); 
  }
  arg1 = reinterpret_cast< pj::JbufState * >(argp1);
  ecode2 = SWIG_AsVal_unsigned_SS_int(swig_obj[1], &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "JbufState_minDelayMsec_set" "', argument " "2"" of type '" "unsigned int""'");
  } 
  arg2 = static_cast< unsigned int >(val2);
  if (arg1) (arg1)->minDelayMsec = arg2;
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_JbufState_minDelayMsec_get(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::JbufState *arg1 = (pj::JbufState *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  unsigned int result;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__JbufState, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "JbufState_minDelayMsec_get" "', argument " "1"" of type '" "pj::JbufState *""'"); 
  }
  arg1 = reinterpret_cast< pj::JbufState * >(argp1);
  result = (unsigned int) ((arg1)->minDelayMsec);
  resultobj = SWIG_From_unsigned_SS_int(static_cast< unsigned int >(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_JbufState_maxDelayMsec_set(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::JbufState *arg1 = (pj::JbufState *) 0 ;
  unsigned int arg2 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  unsigned int val2 ;
  int ecode2 = 0 ;
  PyObject *swig_obj[2] ;
  
  if (!SWIG_Python_UnpackTuple(args, "JbufState_maxDelayMsec_set", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__JbufState, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "JbufState_maxDelayMsec_set" "', argument " "1"" of type '" "pj::JbufState *""'"); 
  }
  arg1 = reinterpret_cast< pj::JbufState * >(argp1);
  ecode2 = SWIG_AsVal_unsigned_SS_int(swig_obj[1], &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "JbufState_maxDelayMsec_set" "', argument " "2"" of type '" "unsigned int""'");
  } 
  arg2 = static_cast< unsigned int >(val2);
  if (arg1) (arg1)->maxDelayMsec = arg2;
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_JbufState_maxDelayMsec_get(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::JbufState *arg1 = (pj::JbufState *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  unsigned int result;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__JbufState, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "JbufState_maxDelayMsec_get" "', argument " "1"" of type '" "pj::JbufState *""'"); 
  }
  arg1 = reinterpret_cast< pj::JbufState * >(argp1);
  result = (unsigned int) ((arg1)->maxDelayMsec);
  resultobj = SWIG_From_unsigned_SS_int(static_cast< unsigned int >(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_JbufState_devDelayMsec_set(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::JbufState *arg1 = (pj::JbufState *) 0 ;
  unsigned int arg2 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  unsigned int val2 ;
  int ecode2 = 0 ;
  PyObject *swig_obj[2] ;
  
  if (!SWIG_Python_UnpackTuple(args, "JbufState_devDelayMsec_set", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__JbufState, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "JbufState_devDelayMsec_set" "', argument " "1"" of type '" "pj::JbufState *""'"); 
  }
  arg1 = reinterpret_cast< pj::JbufState * >(argp1);
  ecode2 = SWIG_AsVal_unsigned_SS_int(swig_obj[1], &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "JbufState_devDelayMsec_set" "', argument " "2"" of type '" "unsigned int""'");
  } 
  arg2 = static_cast< unsigned int >(val2);
  if (arg1) (arg1)->devDelayMsec = arg2;
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_JbufState_devDelayMsec_get(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::JbufState *arg1 = (pj::JbufState *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  unsigned int result;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__JbufState, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "JbufState_devDelayMsec_get" "', argument " "1"" of type '" "pj::JbufState *""'"); 
  }
  arg1 = reinterpret_cast< pj::JbufState * >(argp1);
  result = (unsigned int) ((arg1)->devDelayMsec);
  resultobj = SWIG_From_unsigned_SS_int(static_cast< unsigned int >(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_JbufState_avgBurst_set(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::JbufState *arg1 = (pj::JbufState *) 0 ;
  unsigned int arg2 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  unsigned int val2 ;
  int ecode2 = 0 ;
  PyObject *swig_obj[2] ;
  
  if (!SWIG_Python_UnpackTuple(args, "JbufState_avgBurst_set", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__JbufState, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "JbufState_avgBurst_set" "', argument " "1"" of type '" "pj::JbufState *""'"); 
  }
  arg1 = reinterpret_cast< pj::JbufState * >(argp1);
  ecode2 = SWIG_AsVal_unsigned_SS_int(swig_obj[1], &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "JbufState_avgBurst_set" "', argument " "2"" of type '" "unsigned int""'");
  } 
  arg2 = static_cast< unsigned int >(val2);
  if (arg1) (arg1)->avgBurst = arg2;
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_JbufState_avgBurst_get(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::JbufState *arg1 = (pj::JbufState *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  unsigned int result;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__JbufState, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "JbufState_avgBurst_get" "', argument " "1"" of type '" "pj::JbufState *""'"); 
  }
  arg1 = reinterpret_cast< pj::JbufState * >(argp1);
  result = (unsigned int) ((arg1)->avgBurst);
  resultobj = SWIG_From_unsigned_SS_int(static_cast< unsigned int >(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_JbufState_lost_set(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::JbufState *arg1 = (pj::JbufState *) 0 ;
  unsigned int arg2 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  unsigned int val2 ;
  int ecode2 = 0 ;
  PyObject *swig_obj[2] ;
  
  if (!SWIG_Python_UnpackTuple(args, "JbufState_lost_set", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__JbufState, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "JbufState_lost_set" "', argument " "1"" of type '" "pj::JbufState *""'"); 
  }
  arg1 = reinterpret_cast< pj::JbufState * >(argp1);
  ecode2 = SWIG_AsVal_unsigned_SS_int(swig_obj[1], &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "JbufState_lost_set" "', argument " "2"" of type '" "unsigned int""'");
  } 
  arg2 = static_cast< unsigned int >(val2);
  if (arg1) (arg1)->lost = arg2;
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_JbufState_lost_get(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::JbufState *arg1 = (pj::JbufState *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  unsigned int result;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__JbufState, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "JbufState_lost_get" "', argument " "1"" of type '" "pj::JbufState *""'"); 
  }
  arg1 = reinterpret_cast< pj::JbufState * >(argp1);
  result = (unsigned int) ((arg1)->lost);
  resultobj = SWIG_From_unsigned_SS_int(static_cast< unsigned int >(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_JbufState_discard_set(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::JbufState *arg1 = (pj::JbufState *) 0 ;
  unsigned int arg2 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  unsigned int val2 ;
  int ecode2 = 0 ;
  PyObject *swig_obj[2] ;
  
  if (!SWIG_Python_UnpackTuple(args, "JbufState_discard_set", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__JbufState, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "JbufState_discard_set" "', argument " "1"" of type '" "pj::JbufState *""'"); 
  }
  arg1 = reinterpret_cast< pj::JbufState * >(argp1);
  ecode2 = SWIG_AsVal_unsigned_SS_int(swig_obj[1], &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "JbufState_discard_set" "', argument " "2"" of type '" "unsigned int""'");
  } 
  arg2 = static_cast< unsigned int >(val2);
  if (arg1) (arg1)->discard = arg2;
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_JbufState_discard_get(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::JbufState *arg1 = (pj::JbufState *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  unsigned int result;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__JbufState, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "JbufState_discard_get" "', argument " "1"" of type '" "pj::JbufState *""'"); 
  }
  arg1 = reinterpret_cast< pj::JbufState * >(argp1);
  result = (unsigned int) ((arg1)->discard);
  resultobj = SWIG_From_unsigned_SS_int(static_cast< unsigned int >(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_JbufState_empty_set(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::JbufState *arg1 = (pj::JbufState *) 0 ;
  unsigned int arg2 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  unsigned int val2 ;
  int ecode2 = 0 ;
  PyObject *swig_obj[2] ;
  
  if (!SWIG_Python_UnpackTuple(args, "JbufState_empty_set", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__JbufState, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "JbufState_empty_set" "', argument " "1"" of type '" "pj::JbufState *""'"); 
  }
  arg1 = reinterpret_cast< pj::JbufState * >(argp1);
  ecode2 = SWIG_AsVal_unsigned_SS_int(swig_obj[1], &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "JbufState_empty_set" "', argument " "2"" of type '" "unsigned int""'");
  } 
  arg2 = static_cast< unsigned int >(val2);
  if (arg1) (arg1)->empty = arg2;
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_JbufState_empty_get(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::JbufState *arg1 = (pj::JbufState *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  unsigned int result;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__JbufState, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "JbufState_empty_get" "', argument " "1"" of type '" "pj::JbufState *""'"); 
  }
  arg1 = reinterpret_cast< pj::JbufState * >(argp1);
  result = (unsigned int) ((arg1)->empty);
  resultobj = SWIG_From_unsigned_SS_int(static_cast< unsigned int >(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_new_JbufState(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::JbufState *result = 0 ;
  
  if (!SWIG_Python_UnpackTuple(args, "new_JbufState", 0, 0, 0)) SWIG_fail;
  result = (pj::JbufState *)new pj::JbufState();
  resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(result), SWIGTYPE_p_pj__JbufState, SWIG_POINTER_NEW |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_delete_JbufState(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::JbufState *arg1 = (pj::JbufState *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__JbufState, SWIG_POINTER_DISOWN |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "delete_JbufState" "', argument " "1"" of type '" "pj::JbufState *""'"); 
  }
  arg1 = reinterpret_cast< pj::JbufState * >(argp1);
  delete arg1;
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *JbufState_swigregister(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *obj;
  if (!SWIG_Python_UnpackTuple(args, "swigregister", 1, 1, &obj)) return NULL;
  SWIG_TypeNewClientData(SWIGTYPE_p_pj__JbufState, SWIG_NewClientData(obj));
  return SWIG_Py_Void();
}

SWIGINTERN PyObject *JbufState_swiginit(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  return SWIG_Python_InitShadowInstance(args);
}

SWIGINTERN PyObject *_wrap_SdpSession_wholeSdp_set(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::SdpSession *arg1 = (pj::SdpSession *) 0 ;
  pj::string *arg2 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  int res2 = SWIG_OLDOBJ ;
  PyObject *swig_obj[2] ;
  
  if (!SWIG_Python_UnpackTuple(args, "SdpSession_wholeSdp_set", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__SdpSession, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "SdpSession_wholeSdp_set" "', argument " "1"" of type '" "pj::SdpSession *""'"); 
  }
  arg1 = reinterpret_cast< pj::SdpSession * >(argp1);
  {
    std::string *ptr = (std::string *)0;
    res2 = SWIG_AsPtr_std_string(swig_obj[1], &ptr);
    if (!SWIG_IsOK(res2)) {
      SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "SdpSession_wholeSdp_set" "', argument " "2"" of type '" "pj::string const &""'"); 
    }
    if (!ptr) {
      SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "SdpSession_wholeSdp_set" "', argument " "2"" of type '" "pj::string const &""'"); 
    }
    arg2 = ptr;
  }
  if (arg1) (arg1)->wholeSdp = *arg2;
  resultobj = SWIG_Py_Void();
  if (SWIG_IsNewObj(res2)) delete arg2;
  return resultobj;
fail:
  if (SWIG_IsNewObj(res2)) delete arg2;
  return NULL;
}


SWIGINTERN PyObject *_wrap_SdpSession_wholeSdp_get(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::SdpSession *arg1 = (pj::SdpSession *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  pj::string *result = 0 ;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__SdpSession, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "SdpSession_wholeSdp_get" "', argument " "1"" of type '" "pj::SdpSession *""'"); 
  }
  arg1 = reinterpret_cast< pj::SdpSession * >(argp1);
  result = (pj::string *) & ((arg1)->wholeSdp);
  resultobj = SWIG_From_std_string(static_cast< std::string >(*result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_SdpSession_pjSdpSession_set(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::SdpSession *arg1 = (pj::SdpSession *) 0 ;
  void *arg2 = (void *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  int res2 ;
  PyObject *swig_obj[2] ;
  
  if (!SWIG_Python_UnpackTuple(args, "SdpSession_pjSdpSession_set", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__SdpSession, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "SdpSession_pjSdpSession_set" "', argument " "1"" of type '" "pj::SdpSession *""'"); 
  }
  arg1 = reinterpret_cast< pj::SdpSession * >(argp1);
  res2 = SWIG_ConvertPtr(swig_obj[1],SWIG_as_voidptrptr(&arg2), 0, SWIG_POINTER_DISOWN);
  if (!SWIG_IsOK(res2)) {
    SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "SdpSession_pjSdpSession_set" "', argument " "2"" of type '" "void *""'"); 
  }
  if (arg1) (arg1)->pjSdpSession = arg2;
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_SdpSession_pjSdpSession_get(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::SdpSession *arg1 = (pj::SdpSession *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  void *result = 0 ;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__SdpSession, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "SdpSession_pjSdpSession_get" "', argument " "1"" of type '" "pj::SdpSession *""'"); 
  }
  arg1 = reinterpret_cast< pj::SdpSession * >(argp1);
  result = (void *) ((arg1)->pjSdpSession);
  resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(result), SWIGTYPE_p_void, 0 |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_new_SdpSession(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::SdpSession *result = 0 ;
  
  if (!SWIG_Python_UnpackTuple(args, "new_SdpSession", 0, 0, 0)) SWIG_fail;
  result = (pj::SdpSession *)new pj::SdpSession();
  resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(result), SWIGTYPE_p_pj__SdpSession, SWIG_POINTER_NEW |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_delete_SdpSession(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::SdpSession *arg1 = (pj::SdpSession *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__SdpSession, SWIG_POINTER_DISOWN |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "delete_SdpSession" "', argument " "1"" of type '" "pj::SdpSession *""'"); 
  }
  arg1 = reinterpret_cast< pj::SdpSession * >(argp1);
  delete arg1;
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *SdpSession_swigregister(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *obj;
  if (!SWIG_Python_UnpackTuple(args, "swigregister", 1, 1, &obj)) return NULL;
  SWIG_TypeNewClientData(SWIGTYPE_p_pj__SdpSession, SWIG_NewClientData(obj));
  return SWIG_Py_Void();
}

SWIGINTERN PyObject *SdpSession_swiginit(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  return SWIG_Python_InitShadowInstance(args);
}

SWIGINTERN PyObject *_wrap_MediaTransportInfo_localRtpName_set(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::MediaTransportInfo *arg1 = (pj::MediaTransportInfo *) 0 ;
  pj::SocketAddress *arg2 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  int res2 = SWIG_OLDOBJ ;
  PyObject *swig_obj[2] ;
  
  if (!SWIG_Python_UnpackTuple(args, "MediaTransportInfo_localRtpName_set", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__MediaTransportInfo, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "MediaTransportInfo_localRtpName_set" "', argument " "1"" of type '" "pj::MediaTransportInfo *""'"); 
  }
  arg1 = reinterpret_cast< pj::MediaTransportInfo * >(argp1);
  {
    std::string *ptr = (std::string *)0;
    res2 = SWIG_AsPtr_std_string(swig_obj[1], &ptr);
    if (!SWIG_IsOK(res2)) {
      SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "MediaTransportInfo_localRtpName_set" "', argument " "2"" of type '" "pj::SocketAddress const &""'"); 
    }
    if (!ptr) {
      SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "MediaTransportInfo_localRtpName_set" "', argument " "2"" of type '" "pj::SocketAddress const &""'"); 
    }
    arg2 = ptr;
  }
  if (arg1) (arg1)->localRtpName = *arg2;
  resultobj = SWIG_Py_Void();
  if (SWIG_IsNewObj(res2)) delete arg2;
  return resultobj;
fail:
  if (SWIG_IsNewObj(res2)) delete arg2;
  return NULL;
}


SWIGINTERN PyObject *_wrap_MediaTransportInfo_localRtpName_get(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::MediaTransportInfo *arg1 = (pj::MediaTransportInfo *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  pj::SocketAddress *result = 0 ;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__MediaTransportInfo, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "MediaTransportInfo_localRtpName_get" "', argument " "1"" of type '" "pj::MediaTransportInfo *""'"); 
  }
  arg1 = reinterpret_cast< pj::MediaTransportInfo * >(argp1);
  result = (pj::SocketAddress *) & ((arg1)->localRtpName);
  resultobj = SWIG_From_std_string(static_cast< std::string >(*result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_MediaTransportInfo_localRtcpName_set(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::MediaTransportInfo *arg1 = (pj::MediaTransportInfo *) 0 ;
  pj::SocketAddress *arg2 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  int res2 = SWIG_OLDOBJ ;
  PyObject *swig_obj[2] ;
  
  if (!SWIG_Python_UnpackTuple(args, "MediaTransportInfo_localRtcpName_set", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__MediaTransportInfo, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "MediaTransportInfo_localRtcpName_set" "', argument " "1"" of type '" "pj::MediaTransportInfo *""'"); 
  }
  arg1 = reinterpret_cast< pj::MediaTransportInfo * >(argp1);
  {
    std::string *ptr = (std::string *)0;
    res2 = SWIG_AsPtr_std_string(swig_obj[1], &ptr);
    if (!SWIG_IsOK(res2)) {
      SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "MediaTransportInfo_localRtcpName_set" "', argument " "2"" of type '" "pj::SocketAddress const &""'"); 
    }
    if (!ptr) {
      SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "MediaTransportInfo_localRtcpName_set" "', argument " "2"" of type '" "pj::SocketAddress const &""'"); 
    }
    arg2 = ptr;
  }
  if (arg1) (arg1)->localRtcpName = *arg2;
  resultobj = SWIG_Py_Void();
  if (SWIG_IsNewObj(res2)) delete arg2;
  return resultobj;
fail:
  if (SWIG_IsNewObj(res2)) delete arg2;
  return NULL;
}


SWIGINTERN PyObject *_wrap_MediaTransportInfo_localRtcpName_get(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::MediaTransportInfo *arg1 = (pj::MediaTransportInfo *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  pj::SocketAddress *result = 0 ;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__MediaTransportInfo, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "MediaTransportInfo_localRtcpName_get" "', argument " "1"" of type '" "pj::MediaTransportInfo *""'"); 
  }
  arg1 = reinterpret_cast< pj::MediaTransportInfo * >(argp1);
  result = (pj::SocketAddress *) & ((arg1)->localRtcpName);
  resultobj = SWIG_From_std_string(static_cast< std::string >(*result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_MediaTransportInfo_srcRtpName_set(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::MediaTransportInfo *arg1 = (pj::MediaTransportInfo *) 0 ;
  pj::SocketAddress *arg2 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  int res2 = SWIG_OLDOBJ ;
  PyObject *swig_obj[2] ;
  
  if (!SWIG_Python_UnpackTuple(args, "MediaTransportInfo_srcRtpName_set", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__MediaTransportInfo, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "MediaTransportInfo_srcRtpName_set" "', argument " "1"" of type '" "pj::MediaTransportInfo *""'"); 
  }
  arg1 = reinterpret_cast< pj::MediaTransportInfo * >(argp1);
  {
    std::string *ptr = (std::string *)0;
    res2 = SWIG_AsPtr_std_string(swig_obj[1], &ptr);
    if (!SWIG_IsOK(res2)) {
      SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "MediaTransportInfo_srcRtpName_set" "', argument " "2"" of type '" "pj::SocketAddress const &""'"); 
    }
    if (!ptr) {
      SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "MediaTransportInfo_srcRtpName_set" "', argument " "2"" of type '" "pj::SocketAddress const &""'"); 
    }
    arg2 = ptr;
  }
  if (arg1) (arg1)->srcRtpName = *arg2;
  resultobj = SWIG_Py_Void();
  if (SWIG_IsNewObj(res2)) delete arg2;
  return resultobj;
fail:
  if (SWIG_IsNewObj(res2)) delete arg2;
  return NULL;
}


SWIGINTERN PyObject *_wrap_MediaTransportInfo_srcRtpName_get(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::MediaTransportInfo *arg1 = (pj::MediaTransportInfo *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  pj::SocketAddress *result = 0 ;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__MediaTransportInfo, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "MediaTransportInfo_srcRtpName_get" "', argument " "1"" of type '" "pj::MediaTransportInfo *""'"); 
  }
  arg1 = reinterpret_cast< pj::MediaTransportInfo * >(argp1);
  result = (pj::SocketAddress *) & ((arg1)->srcRtpName);
  resultobj = SWIG_From_std_string(static_cast< std::string >(*result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_MediaTransportInfo_srcRtcpName_set(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::MediaTransportInfo *arg1 = (pj::MediaTransportInfo *) 0 ;
  pj::SocketAddress *arg2 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  int res2 = SWIG_OLDOBJ ;
  PyObject *swig_obj[2] ;
  
  if (!SWIG_Python_UnpackTuple(args, "MediaTransportInfo_srcRtcpName_set", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__MediaTransportInfo, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "MediaTransportInfo_srcRtcpName_set" "', argument " "1"" of type '" "pj::MediaTransportInfo *""'"); 
  }
  arg1 = reinterpret_cast< pj::MediaTransportInfo * >(argp1);
  {
    std::string *ptr = (std::string *)0;
    res2 = SWIG_AsPtr_std_string(swig_obj[1], &ptr);
    if (!SWIG_IsOK(res2)) {
      SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "MediaTransportInfo_srcRtcpName_set" "', argument " "2"" of type '" "pj::SocketAddress const &""'"); 
    }
    if (!ptr) {
      SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "MediaTransportInfo_srcRtcpName_set" "', argument " "2"" of type '" "pj::SocketAddress const &""'"); 
    }
    arg2 = ptr;
  }
  if (arg1) (arg1)->srcRtcpName = *arg2;
  resultobj = SWIG_Py_Void();
  if (SWIG_IsNewObj(res2)) delete arg2;
  return resultobj;
fail:
  if (SWIG_IsNewObj(res2)) delete arg2;
  return NULL;
}


SWIGINTERN PyObject *_wrap_MediaTransportInfo_srcRtcpName_get(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::MediaTransportInfo *arg1 = (pj::MediaTransportInfo *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  pj::SocketAddress *result = 0 ;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__MediaTransportInfo, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "MediaTransportInfo_srcRtcpName_get" "', argument " "1"" of type '" "pj::MediaTransportInfo *""'"); 
  }
  arg1 = reinterpret_cast< pj::MediaTransportInfo * >(argp1);
  result = (pj::SocketAddress *) & ((arg1)->srcRtcpName);
  resultobj = SWIG_From_std_string(static_cast< std::string >(*result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_new_MediaTransportInfo(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::MediaTransportInfo *result = 0 ;
  
  if (!SWIG_Python_UnpackTuple(args, "new_MediaTransportInfo", 0, 0, 0)) SWIG_fail;
  result = (pj::MediaTransportInfo *)new pj::MediaTransportInfo();
  resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(result), SWIGTYPE_p_pj__MediaTransportInfo, SWIG_POINTER_NEW |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_delete_MediaTransportInfo(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::MediaTransportInfo *arg1 = (pj::MediaTransportInfo *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__MediaTransportInfo, SWIG_POINTER_DISOWN |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "delete_MediaTransportInfo" "', argument " "1"" of type '" "pj::MediaTransportInfo *""'"); 
  }
  arg1 = reinterpret_cast< pj::MediaTransportInfo * >(argp1);
  delete arg1;
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *MediaTransportInfo_swigregister(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *obj;
  if (!SWIG_Python_UnpackTuple(args, "swigregister", 1, 1, &obj)) return NULL;
  SWIG_TypeNewClientData(SWIGTYPE_p_pj__MediaTransportInfo, SWIG_NewClientData(obj));
  return SWIG_Py_Void();
}

SWIGINTERN PyObject *MediaTransportInfo_swiginit(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  return SWIG_Python_InitShadowInstance(args);
}

SWIGINTERN PyObject *_wrap_CallSetting_flag_set(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::CallSetting *arg1 = (pj::CallSetting *) 0 ;
  unsigned int arg2 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  unsigned int val2 ;
  int ecode2 = 0 ;
  PyObject *swig_obj[2] ;
  
  if (!SWIG_Python_UnpackTuple(args, "CallSetting_flag_set", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__CallSetting, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "CallSetting_flag_set" "', argument " "1"" of type '" "pj::CallSetting *""'"); 
  }
  arg1 = reinterpret_cast< pj::CallSetting * >(argp1);
  ecode2 = SWIG_AsVal_unsigned_SS_int(swig_obj[1], &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "CallSetting_flag_set" "', argument " "2"" of type '" "unsigned int""'");
  } 
  arg2 = static_cast< unsigned int >(val2);
  if (arg1) (arg1)->flag = arg2;
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_CallSetting_flag_get(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::CallSetting *arg1 = (pj::CallSetting *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  unsigned int result;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__CallSetting, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "CallSetting_flag_get" "', argument " "1"" of type '" "pj::CallSetting *""'"); 
  }
  arg1 = reinterpret_cast< pj::CallSetting * >(argp1);
  result = (unsigned int) ((arg1)->flag);
  resultobj = SWIG_From_unsigned_SS_int(static_cast< unsigned int >(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_CallSetting_reqKeyframeMethod_set(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::CallSetting *arg1 = (pj::CallSetting *) 0 ;
  unsigned int arg2 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  unsigned int val2 ;
  int ecode2 = 0 ;
  PyObject *swig_obj[2] ;
  
  if (!SWIG_Python_UnpackTuple(args, "CallSetting_reqKeyframeMethod_set", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__CallSetting, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "CallSetting_reqKeyframeMethod_set" "', argument " "1"" of type '" "pj::CallSetting *""'"); 
  }
  arg1 = reinterpret_cast< pj::CallSetting * >(argp1);
  ecode2 = SWIG_AsVal_unsigned_SS_int(swig_obj[1], &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "CallSetting_reqKeyframeMethod_set" "', argument " "2"" of type '" "unsigned int""'");
  } 
  arg2 = static_cast< unsigned int >(val2);
  if (arg1) (arg1)->reqKeyframeMethod = arg2;
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_CallSetting_reqKeyframeMethod_get(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::CallSetting *arg1 = (pj::CallSetting *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  unsigned int result;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__CallSetting, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "CallSetting_reqKeyframeMethod_get" "', argument " "1"" of type '" "pj::CallSetting *""'"); 
  }
  arg1 = reinterpret_cast< pj::CallSetting * >(argp1);
  result = (unsigned int) ((arg1)->reqKeyframeMethod);
  resultobj = SWIG_From_unsigned_SS_int(static_cast< unsigned int >(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_CallSetting_audioCount_set(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::CallSetting *arg1 = (pj::CallSetting *) 0 ;
  unsigned int arg2 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  unsigned int val2 ;
  int ecode2 = 0 ;
  PyObject *swig_obj[2] ;
  
  if (!SWIG_Python_UnpackTuple(args, "CallSetting_audioCount_set", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__CallSetting, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "CallSetting_audioCount_set" "', argument " "1"" of type '" "pj::CallSetting *""'"); 
  }
  arg1 = reinterpret_cast< pj::CallSetting * >(argp1);
  ecode2 = SWIG_AsVal_unsigned_SS_int(swig_obj[1], &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "CallSetting_audioCount_set" "', argument " "2"" of type '" "unsigned int""'");
  } 
  arg2 = static_cast< unsigned int >(val2);
  if (arg1) (arg1)->audioCount = arg2;
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_CallSetting_audioCount_get(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::CallSetting *arg1 = (pj::CallSetting *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  unsigned int result;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__CallSetting, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "CallSetting_audioCount_get" "', argument " "1"" of type '" "pj::CallSetting *""'"); 
  }
  arg1 = reinterpret_cast< pj::CallSetting * >(argp1);
  result = (unsigned int) ((arg1)->audioCount);
  resultobj = SWIG_From_unsigned_SS_int(static_cast< unsigned int >(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_CallSetting_videoCount_set(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::CallSetting *arg1 = (pj::CallSetting *) 0 ;
  unsigned int arg2 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  unsigned int val2 ;
  int ecode2 = 0 ;
  PyObject *swig_obj[2] ;
  
  if (!SWIG_Python_UnpackTuple(args, "CallSetting_videoCount_set", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__CallSetting, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "CallSetting_videoCount_set" "', argument " "1"" of type '" "pj::CallSetting *""'"); 
  }
  arg1 = reinterpret_cast< pj::CallSetting * >(argp1);
  ecode2 = SWIG_AsVal_unsigned_SS_int(swig_obj[1], &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "CallSetting_videoCount_set" "', argument " "2"" of type '" "unsigned int""'");
  } 
  arg2 = static_cast< unsigned int >(val2);
  if (arg1) (arg1)->videoCount = arg2;
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_CallSetting_videoCount_get(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::CallSetting *arg1 = (pj::CallSetting *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  unsigned int result;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__CallSetting, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "CallSetting_videoCount_get" "', argument " "1"" of type '" "pj::CallSetting *""'"); 
  }
  arg1 = reinterpret_cast< pj::CallSetting * >(argp1);
  result = (unsigned int) ((arg1)->videoCount);
  resultobj = SWIG_From_unsigned_SS_int(static_cast< unsigned int >(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_CallSetting_mediaDir_set(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::CallSetting *arg1 = (pj::CallSetting *) 0 ;
  pj::MediaDirVector *arg2 = (pj::MediaDirVector *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  void *argp2 = 0 ;
  int res2 = 0 ;
  PyObject *swig_obj[2] ;
  
  if (!SWIG_Python_UnpackTuple(args, "CallSetting_mediaDir_set", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__CallSetting, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "CallSetting_mediaDir_set" "', argument " "1"" of type '" "pj::CallSetting *""'"); 
  }
  arg1 = reinterpret_cast< pj::CallSetting * >(argp1);
  res2 = SWIG_ConvertPtr(swig_obj[1], &argp2,SWIGTYPE_p_std__vectorT_int_std__allocatorT_int_t_t, 0 |  0 );
  if (!SWIG_IsOK(res2)) {
    SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "CallSetting_mediaDir_set" "', argument " "2"" of type '" "pj::MediaDirVector *""'"); 
  }
  arg2 = reinterpret_cast< pj::MediaDirVector * >(argp2);
  if (arg1) (arg1)->mediaDir = *arg2;
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_CallSetting_mediaDir_get(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::CallSetting *arg1 = (pj::CallSetting *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  pj::MediaDirVector *result = 0 ;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__CallSetting, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "CallSetting_mediaDir_get" "', argument " "1"" of type '" "pj::CallSetting *""'"); 
  }
  arg1 = reinterpret_cast< pj::CallSetting * >(argp1);
  result = (pj::MediaDirVector *)& ((arg1)->mediaDir);
  resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(result), SWIGTYPE_p_std__vectorT_int_std__allocatorT_int_t_t, 0 |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_new_CallSetting__SWIG_0(PyObject *SWIGUNUSEDPARM(self), Py_ssize_t nobjs, PyObject **swig_obj) {
  PyObject *resultobj = 0;
  bool arg1 ;
  bool val1 ;
  int ecode1 = 0 ;
  pj::CallSetting *result = 0 ;
  
  if ((nobjs < 1) || (nobjs > 1)) SWIG_fail;
  ecode1 = SWIG_AsVal_bool(swig_obj[0], &val1);
  if (!SWIG_IsOK(ecode1)) {
    SWIG_exception_fail(SWIG_ArgError(ecode1), "in method '" "new_CallSetting" "', argument " "1"" of type '" "bool""'");
  } 
  arg1 = static_cast< bool >(val1);
  result = (pj::CallSetting *)new pj::CallSetting(arg1);
  resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(result), SWIGTYPE_p_pj__CallSetting, SWIG_POINTER_NEW |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_new_CallSetting__SWIG_1(PyObject *SWIGUNUSEDPARM(self), Py_ssize_t nobjs, PyObject **SWIGUNUSEDPARM(swig_obj)) {
  PyObject *resultobj = 0;
  pj::CallSetting *result = 0 ;
  
  if ((nobjs < 0) || (nobjs > 0)) SWIG_fail;
  result = (pj::CallSetting *)new pj::CallSetting();
  resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(result), SWIGTYPE_p_pj__CallSetting, SWIG_POINTER_NEW |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_new_CallSetting(PyObject *self, PyObject *args) {
  Py_ssize_t argc;
  PyObject *argv[2] = {
    0
  };
  
  if (!(argc = SWIG_Python_UnpackTuple(args, "new_CallSetting", 0, 1, argv))) SWIG_fail;
  --argc;
  if (argc == 0) {
    return _wrap_new_CallSetting__SWIG_1(self, argc, argv);
  }
  if (argc == 1) {
    int _v;
    {
      int res = SWIG_AsVal_bool(argv[0], NULL);
      _v = SWIG_CheckState(res);
    }
    if (_v) {
      return _wrap_new_CallSetting__SWIG_0(self, argc, argv);
    }
  }
  
fail:
  SWIG_Python_RaiseOrModifyTypeError("Wrong number or type of arguments for overloaded function 'new_CallSetting'.\n"
    "  Possible C/C++ prototypes are:\n"
    "    pj::CallSetting::CallSetting(bool)\n"
    "    pj::CallSetting::CallSetting()\n");
  return 0;
}


SWIGINTERN PyObject *_wrap_CallSetting_isEmpty(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::CallSetting *arg1 = (pj::CallSetting *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  bool result;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__CallSetting, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "CallSetting_isEmpty" "', argument " "1"" of type '" "pj::CallSetting const *""'"); 
  }
  arg1 = reinterpret_cast< pj::CallSetting * >(argp1);
  result = (bool)((pj::CallSetting const *)arg1)->isEmpty();
  resultobj = SWIG_From_bool(static_cast< bool >(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_delete_CallSetting(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::CallSetting *arg1 = (pj::CallSetting *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__CallSetting, SWIG_POINTER_DISOWN |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "delete_CallSetting" "', argument " "1"" of type '" "pj::CallSetting *""'"); 
  }
  arg1 = reinterpret_cast< pj::CallSetting * >(argp1);
  delete arg1;
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *CallSetting_swigregister(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *obj;
  if (!SWIG_Python_UnpackTuple(args, "swigregister", 1, 1, &obj)) return NULL;
  SWIG_TypeNewClientData(SWIGTYPE_p_pj__CallSetting, SWIG_NewClientData(obj));
  return SWIG_Py_Void();
}

SWIGINTERN PyObject *CallSetting_swiginit(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  return SWIG_Python_InitShadowInstance(args);
}

SWIGINTERN PyObject *_wrap_CallMediaInfo_index_set(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::CallMediaInfo *arg1 = (pj::CallMediaInfo *) 0 ;
  unsigned int arg2 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  unsigned int val2 ;
  int ecode2 = 0 ;
  PyObject *swig_obj[2] ;
  
  if (!SWIG_Python_UnpackTuple(args, "CallMediaInfo_index_set", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__CallMediaInfo, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "CallMediaInfo_index_set" "', argument " "1"" of type '" "pj::CallMediaInfo *""'"); 
  }
  arg1 = reinterpret_cast< pj::CallMediaInfo * >(argp1);
  ecode2 = SWIG_AsVal_unsigned_SS_int(swig_obj[1], &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "CallMediaInfo_index_set" "', argument " "2"" of type '" "unsigned int""'");
  } 
  arg2 = static_cast< unsigned int >(val2);
  if (arg1) (arg1)->index = arg2;
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_CallMediaInfo_index_get(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::CallMediaInfo *arg1 = (pj::CallMediaInfo *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  unsigned int result;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__CallMediaInfo, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "CallMediaInfo_index_get" "', argument " "1"" of type '" "pj::CallMediaInfo *""'"); 
  }
  arg1 = reinterpret_cast< pj::CallMediaInfo * >(argp1);
  result = (unsigned int) ((arg1)->index);
  resultobj = SWIG_From_unsigned_SS_int(static_cast< unsigned int >(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_CallMediaInfo_type_set(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::CallMediaInfo *arg1 = (pj::CallMediaInfo *) 0 ;
  pjmedia_type arg2 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  int val2 ;
  int ecode2 = 0 ;
  PyObject *swig_obj[2] ;
  
  if (!SWIG_Python_UnpackTuple(args, "CallMediaInfo_type_set", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__CallMediaInfo, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "CallMediaInfo_type_set" "', argument " "1"" of type '" "pj::CallMediaInfo *""'"); 
  }
  arg1 = reinterpret_cast< pj::CallMediaInfo * >(argp1);
  ecode2 = SWIG_AsVal_int(swig_obj[1], &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "CallMediaInfo_type_set" "', argument " "2"" of type '" "pjmedia_type""'");
  } 
  arg2 = static_cast< pjmedia_type >(val2);
  if (arg1) (arg1)->type = arg2;
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_CallMediaInfo_type_get(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::CallMediaInfo *arg1 = (pj::CallMediaInfo *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  pjmedia_type result;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__CallMediaInfo, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "CallMediaInfo_type_get" "', argument " "1"" of type '" "pj::CallMediaInfo *""'"); 
  }
  arg1 = reinterpret_cast< pj::CallMediaInfo * >(argp1);
  result = (pjmedia_type) ((arg1)->type);
  resultobj = SWIG_From_int(static_cast< int >(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_CallMediaInfo_dir_set(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::CallMediaInfo *arg1 = (pj::CallMediaInfo *) 0 ;
  pjmedia_dir arg2 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  int val2 ;
  int ecode2 = 0 ;
  PyObject *swig_obj[2] ;
  
  if (!SWIG_Python_UnpackTuple(args, "CallMediaInfo_dir_set", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__CallMediaInfo, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "CallMediaInfo_dir_set" "', argument " "1"" of type '" "pj::CallMediaInfo *""'"); 
  }
  arg1 = reinterpret_cast< pj::CallMediaInfo * >(argp1);
  ecode2 = SWIG_AsVal_int(swig_obj[1], &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "CallMediaInfo_dir_set" "', argument " "2"" of type '" "pjmedia_dir""'");
  } 
  arg2 = static_cast< pjmedia_dir >(val2);
  if (arg1) (arg1)->dir = arg2;
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_CallMediaInfo_dir_get(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::CallMediaInfo *arg1 = (pj::CallMediaInfo *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  pjmedia_dir result;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__CallMediaInfo, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "CallMediaInfo_dir_get" "', argument " "1"" of type '" "pj::CallMediaInfo *""'"); 
  }
  arg1 = reinterpret_cast< pj::CallMediaInfo * >(argp1);
  result = (pjmedia_dir) ((arg1)->dir);
  resultobj = SWIG_From_int(static_cast< int >(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_CallMediaInfo_status_set(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::CallMediaInfo *arg1 = (pj::CallMediaInfo *) 0 ;
  pjsua_call_media_status arg2 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  int val2 ;
  int ecode2 = 0 ;
  PyObject *swig_obj[2] ;
  
  if (!SWIG_Python_UnpackTuple(args, "CallMediaInfo_status_set", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__CallMediaInfo, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "CallMediaInfo_status_set" "', argument " "1"" of type '" "pj::CallMediaInfo *""'"); 
  }
  arg1 = reinterpret_cast< pj::CallMediaInfo * >(argp1);
  ecode2 = SWIG_AsVal_int(swig_obj[1], &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "CallMediaInfo_status_set" "', argument " "2"" of type '" "pjsua_call_media_status""'");
  } 
  arg2 = static_cast< pjsua_call_media_status >(val2);
  if (arg1) (arg1)->status = arg2;
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_CallMediaInfo_status_get(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::CallMediaInfo *arg1 = (pj::CallMediaInfo *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  pjsua_call_media_status result;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__CallMediaInfo, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "CallMediaInfo_status_get" "', argument " "1"" of type '" "pj::CallMediaInfo *""'"); 
  }
  arg1 = reinterpret_cast< pj::CallMediaInfo * >(argp1);
  result = (pjsua_call_media_status) ((arg1)->status);
  resultobj = SWIG_From_int(static_cast< int >(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_CallMediaInfo_audioConfSlot_set(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::CallMediaInfo *arg1 = (pj::CallMediaInfo *) 0 ;
  int arg2 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  int val2 ;
  int ecode2 = 0 ;
  PyObject *swig_obj[2] ;
  
  if (!SWIG_Python_UnpackTuple(args, "CallMediaInfo_audioConfSlot_set", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__CallMediaInfo, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "CallMediaInfo_audioConfSlot_set" "', argument " "1"" of type '" "pj::CallMediaInfo *""'"); 
  }
  arg1 = reinterpret_cast< pj::CallMediaInfo * >(argp1);
  ecode2 = SWIG_AsVal_int(swig_obj[1], &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "CallMediaInfo_audioConfSlot_set" "', argument " "2"" of type '" "int""'");
  } 
  arg2 = static_cast< int >(val2);
  if (arg1) (arg1)->audioConfSlot = arg2;
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_CallMediaInfo_audioConfSlot_get(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::CallMediaInfo *arg1 = (pj::CallMediaInfo *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  int result;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__CallMediaInfo, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "CallMediaInfo_audioConfSlot_get" "', argument " "1"" of type '" "pj::CallMediaInfo *""'"); 
  }
  arg1 = reinterpret_cast< pj::CallMediaInfo * >(argp1);
  result = (int) ((arg1)->audioConfSlot);
  resultobj = SWIG_From_int(static_cast< int >(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_CallMediaInfo_videoIncomingWindowId_set(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::CallMediaInfo *arg1 = (pj::CallMediaInfo *) 0 ;
  pjsua_vid_win_id arg2 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  int val2 ;
  int ecode2 = 0 ;
  PyObject *swig_obj[2] ;
  
  if (!SWIG_Python_UnpackTuple(args, "CallMediaInfo_videoIncomingWindowId_set", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__CallMediaInfo, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "CallMediaInfo_videoIncomingWindowId_set" "', argument " "1"" of type '" "pj::CallMediaInfo *""'"); 
  }
  arg1 = reinterpret_cast< pj::CallMediaInfo * >(argp1);
  ecode2 = SWIG_AsVal_int(swig_obj[1], &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "CallMediaInfo_videoIncomingWindowId_set" "', argument " "2"" of type '" "pjsua_vid_win_id""'");
  } 
  arg2 = static_cast< pjsua_vid_win_id >(val2);
  if (arg1) (arg1)->videoIncomingWindowId = arg2;
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_CallMediaInfo_videoIncomingWindowId_get(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::CallMediaInfo *arg1 = (pj::CallMediaInfo *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  pjsua_vid_win_id result;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__CallMediaInfo, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "CallMediaInfo_videoIncomingWindowId_get" "', argument " "1"" of type '" "pj::CallMediaInfo *""'"); 
  }
  arg1 = reinterpret_cast< pj::CallMediaInfo * >(argp1);
  result = (pjsua_vid_win_id) ((arg1)->videoIncomingWindowId);
  resultobj = SWIG_From_int(static_cast< int >(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_CallMediaInfo_videoWindow_set(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::CallMediaInfo *arg1 = (pj::CallMediaInfo *) 0 ;
  pj::VideoWindow *arg2 = (pj::VideoWindow *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  void *argp2 = 0 ;
  int res2 = 0 ;
  PyObject *swig_obj[2] ;
  
  if (!SWIG_Python_UnpackTuple(args, "CallMediaInfo_videoWindow_set", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__CallMediaInfo, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "CallMediaInfo_videoWindow_set" "', argument " "1"" of type '" "pj::CallMediaInfo *""'"); 
  }
  arg1 = reinterpret_cast< pj::CallMediaInfo * >(argp1);
  res2 = SWIG_ConvertPtr(swig_obj[1], &argp2,SWIGTYPE_p_pj__VideoWindow, 0 |  0 );
  if (!SWIG_IsOK(res2)) {
    SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "CallMediaInfo_videoWindow_set" "', argument " "2"" of type '" "pj::VideoWindow *""'"); 
  }
  arg2 = reinterpret_cast< pj::VideoWindow * >(argp2);
  if (arg1) (arg1)->videoWindow = *arg2;
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_CallMediaInfo_videoWindow_get(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::CallMediaInfo *arg1 = (pj::CallMediaInfo *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  pj::VideoWindow *result = 0 ;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__CallMediaInfo, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "CallMediaInfo_videoWindow_get" "', argument " "1"" of type '" "pj::CallMediaInfo *""'"); 
  }
  arg1 = reinterpret_cast< pj::CallMediaInfo * >(argp1);
  result = (pj::VideoWindow *)& ((arg1)->videoWindow);
  resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(result), SWIGTYPE_p_pj__VideoWindow, 0 |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_CallMediaInfo_videoCapDev_set(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::CallMediaInfo *arg1 = (pj::CallMediaInfo *) 0 ;
  pjmedia_vid_dev_index arg2 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  int val2 ;
  int ecode2 = 0 ;
  PyObject *swig_obj[2] ;
  
  if (!SWIG_Python_UnpackTuple(args, "CallMediaInfo_videoCapDev_set", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__CallMediaInfo, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "CallMediaInfo_videoCapDev_set" "', argument " "1"" of type '" "pj::CallMediaInfo *""'"); 
  }
  arg1 = reinterpret_cast< pj::CallMediaInfo * >(argp1);
  ecode2 = SWIG_AsVal_int(swig_obj[1], &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "CallMediaInfo_videoCapDev_set" "', argument " "2"" of type '" "pjmedia_vid_dev_index""'");
  } 
  arg2 = static_cast< pjmedia_vid_dev_index >(val2);
  if (arg1) (arg1)->videoCapDev = arg2;
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_CallMediaInfo_videoCapDev_get(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::CallMediaInfo *arg1 = (pj::CallMediaInfo *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  pjmedia_vid_dev_index result;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__CallMediaInfo, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "CallMediaInfo_videoCapDev_get" "', argument " "1"" of type '" "pj::CallMediaInfo *""'"); 
  }
  arg1 = reinterpret_cast< pj::CallMediaInfo * >(argp1);
  result = (pjmedia_vid_dev_index) ((arg1)->videoCapDev);
  resultobj = SWIG_From_int(static_cast< int >(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_new_CallMediaInfo(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::CallMediaInfo *result = 0 ;
  
  if (!SWIG_Python_UnpackTuple(args, "new_CallMediaInfo", 0, 0, 0)) SWIG_fail;
  result = (pj::CallMediaInfo *)new pj::CallMediaInfo();
  resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(result), SWIGTYPE_p_pj__CallMediaInfo, SWIG_POINTER_NEW |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_delete_CallMediaInfo(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::CallMediaInfo *arg1 = (pj::CallMediaInfo *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__CallMediaInfo, SWIG_POINTER_DISOWN |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "delete_CallMediaInfo" "', argument " "1"" of type '" "pj::CallMediaInfo *""'"); 
  }
  arg1 = reinterpret_cast< pj::CallMediaInfo * >(argp1);
  delete arg1;
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *CallMediaInfo_swigregister(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *obj;
  if (!SWIG_Python_UnpackTuple(args, "swigregister", 1, 1, &obj)) return NULL;
  SWIG_TypeNewClientData(SWIGTYPE_p_pj__CallMediaInfo, SWIG_NewClientData(obj));
  return SWIG_Py_Void();
}

SWIGINTERN PyObject *CallMediaInfo_swiginit(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  return SWIG_Python_InitShadowInstance(args);
}

SWIGINTERN PyObject *_wrap_CallInfo_id_set(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::CallInfo *arg1 = (pj::CallInfo *) 0 ;
  pjsua_call_id arg2 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  int val2 ;
  int ecode2 = 0 ;
  PyObject *swig_obj[2] ;
  
  if (!SWIG_Python_UnpackTuple(args, "CallInfo_id_set", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__CallInfo, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "CallInfo_id_set" "', argument " "1"" of type '" "pj::CallInfo *""'"); 
  }
  arg1 = reinterpret_cast< pj::CallInfo * >(argp1);
  ecode2 = SWIG_AsVal_int(swig_obj[1], &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "CallInfo_id_set" "', argument " "2"" of type '" "pjsua_call_id""'");
  } 
  arg2 = static_cast< pjsua_call_id >(val2);
  if (arg1) (arg1)->id = arg2;
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_CallInfo_id_get(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::CallInfo *arg1 = (pj::CallInfo *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  pjsua_call_id result;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__CallInfo, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "CallInfo_id_get" "', argument " "1"" of type '" "pj::CallInfo *""'"); 
  }
  arg1 = reinterpret_cast< pj::CallInfo * >(argp1);
  result = (pjsua_call_id) ((arg1)->id);
  resultobj = SWIG_From_int(static_cast< int >(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_CallInfo_role_set(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::CallInfo *arg1 = (pj::CallInfo *) 0 ;
  pjsip_role_e arg2 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  int val2 ;
  int ecode2 = 0 ;
  PyObject *swig_obj[2] ;
  
  if (!SWIG_Python_UnpackTuple(args, "CallInfo_role_set", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__CallInfo, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "CallInfo_role_set" "', argument " "1"" of type '" "pj::CallInfo *""'"); 
  }
  arg1 = reinterpret_cast< pj::CallInfo * >(argp1);
  ecode2 = SWIG_AsVal_int(swig_obj[1], &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "CallInfo_role_set" "', argument " "2"" of type '" "pjsip_role_e""'");
  } 
  arg2 = static_cast< pjsip_role_e >(val2);
  if (arg1) (arg1)->role = arg2;
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_CallInfo_role_get(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::CallInfo *arg1 = (pj::CallInfo *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  pjsip_role_e result;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__CallInfo, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "CallInfo_role_get" "', argument " "1"" of type '" "pj::CallInfo *""'"); 
  }
  arg1 = reinterpret_cast< pj::CallInfo * >(argp1);
  result = (pjsip_role_e) ((arg1)->role);
  resultobj = SWIG_From_int(static_cast< int >(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_CallInfo_accId_set(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::CallInfo *arg1 = (pj::CallInfo *) 0 ;
  pjsua_acc_id arg2 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  int val2 ;
  int ecode2 = 0 ;
  PyObject *swig_obj[2] ;
  
  if (!SWIG_Python_UnpackTuple(args, "CallInfo_accId_set", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__CallInfo, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "CallInfo_accId_set" "', argument " "1"" of type '" "pj::CallInfo *""'"); 
  }
  arg1 = reinterpret_cast< pj::CallInfo * >(argp1);
  ecode2 = SWIG_AsVal_int(swig_obj[1], &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "CallInfo_accId_set" "', argument " "2"" of type '" "pjsua_acc_id""'");
  } 
  arg2 = static_cast< pjsua_acc_id >(val2);
  if (arg1) (arg1)->accId = arg2;
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_CallInfo_accId_get(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::CallInfo *arg1 = (pj::CallInfo *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  pjsua_acc_id result;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__CallInfo, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "CallInfo_accId_get" "', argument " "1"" of type '" "pj::CallInfo *""'"); 
  }
  arg1 = reinterpret_cast< pj::CallInfo * >(argp1);
  result = (pjsua_acc_id) ((arg1)->accId);
  resultobj = SWIG_From_int(static_cast< int >(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_CallInfo_localUri_set(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::CallInfo *arg1 = (pj::CallInfo *) 0 ;
  pj::string *arg2 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  int res2 = SWIG_OLDOBJ ;
  PyObject *swig_obj[2] ;
  
  if (!SWIG_Python_UnpackTuple(args, "CallInfo_localUri_set", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__CallInfo, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "CallInfo_localUri_set" "', argument " "1"" of type '" "pj::CallInfo *""'"); 
  }
  arg1 = reinterpret_cast< pj::CallInfo * >(argp1);
  {
    std::string *ptr = (std::string *)0;
    res2 = SWIG_AsPtr_std_string(swig_obj[1], &ptr);
    if (!SWIG_IsOK(res2)) {
      SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "CallInfo_localUri_set" "', argument " "2"" of type '" "pj::string const &""'"); 
    }
    if (!ptr) {
      SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "CallInfo_localUri_set" "', argument " "2"" of type '" "pj::string const &""'"); 
    }
    arg2 = ptr;
  }
  if (arg1) (arg1)->localUri = *arg2;
  resultobj = SWIG_Py_Void();
  if (SWIG_IsNewObj(res2)) delete arg2;
  return resultobj;
fail:
  if (SWIG_IsNewObj(res2)) delete arg2;
  return NULL;
}


SWIGINTERN PyObject *_wrap_CallInfo_localUri_get(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::CallInfo *arg1 = (pj::CallInfo *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  pj::string *result = 0 ;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__CallInfo, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "CallInfo_localUri_get" "', argument " "1"" of type '" "pj::CallInfo *""'"); 
  }
  arg1 = reinterpret_cast< pj::CallInfo * >(argp1);
  result = (pj::string *) & ((arg1)->localUri);
  resultobj = SWIG_From_std_string(static_cast< std::string >(*result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_CallInfo_localContact_set(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::CallInfo *arg1 = (pj::CallInfo *) 0 ;
  pj::string *arg2 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  int res2 = SWIG_OLDOBJ ;
  PyObject *swig_obj[2] ;
  
  if (!SWIG_Python_UnpackTuple(args, "CallInfo_localContact_set", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__CallInfo, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "CallInfo_localContact_set" "', argument " "1"" of type '" "pj::CallInfo *""'"); 
  }
  arg1 = reinterpret_cast< pj::CallInfo * >(argp1);
  {
    std::string *ptr = (std::string *)0;
    res2 = SWIG_AsPtr_std_string(swig_obj[1], &ptr);
    if (!SWIG_IsOK(res2)) {
      SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "CallInfo_localContact_set" "', argument " "2"" of type '" "pj::string const &""'"); 
    }
    if (!ptr) {
      SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "CallInfo_localContact_set" "', argument " "2"" of type '" "pj::string const &""'"); 
    }
    arg2 = ptr;
  }
  if (arg1) (arg1)->localContact = *arg2;
  resultobj = SWIG_Py_Void();
  if (SWIG_IsNewObj(res2)) delete arg2;
  return resultobj;
fail:
  if (SWIG_IsNewObj(res2)) delete arg2;
  return NULL;
}


SWIGINTERN PyObject *_wrap_CallInfo_localContact_get(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::CallInfo *arg1 = (pj::CallInfo *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  pj::string *result = 0 ;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__CallInfo, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "CallInfo_localContact_get" "', argument " "1"" of type '" "pj::CallInfo *""'"); 
  }
  arg1 = reinterpret_cast< pj::CallInfo * >(argp1);
  result = (pj::string *) & ((arg1)->localContact);
  resultobj = SWIG_From_std_string(static_cast< std::string >(*result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_CallInfo_remoteUri_set(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::CallInfo *arg1 = (pj::CallInfo *) 0 ;
  pj::string *arg2 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  int res2 = SWIG_OLDOBJ ;
  PyObject *swig_obj[2] ;
  
  if (!SWIG_Python_UnpackTuple(args, "CallInfo_remoteUri_set", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__CallInfo, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "CallInfo_remoteUri_set" "', argument " "1"" of type '" "pj::CallInfo *""'"); 
  }
  arg1 = reinterpret_cast< pj::CallInfo * >(argp1);
  {
    std::string *ptr = (std::string *)0;
    res2 = SWIG_AsPtr_std_string(swig_obj[1], &ptr);
    if (!SWIG_IsOK(res2)) {
      SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "CallInfo_remoteUri_set" "', argument " "2"" of type '" "pj::string const &""'"); 
    }
    if (!ptr) {
      SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "CallInfo_remoteUri_set" "', argument " "2"" of type '" "pj::string const &""'"); 
    }
    arg2 = ptr;
  }
  if (arg1) (arg1)->remoteUri = *arg2;
  resultobj = SWIG_Py_Void();
  if (SWIG_IsNewObj(res2)) delete arg2;
  return resultobj;
fail:
  if (SWIG_IsNewObj(res2)) delete arg2;
  return NULL;
}


SWIGINTERN PyObject *_wrap_CallInfo_remoteUri_get(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::CallInfo *arg1 = (pj::CallInfo *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  pj::string *result = 0 ;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__CallInfo, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "CallInfo_remoteUri_get" "', argument " "1"" of type '" "pj::CallInfo *""'"); 
  }
  arg1 = reinterpret_cast< pj::CallInfo * >(argp1);
  result = (pj::string *) & ((arg1)->remoteUri);
  resultobj = SWIG_From_std_string(static_cast< std::string >(*result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_CallInfo_remoteContact_set(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::CallInfo *arg1 = (pj::CallInfo *) 0 ;
  pj::string *arg2 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  int res2 = SWIG_OLDOBJ ;
  PyObject *swig_obj[2] ;
  
  if (!SWIG_Python_UnpackTuple(args, "CallInfo_remoteContact_set", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__CallInfo, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "CallInfo_remoteContact_set" "', argument " "1"" of type '" "pj::CallInfo *""'"); 
  }
  arg1 = reinterpret_cast< pj::CallInfo * >(argp1);
  {
    std::string *ptr = (std::string *)0;
    res2 = SWIG_AsPtr_std_string(swig_obj[1], &ptr);
    if (!SWIG_IsOK(res2)) {
      SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "CallInfo_remoteContact_set" "', argument " "2"" of type '" "pj::string const &""'"); 
    }
    if (!ptr) {
      SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "CallInfo_remoteContact_set" "', argument " "2"" of type '" "pj::string const &""'"); 
    }
    arg2 = ptr;
  }
  if (arg1) (arg1)->remoteContact = *arg2;
  resultobj = SWIG_Py_Void();
  if (SWIG_IsNewObj(res2)) delete arg2;
  return resultobj;
fail:
  if (SWIG_IsNewObj(res2)) delete arg2;
  return NULL;
}


SWIGINTERN PyObject *_wrap_CallInfo_remoteContact_get(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::CallInfo *arg1 = (pj::CallInfo *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  pj::string *result = 0 ;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__CallInfo, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "CallInfo_remoteContact_get" "', argument " "1"" of type '" "pj::CallInfo *""'"); 
  }
  arg1 = reinterpret_cast< pj::CallInfo * >(argp1);
  result = (pj::string *) & ((arg1)->remoteContact);
  resultobj = SWIG_From_std_string(static_cast< std::string >(*result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_CallInfo_callIdString_set(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::CallInfo *arg1 = (pj::CallInfo *) 0 ;
  pj::string *arg2 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  int res2 = SWIG_OLDOBJ ;
  PyObject *swig_obj[2] ;
  
  if (!SWIG_Python_UnpackTuple(args, "CallInfo_callIdString_set", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__CallInfo, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "CallInfo_callIdString_set" "', argument " "1"" of type '" "pj::CallInfo *""'"); 
  }
  arg1 = reinterpret_cast< pj::CallInfo * >(argp1);
  {
    std::string *ptr = (std::string *)0;
    res2 = SWIG_AsPtr_std_string(swig_obj[1], &ptr);
    if (!SWIG_IsOK(res2)) {
      SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "CallInfo_callIdString_set" "', argument " "2"" of type '" "pj::string const &""'"); 
    }
    if (!ptr) {
      SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "CallInfo_callIdString_set" "', argument " "2"" of type '" "pj::string const &""'"); 
    }
    arg2 = ptr;
  }
  if (arg1) (arg1)->callIdString = *arg2;
  resultobj = SWIG_Py_Void();
  if (SWIG_IsNewObj(res2)) delete arg2;
  return resultobj;
fail:
  if (SWIG_IsNewObj(res2)) delete arg2;
  return NULL;
}


SWIGINTERN PyObject *_wrap_CallInfo_callIdString_get(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::CallInfo *arg1 = (pj::CallInfo *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  pj::string *result = 0 ;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__CallInfo, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "CallInfo_callIdString_get" "', argument " "1"" of type '" "pj::CallInfo *""'"); 
  }
  arg1 = reinterpret_cast< pj::CallInfo * >(argp1);
  result = (pj::string *) & ((arg1)->callIdString);
  resultobj = SWIG_From_std_string(static_cast< std::string >(*result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_CallInfo_setting_set(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::CallInfo *arg1 = (pj::CallInfo *) 0 ;
  pj::CallSetting *arg2 = (pj::CallSetting *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  void *argp2 = 0 ;
  int res2 = 0 ;
  PyObject *swig_obj[2] ;
  
  if (!SWIG_Python_UnpackTuple(args, "CallInfo_setting_set", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__CallInfo, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "CallInfo_setting_set" "', argument " "1"" of type '" "pj::CallInfo *""'"); 
  }
  arg1 = reinterpret_cast< pj::CallInfo * >(argp1);
  res2 = SWIG_ConvertPtr(swig_obj[1], &argp2,SWIGTYPE_p_pj__CallSetting, 0 |  0 );
  if (!SWIG_IsOK(res2)) {
    SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "CallInfo_setting_set" "', argument " "2"" of type '" "pj::CallSetting *""'"); 
  }
  arg2 = reinterpret_cast< pj::CallSetting * >(argp2);
  if (arg1) (arg1)->setting = *arg2;
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_CallInfo_setting_get(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::CallInfo *arg1 = (pj::CallInfo *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  pj::CallSetting *result = 0 ;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__CallInfo, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "CallInfo_setting_get" "', argument " "1"" of type '" "pj::CallInfo *""'"); 
  }
  arg1 = reinterpret_cast< pj::CallInfo * >(argp1);
  result = (pj::CallSetting *)& ((arg1)->setting);
  resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(result), SWIGTYPE_p_pj__CallSetting, 0 |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_CallInfo_state_set(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::CallInfo *arg1 = (pj::CallInfo *) 0 ;
  pjsip_inv_state arg2 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  int val2 ;
  int ecode2 = 0 ;
  PyObject *swig_obj[2] ;
  
  if (!SWIG_Python_UnpackTuple(args, "CallInfo_state_set", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__CallInfo, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "CallInfo_state_set" "', argument " "1"" of type '" "pj::CallInfo *""'"); 
  }
  arg1 = reinterpret_cast< pj::CallInfo * >(argp1);
  ecode2 = SWIG_AsVal_int(swig_obj[1], &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "CallInfo_state_set" "', argument " "2"" of type '" "pjsip_inv_state""'");
  } 
  arg2 = static_cast< pjsip_inv_state >(val2);
  if (arg1) (arg1)->state = arg2;
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_CallInfo_state_get(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::CallInfo *arg1 = (pj::CallInfo *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  pjsip_inv_state result;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__CallInfo, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "CallInfo_state_get" "', argument " "1"" of type '" "pj::CallInfo *""'"); 
  }
  arg1 = reinterpret_cast< pj::CallInfo * >(argp1);
  result = (pjsip_inv_state) ((arg1)->state);
  resultobj = SWIG_From_int(static_cast< int >(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_CallInfo_stateText_set(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::CallInfo *arg1 = (pj::CallInfo *) 0 ;
  pj::string *arg2 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  int res2 = SWIG_OLDOBJ ;
  PyObject *swig_obj[2] ;
  
  if (!SWIG_Python_UnpackTuple(args, "CallInfo_stateText_set", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__CallInfo, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "CallInfo_stateText_set" "', argument " "1"" of type '" "pj::CallInfo *""'"); 
  }
  arg1 = reinterpret_cast< pj::CallInfo * >(argp1);
  {
    std::string *ptr = (std::string *)0;
    res2 = SWIG_AsPtr_std_string(swig_obj[1], &ptr);
    if (!SWIG_IsOK(res2)) {
      SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "CallInfo_stateText_set" "', argument " "2"" of type '" "pj::string const &""'"); 
    }
    if (!ptr) {
      SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "CallInfo_stateText_set" "', argument " "2"" of type '" "pj::string const &""'"); 
    }
    arg2 = ptr;
  }
  if (arg1) (arg1)->stateText = *arg2;
  resultobj = SWIG_Py_Void();
  if (SWIG_IsNewObj(res2)) delete arg2;
  return resultobj;
fail:
  if (SWIG_IsNewObj(res2)) delete arg2;
  return NULL;
}


SWIGINTERN PyObject *_wrap_CallInfo_stateText_get(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::CallInfo *arg1 = (pj::CallInfo *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  pj::string *result = 0 ;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__CallInfo, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "CallInfo_stateText_get" "', argument " "1"" of type '" "pj::CallInfo *""'"); 
  }
  arg1 = reinterpret_cast< pj::CallInfo * >(argp1);
  result = (pj::string *) & ((arg1)->stateText);
  resultobj = SWIG_From_std_string(static_cast< std::string >(*result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_CallInfo_lastStatusCode_set(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::CallInfo *arg1 = (pj::CallInfo *) 0 ;
  pjsip_status_code arg2 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  int val2 ;
  int ecode2 = 0 ;
  PyObject *swig_obj[2] ;
  
  if (!SWIG_Python_UnpackTuple(args, "CallInfo_lastStatusCode_set", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__CallInfo, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "CallInfo_lastStatusCode_set" "', argument " "1"" of type '" "pj::CallInfo *""'"); 
  }
  arg1 = reinterpret_cast< pj::CallInfo * >(argp1);
  ecode2 = SWIG_AsVal_int(swig_obj[1], &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "CallInfo_lastStatusCode_set" "', argument " "2"" of type '" "pjsip_status_code""'");
  } 
  arg2 = static_cast< pjsip_status_code >(val2);
  if (arg1) (arg1)->lastStatusCode = arg2;
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_CallInfo_lastStatusCode_get(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::CallInfo *arg1 = (pj::CallInfo *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  pjsip_status_code result;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__CallInfo, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "CallInfo_lastStatusCode_get" "', argument " "1"" of type '" "pj::CallInfo *""'"); 
  }
  arg1 = reinterpret_cast< pj::CallInfo * >(argp1);
  result = (pjsip_status_code) ((arg1)->lastStatusCode);
  resultobj = SWIG_From_int(static_cast< int >(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_CallInfo_lastReason_set(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::CallInfo *arg1 = (pj::CallInfo *) 0 ;
  pj::string *arg2 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  int res2 = SWIG_OLDOBJ ;
  PyObject *swig_obj[2] ;
  
  if (!SWIG_Python_UnpackTuple(args, "CallInfo_lastReason_set", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__CallInfo, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "CallInfo_lastReason_set" "', argument " "1"" of type '" "pj::CallInfo *""'"); 
  }
  arg1 = reinterpret_cast< pj::CallInfo * >(argp1);
  {
    std::string *ptr = (std::string *)0;
    res2 = SWIG_AsPtr_std_string(swig_obj[1], &ptr);
    if (!SWIG_IsOK(res2)) {
      SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "CallInfo_lastReason_set" "', argument " "2"" of type '" "pj::string const &""'"); 
    }
    if (!ptr) {
      SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "CallInfo_lastReason_set" "', argument " "2"" of type '" "pj::string const &""'"); 
    }
    arg2 = ptr;
  }
  if (arg1) (arg1)->lastReason = *arg2;
  resultobj = SWIG_Py_Void();
  if (SWIG_IsNewObj(res2)) delete arg2;
  return resultobj;
fail:
  if (SWIG_IsNewObj(res2)) delete arg2;
  return NULL;
}


SWIGINTERN PyObject *_wrap_CallInfo_lastReason_get(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::CallInfo *arg1 = (pj::CallInfo *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  pj::string *result = 0 ;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__CallInfo, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "CallInfo_lastReason_get" "', argument " "1"" of type '" "pj::CallInfo *""'"); 
  }
  arg1 = reinterpret_cast< pj::CallInfo * >(argp1);
  result = (pj::string *) & ((arg1)->lastReason);
  resultobj = SWIG_From_std_string(static_cast< std::string >(*result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_CallInfo_media_set(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::CallInfo *arg1 = (pj::CallInfo *) 0 ;
  pj::CallMediaInfoVector *arg2 = (pj::CallMediaInfoVector *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  void *argp2 = 0 ;
  int res2 = 0 ;
  PyObject *swig_obj[2] ;
  
  if (!SWIG_Python_UnpackTuple(args, "CallInfo_media_set", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__CallInfo, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "CallInfo_media_set" "', argument " "1"" of type '" "pj::CallInfo *""'"); 
  }
  arg1 = reinterpret_cast< pj::CallInfo * >(argp1);
  res2 = SWIG_ConvertPtr(swig_obj[1], &argp2,SWIGTYPE_p_std__vectorT_pj__CallMediaInfo_std__allocatorT_pj__CallMediaInfo_t_t, 0 |  0 );
  if (!SWIG_IsOK(res2)) {
    SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "CallInfo_media_set" "', argument " "2"" of type '" "pj::CallMediaInfoVector *""'"); 
  }
  arg2 = reinterpret_cast< pj::CallMediaInfoVector * >(argp2);
  if (arg1) (arg1)->media = *arg2;
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_CallInfo_media_get(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::CallInfo *arg1 = (pj::CallInfo *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  pj::CallMediaInfoVector *result = 0 ;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__CallInfo, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "CallInfo_media_get" "', argument " "1"" of type '" "pj::CallInfo *""'"); 
  }
  arg1 = reinterpret_cast< pj::CallInfo * >(argp1);
  result = (pj::CallMediaInfoVector *)& ((arg1)->media);
  resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(result), SWIGTYPE_p_std__vectorT_pj__CallMediaInfo_std__allocatorT_pj__CallMediaInfo_t_t, 0 |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_CallInfo_provMedia_set(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::CallInfo *arg1 = (pj::CallInfo *) 0 ;
  pj::CallMediaInfoVector *arg2 = (pj::CallMediaInfoVector *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  void *argp2 = 0 ;
  int res2 = 0 ;
  PyObject *swig_obj[2] ;
  
  if (!SWIG_Python_UnpackTuple(args, "CallInfo_provMedia_set", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__CallInfo, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "CallInfo_provMedia_set" "', argument " "1"" of type '" "pj::CallInfo *""'"); 
  }
  arg1 = reinterpret_cast< pj::CallInfo * >(argp1);
  res2 = SWIG_ConvertPtr(swig_obj[1], &argp2,SWIGTYPE_p_std__vectorT_pj__CallMediaInfo_std__allocatorT_pj__CallMediaInfo_t_t, 0 |  0 );
  if (!SWIG_IsOK(res2)) {
    SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "CallInfo_provMedia_set" "', argument " "2"" of type '" "pj::CallMediaInfoVector *""'"); 
  }
  arg2 = reinterpret_cast< pj::CallMediaInfoVector * >(argp2);
  if (arg1) (arg1)->provMedia = *arg2;
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_CallInfo_provMedia_get(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::CallInfo *arg1 = (pj::CallInfo *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  pj::CallMediaInfoVector *result = 0 ;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__CallInfo, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "CallInfo_provMedia_get" "', argument " "1"" of type '" "pj::CallInfo *""'"); 
  }
  arg1 = reinterpret_cast< pj::CallInfo * >(argp1);
  result = (pj::CallMediaInfoVector *)& ((arg1)->provMedia);
  resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(result), SWIGTYPE_p_std__vectorT_pj__CallMediaInfo_std__allocatorT_pj__CallMediaInfo_t_t, 0 |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_CallInfo_connectDuration_set(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::CallInfo *arg1 = (pj::CallInfo *) 0 ;
  pj::TimeVal *arg2 = (pj::TimeVal *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  void *argp2 = 0 ;
  int res2 = 0 ;
  PyObject *swig_obj[2] ;
  
  if (!SWIG_Python_UnpackTuple(args, "CallInfo_connectDuration_set", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__CallInfo, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "CallInfo_connectDuration_set" "', argument " "1"" of type '" "pj::CallInfo *""'"); 
  }
  arg1 = reinterpret_cast< pj::CallInfo * >(argp1);
  res2 = SWIG_ConvertPtr(swig_obj[1], &argp2,SWIGTYPE_p_pj__TimeVal, 0 |  0 );
  if (!SWIG_IsOK(res2)) {
    SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "CallInfo_connectDuration_set" "', argument " "2"" of type '" "pj::TimeVal *""'"); 
  }
  arg2 = reinterpret_cast< pj::TimeVal * >(argp2);
  if (arg1) (arg1)->connectDuration = *arg2;
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_CallInfo_connectDuration_get(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::CallInfo *arg1 = (pj::CallInfo *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  pj::TimeVal *result = 0 ;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__CallInfo, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "CallInfo_connectDuration_get" "', argument " "1"" of type '" "pj::CallInfo *""'"); 
  }
  arg1 = reinterpret_cast< pj::CallInfo * >(argp1);
  result = (pj::TimeVal *)& ((arg1)->connectDuration);
  resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(result), SWIGTYPE_p_pj__TimeVal, 0 |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_CallInfo_totalDuration_set(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::CallInfo *arg1 = (pj::CallInfo *) 0 ;
  pj::TimeVal *arg2 = (pj::TimeVal *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  void *argp2 = 0 ;
  int res2 = 0 ;
  PyObject *swig_obj[2] ;
  
  if (!SWIG_Python_UnpackTuple(args, "CallInfo_totalDuration_set", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__CallInfo, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "CallInfo_totalDuration_set" "', argument " "1"" of type '" "pj::CallInfo *""'"); 
  }
  arg1 = reinterpret_cast< pj::CallInfo * >(argp1);
  res2 = SWIG_ConvertPtr(swig_obj[1], &argp2,SWIGTYPE_p_pj__TimeVal, 0 |  0 );
  if (!SWIG_IsOK(res2)) {
    SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "CallInfo_totalDuration_set" "', argument " "2"" of type '" "pj::TimeVal *""'"); 
  }
  arg2 = reinterpret_cast< pj::TimeVal * >(argp2);
  if (arg1) (arg1)->totalDuration = *arg2;
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_CallInfo_totalDuration_get(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::CallInfo *arg1 = (pj::CallInfo *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  pj::TimeVal *result = 0 ;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__CallInfo, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "CallInfo_totalDuration_get" "', argument " "1"" of type '" "pj::CallInfo *""'"); 
  }
  arg1 = reinterpret_cast< pj::CallInfo * >(argp1);
  result = (pj::TimeVal *)& ((arg1)->totalDuration);
  resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(result), SWIGTYPE_p_pj__TimeVal, 0 |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_CallInfo_remOfferer_set(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::CallInfo *arg1 = (pj::CallInfo *) 0 ;
  bool arg2 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  bool val2 ;
  int ecode2 = 0 ;
  PyObject *swig_obj[2] ;
  
  if (!SWIG_Python_UnpackTuple(args, "CallInfo_remOfferer_set", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__CallInfo, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "CallInfo_remOfferer_set" "', argument " "1"" of type '" "pj::CallInfo *""'"); 
  }
  arg1 = reinterpret_cast< pj::CallInfo * >(argp1);
  ecode2 = SWIG_AsVal_bool(swig_obj[1], &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "CallInfo_remOfferer_set" "', argument " "2"" of type '" "bool""'");
  } 
  arg2 = static_cast< bool >(val2);
  if (arg1) (arg1)->remOfferer = arg2;
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_CallInfo_remOfferer_get(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::CallInfo *arg1 = (pj::CallInfo *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  bool result;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__CallInfo, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "CallInfo_remOfferer_get" "', argument " "1"" of type '" "pj::CallInfo *""'"); 
  }
  arg1 = reinterpret_cast< pj::CallInfo * >(argp1);
  result = (bool) ((arg1)->remOfferer);
  resultobj = SWIG_From_bool(static_cast< bool >(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_CallInfo_remAudioCount_set(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::CallInfo *arg1 = (pj::CallInfo *) 0 ;
  unsigned int arg2 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  unsigned int val2 ;
  int ecode2 = 0 ;
  PyObject *swig_obj[2] ;
  
  if (!SWIG_Python_UnpackTuple(args, "CallInfo_remAudioCount_set", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__CallInfo, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "CallInfo_remAudioCount_set" "', argument " "1"" of type '" "pj::CallInfo *""'"); 
  }
  arg1 = reinterpret_cast< pj::CallInfo * >(argp1);
  ecode2 = SWIG_AsVal_unsigned_SS_int(swig_obj[1], &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "CallInfo_remAudioCount_set" "', argument " "2"" of type '" "unsigned int""'");
  } 
  arg2 = static_cast< unsigned int >(val2);
  if (arg1) (arg1)->remAudioCount = arg2;
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_CallInfo_remAudioCount_get(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::CallInfo *arg1 = (pj::CallInfo *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  unsigned int result;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__CallInfo, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "CallInfo_remAudioCount_get" "', argument " "1"" of type '" "pj::CallInfo *""'"); 
  }
  arg1 = reinterpret_cast< pj::CallInfo * >(argp1);
  result = (unsigned int) ((arg1)->remAudioCount);
  resultobj = SWIG_From_unsigned_SS_int(static_cast< unsigned int >(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_CallInfo_remVideoCount_set(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::CallInfo *arg1 = (pj::CallInfo *) 0 ;
  unsigned int arg2 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  unsigned int val2 ;
  int ecode2 = 0 ;
  PyObject *swig_obj[2] ;
  
  if (!SWIG_Python_UnpackTuple(args, "CallInfo_remVideoCount_set", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__CallInfo, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "CallInfo_remVideoCount_set" "', argument " "1"" of type '" "pj::CallInfo *""'"); 
  }
  arg1 = reinterpret_cast< pj::CallInfo * >(argp1);
  ecode2 = SWIG_AsVal_unsigned_SS_int(swig_obj[1], &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "CallInfo_remVideoCount_set" "', argument " "2"" of type '" "unsigned int""'");
  } 
  arg2 = static_cast< unsigned int >(val2);
  if (arg1) (arg1)->remVideoCount = arg2;
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_CallInfo_remVideoCount_get(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::CallInfo *arg1 = (pj::CallInfo *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  unsigned int result;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__CallInfo, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "CallInfo_remVideoCount_get" "', argument " "1"" of type '" "pj::CallInfo *""'"); 
  }
  arg1 = reinterpret_cast< pj::CallInfo * >(argp1);
  result = (unsigned int) ((arg1)->remVideoCount);
  resultobj = SWIG_From_unsigned_SS_int(static_cast< unsigned int >(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_new_CallInfo(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::CallInfo *result = 0 ;
  
  if (!SWIG_Python_UnpackTuple(args, "new_CallInfo", 0, 0, 0)) SWIG_fail;
  result = (pj::CallInfo *)new pj::CallInfo();
  resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(result), SWIGTYPE_p_pj__CallInfo, SWIG_POINTER_NEW |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_delete_CallInfo(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::CallInfo *arg1 = (pj::CallInfo *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__CallInfo, SWIG_POINTER_DISOWN |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "delete_CallInfo" "', argument " "1"" of type '" "pj::CallInfo *""'"); 
  }
  arg1 = reinterpret_cast< pj::CallInfo * >(argp1);
  delete arg1;
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *CallInfo_swigregister(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *obj;
  if (!SWIG_Python_UnpackTuple(args, "swigregister", 1, 1, &obj)) return NULL;
  SWIG_TypeNewClientData(SWIGTYPE_p_pj__CallInfo, SWIG_NewClientData(obj));
  return SWIG_Py_Void();
}

SWIGINTERN PyObject *CallInfo_swiginit(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  return SWIG_Python_InitShadowInstance(args);
}

SWIGINTERN PyObject *_wrap_StreamInfo_type_set(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::StreamInfo *arg1 = (pj::StreamInfo *) 0 ;
  pjmedia_type arg2 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  int val2 ;
  int ecode2 = 0 ;
  PyObject *swig_obj[2] ;
  
  if (!SWIG_Python_UnpackTuple(args, "StreamInfo_type_set", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__StreamInfo, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "StreamInfo_type_set" "', argument " "1"" of type '" "pj::StreamInfo *""'"); 
  }
  arg1 = reinterpret_cast< pj::StreamInfo * >(argp1);
  ecode2 = SWIG_AsVal_int(swig_obj[1], &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "StreamInfo_type_set" "', argument " "2"" of type '" "pjmedia_type""'");
  } 
  arg2 = static_cast< pjmedia_type >(val2);
  if (arg1) (arg1)->type = arg2;
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_StreamInfo_type_get(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::StreamInfo *arg1 = (pj::StreamInfo *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  pjmedia_type result;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__StreamInfo, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "StreamInfo_type_get" "', argument " "1"" of type '" "pj::StreamInfo *""'"); 
  }
  arg1 = reinterpret_cast< pj::StreamInfo * >(argp1);
  result = (pjmedia_type) ((arg1)->type);
  resultobj = SWIG_From_int(static_cast< int >(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_StreamInfo_proto_set(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::StreamInfo *arg1 = (pj::StreamInfo *) 0 ;
  pjmedia_tp_proto arg2 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  int val2 ;
  int ecode2 = 0 ;
  PyObject *swig_obj[2] ;
  
  if (!SWIG_Python_UnpackTuple(args, "StreamInfo_proto_set", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__StreamInfo, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "StreamInfo_proto_set" "', argument " "1"" of type '" "pj::StreamInfo *""'"); 
  }
  arg1 = reinterpret_cast< pj::StreamInfo * >(argp1);
  ecode2 = SWIG_AsVal_int(swig_obj[1], &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "StreamInfo_proto_set" "', argument " "2"" of type '" "pjmedia_tp_proto""'");
  } 
  arg2 = static_cast< pjmedia_tp_proto >(val2);
  if (arg1) (arg1)->proto = arg2;
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_StreamInfo_proto_get(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::StreamInfo *arg1 = (pj::StreamInfo *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  pjmedia_tp_proto result;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__StreamInfo, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "StreamInfo_proto_get" "', argument " "1"" of type '" "pj::StreamInfo *""'"); 
  }
  arg1 = reinterpret_cast< pj::StreamInfo * >(argp1);
  result = (pjmedia_tp_proto) ((arg1)->proto);
  resultobj = SWIG_From_int(static_cast< int >(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_StreamInfo_dir_set(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::StreamInfo *arg1 = (pj::StreamInfo *) 0 ;
  pjmedia_dir arg2 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  int val2 ;
  int ecode2 = 0 ;
  PyObject *swig_obj[2] ;
  
  if (!SWIG_Python_UnpackTuple(args, "StreamInfo_dir_set", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__StreamInfo, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "StreamInfo_dir_set" "', argument " "1"" of type '" "pj::StreamInfo *""'"); 
  }
  arg1 = reinterpret_cast< pj::StreamInfo * >(argp1);
  ecode2 = SWIG_AsVal_int(swig_obj[1], &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "StreamInfo_dir_set" "', argument " "2"" of type '" "pjmedia_dir""'");
  } 
  arg2 = static_cast< pjmedia_dir >(val2);
  if (arg1) (arg1)->dir = arg2;
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_StreamInfo_dir_get(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::StreamInfo *arg1 = (pj::StreamInfo *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  pjmedia_dir result;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__StreamInfo, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "StreamInfo_dir_get" "', argument " "1"" of type '" "pj::StreamInfo *""'"); 
  }
  arg1 = reinterpret_cast< pj::StreamInfo * >(argp1);
  result = (pjmedia_dir) ((arg1)->dir);
  resultobj = SWIG_From_int(static_cast< int >(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_StreamInfo_remoteRtpAddress_set(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::StreamInfo *arg1 = (pj::StreamInfo *) 0 ;
  pj::SocketAddress *arg2 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  int res2 = SWIG_OLDOBJ ;
  PyObject *swig_obj[2] ;
  
  if (!SWIG_Python_UnpackTuple(args, "StreamInfo_remoteRtpAddress_set", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__StreamInfo, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "StreamInfo_remoteRtpAddress_set" "', argument " "1"" of type '" "pj::StreamInfo *""'"); 
  }
  arg1 = reinterpret_cast< pj::StreamInfo * >(argp1);
  {
    std::string *ptr = (std::string *)0;
    res2 = SWIG_AsPtr_std_string(swig_obj[1], &ptr);
    if (!SWIG_IsOK(res2)) {
      SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "StreamInfo_remoteRtpAddress_set" "', argument " "2"" of type '" "pj::SocketAddress const &""'"); 
    }
    if (!ptr) {
      SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "StreamInfo_remoteRtpAddress_set" "', argument " "2"" of type '" "pj::SocketAddress const &""'"); 
    }
    arg2 = ptr;
  }
  if (arg1) (arg1)->remoteRtpAddress = *arg2;
  resultobj = SWIG_Py_Void();
  if (SWIG_IsNewObj(res2)) delete arg2;
  return resultobj;
fail:
  if (SWIG_IsNewObj(res2)) delete arg2;
  return NULL;
}


SWIGINTERN PyObject *_wrap_StreamInfo_remoteRtpAddress_get(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::StreamInfo *arg1 = (pj::StreamInfo *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  pj::SocketAddress *result = 0 ;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__StreamInfo, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "StreamInfo_remoteRtpAddress_get" "', argument " "1"" of type '" "pj::StreamInfo *""'"); 
  }
  arg1 = reinterpret_cast< pj::StreamInfo * >(argp1);
  result = (pj::SocketAddress *) & ((arg1)->remoteRtpAddress);
  resultobj = SWIG_From_std_string(static_cast< std::string >(*result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_StreamInfo_remoteRtcpAddress_set(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::StreamInfo *arg1 = (pj::StreamInfo *) 0 ;
  pj::SocketAddress *arg2 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  int res2 = SWIG_OLDOBJ ;
  PyObject *swig_obj[2] ;
  
  if (!SWIG_Python_UnpackTuple(args, "StreamInfo_remoteRtcpAddress_set", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__StreamInfo, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "StreamInfo_remoteRtcpAddress_set" "', argument " "1"" of type '" "pj::StreamInfo *""'"); 
  }
  arg1 = reinterpret_cast< pj::StreamInfo * >(argp1);
  {
    std::string *ptr = (std::string *)0;
    res2 = SWIG_AsPtr_std_string(swig_obj[1], &ptr);
    if (!SWIG_IsOK(res2)) {
      SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "StreamInfo_remoteRtcpAddress_set" "', argument " "2"" of type '" "pj::SocketAddress const &""'"); 
    }
    if (!ptr) {
      SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "StreamInfo_remoteRtcpAddress_set" "', argument " "2"" of type '" "pj::SocketAddress const &""'"); 
    }
    arg2 = ptr;
  }
  if (arg1) (arg1)->remoteRtcpAddress = *arg2;
  resultobj = SWIG_Py_Void();
  if (SWIG_IsNewObj(res2)) delete arg2;
  return resultobj;
fail:
  if (SWIG_IsNewObj(res2)) delete arg2;
  return NULL;
}


SWIGINTERN PyObject *_wrap_StreamInfo_remoteRtcpAddress_get(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::StreamInfo *arg1 = (pj::StreamInfo *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  pj::SocketAddress *result = 0 ;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__StreamInfo, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "StreamInfo_remoteRtcpAddress_get" "', argument " "1"" of type '" "pj::StreamInfo *""'"); 
  }
  arg1 = reinterpret_cast< pj::StreamInfo * >(argp1);
  result = (pj::SocketAddress *) & ((arg1)->remoteRtcpAddress);
  resultobj = SWIG_From_std_string(static_cast< std::string >(*result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_StreamInfo_txPt_set(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::StreamInfo *arg1 = (pj::StreamInfo *) 0 ;
  unsigned int arg2 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  unsigned int val2 ;
  int ecode2 = 0 ;
  PyObject *swig_obj[2] ;
  
  if (!SWIG_Python_UnpackTuple(args, "StreamInfo_txPt_set", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__StreamInfo, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "StreamInfo_txPt_set" "', argument " "1"" of type '" "pj::StreamInfo *""'"); 
  }
  arg1 = reinterpret_cast< pj::StreamInfo * >(argp1);
  ecode2 = SWIG_AsVal_unsigned_SS_int(swig_obj[1], &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "StreamInfo_txPt_set" "', argument " "2"" of type '" "unsigned int""'");
  } 
  arg2 = static_cast< unsigned int >(val2);
  if (arg1) (arg1)->txPt = arg2;
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_StreamInfo_txPt_get(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::StreamInfo *arg1 = (pj::StreamInfo *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  unsigned int result;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__StreamInfo, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "StreamInfo_txPt_get" "', argument " "1"" of type '" "pj::StreamInfo *""'"); 
  }
  arg1 = reinterpret_cast< pj::StreamInfo * >(argp1);
  result = (unsigned int) ((arg1)->txPt);
  resultobj = SWIG_From_unsigned_SS_int(static_cast< unsigned int >(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_StreamInfo_rxPt_set(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::StreamInfo *arg1 = (pj::StreamInfo *) 0 ;
  unsigned int arg2 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  unsigned int val2 ;
  int ecode2 = 0 ;
  PyObject *swig_obj[2] ;
  
  if (!SWIG_Python_UnpackTuple(args, "StreamInfo_rxPt_set", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__StreamInfo, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "StreamInfo_rxPt_set" "', argument " "1"" of type '" "pj::StreamInfo *""'"); 
  }
  arg1 = reinterpret_cast< pj::StreamInfo * >(argp1);
  ecode2 = SWIG_AsVal_unsigned_SS_int(swig_obj[1], &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "StreamInfo_rxPt_set" "', argument " "2"" of type '" "unsigned int""'");
  } 
  arg2 = static_cast< unsigned int >(val2);
  if (arg1) (arg1)->rxPt = arg2;
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_StreamInfo_rxPt_get(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::StreamInfo *arg1 = (pj::StreamInfo *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  unsigned int result;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__StreamInfo, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "StreamInfo_rxPt_get" "', argument " "1"" of type '" "pj::StreamInfo *""'"); 
  }
  arg1 = reinterpret_cast< pj::StreamInfo * >(argp1);
  result = (unsigned int) ((arg1)->rxPt);
  resultobj = SWIG_From_unsigned_SS_int(static_cast< unsigned int >(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_StreamInfo_codecName_set(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::StreamInfo *arg1 = (pj::StreamInfo *) 0 ;
  pj::string *arg2 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  int res2 = SWIG_OLDOBJ ;
  PyObject *swig_obj[2] ;
  
  if (!SWIG_Python_UnpackTuple(args, "StreamInfo_codecName_set", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__StreamInfo, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "StreamInfo_codecName_set" "', argument " "1"" of type '" "pj::StreamInfo *""'"); 
  }
  arg1 = reinterpret_cast< pj::StreamInfo * >(argp1);
  {
    std::string *ptr = (std::string *)0;
    res2 = SWIG_AsPtr_std_string(swig_obj[1], &ptr);
    if (!SWIG_IsOK(res2)) {
      SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "StreamInfo_codecName_set" "', argument " "2"" of type '" "pj::string const &""'"); 
    }
    if (!ptr) {
      SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "StreamInfo_codecName_set" "', argument " "2"" of type '" "pj::string const &""'"); 
    }
    arg2 = ptr;
  }
  if (arg1) (arg1)->codecName = *arg2;
  resultobj = SWIG_Py_Void();
  if (SWIG_IsNewObj(res2)) delete arg2;
  return resultobj;
fail:
  if (SWIG_IsNewObj(res2)) delete arg2;
  return NULL;
}


SWIGINTERN PyObject *_wrap_StreamInfo_codecName_get(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::StreamInfo *arg1 = (pj::StreamInfo *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  pj::string *result = 0 ;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__StreamInfo, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "StreamInfo_codecName_get" "', argument " "1"" of type '" "pj::StreamInfo *""'"); 
  }
  arg1 = reinterpret_cast< pj::StreamInfo * >(argp1);
  result = (pj::string *) & ((arg1)->codecName);
  resultobj = SWIG_From_std_string(static_cast< std::string >(*result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_StreamInfo_codecClockRate_set(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::StreamInfo *arg1 = (pj::StreamInfo *) 0 ;
  unsigned int arg2 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  unsigned int val2 ;
  int ecode2 = 0 ;
  PyObject *swig_obj[2] ;
  
  if (!SWIG_Python_UnpackTuple(args, "StreamInfo_codecClockRate_set", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__StreamInfo, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "StreamInfo_codecClockRate_set" "', argument " "1"" of type '" "pj::StreamInfo *""'"); 
  }
  arg1 = reinterpret_cast< pj::StreamInfo * >(argp1);
  ecode2 = SWIG_AsVal_unsigned_SS_int(swig_obj[1], &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "StreamInfo_codecClockRate_set" "', argument " "2"" of type '" "unsigned int""'");
  } 
  arg2 = static_cast< unsigned int >(val2);
  if (arg1) (arg1)->codecClockRate = arg2;
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_StreamInfo_codecClockRate_get(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::StreamInfo *arg1 = (pj::StreamInfo *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  unsigned int result;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__StreamInfo, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "StreamInfo_codecClockRate_get" "', argument " "1"" of type '" "pj::StreamInfo *""'"); 
  }
  arg1 = reinterpret_cast< pj::StreamInfo * >(argp1);
  result = (unsigned int) ((arg1)->codecClockRate);
  resultobj = SWIG_From_unsigned_SS_int(static_cast< unsigned int >(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_StreamInfo_audCodecParam_set(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::StreamInfo *arg1 = (pj::StreamInfo *) 0 ;
  pj::CodecParam *arg2 = (pj::CodecParam *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  void *argp2 = 0 ;
  int res2 = 0 ;
  PyObject *swig_obj[2] ;
  
  if (!SWIG_Python_UnpackTuple(args, "StreamInfo_audCodecParam_set", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__StreamInfo, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "StreamInfo_audCodecParam_set" "', argument " "1"" of type '" "pj::StreamInfo *""'"); 
  }
  arg1 = reinterpret_cast< pj::StreamInfo * >(argp1);
  res2 = SWIG_ConvertPtr(swig_obj[1], &argp2,SWIGTYPE_p_pj__CodecParam, 0 |  0 );
  if (!SWIG_IsOK(res2)) {
    SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "StreamInfo_audCodecParam_set" "', argument " "2"" of type '" "pj::CodecParam *""'"); 
  }
  arg2 = reinterpret_cast< pj::CodecParam * >(argp2);
  if (arg1) (arg1)->audCodecParam = *arg2;
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_StreamInfo_audCodecParam_get(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::StreamInfo *arg1 = (pj::StreamInfo *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  pj::CodecParam *result = 0 ;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__StreamInfo, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "StreamInfo_audCodecParam_get" "', argument " "1"" of type '" "pj::StreamInfo *""'"); 
  }
  arg1 = reinterpret_cast< pj::StreamInfo * >(argp1);
  result = (pj::CodecParam *)& ((arg1)->audCodecParam);
  resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(result), SWIGTYPE_p_pj__CodecParam, 0 |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_StreamInfo_vidCodecParam_set(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::StreamInfo *arg1 = (pj::StreamInfo *) 0 ;
  pj::VidCodecParam *arg2 = (pj::VidCodecParam *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  void *argp2 = 0 ;
  int res2 = 0 ;
  PyObject *swig_obj[2] ;
  
  if (!SWIG_Python_UnpackTuple(args, "StreamInfo_vidCodecParam_set", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__StreamInfo, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "StreamInfo_vidCodecParam_set" "', argument " "1"" of type '" "pj::StreamInfo *""'"); 
  }
  arg1 = reinterpret_cast< pj::StreamInfo * >(argp1);
  res2 = SWIG_ConvertPtr(swig_obj[1], &argp2,SWIGTYPE_p_pj__VidCodecParam, 0 |  0 );
  if (!SWIG_IsOK(res2)) {
    SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "StreamInfo_vidCodecParam_set" "', argument " "2"" of type '" "pj::VidCodecParam *""'"); 
  }
  arg2 = reinterpret_cast< pj::VidCodecParam * >(argp2);
  if (arg1) (arg1)->vidCodecParam = *arg2;
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_StreamInfo_vidCodecParam_get(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::StreamInfo *arg1 = (pj::StreamInfo *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  pj::VidCodecParam *result = 0 ;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__StreamInfo, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "StreamInfo_vidCodecParam_get" "', argument " "1"" of type '" "pj::StreamInfo *""'"); 
  }
  arg1 = reinterpret_cast< pj::StreamInfo * >(argp1);
  result = (pj::VidCodecParam *)& ((arg1)->vidCodecParam);
  resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(result), SWIGTYPE_p_pj__VidCodecParam, 0 |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_StreamInfo_jbInit_set(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::StreamInfo *arg1 = (pj::StreamInfo *) 0 ;
  int arg2 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  int val2 ;
  int ecode2 = 0 ;
  PyObject *swig_obj[2] ;
  
  if (!SWIG_Python_UnpackTuple(args, "StreamInfo_jbInit_set", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__StreamInfo, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "StreamInfo_jbInit_set" "', argument " "1"" of type '" "pj::StreamInfo *""'"); 
  }
  arg1 = reinterpret_cast< pj::StreamInfo * >(argp1);
  ecode2 = SWIG_AsVal_int(swig_obj[1], &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "StreamInfo_jbInit_set" "', argument " "2"" of type '" "int""'");
  } 
  arg2 = static_cast< int >(val2);
  if (arg1) (arg1)->jbInit = arg2;
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_StreamInfo_jbInit_get(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::StreamInfo *arg1 = (pj::StreamInfo *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  int result;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__StreamInfo, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "StreamInfo_jbInit_get" "', argument " "1"" of type '" "pj::StreamInfo *""'"); 
  }
  arg1 = reinterpret_cast< pj::StreamInfo * >(argp1);
  result = (int) ((arg1)->jbInit);
  resultobj = SWIG_From_int(static_cast< int >(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_StreamInfo_jbMinPre_set(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::StreamInfo *arg1 = (pj::StreamInfo *) 0 ;
  int arg2 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  int val2 ;
  int ecode2 = 0 ;
  PyObject *swig_obj[2] ;
  
  if (!SWIG_Python_UnpackTuple(args, "StreamInfo_jbMinPre_set", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__StreamInfo, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "StreamInfo_jbMinPre_set" "', argument " "1"" of type '" "pj::StreamInfo *""'"); 
  }
  arg1 = reinterpret_cast< pj::StreamInfo * >(argp1);
  ecode2 = SWIG_AsVal_int(swig_obj[1], &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "StreamInfo_jbMinPre_set" "', argument " "2"" of type '" "int""'");
  } 
  arg2 = static_cast< int >(val2);
  if (arg1) (arg1)->jbMinPre = arg2;
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_StreamInfo_jbMinPre_get(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::StreamInfo *arg1 = (pj::StreamInfo *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  int result;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__StreamInfo, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "StreamInfo_jbMinPre_get" "', argument " "1"" of type '" "pj::StreamInfo *""'"); 
  }
  arg1 = reinterpret_cast< pj::StreamInfo * >(argp1);
  result = (int) ((arg1)->jbMinPre);
  resultobj = SWIG_From_int(static_cast< int >(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_StreamInfo_jbMaxPre_set(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::StreamInfo *arg1 = (pj::StreamInfo *) 0 ;
  int arg2 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  int val2 ;
  int ecode2 = 0 ;
  PyObject *swig_obj[2] ;
  
  if (!SWIG_Python_UnpackTuple(args, "StreamInfo_jbMaxPre_set", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__StreamInfo, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "StreamInfo_jbMaxPre_set" "', argument " "1"" of type '" "pj::StreamInfo *""'"); 
  }
  arg1 = reinterpret_cast< pj::StreamInfo * >(argp1);
  ecode2 = SWIG_AsVal_int(swig_obj[1], &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "StreamInfo_jbMaxPre_set" "', argument " "2"" of type '" "int""'");
  } 
  arg2 = static_cast< int >(val2);
  if (arg1) (arg1)->jbMaxPre = arg2;
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_StreamInfo_jbMaxPre_get(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::StreamInfo *arg1 = (pj::StreamInfo *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  int result;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__StreamInfo, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "StreamInfo_jbMaxPre_get" "', argument " "1"" of type '" "pj::StreamInfo *""'"); 
  }
  arg1 = reinterpret_cast< pj::StreamInfo * >(argp1);
  result = (int) ((arg1)->jbMaxPre);
  resultobj = SWIG_From_int(static_cast< int >(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_StreamInfo_jbMax_set(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::StreamInfo *arg1 = (pj::StreamInfo *) 0 ;
  int arg2 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  int val2 ;
  int ecode2 = 0 ;
  PyObject *swig_obj[2] ;
  
  if (!SWIG_Python_UnpackTuple(args, "StreamInfo_jbMax_set", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__StreamInfo, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "StreamInfo_jbMax_set" "', argument " "1"" of type '" "pj::StreamInfo *""'"); 
  }
  arg1 = reinterpret_cast< pj::StreamInfo * >(argp1);
  ecode2 = SWIG_AsVal_int(swig_obj[1], &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "StreamInfo_jbMax_set" "', argument " "2"" of type '" "int""'");
  } 
  arg2 = static_cast< int >(val2);
  if (arg1) (arg1)->jbMax = arg2;
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_StreamInfo_jbMax_get(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::StreamInfo *arg1 = (pj::StreamInfo *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  int result;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__StreamInfo, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "StreamInfo_jbMax_get" "', argument " "1"" of type '" "pj::StreamInfo *""'"); 
  }
  arg1 = reinterpret_cast< pj::StreamInfo * >(argp1);
  result = (int) ((arg1)->jbMax);
  resultobj = SWIG_From_int(static_cast< int >(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_StreamInfo_jbDiscardAlgo_set(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::StreamInfo *arg1 = (pj::StreamInfo *) 0 ;
  pjmedia_jb_discard_algo arg2 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  void *argp2 ;
  int res2 = 0 ;
  PyObject *swig_obj[2] ;
  
  if (!SWIG_Python_UnpackTuple(args, "StreamInfo_jbDiscardAlgo_set", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__StreamInfo, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "StreamInfo_jbDiscardAlgo_set" "', argument " "1"" of type '" "pj::StreamInfo *""'"); 
  }
  arg1 = reinterpret_cast< pj::StreamInfo * >(argp1);
  {
    res2 = SWIG_ConvertPtr(swig_obj[1], &argp2, SWIGTYPE_p_pjmedia_jb_discard_algo,  0  | 0);
    if (!SWIG_IsOK(res2)) {
      SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "StreamInfo_jbDiscardAlgo_set" "', argument " "2"" of type '" "pjmedia_jb_discard_algo""'"); 
    }  
    if (!argp2) {
      SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "StreamInfo_jbDiscardAlgo_set" "', argument " "2"" of type '" "pjmedia_jb_discard_algo""'");
    } else {
      pjmedia_jb_discard_algo * temp = reinterpret_cast< pjmedia_jb_discard_algo * >(argp2);
      arg2 = *temp;
      if (SWIG_IsNewObj(res2)) delete temp;
    }
  }
  if (arg1) (arg1)->jbDiscardAlgo = arg2;
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_StreamInfo_jbDiscardAlgo_get(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::StreamInfo *arg1 = (pj::StreamInfo *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  pjmedia_jb_discard_algo result;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__StreamInfo, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "StreamInfo_jbDiscardAlgo_get" "', argument " "1"" of type '" "pj::StreamInfo *""'"); 
  }
  arg1 = reinterpret_cast< pj::StreamInfo * >(argp1);
  result =  ((arg1)->jbDiscardAlgo);
  resultobj = SWIG_NewPointerObj((new pjmedia_jb_discard_algo(static_cast< const pjmedia_jb_discard_algo& >(result))), SWIGTYPE_p_pjmedia_jb_discard_algo, SWIG_POINTER_OWN |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_StreamInfo_rtcpSdesByeDisabled_set(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::StreamInfo *arg1 = (pj::StreamInfo *) 0 ;
  bool arg2 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  bool val2 ;
  int ecode2 = 0 ;
  PyObject *swig_obj[2] ;
  
  if (!SWIG_Python_UnpackTuple(args, "StreamInfo_rtcpSdesByeDisabled_set", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__StreamInfo, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "StreamInfo_rtcpSdesByeDisabled_set" "', argument " "1"" of type '" "pj::StreamInfo *""'"); 
  }
  arg1 = reinterpret_cast< pj::StreamInfo * >(argp1);
  ecode2 = SWIG_AsVal_bool(swig_obj[1], &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "StreamInfo_rtcpSdesByeDisabled_set" "', argument " "2"" of type '" "bool""'");
  } 
  arg2 = static_cast< bool >(val2);
  if (arg1) (arg1)->rtcpSdesByeDisabled = arg2;
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_StreamInfo_rtcpSdesByeDisabled_get(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::StreamInfo *arg1 = (pj::StreamInfo *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  bool result;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__StreamInfo, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "StreamInfo_rtcpSdesByeDisabled_get" "', argument " "1"" of type '" "pj::StreamInfo *""'"); 
  }
  arg1 = reinterpret_cast< pj::StreamInfo * >(argp1);
  result = (bool) ((arg1)->rtcpSdesByeDisabled);
  resultobj = SWIG_From_bool(static_cast< bool >(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_new_StreamInfo(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::StreamInfo *result = 0 ;
  
  if (!SWIG_Python_UnpackTuple(args, "new_StreamInfo", 0, 0, 0)) SWIG_fail;
  result = (pj::StreamInfo *)new pj::StreamInfo();
  resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(result), SWIGTYPE_p_pj__StreamInfo, SWIG_POINTER_NEW |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_delete_StreamInfo(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::StreamInfo *arg1 = (pj::StreamInfo *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__StreamInfo, SWIG_POINTER_DISOWN |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "delete_StreamInfo" "', argument " "1"" of type '" "pj::StreamInfo *""'"); 
  }
  arg1 = reinterpret_cast< pj::StreamInfo * >(argp1);
  delete arg1;
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *StreamInfo_swigregister(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *obj;
  if (!SWIG_Python_UnpackTuple(args, "swigregister", 1, 1, &obj)) return NULL;
  SWIG_TypeNewClientData(SWIGTYPE_p_pj__StreamInfo, SWIG_NewClientData(obj));
  return SWIG_Py_Void();
}

SWIGINTERN PyObject *StreamInfo_swiginit(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  return SWIG_Python_InitShadowInstance(args);
}

SWIGINTERN PyObject *_wrap_StreamStat_rtcp_set(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::StreamStat *arg1 = (pj::StreamStat *) 0 ;
  pj::RtcpStat *arg2 = (pj::RtcpStat *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  void *argp2 = 0 ;
  int res2 = 0 ;
  PyObject *swig_obj[2] ;
  
  if (!SWIG_Python_UnpackTuple(args, "StreamStat_rtcp_set", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__StreamStat, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "StreamStat_rtcp_set" "', argument " "1"" of type '" "pj::StreamStat *""'"); 
  }
  arg1 = reinterpret_cast< pj::StreamStat * >(argp1);
  res2 = SWIG_ConvertPtr(swig_obj[1], &argp2,SWIGTYPE_p_pj__RtcpStat, 0 |  0 );
  if (!SWIG_IsOK(res2)) {
    SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "StreamStat_rtcp_set" "', argument " "2"" of type '" "pj::RtcpStat *""'"); 
  }
  arg2 = reinterpret_cast< pj::RtcpStat * >(argp2);
  if (arg1) (arg1)->rtcp = *arg2;
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_StreamStat_rtcp_get(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::StreamStat *arg1 = (pj::StreamStat *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  pj::RtcpStat *result = 0 ;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__StreamStat, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "StreamStat_rtcp_get" "', argument " "1"" of type '" "pj::StreamStat *""'"); 
  }
  arg1 = reinterpret_cast< pj::StreamStat * >(argp1);
  result = (pj::RtcpStat *)& ((arg1)->rtcp);
  resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(result), SWIGTYPE_p_pj__RtcpStat, 0 |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_StreamStat_jbuf_set(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::StreamStat *arg1 = (pj::StreamStat *) 0 ;
  pj::JbufState *arg2 = (pj::JbufState *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  void *argp2 = 0 ;
  int res2 = 0 ;
  PyObject *swig_obj[2] ;
  
  if (!SWIG_Python_UnpackTuple(args, "StreamStat_jbuf_set", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__StreamStat, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "StreamStat_jbuf_set" "', argument " "1"" of type '" "pj::StreamStat *""'"); 
  }
  arg1 = reinterpret_cast< pj::StreamStat * >(argp1);
  res2 = SWIG_ConvertPtr(swig_obj[1], &argp2,SWIGTYPE_p_pj__JbufState, 0 |  0 );
  if (!SWIG_IsOK(res2)) {
    SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "StreamStat_jbuf_set" "', argument " "2"" of type '" "pj::JbufState *""'"); 
  }
  arg2 = reinterpret_cast< pj::JbufState * >(argp2);
  if (arg1) (arg1)->jbuf = *arg2;
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_StreamStat_jbuf_get(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::StreamStat *arg1 = (pj::StreamStat *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  pj::JbufState *result = 0 ;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__StreamStat, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "StreamStat_jbuf_get" "', argument " "1"" of type '" "pj::StreamStat *""'"); 
  }
  arg1 = reinterpret_cast< pj::StreamStat * >(argp1);
  result = (pj::JbufState *)& ((arg1)->jbuf);
  resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(result), SWIGTYPE_p_pj__JbufState, 0 |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_new_StreamStat(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::StreamStat *result = 0 ;
  
  if (!SWIG_Python_UnpackTuple(args, "new_StreamStat", 0, 0, 0)) SWIG_fail;
  result = (pj::StreamStat *)new pj::StreamStat();
  resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(result), SWIGTYPE_p_pj__StreamStat, SWIG_POINTER_NEW |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_delete_StreamStat(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::StreamStat *arg1 = (pj::StreamStat *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__StreamStat, SWIG_POINTER_DISOWN |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "delete_StreamStat" "', argument " "1"" of type '" "pj::StreamStat *""'"); 
  }
  arg1 = reinterpret_cast< pj::StreamStat * >(argp1);
  delete arg1;
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *StreamStat_swigregister(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *obj;
  if (!SWIG_Python_UnpackTuple(args, "swigregister", 1, 1, &obj)) return NULL;
  SWIG_TypeNewClientData(SWIGTYPE_p_pj__StreamStat, SWIG_NewClientData(obj));
  return SWIG_Py_Void();
}

SWIGINTERN PyObject *StreamStat_swiginit(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  return SWIG_Python_InitShadowInstance(args);
}

SWIGINTERN PyObject *_wrap_OnCallStateParam_e_set(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::OnCallStateParam *arg1 = (pj::OnCallStateParam *) 0 ;
  pj::SipEvent *arg2 = (pj::SipEvent *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  void *argp2 = 0 ;
  int res2 = 0 ;
  PyObject *swig_obj[2] ;
  
  if (!SWIG_Python_UnpackTuple(args, "OnCallStateParam_e_set", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__OnCallStateParam, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "OnCallStateParam_e_set" "', argument " "1"" of type '" "pj::OnCallStateParam *""'"); 
  }
  arg1 = reinterpret_cast< pj::OnCallStateParam * >(argp1);
  res2 = SWIG_ConvertPtr(swig_obj[1], &argp2,SWIGTYPE_p_pj__SipEvent, 0 |  0 );
  if (!SWIG_IsOK(res2)) {
    SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "OnCallStateParam_e_set" "', argument " "2"" of type '" "pj::SipEvent *""'"); 
  }
  arg2 = reinterpret_cast< pj::SipEvent * >(argp2);
  if (arg1) (arg1)->e = *arg2;
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_OnCallStateParam_e_get(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::OnCallStateParam *arg1 = (pj::OnCallStateParam *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  pj::SipEvent *result = 0 ;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__OnCallStateParam, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "OnCallStateParam_e_get" "', argument " "1"" of type '" "pj::OnCallStateParam *""'"); 
  }
  arg1 = reinterpret_cast< pj::OnCallStateParam * >(argp1);
  result = (pj::SipEvent *)& ((arg1)->e);
  resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(result), SWIGTYPE_p_pj__SipEvent, 0 |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_new_OnCallStateParam(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::OnCallStateParam *result = 0 ;
  
  if (!SWIG_Python_UnpackTuple(args, "new_OnCallStateParam", 0, 0, 0)) SWIG_fail;
  result = (pj::OnCallStateParam *)new pj::OnCallStateParam();
  resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(result), SWIGTYPE_p_pj__OnCallStateParam, SWIG_POINTER_NEW |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_delete_OnCallStateParam(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::OnCallStateParam *arg1 = (pj::OnCallStateParam *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__OnCallStateParam, SWIG_POINTER_DISOWN |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "delete_OnCallStateParam" "', argument " "1"" of type '" "pj::OnCallStateParam *""'"); 
  }
  arg1 = reinterpret_cast< pj::OnCallStateParam * >(argp1);
  delete arg1;
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *OnCallStateParam_swigregister(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *obj;
  if (!SWIG_Python_UnpackTuple(args, "swigregister", 1, 1, &obj)) return NULL;
  SWIG_TypeNewClientData(SWIGTYPE_p_pj__OnCallStateParam, SWIG_NewClientData(obj));
  return SWIG_Py_Void();
}

SWIGINTERN PyObject *OnCallStateParam_swiginit(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  return SWIG_Python_InitShadowInstance(args);
}

SWIGINTERN PyObject *_wrap_OnCallTsxStateParam_e_set(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::OnCallTsxStateParam *arg1 = (pj::OnCallTsxStateParam *) 0 ;
  pj::SipEvent *arg2 = (pj::SipEvent *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  void *argp2 = 0 ;
  int res2 = 0 ;
  PyObject *swig_obj[2] ;
  
  if (!SWIG_Python_UnpackTuple(args, "OnCallTsxStateParam_e_set", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__OnCallTsxStateParam, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "OnCallTsxStateParam_e_set" "', argument " "1"" of type '" "pj::OnCallTsxStateParam *""'"); 
  }
  arg1 = reinterpret_cast< pj::OnCallTsxStateParam * >(argp1);
  res2 = SWIG_ConvertPtr(swig_obj[1], &argp2,SWIGTYPE_p_pj__SipEvent, 0 |  0 );
  if (!SWIG_IsOK(res2)) {
    SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "OnCallTsxStateParam_e_set" "', argument " "2"" of type '" "pj::SipEvent *""'"); 
  }
  arg2 = reinterpret_cast< pj::SipEvent * >(argp2);
  if (arg1) (arg1)->e = *arg2;
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_OnCallTsxStateParam_e_get(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::OnCallTsxStateParam *arg1 = (pj::OnCallTsxStateParam *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  pj::SipEvent *result = 0 ;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__OnCallTsxStateParam, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "OnCallTsxStateParam_e_get" "', argument " "1"" of type '" "pj::OnCallTsxStateParam *""'"); 
  }
  arg1 = reinterpret_cast< pj::OnCallTsxStateParam * >(argp1);
  result = (pj::SipEvent *)& ((arg1)->e);
  resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(result), SWIGTYPE_p_pj__SipEvent, 0 |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_new_OnCallTsxStateParam(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::OnCallTsxStateParam *result = 0 ;
  
  if (!SWIG_Python_UnpackTuple(args, "new_OnCallTsxStateParam", 0, 0, 0)) SWIG_fail;
  result = (pj::OnCallTsxStateParam *)new pj::OnCallTsxStateParam();
  resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(result), SWIGTYPE_p_pj__OnCallTsxStateParam, SWIG_POINTER_NEW |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_delete_OnCallTsxStateParam(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::OnCallTsxStateParam *arg1 = (pj::OnCallTsxStateParam *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__OnCallTsxStateParam, SWIG_POINTER_DISOWN |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "delete_OnCallTsxStateParam" "', argument " "1"" of type '" "pj::OnCallTsxStateParam *""'"); 
  }
  arg1 = reinterpret_cast< pj::OnCallTsxStateParam * >(argp1);
  delete arg1;
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *OnCallTsxStateParam_swigregister(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *obj;
  if (!SWIG_Python_UnpackTuple(args, "swigregister", 1, 1, &obj)) return NULL;
  SWIG_TypeNewClientData(SWIGTYPE_p_pj__OnCallTsxStateParam, SWIG_NewClientData(obj));
  return SWIG_Py_Void();
}

SWIGINTERN PyObject *OnCallTsxStateParam_swiginit(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  return SWIG_Python_InitShadowInstance(args);
}

SWIGINTERN PyObject *_wrap_new_OnCallMediaStateParam(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::OnCallMediaStateParam *result = 0 ;
  
  if (!SWIG_Python_UnpackTuple(args, "new_OnCallMediaStateParam", 0, 0, 0)) SWIG_fail;
  result = (pj::OnCallMediaStateParam *)new pj::OnCallMediaStateParam();
  resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(result), SWIGTYPE_p_pj__OnCallMediaStateParam, SWIG_POINTER_NEW |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_delete_OnCallMediaStateParam(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::OnCallMediaStateParam *arg1 = (pj::OnCallMediaStateParam *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__OnCallMediaStateParam, SWIG_POINTER_DISOWN |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "delete_OnCallMediaStateParam" "', argument " "1"" of type '" "pj::OnCallMediaStateParam *""'"); 
  }
  arg1 = reinterpret_cast< pj::OnCallMediaStateParam * >(argp1);
  delete arg1;
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *OnCallMediaStateParam_swigregister(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *obj;
  if (!SWIG_Python_UnpackTuple(args, "swigregister", 1, 1, &obj)) return NULL;
  SWIG_TypeNewClientData(SWIGTYPE_p_pj__OnCallMediaStateParam, SWIG_NewClientData(obj));
  return SWIG_Py_Void();
}

SWIGINTERN PyObject *OnCallMediaStateParam_swiginit(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  return SWIG_Python_InitShadowInstance(args);
}

SWIGINTERN PyObject *_wrap_OnCallSdpCreatedParam_sdp_set(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::OnCallSdpCreatedParam *arg1 = (pj::OnCallSdpCreatedParam *) 0 ;
  pj::SdpSession *arg2 = (pj::SdpSession *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  void *argp2 = 0 ;
  int res2 = 0 ;
  PyObject *swig_obj[2] ;
  
  if (!SWIG_Python_UnpackTuple(args, "OnCallSdpCreatedParam_sdp_set", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__OnCallSdpCreatedParam, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "OnCallSdpCreatedParam_sdp_set" "', argument " "1"" of type '" "pj::OnCallSdpCreatedParam *""'"); 
  }
  arg1 = reinterpret_cast< pj::OnCallSdpCreatedParam * >(argp1);
  res2 = SWIG_ConvertPtr(swig_obj[1], &argp2,SWIGTYPE_p_pj__SdpSession, 0 |  0 );
  if (!SWIG_IsOK(res2)) {
    SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "OnCallSdpCreatedParam_sdp_set" "', argument " "2"" of type '" "pj::SdpSession *""'"); 
  }
  arg2 = reinterpret_cast< pj::SdpSession * >(argp2);
  if (arg1) (arg1)->sdp = *arg2;
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_OnCallSdpCreatedParam_sdp_get(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::OnCallSdpCreatedParam *arg1 = (pj::OnCallSdpCreatedParam *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  pj::SdpSession *result = 0 ;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__OnCallSdpCreatedParam, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "OnCallSdpCreatedParam_sdp_get" "', argument " "1"" of type '" "pj::OnCallSdpCreatedParam *""'"); 
  }
  arg1 = reinterpret_cast< pj::OnCallSdpCreatedParam * >(argp1);
  result = (pj::SdpSession *)& ((arg1)->sdp);
  resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(result), SWIGTYPE_p_pj__SdpSession, 0 |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_OnCallSdpCreatedParam_remSdp_set(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::OnCallSdpCreatedParam *arg1 = (pj::OnCallSdpCreatedParam *) 0 ;
  pj::SdpSession *arg2 = (pj::SdpSession *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  void *argp2 = 0 ;
  int res2 = 0 ;
  PyObject *swig_obj[2] ;
  
  if (!SWIG_Python_UnpackTuple(args, "OnCallSdpCreatedParam_remSdp_set", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__OnCallSdpCreatedParam, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "OnCallSdpCreatedParam_remSdp_set" "', argument " "1"" of type '" "pj::OnCallSdpCreatedParam *""'"); 
  }
  arg1 = reinterpret_cast< pj::OnCallSdpCreatedParam * >(argp1);
  res2 = SWIG_ConvertPtr(swig_obj[1], &argp2,SWIGTYPE_p_pj__SdpSession, 0 |  0 );
  if (!SWIG_IsOK(res2)) {
    SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "OnCallSdpCreatedParam_remSdp_set" "', argument " "2"" of type '" "pj::SdpSession *""'"); 
  }
  arg2 = reinterpret_cast< pj::SdpSession * >(argp2);
  if (arg1) (arg1)->remSdp = *arg2;
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_OnCallSdpCreatedParam_remSdp_get(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::OnCallSdpCreatedParam *arg1 = (pj::OnCallSdpCreatedParam *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  pj::SdpSession *result = 0 ;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__OnCallSdpCreatedParam, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "OnCallSdpCreatedParam_remSdp_get" "', argument " "1"" of type '" "pj::OnCallSdpCreatedParam *""'"); 
  }
  arg1 = reinterpret_cast< pj::OnCallSdpCreatedParam * >(argp1);
  result = (pj::SdpSession *)& ((arg1)->remSdp);
  resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(result), SWIGTYPE_p_pj__SdpSession, 0 |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_new_OnCallSdpCreatedParam(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::OnCallSdpCreatedParam *result = 0 ;
  
  if (!SWIG_Python_UnpackTuple(args, "new_OnCallSdpCreatedParam", 0, 0, 0)) SWIG_fail;
  result = (pj::OnCallSdpCreatedParam *)new pj::OnCallSdpCreatedParam();
  resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(result), SWIGTYPE_p_pj__OnCallSdpCreatedParam, SWIG_POINTER_NEW |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_delete_OnCallSdpCreatedParam(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::OnCallSdpCreatedParam *arg1 = (pj::OnCallSdpCreatedParam *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__OnCallSdpCreatedParam, SWIG_POINTER_DISOWN |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "delete_OnCallSdpCreatedParam" "', argument " "1"" of type '" "pj::OnCallSdpCreatedParam *""'"); 
  }
  arg1 = reinterpret_cast< pj::OnCallSdpCreatedParam * >(argp1);
  delete arg1;
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *OnCallSdpCreatedParam_swigregister(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *obj;
  if (!SWIG_Python_UnpackTuple(args, "swigregister", 1, 1, &obj)) return NULL;
  SWIG_TypeNewClientData(SWIGTYPE_p_pj__OnCallSdpCreatedParam, SWIG_NewClientData(obj));
  return SWIG_Py_Void();
}

SWIGINTERN PyObject *OnCallSdpCreatedParam_swiginit(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  return SWIG_Python_InitShadowInstance(args);
}

SWIGINTERN PyObject *_wrap_OnStreamPreCreateParam_streamIdx_set(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::OnStreamPreCreateParam *arg1 = (pj::OnStreamPreCreateParam *) 0 ;
  unsigned int arg2 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  unsigned int val2 ;
  int ecode2 = 0 ;
  PyObject *swig_obj[2] ;
  
  if (!SWIG_Python_UnpackTuple(args, "OnStreamPreCreateParam_streamIdx_set", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__OnStreamPreCreateParam, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "OnStreamPreCreateParam_streamIdx_set" "', argument " "1"" of type '" "pj::OnStreamPreCreateParam *""'"); 
  }
  arg1 = reinterpret_cast< pj::OnStreamPreCreateParam * >(argp1);
  ecode2 = SWIG_AsVal_unsigned_SS_int(swig_obj[1], &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "OnStreamPreCreateParam_streamIdx_set" "', argument " "2"" of type '" "unsigned int""'");
  } 
  arg2 = static_cast< unsigned int >(val2);
  if (arg1) (arg1)->streamIdx = arg2;
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_OnStreamPreCreateParam_streamIdx_get(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::OnStreamPreCreateParam *arg1 = (pj::OnStreamPreCreateParam *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  unsigned int result;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__OnStreamPreCreateParam, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "OnStreamPreCreateParam_streamIdx_get" "', argument " "1"" of type '" "pj::OnStreamPreCreateParam *""'"); 
  }
  arg1 = reinterpret_cast< pj::OnStreamPreCreateParam * >(argp1);
  result = (unsigned int) ((arg1)->streamIdx);
  resultobj = SWIG_From_unsigned_SS_int(static_cast< unsigned int >(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_OnStreamPreCreateParam_streamInfo_set(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::OnStreamPreCreateParam *arg1 = (pj::OnStreamPreCreateParam *) 0 ;
  pj::StreamInfo *arg2 = (pj::StreamInfo *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  void *argp2 = 0 ;
  int res2 = 0 ;
  PyObject *swig_obj[2] ;
  
  if (!SWIG_Python_UnpackTuple(args, "OnStreamPreCreateParam_streamInfo_set", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__OnStreamPreCreateParam, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "OnStreamPreCreateParam_streamInfo_set" "', argument " "1"" of type '" "pj::OnStreamPreCreateParam *""'"); 
  }
  arg1 = reinterpret_cast< pj::OnStreamPreCreateParam * >(argp1);
  res2 = SWIG_ConvertPtr(swig_obj[1], &argp2,SWIGTYPE_p_pj__StreamInfo, 0 |  0 );
  if (!SWIG_IsOK(res2)) {
    SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "OnStreamPreCreateParam_streamInfo_set" "', argument " "2"" of type '" "pj::StreamInfo *""'"); 
  }
  arg2 = reinterpret_cast< pj::StreamInfo * >(argp2);
  if (arg1) (arg1)->streamInfo = *arg2;
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_OnStreamPreCreateParam_streamInfo_get(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::OnStreamPreCreateParam *arg1 = (pj::OnStreamPreCreateParam *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  pj::StreamInfo *result = 0 ;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__OnStreamPreCreateParam, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "OnStreamPreCreateParam_streamInfo_get" "', argument " "1"" of type '" "pj::OnStreamPreCreateParam *""'"); 
  }
  arg1 = reinterpret_cast< pj::OnStreamPreCreateParam * >(argp1);
  result = (pj::StreamInfo *)& ((arg1)->streamInfo);
  resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(result), SWIGTYPE_p_pj__StreamInfo, 0 |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_new_OnStreamPreCreateParam(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::OnStreamPreCreateParam *result = 0 ;
  
  if (!SWIG_Python_UnpackTuple(args, "new_OnStreamPreCreateParam", 0, 0, 0)) SWIG_fail;
  result = (pj::OnStreamPreCreateParam *)new pj::OnStreamPreCreateParam();
  resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(result), SWIGTYPE_p_pj__OnStreamPreCreateParam, SWIG_POINTER_NEW |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_delete_OnStreamPreCreateParam(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::OnStreamPreCreateParam *arg1 = (pj::OnStreamPreCreateParam *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__OnStreamPreCreateParam, SWIG_POINTER_DISOWN |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "delete_OnStreamPreCreateParam" "', argument " "1"" of type '" "pj::OnStreamPreCreateParam *""'"); 
  }
  arg1 = reinterpret_cast< pj::OnStreamPreCreateParam * >(argp1);
  delete arg1;
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *OnStreamPreCreateParam_swigregister(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *obj;
  if (!SWIG_Python_UnpackTuple(args, "swigregister", 1, 1, &obj)) return NULL;
  SWIG_TypeNewClientData(SWIGTYPE_p_pj__OnStreamPreCreateParam, SWIG_NewClientData(obj));
  return SWIG_Py_Void();
}

SWIGINTERN PyObject *OnStreamPreCreateParam_swiginit(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  return SWIG_Python_InitShadowInstance(args);
}

SWIGINTERN PyObject *_wrap_OnStreamCreatedParam_stream_set(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::OnStreamCreatedParam *arg1 = (pj::OnStreamCreatedParam *) 0 ;
  pj::MediaStream arg2 = (pj::MediaStream) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  int res2 ;
  PyObject *swig_obj[2] ;
  
  if (!SWIG_Python_UnpackTuple(args, "OnStreamCreatedParam_stream_set", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__OnStreamCreatedParam, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "OnStreamCreatedParam_stream_set" "', argument " "1"" of type '" "pj::OnStreamCreatedParam *""'"); 
  }
  arg1 = reinterpret_cast< pj::OnStreamCreatedParam * >(argp1);
  res2 = SWIG_ConvertPtr(swig_obj[1],SWIG_as_voidptrptr(&arg2), 0, SWIG_POINTER_DISOWN);
  if (!SWIG_IsOK(res2)) {
    SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "OnStreamCreatedParam_stream_set" "', argument " "2"" of type '" "pj::MediaStream""'"); 
  }
  if (arg1) (arg1)->stream = arg2;
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_OnStreamCreatedParam_stream_get(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::OnStreamCreatedParam *arg1 = (pj::OnStreamCreatedParam *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  pj::MediaStream result;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__OnStreamCreatedParam, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "OnStreamCreatedParam_stream_get" "', argument " "1"" of type '" "pj::OnStreamCreatedParam *""'"); 
  }
  arg1 = reinterpret_cast< pj::OnStreamCreatedParam * >(argp1);
  result = (pj::MediaStream) ((arg1)->stream);
  resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(result), SWIGTYPE_p_void, 0 |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_OnStreamCreatedParam_streamIdx_set(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::OnStreamCreatedParam *arg1 = (pj::OnStreamCreatedParam *) 0 ;
  unsigned int arg2 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  unsigned int val2 ;
  int ecode2 = 0 ;
  PyObject *swig_obj[2] ;
  
  if (!SWIG_Python_UnpackTuple(args, "OnStreamCreatedParam_streamIdx_set", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__OnStreamCreatedParam, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "OnStreamCreatedParam_streamIdx_set" "', argument " "1"" of type '" "pj::OnStreamCreatedParam *""'"); 
  }
  arg1 = reinterpret_cast< pj::OnStreamCreatedParam * >(argp1);
  ecode2 = SWIG_AsVal_unsigned_SS_int(swig_obj[1], &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "OnStreamCreatedParam_streamIdx_set" "', argument " "2"" of type '" "unsigned int""'");
  } 
  arg2 = static_cast< unsigned int >(val2);
  if (arg1) (arg1)->streamIdx = arg2;
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_OnStreamCreatedParam_streamIdx_get(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::OnStreamCreatedParam *arg1 = (pj::OnStreamCreatedParam *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  unsigned int result;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__OnStreamCreatedParam, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "OnStreamCreatedParam_streamIdx_get" "', argument " "1"" of type '" "pj::OnStreamCreatedParam *""'"); 
  }
  arg1 = reinterpret_cast< pj::OnStreamCreatedParam * >(argp1);
  result = (unsigned int) ((arg1)->streamIdx);
  resultobj = SWIG_From_unsigned_SS_int(static_cast< unsigned int >(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_OnStreamCreatedParam_destroyPort_set(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::OnStreamCreatedParam *arg1 = (pj::OnStreamCreatedParam *) 0 ;
  bool arg2 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  bool val2 ;
  int ecode2 = 0 ;
  PyObject *swig_obj[2] ;
  
  if (!SWIG_Python_UnpackTuple(args, "OnStreamCreatedParam_destroyPort_set", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__OnStreamCreatedParam, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "OnStreamCreatedParam_destroyPort_set" "', argument " "1"" of type '" "pj::OnStreamCreatedParam *""'"); 
  }
  arg1 = reinterpret_cast< pj::OnStreamCreatedParam * >(argp1);
  ecode2 = SWIG_AsVal_bool(swig_obj[1], &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "OnStreamCreatedParam_destroyPort_set" "', argument " "2"" of type '" "bool""'");
  } 
  arg2 = static_cast< bool >(val2);
  if (arg1) (arg1)->destroyPort = arg2;
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_OnStreamCreatedParam_destroyPort_get(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::OnStreamCreatedParam *arg1 = (pj::OnStreamCreatedParam *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  bool result;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__OnStreamCreatedParam, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "OnStreamCreatedParam_destroyPort_get" "', argument " "1"" of type '" "pj::OnStreamCreatedParam *""'"); 
  }
  arg1 = reinterpret_cast< pj::OnStreamCreatedParam * >(argp1);
  result = (bool) ((arg1)->destroyPort);
  resultobj = SWIG_From_bool(static_cast< bool >(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_OnStreamCreatedParam_pPort_set(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::OnStreamCreatedParam *arg1 = (pj::OnStreamCreatedParam *) 0 ;
  pj::MediaPort arg2 = (pj::MediaPort) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  int res2 ;
  PyObject *swig_obj[2] ;
  
  if (!SWIG_Python_UnpackTuple(args, "OnStreamCreatedParam_pPort_set", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__OnStreamCreatedParam, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "OnStreamCreatedParam_pPort_set" "', argument " "1"" of type '" "pj::OnStreamCreatedParam *""'"); 
  }
  arg1 = reinterpret_cast< pj::OnStreamCreatedParam * >(argp1);
  res2 = SWIG_ConvertPtr(swig_obj[1],SWIG_as_voidptrptr(&arg2), 0, SWIG_POINTER_DISOWN);
  if (!SWIG_IsOK(res2)) {
    SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "OnStreamCreatedParam_pPort_set" "', argument " "2"" of type '" "pj::MediaPort""'"); 
  }
  if (arg1) (arg1)->pPort = arg2;
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_OnStreamCreatedParam_pPort_get(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::OnStreamCreatedParam *arg1 = (pj::OnStreamCreatedParam *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  pj::MediaPort result;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__OnStreamCreatedParam, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "OnStreamCreatedParam_pPort_get" "', argument " "1"" of type '" "pj::OnStreamCreatedParam *""'"); 
  }
  arg1 = reinterpret_cast< pj::OnStreamCreatedParam * >(argp1);
  result = (pj::MediaPort) ((arg1)->pPort);
  resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(result), SWIGTYPE_p_void, 0 |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_new_OnStreamCreatedParam(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::OnStreamCreatedParam *result = 0 ;
  
  if (!SWIG_Python_UnpackTuple(args, "new_OnStreamCreatedParam", 0, 0, 0)) SWIG_fail;
  result = (pj::OnStreamCreatedParam *)new pj::OnStreamCreatedParam();
  resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(result), SWIGTYPE_p_pj__OnStreamCreatedParam, SWIG_POINTER_NEW |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_delete_OnStreamCreatedParam(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::OnStreamCreatedParam *arg1 = (pj::OnStreamCreatedParam *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__OnStreamCreatedParam, SWIG_POINTER_DISOWN |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "delete_OnStreamCreatedParam" "', argument " "1"" of type '" "pj::OnStreamCreatedParam *""'"); 
  }
  arg1 = reinterpret_cast< pj::OnStreamCreatedParam * >(argp1);
  delete arg1;
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *OnStreamCreatedParam_swigregister(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *obj;
  if (!SWIG_Python_UnpackTuple(args, "swigregister", 1, 1, &obj)) return NULL;
  SWIG_TypeNewClientData(SWIGTYPE_p_pj__OnStreamCreatedParam, SWIG_NewClientData(obj));
  return SWIG_Py_Void();
}

SWIGINTERN PyObject *OnStreamCreatedParam_swiginit(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  return SWIG_Python_InitShadowInstance(args);
}

SWIGINTERN PyObject *_wrap_OnStreamDestroyedParam_stream_set(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::OnStreamDestroyedParam *arg1 = (pj::OnStreamDestroyedParam *) 0 ;
  pj::MediaStream arg2 = (pj::MediaStream) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  int res2 ;
  PyObject *swig_obj[2] ;
  
  if (!SWIG_Python_UnpackTuple(args, "OnStreamDestroyedParam_stream_set", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__OnStreamDestroyedParam, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "OnStreamDestroyedParam_stream_set" "', argument " "1"" of type '" "pj::OnStreamDestroyedParam *""'"); 
  }
  arg1 = reinterpret_cast< pj::OnStreamDestroyedParam * >(argp1);
  res2 = SWIG_ConvertPtr(swig_obj[1],SWIG_as_voidptrptr(&arg2), 0, SWIG_POINTER_DISOWN);
  if (!SWIG_IsOK(res2)) {
    SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "OnStreamDestroyedParam_stream_set" "', argument " "2"" of type '" "pj::MediaStream""'"); 
  }
  if (arg1) (arg1)->stream = arg2;
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_OnStreamDestroyedParam_stream_get(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::OnStreamDestroyedParam *arg1 = (pj::OnStreamDestroyedParam *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  pj::MediaStream result;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__OnStreamDestroyedParam, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "OnStreamDestroyedParam_stream_get" "', argument " "1"" of type '" "pj::OnStreamDestroyedParam *""'"); 
  }
  arg1 = reinterpret_cast< pj::OnStreamDestroyedParam * >(argp1);
  result = (pj::MediaStream) ((arg1)->stream);
  resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(result), SWIGTYPE_p_void, 0 |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_OnStreamDestroyedParam_streamIdx_set(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::OnStreamDestroyedParam *arg1 = (pj::OnStreamDestroyedParam *) 0 ;
  unsigned int arg2 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  unsigned int val2 ;
  int ecode2 = 0 ;
  PyObject *swig_obj[2] ;
  
  if (!SWIG_Python_UnpackTuple(args, "OnStreamDestroyedParam_streamIdx_set", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__OnStreamDestroyedParam, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "OnStreamDestroyedParam_streamIdx_set" "', argument " "1"" of type '" "pj::OnStreamDestroyedParam *""'"); 
  }
  arg1 = reinterpret_cast< pj::OnStreamDestroyedParam * >(argp1);
  ecode2 = SWIG_AsVal_unsigned_SS_int(swig_obj[1], &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "OnStreamDestroyedParam_streamIdx_set" "', argument " "2"" of type '" "unsigned int""'");
  } 
  arg2 = static_cast< unsigned int >(val2);
  if (arg1) (arg1)->streamIdx = arg2;
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_OnStreamDestroyedParam_streamIdx_get(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::OnStreamDestroyedParam *arg1 = (pj::OnStreamDestroyedParam *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  unsigned int result;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__OnStreamDestroyedParam, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "OnStreamDestroyedParam_streamIdx_get" "', argument " "1"" of type '" "pj::OnStreamDestroyedParam *""'"); 
  }
  arg1 = reinterpret_cast< pj::OnStreamDestroyedParam * >(argp1);
  result = (unsigned int) ((arg1)->streamIdx);
  resultobj = SWIG_From_unsigned_SS_int(static_cast< unsigned int >(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_new_OnStreamDestroyedParam(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::OnStreamDestroyedParam *result = 0 ;
  
  if (!SWIG_Python_UnpackTuple(args, "new_OnStreamDestroyedParam", 0, 0, 0)) SWIG_fail;
  result = (pj::OnStreamDestroyedParam *)new pj::OnStreamDestroyedParam();
  resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(result), SWIGTYPE_p_pj__OnStreamDestroyedParam, SWIG_POINTER_NEW |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_delete_OnStreamDestroyedParam(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::OnStreamDestroyedParam *arg1 = (pj::OnStreamDestroyedParam *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__OnStreamDestroyedParam, SWIG_POINTER_DISOWN |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "delete_OnStreamDestroyedParam" "', argument " "1"" of type '" "pj::OnStreamDestroyedParam *""'"); 
  }
  arg1 = reinterpret_cast< pj::OnStreamDestroyedParam * >(argp1);
  delete arg1;
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *OnStreamDestroyedParam_swigregister(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *obj;
  if (!SWIG_Python_UnpackTuple(args, "swigregister", 1, 1, &obj)) return NULL;
  SWIG_TypeNewClientData(SWIGTYPE_p_pj__OnStreamDestroyedParam, SWIG_NewClientData(obj));
  return SWIG_Py_Void();
}

SWIGINTERN PyObject *OnStreamDestroyedParam_swiginit(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  return SWIG_Python_InitShadowInstance(args);
}

SWIGINTERN PyObject *_wrap_OnDtmfDigitParam_method_set(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::OnDtmfDigitParam *arg1 = (pj::OnDtmfDigitParam *) 0 ;
  pjsua_dtmf_method arg2 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  int val2 ;
  int ecode2 = 0 ;
  PyObject *swig_obj[2] ;
  
  if (!SWIG_Python_UnpackTuple(args, "OnDtmfDigitParam_method_set", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__OnDtmfDigitParam, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "OnDtmfDigitParam_method_set" "', argument " "1"" of type '" "pj::OnDtmfDigitParam *""'"); 
  }
  arg1 = reinterpret_cast< pj::OnDtmfDigitParam * >(argp1);
  ecode2 = SWIG_AsVal_int(swig_obj[1], &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "OnDtmfDigitParam_method_set" "', argument " "2"" of type '" "pjsua_dtmf_method""'");
  } 
  arg2 = static_cast< pjsua_dtmf_method >(val2);
  if (arg1) (arg1)->method = arg2;
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_OnDtmfDigitParam_method_get(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::OnDtmfDigitParam *arg1 = (pj::OnDtmfDigitParam *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  pjsua_dtmf_method result;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__OnDtmfDigitParam, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "OnDtmfDigitParam_method_get" "', argument " "1"" of type '" "pj::OnDtmfDigitParam *""'"); 
  }
  arg1 = reinterpret_cast< pj::OnDtmfDigitParam * >(argp1);
  result = (pjsua_dtmf_method) ((arg1)->method);
  resultobj = SWIG_From_int(static_cast< int >(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_OnDtmfDigitParam_digit_set(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::OnDtmfDigitParam *arg1 = (pj::OnDtmfDigitParam *) 0 ;
  pj::string *arg2 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  int res2 = SWIG_OLDOBJ ;
  PyObject *swig_obj[2] ;
  
  if (!SWIG_Python_UnpackTuple(args, "OnDtmfDigitParam_digit_set", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__OnDtmfDigitParam, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "OnDtmfDigitParam_digit_set" "', argument " "1"" of type '" "pj::OnDtmfDigitParam *""'"); 
  }
  arg1 = reinterpret_cast< pj::OnDtmfDigitParam * >(argp1);
  {
    std::string *ptr = (std::string *)0;
    res2 = SWIG_AsPtr_std_string(swig_obj[1], &ptr);
    if (!SWIG_IsOK(res2)) {
      SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "OnDtmfDigitParam_digit_set" "', argument " "2"" of type '" "pj::string const &""'"); 
    }
    if (!ptr) {
      SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "OnDtmfDigitParam_digit_set" "', argument " "2"" of type '" "pj::string const &""'"); 
    }
    arg2 = ptr;
  }
  if (arg1) (arg1)->digit = *arg2;
  resultobj = SWIG_Py_Void();
  if (SWIG_IsNewObj(res2)) delete arg2;
  return resultobj;
fail:
  if (SWIG_IsNewObj(res2)) delete arg2;
  return NULL;
}


SWIGINTERN PyObject *_wrap_OnDtmfDigitParam_digit_get(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::OnDtmfDigitParam *arg1 = (pj::OnDtmfDigitParam *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  pj::string *result = 0 ;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__OnDtmfDigitParam, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "OnDtmfDigitParam_digit_get" "', argument " "1"" of type '" "pj::OnDtmfDigitParam *""'"); 
  }
  arg1 = reinterpret_cast< pj::OnDtmfDigitParam * >(argp1);
  result = (pj::string *) & ((arg1)->digit);
  resultobj = SWIG_From_std_string(static_cast< std::string >(*result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_OnDtmfDigitParam_duration_set(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::OnDtmfDigitParam *arg1 = (pj::OnDtmfDigitParam *) 0 ;
  unsigned int arg2 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  unsigned int val2 ;
  int ecode2 = 0 ;
  PyObject *swig_obj[2] ;
  
  if (!SWIG_Python_UnpackTuple(args, "OnDtmfDigitParam_duration_set", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__OnDtmfDigitParam, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "OnDtmfDigitParam_duration_set" "', argument " "1"" of type '" "pj::OnDtmfDigitParam *""'"); 
  }
  arg1 = reinterpret_cast< pj::OnDtmfDigitParam * >(argp1);
  ecode2 = SWIG_AsVal_unsigned_SS_int(swig_obj[1], &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "OnDtmfDigitParam_duration_set" "', argument " "2"" of type '" "unsigned int""'");
  } 
  arg2 = static_cast< unsigned int >(val2);
  if (arg1) (arg1)->duration = arg2;
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_OnDtmfDigitParam_duration_get(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::OnDtmfDigitParam *arg1 = (pj::OnDtmfDigitParam *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  unsigned int result;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__OnDtmfDigitParam, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "OnDtmfDigitParam_duration_get" "', argument " "1"" of type '" "pj::OnDtmfDigitParam *""'"); 
  }
  arg1 = reinterpret_cast< pj::OnDtmfDigitParam * >(argp1);
  result = (unsigned int) ((arg1)->duration);
  resultobj = SWIG_From_unsigned_SS_int(static_cast< unsigned int >(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_new_OnDtmfDigitParam(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::OnDtmfDigitParam *result = 0 ;
  
  if (!SWIG_Python_UnpackTuple(args, "new_OnDtmfDigitParam", 0, 0, 0)) SWIG_fail;
  result = (pj::OnDtmfDigitParam *)new pj::OnDtmfDigitParam();
  resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(result), SWIGTYPE_p_pj__OnDtmfDigitParam, SWIG_POINTER_NEW |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_delete_OnDtmfDigitParam(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::OnDtmfDigitParam *arg1 = (pj::OnDtmfDigitParam *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__OnDtmfDigitParam, SWIG_POINTER_DISOWN |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "delete_OnDtmfDigitParam" "', argument " "1"" of type '" "pj::OnDtmfDigitParam *""'"); 
  }
  arg1 = reinterpret_cast< pj::OnDtmfDigitParam * >(argp1);
  delete arg1;
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *OnDtmfDigitParam_swigregister(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *obj;
  if (!SWIG_Python_UnpackTuple(args, "swigregister", 1, 1, &obj)) return NULL;
  SWIG_TypeNewClientData(SWIGTYPE_p_pj__OnDtmfDigitParam, SWIG_NewClientData(obj));
  return SWIG_Py_Void();
}

SWIGINTERN PyObject *OnDtmfDigitParam_swiginit(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  return SWIG_Python_InitShadowInstance(args);
}

SWIGINTERN PyObject *_wrap_OnDtmfEventParam_method_set(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::OnDtmfEventParam *arg1 = (pj::OnDtmfEventParam *) 0 ;
  pjsua_dtmf_method arg2 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  int val2 ;
  int ecode2 = 0 ;
  PyObject *swig_obj[2] ;
  
  if (!SWIG_Python_UnpackTuple(args, "OnDtmfEventParam_method_set", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__OnDtmfEventParam, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "OnDtmfEventParam_method_set" "', argument " "1"" of type '" "pj::OnDtmfEventParam *""'"); 
  }
  arg1 = reinterpret_cast< pj::OnDtmfEventParam * >(argp1);
  ecode2 = SWIG_AsVal_int(swig_obj[1], &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "OnDtmfEventParam_method_set" "', argument " "2"" of type '" "pjsua_dtmf_method""'");
  } 
  arg2 = static_cast< pjsua_dtmf_method >(val2);
  if (arg1) (arg1)->method = arg2;
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_OnDtmfEventParam_method_get(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::OnDtmfEventParam *arg1 = (pj::OnDtmfEventParam *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  pjsua_dtmf_method result;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__OnDtmfEventParam, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "OnDtmfEventParam_method_get" "', argument " "1"" of type '" "pj::OnDtmfEventParam *""'"); 
  }
  arg1 = reinterpret_cast< pj::OnDtmfEventParam * >(argp1);
  result = (pjsua_dtmf_method) ((arg1)->method);
  resultobj = SWIG_From_int(static_cast< int >(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_OnDtmfEventParam_timestamp_set(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::OnDtmfEventParam *arg1 = (pj::OnDtmfEventParam *) 0 ;
  unsigned int arg2 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  unsigned int val2 ;
  int ecode2 = 0 ;
  PyObject *swig_obj[2] ;
  
  if (!SWIG_Python_UnpackTuple(args, "OnDtmfEventParam_timestamp_set", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__OnDtmfEventParam, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "OnDtmfEventParam_timestamp_set" "', argument " "1"" of type '" "pj::OnDtmfEventParam *""'"); 
  }
  arg1 = reinterpret_cast< pj::OnDtmfEventParam * >(argp1);
  ecode2 = SWIG_AsVal_unsigned_SS_int(swig_obj[1], &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "OnDtmfEventParam_timestamp_set" "', argument " "2"" of type '" "unsigned int""'");
  } 
  arg2 = static_cast< unsigned int >(val2);
  if (arg1) (arg1)->timestamp = arg2;
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_OnDtmfEventParam_timestamp_get(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::OnDtmfEventParam *arg1 = (pj::OnDtmfEventParam *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  unsigned int result;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__OnDtmfEventParam, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "OnDtmfEventParam_timestamp_get" "', argument " "1"" of type '" "pj::OnDtmfEventParam *""'"); 
  }
  arg1 = reinterpret_cast< pj::OnDtmfEventParam * >(argp1);
  result = (unsigned int) ((arg1)->timestamp);
  resultobj = SWIG_From_unsigned_SS_int(static_cast< unsigned int >(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_OnDtmfEventParam_digit_set(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::OnDtmfEventParam *arg1 = (pj::OnDtmfEventParam *) 0 ;
  pj::string *arg2 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  int res2 = SWIG_OLDOBJ ;
  PyObject *swig_obj[2] ;
  
  if (!SWIG_Python_UnpackTuple(args, "OnDtmfEventParam_digit_set", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__OnDtmfEventParam, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "OnDtmfEventParam_digit_set" "', argument " "1"" of type '" "pj::OnDtmfEventParam *""'"); 
  }
  arg1 = reinterpret_cast< pj::OnDtmfEventParam * >(argp1);
  {
    std::string *ptr = (std::string *)0;
    res2 = SWIG_AsPtr_std_string(swig_obj[1], &ptr);
    if (!SWIG_IsOK(res2)) {
      SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "OnDtmfEventParam_digit_set" "', argument " "2"" of type '" "pj::string const &""'"); 
    }
    if (!ptr) {
      SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "OnDtmfEventParam_digit_set" "', argument " "2"" of type '" "pj::string const &""'"); 
    }
    arg2 = ptr;
  }
  if (arg1) (arg1)->digit = *arg2;
  resultobj = SWIG_Py_Void();
  if (SWIG_IsNewObj(res2)) delete arg2;
  return resultobj;
fail:
  if (SWIG_IsNewObj(res2)) delete arg2;
  return NULL;
}


SWIGINTERN PyObject *_wrap_OnDtmfEventParam_digit_get(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::OnDtmfEventParam *arg1 = (pj::OnDtmfEventParam *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  pj::string *result = 0 ;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__OnDtmfEventParam, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "OnDtmfEventParam_digit_get" "', argument " "1"" of type '" "pj::OnDtmfEventParam *""'"); 
  }
  arg1 = reinterpret_cast< pj::OnDtmfEventParam * >(argp1);
  result = (pj::string *) & ((arg1)->digit);
  resultobj = SWIG_From_std_string(static_cast< std::string >(*result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_OnDtmfEventParam_duration_set(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::OnDtmfEventParam *arg1 = (pj::OnDtmfEventParam *) 0 ;
  unsigned int arg2 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  unsigned int val2 ;
  int ecode2 = 0 ;
  PyObject *swig_obj[2] ;
  
  if (!SWIG_Python_UnpackTuple(args, "OnDtmfEventParam_duration_set", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__OnDtmfEventParam, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "OnDtmfEventParam_duration_set" "', argument " "1"" of type '" "pj::OnDtmfEventParam *""'"); 
  }
  arg1 = reinterpret_cast< pj::OnDtmfEventParam * >(argp1);
  ecode2 = SWIG_AsVal_unsigned_SS_int(swig_obj[1], &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "OnDtmfEventParam_duration_set" "', argument " "2"" of type '" "unsigned int""'");
  } 
  arg2 = static_cast< unsigned int >(val2);
  if (arg1) (arg1)->duration = arg2;
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_OnDtmfEventParam_duration_get(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::OnDtmfEventParam *arg1 = (pj::OnDtmfEventParam *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  unsigned int result;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__OnDtmfEventParam, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "OnDtmfEventParam_duration_get" "', argument " "1"" of type '" "pj::OnDtmfEventParam *""'"); 
  }
  arg1 = reinterpret_cast< pj::OnDtmfEventParam * >(argp1);
  result = (unsigned int) ((arg1)->duration);
  resultobj = SWIG_From_unsigned_SS_int(static_cast< unsigned int >(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_OnDtmfEventParam_flags_set(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::OnDtmfEventParam *arg1 = (pj::OnDtmfEventParam *) 0 ;
  unsigned int arg2 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  unsigned int val2 ;
  int ecode2 = 0 ;
  PyObject *swig_obj[2] ;
  
  if (!SWIG_Python_UnpackTuple(args, "OnDtmfEventParam_flags_set", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__OnDtmfEventParam, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "OnDtmfEventParam_flags_set" "', argument " "1"" of type '" "pj::OnDtmfEventParam *""'"); 
  }
  arg1 = reinterpret_cast< pj::OnDtmfEventParam * >(argp1);
  ecode2 = SWIG_AsVal_unsigned_SS_int(swig_obj[1], &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "OnDtmfEventParam_flags_set" "', argument " "2"" of type '" "unsigned int""'");
  } 
  arg2 = static_cast< unsigned int >(val2);
  if (arg1) (arg1)->flags = arg2;
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_OnDtmfEventParam_flags_get(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::OnDtmfEventParam *arg1 = (pj::OnDtmfEventParam *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  unsigned int result;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__OnDtmfEventParam, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "OnDtmfEventParam_flags_get" "', argument " "1"" of type '" "pj::OnDtmfEventParam *""'"); 
  }
  arg1 = reinterpret_cast< pj::OnDtmfEventParam * >(argp1);
  result = (unsigned int) ((arg1)->flags);
  resultobj = SWIG_From_unsigned_SS_int(static_cast< unsigned int >(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_new_OnDtmfEventParam(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::OnDtmfEventParam *result = 0 ;
  
  if (!SWIG_Python_UnpackTuple(args, "new_OnDtmfEventParam", 0, 0, 0)) SWIG_fail;
  result = (pj::OnDtmfEventParam *)new pj::OnDtmfEventParam();
  resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(result), SWIGTYPE_p_pj__OnDtmfEventParam, SWIG_POINTER_NEW |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_delete_OnDtmfEventParam(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::OnDtmfEventParam *arg1 = (pj::OnDtmfEventParam *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__OnDtmfEventParam, SWIG_POINTER_DISOWN |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "delete_OnDtmfEventParam" "', argument " "1"" of type '" "pj::OnDtmfEventParam *""'"); 
  }
  arg1 = reinterpret_cast< pj::OnDtmfEventParam * >(argp1);
  delete arg1;
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *OnDtmfEventParam_swigregister(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *obj;
  if (!SWIG_Python_UnpackTuple(args, "swigregister", 1, 1, &obj)) return NULL;
  SWIG_TypeNewClientData(SWIGTYPE_p_pj__OnDtmfEventParam, SWIG_NewClientData(obj));
  return SWIG_Py_Void();
}

SWIGINTERN PyObject *OnDtmfEventParam_swiginit(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  return SWIG_Python_InitShadowInstance(args);
}

SWIGINTERN PyObject *_wrap_OnCallTransferRequestParam_dstUri_set(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::OnCallTransferRequestParam *arg1 = (pj::OnCallTransferRequestParam *) 0 ;
  pj::string *arg2 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  int res2 = SWIG_OLDOBJ ;
  PyObject *swig_obj[2] ;
  
  if (!SWIG_Python_UnpackTuple(args, "OnCallTransferRequestParam_dstUri_set", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__OnCallTransferRequestParam, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "OnCallTransferRequestParam_dstUri_set" "', argument " "1"" of type '" "pj::OnCallTransferRequestParam *""'"); 
  }
  arg1 = reinterpret_cast< pj::OnCallTransferRequestParam * >(argp1);
  {
    std::string *ptr = (std::string *)0;
    res2 = SWIG_AsPtr_std_string(swig_obj[1], &ptr);
    if (!SWIG_IsOK(res2)) {
      SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "OnCallTransferRequestParam_dstUri_set" "', argument " "2"" of type '" "pj::string const &""'"); 
    }
    if (!ptr) {
      SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "OnCallTransferRequestParam_dstUri_set" "', argument " "2"" of type '" "pj::string const &""'"); 
    }
    arg2 = ptr;
  }
  if (arg1) (arg1)->dstUri = *arg2;
  resultobj = SWIG_Py_Void();
  if (SWIG_IsNewObj(res2)) delete arg2;
  return resultobj;
fail:
  if (SWIG_IsNewObj(res2)) delete arg2;
  return NULL;
}


SWIGINTERN PyObject *_wrap_OnCallTransferRequestParam_dstUri_get(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::OnCallTransferRequestParam *arg1 = (pj::OnCallTransferRequestParam *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  pj::string *result = 0 ;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__OnCallTransferRequestParam, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "OnCallTransferRequestParam_dstUri_get" "', argument " "1"" of type '" "pj::OnCallTransferRequestParam *""'"); 
  }
  arg1 = reinterpret_cast< pj::OnCallTransferRequestParam * >(argp1);
  result = (pj::string *) & ((arg1)->dstUri);
  resultobj = SWIG_From_std_string(static_cast< std::string >(*result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_OnCallTransferRequestParam_statusCode_set(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::OnCallTransferRequestParam *arg1 = (pj::OnCallTransferRequestParam *) 0 ;
  pjsip_status_code arg2 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  int val2 ;
  int ecode2 = 0 ;
  PyObject *swig_obj[2] ;
  
  if (!SWIG_Python_UnpackTuple(args, "OnCallTransferRequestParam_statusCode_set", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__OnCallTransferRequestParam, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "OnCallTransferRequestParam_statusCode_set" "', argument " "1"" of type '" "pj::OnCallTransferRequestParam *""'"); 
  }
  arg1 = reinterpret_cast< pj::OnCallTransferRequestParam * >(argp1);
  ecode2 = SWIG_AsVal_int(swig_obj[1], &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "OnCallTransferRequestParam_statusCode_set" "', argument " "2"" of type '" "pjsip_status_code""'");
  } 
  arg2 = static_cast< pjsip_status_code >(val2);
  if (arg1) (arg1)->statusCode = arg2;
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_OnCallTransferRequestParam_statusCode_get(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::OnCallTransferRequestParam *arg1 = (pj::OnCallTransferRequestParam *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  pjsip_status_code result;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__OnCallTransferRequestParam, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "OnCallTransferRequestParam_statusCode_get" "', argument " "1"" of type '" "pj::OnCallTransferRequestParam *""'"); 
  }
  arg1 = reinterpret_cast< pj::OnCallTransferRequestParam * >(argp1);
  result = (pjsip_status_code) ((arg1)->statusCode);
  resultobj = SWIG_From_int(static_cast< int >(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_OnCallTransferRequestParam_opt_set(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::OnCallTransferRequestParam *arg1 = (pj::OnCallTransferRequestParam *) 0 ;
  pj::CallSetting *arg2 = (pj::CallSetting *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  void *argp2 = 0 ;
  int res2 = 0 ;
  PyObject *swig_obj[2] ;
  
  if (!SWIG_Python_UnpackTuple(args, "OnCallTransferRequestParam_opt_set", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__OnCallTransferRequestParam, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "OnCallTransferRequestParam_opt_set" "', argument " "1"" of type '" "pj::OnCallTransferRequestParam *""'"); 
  }
  arg1 = reinterpret_cast< pj::OnCallTransferRequestParam * >(argp1);
  res2 = SWIG_ConvertPtr(swig_obj[1], &argp2,SWIGTYPE_p_pj__CallSetting, 0 |  0 );
  if (!SWIG_IsOK(res2)) {
    SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "OnCallTransferRequestParam_opt_set" "', argument " "2"" of type '" "pj::CallSetting *""'"); 
  }
  arg2 = reinterpret_cast< pj::CallSetting * >(argp2);
  if (arg1) (arg1)->opt = *arg2;
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_OnCallTransferRequestParam_opt_get(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::OnCallTransferRequestParam *arg1 = (pj::OnCallTransferRequestParam *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  pj::CallSetting *result = 0 ;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__OnCallTransferRequestParam, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "OnCallTransferRequestParam_opt_get" "', argument " "1"" of type '" "pj::OnCallTransferRequestParam *""'"); 
  }
  arg1 = reinterpret_cast< pj::OnCallTransferRequestParam * >(argp1);
  result = (pj::CallSetting *)& ((arg1)->opt);
  resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(result), SWIGTYPE_p_pj__CallSetting, 0 |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_OnCallTransferRequestParam_newCall_set(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::OnCallTransferRequestParam *arg1 = (pj::OnCallTransferRequestParam *) 0 ;
  pj::Call *arg2 = (pj::Call *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  void *argp2 = 0 ;
  int res2 = 0 ;
  PyObject *swig_obj[2] ;
  
  if (!SWIG_Python_UnpackTuple(args, "OnCallTransferRequestParam_newCall_set", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__OnCallTransferRequestParam, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "OnCallTransferRequestParam_newCall_set" "', argument " "1"" of type '" "pj::OnCallTransferRequestParam *""'"); 
  }
  arg1 = reinterpret_cast< pj::OnCallTransferRequestParam * >(argp1);
  res2 = SWIG_ConvertPtr(swig_obj[1], &argp2,SWIGTYPE_p_pj__Call, SWIG_POINTER_DISOWN |  0 );
  if (!SWIG_IsOK(res2)) {
    SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "OnCallTransferRequestParam_newCall_set" "', argument " "2"" of type '" "pj::Call *""'"); 
  }
  arg2 = reinterpret_cast< pj::Call * >(argp2);
  if (arg1) (arg1)->newCall = arg2;
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_OnCallTransferRequestParam_newCall_get(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::OnCallTransferRequestParam *arg1 = (pj::OnCallTransferRequestParam *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  pj::Call *result = 0 ;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__OnCallTransferRequestParam, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "OnCallTransferRequestParam_newCall_get" "', argument " "1"" of type '" "pj::OnCallTransferRequestParam *""'"); 
  }
  arg1 = reinterpret_cast< pj::OnCallTransferRequestParam * >(argp1);
  result = (pj::Call *) ((arg1)->newCall);
  resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(result), SWIGTYPE_p_pj__Call, 0 |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_new_OnCallTransferRequestParam(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::OnCallTransferRequestParam *result = 0 ;
  
  if (!SWIG_Python_UnpackTuple(args, "new_OnCallTransferRequestParam", 0, 0, 0)) SWIG_fail;
  result = (pj::OnCallTransferRequestParam *)new pj::OnCallTransferRequestParam();
  resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(result), SWIGTYPE_p_pj__OnCallTransferRequestParam, SWIG_POINTER_NEW |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_delete_OnCallTransferRequestParam(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::OnCallTransferRequestParam *arg1 = (pj::OnCallTransferRequestParam *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__OnCallTransferRequestParam, SWIG_POINTER_DISOWN |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "delete_OnCallTransferRequestParam" "', argument " "1"" of type '" "pj::OnCallTransferRequestParam *""'"); 
  }
  arg1 = reinterpret_cast< pj::OnCallTransferRequestParam * >(argp1);
  delete arg1;
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *OnCallTransferRequestParam_swigregister(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *obj;
  if (!SWIG_Python_UnpackTuple(args, "swigregister", 1, 1, &obj)) return NULL;
  SWIG_TypeNewClientData(SWIGTYPE_p_pj__OnCallTransferRequestParam, SWIG_NewClientData(obj));
  return SWIG_Py_Void();
}

SWIGINTERN PyObject *OnCallTransferRequestParam_swiginit(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  return SWIG_Python_InitShadowInstance(args);
}

SWIGINTERN PyObject *_wrap_OnCallTransferStatusParam_statusCode_set(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::OnCallTransferStatusParam *arg1 = (pj::OnCallTransferStatusParam *) 0 ;
  pjsip_status_code arg2 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  int val2 ;
  int ecode2 = 0 ;
  PyObject *swig_obj[2] ;
  
  if (!SWIG_Python_UnpackTuple(args, "OnCallTransferStatusParam_statusCode_set", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__OnCallTransferStatusParam, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "OnCallTransferStatusParam_statusCode_set" "', argument " "1"" of type '" "pj::OnCallTransferStatusParam *""'"); 
  }
  arg1 = reinterpret_cast< pj::OnCallTransferStatusParam * >(argp1);
  ecode2 = SWIG_AsVal_int(swig_obj[1], &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "OnCallTransferStatusParam_statusCode_set" "', argument " "2"" of type '" "pjsip_status_code""'");
  } 
  arg2 = static_cast< pjsip_status_code >(val2);
  if (arg1) (arg1)->statusCode = arg2;
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_OnCallTransferStatusParam_statusCode_get(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::OnCallTransferStatusParam *arg1 = (pj::OnCallTransferStatusParam *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  pjsip_status_code result;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__OnCallTransferStatusParam, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "OnCallTransferStatusParam_statusCode_get" "', argument " "1"" of type '" "pj::OnCallTransferStatusParam *""'"); 
  }
  arg1 = reinterpret_cast< pj::OnCallTransferStatusParam * >(argp1);
  result = (pjsip_status_code) ((arg1)->statusCode);
  resultobj = SWIG_From_int(static_cast< int >(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_OnCallTransferStatusParam_reason_set(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::OnCallTransferStatusParam *arg1 = (pj::OnCallTransferStatusParam *) 0 ;
  pj::string *arg2 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  int res2 = SWIG_OLDOBJ ;
  PyObject *swig_obj[2] ;
  
  if (!SWIG_Python_UnpackTuple(args, "OnCallTransferStatusParam_reason_set", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__OnCallTransferStatusParam, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "OnCallTransferStatusParam_reason_set" "', argument " "1"" of type '" "pj::OnCallTransferStatusParam *""'"); 
  }
  arg1 = reinterpret_cast< pj::OnCallTransferStatusParam * >(argp1);
  {
    std::string *ptr = (std::string *)0;
    res2 = SWIG_AsPtr_std_string(swig_obj[1], &ptr);
    if (!SWIG_IsOK(res2)) {
      SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "OnCallTransferStatusParam_reason_set" "', argument " "2"" of type '" "pj::string const &""'"); 
    }
    if (!ptr) {
      SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "OnCallTransferStatusParam_reason_set" "', argument " "2"" of type '" "pj::string const &""'"); 
    }
    arg2 = ptr;
  }
  if (arg1) (arg1)->reason = *arg2;
  resultobj = SWIG_Py_Void();
  if (SWIG_IsNewObj(res2)) delete arg2;
  return resultobj;
fail:
  if (SWIG_IsNewObj(res2)) delete arg2;
  return NULL;
}


SWIGINTERN PyObject *_wrap_OnCallTransferStatusParam_reason_get(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::OnCallTransferStatusParam *arg1 = (pj::OnCallTransferStatusParam *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  pj::string *result = 0 ;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__OnCallTransferStatusParam, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "OnCallTransferStatusParam_reason_get" "', argument " "1"" of type '" "pj::OnCallTransferStatusParam *""'"); 
  }
  arg1 = reinterpret_cast< pj::OnCallTransferStatusParam * >(argp1);
  result = (pj::string *) & ((arg1)->reason);
  resultobj = SWIG_From_std_string(static_cast< std::string >(*result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_OnCallTransferStatusParam_finalNotify_set(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::OnCallTransferStatusParam *arg1 = (pj::OnCallTransferStatusParam *) 0 ;
  bool arg2 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  bool val2 ;
  int ecode2 = 0 ;
  PyObject *swig_obj[2] ;
  
  if (!SWIG_Python_UnpackTuple(args, "OnCallTransferStatusParam_finalNotify_set", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__OnCallTransferStatusParam, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "OnCallTransferStatusParam_finalNotify_set" "', argument " "1"" of type '" "pj::OnCallTransferStatusParam *""'"); 
  }
  arg1 = reinterpret_cast< pj::OnCallTransferStatusParam * >(argp1);
  ecode2 = SWIG_AsVal_bool(swig_obj[1], &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "OnCallTransferStatusParam_finalNotify_set" "', argument " "2"" of type '" "bool""'");
  } 
  arg2 = static_cast< bool >(val2);
  if (arg1) (arg1)->finalNotify = arg2;
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_OnCallTransferStatusParam_finalNotify_get(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::OnCallTransferStatusParam *arg1 = (pj::OnCallTransferStatusParam *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  bool result;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__OnCallTransferStatusParam, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "OnCallTransferStatusParam_finalNotify_get" "', argument " "1"" of type '" "pj::OnCallTransferStatusParam *""'"); 
  }
  arg1 = reinterpret_cast< pj::OnCallTransferStatusParam * >(argp1);
  result = (bool) ((arg1)->finalNotify);
  resultobj = SWIG_From_bool(static_cast< bool >(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_OnCallTransferStatusParam_cont_set(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::OnCallTransferStatusParam *arg1 = (pj::OnCallTransferStatusParam *) 0 ;
  bool arg2 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  bool val2 ;
  int ecode2 = 0 ;
  PyObject *swig_obj[2] ;
  
  if (!SWIG_Python_UnpackTuple(args, "OnCallTransferStatusParam_cont_set", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__OnCallTransferStatusParam, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "OnCallTransferStatusParam_cont_set" "', argument " "1"" of type '" "pj::OnCallTransferStatusParam *""'"); 
  }
  arg1 = reinterpret_cast< pj::OnCallTransferStatusParam * >(argp1);
  ecode2 = SWIG_AsVal_bool(swig_obj[1], &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "OnCallTransferStatusParam_cont_set" "', argument " "2"" of type '" "bool""'");
  } 
  arg2 = static_cast< bool >(val2);
  if (arg1) (arg1)->cont = arg2;
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_OnCallTransferStatusParam_cont_get(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::OnCallTransferStatusParam *arg1 = (pj::OnCallTransferStatusParam *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  bool result;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__OnCallTransferStatusParam, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "OnCallTransferStatusParam_cont_get" "', argument " "1"" of type '" "pj::OnCallTransferStatusParam *""'"); 
  }
  arg1 = reinterpret_cast< pj::OnCallTransferStatusParam * >(argp1);
  result = (bool) ((arg1)->cont);
  resultobj = SWIG_From_bool(static_cast< bool >(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_new_OnCallTransferStatusParam(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::OnCallTransferStatusParam *result = 0 ;
  
  if (!SWIG_Python_UnpackTuple(args, "new_OnCallTransferStatusParam", 0, 0, 0)) SWIG_fail;
  result = (pj::OnCallTransferStatusParam *)new pj::OnCallTransferStatusParam();
  resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(result), SWIGTYPE_p_pj__OnCallTransferStatusParam, SWIG_POINTER_NEW |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_delete_OnCallTransferStatusParam(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::OnCallTransferStatusParam *arg1 = (pj::OnCallTransferStatusParam *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__OnCallTransferStatusParam, SWIG_POINTER_DISOWN |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "delete_OnCallTransferStatusParam" "', argument " "1"" of type '" "pj::OnCallTransferStatusParam *""'"); 
  }
  arg1 = reinterpret_cast< pj::OnCallTransferStatusParam * >(argp1);
  delete arg1;
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *OnCallTransferStatusParam_swigregister(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *obj;
  if (!SWIG_Python_UnpackTuple(args, "swigregister", 1, 1, &obj)) return NULL;
  SWIG_TypeNewClientData(SWIGTYPE_p_pj__OnCallTransferStatusParam, SWIG_NewClientData(obj));
  return SWIG_Py_Void();
}

SWIGINTERN PyObject *OnCallTransferStatusParam_swiginit(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  return SWIG_Python_InitShadowInstance(args);
}

SWIGINTERN PyObject *_wrap_OnCallReplaceRequestParam_rdata_set(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::OnCallReplaceRequestParam *arg1 = (pj::OnCallReplaceRequestParam *) 0 ;
  pj::SipRxData *arg2 = (pj::SipRxData *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  void *argp2 = 0 ;
  int res2 = 0 ;
  PyObject *swig_obj[2] ;
  
  if (!SWIG_Python_UnpackTuple(args, "OnCallReplaceRequestParam_rdata_set", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__OnCallReplaceRequestParam, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "OnCallReplaceRequestParam_rdata_set" "', argument " "1"" of type '" "pj::OnCallReplaceRequestParam *""'"); 
  }
  arg1 = reinterpret_cast< pj::OnCallReplaceRequestParam * >(argp1);
  res2 = SWIG_ConvertPtr(swig_obj[1], &argp2,SWIGTYPE_p_pj__SipRxData, 0 |  0 );
  if (!SWIG_IsOK(res2)) {
    SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "OnCallReplaceRequestParam_rdata_set" "', argument " "2"" of type '" "pj::SipRxData *""'"); 
  }
  arg2 = reinterpret_cast< pj::SipRxData * >(argp2);
  if (arg1) (arg1)->rdata = *arg2;
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_OnCallReplaceRequestParam_rdata_get(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::OnCallReplaceRequestParam *arg1 = (pj::OnCallReplaceRequestParam *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  pj::SipRxData *result = 0 ;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__OnCallReplaceRequestParam, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "OnCallReplaceRequestParam_rdata_get" "', argument " "1"" of type '" "pj::OnCallReplaceRequestParam *""'"); 
  }
  arg1 = reinterpret_cast< pj::OnCallReplaceRequestParam * >(argp1);
  result = (pj::SipRxData *)& ((arg1)->rdata);
  resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(result), SWIGTYPE_p_pj__SipRxData, 0 |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_OnCallReplaceRequestParam_statusCode_set(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::OnCallReplaceRequestParam *arg1 = (pj::OnCallReplaceRequestParam *) 0 ;
  pjsip_status_code arg2 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  int val2 ;
  int ecode2 = 0 ;
  PyObject *swig_obj[2] ;
  
  if (!SWIG_Python_UnpackTuple(args, "OnCallReplaceRequestParam_statusCode_set", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__OnCallReplaceRequestParam, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "OnCallReplaceRequestParam_statusCode_set" "', argument " "1"" of type '" "pj::OnCallReplaceRequestParam *""'"); 
  }
  arg1 = reinterpret_cast< pj::OnCallReplaceRequestParam * >(argp1);
  ecode2 = SWIG_AsVal_int(swig_obj[1], &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "OnCallReplaceRequestParam_statusCode_set" "', argument " "2"" of type '" "pjsip_status_code""'");
  } 
  arg2 = static_cast< pjsip_status_code >(val2);
  if (arg1) (arg1)->statusCode = arg2;
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_OnCallReplaceRequestParam_statusCode_get(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::OnCallReplaceRequestParam *arg1 = (pj::OnCallReplaceRequestParam *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  pjsip_status_code result;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__OnCallReplaceRequestParam, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "OnCallReplaceRequestParam_statusCode_get" "', argument " "1"" of type '" "pj::OnCallReplaceRequestParam *""'"); 
  }
  arg1 = reinterpret_cast< pj::OnCallReplaceRequestParam * >(argp1);
  result = (pjsip_status_code) ((arg1)->statusCode);
  resultobj = SWIG_From_int(static_cast< int >(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_OnCallReplaceRequestParam_reason_set(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::OnCallReplaceRequestParam *arg1 = (pj::OnCallReplaceRequestParam *) 0 ;
  pj::string *arg2 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  int res2 = SWIG_OLDOBJ ;
  PyObject *swig_obj[2] ;
  
  if (!SWIG_Python_UnpackTuple(args, "OnCallReplaceRequestParam_reason_set", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__OnCallReplaceRequestParam, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "OnCallReplaceRequestParam_reason_set" "', argument " "1"" of type '" "pj::OnCallReplaceRequestParam *""'"); 
  }
  arg1 = reinterpret_cast< pj::OnCallReplaceRequestParam * >(argp1);
  {
    std::string *ptr = (std::string *)0;
    res2 = SWIG_AsPtr_std_string(swig_obj[1], &ptr);
    if (!SWIG_IsOK(res2)) {
      SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "OnCallReplaceRequestParam_reason_set" "', argument " "2"" of type '" "pj::string const &""'"); 
    }
    if (!ptr) {
      SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "OnCallReplaceRequestParam_reason_set" "', argument " "2"" of type '" "pj::string const &""'"); 
    }
    arg2 = ptr;
  }
  if (arg1) (arg1)->reason = *arg2;
  resultobj = SWIG_Py_Void();
  if (SWIG_IsNewObj(res2)) delete arg2;
  return resultobj;
fail:
  if (SWIG_IsNewObj(res2)) delete arg2;
  return NULL;
}


SWIGINTERN PyObject *_wrap_OnCallReplaceRequestParam_reason_get(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::OnCallReplaceRequestParam *arg1 = (pj::OnCallReplaceRequestParam *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  pj::string *result = 0 ;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__OnCallReplaceRequestParam, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "OnCallReplaceRequestParam_reason_get" "', argument " "1"" of type '" "pj::OnCallReplaceRequestParam *""'"); 
  }
  arg1 = reinterpret_cast< pj::OnCallReplaceRequestParam * >(argp1);
  result = (pj::string *) & ((arg1)->reason);
  resultobj = SWIG_From_std_string(static_cast< std::string >(*result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_OnCallReplaceRequestParam_opt_set(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::OnCallReplaceRequestParam *arg1 = (pj::OnCallReplaceRequestParam *) 0 ;
  pj::CallSetting *arg2 = (pj::CallSetting *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  void *argp2 = 0 ;
  int res2 = 0 ;
  PyObject *swig_obj[2] ;
  
  if (!SWIG_Python_UnpackTuple(args, "OnCallReplaceRequestParam_opt_set", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__OnCallReplaceRequestParam, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "OnCallReplaceRequestParam_opt_set" "', argument " "1"" of type '" "pj::OnCallReplaceRequestParam *""'"); 
  }
  arg1 = reinterpret_cast< pj::OnCallReplaceRequestParam * >(argp1);
  res2 = SWIG_ConvertPtr(swig_obj[1], &argp2,SWIGTYPE_p_pj__CallSetting, 0 |  0 );
  if (!SWIG_IsOK(res2)) {
    SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "OnCallReplaceRequestParam_opt_set" "', argument " "2"" of type '" "pj::CallSetting *""'"); 
  }
  arg2 = reinterpret_cast< pj::CallSetting * >(argp2);
  if (arg1) (arg1)->opt = *arg2;
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_OnCallReplaceRequestParam_opt_get(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::OnCallReplaceRequestParam *arg1 = (pj::OnCallReplaceRequestParam *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  pj::CallSetting *result = 0 ;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__OnCallReplaceRequestParam, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "OnCallReplaceRequestParam_opt_get" "', argument " "1"" of type '" "pj::OnCallReplaceRequestParam *""'"); 
  }
  arg1 = reinterpret_cast< pj::OnCallReplaceRequestParam * >(argp1);
  result = (pj::CallSetting *)& ((arg1)->opt);
  resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(result), SWIGTYPE_p_pj__CallSetting, 0 |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_new_OnCallReplaceRequestParam(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::OnCallReplaceRequestParam *result = 0 ;
  
  if (!SWIG_Python_UnpackTuple(args, "new_OnCallReplaceRequestParam", 0, 0, 0)) SWIG_fail;
  result = (pj::OnCallReplaceRequestParam *)new pj::OnCallReplaceRequestParam();
  resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(result), SWIGTYPE_p_pj__OnCallReplaceRequestParam, SWIG_POINTER_NEW |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_delete_OnCallReplaceRequestParam(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::OnCallReplaceRequestParam *arg1 = (pj::OnCallReplaceRequestParam *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__OnCallReplaceRequestParam, SWIG_POINTER_DISOWN |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "delete_OnCallReplaceRequestParam" "', argument " "1"" of type '" "pj::OnCallReplaceRequestParam *""'"); 
  }
  arg1 = reinterpret_cast< pj::OnCallReplaceRequestParam * >(argp1);
  delete arg1;
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *OnCallReplaceRequestParam_swigregister(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *obj;
  if (!SWIG_Python_UnpackTuple(args, "swigregister", 1, 1, &obj)) return NULL;
  SWIG_TypeNewClientData(SWIGTYPE_p_pj__OnCallReplaceRequestParam, SWIG_NewClientData(obj));
  return SWIG_Py_Void();
}

SWIGINTERN PyObject *OnCallReplaceRequestParam_swiginit(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  return SWIG_Python_InitShadowInstance(args);
}

SWIGINTERN PyObject *_wrap_OnCallReplacedParam_newCallId_set(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::OnCallReplacedParam *arg1 = (pj::OnCallReplacedParam *) 0 ;
  pjsua_call_id arg2 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  int val2 ;
  int ecode2 = 0 ;
  PyObject *swig_obj[2] ;
  
  if (!SWIG_Python_UnpackTuple(args, "OnCallReplacedParam_newCallId_set", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__OnCallReplacedParam, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "OnCallReplacedParam_newCallId_set" "', argument " "1"" of type '" "pj::OnCallReplacedParam *""'"); 
  }
  arg1 = reinterpret_cast< pj::OnCallReplacedParam * >(argp1);
  ecode2 = SWIG_AsVal_int(swig_obj[1], &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "OnCallReplacedParam_newCallId_set" "', argument " "2"" of type '" "pjsua_call_id""'");
  } 
  arg2 = static_cast< pjsua_call_id >(val2);
  if (arg1) (arg1)->newCallId = arg2;
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_OnCallReplacedParam_newCallId_get(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::OnCallReplacedParam *arg1 = (pj::OnCallReplacedParam *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  pjsua_call_id result;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__OnCallReplacedParam, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "OnCallReplacedParam_newCallId_get" "', argument " "1"" of type '" "pj::OnCallReplacedParam *""'"); 
  }
  arg1 = reinterpret_cast< pj::OnCallReplacedParam * >(argp1);
  result = (pjsua_call_id) ((arg1)->newCallId);
  resultobj = SWIG_From_int(static_cast< int >(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_OnCallReplacedParam_newCall_set(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::OnCallReplacedParam *arg1 = (pj::OnCallReplacedParam *) 0 ;
  pj::Call *arg2 = (pj::Call *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  void *argp2 = 0 ;
  int res2 = 0 ;
  PyObject *swig_obj[2] ;
  
  if (!SWIG_Python_UnpackTuple(args, "OnCallReplacedParam_newCall_set", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__OnCallReplacedParam, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "OnCallReplacedParam_newCall_set" "', argument " "1"" of type '" "pj::OnCallReplacedParam *""'"); 
  }
  arg1 = reinterpret_cast< pj::OnCallReplacedParam * >(argp1);
  res2 = SWIG_ConvertPtr(swig_obj[1], &argp2,SWIGTYPE_p_pj__Call, SWIG_POINTER_DISOWN |  0 );
  if (!SWIG_IsOK(res2)) {
    SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "OnCallReplacedParam_newCall_set" "', argument " "2"" of type '" "pj::Call *""'"); 
  }
  arg2 = reinterpret_cast< pj::Call * >(argp2);
  if (arg1) (arg1)->newCall = arg2;
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_OnCallReplacedParam_newCall_get(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::OnCallReplacedParam *arg1 = (pj::OnCallReplacedParam *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  pj::Call *result = 0 ;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__OnCallReplacedParam, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "OnCallReplacedParam_newCall_get" "', argument " "1"" of type '" "pj::OnCallReplacedParam *""'"); 
  }
  arg1 = reinterpret_cast< pj::OnCallReplacedParam * >(argp1);
  result = (pj::Call *) ((arg1)->newCall);
  resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(result), SWIGTYPE_p_pj__Call, 0 |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_new_OnCallReplacedParam(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::OnCallReplacedParam *result = 0 ;
  
  if (!SWIG_Python_UnpackTuple(args, "new_OnCallReplacedParam", 0, 0, 0)) SWIG_fail;
  result = (pj::OnCallReplacedParam *)new pj::OnCallReplacedParam();
  resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(result), SWIGTYPE_p_pj__OnCallReplacedParam, SWIG_POINTER_NEW |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_delete_OnCallReplacedParam(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::OnCallReplacedParam *arg1 = (pj::OnCallReplacedParam *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__OnCallReplacedParam, SWIG_POINTER_DISOWN |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "delete_OnCallReplacedParam" "', argument " "1"" of type '" "pj::OnCallReplacedParam *""'"); 
  }
  arg1 = reinterpret_cast< pj::OnCallReplacedParam * >(argp1);
  delete arg1;
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *OnCallReplacedParam_swigregister(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *obj;
  if (!SWIG_Python_UnpackTuple(args, "swigregister", 1, 1, &obj)) return NULL;
  SWIG_TypeNewClientData(SWIGTYPE_p_pj__OnCallReplacedParam, SWIG_NewClientData(obj));
  return SWIG_Py_Void();
}

SWIGINTERN PyObject *OnCallReplacedParam_swiginit(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  return SWIG_Python_InitShadowInstance(args);
}

SWIGINTERN PyObject *_wrap_OnCallRxOfferParam_offer_set(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::OnCallRxOfferParam *arg1 = (pj::OnCallRxOfferParam *) 0 ;
  pj::SdpSession *arg2 = (pj::SdpSession *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  void *argp2 = 0 ;
  int res2 = 0 ;
  PyObject *swig_obj[2] ;
  
  if (!SWIG_Python_UnpackTuple(args, "OnCallRxOfferParam_offer_set", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__OnCallRxOfferParam, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "OnCallRxOfferParam_offer_set" "', argument " "1"" of type '" "pj::OnCallRxOfferParam *""'"); 
  }
  arg1 = reinterpret_cast< pj::OnCallRxOfferParam * >(argp1);
  res2 = SWIG_ConvertPtr(swig_obj[1], &argp2,SWIGTYPE_p_pj__SdpSession, 0 |  0 );
  if (!SWIG_IsOK(res2)) {
    SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "OnCallRxOfferParam_offer_set" "', argument " "2"" of type '" "pj::SdpSession *""'"); 
  }
  arg2 = reinterpret_cast< pj::SdpSession * >(argp2);
  if (arg1) (arg1)->offer = *arg2;
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_OnCallRxOfferParam_offer_get(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::OnCallRxOfferParam *arg1 = (pj::OnCallRxOfferParam *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  pj::SdpSession *result = 0 ;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__OnCallRxOfferParam, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "OnCallRxOfferParam_offer_get" "', argument " "1"" of type '" "pj::OnCallRxOfferParam *""'"); 
  }
  arg1 = reinterpret_cast< pj::OnCallRxOfferParam * >(argp1);
  result = (pj::SdpSession *)& ((arg1)->offer);
  resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(result), SWIGTYPE_p_pj__SdpSession, 0 |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_OnCallRxOfferParam_statusCode_set(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::OnCallRxOfferParam *arg1 = (pj::OnCallRxOfferParam *) 0 ;
  pjsip_status_code arg2 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  int val2 ;
  int ecode2 = 0 ;
  PyObject *swig_obj[2] ;
  
  if (!SWIG_Python_UnpackTuple(args, "OnCallRxOfferParam_statusCode_set", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__OnCallRxOfferParam, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "OnCallRxOfferParam_statusCode_set" "', argument " "1"" of type '" "pj::OnCallRxOfferParam *""'"); 
  }
  arg1 = reinterpret_cast< pj::OnCallRxOfferParam * >(argp1);
  ecode2 = SWIG_AsVal_int(swig_obj[1], &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "OnCallRxOfferParam_statusCode_set" "', argument " "2"" of type '" "pjsip_status_code""'");
  } 
  arg2 = static_cast< pjsip_status_code >(val2);
  if (arg1) (arg1)->statusCode = arg2;
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_OnCallRxOfferParam_statusCode_get(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::OnCallRxOfferParam *arg1 = (pj::OnCallRxOfferParam *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  pjsip_status_code result;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__OnCallRxOfferParam, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "OnCallRxOfferParam_statusCode_get" "', argument " "1"" of type '" "pj::OnCallRxOfferParam *""'"); 
  }
  arg1 = reinterpret_cast< pj::OnCallRxOfferParam * >(argp1);
  result = (pjsip_status_code) ((arg1)->statusCode);
  resultobj = SWIG_From_int(static_cast< int >(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_OnCallRxOfferParam_opt_set(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::OnCallRxOfferParam *arg1 = (pj::OnCallRxOfferParam *) 0 ;
  pj::CallSetting *arg2 = (pj::CallSetting *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  void *argp2 = 0 ;
  int res2 = 0 ;
  PyObject *swig_obj[2] ;
  
  if (!SWIG_Python_UnpackTuple(args, "OnCallRxOfferParam_opt_set", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__OnCallRxOfferParam, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "OnCallRxOfferParam_opt_set" "', argument " "1"" of type '" "pj::OnCallRxOfferParam *""'"); 
  }
  arg1 = reinterpret_cast< pj::OnCallRxOfferParam * >(argp1);
  res2 = SWIG_ConvertPtr(swig_obj[1], &argp2,SWIGTYPE_p_pj__CallSetting, 0 |  0 );
  if (!SWIG_IsOK(res2)) {
    SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "OnCallRxOfferParam_opt_set" "', argument " "2"" of type '" "pj::CallSetting *""'"); 
  }
  arg2 = reinterpret_cast< pj::CallSetting * >(argp2);
  if (arg1) (arg1)->opt = *arg2;
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_OnCallRxOfferParam_opt_get(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::OnCallRxOfferParam *arg1 = (pj::OnCallRxOfferParam *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  pj::CallSetting *result = 0 ;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__OnCallRxOfferParam, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "OnCallRxOfferParam_opt_get" "', argument " "1"" of type '" "pj::OnCallRxOfferParam *""'"); 
  }
  arg1 = reinterpret_cast< pj::OnCallRxOfferParam * >(argp1);
  result = (pj::CallSetting *)& ((arg1)->opt);
  resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(result), SWIGTYPE_p_pj__CallSetting, 0 |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_new_OnCallRxOfferParam(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::OnCallRxOfferParam *result = 0 ;
  
  if (!SWIG_Python_UnpackTuple(args, "new_OnCallRxOfferParam", 0, 0, 0)) SWIG_fail;
  result = (pj::OnCallRxOfferParam *)new pj::OnCallRxOfferParam();
  resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(result), SWIGTYPE_p_pj__OnCallRxOfferParam, SWIG_POINTER_NEW |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_delete_OnCallRxOfferParam(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::OnCallRxOfferParam *arg1 = (pj::OnCallRxOfferParam *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__OnCallRxOfferParam, SWIG_POINTER_DISOWN |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "delete_OnCallRxOfferParam" "', argument " "1"" of type '" "pj::OnCallRxOfferParam *""'"); 
  }
  arg1 = reinterpret_cast< pj::OnCallRxOfferParam * >(argp1);
  delete arg1;
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *OnCallRxOfferParam_swigregister(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *obj;
  if (!SWIG_Python_UnpackTuple(args, "swigregister", 1, 1, &obj)) return NULL;
  SWIG_TypeNewClientData(SWIGTYPE_p_pj__OnCallRxOfferParam, SWIG_NewClientData(obj));
  return SWIG_Py_Void();
}

SWIGINTERN PyObject *OnCallRxOfferParam_swiginit(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  return SWIG_Python_InitShadowInstance(args);
}

SWIGINTERN PyObject *_wrap_OnCallRxReinviteParam_offer_set(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::OnCallRxReinviteParam *arg1 = (pj::OnCallRxReinviteParam *) 0 ;
  pj::SdpSession *arg2 = (pj::SdpSession *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  void *argp2 = 0 ;
  int res2 = 0 ;
  PyObject *swig_obj[2] ;
  
  if (!SWIG_Python_UnpackTuple(args, "OnCallRxReinviteParam_offer_set", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__OnCallRxReinviteParam, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "OnCallRxReinviteParam_offer_set" "', argument " "1"" of type '" "pj::OnCallRxReinviteParam *""'"); 
  }
  arg1 = reinterpret_cast< pj::OnCallRxReinviteParam * >(argp1);
  res2 = SWIG_ConvertPtr(swig_obj[1], &argp2,SWIGTYPE_p_pj__SdpSession, 0 |  0 );
  if (!SWIG_IsOK(res2)) {
    SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "OnCallRxReinviteParam_offer_set" "', argument " "2"" of type '" "pj::SdpSession *""'"); 
  }
  arg2 = reinterpret_cast< pj::SdpSession * >(argp2);
  if (arg1) (arg1)->offer = *arg2;
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_OnCallRxReinviteParam_offer_get(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::OnCallRxReinviteParam *arg1 = (pj::OnCallRxReinviteParam *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  pj::SdpSession *result = 0 ;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__OnCallRxReinviteParam, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "OnCallRxReinviteParam_offer_get" "', argument " "1"" of type '" "pj::OnCallRxReinviteParam *""'"); 
  }
  arg1 = reinterpret_cast< pj::OnCallRxReinviteParam * >(argp1);
  result = (pj::SdpSession *)& ((arg1)->offer);
  resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(result), SWIGTYPE_p_pj__SdpSession, 0 |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_OnCallRxReinviteParam_rdata_set(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::OnCallRxReinviteParam *arg1 = (pj::OnCallRxReinviteParam *) 0 ;
  pj::SipRxData *arg2 = (pj::SipRxData *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  void *argp2 = 0 ;
  int res2 = 0 ;
  PyObject *swig_obj[2] ;
  
  if (!SWIG_Python_UnpackTuple(args, "OnCallRxReinviteParam_rdata_set", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__OnCallRxReinviteParam, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "OnCallRxReinviteParam_rdata_set" "', argument " "1"" of type '" "pj::OnCallRxReinviteParam *""'"); 
  }
  arg1 = reinterpret_cast< pj::OnCallRxReinviteParam * >(argp1);
  res2 = SWIG_ConvertPtr(swig_obj[1], &argp2,SWIGTYPE_p_pj__SipRxData, 0 |  0 );
  if (!SWIG_IsOK(res2)) {
    SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "OnCallRxReinviteParam_rdata_set" "', argument " "2"" of type '" "pj::SipRxData *""'"); 
  }
  arg2 = reinterpret_cast< pj::SipRxData * >(argp2);
  if (arg1) (arg1)->rdata = *arg2;
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_OnCallRxReinviteParam_rdata_get(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::OnCallRxReinviteParam *arg1 = (pj::OnCallRxReinviteParam *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  pj::SipRxData *result = 0 ;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__OnCallRxReinviteParam, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "OnCallRxReinviteParam_rdata_get" "', argument " "1"" of type '" "pj::OnCallRxReinviteParam *""'"); 
  }
  arg1 = reinterpret_cast< pj::OnCallRxReinviteParam * >(argp1);
  result = (pj::SipRxData *)& ((arg1)->rdata);
  resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(result), SWIGTYPE_p_pj__SipRxData, 0 |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_OnCallRxReinviteParam_isAsync_set(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::OnCallRxReinviteParam *arg1 = (pj::OnCallRxReinviteParam *) 0 ;
  bool arg2 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  bool val2 ;
  int ecode2 = 0 ;
  PyObject *swig_obj[2] ;
  
  if (!SWIG_Python_UnpackTuple(args, "OnCallRxReinviteParam_isAsync_set", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__OnCallRxReinviteParam, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "OnCallRxReinviteParam_isAsync_set" "', argument " "1"" of type '" "pj::OnCallRxReinviteParam *""'"); 
  }
  arg1 = reinterpret_cast< pj::OnCallRxReinviteParam * >(argp1);
  ecode2 = SWIG_AsVal_bool(swig_obj[1], &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "OnCallRxReinviteParam_isAsync_set" "', argument " "2"" of type '" "bool""'");
  } 
  arg2 = static_cast< bool >(val2);
  if (arg1) (arg1)->isAsync = arg2;
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_OnCallRxReinviteParam_isAsync_get(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::OnCallRxReinviteParam *arg1 = (pj::OnCallRxReinviteParam *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  bool result;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__OnCallRxReinviteParam, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "OnCallRxReinviteParam_isAsync_get" "', argument " "1"" of type '" "pj::OnCallRxReinviteParam *""'"); 
  }
  arg1 = reinterpret_cast< pj::OnCallRxReinviteParam * >(argp1);
  result = (bool) ((arg1)->isAsync);
  resultobj = SWIG_From_bool(static_cast< bool >(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_OnCallRxReinviteParam_statusCode_set(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::OnCallRxReinviteParam *arg1 = (pj::OnCallRxReinviteParam *) 0 ;
  pjsip_status_code arg2 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  int val2 ;
  int ecode2 = 0 ;
  PyObject *swig_obj[2] ;
  
  if (!SWIG_Python_UnpackTuple(args, "OnCallRxReinviteParam_statusCode_set", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__OnCallRxReinviteParam, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "OnCallRxReinviteParam_statusCode_set" "', argument " "1"" of type '" "pj::OnCallRxReinviteParam *""'"); 
  }
  arg1 = reinterpret_cast< pj::OnCallRxReinviteParam * >(argp1);
  ecode2 = SWIG_AsVal_int(swig_obj[1], &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "OnCallRxReinviteParam_statusCode_set" "', argument " "2"" of type '" "pjsip_status_code""'");
  } 
  arg2 = static_cast< pjsip_status_code >(val2);
  if (arg1) (arg1)->statusCode = arg2;
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_OnCallRxReinviteParam_statusCode_get(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::OnCallRxReinviteParam *arg1 = (pj::OnCallRxReinviteParam *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  pjsip_status_code result;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__OnCallRxReinviteParam, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "OnCallRxReinviteParam_statusCode_get" "', argument " "1"" of type '" "pj::OnCallRxReinviteParam *""'"); 
  }
  arg1 = reinterpret_cast< pj::OnCallRxReinviteParam * >(argp1);
  result = (pjsip_status_code) ((arg1)->statusCode);
  resultobj = SWIG_From_int(static_cast< int >(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_OnCallRxReinviteParam_opt_set(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::OnCallRxReinviteParam *arg1 = (pj::OnCallRxReinviteParam *) 0 ;
  pj::CallSetting *arg2 = (pj::CallSetting *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  void *argp2 = 0 ;
  int res2 = 0 ;
  PyObject *swig_obj[2] ;
  
  if (!SWIG_Python_UnpackTuple(args, "OnCallRxReinviteParam_opt_set", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__OnCallRxReinviteParam, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "OnCallRxReinviteParam_opt_set" "', argument " "1"" of type '" "pj::OnCallRxReinviteParam *""'"); 
  }
  arg1 = reinterpret_cast< pj::OnCallRxReinviteParam * >(argp1);
  res2 = SWIG_ConvertPtr(swig_obj[1], &argp2,SWIGTYPE_p_pj__CallSetting, 0 |  0 );
  if (!SWIG_IsOK(res2)) {
    SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "OnCallRxReinviteParam_opt_set" "', argument " "2"" of type '" "pj::CallSetting *""'"); 
  }
  arg2 = reinterpret_cast< pj::CallSetting * >(argp2);
  if (arg1) (arg1)->opt = *arg2;
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_OnCallRxReinviteParam_opt_get(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::OnCallRxReinviteParam *arg1 = (pj::OnCallRxReinviteParam *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  pj::CallSetting *result = 0 ;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__OnCallRxReinviteParam, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "OnCallRxReinviteParam_opt_get" "', argument " "1"" of type '" "pj::OnCallRxReinviteParam *""'"); 
  }
  arg1 = reinterpret_cast< pj::OnCallRxReinviteParam * >(argp1);
  result = (pj::CallSetting *)& ((arg1)->opt);
  resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(result), SWIGTYPE_p_pj__CallSetting, 0 |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_new_OnCallRxReinviteParam(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::OnCallRxReinviteParam *result = 0 ;
  
  if (!SWIG_Python_UnpackTuple(args, "new_OnCallRxReinviteParam", 0, 0, 0)) SWIG_fail;
  result = (pj::OnCallRxReinviteParam *)new pj::OnCallRxReinviteParam();
  resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(result), SWIGTYPE_p_pj__OnCallRxReinviteParam, SWIG_POINTER_NEW |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_delete_OnCallRxReinviteParam(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::OnCallRxReinviteParam *arg1 = (pj::OnCallRxReinviteParam *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__OnCallRxReinviteParam, SWIG_POINTER_DISOWN |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "delete_OnCallRxReinviteParam" "', argument " "1"" of type '" "pj::OnCallRxReinviteParam *""'"); 
  }
  arg1 = reinterpret_cast< pj::OnCallRxReinviteParam * >(argp1);
  delete arg1;
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *OnCallRxReinviteParam_swigregister(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *obj;
  if (!SWIG_Python_UnpackTuple(args, "swigregister", 1, 1, &obj)) return NULL;
  SWIG_TypeNewClientData(SWIGTYPE_p_pj__OnCallRxReinviteParam, SWIG_NewClientData(obj));
  return SWIG_Py_Void();
}

SWIGINTERN PyObject *OnCallRxReinviteParam_swiginit(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  return SWIG_Python_InitShadowInstance(args);
}

SWIGINTERN PyObject *_wrap_OnCallTxOfferParam_opt_set(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::OnCallTxOfferParam *arg1 = (pj::OnCallTxOfferParam *) 0 ;
  pj::CallSetting *arg2 = (pj::CallSetting *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  void *argp2 = 0 ;
  int res2 = 0 ;
  PyObject *swig_obj[2] ;
  
  if (!SWIG_Python_UnpackTuple(args, "OnCallTxOfferParam_opt_set", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__OnCallTxOfferParam, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "OnCallTxOfferParam_opt_set" "', argument " "1"" of type '" "pj::OnCallTxOfferParam *""'"); 
  }
  arg1 = reinterpret_cast< pj::OnCallTxOfferParam * >(argp1);
  res2 = SWIG_ConvertPtr(swig_obj[1], &argp2,SWIGTYPE_p_pj__CallSetting, 0 |  0 );
  if (!SWIG_IsOK(res2)) {
    SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "OnCallTxOfferParam_opt_set" "', argument " "2"" of type '" "pj::CallSetting *""'"); 
  }
  arg2 = reinterpret_cast< pj::CallSetting * >(argp2);
  if (arg1) (arg1)->opt = *arg2;
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_OnCallTxOfferParam_opt_get(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::OnCallTxOfferParam *arg1 = (pj::OnCallTxOfferParam *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  pj::CallSetting *result = 0 ;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__OnCallTxOfferParam, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "OnCallTxOfferParam_opt_get" "', argument " "1"" of type '" "pj::OnCallTxOfferParam *""'"); 
  }
  arg1 = reinterpret_cast< pj::OnCallTxOfferParam * >(argp1);
  result = (pj::CallSetting *)& ((arg1)->opt);
  resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(result), SWIGTYPE_p_pj__CallSetting, 0 |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_new_OnCallTxOfferParam(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::OnCallTxOfferParam *result = 0 ;
  
  if (!SWIG_Python_UnpackTuple(args, "new_OnCallTxOfferParam", 0, 0, 0)) SWIG_fail;
  result = (pj::OnCallTxOfferParam *)new pj::OnCallTxOfferParam();
  resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(result), SWIGTYPE_p_pj__OnCallTxOfferParam, SWIG_POINTER_NEW |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_delete_OnCallTxOfferParam(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::OnCallTxOfferParam *arg1 = (pj::OnCallTxOfferParam *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__OnCallTxOfferParam, SWIG_POINTER_DISOWN |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "delete_OnCallTxOfferParam" "', argument " "1"" of type '" "pj::OnCallTxOfferParam *""'"); 
  }
  arg1 = reinterpret_cast< pj::OnCallTxOfferParam * >(argp1);
  delete arg1;
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *OnCallTxOfferParam_swigregister(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *obj;
  if (!SWIG_Python_UnpackTuple(args, "swigregister", 1, 1, &obj)) return NULL;
  SWIG_TypeNewClientData(SWIGTYPE_p_pj__OnCallTxOfferParam, SWIG_NewClientData(obj));
  return SWIG_Py_Void();
}

SWIGINTERN PyObject *OnCallTxOfferParam_swiginit(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  return SWIG_Python_InitShadowInstance(args);
}

SWIGINTERN PyObject *_wrap_OnCallRedirectedParam_targetUri_set(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::OnCallRedirectedParam *arg1 = (pj::OnCallRedirectedParam *) 0 ;
  pj::string *arg2 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  int res2 = SWIG_OLDOBJ ;
  PyObject *swig_obj[2] ;
  
  if (!SWIG_Python_UnpackTuple(args, "OnCallRedirectedParam_targetUri_set", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__OnCallRedirectedParam, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "OnCallRedirectedParam_targetUri_set" "', argument " "1"" of type '" "pj::OnCallRedirectedParam *""'"); 
  }
  arg1 = reinterpret_cast< pj::OnCallRedirectedParam * >(argp1);
  {
    std::string *ptr = (std::string *)0;
    res2 = SWIG_AsPtr_std_string(swig_obj[1], &ptr);
    if (!SWIG_IsOK(res2)) {
      SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "OnCallRedirectedParam_targetUri_set" "', argument " "2"" of type '" "pj::string const &""'"); 
    }
    if (!ptr) {
      SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "OnCallRedirectedParam_targetUri_set" "', argument " "2"" of type '" "pj::string const &""'"); 
    }
    arg2 = ptr;
  }
  if (arg1) (arg1)->targetUri = *arg2;
  resultobj = SWIG_Py_Void();
  if (SWIG_IsNewObj(res2)) delete arg2;
  return resultobj;
fail:
  if (SWIG_IsNewObj(res2)) delete arg2;
  return NULL;
}


SWIGINTERN PyObject *_wrap_OnCallRedirectedParam_targetUri_get(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::OnCallRedirectedParam *arg1 = (pj::OnCallRedirectedParam *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  pj::string *result = 0 ;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__OnCallRedirectedParam, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "OnCallRedirectedParam_targetUri_get" "', argument " "1"" of type '" "pj::OnCallRedirectedParam *""'"); 
  }
  arg1 = reinterpret_cast< pj::OnCallRedirectedParam * >(argp1);
  result = (pj::string *) & ((arg1)->targetUri);
  resultobj = SWIG_From_std_string(static_cast< std::string >(*result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_OnCallRedirectedParam_e_set(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::OnCallRedirectedParam *arg1 = (pj::OnCallRedirectedParam *) 0 ;
  pj::SipEvent *arg2 = (pj::SipEvent *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  void *argp2 = 0 ;
  int res2 = 0 ;
  PyObject *swig_obj[2] ;
  
  if (!SWIG_Python_UnpackTuple(args, "OnCallRedirectedParam_e_set", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__OnCallRedirectedParam, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "OnCallRedirectedParam_e_set" "', argument " "1"" of type '" "pj::OnCallRedirectedParam *""'"); 
  }
  arg1 = reinterpret_cast< pj::OnCallRedirectedParam * >(argp1);
  res2 = SWIG_ConvertPtr(swig_obj[1], &argp2,SWIGTYPE_p_pj__SipEvent, 0 |  0 );
  if (!SWIG_IsOK(res2)) {
    SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "OnCallRedirectedParam_e_set" "', argument " "2"" of type '" "pj::SipEvent *""'"); 
  }
  arg2 = reinterpret_cast< pj::SipEvent * >(argp2);
  if (arg1) (arg1)->e = *arg2;
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_OnCallRedirectedParam_e_get(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::OnCallRedirectedParam *arg1 = (pj::OnCallRedirectedParam *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  pj::SipEvent *result = 0 ;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__OnCallRedirectedParam, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "OnCallRedirectedParam_e_get" "', argument " "1"" of type '" "pj::OnCallRedirectedParam *""'"); 
  }
  arg1 = reinterpret_cast< pj::OnCallRedirectedParam * >(argp1);
  result = (pj::SipEvent *)& ((arg1)->e);
  resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(result), SWIGTYPE_p_pj__SipEvent, 0 |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_new_OnCallRedirectedParam(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::OnCallRedirectedParam *result = 0 ;
  
  if (!SWIG_Python_UnpackTuple(args, "new_OnCallRedirectedParam", 0, 0, 0)) SWIG_fail;
  result = (pj::OnCallRedirectedParam *)new pj::OnCallRedirectedParam();
  resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(result), SWIGTYPE_p_pj__OnCallRedirectedParam, SWIG_POINTER_NEW |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_delete_OnCallRedirectedParam(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::OnCallRedirectedParam *arg1 = (pj::OnCallRedirectedParam *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__OnCallRedirectedParam, SWIG_POINTER_DISOWN |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "delete_OnCallRedirectedParam" "', argument " "1"" of type '" "pj::OnCallRedirectedParam *""'"); 
  }
  arg1 = reinterpret_cast< pj::OnCallRedirectedParam * >(argp1);
  delete arg1;
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *OnCallRedirectedParam_swigregister(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *obj;
  if (!SWIG_Python_UnpackTuple(args, "swigregister", 1, 1, &obj)) return NULL;
  SWIG_TypeNewClientData(SWIGTYPE_p_pj__OnCallRedirectedParam, SWIG_NewClientData(obj));
  return SWIG_Py_Void();
}

SWIGINTERN PyObject *OnCallRedirectedParam_swiginit(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  return SWIG_Python_InitShadowInstance(args);
}

SWIGINTERN PyObject *_wrap_OnCallMediaEventParam_medIdx_set(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::OnCallMediaEventParam *arg1 = (pj::OnCallMediaEventParam *) 0 ;
  unsigned int arg2 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  unsigned int val2 ;
  int ecode2 = 0 ;
  PyObject *swig_obj[2] ;
  
  if (!SWIG_Python_UnpackTuple(args, "OnCallMediaEventParam_medIdx_set", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__OnCallMediaEventParam, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "OnCallMediaEventParam_medIdx_set" "', argument " "1"" of type '" "pj::OnCallMediaEventParam *""'"); 
  }
  arg1 = reinterpret_cast< pj::OnCallMediaEventParam * >(argp1);
  ecode2 = SWIG_AsVal_unsigned_SS_int(swig_obj[1], &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "OnCallMediaEventParam_medIdx_set" "', argument " "2"" of type '" "unsigned int""'");
  } 
  arg2 = static_cast< unsigned int >(val2);
  if (arg1) (arg1)->medIdx = arg2;
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_OnCallMediaEventParam_medIdx_get(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::OnCallMediaEventParam *arg1 = (pj::OnCallMediaEventParam *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  unsigned int result;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__OnCallMediaEventParam, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "OnCallMediaEventParam_medIdx_get" "', argument " "1"" of type '" "pj::OnCallMediaEventParam *""'"); 
  }
  arg1 = reinterpret_cast< pj::OnCallMediaEventParam * >(argp1);
  result = (unsigned int) ((arg1)->medIdx);
  resultobj = SWIG_From_unsigned_SS_int(static_cast< unsigned int >(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_OnCallMediaEventParam_ev_set(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::OnCallMediaEventParam *arg1 = (pj::OnCallMediaEventParam *) 0 ;
  pj::MediaEvent *arg2 = (pj::MediaEvent *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  void *argp2 = 0 ;
  int res2 = 0 ;
  PyObject *swig_obj[2] ;
  
  if (!SWIG_Python_UnpackTuple(args, "OnCallMediaEventParam_ev_set", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__OnCallMediaEventParam, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "OnCallMediaEventParam_ev_set" "', argument " "1"" of type '" "pj::OnCallMediaEventParam *""'"); 
  }
  arg1 = reinterpret_cast< pj::OnCallMediaEventParam * >(argp1);
  res2 = SWIG_ConvertPtr(swig_obj[1], &argp2,SWIGTYPE_p_pj__MediaEvent, 0 |  0 );
  if (!SWIG_IsOK(res2)) {
    SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "OnCallMediaEventParam_ev_set" "', argument " "2"" of type '" "pj::MediaEvent *""'"); 
  }
  arg2 = reinterpret_cast< pj::MediaEvent * >(argp2);
  if (arg1) (arg1)->ev = *arg2;
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_OnCallMediaEventParam_ev_get(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::OnCallMediaEventParam *arg1 = (pj::OnCallMediaEventParam *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  pj::MediaEvent *result = 0 ;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__OnCallMediaEventParam, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "OnCallMediaEventParam_ev_get" "', argument " "1"" of type '" "pj::OnCallMediaEventParam *""'"); 
  }
  arg1 = reinterpret_cast< pj::OnCallMediaEventParam * >(argp1);
  result = (pj::MediaEvent *)& ((arg1)->ev);
  resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(result), SWIGTYPE_p_pj__MediaEvent, 0 |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_new_OnCallMediaEventParam(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::OnCallMediaEventParam *result = 0 ;
  
  if (!SWIG_Python_UnpackTuple(args, "new_OnCallMediaEventParam", 0, 0, 0)) SWIG_fail;
  result = (pj::OnCallMediaEventParam *)new pj::OnCallMediaEventParam();
  resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(result), SWIGTYPE_p_pj__OnCallMediaEventParam, SWIG_POINTER_NEW |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_delete_OnCallMediaEventParam(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::OnCallMediaEventParam *arg1 = (pj::OnCallMediaEventParam *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__OnCallMediaEventParam, SWIG_POINTER_DISOWN |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "delete_OnCallMediaEventParam" "', argument " "1"" of type '" "pj::OnCallMediaEventParam *""'"); 
  }
  arg1 = reinterpret_cast< pj::OnCallMediaEventParam * >(argp1);
  delete arg1;
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *OnCallMediaEventParam_swigregister(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *obj;
  if (!SWIG_Python_UnpackTuple(args, "swigregister", 1, 1, &obj)) return NULL;
  SWIG_TypeNewClientData(SWIGTYPE_p_pj__OnCallMediaEventParam, SWIG_NewClientData(obj));
  return SWIG_Py_Void();
}

SWIGINTERN PyObject *OnCallMediaEventParam_swiginit(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  return SWIG_Python_InitShadowInstance(args);
}

SWIGINTERN PyObject *_wrap_OnCallMediaTransportStateParam_medIdx_set(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::OnCallMediaTransportStateParam *arg1 = (pj::OnCallMediaTransportStateParam *) 0 ;
  unsigned int arg2 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  unsigned int val2 ;
  int ecode2 = 0 ;
  PyObject *swig_obj[2] ;
  
  if (!SWIG_Python_UnpackTuple(args, "OnCallMediaTransportStateParam_medIdx_set", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__OnCallMediaTransportStateParam, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "OnCallMediaTransportStateParam_medIdx_set" "', argument " "1"" of type '" "pj::OnCallMediaTransportStateParam *""'"); 
  }
  arg1 = reinterpret_cast< pj::OnCallMediaTransportStateParam * >(argp1);
  ecode2 = SWIG_AsVal_unsigned_SS_int(swig_obj[1], &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "OnCallMediaTransportStateParam_medIdx_set" "', argument " "2"" of type '" "unsigned int""'");
  } 
  arg2 = static_cast< unsigned int >(val2);
  if (arg1) (arg1)->medIdx = arg2;
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_OnCallMediaTransportStateParam_medIdx_get(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::OnCallMediaTransportStateParam *arg1 = (pj::OnCallMediaTransportStateParam *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  unsigned int result;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__OnCallMediaTransportStateParam, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "OnCallMediaTransportStateParam_medIdx_get" "', argument " "1"" of type '" "pj::OnCallMediaTransportStateParam *""'"); 
  }
  arg1 = reinterpret_cast< pj::OnCallMediaTransportStateParam * >(argp1);
  result = (unsigned int) ((arg1)->medIdx);
  resultobj = SWIG_From_unsigned_SS_int(static_cast< unsigned int >(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_OnCallMediaTransportStateParam_state_set(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::OnCallMediaTransportStateParam *arg1 = (pj::OnCallMediaTransportStateParam *) 0 ;
  pjsua_med_tp_st arg2 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  int val2 ;
  int ecode2 = 0 ;
  PyObject *swig_obj[2] ;
  
  if (!SWIG_Python_UnpackTuple(args, "OnCallMediaTransportStateParam_state_set", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__OnCallMediaTransportStateParam, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "OnCallMediaTransportStateParam_state_set" "', argument " "1"" of type '" "pj::OnCallMediaTransportStateParam *""'"); 
  }
  arg1 = reinterpret_cast< pj::OnCallMediaTransportStateParam * >(argp1);
  ecode2 = SWIG_AsVal_int(swig_obj[1], &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "OnCallMediaTransportStateParam_state_set" "', argument " "2"" of type '" "pjsua_med_tp_st""'");
  } 
  arg2 = static_cast< pjsua_med_tp_st >(val2);
  if (arg1) (arg1)->state = arg2;
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_OnCallMediaTransportStateParam_state_get(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::OnCallMediaTransportStateParam *arg1 = (pj::OnCallMediaTransportStateParam *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  pjsua_med_tp_st result;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__OnCallMediaTransportStateParam, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "OnCallMediaTransportStateParam_state_get" "', argument " "1"" of type '" "pj::OnCallMediaTransportStateParam *""'"); 
  }
  arg1 = reinterpret_cast< pj::OnCallMediaTransportStateParam * >(argp1);
  result = (pjsua_med_tp_st) ((arg1)->state);
  resultobj = SWIG_From_int(static_cast< int >(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_OnCallMediaTransportStateParam_status_set(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::OnCallMediaTransportStateParam *arg1 = (pj::OnCallMediaTransportStateParam *) 0 ;
  pj_status_t arg2 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  int val2 ;
  int ecode2 = 0 ;
  PyObject *swig_obj[2] ;
  
  if (!SWIG_Python_UnpackTuple(args, "OnCallMediaTransportStateParam_status_set", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__OnCallMediaTransportStateParam, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "OnCallMediaTransportStateParam_status_set" "', argument " "1"" of type '" "pj::OnCallMediaTransportStateParam *""'"); 
  }
  arg1 = reinterpret_cast< pj::OnCallMediaTransportStateParam * >(argp1);
  ecode2 = SWIG_AsVal_int(swig_obj[1], &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "OnCallMediaTransportStateParam_status_set" "', argument " "2"" of type '" "pj_status_t""'");
  } 
  arg2 = static_cast< pj_status_t >(val2);
  if (arg1) (arg1)->status = arg2;
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_OnCallMediaTransportStateParam_status_get(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::OnCallMediaTransportStateParam *arg1 = (pj::OnCallMediaTransportStateParam *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  pj_status_t result;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__OnCallMediaTransportStateParam, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "OnCallMediaTransportStateParam_status_get" "', argument " "1"" of type '" "pj::OnCallMediaTransportStateParam *""'"); 
  }
  arg1 = reinterpret_cast< pj::OnCallMediaTransportStateParam * >(argp1);
  result = (pj_status_t) ((arg1)->status);
  resultobj = SWIG_From_int(static_cast< int >(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_OnCallMediaTransportStateParam_sipErrorCode_set(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::OnCallMediaTransportStateParam *arg1 = (pj::OnCallMediaTransportStateParam *) 0 ;
  int arg2 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  int val2 ;
  int ecode2 = 0 ;
  PyObject *swig_obj[2] ;
  
  if (!SWIG_Python_UnpackTuple(args, "OnCallMediaTransportStateParam_sipErrorCode_set", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__OnCallMediaTransportStateParam, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "OnCallMediaTransportStateParam_sipErrorCode_set" "', argument " "1"" of type '" "pj::OnCallMediaTransportStateParam *""'"); 
  }
  arg1 = reinterpret_cast< pj::OnCallMediaTransportStateParam * >(argp1);
  ecode2 = SWIG_AsVal_int(swig_obj[1], &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "OnCallMediaTransportStateParam_sipErrorCode_set" "', argument " "2"" of type '" "int""'");
  } 
  arg2 = static_cast< int >(val2);
  if (arg1) (arg1)->sipErrorCode = arg2;
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_OnCallMediaTransportStateParam_sipErrorCode_get(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::OnCallMediaTransportStateParam *arg1 = (pj::OnCallMediaTransportStateParam *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  int result;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__OnCallMediaTransportStateParam, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "OnCallMediaTransportStateParam_sipErrorCode_get" "', argument " "1"" of type '" "pj::OnCallMediaTransportStateParam *""'"); 
  }
  arg1 = reinterpret_cast< pj::OnCallMediaTransportStateParam * >(argp1);
  result = (int) ((arg1)->sipErrorCode);
  resultobj = SWIG_From_int(static_cast< int >(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_new_OnCallMediaTransportStateParam(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::OnCallMediaTransportStateParam *result = 0 ;
  
  if (!SWIG_Python_UnpackTuple(args, "new_OnCallMediaTransportStateParam", 0, 0, 0)) SWIG_fail;
  result = (pj::OnCallMediaTransportStateParam *)new pj::OnCallMediaTransportStateParam();
  resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(result), SWIGTYPE_p_pj__OnCallMediaTransportStateParam, SWIG_POINTER_NEW |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_delete_OnCallMediaTransportStateParam(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::OnCallMediaTransportStateParam *arg1 = (pj::OnCallMediaTransportStateParam *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__OnCallMediaTransportStateParam, SWIG_POINTER_DISOWN |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "delete_OnCallMediaTransportStateParam" "', argument " "1"" of type '" "pj::OnCallMediaTransportStateParam *""'"); 
  }
  arg1 = reinterpret_cast< pj::OnCallMediaTransportStateParam * >(argp1);
  delete arg1;
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *OnCallMediaTransportStateParam_swigregister(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *obj;
  if (!SWIG_Python_UnpackTuple(args, "swigregister", 1, 1, &obj)) return NULL;
  SWIG_TypeNewClientData(SWIGTYPE_p_pj__OnCallMediaTransportStateParam, SWIG_NewClientData(obj));
  return SWIG_Py_Void();
}

SWIGINTERN PyObject *OnCallMediaTransportStateParam_swiginit(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  return SWIG_Python_InitShadowInstance(args);
}

SWIGINTERN PyObject *_wrap_OnCreateMediaTransportParam_mediaIdx_set(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::OnCreateMediaTransportParam *arg1 = (pj::OnCreateMediaTransportParam *) 0 ;
  unsigned int arg2 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  unsigned int val2 ;
  int ecode2 = 0 ;
  PyObject *swig_obj[2] ;
  
  if (!SWIG_Python_UnpackTuple(args, "OnCreateMediaTransportParam_mediaIdx_set", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__OnCreateMediaTransportParam, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "OnCreateMediaTransportParam_mediaIdx_set" "', argument " "1"" of type '" "pj::OnCreateMediaTransportParam *""'"); 
  }
  arg1 = reinterpret_cast< pj::OnCreateMediaTransportParam * >(argp1);
  ecode2 = SWIG_AsVal_unsigned_SS_int(swig_obj[1], &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "OnCreateMediaTransportParam_mediaIdx_set" "', argument " "2"" of type '" "unsigned int""'");
  } 
  arg2 = static_cast< unsigned int >(val2);
  if (arg1) (arg1)->mediaIdx = arg2;
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_OnCreateMediaTransportParam_mediaIdx_get(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::OnCreateMediaTransportParam *arg1 = (pj::OnCreateMediaTransportParam *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  unsigned int result;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__OnCreateMediaTransportParam, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "OnCreateMediaTransportParam_mediaIdx_get" "', argument " "1"" of type '" "pj::OnCreateMediaTransportParam *""'"); 
  }
  arg1 = reinterpret_cast< pj::OnCreateMediaTransportParam * >(argp1);
  result = (unsigned int) ((arg1)->mediaIdx);
  resultobj = SWIG_From_unsigned_SS_int(static_cast< unsigned int >(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_OnCreateMediaTransportParam_mediaTp_set(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::OnCreateMediaTransportParam *arg1 = (pj::OnCreateMediaTransportParam *) 0 ;
  pj::MediaTransport arg2 = (pj::MediaTransport) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  int res2 ;
  PyObject *swig_obj[2] ;
  
  if (!SWIG_Python_UnpackTuple(args, "OnCreateMediaTransportParam_mediaTp_set", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__OnCreateMediaTransportParam, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "OnCreateMediaTransportParam_mediaTp_set" "', argument " "1"" of type '" "pj::OnCreateMediaTransportParam *""'"); 
  }
  arg1 = reinterpret_cast< pj::OnCreateMediaTransportParam * >(argp1);
  res2 = SWIG_ConvertPtr(swig_obj[1],SWIG_as_voidptrptr(&arg2), 0, SWIG_POINTER_DISOWN);
  if (!SWIG_IsOK(res2)) {
    SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "OnCreateMediaTransportParam_mediaTp_set" "', argument " "2"" of type '" "pj::MediaTransport""'"); 
  }
  if (arg1) (arg1)->mediaTp = arg2;
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_OnCreateMediaTransportParam_mediaTp_get(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::OnCreateMediaTransportParam *arg1 = (pj::OnCreateMediaTransportParam *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  pj::MediaTransport result;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__OnCreateMediaTransportParam, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "OnCreateMediaTransportParam_mediaTp_get" "', argument " "1"" of type '" "pj::OnCreateMediaTransportParam *""'"); 
  }
  arg1 = reinterpret_cast< pj::OnCreateMediaTransportParam * >(argp1);
  result = (pj::MediaTransport) ((arg1)->mediaTp);
  resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(result), SWIGTYPE_p_void, 0 |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_OnCreateMediaTransportParam_flags_set(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::OnCreateMediaTransportParam *arg1 = (pj::OnCreateMediaTransportParam *) 0 ;
  unsigned int arg2 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  unsigned int val2 ;
  int ecode2 = 0 ;
  PyObject *swig_obj[2] ;
  
  if (!SWIG_Python_UnpackTuple(args, "OnCreateMediaTransportParam_flags_set", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__OnCreateMediaTransportParam, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "OnCreateMediaTransportParam_flags_set" "', argument " "1"" of type '" "pj::OnCreateMediaTransportParam *""'"); 
  }
  arg1 = reinterpret_cast< pj::OnCreateMediaTransportParam * >(argp1);
  ecode2 = SWIG_AsVal_unsigned_SS_int(swig_obj[1], &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "OnCreateMediaTransportParam_flags_set" "', argument " "2"" of type '" "unsigned int""'");
  } 
  arg2 = static_cast< unsigned int >(val2);
  if (arg1) (arg1)->flags = arg2;
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_OnCreateMediaTransportParam_flags_get(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::OnCreateMediaTransportParam *arg1 = (pj::OnCreateMediaTransportParam *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  unsigned int result;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__OnCreateMediaTransportParam, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "OnCreateMediaTransportParam_flags_get" "', argument " "1"" of type '" "pj::OnCreateMediaTransportParam *""'"); 
  }
  arg1 = reinterpret_cast< pj::OnCreateMediaTransportParam * >(argp1);
  result = (unsigned int) ((arg1)->flags);
  resultobj = SWIG_From_unsigned_SS_int(static_cast< unsigned int >(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_new_OnCreateMediaTransportParam(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::OnCreateMediaTransportParam *result = 0 ;
  
  if (!SWIG_Python_UnpackTuple(args, "new_OnCreateMediaTransportParam", 0, 0, 0)) SWIG_fail;
  result = (pj::OnCreateMediaTransportParam *)new pj::OnCreateMediaTransportParam();
  resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(result), SWIGTYPE_p_pj__OnCreateMediaTransportParam, SWIG_POINTER_NEW |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_delete_OnCreateMediaTransportParam(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::OnCreateMediaTransportParam *arg1 = (pj::OnCreateMediaTransportParam *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__OnCreateMediaTransportParam, SWIG_POINTER_DISOWN |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "delete_OnCreateMediaTransportParam" "', argument " "1"" of type '" "pj::OnCreateMediaTransportParam *""'"); 
  }
  arg1 = reinterpret_cast< pj::OnCreateMediaTransportParam * >(argp1);
  delete arg1;
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *OnCreateMediaTransportParam_swigregister(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *obj;
  if (!SWIG_Python_UnpackTuple(args, "swigregister", 1, 1, &obj)) return NULL;
  SWIG_TypeNewClientData(SWIGTYPE_p_pj__OnCreateMediaTransportParam, SWIG_NewClientData(obj));
  return SWIG_Py_Void();
}

SWIGINTERN PyObject *OnCreateMediaTransportParam_swiginit(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  return SWIG_Python_InitShadowInstance(args);
}

SWIGINTERN PyObject *_wrap_OnCreateMediaTransportSrtpParam_mediaIdx_set(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::OnCreateMediaTransportSrtpParam *arg1 = (pj::OnCreateMediaTransportSrtpParam *) 0 ;
  unsigned int arg2 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  unsigned int val2 ;
  int ecode2 = 0 ;
  PyObject *swig_obj[2] ;
  
  if (!SWIG_Python_UnpackTuple(args, "OnCreateMediaTransportSrtpParam_mediaIdx_set", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__OnCreateMediaTransportSrtpParam, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "OnCreateMediaTransportSrtpParam_mediaIdx_set" "', argument " "1"" of type '" "pj::OnCreateMediaTransportSrtpParam *""'"); 
  }
  arg1 = reinterpret_cast< pj::OnCreateMediaTransportSrtpParam * >(argp1);
  ecode2 = SWIG_AsVal_unsigned_SS_int(swig_obj[1], &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "OnCreateMediaTransportSrtpParam_mediaIdx_set" "', argument " "2"" of type '" "unsigned int""'");
  } 
  arg2 = static_cast< unsigned int >(val2);
  if (arg1) (arg1)->mediaIdx = arg2;
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_OnCreateMediaTransportSrtpParam_mediaIdx_get(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::OnCreateMediaTransportSrtpParam *arg1 = (pj::OnCreateMediaTransportSrtpParam *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  unsigned int result;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__OnCreateMediaTransportSrtpParam, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "OnCreateMediaTransportSrtpParam_mediaIdx_get" "', argument " "1"" of type '" "pj::OnCreateMediaTransportSrtpParam *""'"); 
  }
  arg1 = reinterpret_cast< pj::OnCreateMediaTransportSrtpParam * >(argp1);
  result = (unsigned int) ((arg1)->mediaIdx);
  resultobj = SWIG_From_unsigned_SS_int(static_cast< unsigned int >(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_OnCreateMediaTransportSrtpParam_srtpUse_set(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::OnCreateMediaTransportSrtpParam *arg1 = (pj::OnCreateMediaTransportSrtpParam *) 0 ;
  pjmedia_srtp_use arg2 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  int val2 ;
  int ecode2 = 0 ;
  PyObject *swig_obj[2] ;
  
  if (!SWIG_Python_UnpackTuple(args, "OnCreateMediaTransportSrtpParam_srtpUse_set", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__OnCreateMediaTransportSrtpParam, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "OnCreateMediaTransportSrtpParam_srtpUse_set" "', argument " "1"" of type '" "pj::OnCreateMediaTransportSrtpParam *""'"); 
  }
  arg1 = reinterpret_cast< pj::OnCreateMediaTransportSrtpParam * >(argp1);
  ecode2 = SWIG_AsVal_int(swig_obj[1], &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "OnCreateMediaTransportSrtpParam_srtpUse_set" "', argument " "2"" of type '" "pjmedia_srtp_use""'");
  } 
  arg2 = static_cast< pjmedia_srtp_use >(val2);
  if (arg1) (arg1)->srtpUse = arg2;
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_OnCreateMediaTransportSrtpParam_srtpUse_get(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::OnCreateMediaTransportSrtpParam *arg1 = (pj::OnCreateMediaTransportSrtpParam *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  pjmedia_srtp_use result;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__OnCreateMediaTransportSrtpParam, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "OnCreateMediaTransportSrtpParam_srtpUse_get" "', argument " "1"" of type '" "pj::OnCreateMediaTransportSrtpParam *""'"); 
  }
  arg1 = reinterpret_cast< pj::OnCreateMediaTransportSrtpParam * >(argp1);
  result = (pjmedia_srtp_use) ((arg1)->srtpUse);
  resultobj = SWIG_From_int(static_cast< int >(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_OnCreateMediaTransportSrtpParam_cryptos_set(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::OnCreateMediaTransportSrtpParam *arg1 = (pj::OnCreateMediaTransportSrtpParam *) 0 ;
  pj::SrtpCryptoVector *arg2 = (pj::SrtpCryptoVector *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  void *argp2 = 0 ;
  int res2 = 0 ;
  PyObject *swig_obj[2] ;
  
  if (!SWIG_Python_UnpackTuple(args, "OnCreateMediaTransportSrtpParam_cryptos_set", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__OnCreateMediaTransportSrtpParam, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "OnCreateMediaTransportSrtpParam_cryptos_set" "', argument " "1"" of type '" "pj::OnCreateMediaTransportSrtpParam *""'"); 
  }
  arg1 = reinterpret_cast< pj::OnCreateMediaTransportSrtpParam * >(argp1);
  res2 = SWIG_ConvertPtr(swig_obj[1], &argp2,SWIGTYPE_p_std__vectorT_pj__SrtpCrypto_std__allocatorT_pj__SrtpCrypto_t_t, 0 |  0 );
  if (!SWIG_IsOK(res2)) {
    SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "OnCreateMediaTransportSrtpParam_cryptos_set" "', argument " "2"" of type '" "pj::SrtpCryptoVector *""'"); 
  }
  arg2 = reinterpret_cast< pj::SrtpCryptoVector * >(argp2);
  if (arg1) (arg1)->cryptos = *arg2;
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_OnCreateMediaTransportSrtpParam_cryptos_get(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::OnCreateMediaTransportSrtpParam *arg1 = (pj::OnCreateMediaTransportSrtpParam *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  pj::SrtpCryptoVector *result = 0 ;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__OnCreateMediaTransportSrtpParam, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "OnCreateMediaTransportSrtpParam_cryptos_get" "', argument " "1"" of type '" "pj::OnCreateMediaTransportSrtpParam *""'"); 
  }
  arg1 = reinterpret_cast< pj::OnCreateMediaTransportSrtpParam * >(argp1);
  result = (pj::SrtpCryptoVector *)& ((arg1)->cryptos);
  resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(result), SWIGTYPE_p_std__vectorT_pj__SrtpCrypto_std__allocatorT_pj__SrtpCrypto_t_t, 0 |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_new_OnCreateMediaTransportSrtpParam(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::OnCreateMediaTransportSrtpParam *result = 0 ;
  
  if (!SWIG_Python_UnpackTuple(args, "new_OnCreateMediaTransportSrtpParam", 0, 0, 0)) SWIG_fail;
  result = (pj::OnCreateMediaTransportSrtpParam *)new pj::OnCreateMediaTransportSrtpParam();
  resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(result), SWIGTYPE_p_pj__OnCreateMediaTransportSrtpParam, SWIG_POINTER_NEW |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_delete_OnCreateMediaTransportSrtpParam(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::OnCreateMediaTransportSrtpParam *arg1 = (pj::OnCreateMediaTransportSrtpParam *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__OnCreateMediaTransportSrtpParam, SWIG_POINTER_DISOWN |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "delete_OnCreateMediaTransportSrtpParam" "', argument " "1"" of type '" "pj::OnCreateMediaTransportSrtpParam *""'"); 
  }
  arg1 = reinterpret_cast< pj::OnCreateMediaTransportSrtpParam * >(argp1);
  delete arg1;
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *OnCreateMediaTransportSrtpParam_swigregister(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *obj;
  if (!SWIG_Python_UnpackTuple(args, "swigregister", 1, 1, &obj)) return NULL;
  SWIG_TypeNewClientData(SWIGTYPE_p_pj__OnCreateMediaTransportSrtpParam, SWIG_NewClientData(obj));
  return SWIG_Py_Void();
}

SWIGINTERN PyObject *OnCreateMediaTransportSrtpParam_swiginit(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  return SWIG_Python_InitShadowInstance(args);
}

SWIGINTERN PyObject *_wrap_CallOpParam_opt_set(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::CallOpParam *arg1 = (pj::CallOpParam *) 0 ;
  pj::CallSetting *arg2 = (pj::CallSetting *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  void *argp2 = 0 ;
  int res2 = 0 ;
  PyObject *swig_obj[2] ;
  
  if (!SWIG_Python_UnpackTuple(args, "CallOpParam_opt_set", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__CallOpParam, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "CallOpParam_opt_set" "', argument " "1"" of type '" "pj::CallOpParam *""'"); 
  }
  arg1 = reinterpret_cast< pj::CallOpParam * >(argp1);
  res2 = SWIG_ConvertPtr(swig_obj[1], &argp2,SWIGTYPE_p_pj__CallSetting, 0 |  0 );
  if (!SWIG_IsOK(res2)) {
    SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "CallOpParam_opt_set" "', argument " "2"" of type '" "pj::CallSetting *""'"); 
  }
  arg2 = reinterpret_cast< pj::CallSetting * >(argp2);
  if (arg1) (arg1)->opt = *arg2;
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_CallOpParam_opt_get(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::CallOpParam *arg1 = (pj::CallOpParam *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  pj::CallSetting *result = 0 ;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__CallOpParam, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "CallOpParam_opt_get" "', argument " "1"" of type '" "pj::CallOpParam *""'"); 
  }
  arg1 = reinterpret_cast< pj::CallOpParam * >(argp1);
  result = (pj::CallSetting *)& ((arg1)->opt);
  resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(result), SWIGTYPE_p_pj__CallSetting, 0 |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_CallOpParam_statusCode_set(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::CallOpParam *arg1 = (pj::CallOpParam *) 0 ;
  pjsip_status_code arg2 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  int val2 ;
  int ecode2 = 0 ;
  PyObject *swig_obj[2] ;
  
  if (!SWIG_Python_UnpackTuple(args, "CallOpParam_statusCode_set", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__CallOpParam, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "CallOpParam_statusCode_set" "', argument " "1"" of type '" "pj::CallOpParam *""'"); 
  }
  arg1 = reinterpret_cast< pj::CallOpParam * >(argp1);
  ecode2 = SWIG_AsVal_int(swig_obj[1], &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "CallOpParam_statusCode_set" "', argument " "2"" of type '" "pjsip_status_code""'");
  } 
  arg2 = static_cast< pjsip_status_code >(val2);
  if (arg1) (arg1)->statusCode = arg2;
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_CallOpParam_statusCode_get(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::CallOpParam *arg1 = (pj::CallOpParam *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  pjsip_status_code result;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__CallOpParam, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "CallOpParam_statusCode_get" "', argument " "1"" of type '" "pj::CallOpParam *""'"); 
  }
  arg1 = reinterpret_cast< pj::CallOpParam * >(argp1);
  result = (pjsip_status_code) ((arg1)->statusCode);
  resultobj = SWIG_From_int(static_cast< int >(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_CallOpParam_reason_set(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::CallOpParam *arg1 = (pj::CallOpParam *) 0 ;
  pj::string *arg2 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  int res2 = SWIG_OLDOBJ ;
  PyObject *swig_obj[2] ;
  
  if (!SWIG_Python_UnpackTuple(args, "CallOpParam_reason_set", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__CallOpParam, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "CallOpParam_reason_set" "', argument " "1"" of type '" "pj::CallOpParam *""'"); 
  }
  arg1 = reinterpret_cast< pj::CallOpParam * >(argp1);
  {
    std::string *ptr = (std::string *)0;
    res2 = SWIG_AsPtr_std_string(swig_obj[1], &ptr);
    if (!SWIG_IsOK(res2)) {
      SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "CallOpParam_reason_set" "', argument " "2"" of type '" "pj::string const &""'"); 
    }
    if (!ptr) {
      SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "CallOpParam_reason_set" "', argument " "2"" of type '" "pj::string const &""'"); 
    }
    arg2 = ptr;
  }
  if (arg1) (arg1)->reason = *arg2;
  resultobj = SWIG_Py_Void();
  if (SWIG_IsNewObj(res2)) delete arg2;
  return resultobj;
fail:
  if (SWIG_IsNewObj(res2)) delete arg2;
  return NULL;
}


SWIGINTERN PyObject *_wrap_CallOpParam_reason_get(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::CallOpParam *arg1 = (pj::CallOpParam *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  pj::string *result = 0 ;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__CallOpParam, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "CallOpParam_reason_get" "', argument " "1"" of type '" "pj::CallOpParam *""'"); 
  }
  arg1 = reinterpret_cast< pj::CallOpParam * >(argp1);
  result = (pj::string *) & ((arg1)->reason);
  resultobj = SWIG_From_std_string(static_cast< std::string >(*result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_CallOpParam_options_set(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::CallOpParam *arg1 = (pj::CallOpParam *) 0 ;
  unsigned int arg2 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  unsigned int val2 ;
  int ecode2 = 0 ;
  PyObject *swig_obj[2] ;
  
  if (!SWIG_Python_UnpackTuple(args, "CallOpParam_options_set", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__CallOpParam, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "CallOpParam_options_set" "', argument " "1"" of type '" "pj::CallOpParam *""'"); 
  }
  arg1 = reinterpret_cast< pj::CallOpParam * >(argp1);
  ecode2 = SWIG_AsVal_unsigned_SS_int(swig_obj[1], &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "CallOpParam_options_set" "', argument " "2"" of type '" "unsigned int""'");
  } 
  arg2 = static_cast< unsigned int >(val2);
  if (arg1) (arg1)->options = arg2;
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_CallOpParam_options_get(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::CallOpParam *arg1 = (pj::CallOpParam *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  unsigned int result;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__CallOpParam, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "CallOpParam_options_get" "', argument " "1"" of type '" "pj::CallOpParam *""'"); 
  }
  arg1 = reinterpret_cast< pj::CallOpParam * >(argp1);
  result = (unsigned int) ((arg1)->options);
  resultobj = SWIG_From_unsigned_SS_int(static_cast< unsigned int >(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_CallOpParam_txOption_set(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::CallOpParam *arg1 = (pj::CallOpParam *) 0 ;
  pj::SipTxOption *arg2 = (pj::SipTxOption *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  void *argp2 = 0 ;
  int res2 = 0 ;
  PyObject *swig_obj[2] ;
  
  if (!SWIG_Python_UnpackTuple(args, "CallOpParam_txOption_set", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__CallOpParam, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "CallOpParam_txOption_set" "', argument " "1"" of type '" "pj::CallOpParam *""'"); 
  }
  arg1 = reinterpret_cast< pj::CallOpParam * >(argp1);
  res2 = SWIG_ConvertPtr(swig_obj[1], &argp2,SWIGTYPE_p_pj__SipTxOption, 0 |  0 );
  if (!SWIG_IsOK(res2)) {
    SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "CallOpParam_txOption_set" "', argument " "2"" of type '" "pj::SipTxOption *""'"); 
  }
  arg2 = reinterpret_cast< pj::SipTxOption * >(argp2);
  if (arg1) (arg1)->txOption = *arg2;
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_CallOpParam_txOption_get(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::CallOpParam *arg1 = (pj::CallOpParam *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  pj::SipTxOption *result = 0 ;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__CallOpParam, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "CallOpParam_txOption_get" "', argument " "1"" of type '" "pj::CallOpParam *""'"); 
  }
  arg1 = reinterpret_cast< pj::CallOpParam * >(argp1);
  result = (pj::SipTxOption *)& ((arg1)->txOption);
  resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(result), SWIGTYPE_p_pj__SipTxOption, 0 |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_CallOpParam_sdp_set(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::CallOpParam *arg1 = (pj::CallOpParam *) 0 ;
  pj::SdpSession *arg2 = (pj::SdpSession *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  void *argp2 = 0 ;
  int res2 = 0 ;
  PyObject *swig_obj[2] ;
  
  if (!SWIG_Python_UnpackTuple(args, "CallOpParam_sdp_set", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__CallOpParam, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "CallOpParam_sdp_set" "', argument " "1"" of type '" "pj::CallOpParam *""'"); 
  }
  arg1 = reinterpret_cast< pj::CallOpParam * >(argp1);
  res2 = SWIG_ConvertPtr(swig_obj[1], &argp2,SWIGTYPE_p_pj__SdpSession, 0 |  0 );
  if (!SWIG_IsOK(res2)) {
    SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "CallOpParam_sdp_set" "', argument " "2"" of type '" "pj::SdpSession *""'"); 
  }
  arg2 = reinterpret_cast< pj::SdpSession * >(argp2);
  if (arg1) (arg1)->sdp = *arg2;
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_CallOpParam_sdp_get(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::CallOpParam *arg1 = (pj::CallOpParam *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  pj::SdpSession *result = 0 ;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__CallOpParam, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "CallOpParam_sdp_get" "', argument " "1"" of type '" "pj::CallOpParam *""'"); 
  }
  arg1 = reinterpret_cast< pj::CallOpParam * >(argp1);
  result = (pj::SdpSession *)& ((arg1)->sdp);
  resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(result), SWIGTYPE_p_pj__SdpSession, 0 |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_new_CallOpParam__SWIG_0(PyObject *SWIGUNUSEDPARM(self), Py_ssize_t nobjs, PyObject **swig_obj) {
  PyObject *resultobj = 0;
  bool arg1 ;
  bool val1 ;
  int ecode1 = 0 ;
  pj::CallOpParam *result = 0 ;
  
  if ((nobjs < 1) || (nobjs > 1)) SWIG_fail;
  ecode1 = SWIG_AsVal_bool(swig_obj[0], &val1);
  if (!SWIG_IsOK(ecode1)) {
    SWIG_exception_fail(SWIG_ArgError(ecode1), "in method '" "new_CallOpParam" "', argument " "1"" of type '" "bool""'");
  } 
  arg1 = static_cast< bool >(val1);
  result = (pj::CallOpParam *)new pj::CallOpParam(arg1);
  resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(result), SWIGTYPE_p_pj__CallOpParam, SWIG_POINTER_NEW |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_new_CallOpParam__SWIG_1(PyObject *SWIGUNUSEDPARM(self), Py_ssize_t nobjs, PyObject **SWIGUNUSEDPARM(swig_obj)) {
  PyObject *resultobj = 0;
  pj::CallOpParam *result = 0 ;
  
  if ((nobjs < 0) || (nobjs > 0)) SWIG_fail;
  result = (pj::CallOpParam *)new pj::CallOpParam();
  resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(result), SWIGTYPE_p_pj__CallOpParam, SWIG_POINTER_NEW |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_new_CallOpParam(PyObject *self, PyObject *args) {
  Py_ssize_t argc;
  PyObject *argv[2] = {
    0
  };
  
  if (!(argc = SWIG_Python_UnpackTuple(args, "new_CallOpParam", 0, 1, argv))) SWIG_fail;
  --argc;
  if (argc == 0) {
    return _wrap_new_CallOpParam__SWIG_1(self, argc, argv);
  }
  if (argc == 1) {
    int _v;
    {
      int res = SWIG_AsVal_bool(argv[0], NULL);
      _v = SWIG_CheckState(res);
    }
    if (_v) {
      return _wrap_new_CallOpParam__SWIG_0(self, argc, argv);
    }
  }
  
fail:
  SWIG_Python_RaiseOrModifyTypeError("Wrong number or type of arguments for overloaded function 'new_CallOpParam'.\n"
    "  Possible C/C++ prototypes are:\n"
    "    pj::CallOpParam::CallOpParam(bool)\n"
    "    pj::CallOpParam::CallOpParam()\n");
  return 0;
}


SWIGINTERN PyObject *_wrap_delete_CallOpParam(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::CallOpParam *arg1 = (pj::CallOpParam *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__CallOpParam, SWIG_POINTER_DISOWN |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "delete_CallOpParam" "', argument " "1"" of type '" "pj::CallOpParam *""'"); 
  }
  arg1 = reinterpret_cast< pj::CallOpParam * >(argp1);
  delete arg1;
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *CallOpParam_swigregister(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *obj;
  if (!SWIG_Python_UnpackTuple(args, "swigregister", 1, 1, &obj)) return NULL;
  SWIG_TypeNewClientData(SWIGTYPE_p_pj__CallOpParam, SWIG_NewClientData(obj));
  return SWIG_Py_Void();
}

SWIGINTERN PyObject *CallOpParam_swiginit(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  return SWIG_Python_InitShadowInstance(args);
}

SWIGINTERN PyObject *_wrap_CallSendRequestParam_method_set(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::CallSendRequestParam *arg1 = (pj::CallSendRequestParam *) 0 ;
  pj::string *arg2 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  int res2 = SWIG_OLDOBJ ;
  PyObject *swig_obj[2] ;
  
  if (!SWIG_Python_UnpackTuple(args, "CallSendRequestParam_method_set", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__CallSendRequestParam, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "CallSendRequestParam_method_set" "', argument " "1"" of type '" "pj::CallSendRequestParam *""'"); 
  }
  arg1 = reinterpret_cast< pj::CallSendRequestParam * >(argp1);
  {
    std::string *ptr = (std::string *)0;
    res2 = SWIG_AsPtr_std_string(swig_obj[1], &ptr);
    if (!SWIG_IsOK(res2)) {
      SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "CallSendRequestParam_method_set" "', argument " "2"" of type '" "pj::string const &""'"); 
    }
    if (!ptr) {
      SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "CallSendRequestParam_method_set" "', argument " "2"" of type '" "pj::string const &""'"); 
    }
    arg2 = ptr;
  }
  if (arg1) (arg1)->method = *arg2;
  resultobj = SWIG_Py_Void();
  if (SWIG_IsNewObj(res2)) delete arg2;
  return resultobj;
fail:
  if (SWIG_IsNewObj(res2)) delete arg2;
  return NULL;
}


SWIGINTERN PyObject *_wrap_CallSendRequestParam_method_get(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::CallSendRequestParam *arg1 = (pj::CallSendRequestParam *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  pj::string *result = 0 ;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__CallSendRequestParam, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "CallSendRequestParam_method_get" "', argument " "1"" of type '" "pj::CallSendRequestParam *""'"); 
  }
  arg1 = reinterpret_cast< pj::CallSendRequestParam * >(argp1);
  result = (pj::string *) & ((arg1)->method);
  resultobj = SWIG_From_std_string(static_cast< std::string >(*result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_CallSendRequestParam_txOption_set(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::CallSendRequestParam *arg1 = (pj::CallSendRequestParam *) 0 ;
  pj::SipTxOption *arg2 = (pj::SipTxOption *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  void *argp2 = 0 ;
  int res2 = 0 ;
  PyObject *swig_obj[2] ;
  
  if (!SWIG_Python_UnpackTuple(args, "CallSendRequestParam_txOption_set", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__CallSendRequestParam, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "CallSendRequestParam_txOption_set" "', argument " "1"" of type '" "pj::CallSendRequestParam *""'"); 
  }
  arg1 = reinterpret_cast< pj::CallSendRequestParam * >(argp1);
  res2 = SWIG_ConvertPtr(swig_obj[1], &argp2,SWIGTYPE_p_pj__SipTxOption, 0 |  0 );
  if (!SWIG_IsOK(res2)) {
    SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "CallSendRequestParam_txOption_set" "', argument " "2"" of type '" "pj::SipTxOption *""'"); 
  }
  arg2 = reinterpret_cast< pj::SipTxOption * >(argp2);
  if (arg1) (arg1)->txOption = *arg2;
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_CallSendRequestParam_txOption_get(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::CallSendRequestParam *arg1 = (pj::CallSendRequestParam *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  pj::SipTxOption *result = 0 ;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__CallSendRequestParam, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "CallSendRequestParam_txOption_get" "', argument " "1"" of type '" "pj::CallSendRequestParam *""'"); 
  }
  arg1 = reinterpret_cast< pj::CallSendRequestParam * >(argp1);
  result = (pj::SipTxOption *)& ((arg1)->txOption);
  resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(result), SWIGTYPE_p_pj__SipTxOption, 0 |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_new_CallSendRequestParam(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::CallSendRequestParam *result = 0 ;
  
  if (!SWIG_Python_UnpackTuple(args, "new_CallSendRequestParam", 0, 0, 0)) SWIG_fail;
  result = (pj::CallSendRequestParam *)new pj::CallSendRequestParam();
  resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(result), SWIGTYPE_p_pj__CallSendRequestParam, SWIG_POINTER_NEW |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_delete_CallSendRequestParam(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::CallSendRequestParam *arg1 = (pj::CallSendRequestParam *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__CallSendRequestParam, SWIG_POINTER_DISOWN |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "delete_CallSendRequestParam" "', argument " "1"" of type '" "pj::CallSendRequestParam *""'"); 
  }
  arg1 = reinterpret_cast< pj::CallSendRequestParam * >(argp1);
  delete arg1;
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *CallSendRequestParam_swigregister(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *obj;
  if (!SWIG_Python_UnpackTuple(args, "swigregister", 1, 1, &obj)) return NULL;
  SWIG_TypeNewClientData(SWIGTYPE_p_pj__CallSendRequestParam, SWIG_NewClientData(obj));
  return SWIG_Py_Void();
}

SWIGINTERN PyObject *CallSendRequestParam_swiginit(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  return SWIG_Python_InitShadowInstance(args);
}

SWIGINTERN PyObject *_wrap_CallVidSetStreamParam_medIdx_set(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::CallVidSetStreamParam *arg1 = (pj::CallVidSetStreamParam *) 0 ;
  int arg2 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  int val2 ;
  int ecode2 = 0 ;
  PyObject *swig_obj[2] ;
  
  if (!SWIG_Python_UnpackTuple(args, "CallVidSetStreamParam_medIdx_set", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__CallVidSetStreamParam, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "CallVidSetStreamParam_medIdx_set" "', argument " "1"" of type '" "pj::CallVidSetStreamParam *""'"); 
  }
  arg1 = reinterpret_cast< pj::CallVidSetStreamParam * >(argp1);
  ecode2 = SWIG_AsVal_int(swig_obj[1], &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "CallVidSetStreamParam_medIdx_set" "', argument " "2"" of type '" "int""'");
  } 
  arg2 = static_cast< int >(val2);
  if (arg1) (arg1)->medIdx = arg2;
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_CallVidSetStreamParam_medIdx_get(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::CallVidSetStreamParam *arg1 = (pj::CallVidSetStreamParam *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  int result;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__CallVidSetStreamParam, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "CallVidSetStreamParam_medIdx_get" "', argument " "1"" of type '" "pj::CallVidSetStreamParam *""'"); 
  }
  arg1 = reinterpret_cast< pj::CallVidSetStreamParam * >(argp1);
  result = (int) ((arg1)->medIdx);
  resultobj = SWIG_From_int(static_cast< int >(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_CallVidSetStreamParam_dir_set(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::CallVidSetStreamParam *arg1 = (pj::CallVidSetStreamParam *) 0 ;
  pjmedia_dir arg2 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  int val2 ;
  int ecode2 = 0 ;
  PyObject *swig_obj[2] ;
  
  if (!SWIG_Python_UnpackTuple(args, "CallVidSetStreamParam_dir_set", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__CallVidSetStreamParam, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "CallVidSetStreamParam_dir_set" "', argument " "1"" of type '" "pj::CallVidSetStreamParam *""'"); 
  }
  arg1 = reinterpret_cast< pj::CallVidSetStreamParam * >(argp1);
  ecode2 = SWIG_AsVal_int(swig_obj[1], &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "CallVidSetStreamParam_dir_set" "', argument " "2"" of type '" "pjmedia_dir""'");
  } 
  arg2 = static_cast< pjmedia_dir >(val2);
  if (arg1) (arg1)->dir = arg2;
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_CallVidSetStreamParam_dir_get(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::CallVidSetStreamParam *arg1 = (pj::CallVidSetStreamParam *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  pjmedia_dir result;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__CallVidSetStreamParam, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "CallVidSetStreamParam_dir_get" "', argument " "1"" of type '" "pj::CallVidSetStreamParam *""'"); 
  }
  arg1 = reinterpret_cast< pj::CallVidSetStreamParam * >(argp1);
  result = (pjmedia_dir) ((arg1)->dir);
  resultobj = SWIG_From_int(static_cast< int >(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_CallVidSetStreamParam_capDev_set(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::CallVidSetStreamParam *arg1 = (pj::CallVidSetStreamParam *) 0 ;
  pjmedia_vid_dev_index arg2 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  int val2 ;
  int ecode2 = 0 ;
  PyObject *swig_obj[2] ;
  
  if (!SWIG_Python_UnpackTuple(args, "CallVidSetStreamParam_capDev_set", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__CallVidSetStreamParam, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "CallVidSetStreamParam_capDev_set" "', argument " "1"" of type '" "pj::CallVidSetStreamParam *""'"); 
  }
  arg1 = reinterpret_cast< pj::CallVidSetStreamParam * >(argp1);
  ecode2 = SWIG_AsVal_int(swig_obj[1], &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "CallVidSetStreamParam_capDev_set" "', argument " "2"" of type '" "pjmedia_vid_dev_index""'");
  } 
  arg2 = static_cast< pjmedia_vid_dev_index >(val2);
  if (arg1) (arg1)->capDev = arg2;
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_CallVidSetStreamParam_capDev_get(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::CallVidSetStreamParam *arg1 = (pj::CallVidSetStreamParam *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  pjmedia_vid_dev_index result;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__CallVidSetStreamParam, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "CallVidSetStreamParam_capDev_get" "', argument " "1"" of type '" "pj::CallVidSetStreamParam *""'"); 
  }
  arg1 = reinterpret_cast< pj::CallVidSetStreamParam * >(argp1);
  result = (pjmedia_vid_dev_index) ((arg1)->capDev);
  resultobj = SWIG_From_int(static_cast< int >(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_new_CallVidSetStreamParam(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::CallVidSetStreamParam *result = 0 ;
  
  if (!SWIG_Python_UnpackTuple(args, "new_CallVidSetStreamParam", 0, 0, 0)) SWIG_fail;
  result = (pj::CallVidSetStreamParam *)new pj::CallVidSetStreamParam();
  resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(result), SWIGTYPE_p_pj__CallVidSetStreamParam, SWIG_POINTER_NEW |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_delete_CallVidSetStreamParam(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::CallVidSetStreamParam *arg1 = (pj::CallVidSetStreamParam *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__CallVidSetStreamParam, SWIG_POINTER_DISOWN |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "delete_CallVidSetStreamParam" "', argument " "1"" of type '" "pj::CallVidSetStreamParam *""'"); 
  }
  arg1 = reinterpret_cast< pj::CallVidSetStreamParam * >(argp1);
  delete arg1;
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *CallVidSetStreamParam_swigregister(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *obj;
  if (!SWIG_Python_UnpackTuple(args, "swigregister", 1, 1, &obj)) return NULL;
  SWIG_TypeNewClientData(SWIGTYPE_p_pj__CallVidSetStreamParam, SWIG_NewClientData(obj));
  return SWIG_Py_Void();
}

SWIGINTERN PyObject *CallVidSetStreamParam_swiginit(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  return SWIG_Python_InitShadowInstance(args);
}

SWIGINTERN PyObject *_wrap_CallSendDtmfParam_method_set(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::CallSendDtmfParam *arg1 = (pj::CallSendDtmfParam *) 0 ;
  pjsua_dtmf_method arg2 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  int val2 ;
  int ecode2 = 0 ;
  PyObject *swig_obj[2] ;
  
  if (!SWIG_Python_UnpackTuple(args, "CallSendDtmfParam_method_set", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__CallSendDtmfParam, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "CallSendDtmfParam_method_set" "', argument " "1"" of type '" "pj::CallSendDtmfParam *""'"); 
  }
  arg1 = reinterpret_cast< pj::CallSendDtmfParam * >(argp1);
  ecode2 = SWIG_AsVal_int(swig_obj[1], &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "CallSendDtmfParam_method_set" "', argument " "2"" of type '" "pjsua_dtmf_method""'");
  } 
  arg2 = static_cast< pjsua_dtmf_method >(val2);
  if (arg1) (arg1)->method = arg2;
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_CallSendDtmfParam_method_get(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::CallSendDtmfParam *arg1 = (pj::CallSendDtmfParam *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  pjsua_dtmf_method result;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__CallSendDtmfParam, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "CallSendDtmfParam_method_get" "', argument " "1"" of type '" "pj::CallSendDtmfParam *""'"); 
  }
  arg1 = reinterpret_cast< pj::CallSendDtmfParam * >(argp1);
  result = (pjsua_dtmf_method) ((arg1)->method);
  resultobj = SWIG_From_int(static_cast< int >(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_CallSendDtmfParam_duration_set(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::CallSendDtmfParam *arg1 = (pj::CallSendDtmfParam *) 0 ;
  unsigned int arg2 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  unsigned int val2 ;
  int ecode2 = 0 ;
  PyObject *swig_obj[2] ;
  
  if (!SWIG_Python_UnpackTuple(args, "CallSendDtmfParam_duration_set", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__CallSendDtmfParam, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "CallSendDtmfParam_duration_set" "', argument " "1"" of type '" "pj::CallSendDtmfParam *""'"); 
  }
  arg1 = reinterpret_cast< pj::CallSendDtmfParam * >(argp1);
  ecode2 = SWIG_AsVal_unsigned_SS_int(swig_obj[1], &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "CallSendDtmfParam_duration_set" "', argument " "2"" of type '" "unsigned int""'");
  } 
  arg2 = static_cast< unsigned int >(val2);
  if (arg1) (arg1)->duration = arg2;
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_CallSendDtmfParam_duration_get(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::CallSendDtmfParam *arg1 = (pj::CallSendDtmfParam *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  unsigned int result;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__CallSendDtmfParam, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "CallSendDtmfParam_duration_get" "', argument " "1"" of type '" "pj::CallSendDtmfParam *""'"); 
  }
  arg1 = reinterpret_cast< pj::CallSendDtmfParam * >(argp1);
  result = (unsigned int) ((arg1)->duration);
  resultobj = SWIG_From_unsigned_SS_int(static_cast< unsigned int >(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_CallSendDtmfParam_digits_set(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::CallSendDtmfParam *arg1 = (pj::CallSendDtmfParam *) 0 ;
  pj::string *arg2 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  int res2 = SWIG_OLDOBJ ;
  PyObject *swig_obj[2] ;
  
  if (!SWIG_Python_UnpackTuple(args, "CallSendDtmfParam_digits_set", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__CallSendDtmfParam, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "CallSendDtmfParam_digits_set" "', argument " "1"" of type '" "pj::CallSendDtmfParam *""'"); 
  }
  arg1 = reinterpret_cast< pj::CallSendDtmfParam * >(argp1);
  {
    std::string *ptr = (std::string *)0;
    res2 = SWIG_AsPtr_std_string(swig_obj[1], &ptr);
    if (!SWIG_IsOK(res2)) {
      SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "CallSendDtmfParam_digits_set" "', argument " "2"" of type '" "pj::string const &""'"); 
    }
    if (!ptr) {
      SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "CallSendDtmfParam_digits_set" "', argument " "2"" of type '" "pj::string const &""'"); 
    }
    arg2 = ptr;
  }
  if (arg1) (arg1)->digits = *arg2;
  resultobj = SWIG_Py_Void();
  if (SWIG_IsNewObj(res2)) delete arg2;
  return resultobj;
fail:
  if (SWIG_IsNewObj(res2)) delete arg2;
  return NULL;
}


SWIGINTERN PyObject *_wrap_CallSendDtmfParam_digits_get(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::CallSendDtmfParam *arg1 = (pj::CallSendDtmfParam *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  pj::string *result = 0 ;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__CallSendDtmfParam, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "CallSendDtmfParam_digits_get" "', argument " "1"" of type '" "pj::CallSendDtmfParam *""'"); 
  }
  arg1 = reinterpret_cast< pj::CallSendDtmfParam * >(argp1);
  result = (pj::string *) & ((arg1)->digits);
  resultobj = SWIG_From_std_string(static_cast< std::string >(*result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_new_CallSendDtmfParam(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::CallSendDtmfParam *result = 0 ;
  
  if (!SWIG_Python_UnpackTuple(args, "new_CallSendDtmfParam", 0, 0, 0)) SWIG_fail;
  result = (pj::CallSendDtmfParam *)new pj::CallSendDtmfParam();
  resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(result), SWIGTYPE_p_pj__CallSendDtmfParam, SWIG_POINTER_NEW |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_delete_CallSendDtmfParam(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::CallSendDtmfParam *arg1 = (pj::CallSendDtmfParam *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__CallSendDtmfParam, SWIG_POINTER_DISOWN |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "delete_CallSendDtmfParam" "', argument " "1"" of type '" "pj::CallSendDtmfParam *""'"); 
  }
  arg1 = reinterpret_cast< pj::CallSendDtmfParam * >(argp1);
  delete arg1;
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *CallSendDtmfParam_swigregister(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *obj;
  if (!SWIG_Python_UnpackTuple(args, "swigregister", 1, 1, &obj)) return NULL;
  SWIG_TypeNewClientData(SWIGTYPE_p_pj__CallSendDtmfParam, SWIG_NewClientData(obj));
  return SWIG_Py_Void();
}

SWIGINTERN PyObject *CallSendDtmfParam_swiginit(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  return SWIG_Python_InitShadowInstance(args);
}

SWIGINTERN PyObject *_wrap_new_Call__SWIG_0(PyObject *SWIGUNUSEDPARM(self), Py_ssize_t nobjs, PyObject **swig_obj) {
  PyObject *resultobj = 0;
  PyObject *arg1 = (PyObject *) 0 ;
  pj::Account *arg2 = 0 ;
  int arg3 ;
  void *argp2 = 0 ;
  int res2 = 0 ;
  int val3 ;
  int ecode3 = 0 ;
  pj::Call *result = 0 ;
  
  if ((nobjs < 3) || (nobjs > 3)) SWIG_fail;
  arg1 = swig_obj[0];
  res2 = SWIG_ConvertPtr(swig_obj[1], &argp2, SWIGTYPE_p_pj__Account,  0 );
  if (!SWIG_IsOK(res2)) {
    SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "new_Call" "', argument " "2"" of type '" "pj::Account &""'"); 
  }
  if (!argp2) {
    SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "new_Call" "', argument " "2"" of type '" "pj::Account &""'"); 
  }
  arg2 = reinterpret_cast< pj::Account * >(argp2);
  ecode3 = SWIG_AsVal_int(swig_obj[2], &val3);
  if (!SWIG_IsOK(ecode3)) {
    SWIG_exception_fail(SWIG_ArgError(ecode3), "in method '" "new_Call" "', argument " "3"" of type '" "int""'");
  } 
  arg3 = static_cast< int >(val3);
  if ( arg1 != Py_None ) {
    /* subclassed */
    result = (pj::Call *)new SwigDirector_Call(arg1,*arg2,arg3); 
  } else {
    result = (pj::Call *)new pj::Call(*arg2,arg3); 
  }
  
  resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(result), SWIGTYPE_p_pj__Call, SWIG_POINTER_NEW |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_new_Call__SWIG_1(PyObject *SWIGUNUSEDPARM(self), Py_ssize_t nobjs, PyObject **swig_obj) {
  PyObject *resultobj = 0;
  PyObject *arg1 = (PyObject *) 0 ;
  pj::Account *arg2 = 0 ;
  void *argp2 = 0 ;
  int res2 = 0 ;
  pj::Call *result = 0 ;
  
  if ((nobjs < 2) || (nobjs > 2)) SWIG_fail;
  arg1 = swig_obj[0];
  res2 = SWIG_ConvertPtr(swig_obj[1], &argp2, SWIGTYPE_p_pj__Account,  0 );
  if (!SWIG_IsOK(res2)) {
    SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "new_Call" "', argument " "2"" of type '" "pj::Account &""'"); 
  }
  if (!argp2) {
    SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "new_Call" "', argument " "2"" of type '" "pj::Account &""'"); 
  }
  arg2 = reinterpret_cast< pj::Account * >(argp2);
  if ( arg1 != Py_None ) {
    /* subclassed */
    result = (pj::Call *)new SwigDirector_Call(arg1,*arg2); 
  } else {
    result = (pj::Call *)new pj::Call(*arg2); 
  }
  
  resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(result), SWIGTYPE_p_pj__Call, SWIG_POINTER_NEW |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_new_Call(PyObject *self, PyObject *args) {
  Py_ssize_t argc;
  PyObject *argv[4] = {
    0
  };
  
  if (!(argc = SWIG_Python_UnpackTuple(args, "new_Call", 0, 3, argv))) SWIG_fail;
  --argc;
  if (argc == 2) {
    int _v;
    _v = (argv[0] != 0);
    if (_v) {
      void *vptr = 0;
      int res = SWIG_ConvertPtr(argv[1], &vptr, SWIGTYPE_p_pj__Account, SWIG_POINTER_NO_NULL);
      _v = SWIG_CheckState(res);
      if (_v) {
        return _wrap_new_Call__SWIG_1(self, argc, argv);
      }
    }
  }
  if (argc == 3) {
    int _v;
    _v = (argv[0] != 0);
    if (_v) {
      void *vptr = 0;
      int res = SWIG_ConvertPtr(argv[1], &vptr, SWIGTYPE_p_pj__Account, SWIG_POINTER_NO_NULL);
      _v = SWIG_CheckState(res);
      if (_v) {
        {
          int res = SWIG_AsVal_int(argv[2], NULL);
          _v = SWIG_CheckState(res);
        }
        if (_v) {
          return _wrap_new_Call__SWIG_0(self, argc, argv);
        }
      }
    }
  }
  
fail:
  SWIG_Python_RaiseOrModifyTypeError("Wrong number or type of arguments for overloaded function 'new_Call'.\n"
    "  Possible C/C++ prototypes are:\n"
    "    pj::Call::Call(pj::Account &,int)\n"
    "    pj::Call::Call(PyObject *,pj::Account &)\n");
  return 0;
}


SWIGINTERN PyObject *_wrap_delete_Call(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::Call *arg1 = (pj::Call *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__Call, SWIG_POINTER_DISOWN |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "delete_Call" "', argument " "1"" of type '" "pj::Call *""'"); 
  }
  arg1 = reinterpret_cast< pj::Call * >(argp1);
  delete arg1;
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_Call_getInfo(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::Call *arg1 = (pj::Call *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  pj::CallInfo result;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__Call, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "Call_getInfo" "', argument " "1"" of type '" "pj::Call const *""'"); 
  }
  arg1 = reinterpret_cast< pj::Call * >(argp1);
  try {
    result = ((pj::Call const *)arg1)->getInfo();
  } catch(pj::Error &_e) {
    SWIG_Python_Raise(SWIG_NewPointerObj((new pj::Error(static_cast< const pj::Error& >(_e))),SWIGTYPE_p_pj__Error,SWIG_POINTER_OWN), "pj::Error", SWIGTYPE_p_pj__Error); SWIG_fail;
  }
  resultobj = SWIG_NewPointerObj((new pj::CallInfo(static_cast< const pj::CallInfo& >(result))), SWIGTYPE_p_pj__CallInfo, SWIG_POINTER_OWN |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_Call_isActive(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::Call *arg1 = (pj::Call *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  bool result;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__Call, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "Call_isActive" "', argument " "1"" of type '" "pj::Call const *""'"); 
  }
  arg1 = reinterpret_cast< pj::Call * >(argp1);
  result = (bool)((pj::Call const *)arg1)->isActive();
  resultobj = SWIG_From_bool(static_cast< bool >(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_Call_getId(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::Call *arg1 = (pj::Call *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  int result;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__Call, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "Call_getId" "', argument " "1"" of type '" "pj::Call const *""'"); 
  }
  arg1 = reinterpret_cast< pj::Call * >(argp1);
  result = (int)((pj::Call const *)arg1)->getId();
  resultobj = SWIG_From_int(static_cast< int >(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_Call_lookup(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  int arg1 ;
  int val1 ;
  int ecode1 = 0 ;
  PyObject *swig_obj[1] ;
  Swig::Director *director = 0;
  pj::Call *result = 0 ;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  ecode1 = SWIG_AsVal_int(swig_obj[0], &val1);
  if (!SWIG_IsOK(ecode1)) {
    SWIG_exception_fail(SWIG_ArgError(ecode1), "in method '" "Call_lookup" "', argument " "1"" of type '" "int""'");
  } 
  arg1 = static_cast< int >(val1);
  result = (pj::Call *)pj::Call::lookup(arg1);
  director = SWIG_DIRECTOR_CAST(result);
  if (director) {
    resultobj = director->swig_get_self();
    Py_INCREF(resultobj);
  } else {
    resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(result), SWIGTYPE_p_pj__Call, 0 |  0 );
  }
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_Call_hasMedia(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::Call *arg1 = (pj::Call *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  bool result;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__Call, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "Call_hasMedia" "', argument " "1"" of type '" "pj::Call const *""'"); 
  }
  arg1 = reinterpret_cast< pj::Call * >(argp1);
  result = (bool)((pj::Call const *)arg1)->hasMedia();
  resultobj = SWIG_From_bool(static_cast< bool >(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_Call_getMedia(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::Call *arg1 = (pj::Call *) 0 ;
  unsigned int arg2 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  unsigned int val2 ;
  int ecode2 = 0 ;
  PyObject *swig_obj[2] ;
  pj::Media *result = 0 ;
  
  if (!SWIG_Python_UnpackTuple(args, "Call_getMedia", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__Call, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "Call_getMedia" "', argument " "1"" of type '" "pj::Call const *""'"); 
  }
  arg1 = reinterpret_cast< pj::Call * >(argp1);
  ecode2 = SWIG_AsVal_unsigned_SS_int(swig_obj[1], &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "Call_getMedia" "', argument " "2"" of type '" "unsigned int""'");
  } 
  arg2 = static_cast< unsigned int >(val2);
  result = (pj::Media *)((pj::Call const *)arg1)->getMedia(arg2);
  resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(result), SWIGTYPE_p_pj__Media, 0 |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_Call_getAudioMedia(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::Call *arg1 = (pj::Call *) 0 ;
  int arg2 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  int val2 ;
  int ecode2 = 0 ;
  PyObject *swig_obj[2] ;
  pj::AudioMedia result;
  
  if (!SWIG_Python_UnpackTuple(args, "Call_getAudioMedia", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__Call, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "Call_getAudioMedia" "', argument " "1"" of type '" "pj::Call const *""'"); 
  }
  arg1 = reinterpret_cast< pj::Call * >(argp1);
  ecode2 = SWIG_AsVal_int(swig_obj[1], &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "Call_getAudioMedia" "', argument " "2"" of type '" "int""'");
  } 
  arg2 = static_cast< int >(val2);
  try {
    result = ((pj::Call const *)arg1)->getAudioMedia(arg2);
  } catch(pj::Error &_e) {
    SWIG_Python_Raise(SWIG_NewPointerObj((new pj::Error(static_cast< const pj::Error& >(_e))),SWIGTYPE_p_pj__Error,SWIG_POINTER_OWN), "pj::Error", SWIGTYPE_p_pj__Error); SWIG_fail;
  }
  resultobj = SWIG_NewPointerObj((new pj::AudioMedia(static_cast< const pj::AudioMedia& >(result))), SWIGTYPE_p_pj__AudioMedia, SWIG_POINTER_OWN |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_Call_getEncodingVideoMedia(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::Call *arg1 = (pj::Call *) 0 ;
  int arg2 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  int val2 ;
  int ecode2 = 0 ;
  PyObject *swig_obj[2] ;
  pj::VideoMedia result;
  
  if (!SWIG_Python_UnpackTuple(args, "Call_getEncodingVideoMedia", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__Call, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "Call_getEncodingVideoMedia" "', argument " "1"" of type '" "pj::Call const *""'"); 
  }
  arg1 = reinterpret_cast< pj::Call * >(argp1);
  ecode2 = SWIG_AsVal_int(swig_obj[1], &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "Call_getEncodingVideoMedia" "', argument " "2"" of type '" "int""'");
  } 
  arg2 = static_cast< int >(val2);
  try {
    result = ((pj::Call const *)arg1)->getEncodingVideoMedia(arg2);
  } catch(pj::Error &_e) {
    SWIG_Python_Raise(SWIG_NewPointerObj((new pj::Error(static_cast< const pj::Error& >(_e))),SWIGTYPE_p_pj__Error,SWIG_POINTER_OWN), "pj::Error", SWIGTYPE_p_pj__Error); SWIG_fail;
  }
  resultobj = SWIG_NewPointerObj((new pj::VideoMedia(static_cast< const pj::VideoMedia& >(result))), SWIGTYPE_p_pj__VideoMedia, SWIG_POINTER_OWN |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_Call_getDecodingVideoMedia(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::Call *arg1 = (pj::Call *) 0 ;
  int arg2 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  int val2 ;
  int ecode2 = 0 ;
  PyObject *swig_obj[2] ;
  pj::VideoMedia result;
  
  if (!SWIG_Python_UnpackTuple(args, "Call_getDecodingVideoMedia", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__Call, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "Call_getDecodingVideoMedia" "', argument " "1"" of type '" "pj::Call const *""'"); 
  }
  arg1 = reinterpret_cast< pj::Call * >(argp1);
  ecode2 = SWIG_AsVal_int(swig_obj[1], &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "Call_getDecodingVideoMedia" "', argument " "2"" of type '" "int""'");
  } 
  arg2 = static_cast< int >(val2);
  try {
    result = ((pj::Call const *)arg1)->getDecodingVideoMedia(arg2);
  } catch(pj::Error &_e) {
    SWIG_Python_Raise(SWIG_NewPointerObj((new pj::Error(static_cast< const pj::Error& >(_e))),SWIGTYPE_p_pj__Error,SWIG_POINTER_OWN), "pj::Error", SWIGTYPE_p_pj__Error); SWIG_fail;
  }
  resultobj = SWIG_NewPointerObj((new pj::VideoMedia(static_cast< const pj::VideoMedia& >(result))), SWIGTYPE_p_pj__VideoMedia, SWIG_POINTER_OWN |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_Call_remoteHasCap(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::Call *arg1 = (pj::Call *) 0 ;
  int arg2 ;
  pj::string *arg3 = 0 ;
  pj::string *arg4 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  int val2 ;
  int ecode2 = 0 ;
  int res3 = SWIG_OLDOBJ ;
  int res4 = SWIG_OLDOBJ ;
  PyObject *swig_obj[4] ;
  pjsip_dialog_cap_status result;
  
  if (!SWIG_Python_UnpackTuple(args, "Call_remoteHasCap", 4, 4, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__Call, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "Call_remoteHasCap" "', argument " "1"" of type '" "pj::Call const *""'"); 
  }
  arg1 = reinterpret_cast< pj::Call * >(argp1);
  ecode2 = SWIG_AsVal_int(swig_obj[1], &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "Call_remoteHasCap" "', argument " "2"" of type '" "int""'");
  } 
  arg2 = static_cast< int >(val2);
  {
    std::string *ptr = (std::string *)0;
    res3 = SWIG_AsPtr_std_string(swig_obj[2], &ptr);
    if (!SWIG_IsOK(res3)) {
      SWIG_exception_fail(SWIG_ArgError(res3), "in method '" "Call_remoteHasCap" "', argument " "3"" of type '" "pj::string const &""'"); 
    }
    if (!ptr) {
      SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "Call_remoteHasCap" "', argument " "3"" of type '" "pj::string const &""'"); 
    }
    arg3 = ptr;
  }
  {
    std::string *ptr = (std::string *)0;
    res4 = SWIG_AsPtr_std_string(swig_obj[3], &ptr);
    if (!SWIG_IsOK(res4)) {
      SWIG_exception_fail(SWIG_ArgError(res4), "in method '" "Call_remoteHasCap" "', argument " "4"" of type '" "pj::string const &""'"); 
    }
    if (!ptr) {
      SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "Call_remoteHasCap" "', argument " "4"" of type '" "pj::string const &""'"); 
    }
    arg4 = ptr;
  }
  result = (pjsip_dialog_cap_status)((pj::Call const *)arg1)->remoteHasCap(arg2,(pj::string const &)*arg3,(pj::string const &)*arg4);
  resultobj = SWIG_From_int(static_cast< int >(result));
  if (SWIG_IsNewObj(res3)) delete arg3;
  if (SWIG_IsNewObj(res4)) delete arg4;
  return resultobj;
fail:
  if (SWIG_IsNewObj(res3)) delete arg3;
  if (SWIG_IsNewObj(res4)) delete arg4;
  return NULL;
}


SWIGINTERN PyObject *_wrap_Call_setUserData(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::Call *arg1 = (pj::Call *) 0 ;
  pj::Token arg2 = (pj::Token) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  int res2 ;
  PyObject *swig_obj[2] ;
  
  if (!SWIG_Python_UnpackTuple(args, "Call_setUserData", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__Call, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "Call_setUserData" "', argument " "1"" of type '" "pj::Call *""'"); 
  }
  arg1 = reinterpret_cast< pj::Call * >(argp1);
  res2 = SWIG_ConvertPtr(swig_obj[1],SWIG_as_voidptrptr(&arg2), 0, 0);
  if (!SWIG_IsOK(res2)) {
    SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "Call_setUserData" "', argument " "2"" of type '" "pj::Token""'"); 
  }
  (arg1)->setUserData(arg2);
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_Call_getUserData(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::Call *arg1 = (pj::Call *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  pj::Token result;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__Call, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "Call_getUserData" "', argument " "1"" of type '" "pj::Call const *""'"); 
  }
  arg1 = reinterpret_cast< pj::Call * >(argp1);
  result = (pj::Token)((pj::Call const *)arg1)->getUserData();
  resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(result), SWIGTYPE_p_void, 0 |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_Call_getRemNatType(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::Call *arg1 = (pj::Call *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  pj_stun_nat_type result;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__Call, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "Call_getRemNatType" "', argument " "1"" of type '" "pj::Call *""'"); 
  }
  arg1 = reinterpret_cast< pj::Call * >(argp1);
  try {
    result = (pj_stun_nat_type)(arg1)->getRemNatType();
  } catch(pj::Error &_e) {
    SWIG_Python_Raise(SWIG_NewPointerObj((new pj::Error(static_cast< const pj::Error& >(_e))),SWIGTYPE_p_pj__Error,SWIG_POINTER_OWN), "pj::Error", SWIGTYPE_p_pj__Error); SWIG_fail;
  }
  resultobj = SWIG_From_int(static_cast< int >(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_Call_makeCall(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::Call *arg1 = (pj::Call *) 0 ;
  pj::string *arg2 = 0 ;
  pj::CallOpParam *arg3 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  int res2 = SWIG_OLDOBJ ;
  void *argp3 = 0 ;
  int res3 = 0 ;
  PyObject *swig_obj[3] ;
  
  if (!SWIG_Python_UnpackTuple(args, "Call_makeCall", 3, 3, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__Call, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "Call_makeCall" "', argument " "1"" of type '" "pj::Call *""'"); 
  }
  arg1 = reinterpret_cast< pj::Call * >(argp1);
  {
    std::string *ptr = (std::string *)0;
    res2 = SWIG_AsPtr_std_string(swig_obj[1], &ptr);
    if (!SWIG_IsOK(res2)) {
      SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "Call_makeCall" "', argument " "2"" of type '" "pj::string const &""'"); 
    }
    if (!ptr) {
      SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "Call_makeCall" "', argument " "2"" of type '" "pj::string const &""'"); 
    }
    arg2 = ptr;
  }
  res3 = SWIG_ConvertPtr(swig_obj[2], &argp3, SWIGTYPE_p_pj__CallOpParam,  0  | 0);
  if (!SWIG_IsOK(res3)) {
    SWIG_exception_fail(SWIG_ArgError(res3), "in method '" "Call_makeCall" "', argument " "3"" of type '" "pj::CallOpParam const &""'"); 
  }
  if (!argp3) {
    SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "Call_makeCall" "', argument " "3"" of type '" "pj::CallOpParam const &""'"); 
  }
  arg3 = reinterpret_cast< pj::CallOpParam * >(argp3);
  try {
    (arg1)->makeCall((pj::string const &)*arg2,(pj::CallOpParam const &)*arg3);
  } catch(pj::Error &_e) {
    SWIG_Python_Raise(SWIG_NewPointerObj((new pj::Error(static_cast< const pj::Error& >(_e))),SWIGTYPE_p_pj__Error,SWIG_POINTER_OWN), "pj::Error", SWIGTYPE_p_pj__Error); SWIG_fail;
  }
  resultobj = SWIG_Py_Void();
  if (SWIG_IsNewObj(res2)) delete arg2;
  return resultobj;
fail:
  if (SWIG_IsNewObj(res2)) delete arg2;
  return NULL;
}


SWIGINTERN PyObject *_wrap_Call_answer(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::Call *arg1 = (pj::Call *) 0 ;
  pj::CallOpParam *arg2 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  void *argp2 = 0 ;
  int res2 = 0 ;
  PyObject *swig_obj[2] ;
  
  if (!SWIG_Python_UnpackTuple(args, "Call_answer", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__Call, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "Call_answer" "', argument " "1"" of type '" "pj::Call *""'"); 
  }
  arg1 = reinterpret_cast< pj::Call * >(argp1);
  res2 = SWIG_ConvertPtr(swig_obj[1], &argp2, SWIGTYPE_p_pj__CallOpParam,  0  | 0);
  if (!SWIG_IsOK(res2)) {
    SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "Call_answer" "', argument " "2"" of type '" "pj::CallOpParam const &""'"); 
  }
  if (!argp2) {
    SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "Call_answer" "', argument " "2"" of type '" "pj::CallOpParam const &""'"); 
  }
  arg2 = reinterpret_cast< pj::CallOpParam * >(argp2);
  try {
    (arg1)->answer((pj::CallOpParam const &)*arg2);
  } catch(pj::Error &_e) {
    SWIG_Python_Raise(SWIG_NewPointerObj((new pj::Error(static_cast< const pj::Error& >(_e))),SWIGTYPE_p_pj__Error,SWIG_POINTER_OWN), "pj::Error", SWIGTYPE_p_pj__Error); SWIG_fail;
  }
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_Call_hangup(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::Call *arg1 = (pj::Call *) 0 ;
  pj::CallOpParam *arg2 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  void *argp2 = 0 ;
  int res2 = 0 ;
  PyObject *swig_obj[2] ;
  
  if (!SWIG_Python_UnpackTuple(args, "Call_hangup", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__Call, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "Call_hangup" "', argument " "1"" of type '" "pj::Call *""'"); 
  }
  arg1 = reinterpret_cast< pj::Call * >(argp1);
  res2 = SWIG_ConvertPtr(swig_obj[1], &argp2, SWIGTYPE_p_pj__CallOpParam,  0  | 0);
  if (!SWIG_IsOK(res2)) {
    SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "Call_hangup" "', argument " "2"" of type '" "pj::CallOpParam const &""'"); 
  }
  if (!argp2) {
    SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "Call_hangup" "', argument " "2"" of type '" "pj::CallOpParam const &""'"); 
  }
  arg2 = reinterpret_cast< pj::CallOpParam * >(argp2);
  try {
    (arg1)->hangup((pj::CallOpParam const &)*arg2);
  } catch(pj::Error &_e) {
    SWIG_Python_Raise(SWIG_NewPointerObj((new pj::Error(static_cast< const pj::Error& >(_e))),SWIGTYPE_p_pj__Error,SWIG_POINTER_OWN), "pj::Error", SWIGTYPE_p_pj__Error); SWIG_fail;
  }
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_Call_setHold(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::Call *arg1 = (pj::Call *) 0 ;
  pj::CallOpParam *arg2 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  void *argp2 = 0 ;
  int res2 = 0 ;
  PyObject *swig_obj[2] ;
  
  if (!SWIG_Python_UnpackTuple(args, "Call_setHold", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__Call, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "Call_setHold" "', argument " "1"" of type '" "pj::Call *""'"); 
  }
  arg1 = reinterpret_cast< pj::Call * >(argp1);
  res2 = SWIG_ConvertPtr(swig_obj[1], &argp2, SWIGTYPE_p_pj__CallOpParam,  0  | 0);
  if (!SWIG_IsOK(res2)) {
    SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "Call_setHold" "', argument " "2"" of type '" "pj::CallOpParam const &""'"); 
  }
  if (!argp2) {
    SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "Call_setHold" "', argument " "2"" of type '" "pj::CallOpParam const &""'"); 
  }
  arg2 = reinterpret_cast< pj::CallOpParam * >(argp2);
  try {
    (arg1)->setHold((pj::CallOpParam const &)*arg2);
  } catch(pj::Error &_e) {
    SWIG_Python_Raise(SWIG_NewPointerObj((new pj::Error(static_cast< const pj::Error& >(_e))),SWIGTYPE_p_pj__Error,SWIG_POINTER_OWN), "pj::Error", SWIGTYPE_p_pj__Error); SWIG_fail;
  }
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_Call_reinvite(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::Call *arg1 = (pj::Call *) 0 ;
  pj::CallOpParam *arg2 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  void *argp2 = 0 ;
  int res2 = 0 ;
  PyObject *swig_obj[2] ;
  
  if (!SWIG_Python_UnpackTuple(args, "Call_reinvite", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__Call, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "Call_reinvite" "', argument " "1"" of type '" "pj::Call *""'"); 
  }
  arg1 = reinterpret_cast< pj::Call * >(argp1);
  res2 = SWIG_ConvertPtr(swig_obj[1], &argp2, SWIGTYPE_p_pj__CallOpParam,  0  | 0);
  if (!SWIG_IsOK(res2)) {
    SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "Call_reinvite" "', argument " "2"" of type '" "pj::CallOpParam const &""'"); 
  }
  if (!argp2) {
    SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "Call_reinvite" "', argument " "2"" of type '" "pj::CallOpParam const &""'"); 
  }
  arg2 = reinterpret_cast< pj::CallOpParam * >(argp2);
  try {
    (arg1)->reinvite((pj::CallOpParam const &)*arg2);
  } catch(pj::Error &_e) {
    SWIG_Python_Raise(SWIG_NewPointerObj((new pj::Error(static_cast< const pj::Error& >(_e))),SWIGTYPE_p_pj__Error,SWIG_POINTER_OWN), "pj::Error", SWIGTYPE_p_pj__Error); SWIG_fail;
  }
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_Call_update(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::Call *arg1 = (pj::Call *) 0 ;
  pj::CallOpParam *arg2 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  void *argp2 = 0 ;
  int res2 = 0 ;
  PyObject *swig_obj[2] ;
  
  if (!SWIG_Python_UnpackTuple(args, "Call_update", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__Call, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "Call_update" "', argument " "1"" of type '" "pj::Call *""'"); 
  }
  arg1 = reinterpret_cast< pj::Call * >(argp1);
  res2 = SWIG_ConvertPtr(swig_obj[1], &argp2, SWIGTYPE_p_pj__CallOpParam,  0  | 0);
  if (!SWIG_IsOK(res2)) {
    SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "Call_update" "', argument " "2"" of type '" "pj::CallOpParam const &""'"); 
  }
  if (!argp2) {
    SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "Call_update" "', argument " "2"" of type '" "pj::CallOpParam const &""'"); 
  }
  arg2 = reinterpret_cast< pj::CallOpParam * >(argp2);
  try {
    (arg1)->update((pj::CallOpParam const &)*arg2);
  } catch(pj::Error &_e) {
    SWIG_Python_Raise(SWIG_NewPointerObj((new pj::Error(static_cast< const pj::Error& >(_e))),SWIGTYPE_p_pj__Error,SWIG_POINTER_OWN), "pj::Error", SWIGTYPE_p_pj__Error); SWIG_fail;
  }
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_Call_xfer(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::Call *arg1 = (pj::Call *) 0 ;
  pj::string *arg2 = 0 ;
  pj::CallOpParam *arg3 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  int res2 = SWIG_OLDOBJ ;
  void *argp3 = 0 ;
  int res3 = 0 ;
  PyObject *swig_obj[3] ;
  
  if (!SWIG_Python_UnpackTuple(args, "Call_xfer", 3, 3, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__Call, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "Call_xfer" "', argument " "1"" of type '" "pj::Call *""'"); 
  }
  arg1 = reinterpret_cast< pj::Call * >(argp1);
  {
    std::string *ptr = (std::string *)0;
    res2 = SWIG_AsPtr_std_string(swig_obj[1], &ptr);
    if (!SWIG_IsOK(res2)) {
      SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "Call_xfer" "', argument " "2"" of type '" "pj::string const &""'"); 
    }
    if (!ptr) {
      SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "Call_xfer" "', argument " "2"" of type '" "pj::string const &""'"); 
    }
    arg2 = ptr;
  }
  res3 = SWIG_ConvertPtr(swig_obj[2], &argp3, SWIGTYPE_p_pj__CallOpParam,  0  | 0);
  if (!SWIG_IsOK(res3)) {
    SWIG_exception_fail(SWIG_ArgError(res3), "in method '" "Call_xfer" "', argument " "3"" of type '" "pj::CallOpParam const &""'"); 
  }
  if (!argp3) {
    SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "Call_xfer" "', argument " "3"" of type '" "pj::CallOpParam const &""'"); 
  }
  arg3 = reinterpret_cast< pj::CallOpParam * >(argp3);
  try {
    (arg1)->xfer((pj::string const &)*arg2,(pj::CallOpParam const &)*arg3);
  } catch(pj::Error &_e) {
    SWIG_Python_Raise(SWIG_NewPointerObj((new pj::Error(static_cast< const pj::Error& >(_e))),SWIGTYPE_p_pj__Error,SWIG_POINTER_OWN), "pj::Error", SWIGTYPE_p_pj__Error); SWIG_fail;
  }
  resultobj = SWIG_Py_Void();
  if (SWIG_IsNewObj(res2)) delete arg2;
  return resultobj;
fail:
  if (SWIG_IsNewObj(res2)) delete arg2;
  return NULL;
}


SWIGINTERN PyObject *_wrap_Call_xferReplaces(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::Call *arg1 = (pj::Call *) 0 ;
  pj::Call *arg2 = 0 ;
  pj::CallOpParam *arg3 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  void *argp2 = 0 ;
  int res2 = 0 ;
  void *argp3 = 0 ;
  int res3 = 0 ;
  PyObject *swig_obj[3] ;
  
  if (!SWIG_Python_UnpackTuple(args, "Call_xferReplaces", 3, 3, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__Call, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "Call_xferReplaces" "', argument " "1"" of type '" "pj::Call *""'"); 
  }
  arg1 = reinterpret_cast< pj::Call * >(argp1);
  res2 = SWIG_ConvertPtr(swig_obj[1], &argp2, SWIGTYPE_p_pj__Call,  0  | 0);
  if (!SWIG_IsOK(res2)) {
    SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "Call_xferReplaces" "', argument " "2"" of type '" "pj::Call const &""'"); 
  }
  if (!argp2) {
    SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "Call_xferReplaces" "', argument " "2"" of type '" "pj::Call const &""'"); 
  }
  arg2 = reinterpret_cast< pj::Call * >(argp2);
  res3 = SWIG_ConvertPtr(swig_obj[2], &argp3, SWIGTYPE_p_pj__CallOpParam,  0  | 0);
  if (!SWIG_IsOK(res3)) {
    SWIG_exception_fail(SWIG_ArgError(res3), "in method '" "Call_xferReplaces" "', argument " "3"" of type '" "pj::CallOpParam const &""'"); 
  }
  if (!argp3) {
    SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "Call_xferReplaces" "', argument " "3"" of type '" "pj::CallOpParam const &""'"); 
  }
  arg3 = reinterpret_cast< pj::CallOpParam * >(argp3);
  try {
    (arg1)->xferReplaces((pj::Call const &)*arg2,(pj::CallOpParam const &)*arg3);
  } catch(pj::Error &_e) {
    SWIG_Python_Raise(SWIG_NewPointerObj((new pj::Error(static_cast< const pj::Error& >(_e))),SWIGTYPE_p_pj__Error,SWIG_POINTER_OWN), "pj::Error", SWIGTYPE_p_pj__Error); SWIG_fail;
  }
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_Call_processRedirect(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::Call *arg1 = (pj::Call *) 0 ;
  pjsip_redirect_op arg2 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  int val2 ;
  int ecode2 = 0 ;
  PyObject *swig_obj[2] ;
  
  if (!SWIG_Python_UnpackTuple(args, "Call_processRedirect", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__Call, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "Call_processRedirect" "', argument " "1"" of type '" "pj::Call *""'"); 
  }
  arg1 = reinterpret_cast< pj::Call * >(argp1);
  ecode2 = SWIG_AsVal_int(swig_obj[1], &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "Call_processRedirect" "', argument " "2"" of type '" "pjsip_redirect_op""'");
  } 
  arg2 = static_cast< pjsip_redirect_op >(val2);
  try {
    (arg1)->processRedirect(arg2);
  } catch(pj::Error &_e) {
    SWIG_Python_Raise(SWIG_NewPointerObj((new pj::Error(static_cast< const pj::Error& >(_e))),SWIGTYPE_p_pj__Error,SWIG_POINTER_OWN), "pj::Error", SWIGTYPE_p_pj__Error); SWIG_fail;
  }
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_Call_dialDtmf(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::Call *arg1 = (pj::Call *) 0 ;
  pj::string *arg2 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  int res2 = SWIG_OLDOBJ ;
  PyObject *swig_obj[2] ;
  
  if (!SWIG_Python_UnpackTuple(args, "Call_dialDtmf", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__Call, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "Call_dialDtmf" "', argument " "1"" of type '" "pj::Call *""'"); 
  }
  arg1 = reinterpret_cast< pj::Call * >(argp1);
  {
    std::string *ptr = (std::string *)0;
    res2 = SWIG_AsPtr_std_string(swig_obj[1], &ptr);
    if (!SWIG_IsOK(res2)) {
      SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "Call_dialDtmf" "', argument " "2"" of type '" "pj::string const &""'"); 
    }
    if (!ptr) {
      SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "Call_dialDtmf" "', argument " "2"" of type '" "pj::string const &""'"); 
    }
    arg2 = ptr;
  }
  try {
    (arg1)->dialDtmf((pj::string const &)*arg2);
  } catch(pj::Error &_e) {
    SWIG_Python_Raise(SWIG_NewPointerObj((new pj::Error(static_cast< const pj::Error& >(_e))),SWIGTYPE_p_pj__Error,SWIG_POINTER_OWN), "pj::Error", SWIGTYPE_p_pj__Error); SWIG_fail;
  }
  resultobj = SWIG_Py_Void();
  if (SWIG_IsNewObj(res2)) delete arg2;
  return resultobj;
fail:
  if (SWIG_IsNewObj(res2)) delete arg2;
  return NULL;
}


SWIGINTERN PyObject *_wrap_Call_sendDtmf(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::Call *arg1 = (pj::Call *) 0 ;
  pj::CallSendDtmfParam *arg2 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  void *argp2 = 0 ;
  int res2 = 0 ;
  PyObject *swig_obj[2] ;
  
  if (!SWIG_Python_UnpackTuple(args, "Call_sendDtmf", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__Call, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "Call_sendDtmf" "', argument " "1"" of type '" "pj::Call *""'"); 
  }
  arg1 = reinterpret_cast< pj::Call * >(argp1);
  res2 = SWIG_ConvertPtr(swig_obj[1], &argp2, SWIGTYPE_p_pj__CallSendDtmfParam,  0  | 0);
  if (!SWIG_IsOK(res2)) {
    SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "Call_sendDtmf" "', argument " "2"" of type '" "pj::CallSendDtmfParam const &""'"); 
  }
  if (!argp2) {
    SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "Call_sendDtmf" "', argument " "2"" of type '" "pj::CallSendDtmfParam const &""'"); 
  }
  arg2 = reinterpret_cast< pj::CallSendDtmfParam * >(argp2);
  try {
    (arg1)->sendDtmf((pj::CallSendDtmfParam const &)*arg2);
  } catch(pj::Error &_e) {
    SWIG_Python_Raise(SWIG_NewPointerObj((new pj::Error(static_cast< const pj::Error& >(_e))),SWIGTYPE_p_pj__Error,SWIG_POINTER_OWN), "pj::Error", SWIGTYPE_p_pj__Error); SWIG_fail;
  }
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_Call_sendInstantMessage(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::Call *arg1 = (pj::Call *) 0 ;
  pj::SendInstantMessageParam *arg2 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  void *argp2 = 0 ;
  int res2 = 0 ;
  PyObject *swig_obj[2] ;
  
  if (!SWIG_Python_UnpackTuple(args, "Call_sendInstantMessage", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__Call, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "Call_sendInstantMessage" "', argument " "1"" of type '" "pj::Call *""'"); 
  }
  arg1 = reinterpret_cast< pj::Call * >(argp1);
  res2 = SWIG_ConvertPtr(swig_obj[1], &argp2, SWIGTYPE_p_pj__SendInstantMessageParam,  0  | 0);
  if (!SWIG_IsOK(res2)) {
    SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "Call_sendInstantMessage" "', argument " "2"" of type '" "pj::SendInstantMessageParam const &""'"); 
  }
  if (!argp2) {
    SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "Call_sendInstantMessage" "', argument " "2"" of type '" "pj::SendInstantMessageParam const &""'"); 
  }
  arg2 = reinterpret_cast< pj::SendInstantMessageParam * >(argp2);
  try {
    (arg1)->sendInstantMessage((pj::SendInstantMessageParam const &)*arg2);
  } catch(pj::Error &_e) {
    SWIG_Python_Raise(SWIG_NewPointerObj((new pj::Error(static_cast< const pj::Error& >(_e))),SWIGTYPE_p_pj__Error,SWIG_POINTER_OWN), "pj::Error", SWIGTYPE_p_pj__Error); SWIG_fail;
  }
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_Call_sendTypingIndication(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::Call *arg1 = (pj::Call *) 0 ;
  pj::SendTypingIndicationParam *arg2 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  void *argp2 = 0 ;
  int res2 = 0 ;
  PyObject *swig_obj[2] ;
  
  if (!SWIG_Python_UnpackTuple(args, "Call_sendTypingIndication", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__Call, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "Call_sendTypingIndication" "', argument " "1"" of type '" "pj::Call *""'"); 
  }
  arg1 = reinterpret_cast< pj::Call * >(argp1);
  res2 = SWIG_ConvertPtr(swig_obj[1], &argp2, SWIGTYPE_p_pj__SendTypingIndicationParam,  0  | 0);
  if (!SWIG_IsOK(res2)) {
    SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "Call_sendTypingIndication" "', argument " "2"" of type '" "pj::SendTypingIndicationParam const &""'"); 
  }
  if (!argp2) {
    SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "Call_sendTypingIndication" "', argument " "2"" of type '" "pj::SendTypingIndicationParam const &""'"); 
  }
  arg2 = reinterpret_cast< pj::SendTypingIndicationParam * >(argp2);
  try {
    (arg1)->sendTypingIndication((pj::SendTypingIndicationParam const &)*arg2);
  } catch(pj::Error &_e) {
    SWIG_Python_Raise(SWIG_NewPointerObj((new pj::Error(static_cast< const pj::Error& >(_e))),SWIGTYPE_p_pj__Error,SWIG_POINTER_OWN), "pj::Error", SWIGTYPE_p_pj__Error); SWIG_fail;
  }
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_Call_sendRequest(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::Call *arg1 = (pj::Call *) 0 ;
  pj::CallSendRequestParam *arg2 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  void *argp2 = 0 ;
  int res2 = 0 ;
  PyObject *swig_obj[2] ;
  
  if (!SWIG_Python_UnpackTuple(args, "Call_sendRequest", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__Call, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "Call_sendRequest" "', argument " "1"" of type '" "pj::Call *""'"); 
  }
  arg1 = reinterpret_cast< pj::Call * >(argp1);
  res2 = SWIG_ConvertPtr(swig_obj[1], &argp2, SWIGTYPE_p_pj__CallSendRequestParam,  0  | 0);
  if (!SWIG_IsOK(res2)) {
    SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "Call_sendRequest" "', argument " "2"" of type '" "pj::CallSendRequestParam const &""'"); 
  }
  if (!argp2) {
    SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "Call_sendRequest" "', argument " "2"" of type '" "pj::CallSendRequestParam const &""'"); 
  }
  arg2 = reinterpret_cast< pj::CallSendRequestParam * >(argp2);
  try {
    (arg1)->sendRequest((pj::CallSendRequestParam const &)*arg2);
  } catch(pj::Error &_e) {
    SWIG_Python_Raise(SWIG_NewPointerObj((new pj::Error(static_cast< const pj::Error& >(_e))),SWIGTYPE_p_pj__Error,SWIG_POINTER_OWN), "pj::Error", SWIGTYPE_p_pj__Error); SWIG_fail;
  }
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_Call_dump(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::Call *arg1 = (pj::Call *) 0 ;
  bool arg2 ;
  pj::string arg3 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  bool val2 ;
  int ecode2 = 0 ;
  PyObject *swig_obj[3] ;
  pj::string result;
  
  if (!SWIG_Python_UnpackTuple(args, "Call_dump", 3, 3, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__Call, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "Call_dump" "', argument " "1"" of type '" "pj::Call *""'"); 
  }
  arg1 = reinterpret_cast< pj::Call * >(argp1);
  ecode2 = SWIG_AsVal_bool(swig_obj[1], &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "Call_dump" "', argument " "2"" of type '" "bool""'");
  } 
  arg2 = static_cast< bool >(val2);
  {
    std::string *ptr = (std::string *)0;
    int res = SWIG_AsPtr_std_string(swig_obj[2], &ptr);
    if (!SWIG_IsOK(res) || !ptr) {
      SWIG_exception_fail(SWIG_ArgError((ptr ? res : SWIG_TypeError)), "in method '" "Call_dump" "', argument " "3"" of type '" "pj::string const""'"); 
    }
    arg3 = *ptr;
    if (SWIG_IsNewObj(res)) delete ptr;
  }
  try {
    result = (arg1)->dump(arg2,arg3);
  } catch(pj::Error &_e) {
    SWIG_Python_Raise(SWIG_NewPointerObj((new pj::Error(static_cast< const pj::Error& >(_e))),SWIGTYPE_p_pj__Error,SWIG_POINTER_OWN), "pj::Error", SWIGTYPE_p_pj__Error); SWIG_fail;
  }
  resultobj = SWIG_From_std_string(static_cast< std::string >(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_Call_vidGetStreamIdx(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::Call *arg1 = (pj::Call *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  int result;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__Call, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "Call_vidGetStreamIdx" "', argument " "1"" of type '" "pj::Call const *""'"); 
  }
  arg1 = reinterpret_cast< pj::Call * >(argp1);
  result = (int)((pj::Call const *)arg1)->vidGetStreamIdx();
  resultobj = SWIG_From_int(static_cast< int >(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_Call_vidStreamIsRunning(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::Call *arg1 = (pj::Call *) 0 ;
  int arg2 ;
  pjmedia_dir arg3 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  int val2 ;
  int ecode2 = 0 ;
  int val3 ;
  int ecode3 = 0 ;
  PyObject *swig_obj[3] ;
  bool result;
  
  if (!SWIG_Python_UnpackTuple(args, "Call_vidStreamIsRunning", 3, 3, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__Call, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "Call_vidStreamIsRunning" "', argument " "1"" of type '" "pj::Call const *""'"); 
  }
  arg1 = reinterpret_cast< pj::Call * >(argp1);
  ecode2 = SWIG_AsVal_int(swig_obj[1], &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "Call_vidStreamIsRunning" "', argument " "2"" of type '" "int""'");
  } 
  arg2 = static_cast< int >(val2);
  ecode3 = SWIG_AsVal_int(swig_obj[2], &val3);
  if (!SWIG_IsOK(ecode3)) {
    SWIG_exception_fail(SWIG_ArgError(ecode3), "in method '" "Call_vidStreamIsRunning" "', argument " "3"" of type '" "pjmedia_dir""'");
  } 
  arg3 = static_cast< pjmedia_dir >(val3);
  result = (bool)((pj::Call const *)arg1)->vidStreamIsRunning(arg2,arg3);
  resultobj = SWIG_From_bool(static_cast< bool >(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_Call_vidSetStream(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::Call *arg1 = (pj::Call *) 0 ;
  pjsua_call_vid_strm_op arg2 ;
  pj::CallVidSetStreamParam *arg3 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  int val2 ;
  int ecode2 = 0 ;
  void *argp3 = 0 ;
  int res3 = 0 ;
  PyObject *swig_obj[3] ;
  
  if (!SWIG_Python_UnpackTuple(args, "Call_vidSetStream", 3, 3, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__Call, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "Call_vidSetStream" "', argument " "1"" of type '" "pj::Call *""'"); 
  }
  arg1 = reinterpret_cast< pj::Call * >(argp1);
  ecode2 = SWIG_AsVal_int(swig_obj[1], &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "Call_vidSetStream" "', argument " "2"" of type '" "pjsua_call_vid_strm_op""'");
  } 
  arg2 = static_cast< pjsua_call_vid_strm_op >(val2);
  res3 = SWIG_ConvertPtr(swig_obj[2], &argp3, SWIGTYPE_p_pj__CallVidSetStreamParam,  0  | 0);
  if (!SWIG_IsOK(res3)) {
    SWIG_exception_fail(SWIG_ArgError(res3), "in method '" "Call_vidSetStream" "', argument " "3"" of type '" "pj::CallVidSetStreamParam const &""'"); 
  }
  if (!argp3) {
    SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "Call_vidSetStream" "', argument " "3"" of type '" "pj::CallVidSetStreamParam const &""'"); 
  }
  arg3 = reinterpret_cast< pj::CallVidSetStreamParam * >(argp3);
  try {
    (arg1)->vidSetStream(arg2,(pj::CallVidSetStreamParam const &)*arg3);
  } catch(pj::Error &_e) {
    SWIG_Python_Raise(SWIG_NewPointerObj((new pj::Error(static_cast< const pj::Error& >(_e))),SWIGTYPE_p_pj__Error,SWIG_POINTER_OWN), "pj::Error", SWIGTYPE_p_pj__Error); SWIG_fail;
  }
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_Call_getStreamInfo(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::Call *arg1 = (pj::Call *) 0 ;
  unsigned int arg2 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  unsigned int val2 ;
  int ecode2 = 0 ;
  PyObject *swig_obj[2] ;
  pj::StreamInfo result;
  
  if (!SWIG_Python_UnpackTuple(args, "Call_getStreamInfo", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__Call, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "Call_getStreamInfo" "', argument " "1"" of type '" "pj::Call const *""'"); 
  }
  arg1 = reinterpret_cast< pj::Call * >(argp1);
  ecode2 = SWIG_AsVal_unsigned_SS_int(swig_obj[1], &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "Call_getStreamInfo" "', argument " "2"" of type '" "unsigned int""'");
  } 
  arg2 = static_cast< unsigned int >(val2);
  try {
    result = ((pj::Call const *)arg1)->getStreamInfo(arg2);
  } catch(pj::Error &_e) {
    SWIG_Python_Raise(SWIG_NewPointerObj((new pj::Error(static_cast< const pj::Error& >(_e))),SWIGTYPE_p_pj__Error,SWIG_POINTER_OWN), "pj::Error", SWIGTYPE_p_pj__Error); SWIG_fail;
  }
  resultobj = SWIG_NewPointerObj((new pj::StreamInfo(static_cast< const pj::StreamInfo& >(result))), SWIGTYPE_p_pj__StreamInfo, SWIG_POINTER_OWN |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_Call_getStreamStat(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::Call *arg1 = (pj::Call *) 0 ;
  unsigned int arg2 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  unsigned int val2 ;
  int ecode2 = 0 ;
  PyObject *swig_obj[2] ;
  pj::StreamStat result;
  
  if (!SWIG_Python_UnpackTuple(args, "Call_getStreamStat", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__Call, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "Call_getStreamStat" "', argument " "1"" of type '" "pj::Call const *""'"); 
  }
  arg1 = reinterpret_cast< pj::Call * >(argp1);
  ecode2 = SWIG_AsVal_unsigned_SS_int(swig_obj[1], &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "Call_getStreamStat" "', argument " "2"" of type '" "unsigned int""'");
  } 
  arg2 = static_cast< unsigned int >(val2);
  try {
    result = ((pj::Call const *)arg1)->getStreamStat(arg2);
  } catch(pj::Error &_e) {
    SWIG_Python_Raise(SWIG_NewPointerObj((new pj::Error(static_cast< const pj::Error& >(_e))),SWIGTYPE_p_pj__Error,SWIG_POINTER_OWN), "pj::Error", SWIGTYPE_p_pj__Error); SWIG_fail;
  }
  resultobj = SWIG_NewPointerObj((new pj::StreamStat(static_cast< const pj::StreamStat& >(result))), SWIGTYPE_p_pj__StreamStat, SWIG_POINTER_OWN |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_Call_getMedTransportInfo(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::Call *arg1 = (pj::Call *) 0 ;
  unsigned int arg2 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  unsigned int val2 ;
  int ecode2 = 0 ;
  PyObject *swig_obj[2] ;
  pj::MediaTransportInfo result;
  
  if (!SWIG_Python_UnpackTuple(args, "Call_getMedTransportInfo", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__Call, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "Call_getMedTransportInfo" "', argument " "1"" of type '" "pj::Call const *""'"); 
  }
  arg1 = reinterpret_cast< pj::Call * >(argp1);
  ecode2 = SWIG_AsVal_unsigned_SS_int(swig_obj[1], &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "Call_getMedTransportInfo" "', argument " "2"" of type '" "unsigned int""'");
  } 
  arg2 = static_cast< unsigned int >(val2);
  try {
    result = ((pj::Call const *)arg1)->getMedTransportInfo(arg2);
  } catch(pj::Error &_e) {
    SWIG_Python_Raise(SWIG_NewPointerObj((new pj::Error(static_cast< const pj::Error& >(_e))),SWIGTYPE_p_pj__Error,SWIG_POINTER_OWN), "pj::Error", SWIGTYPE_p_pj__Error); SWIG_fail;
  }
  resultobj = SWIG_NewPointerObj((new pj::MediaTransportInfo(static_cast< const pj::MediaTransportInfo& >(result))), SWIGTYPE_p_pj__MediaTransportInfo, SWIG_POINTER_OWN |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_Call_processMediaUpdate(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::Call *arg1 = (pj::Call *) 0 ;
  pj::OnCallMediaStateParam *arg2 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  void *argp2 = 0 ;
  int res2 = 0 ;
  PyObject *swig_obj[2] ;
  
  if (!SWIG_Python_UnpackTuple(args, "Call_processMediaUpdate", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__Call, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "Call_processMediaUpdate" "', argument " "1"" of type '" "pj::Call *""'"); 
  }
  arg1 = reinterpret_cast< pj::Call * >(argp1);
  res2 = SWIG_ConvertPtr(swig_obj[1], &argp2, SWIGTYPE_p_pj__OnCallMediaStateParam,  0 );
  if (!SWIG_IsOK(res2)) {
    SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "Call_processMediaUpdate" "', argument " "2"" of type '" "pj::OnCallMediaStateParam &""'"); 
  }
  if (!argp2) {
    SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "Call_processMediaUpdate" "', argument " "2"" of type '" "pj::OnCallMediaStateParam &""'"); 
  }
  arg2 = reinterpret_cast< pj::OnCallMediaStateParam * >(argp2);
  (arg1)->processMediaUpdate(*arg2);
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_Call_processStateChange(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::Call *arg1 = (pj::Call *) 0 ;
  pj::OnCallStateParam *arg2 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  void *argp2 = 0 ;
  int res2 = 0 ;
  PyObject *swig_obj[2] ;
  
  if (!SWIG_Python_UnpackTuple(args, "Call_processStateChange", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__Call, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "Call_processStateChange" "', argument " "1"" of type '" "pj::Call *""'"); 
  }
  arg1 = reinterpret_cast< pj::Call * >(argp1);
  res2 = SWIG_ConvertPtr(swig_obj[1], &argp2, SWIGTYPE_p_pj__OnCallStateParam,  0 );
  if (!SWIG_IsOK(res2)) {
    SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "Call_processStateChange" "', argument " "2"" of type '" "pj::OnCallStateParam &""'"); 
  }
  if (!argp2) {
    SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "Call_processStateChange" "', argument " "2"" of type '" "pj::OnCallStateParam &""'"); 
  }
  arg2 = reinterpret_cast< pj::OnCallStateParam * >(argp2);
  (arg1)->processStateChange(*arg2);
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_Call_onCallState(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::Call *arg1 = (pj::Call *) 0 ;
  pj::OnCallStateParam *arg2 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  void *argp2 = 0 ;
  int res2 = 0 ;
  PyObject *swig_obj[2] ;
  Swig::Director *director = 0;
  bool upcall = false;
  
  if (!SWIG_Python_UnpackTuple(args, "Call_onCallState", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__Call, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "Call_onCallState" "', argument " "1"" of type '" "pj::Call *""'"); 
  }
  arg1 = reinterpret_cast< pj::Call * >(argp1);
  res2 = SWIG_ConvertPtr(swig_obj[1], &argp2, SWIGTYPE_p_pj__OnCallStateParam,  0 );
  if (!SWIG_IsOK(res2)) {
    SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "Call_onCallState" "', argument " "2"" of type '" "pj::OnCallStateParam &""'"); 
  }
  if (!argp2) {
    SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "Call_onCallState" "', argument " "2"" of type '" "pj::OnCallStateParam &""'"); 
  }
  arg2 = reinterpret_cast< pj::OnCallStateParam * >(argp2);
  director = SWIG_DIRECTOR_CAST(arg1);
  upcall = (director && (director->swig_get_self()==swig_obj[0]));
  try {
    if (upcall) {
      (arg1)->pj::Call::onCallState(*arg2);
    } else {
      (arg1)->onCallState(*arg2);
    }
  } catch (Swig::DirectorException&) {
    SWIG_fail;
  }
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_Call_onCallTsxState(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::Call *arg1 = (pj::Call *) 0 ;
  pj::OnCallTsxStateParam *arg2 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  void *argp2 = 0 ;
  int res2 = 0 ;
  PyObject *swig_obj[2] ;
  Swig::Director *director = 0;
  bool upcall = false;
  
  if (!SWIG_Python_UnpackTuple(args, "Call_onCallTsxState", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__Call, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "Call_onCallTsxState" "', argument " "1"" of type '" "pj::Call *""'"); 
  }
  arg1 = reinterpret_cast< pj::Call * >(argp1);
  res2 = SWIG_ConvertPtr(swig_obj[1], &argp2, SWIGTYPE_p_pj__OnCallTsxStateParam,  0 );
  if (!SWIG_IsOK(res2)) {
    SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "Call_onCallTsxState" "', argument " "2"" of type '" "pj::OnCallTsxStateParam &""'"); 
  }
  if (!argp2) {
    SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "Call_onCallTsxState" "', argument " "2"" of type '" "pj::OnCallTsxStateParam &""'"); 
  }
  arg2 = reinterpret_cast< pj::OnCallTsxStateParam * >(argp2);
  director = SWIG_DIRECTOR_CAST(arg1);
  upcall = (director && (director->swig_get_self()==swig_obj[0]));
  try {
    if (upcall) {
      (arg1)->pj::Call::onCallTsxState(*arg2);
    } else {
      (arg1)->onCallTsxState(*arg2);
    }
  } catch (Swig::DirectorException&) {
    SWIG_fail;
  }
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_Call_onCallMediaState(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::Call *arg1 = (pj::Call *) 0 ;
  pj::OnCallMediaStateParam *arg2 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  void *argp2 = 0 ;
  int res2 = 0 ;
  PyObject *swig_obj[2] ;
  Swig::Director *director = 0;
  bool upcall = false;
  
  if (!SWIG_Python_UnpackTuple(args, "Call_onCallMediaState", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__Call, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "Call_onCallMediaState" "', argument " "1"" of type '" "pj::Call *""'"); 
  }
  arg1 = reinterpret_cast< pj::Call * >(argp1);
  res2 = SWIG_ConvertPtr(swig_obj[1], &argp2, SWIGTYPE_p_pj__OnCallMediaStateParam,  0 );
  if (!SWIG_IsOK(res2)) {
    SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "Call_onCallMediaState" "', argument " "2"" of type '" "pj::OnCallMediaStateParam &""'"); 
  }
  if (!argp2) {
    SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "Call_onCallMediaState" "', argument " "2"" of type '" "pj::OnCallMediaStateParam &""'"); 
  }
  arg2 = reinterpret_cast< pj::OnCallMediaStateParam * >(argp2);
  director = SWIG_DIRECTOR_CAST(arg1);
  upcall = (director && (director->swig_get_self()==swig_obj[0]));
  try {
    if (upcall) {
      (arg1)->pj::Call::onCallMediaState(*arg2);
    } else {
      (arg1)->onCallMediaState(*arg2);
    }
  } catch (Swig::DirectorException&) {
    SWIG_fail;
  }
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_Call_onCallSdpCreated(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::Call *arg1 = (pj::Call *) 0 ;
  pj::OnCallSdpCreatedParam *arg2 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  void *argp2 = 0 ;
  int res2 = 0 ;
  PyObject *swig_obj[2] ;
  Swig::Director *director = 0;
  bool upcall = false;
  
  if (!SWIG_Python_UnpackTuple(args, "Call_onCallSdpCreated", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__Call, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "Call_onCallSdpCreated" "', argument " "1"" of type '" "pj::Call *""'"); 
  }
  arg1 = reinterpret_cast< pj::Call * >(argp1);
  res2 = SWIG_ConvertPtr(swig_obj[1], &argp2, SWIGTYPE_p_pj__OnCallSdpCreatedParam,  0 );
  if (!SWIG_IsOK(res2)) {
    SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "Call_onCallSdpCreated" "', argument " "2"" of type '" "pj::OnCallSdpCreatedParam &""'"); 
  }
  if (!argp2) {
    SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "Call_onCallSdpCreated" "', argument " "2"" of type '" "pj::OnCallSdpCreatedParam &""'"); 
  }
  arg2 = reinterpret_cast< pj::OnCallSdpCreatedParam * >(argp2);
  director = SWIG_DIRECTOR_CAST(arg1);
  upcall = (director && (director->swig_get_self()==swig_obj[0]));
  try {
    if (upcall) {
      (arg1)->pj::Call::onCallSdpCreated(*arg2);
    } else {
      (arg1)->onCallSdpCreated(*arg2);
    }
  } catch (Swig::DirectorException&) {
    SWIG_fail;
  }
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_Call_onStreamPreCreate(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::Call *arg1 = (pj::Call *) 0 ;
  pj::OnStreamPreCreateParam *arg2 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  void *argp2 = 0 ;
  int res2 = 0 ;
  PyObject *swig_obj[2] ;
  Swig::Director *director = 0;
  bool upcall = false;
  
  if (!SWIG_Python_UnpackTuple(args, "Call_onStreamPreCreate", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__Call, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "Call_onStreamPreCreate" "', argument " "1"" of type '" "pj::Call *""'"); 
  }
  arg1 = reinterpret_cast< pj::Call * >(argp1);
  res2 = SWIG_ConvertPtr(swig_obj[1], &argp2, SWIGTYPE_p_pj__OnStreamPreCreateParam,  0 );
  if (!SWIG_IsOK(res2)) {
    SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "Call_onStreamPreCreate" "', argument " "2"" of type '" "pj::OnStreamPreCreateParam &""'"); 
  }
  if (!argp2) {
    SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "Call_onStreamPreCreate" "', argument " "2"" of type '" "pj::OnStreamPreCreateParam &""'"); 
  }
  arg2 = reinterpret_cast< pj::OnStreamPreCreateParam * >(argp2);
  director = SWIG_DIRECTOR_CAST(arg1);
  upcall = (director && (director->swig_get_self()==swig_obj[0]));
  try {
    if (upcall) {
      (arg1)->pj::Call::onStreamPreCreate(*arg2);
    } else {
      (arg1)->onStreamPreCreate(*arg2);
    }
  } catch (Swig::DirectorException&) {
    SWIG_fail;
  }
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_Call_onStreamCreated(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::Call *arg1 = (pj::Call *) 0 ;
  pj::OnStreamCreatedParam *arg2 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  void *argp2 = 0 ;
  int res2 = 0 ;
  PyObject *swig_obj[2] ;
  Swig::Director *director = 0;
  bool upcall = false;
  
  if (!SWIG_Python_UnpackTuple(args, "Call_onStreamCreated", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__Call, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "Call_onStreamCreated" "', argument " "1"" of type '" "pj::Call *""'"); 
  }
  arg1 = reinterpret_cast< pj::Call * >(argp1);
  res2 = SWIG_ConvertPtr(swig_obj[1], &argp2, SWIGTYPE_p_pj__OnStreamCreatedParam,  0 );
  if (!SWIG_IsOK(res2)) {
    SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "Call_onStreamCreated" "', argument " "2"" of type '" "pj::OnStreamCreatedParam &""'"); 
  }
  if (!argp2) {
    SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "Call_onStreamCreated" "', argument " "2"" of type '" "pj::OnStreamCreatedParam &""'"); 
  }
  arg2 = reinterpret_cast< pj::OnStreamCreatedParam * >(argp2);
  director = SWIG_DIRECTOR_CAST(arg1);
  upcall = (director && (director->swig_get_self()==swig_obj[0]));
  try {
    if (upcall) {
      (arg1)->pj::Call::onStreamCreated(*arg2);
    } else {
      (arg1)->onStreamCreated(*arg2);
    }
  } catch (Swig::DirectorException&) {
    SWIG_fail;
  }
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_Call_onStreamDestroyed(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::Call *arg1 = (pj::Call *) 0 ;
  pj::OnStreamDestroyedParam *arg2 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  void *argp2 = 0 ;
  int res2 = 0 ;
  PyObject *swig_obj[2] ;
  Swig::Director *director = 0;
  bool upcall = false;
  
  if (!SWIG_Python_UnpackTuple(args, "Call_onStreamDestroyed", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__Call, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "Call_onStreamDestroyed" "', argument " "1"" of type '" "pj::Call *""'"); 
  }
  arg1 = reinterpret_cast< pj::Call * >(argp1);
  res2 = SWIG_ConvertPtr(swig_obj[1], &argp2, SWIGTYPE_p_pj__OnStreamDestroyedParam,  0 );
  if (!SWIG_IsOK(res2)) {
    SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "Call_onStreamDestroyed" "', argument " "2"" of type '" "pj::OnStreamDestroyedParam &""'"); 
  }
  if (!argp2) {
    SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "Call_onStreamDestroyed" "', argument " "2"" of type '" "pj::OnStreamDestroyedParam &""'"); 
  }
  arg2 = reinterpret_cast< pj::OnStreamDestroyedParam * >(argp2);
  director = SWIG_DIRECTOR_CAST(arg1);
  upcall = (director && (director->swig_get_self()==swig_obj[0]));
  try {
    if (upcall) {
      (arg1)->pj::Call::onStreamDestroyed(*arg2);
    } else {
      (arg1)->onStreamDestroyed(*arg2);
    }
  } catch (Swig::DirectorException&) {
    SWIG_fail;
  }
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_Call_onDtmfDigit(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::Call *arg1 = (pj::Call *) 0 ;
  pj::OnDtmfDigitParam *arg2 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  void *argp2 = 0 ;
  int res2 = 0 ;
  PyObject *swig_obj[2] ;
  Swig::Director *director = 0;
  bool upcall = false;
  
  if (!SWIG_Python_UnpackTuple(args, "Call_onDtmfDigit", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__Call, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "Call_onDtmfDigit" "', argument " "1"" of type '" "pj::Call *""'"); 
  }
  arg1 = reinterpret_cast< pj::Call * >(argp1);
  res2 = SWIG_ConvertPtr(swig_obj[1], &argp2, SWIGTYPE_p_pj__OnDtmfDigitParam,  0 );
  if (!SWIG_IsOK(res2)) {
    SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "Call_onDtmfDigit" "', argument " "2"" of type '" "pj::OnDtmfDigitParam &""'"); 
  }
  if (!argp2) {
    SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "Call_onDtmfDigit" "', argument " "2"" of type '" "pj::OnDtmfDigitParam &""'"); 
  }
  arg2 = reinterpret_cast< pj::OnDtmfDigitParam * >(argp2);
  director = SWIG_DIRECTOR_CAST(arg1);
  upcall = (director && (director->swig_get_self()==swig_obj[0]));
  try {
    if (upcall) {
      (arg1)->pj::Call::onDtmfDigit(*arg2);
    } else {
      (arg1)->onDtmfDigit(*arg2);
    }
  } catch (Swig::DirectorException&) {
    SWIG_fail;
  }
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_Call_onDtmfEvent(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::Call *arg1 = (pj::Call *) 0 ;
  pj::OnDtmfEventParam *arg2 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  void *argp2 = 0 ;
  int res2 = 0 ;
  PyObject *swig_obj[2] ;
  Swig::Director *director = 0;
  bool upcall = false;
  
  if (!SWIG_Python_UnpackTuple(args, "Call_onDtmfEvent", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__Call, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "Call_onDtmfEvent" "', argument " "1"" of type '" "pj::Call *""'"); 
  }
  arg1 = reinterpret_cast< pj::Call * >(argp1);
  res2 = SWIG_ConvertPtr(swig_obj[1], &argp2, SWIGTYPE_p_pj__OnDtmfEventParam,  0 );
  if (!SWIG_IsOK(res2)) {
    SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "Call_onDtmfEvent" "', argument " "2"" of type '" "pj::OnDtmfEventParam &""'"); 
  }
  if (!argp2) {
    SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "Call_onDtmfEvent" "', argument " "2"" of type '" "pj::OnDtmfEventParam &""'"); 
  }
  arg2 = reinterpret_cast< pj::OnDtmfEventParam * >(argp2);
  director = SWIG_DIRECTOR_CAST(arg1);
  upcall = (director && (director->swig_get_self()==swig_obj[0]));
  try {
    if (upcall) {
      (arg1)->pj::Call::onDtmfEvent(*arg2);
    } else {
      (arg1)->onDtmfEvent(*arg2);
    }
  } catch (Swig::DirectorException&) {
    SWIG_fail;
  }
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_Call_onCallTransferRequest(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::Call *arg1 = (pj::Call *) 0 ;
  pj::OnCallTransferRequestParam *arg2 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  void *argp2 = 0 ;
  int res2 = 0 ;
  PyObject *swig_obj[2] ;
  Swig::Director *director = 0;
  bool upcall = false;
  
  if (!SWIG_Python_UnpackTuple(args, "Call_onCallTransferRequest", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__Call, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "Call_onCallTransferRequest" "', argument " "1"" of type '" "pj::Call *""'"); 
  }
  arg1 = reinterpret_cast< pj::Call * >(argp1);
  res2 = SWIG_ConvertPtr(swig_obj[1], &argp2, SWIGTYPE_p_pj__OnCallTransferRequestParam,  0 );
  if (!SWIG_IsOK(res2)) {
    SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "Call_onCallTransferRequest" "', argument " "2"" of type '" "pj::OnCallTransferRequestParam &""'"); 
  }
  if (!argp2) {
    SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "Call_onCallTransferRequest" "', argument " "2"" of type '" "pj::OnCallTransferRequestParam &""'"); 
  }
  arg2 = reinterpret_cast< pj::OnCallTransferRequestParam * >(argp2);
  director = SWIG_DIRECTOR_CAST(arg1);
  upcall = (director && (director->swig_get_self()==swig_obj[0]));
  try {
    if (upcall) {
      (arg1)->pj::Call::onCallTransferRequest(*arg2);
    } else {
      (arg1)->onCallTransferRequest(*arg2);
    }
  } catch (Swig::DirectorException&) {
    SWIG_fail;
  }
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_Call_onCallTransferStatus(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::Call *arg1 = (pj::Call *) 0 ;
  pj::OnCallTransferStatusParam *arg2 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  void *argp2 = 0 ;
  int res2 = 0 ;
  PyObject *swig_obj[2] ;
  Swig::Director *director = 0;
  bool upcall = false;
  
  if (!SWIG_Python_UnpackTuple(args, "Call_onCallTransferStatus", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__Call, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "Call_onCallTransferStatus" "', argument " "1"" of type '" "pj::Call *""'"); 
  }
  arg1 = reinterpret_cast< pj::Call * >(argp1);
  res2 = SWIG_ConvertPtr(swig_obj[1], &argp2, SWIGTYPE_p_pj__OnCallTransferStatusParam,  0 );
  if (!SWIG_IsOK(res2)) {
    SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "Call_onCallTransferStatus" "', argument " "2"" of type '" "pj::OnCallTransferStatusParam &""'"); 
  }
  if (!argp2) {
    SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "Call_onCallTransferStatus" "', argument " "2"" of type '" "pj::OnCallTransferStatusParam &""'"); 
  }
  arg2 = reinterpret_cast< pj::OnCallTransferStatusParam * >(argp2);
  director = SWIG_DIRECTOR_CAST(arg1);
  upcall = (director && (director->swig_get_self()==swig_obj[0]));
  try {
    if (upcall) {
      (arg1)->pj::Call::onCallTransferStatus(*arg2);
    } else {
      (arg1)->onCallTransferStatus(*arg2);
    }
  } catch (Swig::DirectorException&) {
    SWIG_fail;
  }
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_Call_onCallReplaceRequest(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::Call *arg1 = (pj::Call *) 0 ;
  pj::OnCallReplaceRequestParam *arg2 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  void *argp2 = 0 ;
  int res2 = 0 ;
  PyObject *swig_obj[2] ;
  Swig::Director *director = 0;
  bool upcall = false;
  
  if (!SWIG_Python_UnpackTuple(args, "Call_onCallReplaceRequest", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__Call, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "Call_onCallReplaceRequest" "', argument " "1"" of type '" "pj::Call *""'"); 
  }
  arg1 = reinterpret_cast< pj::Call * >(argp1);
  res2 = SWIG_ConvertPtr(swig_obj[1], &argp2, SWIGTYPE_p_pj__OnCallReplaceRequestParam,  0 );
  if (!SWIG_IsOK(res2)) {
    SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "Call_onCallReplaceRequest" "', argument " "2"" of type '" "pj::OnCallReplaceRequestParam &""'"); 
  }
  if (!argp2) {
    SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "Call_onCallReplaceRequest" "', argument " "2"" of type '" "pj::OnCallReplaceRequestParam &""'"); 
  }
  arg2 = reinterpret_cast< pj::OnCallReplaceRequestParam * >(argp2);
  director = SWIG_DIRECTOR_CAST(arg1);
  upcall = (director && (director->swig_get_self()==swig_obj[0]));
  try {
    if (upcall) {
      (arg1)->pj::Call::onCallReplaceRequest(*arg2);
    } else {
      (arg1)->onCallReplaceRequest(*arg2);
    }
  } catch (Swig::DirectorException&) {
    SWIG_fail;
  }
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_Call_onCallReplaced(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::Call *arg1 = (pj::Call *) 0 ;
  pj::OnCallReplacedParam *arg2 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  void *argp2 = 0 ;
  int res2 = 0 ;
  PyObject *swig_obj[2] ;
  Swig::Director *director = 0;
  bool upcall = false;
  
  if (!SWIG_Python_UnpackTuple(args, "Call_onCallReplaced", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__Call, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "Call_onCallReplaced" "', argument " "1"" of type '" "pj::Call *""'"); 
  }
  arg1 = reinterpret_cast< pj::Call * >(argp1);
  res2 = SWIG_ConvertPtr(swig_obj[1], &argp2, SWIGTYPE_p_pj__OnCallReplacedParam,  0 );
  if (!SWIG_IsOK(res2)) {
    SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "Call_onCallReplaced" "', argument " "2"" of type '" "pj::OnCallReplacedParam &""'"); 
  }
  if (!argp2) {
    SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "Call_onCallReplaced" "', argument " "2"" of type '" "pj::OnCallReplacedParam &""'"); 
  }
  arg2 = reinterpret_cast< pj::OnCallReplacedParam * >(argp2);
  director = SWIG_DIRECTOR_CAST(arg1);
  upcall = (director && (director->swig_get_self()==swig_obj[0]));
  try {
    if (upcall) {
      (arg1)->pj::Call::onCallReplaced(*arg2);
    } else {
      (arg1)->onCallReplaced(*arg2);
    }
  } catch (Swig::DirectorException&) {
    SWIG_fail;
  }
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_Call_onCallRxOffer(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::Call *arg1 = (pj::Call *) 0 ;
  pj::OnCallRxOfferParam *arg2 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  void *argp2 = 0 ;
  int res2 = 0 ;
  PyObject *swig_obj[2] ;
  Swig::Director *director = 0;
  bool upcall = false;
  
  if (!SWIG_Python_UnpackTuple(args, "Call_onCallRxOffer", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__Call, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "Call_onCallRxOffer" "', argument " "1"" of type '" "pj::Call *""'"); 
  }
  arg1 = reinterpret_cast< pj::Call * >(argp1);
  res2 = SWIG_ConvertPtr(swig_obj[1], &argp2, SWIGTYPE_p_pj__OnCallRxOfferParam,  0 );
  if (!SWIG_IsOK(res2)) {
    SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "Call_onCallRxOffer" "', argument " "2"" of type '" "pj::OnCallRxOfferParam &""'"); 
  }
  if (!argp2) {
    SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "Call_onCallRxOffer" "', argument " "2"" of type '" "pj::OnCallRxOfferParam &""'"); 
  }
  arg2 = reinterpret_cast< pj::OnCallRxOfferParam * >(argp2);
  director = SWIG_DIRECTOR_CAST(arg1);
  upcall = (director && (director->swig_get_self()==swig_obj[0]));
  try {
    if (upcall) {
      (arg1)->pj::Call::onCallRxOffer(*arg2);
    } else {
      (arg1)->onCallRxOffer(*arg2);
    }
  } catch (Swig::DirectorException&) {
    SWIG_fail;
  }
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_Call_onCallRxReinvite(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::Call *arg1 = (pj::Call *) 0 ;
  pj::OnCallRxReinviteParam *arg2 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  void *argp2 = 0 ;
  int res2 = 0 ;
  PyObject *swig_obj[2] ;
  Swig::Director *director = 0;
  bool upcall = false;
  
  if (!SWIG_Python_UnpackTuple(args, "Call_onCallRxReinvite", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__Call, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "Call_onCallRxReinvite" "', argument " "1"" of type '" "pj::Call *""'"); 
  }
  arg1 = reinterpret_cast< pj::Call * >(argp1);
  res2 = SWIG_ConvertPtr(swig_obj[1], &argp2, SWIGTYPE_p_pj__OnCallRxReinviteParam,  0 );
  if (!SWIG_IsOK(res2)) {
    SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "Call_onCallRxReinvite" "', argument " "2"" of type '" "pj::OnCallRxReinviteParam &""'"); 
  }
  if (!argp2) {
    SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "Call_onCallRxReinvite" "', argument " "2"" of type '" "pj::OnCallRxReinviteParam &""'"); 
  }
  arg2 = reinterpret_cast< pj::OnCallRxReinviteParam * >(argp2);
  director = SWIG_DIRECTOR_CAST(arg1);
  upcall = (director && (director->swig_get_self()==swig_obj[0]));
  try {
    if (upcall) {
      (arg1)->pj::Call::onCallRxReinvite(*arg2);
    } else {
      (arg1)->onCallRxReinvite(*arg2);
    }
  } catch (Swig::DirectorException&) {
    SWIG_fail;
  }
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_Call_onCallTxOffer(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::Call *arg1 = (pj::Call *) 0 ;
  pj::OnCallTxOfferParam *arg2 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  void *argp2 = 0 ;
  int res2 = 0 ;
  PyObject *swig_obj[2] ;
  Swig::Director *director = 0;
  bool upcall = false;
  
  if (!SWIG_Python_UnpackTuple(args, "Call_onCallTxOffer", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__Call, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "Call_onCallTxOffer" "', argument " "1"" of type '" "pj::Call *""'"); 
  }
  arg1 = reinterpret_cast< pj::Call * >(argp1);
  res2 = SWIG_ConvertPtr(swig_obj[1], &argp2, SWIGTYPE_p_pj__OnCallTxOfferParam,  0 );
  if (!SWIG_IsOK(res2)) {
    SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "Call_onCallTxOffer" "', argument " "2"" of type '" "pj::OnCallTxOfferParam &""'"); 
  }
  if (!argp2) {
    SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "Call_onCallTxOffer" "', argument " "2"" of type '" "pj::OnCallTxOfferParam &""'"); 
  }
  arg2 = reinterpret_cast< pj::OnCallTxOfferParam * >(argp2);
  director = SWIG_DIRECTOR_CAST(arg1);
  upcall = (director && (director->swig_get_self()==swig_obj[0]));
  try {
    if (upcall) {
      (arg1)->pj::Call::onCallTxOffer(*arg2);
    } else {
      (arg1)->onCallTxOffer(*arg2);
    }
  } catch (Swig::DirectorException&) {
    SWIG_fail;
  }
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_Call_onInstantMessage(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::Call *arg1 = (pj::Call *) 0 ;
  pj::OnInstantMessageParam *arg2 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  void *argp2 = 0 ;
  int res2 = 0 ;
  PyObject *swig_obj[2] ;
  Swig::Director *director = 0;
  bool upcall = false;
  
  if (!SWIG_Python_UnpackTuple(args, "Call_onInstantMessage", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__Call, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "Call_onInstantMessage" "', argument " "1"" of type '" "pj::Call *""'"); 
  }
  arg1 = reinterpret_cast< pj::Call * >(argp1);
  res2 = SWIG_ConvertPtr(swig_obj[1], &argp2, SWIGTYPE_p_pj__OnInstantMessageParam,  0 );
  if (!SWIG_IsOK(res2)) {
    SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "Call_onInstantMessage" "', argument " "2"" of type '" "pj::OnInstantMessageParam &""'"); 
  }
  if (!argp2) {
    SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "Call_onInstantMessage" "', argument " "2"" of type '" "pj::OnInstantMessageParam &""'"); 
  }
  arg2 = reinterpret_cast< pj::OnInstantMessageParam * >(argp2);
  director = SWIG_DIRECTOR_CAST(arg1);
  upcall = (director && (director->swig_get_self()==swig_obj[0]));
  try {
    if (upcall) {
      (arg1)->pj::Call::onInstantMessage(*arg2);
    } else {
      (arg1)->onInstantMessage(*arg2);
    }
  } catch (Swig::DirectorException&) {
    SWIG_fail;
  }
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_Call_onInstantMessageStatus(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::Call *arg1 = (pj::Call *) 0 ;
  pj::OnInstantMessageStatusParam *arg2 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  void *argp2 = 0 ;
  int res2 = 0 ;
  PyObject *swig_obj[2] ;
  Swig::Director *director = 0;
  bool upcall = false;
  
  if (!SWIG_Python_UnpackTuple(args, "Call_onInstantMessageStatus", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__Call, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "Call_onInstantMessageStatus" "', argument " "1"" of type '" "pj::Call *""'"); 
  }
  arg1 = reinterpret_cast< pj::Call * >(argp1);
  res2 = SWIG_ConvertPtr(swig_obj[1], &argp2, SWIGTYPE_p_pj__OnInstantMessageStatusParam,  0 );
  if (!SWIG_IsOK(res2)) {
    SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "Call_onInstantMessageStatus" "', argument " "2"" of type '" "pj::OnInstantMessageStatusParam &""'"); 
  }
  if (!argp2) {
    SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "Call_onInstantMessageStatus" "', argument " "2"" of type '" "pj::OnInstantMessageStatusParam &""'"); 
  }
  arg2 = reinterpret_cast< pj::OnInstantMessageStatusParam * >(argp2);
  director = SWIG_DIRECTOR_CAST(arg1);
  upcall = (director && (director->swig_get_self()==swig_obj[0]));
  try {
    if (upcall) {
      (arg1)->pj::Call::onInstantMessageStatus(*arg2);
    } else {
      (arg1)->onInstantMessageStatus(*arg2);
    }
  } catch (Swig::DirectorException&) {
    SWIG_fail;
  }
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_Call_onTypingIndication(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::Call *arg1 = (pj::Call *) 0 ;
  pj::OnTypingIndicationParam *arg2 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  void *argp2 = 0 ;
  int res2 = 0 ;
  PyObject *swig_obj[2] ;
  Swig::Director *director = 0;
  bool upcall = false;
  
  if (!SWIG_Python_UnpackTuple(args, "Call_onTypingIndication", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__Call, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "Call_onTypingIndication" "', argument " "1"" of type '" "pj::Call *""'"); 
  }
  arg1 = reinterpret_cast< pj::Call * >(argp1);
  res2 = SWIG_ConvertPtr(swig_obj[1], &argp2, SWIGTYPE_p_pj__OnTypingIndicationParam,  0 );
  if (!SWIG_IsOK(res2)) {
    SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "Call_onTypingIndication" "', argument " "2"" of type '" "pj::OnTypingIndicationParam &""'"); 
  }
  if (!argp2) {
    SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "Call_onTypingIndication" "', argument " "2"" of type '" "pj::OnTypingIndicationParam &""'"); 
  }
  arg2 = reinterpret_cast< pj::OnTypingIndicationParam * >(argp2);
  director = SWIG_DIRECTOR_CAST(arg1);
  upcall = (director && (director->swig_get_self()==swig_obj[0]));
  try {
    if (upcall) {
      (arg1)->pj::Call::onTypingIndication(*arg2);
    } else {
      (arg1)->onTypingIndication(*arg2);
    }
  } catch (Swig::DirectorException&) {
    SWIG_fail;
  }
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_Call_onCallRedirected(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::Call *arg1 = (pj::Call *) 0 ;
  pj::OnCallRedirectedParam *arg2 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  void *argp2 = 0 ;
  int res2 = 0 ;
  PyObject *swig_obj[2] ;
  Swig::Director *director = 0;
  bool upcall = false;
  pjsip_redirect_op result;
  
  if (!SWIG_Python_UnpackTuple(args, "Call_onCallRedirected", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__Call, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "Call_onCallRedirected" "', argument " "1"" of type '" "pj::Call *""'"); 
  }
  arg1 = reinterpret_cast< pj::Call * >(argp1);
  res2 = SWIG_ConvertPtr(swig_obj[1], &argp2, SWIGTYPE_p_pj__OnCallRedirectedParam,  0 );
  if (!SWIG_IsOK(res2)) {
    SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "Call_onCallRedirected" "', argument " "2"" of type '" "pj::OnCallRedirectedParam &""'"); 
  }
  if (!argp2) {
    SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "Call_onCallRedirected" "', argument " "2"" of type '" "pj::OnCallRedirectedParam &""'"); 
  }
  arg2 = reinterpret_cast< pj::OnCallRedirectedParam * >(argp2);
  director = SWIG_DIRECTOR_CAST(arg1);
  upcall = (director && (director->swig_get_self()==swig_obj[0]));
  try {
    if (upcall) {
      result = (pjsip_redirect_op)(arg1)->pj::Call::onCallRedirected(*arg2);
    } else {
      result = (pjsip_redirect_op)(arg1)->onCallRedirected(*arg2);
    }
  } catch (Swig::DirectorException&) {
    SWIG_fail;
  }
  resultobj = SWIG_From_int(static_cast< int >(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_Call_onCallMediaTransportState(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::Call *arg1 = (pj::Call *) 0 ;
  pj::OnCallMediaTransportStateParam *arg2 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  void *argp2 = 0 ;
  int res2 = 0 ;
  PyObject *swig_obj[2] ;
  Swig::Director *director = 0;
  bool upcall = false;
  
  if (!SWIG_Python_UnpackTuple(args, "Call_onCallMediaTransportState", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__Call, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "Call_onCallMediaTransportState" "', argument " "1"" of type '" "pj::Call *""'"); 
  }
  arg1 = reinterpret_cast< pj::Call * >(argp1);
  res2 = SWIG_ConvertPtr(swig_obj[1], &argp2, SWIGTYPE_p_pj__OnCallMediaTransportStateParam,  0 );
  if (!SWIG_IsOK(res2)) {
    SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "Call_onCallMediaTransportState" "', argument " "2"" of type '" "pj::OnCallMediaTransportStateParam &""'"); 
  }
  if (!argp2) {
    SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "Call_onCallMediaTransportState" "', argument " "2"" of type '" "pj::OnCallMediaTransportStateParam &""'"); 
  }
  arg2 = reinterpret_cast< pj::OnCallMediaTransportStateParam * >(argp2);
  director = SWIG_DIRECTOR_CAST(arg1);
  upcall = (director && (director->swig_get_self()==swig_obj[0]));
  try {
    if (upcall) {
      (arg1)->pj::Call::onCallMediaTransportState(*arg2);
    } else {
      (arg1)->onCallMediaTransportState(*arg2);
    }
  } catch (Swig::DirectorException&) {
    SWIG_fail;
  }
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_Call_onCallMediaEvent(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::Call *arg1 = (pj::Call *) 0 ;
  pj::OnCallMediaEventParam *arg2 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  void *argp2 = 0 ;
  int res2 = 0 ;
  PyObject *swig_obj[2] ;
  Swig::Director *director = 0;
  bool upcall = false;
  
  if (!SWIG_Python_UnpackTuple(args, "Call_onCallMediaEvent", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__Call, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "Call_onCallMediaEvent" "', argument " "1"" of type '" "pj::Call *""'"); 
  }
  arg1 = reinterpret_cast< pj::Call * >(argp1);
  res2 = SWIG_ConvertPtr(swig_obj[1], &argp2, SWIGTYPE_p_pj__OnCallMediaEventParam,  0 );
  if (!SWIG_IsOK(res2)) {
    SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "Call_onCallMediaEvent" "', argument " "2"" of type '" "pj::OnCallMediaEventParam &""'"); 
  }
  if (!argp2) {
    SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "Call_onCallMediaEvent" "', argument " "2"" of type '" "pj::OnCallMediaEventParam &""'"); 
  }
  arg2 = reinterpret_cast< pj::OnCallMediaEventParam * >(argp2);
  director = SWIG_DIRECTOR_CAST(arg1);
  upcall = (director && (director->swig_get_self()==swig_obj[0]));
  try {
    if (upcall) {
      (arg1)->pj::Call::onCallMediaEvent(*arg2);
    } else {
      (arg1)->onCallMediaEvent(*arg2);
    }
  } catch (Swig::DirectorException&) {
    SWIG_fail;
  }
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_Call_onCreateMediaTransport(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::Call *arg1 = (pj::Call *) 0 ;
  pj::OnCreateMediaTransportParam *arg2 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  void *argp2 = 0 ;
  int res2 = 0 ;
  PyObject *swig_obj[2] ;
  Swig::Director *director = 0;
  bool upcall = false;
  
  if (!SWIG_Python_UnpackTuple(args, "Call_onCreateMediaTransport", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__Call, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "Call_onCreateMediaTransport" "', argument " "1"" of type '" "pj::Call *""'"); 
  }
  arg1 = reinterpret_cast< pj::Call * >(argp1);
  res2 = SWIG_ConvertPtr(swig_obj[1], &argp2, SWIGTYPE_p_pj__OnCreateMediaTransportParam,  0 );
  if (!SWIG_IsOK(res2)) {
    SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "Call_onCreateMediaTransport" "', argument " "2"" of type '" "pj::OnCreateMediaTransportParam &""'"); 
  }
  if (!argp2) {
    SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "Call_onCreateMediaTransport" "', argument " "2"" of type '" "pj::OnCreateMediaTransportParam &""'"); 
  }
  arg2 = reinterpret_cast< pj::OnCreateMediaTransportParam * >(argp2);
  director = SWIG_DIRECTOR_CAST(arg1);
  upcall = (director && (director->swig_get_self()==swig_obj[0]));
  try {
    if (upcall) {
      (arg1)->pj::Call::onCreateMediaTransport(*arg2);
    } else {
      (arg1)->onCreateMediaTransport(*arg2);
    }
  } catch (Swig::DirectorException&) {
    SWIG_fail;
  }
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_Call_onCreateMediaTransportSrtp(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::Call *arg1 = (pj::Call *) 0 ;
  pj::OnCreateMediaTransportSrtpParam *arg2 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  void *argp2 = 0 ;
  int res2 = 0 ;
  PyObject *swig_obj[2] ;
  Swig::Director *director = 0;
  bool upcall = false;
  
  if (!SWIG_Python_UnpackTuple(args, "Call_onCreateMediaTransportSrtp", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__Call, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "Call_onCreateMediaTransportSrtp" "', argument " "1"" of type '" "pj::Call *""'"); 
  }
  arg1 = reinterpret_cast< pj::Call * >(argp1);
  res2 = SWIG_ConvertPtr(swig_obj[1], &argp2, SWIGTYPE_p_pj__OnCreateMediaTransportSrtpParam,  0 );
  if (!SWIG_IsOK(res2)) {
    SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "Call_onCreateMediaTransportSrtp" "', argument " "2"" of type '" "pj::OnCreateMediaTransportSrtpParam &""'"); 
  }
  if (!argp2) {
    SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "Call_onCreateMediaTransportSrtp" "', argument " "2"" of type '" "pj::OnCreateMediaTransportSrtpParam &""'"); 
  }
  arg2 = reinterpret_cast< pj::OnCreateMediaTransportSrtpParam * >(argp2);
  director = SWIG_DIRECTOR_CAST(arg1);
  upcall = (director && (director->swig_get_self()==swig_obj[0]));
  try {
    if (upcall) {
      (arg1)->pj::Call::onCreateMediaTransportSrtp(*arg2);
    } else {
      (arg1)->onCreateMediaTransportSrtp(*arg2);
    }
  } catch (Swig::DirectorException&) {
    SWIG_fail;
  }
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_disown_Call(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::Call *arg1 = (pj::Call *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__Call, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "disown_Call" "', argument " "1"" of type '" "pj::Call *""'"); 
  }
  arg1 = reinterpret_cast< pj::Call * >(argp1);
  {
    Swig::Director *director = SWIG_DIRECTOR_CAST(arg1);
    if (director) director->swig_disown();
  }
  
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *Call_swigregister(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *obj;
  if (!SWIG_Python_UnpackTuple(args, "swigregister", 1, 1, &obj)) return NULL;
  SWIG_TypeNewClientData(SWIGTYPE_p_pj__Call, SWIG_NewClientData(obj));
  return SWIG_Py_Void();
}

SWIGINTERN PyObject *Call_swiginit(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  return SWIG_Python_InitShadowInstance(args);
}

SWIGINTERN PyObject *_wrap_new_JsonDocument(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::JsonDocument *result = 0 ;
  
  if (!SWIG_Python_UnpackTuple(args, "new_JsonDocument", 0, 0, 0)) SWIG_fail;
  result = (pj::JsonDocument *)new pj::JsonDocument();
  resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(result), SWIGTYPE_p_pj__JsonDocument, SWIG_POINTER_NEW |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_delete_JsonDocument(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::JsonDocument *arg1 = (pj::JsonDocument *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__JsonDocument, SWIG_POINTER_DISOWN |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "delete_JsonDocument" "', argument " "1"" of type '" "pj::JsonDocument *""'"); 
  }
  arg1 = reinterpret_cast< pj::JsonDocument * >(argp1);
  delete arg1;
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_JsonDocument_loadFile(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::JsonDocument *arg1 = (pj::JsonDocument *) 0 ;
  pj::string *arg2 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  int res2 = SWIG_OLDOBJ ;
  PyObject *swig_obj[2] ;
  
  if (!SWIG_Python_UnpackTuple(args, "JsonDocument_loadFile", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__JsonDocument, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "JsonDocument_loadFile" "', argument " "1"" of type '" "pj::JsonDocument *""'"); 
  }
  arg1 = reinterpret_cast< pj::JsonDocument * >(argp1);
  {
    std::string *ptr = (std::string *)0;
    res2 = SWIG_AsPtr_std_string(swig_obj[1], &ptr);
    if (!SWIG_IsOK(res2)) {
      SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "JsonDocument_loadFile" "', argument " "2"" of type '" "pj::string const &""'"); 
    }
    if (!ptr) {
      SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "JsonDocument_loadFile" "', argument " "2"" of type '" "pj::string const &""'"); 
    }
    arg2 = ptr;
  }
  try {
    (arg1)->loadFile((pj::string const &)*arg2);
  } catch(pj::Error &_e) {
    SWIG_Python_Raise(SWIG_NewPointerObj((new pj::Error(static_cast< const pj::Error& >(_e))),SWIGTYPE_p_pj__Error,SWIG_POINTER_OWN), "pj::Error", SWIGTYPE_p_pj__Error); SWIG_fail;
  }
  resultobj = SWIG_Py_Void();
  if (SWIG_IsNewObj(res2)) delete arg2;
  return resultobj;
fail:
  if (SWIG_IsNewObj(res2)) delete arg2;
  return NULL;
}


SWIGINTERN PyObject *_wrap_JsonDocument_loadString(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::JsonDocument *arg1 = (pj::JsonDocument *) 0 ;
  pj::string *arg2 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  int res2 = SWIG_OLDOBJ ;
  PyObject *swig_obj[2] ;
  
  if (!SWIG_Python_UnpackTuple(args, "JsonDocument_loadString", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__JsonDocument, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "JsonDocument_loadString" "', argument " "1"" of type '" "pj::JsonDocument *""'"); 
  }
  arg1 = reinterpret_cast< pj::JsonDocument * >(argp1);
  {
    std::string *ptr = (std::string *)0;
    res2 = SWIG_AsPtr_std_string(swig_obj[1], &ptr);
    if (!SWIG_IsOK(res2)) {
      SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "JsonDocument_loadString" "', argument " "2"" of type '" "pj::string const &""'"); 
    }
    if (!ptr) {
      SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "JsonDocument_loadString" "', argument " "2"" of type '" "pj::string const &""'"); 
    }
    arg2 = ptr;
  }
  try {
    (arg1)->loadString((pj::string const &)*arg2);
  } catch(pj::Error &_e) {
    SWIG_Python_Raise(SWIG_NewPointerObj((new pj::Error(static_cast< const pj::Error& >(_e))),SWIGTYPE_p_pj__Error,SWIG_POINTER_OWN), "pj::Error", SWIGTYPE_p_pj__Error); SWIG_fail;
  }
  resultobj = SWIG_Py_Void();
  if (SWIG_IsNewObj(res2)) delete arg2;
  return resultobj;
fail:
  if (SWIG_IsNewObj(res2)) delete arg2;
  return NULL;
}


SWIGINTERN PyObject *_wrap_JsonDocument_saveFile(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::JsonDocument *arg1 = (pj::JsonDocument *) 0 ;
  pj::string *arg2 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  int res2 = SWIG_OLDOBJ ;
  PyObject *swig_obj[2] ;
  
  if (!SWIG_Python_UnpackTuple(args, "JsonDocument_saveFile", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__JsonDocument, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "JsonDocument_saveFile" "', argument " "1"" of type '" "pj::JsonDocument *""'"); 
  }
  arg1 = reinterpret_cast< pj::JsonDocument * >(argp1);
  {
    std::string *ptr = (std::string *)0;
    res2 = SWIG_AsPtr_std_string(swig_obj[1], &ptr);
    if (!SWIG_IsOK(res2)) {
      SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "JsonDocument_saveFile" "', argument " "2"" of type '" "pj::string const &""'"); 
    }
    if (!ptr) {
      SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "JsonDocument_saveFile" "', argument " "2"" of type '" "pj::string const &""'"); 
    }
    arg2 = ptr;
  }
  try {
    (arg1)->saveFile((pj::string const &)*arg2);
  } catch(pj::Error &_e) {
    SWIG_Python_Raise(SWIG_NewPointerObj((new pj::Error(static_cast< const pj::Error& >(_e))),SWIGTYPE_p_pj__Error,SWIG_POINTER_OWN), "pj::Error", SWIGTYPE_p_pj__Error); SWIG_fail;
  }
  resultobj = SWIG_Py_Void();
  if (SWIG_IsNewObj(res2)) delete arg2;
  return resultobj;
fail:
  if (SWIG_IsNewObj(res2)) delete arg2;
  return NULL;
}


SWIGINTERN PyObject *_wrap_JsonDocument_saveString(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::JsonDocument *arg1 = (pj::JsonDocument *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  pj::string result;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__JsonDocument, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "JsonDocument_saveString" "', argument " "1"" of type '" "pj::JsonDocument *""'"); 
  }
  arg1 = reinterpret_cast< pj::JsonDocument * >(argp1);
  try {
    result = (arg1)->saveString();
  } catch(pj::Error &_e) {
    SWIG_Python_Raise(SWIG_NewPointerObj((new pj::Error(static_cast< const pj::Error& >(_e))),SWIGTYPE_p_pj__Error,SWIG_POINTER_OWN), "pj::Error", SWIGTYPE_p_pj__Error); SWIG_fail;
  }
  resultobj = SWIG_From_std_string(static_cast< std::string >(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_JsonDocument_getRootContainer(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::JsonDocument *arg1 = (pj::JsonDocument *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  pj::ContainerNode *result = 0 ;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__JsonDocument, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "JsonDocument_getRootContainer" "', argument " "1"" of type '" "pj::JsonDocument const *""'"); 
  }
  arg1 = reinterpret_cast< pj::JsonDocument * >(argp1);
  result = (pj::ContainerNode *) &((pj::JsonDocument const *)arg1)->getRootContainer();
  resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(result), SWIGTYPE_p_pj__ContainerNode, 0 |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *JsonDocument_swigregister(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *obj;
  if (!SWIG_Python_UnpackTuple(args, "swigregister", 1, 1, &obj)) return NULL;
  SWIG_TypeNewClientData(SWIGTYPE_p_pj__JsonDocument, SWIG_NewClientData(obj));
  return SWIG_Py_Void();
}

SWIGINTERN PyObject *JsonDocument_swiginit(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  return SWIG_Python_InitShadowInstance(args);
}

SWIGINTERN PyObject *_wrap_OnNatDetectionCompleteParam_status_set(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::OnNatDetectionCompleteParam *arg1 = (pj::OnNatDetectionCompleteParam *) 0 ;
  pj_status_t arg2 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  int val2 ;
  int ecode2 = 0 ;
  PyObject *swig_obj[2] ;
  
  if (!SWIG_Python_UnpackTuple(args, "OnNatDetectionCompleteParam_status_set", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__OnNatDetectionCompleteParam, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "OnNatDetectionCompleteParam_status_set" "', argument " "1"" of type '" "pj::OnNatDetectionCompleteParam *""'"); 
  }
  arg1 = reinterpret_cast< pj::OnNatDetectionCompleteParam * >(argp1);
  ecode2 = SWIG_AsVal_int(swig_obj[1], &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "OnNatDetectionCompleteParam_status_set" "', argument " "2"" of type '" "pj_status_t""'");
  } 
  arg2 = static_cast< pj_status_t >(val2);
  if (arg1) (arg1)->status = arg2;
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_OnNatDetectionCompleteParam_status_get(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::OnNatDetectionCompleteParam *arg1 = (pj::OnNatDetectionCompleteParam *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  pj_status_t result;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__OnNatDetectionCompleteParam, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "OnNatDetectionCompleteParam_status_get" "', argument " "1"" of type '" "pj::OnNatDetectionCompleteParam *""'"); 
  }
  arg1 = reinterpret_cast< pj::OnNatDetectionCompleteParam * >(argp1);
  result = (pj_status_t) ((arg1)->status);
  resultobj = SWIG_From_int(static_cast< int >(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_OnNatDetectionCompleteParam_reason_set(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::OnNatDetectionCompleteParam *arg1 = (pj::OnNatDetectionCompleteParam *) 0 ;
  pj::string *arg2 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  int res2 = SWIG_OLDOBJ ;
  PyObject *swig_obj[2] ;
  
  if (!SWIG_Python_UnpackTuple(args, "OnNatDetectionCompleteParam_reason_set", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__OnNatDetectionCompleteParam, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "OnNatDetectionCompleteParam_reason_set" "', argument " "1"" of type '" "pj::OnNatDetectionCompleteParam *""'"); 
  }
  arg1 = reinterpret_cast< pj::OnNatDetectionCompleteParam * >(argp1);
  {
    std::string *ptr = (std::string *)0;
    res2 = SWIG_AsPtr_std_string(swig_obj[1], &ptr);
    if (!SWIG_IsOK(res2)) {
      SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "OnNatDetectionCompleteParam_reason_set" "', argument " "2"" of type '" "pj::string const &""'"); 
    }
    if (!ptr) {
      SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "OnNatDetectionCompleteParam_reason_set" "', argument " "2"" of type '" "pj::string const &""'"); 
    }
    arg2 = ptr;
  }
  if (arg1) (arg1)->reason = *arg2;
  resultobj = SWIG_Py_Void();
  if (SWIG_IsNewObj(res2)) delete arg2;
  return resultobj;
fail:
  if (SWIG_IsNewObj(res2)) delete arg2;
  return NULL;
}


SWIGINTERN PyObject *_wrap_OnNatDetectionCompleteParam_reason_get(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::OnNatDetectionCompleteParam *arg1 = (pj::OnNatDetectionCompleteParam *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  pj::string *result = 0 ;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__OnNatDetectionCompleteParam, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "OnNatDetectionCompleteParam_reason_get" "', argument " "1"" of type '" "pj::OnNatDetectionCompleteParam *""'"); 
  }
  arg1 = reinterpret_cast< pj::OnNatDetectionCompleteParam * >(argp1);
  result = (pj::string *) & ((arg1)->reason);
  resultobj = SWIG_From_std_string(static_cast< std::string >(*result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_OnNatDetectionCompleteParam_natType_set(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::OnNatDetectionCompleteParam *arg1 = (pj::OnNatDetectionCompleteParam *) 0 ;
  pj_stun_nat_type arg2 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  int val2 ;
  int ecode2 = 0 ;
  PyObject *swig_obj[2] ;
  
  if (!SWIG_Python_UnpackTuple(args, "OnNatDetectionCompleteParam_natType_set", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__OnNatDetectionCompleteParam, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "OnNatDetectionCompleteParam_natType_set" "', argument " "1"" of type '" "pj::OnNatDetectionCompleteParam *""'"); 
  }
  arg1 = reinterpret_cast< pj::OnNatDetectionCompleteParam * >(argp1);
  ecode2 = SWIG_AsVal_int(swig_obj[1], &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "OnNatDetectionCompleteParam_natType_set" "', argument " "2"" of type '" "pj_stun_nat_type""'");
  } 
  arg2 = static_cast< pj_stun_nat_type >(val2);
  if (arg1) (arg1)->natType = arg2;
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_OnNatDetectionCompleteParam_natType_get(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::OnNatDetectionCompleteParam *arg1 = (pj::OnNatDetectionCompleteParam *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  pj_stun_nat_type result;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__OnNatDetectionCompleteParam, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "OnNatDetectionCompleteParam_natType_get" "', argument " "1"" of type '" "pj::OnNatDetectionCompleteParam *""'"); 
  }
  arg1 = reinterpret_cast< pj::OnNatDetectionCompleteParam * >(argp1);
  result = (pj_stun_nat_type) ((arg1)->natType);
  resultobj = SWIG_From_int(static_cast< int >(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_OnNatDetectionCompleteParam_natTypeName_set(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::OnNatDetectionCompleteParam *arg1 = (pj::OnNatDetectionCompleteParam *) 0 ;
  pj::string *arg2 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  int res2 = SWIG_OLDOBJ ;
  PyObject *swig_obj[2] ;
  
  if (!SWIG_Python_UnpackTuple(args, "OnNatDetectionCompleteParam_natTypeName_set", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__OnNatDetectionCompleteParam, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "OnNatDetectionCompleteParam_natTypeName_set" "', argument " "1"" of type '" "pj::OnNatDetectionCompleteParam *""'"); 
  }
  arg1 = reinterpret_cast< pj::OnNatDetectionCompleteParam * >(argp1);
  {
    std::string *ptr = (std::string *)0;
    res2 = SWIG_AsPtr_std_string(swig_obj[1], &ptr);
    if (!SWIG_IsOK(res2)) {
      SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "OnNatDetectionCompleteParam_natTypeName_set" "', argument " "2"" of type '" "pj::string const &""'"); 
    }
    if (!ptr) {
      SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "OnNatDetectionCompleteParam_natTypeName_set" "', argument " "2"" of type '" "pj::string const &""'"); 
    }
    arg2 = ptr;
  }
  if (arg1) (arg1)->natTypeName = *arg2;
  resultobj = SWIG_Py_Void();
  if (SWIG_IsNewObj(res2)) delete arg2;
  return resultobj;
fail:
  if (SWIG_IsNewObj(res2)) delete arg2;
  return NULL;
}


SWIGINTERN PyObject *_wrap_OnNatDetectionCompleteParam_natTypeName_get(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::OnNatDetectionCompleteParam *arg1 = (pj::OnNatDetectionCompleteParam *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  pj::string *result = 0 ;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__OnNatDetectionCompleteParam, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "OnNatDetectionCompleteParam_natTypeName_get" "', argument " "1"" of type '" "pj::OnNatDetectionCompleteParam *""'"); 
  }
  arg1 = reinterpret_cast< pj::OnNatDetectionCompleteParam * >(argp1);
  result = (pj::string *) & ((arg1)->natTypeName);
  resultobj = SWIG_From_std_string(static_cast< std::string >(*result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_new_OnNatDetectionCompleteParam(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::OnNatDetectionCompleteParam *result = 0 ;
  
  if (!SWIG_Python_UnpackTuple(args, "new_OnNatDetectionCompleteParam", 0, 0, 0)) SWIG_fail;
  result = (pj::OnNatDetectionCompleteParam *)new pj::OnNatDetectionCompleteParam();
  resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(result), SWIGTYPE_p_pj__OnNatDetectionCompleteParam, SWIG_POINTER_NEW |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_delete_OnNatDetectionCompleteParam(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::OnNatDetectionCompleteParam *arg1 = (pj::OnNatDetectionCompleteParam *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__OnNatDetectionCompleteParam, SWIG_POINTER_DISOWN |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "delete_OnNatDetectionCompleteParam" "', argument " "1"" of type '" "pj::OnNatDetectionCompleteParam *""'"); 
  }
  arg1 = reinterpret_cast< pj::OnNatDetectionCompleteParam * >(argp1);
  delete arg1;
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *OnNatDetectionCompleteParam_swigregister(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *obj;
  if (!SWIG_Python_UnpackTuple(args, "swigregister", 1, 1, &obj)) return NULL;
  SWIG_TypeNewClientData(SWIGTYPE_p_pj__OnNatDetectionCompleteParam, SWIG_NewClientData(obj));
  return SWIG_Py_Void();
}

SWIGINTERN PyObject *OnNatDetectionCompleteParam_swiginit(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  return SWIG_Python_InitShadowInstance(args);
}

SWIGINTERN PyObject *_wrap_OnNatCheckStunServersCompleteParam_userData_set(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::OnNatCheckStunServersCompleteParam *arg1 = (pj::OnNatCheckStunServersCompleteParam *) 0 ;
  pj::Token arg2 = (pj::Token) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  int res2 ;
  PyObject *swig_obj[2] ;
  
  if (!SWIG_Python_UnpackTuple(args, "OnNatCheckStunServersCompleteParam_userData_set", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__OnNatCheckStunServersCompleteParam, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "OnNatCheckStunServersCompleteParam_userData_set" "', argument " "1"" of type '" "pj::OnNatCheckStunServersCompleteParam *""'"); 
  }
  arg1 = reinterpret_cast< pj::OnNatCheckStunServersCompleteParam * >(argp1);
  res2 = SWIG_ConvertPtr(swig_obj[1],SWIG_as_voidptrptr(&arg2), 0, SWIG_POINTER_DISOWN);
  if (!SWIG_IsOK(res2)) {
    SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "OnNatCheckStunServersCompleteParam_userData_set" "', argument " "2"" of type '" "pj::Token""'"); 
  }
  if (arg1) (arg1)->userData = arg2;
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_OnNatCheckStunServersCompleteParam_userData_get(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::OnNatCheckStunServersCompleteParam *arg1 = (pj::OnNatCheckStunServersCompleteParam *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  pj::Token result;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__OnNatCheckStunServersCompleteParam, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "OnNatCheckStunServersCompleteParam_userData_get" "', argument " "1"" of type '" "pj::OnNatCheckStunServersCompleteParam *""'"); 
  }
  arg1 = reinterpret_cast< pj::OnNatCheckStunServersCompleteParam * >(argp1);
  result = (pj::Token) ((arg1)->userData);
  resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(result), SWIGTYPE_p_void, 0 |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_OnNatCheckStunServersCompleteParam_status_set(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::OnNatCheckStunServersCompleteParam *arg1 = (pj::OnNatCheckStunServersCompleteParam *) 0 ;
  pj_status_t arg2 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  int val2 ;
  int ecode2 = 0 ;
  PyObject *swig_obj[2] ;
  
  if (!SWIG_Python_UnpackTuple(args, "OnNatCheckStunServersCompleteParam_status_set", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__OnNatCheckStunServersCompleteParam, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "OnNatCheckStunServersCompleteParam_status_set" "', argument " "1"" of type '" "pj::OnNatCheckStunServersCompleteParam *""'"); 
  }
  arg1 = reinterpret_cast< pj::OnNatCheckStunServersCompleteParam * >(argp1);
  ecode2 = SWIG_AsVal_int(swig_obj[1], &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "OnNatCheckStunServersCompleteParam_status_set" "', argument " "2"" of type '" "pj_status_t""'");
  } 
  arg2 = static_cast< pj_status_t >(val2);
  if (arg1) (arg1)->status = arg2;
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_OnNatCheckStunServersCompleteParam_status_get(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::OnNatCheckStunServersCompleteParam *arg1 = (pj::OnNatCheckStunServersCompleteParam *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  pj_status_t result;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__OnNatCheckStunServersCompleteParam, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "OnNatCheckStunServersCompleteParam_status_get" "', argument " "1"" of type '" "pj::OnNatCheckStunServersCompleteParam *""'"); 
  }
  arg1 = reinterpret_cast< pj::OnNatCheckStunServersCompleteParam * >(argp1);
  result = (pj_status_t) ((arg1)->status);
  resultobj = SWIG_From_int(static_cast< int >(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_OnNatCheckStunServersCompleteParam_name_set(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::OnNatCheckStunServersCompleteParam *arg1 = (pj::OnNatCheckStunServersCompleteParam *) 0 ;
  pj::string *arg2 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  int res2 = SWIG_OLDOBJ ;
  PyObject *swig_obj[2] ;
  
  if (!SWIG_Python_UnpackTuple(args, "OnNatCheckStunServersCompleteParam_name_set", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__OnNatCheckStunServersCompleteParam, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "OnNatCheckStunServersCompleteParam_name_set" "', argument " "1"" of type '" "pj::OnNatCheckStunServersCompleteParam *""'"); 
  }
  arg1 = reinterpret_cast< pj::OnNatCheckStunServersCompleteParam * >(argp1);
  {
    std::string *ptr = (std::string *)0;
    res2 = SWIG_AsPtr_std_string(swig_obj[1], &ptr);
    if (!SWIG_IsOK(res2)) {
      SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "OnNatCheckStunServersCompleteParam_name_set" "', argument " "2"" of type '" "pj::string const &""'"); 
    }
    if (!ptr) {
      SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "OnNatCheckStunServersCompleteParam_name_set" "', argument " "2"" of type '" "pj::string const &""'"); 
    }
    arg2 = ptr;
  }
  if (arg1) (arg1)->name = *arg2;
  resultobj = SWIG_Py_Void();
  if (SWIG_IsNewObj(res2)) delete arg2;
  return resultobj;
fail:
  if (SWIG_IsNewObj(res2)) delete arg2;
  return NULL;
}


SWIGINTERN PyObject *_wrap_OnNatCheckStunServersCompleteParam_name_get(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::OnNatCheckStunServersCompleteParam *arg1 = (pj::OnNatCheckStunServersCompleteParam *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  pj::string *result = 0 ;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__OnNatCheckStunServersCompleteParam, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "OnNatCheckStunServersCompleteParam_name_get" "', argument " "1"" of type '" "pj::OnNatCheckStunServersCompleteParam *""'"); 
  }
  arg1 = reinterpret_cast< pj::OnNatCheckStunServersCompleteParam * >(argp1);
  result = (pj::string *) & ((arg1)->name);
  resultobj = SWIG_From_std_string(static_cast< std::string >(*result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_OnNatCheckStunServersCompleteParam_addr_set(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::OnNatCheckStunServersCompleteParam *arg1 = (pj::OnNatCheckStunServersCompleteParam *) 0 ;
  pj::SocketAddress *arg2 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  int res2 = SWIG_OLDOBJ ;
  PyObject *swig_obj[2] ;
  
  if (!SWIG_Python_UnpackTuple(args, "OnNatCheckStunServersCompleteParam_addr_set", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__OnNatCheckStunServersCompleteParam, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "OnNatCheckStunServersCompleteParam_addr_set" "', argument " "1"" of type '" "pj::OnNatCheckStunServersCompleteParam *""'"); 
  }
  arg1 = reinterpret_cast< pj::OnNatCheckStunServersCompleteParam * >(argp1);
  {
    std::string *ptr = (std::string *)0;
    res2 = SWIG_AsPtr_std_string(swig_obj[1], &ptr);
    if (!SWIG_IsOK(res2)) {
      SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "OnNatCheckStunServersCompleteParam_addr_set" "', argument " "2"" of type '" "pj::SocketAddress const &""'"); 
    }
    if (!ptr) {
      SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "OnNatCheckStunServersCompleteParam_addr_set" "', argument " "2"" of type '" "pj::SocketAddress const &""'"); 
    }
    arg2 = ptr;
  }
  if (arg1) (arg1)->addr = *arg2;
  resultobj = SWIG_Py_Void();
  if (SWIG_IsNewObj(res2)) delete arg2;
  return resultobj;
fail:
  if (SWIG_IsNewObj(res2)) delete arg2;
  return NULL;
}


SWIGINTERN PyObject *_wrap_OnNatCheckStunServersCompleteParam_addr_get(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::OnNatCheckStunServersCompleteParam *arg1 = (pj::OnNatCheckStunServersCompleteParam *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  pj::SocketAddress *result = 0 ;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__OnNatCheckStunServersCompleteParam, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "OnNatCheckStunServersCompleteParam_addr_get" "', argument " "1"" of type '" "pj::OnNatCheckStunServersCompleteParam *""'"); 
  }
  arg1 = reinterpret_cast< pj::OnNatCheckStunServersCompleteParam * >(argp1);
  result = (pj::SocketAddress *) & ((arg1)->addr);
  resultobj = SWIG_From_std_string(static_cast< std::string >(*result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_new_OnNatCheckStunServersCompleteParam(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::OnNatCheckStunServersCompleteParam *result = 0 ;
  
  if (!SWIG_Python_UnpackTuple(args, "new_OnNatCheckStunServersCompleteParam", 0, 0, 0)) SWIG_fail;
  result = (pj::OnNatCheckStunServersCompleteParam *)new pj::OnNatCheckStunServersCompleteParam();
  resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(result), SWIGTYPE_p_pj__OnNatCheckStunServersCompleteParam, SWIG_POINTER_NEW |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_delete_OnNatCheckStunServersCompleteParam(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::OnNatCheckStunServersCompleteParam *arg1 = (pj::OnNatCheckStunServersCompleteParam *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__OnNatCheckStunServersCompleteParam, SWIG_POINTER_DISOWN |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "delete_OnNatCheckStunServersCompleteParam" "', argument " "1"" of type '" "pj::OnNatCheckStunServersCompleteParam *""'"); 
  }
  arg1 = reinterpret_cast< pj::OnNatCheckStunServersCompleteParam * >(argp1);
  delete arg1;
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *OnNatCheckStunServersCompleteParam_swigregister(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *obj;
  if (!SWIG_Python_UnpackTuple(args, "swigregister", 1, 1, &obj)) return NULL;
  SWIG_TypeNewClientData(SWIGTYPE_p_pj__OnNatCheckStunServersCompleteParam, SWIG_NewClientData(obj));
  return SWIG_Py_Void();
}

SWIGINTERN PyObject *OnNatCheckStunServersCompleteParam_swiginit(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  return SWIG_Python_InitShadowInstance(args);
}

SWIGINTERN PyObject *_wrap_OnTimerParam_userData_set(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::OnTimerParam *arg1 = (pj::OnTimerParam *) 0 ;
  pj::Token arg2 = (pj::Token) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  int res2 ;
  PyObject *swig_obj[2] ;
  
  if (!SWIG_Python_UnpackTuple(args, "OnTimerParam_userData_set", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__OnTimerParam, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "OnTimerParam_userData_set" "', argument " "1"" of type '" "pj::OnTimerParam *""'"); 
  }
  arg1 = reinterpret_cast< pj::OnTimerParam * >(argp1);
  res2 = SWIG_ConvertPtr(swig_obj[1],SWIG_as_voidptrptr(&arg2), 0, SWIG_POINTER_DISOWN);
  if (!SWIG_IsOK(res2)) {
    SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "OnTimerParam_userData_set" "', argument " "2"" of type '" "pj::Token""'"); 
  }
  if (arg1) (arg1)->userData = arg2;
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_OnTimerParam_userData_get(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::OnTimerParam *arg1 = (pj::OnTimerParam *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  pj::Token result;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__OnTimerParam, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "OnTimerParam_userData_get" "', argument " "1"" of type '" "pj::OnTimerParam *""'"); 
  }
  arg1 = reinterpret_cast< pj::OnTimerParam * >(argp1);
  result = (pj::Token) ((arg1)->userData);
  resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(result), SWIGTYPE_p_void, 0 |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_OnTimerParam_msecDelay_set(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::OnTimerParam *arg1 = (pj::OnTimerParam *) 0 ;
  unsigned int arg2 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  unsigned int val2 ;
  int ecode2 = 0 ;
  PyObject *swig_obj[2] ;
  
  if (!SWIG_Python_UnpackTuple(args, "OnTimerParam_msecDelay_set", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__OnTimerParam, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "OnTimerParam_msecDelay_set" "', argument " "1"" of type '" "pj::OnTimerParam *""'"); 
  }
  arg1 = reinterpret_cast< pj::OnTimerParam * >(argp1);
  ecode2 = SWIG_AsVal_unsigned_SS_int(swig_obj[1], &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "OnTimerParam_msecDelay_set" "', argument " "2"" of type '" "unsigned int""'");
  } 
  arg2 = static_cast< unsigned int >(val2);
  if (arg1) (arg1)->msecDelay = arg2;
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_OnTimerParam_msecDelay_get(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::OnTimerParam *arg1 = (pj::OnTimerParam *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  unsigned int result;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__OnTimerParam, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "OnTimerParam_msecDelay_get" "', argument " "1"" of type '" "pj::OnTimerParam *""'"); 
  }
  arg1 = reinterpret_cast< pj::OnTimerParam * >(argp1);
  result = (unsigned int) ((arg1)->msecDelay);
  resultobj = SWIG_From_unsigned_SS_int(static_cast< unsigned int >(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_new_OnTimerParam(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::OnTimerParam *result = 0 ;
  
  if (!SWIG_Python_UnpackTuple(args, "new_OnTimerParam", 0, 0, 0)) SWIG_fail;
  result = (pj::OnTimerParam *)new pj::OnTimerParam();
  resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(result), SWIGTYPE_p_pj__OnTimerParam, SWIG_POINTER_NEW |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_delete_OnTimerParam(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::OnTimerParam *arg1 = (pj::OnTimerParam *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__OnTimerParam, SWIG_POINTER_DISOWN |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "delete_OnTimerParam" "', argument " "1"" of type '" "pj::OnTimerParam *""'"); 
  }
  arg1 = reinterpret_cast< pj::OnTimerParam * >(argp1);
  delete arg1;
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *OnTimerParam_swigregister(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *obj;
  if (!SWIG_Python_UnpackTuple(args, "swigregister", 1, 1, &obj)) return NULL;
  SWIG_TypeNewClientData(SWIGTYPE_p_pj__OnTimerParam, SWIG_NewClientData(obj));
  return SWIG_Py_Void();
}

SWIGINTERN PyObject *OnTimerParam_swiginit(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  return SWIG_Python_InitShadowInstance(args);
}

SWIGINTERN PyObject *_wrap_SslCertName_type_set(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::SslCertName *arg1 = (pj::SslCertName *) 0 ;
  pj_ssl_cert_name_type arg2 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  int val2 ;
  int ecode2 = 0 ;
  PyObject *swig_obj[2] ;
  
  if (!SWIG_Python_UnpackTuple(args, "SslCertName_type_set", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__SslCertName, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "SslCertName_type_set" "', argument " "1"" of type '" "pj::SslCertName *""'"); 
  }
  arg1 = reinterpret_cast< pj::SslCertName * >(argp1);
  ecode2 = SWIG_AsVal_int(swig_obj[1], &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "SslCertName_type_set" "', argument " "2"" of type '" "pj_ssl_cert_name_type""'");
  } 
  arg2 = static_cast< pj_ssl_cert_name_type >(val2);
  if (arg1) (arg1)->type = arg2;
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_SslCertName_type_get(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::SslCertName *arg1 = (pj::SslCertName *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  pj_ssl_cert_name_type result;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__SslCertName, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "SslCertName_type_get" "', argument " "1"" of type '" "pj::SslCertName *""'"); 
  }
  arg1 = reinterpret_cast< pj::SslCertName * >(argp1);
  result = (pj_ssl_cert_name_type) ((arg1)->type);
  resultobj = SWIG_From_int(static_cast< int >(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_SslCertName_name_set(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::SslCertName *arg1 = (pj::SslCertName *) 0 ;
  pj::string *arg2 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  int res2 = SWIG_OLDOBJ ;
  PyObject *swig_obj[2] ;
  
  if (!SWIG_Python_UnpackTuple(args, "SslCertName_name_set", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__SslCertName, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "SslCertName_name_set" "', argument " "1"" of type '" "pj::SslCertName *""'"); 
  }
  arg1 = reinterpret_cast< pj::SslCertName * >(argp1);
  {
    std::string *ptr = (std::string *)0;
    res2 = SWIG_AsPtr_std_string(swig_obj[1], &ptr);
    if (!SWIG_IsOK(res2)) {
      SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "SslCertName_name_set" "', argument " "2"" of type '" "pj::string const &""'"); 
    }
    if (!ptr) {
      SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "SslCertName_name_set" "', argument " "2"" of type '" "pj::string const &""'"); 
    }
    arg2 = ptr;
  }
  if (arg1) (arg1)->name = *arg2;
  resultobj = SWIG_Py_Void();
  if (SWIG_IsNewObj(res2)) delete arg2;
  return resultobj;
fail:
  if (SWIG_IsNewObj(res2)) delete arg2;
  return NULL;
}


SWIGINTERN PyObject *_wrap_SslCertName_name_get(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::SslCertName *arg1 = (pj::SslCertName *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  pj::string *result = 0 ;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__SslCertName, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "SslCertName_name_get" "', argument " "1"" of type '" "pj::SslCertName *""'"); 
  }
  arg1 = reinterpret_cast< pj::SslCertName * >(argp1);
  result = (pj::string *) & ((arg1)->name);
  resultobj = SWIG_From_std_string(static_cast< std::string >(*result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_new_SslCertName(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::SslCertName *result = 0 ;
  
  if (!SWIG_Python_UnpackTuple(args, "new_SslCertName", 0, 0, 0)) SWIG_fail;
  result = (pj::SslCertName *)new pj::SslCertName();
  resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(result), SWIGTYPE_p_pj__SslCertName, SWIG_POINTER_NEW |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_delete_SslCertName(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::SslCertName *arg1 = (pj::SslCertName *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__SslCertName, SWIG_POINTER_DISOWN |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "delete_SslCertName" "', argument " "1"" of type '" "pj::SslCertName *""'"); 
  }
  arg1 = reinterpret_cast< pj::SslCertName * >(argp1);
  delete arg1;
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *SslCertName_swigregister(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *obj;
  if (!SWIG_Python_UnpackTuple(args, "swigregister", 1, 1, &obj)) return NULL;
  SWIG_TypeNewClientData(SWIGTYPE_p_pj__SslCertName, SWIG_NewClientData(obj));
  return SWIG_Py_Void();
}

SWIGINTERN PyObject *SslCertName_swiginit(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  return SWIG_Python_InitShadowInstance(args);
}

SWIGINTERN PyObject *_wrap_SslCertInfo_version_set(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::SslCertInfo *arg1 = (pj::SslCertInfo *) 0 ;
  unsigned int arg2 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  unsigned int val2 ;
  int ecode2 = 0 ;
  PyObject *swig_obj[2] ;
  
  if (!SWIG_Python_UnpackTuple(args, "SslCertInfo_version_set", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__SslCertInfo, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "SslCertInfo_version_set" "', argument " "1"" of type '" "pj::SslCertInfo *""'"); 
  }
  arg1 = reinterpret_cast< pj::SslCertInfo * >(argp1);
  ecode2 = SWIG_AsVal_unsigned_SS_int(swig_obj[1], &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "SslCertInfo_version_set" "', argument " "2"" of type '" "unsigned int""'");
  } 
  arg2 = static_cast< unsigned int >(val2);
  if (arg1) (arg1)->version = arg2;
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_SslCertInfo_version_get(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::SslCertInfo *arg1 = (pj::SslCertInfo *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  unsigned int result;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__SslCertInfo, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "SslCertInfo_version_get" "', argument " "1"" of type '" "pj::SslCertInfo *""'"); 
  }
  arg1 = reinterpret_cast< pj::SslCertInfo * >(argp1);
  result = (unsigned int) ((arg1)->version);
  resultobj = SWIG_From_unsigned_SS_int(static_cast< unsigned int >(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_SslCertInfo_serialNo_set(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::SslCertInfo *arg1 = (pj::SslCertInfo *) 0 ;
  unsigned char *arg2 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  void *argp2 = 0 ;
  int res2 = 0 ;
  PyObject *swig_obj[2] ;
  
  if (!SWIG_Python_UnpackTuple(args, "SslCertInfo_serialNo_set", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__SslCertInfo, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "SslCertInfo_serialNo_set" "', argument " "1"" of type '" "pj::SslCertInfo *""'"); 
  }
  arg1 = reinterpret_cast< pj::SslCertInfo * >(argp1);
  res2 = SWIG_ConvertPtr(swig_obj[1], &argp2,SWIGTYPE_p_unsigned_char, 0 |  0 );
  if (!SWIG_IsOK(res2)) {
    SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "SslCertInfo_serialNo_set" "', argument " "2"" of type '" "unsigned char [20]""'"); 
  } 
  arg2 = reinterpret_cast< unsigned char * >(argp2);
  {
    if (arg2) {
      size_t ii = 0;
      for (; ii < (size_t)20; ++ii) *(unsigned char *)&arg1->serialNo[ii] = *((unsigned char *)arg2 + ii);
    } else {
      SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in variable '""serialNo""' of type '""unsigned char [20]""'");
    }
  }
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_SslCertInfo_serialNo_get(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::SslCertInfo *arg1 = (pj::SslCertInfo *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  unsigned char *result = 0 ;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__SslCertInfo, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "SslCertInfo_serialNo_get" "', argument " "1"" of type '" "pj::SslCertInfo *""'"); 
  }
  arg1 = reinterpret_cast< pj::SslCertInfo * >(argp1);
  result = (unsigned char *)(unsigned char *) ((arg1)->serialNo);
  resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(result), SWIGTYPE_p_unsigned_char, 0 |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_SslCertInfo_subjectCn_set(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::SslCertInfo *arg1 = (pj::SslCertInfo *) 0 ;
  pj::string *arg2 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  int res2 = SWIG_OLDOBJ ;
  PyObject *swig_obj[2] ;
  
  if (!SWIG_Python_UnpackTuple(args, "SslCertInfo_subjectCn_set", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__SslCertInfo, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "SslCertInfo_subjectCn_set" "', argument " "1"" of type '" "pj::SslCertInfo *""'"); 
  }
  arg1 = reinterpret_cast< pj::SslCertInfo * >(argp1);
  {
    std::string *ptr = (std::string *)0;
    res2 = SWIG_AsPtr_std_string(swig_obj[1], &ptr);
    if (!SWIG_IsOK(res2)) {
      SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "SslCertInfo_subjectCn_set" "', argument " "2"" of type '" "pj::string const &""'"); 
    }
    if (!ptr) {
      SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "SslCertInfo_subjectCn_set" "', argument " "2"" of type '" "pj::string const &""'"); 
    }
    arg2 = ptr;
  }
  if (arg1) (arg1)->subjectCn = *arg2;
  resultobj = SWIG_Py_Void();
  if (SWIG_IsNewObj(res2)) delete arg2;
  return resultobj;
fail:
  if (SWIG_IsNewObj(res2)) delete arg2;
  return NULL;
}


SWIGINTERN PyObject *_wrap_SslCertInfo_subjectCn_get(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::SslCertInfo *arg1 = (pj::SslCertInfo *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  pj::string *result = 0 ;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__SslCertInfo, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "SslCertInfo_subjectCn_get" "', argument " "1"" of type '" "pj::SslCertInfo *""'"); 
  }
  arg1 = reinterpret_cast< pj::SslCertInfo * >(argp1);
  result = (pj::string *) & ((arg1)->subjectCn);
  resultobj = SWIG_From_std_string(static_cast< std::string >(*result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_SslCertInfo_subjectInfo_set(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::SslCertInfo *arg1 = (pj::SslCertInfo *) 0 ;
  pj::string *arg2 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  int res2 = SWIG_OLDOBJ ;
  PyObject *swig_obj[2] ;
  
  if (!SWIG_Python_UnpackTuple(args, "SslCertInfo_subjectInfo_set", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__SslCertInfo, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "SslCertInfo_subjectInfo_set" "', argument " "1"" of type '" "pj::SslCertInfo *""'"); 
  }
  arg1 = reinterpret_cast< pj::SslCertInfo * >(argp1);
  {
    std::string *ptr = (std::string *)0;
    res2 = SWIG_AsPtr_std_string(swig_obj[1], &ptr);
    if (!SWIG_IsOK(res2)) {
      SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "SslCertInfo_subjectInfo_set" "', argument " "2"" of type '" "pj::string const &""'"); 
    }
    if (!ptr) {
      SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "SslCertInfo_subjectInfo_set" "', argument " "2"" of type '" "pj::string const &""'"); 
    }
    arg2 = ptr;
  }
  if (arg1) (arg1)->subjectInfo = *arg2;
  resultobj = SWIG_Py_Void();
  if (SWIG_IsNewObj(res2)) delete arg2;
  return resultobj;
fail:
  if (SWIG_IsNewObj(res2)) delete arg2;
  return NULL;
}


SWIGINTERN PyObject *_wrap_SslCertInfo_subjectInfo_get(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::SslCertInfo *arg1 = (pj::SslCertInfo *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  pj::string *result = 0 ;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__SslCertInfo, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "SslCertInfo_subjectInfo_get" "', argument " "1"" of type '" "pj::SslCertInfo *""'"); 
  }
  arg1 = reinterpret_cast< pj::SslCertInfo * >(argp1);
  result = (pj::string *) & ((arg1)->subjectInfo);
  resultobj = SWIG_From_std_string(static_cast< std::string >(*result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_SslCertInfo_issuerCn_set(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::SslCertInfo *arg1 = (pj::SslCertInfo *) 0 ;
  pj::string *arg2 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  int res2 = SWIG_OLDOBJ ;
  PyObject *swig_obj[2] ;
  
  if (!SWIG_Python_UnpackTuple(args, "SslCertInfo_issuerCn_set", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__SslCertInfo, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "SslCertInfo_issuerCn_set" "', argument " "1"" of type '" "pj::SslCertInfo *""'"); 
  }
  arg1 = reinterpret_cast< pj::SslCertInfo * >(argp1);
  {
    std::string *ptr = (std::string *)0;
    res2 = SWIG_AsPtr_std_string(swig_obj[1], &ptr);
    if (!SWIG_IsOK(res2)) {
      SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "SslCertInfo_issuerCn_set" "', argument " "2"" of type '" "pj::string const &""'"); 
    }
    if (!ptr) {
      SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "SslCertInfo_issuerCn_set" "', argument " "2"" of type '" "pj::string const &""'"); 
    }
    arg2 = ptr;
  }
  if (arg1) (arg1)->issuerCn = *arg2;
  resultobj = SWIG_Py_Void();
  if (SWIG_IsNewObj(res2)) delete arg2;
  return resultobj;
fail:
  if (SWIG_IsNewObj(res2)) delete arg2;
  return NULL;
}


SWIGINTERN PyObject *_wrap_SslCertInfo_issuerCn_get(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::SslCertInfo *arg1 = (pj::SslCertInfo *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  pj::string *result = 0 ;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__SslCertInfo, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "SslCertInfo_issuerCn_get" "', argument " "1"" of type '" "pj::SslCertInfo *""'"); 
  }
  arg1 = reinterpret_cast< pj::SslCertInfo * >(argp1);
  result = (pj::string *) & ((arg1)->issuerCn);
  resultobj = SWIG_From_std_string(static_cast< std::string >(*result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_SslCertInfo_issuerInfo_set(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::SslCertInfo *arg1 = (pj::SslCertInfo *) 0 ;
  pj::string *arg2 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  int res2 = SWIG_OLDOBJ ;
  PyObject *swig_obj[2] ;
  
  if (!SWIG_Python_UnpackTuple(args, "SslCertInfo_issuerInfo_set", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__SslCertInfo, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "SslCertInfo_issuerInfo_set" "', argument " "1"" of type '" "pj::SslCertInfo *""'"); 
  }
  arg1 = reinterpret_cast< pj::SslCertInfo * >(argp1);
  {
    std::string *ptr = (std::string *)0;
    res2 = SWIG_AsPtr_std_string(swig_obj[1], &ptr);
    if (!SWIG_IsOK(res2)) {
      SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "SslCertInfo_issuerInfo_set" "', argument " "2"" of type '" "pj::string const &""'"); 
    }
    if (!ptr) {
      SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "SslCertInfo_issuerInfo_set" "', argument " "2"" of type '" "pj::string const &""'"); 
    }
    arg2 = ptr;
  }
  if (arg1) (arg1)->issuerInfo = *arg2;
  resultobj = SWIG_Py_Void();
  if (SWIG_IsNewObj(res2)) delete arg2;
  return resultobj;
fail:
  if (SWIG_IsNewObj(res2)) delete arg2;
  return NULL;
}


SWIGINTERN PyObject *_wrap_SslCertInfo_issuerInfo_get(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::SslCertInfo *arg1 = (pj::SslCertInfo *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  pj::string *result = 0 ;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__SslCertInfo, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "SslCertInfo_issuerInfo_get" "', argument " "1"" of type '" "pj::SslCertInfo *""'"); 
  }
  arg1 = reinterpret_cast< pj::SslCertInfo * >(argp1);
  result = (pj::string *) & ((arg1)->issuerInfo);
  resultobj = SWIG_From_std_string(static_cast< std::string >(*result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_SslCertInfo_validityStart_set(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::SslCertInfo *arg1 = (pj::SslCertInfo *) 0 ;
  pj::TimeVal *arg2 = (pj::TimeVal *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  void *argp2 = 0 ;
  int res2 = 0 ;
  PyObject *swig_obj[2] ;
  
  if (!SWIG_Python_UnpackTuple(args, "SslCertInfo_validityStart_set", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__SslCertInfo, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "SslCertInfo_validityStart_set" "', argument " "1"" of type '" "pj::SslCertInfo *""'"); 
  }
  arg1 = reinterpret_cast< pj::SslCertInfo * >(argp1);
  res2 = SWIG_ConvertPtr(swig_obj[1], &argp2,SWIGTYPE_p_pj__TimeVal, 0 |  0 );
  if (!SWIG_IsOK(res2)) {
    SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "SslCertInfo_validityStart_set" "', argument " "2"" of type '" "pj::TimeVal *""'"); 
  }
  arg2 = reinterpret_cast< pj::TimeVal * >(argp2);
  if (arg1) (arg1)->validityStart = *arg2;
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_SslCertInfo_validityStart_get(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::SslCertInfo *arg1 = (pj::SslCertInfo *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  pj::TimeVal *result = 0 ;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__SslCertInfo, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "SslCertInfo_validityStart_get" "', argument " "1"" of type '" "pj::SslCertInfo *""'"); 
  }
  arg1 = reinterpret_cast< pj::SslCertInfo * >(argp1);
  result = (pj::TimeVal *)& ((arg1)->validityStart);
  resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(result), SWIGTYPE_p_pj__TimeVal, 0 |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_SslCertInfo_validityEnd_set(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::SslCertInfo *arg1 = (pj::SslCertInfo *) 0 ;
  pj::TimeVal *arg2 = (pj::TimeVal *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  void *argp2 = 0 ;
  int res2 = 0 ;
  PyObject *swig_obj[2] ;
  
  if (!SWIG_Python_UnpackTuple(args, "SslCertInfo_validityEnd_set", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__SslCertInfo, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "SslCertInfo_validityEnd_set" "', argument " "1"" of type '" "pj::SslCertInfo *""'"); 
  }
  arg1 = reinterpret_cast< pj::SslCertInfo * >(argp1);
  res2 = SWIG_ConvertPtr(swig_obj[1], &argp2,SWIGTYPE_p_pj__TimeVal, 0 |  0 );
  if (!SWIG_IsOK(res2)) {
    SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "SslCertInfo_validityEnd_set" "', argument " "2"" of type '" "pj::TimeVal *""'"); 
  }
  arg2 = reinterpret_cast< pj::TimeVal * >(argp2);
  if (arg1) (arg1)->validityEnd = *arg2;
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_SslCertInfo_validityEnd_get(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::SslCertInfo *arg1 = (pj::SslCertInfo *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  pj::TimeVal *result = 0 ;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__SslCertInfo, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "SslCertInfo_validityEnd_get" "', argument " "1"" of type '" "pj::SslCertInfo *""'"); 
  }
  arg1 = reinterpret_cast< pj::SslCertInfo * >(argp1);
  result = (pj::TimeVal *)& ((arg1)->validityEnd);
  resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(result), SWIGTYPE_p_pj__TimeVal, 0 |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_SslCertInfo_validityGmt_set(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::SslCertInfo *arg1 = (pj::SslCertInfo *) 0 ;
  bool arg2 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  bool val2 ;
  int ecode2 = 0 ;
  PyObject *swig_obj[2] ;
  
  if (!SWIG_Python_UnpackTuple(args, "SslCertInfo_validityGmt_set", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__SslCertInfo, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "SslCertInfo_validityGmt_set" "', argument " "1"" of type '" "pj::SslCertInfo *""'"); 
  }
  arg1 = reinterpret_cast< pj::SslCertInfo * >(argp1);
  ecode2 = SWIG_AsVal_bool(swig_obj[1], &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "SslCertInfo_validityGmt_set" "', argument " "2"" of type '" "bool""'");
  } 
  arg2 = static_cast< bool >(val2);
  if (arg1) (arg1)->validityGmt = arg2;
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_SslCertInfo_validityGmt_get(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::SslCertInfo *arg1 = (pj::SslCertInfo *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  bool result;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__SslCertInfo, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "SslCertInfo_validityGmt_get" "', argument " "1"" of type '" "pj::SslCertInfo *""'"); 
  }
  arg1 = reinterpret_cast< pj::SslCertInfo * >(argp1);
  result = (bool) ((arg1)->validityGmt);
  resultobj = SWIG_From_bool(static_cast< bool >(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_SslCertInfo_subjectAltName_set(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::SslCertInfo *arg1 = (pj::SslCertInfo *) 0 ;
  pj::SslCertNameVector *arg2 = (pj::SslCertNameVector *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  void *argp2 = 0 ;
  int res2 = 0 ;
  PyObject *swig_obj[2] ;
  
  if (!SWIG_Python_UnpackTuple(args, "SslCertInfo_subjectAltName_set", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__SslCertInfo, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "SslCertInfo_subjectAltName_set" "', argument " "1"" of type '" "pj::SslCertInfo *""'"); 
  }
  arg1 = reinterpret_cast< pj::SslCertInfo * >(argp1);
  res2 = SWIG_ConvertPtr(swig_obj[1], &argp2,SWIGTYPE_p_std__vectorT_pj__SslCertName_std__allocatorT_pj__SslCertName_t_t, 0 |  0 );
  if (!SWIG_IsOK(res2)) {
    SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "SslCertInfo_subjectAltName_set" "', argument " "2"" of type '" "pj::SslCertNameVector *""'"); 
  }
  arg2 = reinterpret_cast< pj::SslCertNameVector * >(argp2);
  if (arg1) (arg1)->subjectAltName = *arg2;
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_SslCertInfo_subjectAltName_get(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::SslCertInfo *arg1 = (pj::SslCertInfo *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  pj::SslCertNameVector *result = 0 ;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__SslCertInfo, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "SslCertInfo_subjectAltName_get" "', argument " "1"" of type '" "pj::SslCertInfo *""'"); 
  }
  arg1 = reinterpret_cast< pj::SslCertInfo * >(argp1);
  result = (pj::SslCertNameVector *)& ((arg1)->subjectAltName);
  resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(result), SWIGTYPE_p_std__vectorT_pj__SslCertName_std__allocatorT_pj__SslCertName_t_t, 0 |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_SslCertInfo_raw_set(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::SslCertInfo *arg1 = (pj::SslCertInfo *) 0 ;
  pj::string *arg2 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  int res2 = SWIG_OLDOBJ ;
  PyObject *swig_obj[2] ;
  
  if (!SWIG_Python_UnpackTuple(args, "SslCertInfo_raw_set", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__SslCertInfo, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "SslCertInfo_raw_set" "', argument " "1"" of type '" "pj::SslCertInfo *""'"); 
  }
  arg1 = reinterpret_cast< pj::SslCertInfo * >(argp1);
  {
    std::string *ptr = (std::string *)0;
    res2 = SWIG_AsPtr_std_string(swig_obj[1], &ptr);
    if (!SWIG_IsOK(res2)) {
      SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "SslCertInfo_raw_set" "', argument " "2"" of type '" "pj::string const &""'"); 
    }
    if (!ptr) {
      SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "SslCertInfo_raw_set" "', argument " "2"" of type '" "pj::string const &""'"); 
    }
    arg2 = ptr;
  }
  if (arg1) (arg1)->raw = *arg2;
  resultobj = SWIG_Py_Void();
  if (SWIG_IsNewObj(res2)) delete arg2;
  return resultobj;
fail:
  if (SWIG_IsNewObj(res2)) delete arg2;
  return NULL;
}


SWIGINTERN PyObject *_wrap_SslCertInfo_raw_get(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::SslCertInfo *arg1 = (pj::SslCertInfo *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  pj::string *result = 0 ;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__SslCertInfo, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "SslCertInfo_raw_get" "', argument " "1"" of type '" "pj::SslCertInfo *""'"); 
  }
  arg1 = reinterpret_cast< pj::SslCertInfo * >(argp1);
  result = (pj::string *) & ((arg1)->raw);
  resultobj = SWIG_From_std_string(static_cast< std::string >(*result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_new_SslCertInfo(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::SslCertInfo *result = 0 ;
  
  if (!SWIG_Python_UnpackTuple(args, "new_SslCertInfo", 0, 0, 0)) SWIG_fail;
  result = (pj::SslCertInfo *)new pj::SslCertInfo();
  resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(result), SWIGTYPE_p_pj__SslCertInfo, SWIG_POINTER_NEW |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_SslCertInfo_isEmpty(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::SslCertInfo *arg1 = (pj::SslCertInfo *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  bool result;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__SslCertInfo, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "SslCertInfo_isEmpty" "', argument " "1"" of type '" "pj::SslCertInfo const *""'"); 
  }
  arg1 = reinterpret_cast< pj::SslCertInfo * >(argp1);
  result = (bool)((pj::SslCertInfo const *)arg1)->isEmpty();
  resultobj = SWIG_From_bool(static_cast< bool >(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_delete_SslCertInfo(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::SslCertInfo *arg1 = (pj::SslCertInfo *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__SslCertInfo, SWIG_POINTER_DISOWN |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "delete_SslCertInfo" "', argument " "1"" of type '" "pj::SslCertInfo *""'"); 
  }
  arg1 = reinterpret_cast< pj::SslCertInfo * >(argp1);
  delete arg1;
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *SslCertInfo_swigregister(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *obj;
  if (!SWIG_Python_UnpackTuple(args, "swigregister", 1, 1, &obj)) return NULL;
  SWIG_TypeNewClientData(SWIGTYPE_p_pj__SslCertInfo, SWIG_NewClientData(obj));
  return SWIG_Py_Void();
}

SWIGINTERN PyObject *SslCertInfo_swiginit(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  return SWIG_Python_InitShadowInstance(args);
}

SWIGINTERN PyObject *_wrap_TlsInfo_established_set(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::TlsInfo *arg1 = (pj::TlsInfo *) 0 ;
  bool arg2 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  bool val2 ;
  int ecode2 = 0 ;
  PyObject *swig_obj[2] ;
  
  if (!SWIG_Python_UnpackTuple(args, "TlsInfo_established_set", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__TlsInfo, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "TlsInfo_established_set" "', argument " "1"" of type '" "pj::TlsInfo *""'"); 
  }
  arg1 = reinterpret_cast< pj::TlsInfo * >(argp1);
  ecode2 = SWIG_AsVal_bool(swig_obj[1], &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "TlsInfo_established_set" "', argument " "2"" of type '" "bool""'");
  } 
  arg2 = static_cast< bool >(val2);
  if (arg1) (arg1)->established = arg2;
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_TlsInfo_established_get(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::TlsInfo *arg1 = (pj::TlsInfo *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  bool result;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__TlsInfo, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "TlsInfo_established_get" "', argument " "1"" of type '" "pj::TlsInfo *""'"); 
  }
  arg1 = reinterpret_cast< pj::TlsInfo * >(argp1);
  result = (bool) ((arg1)->established);
  resultobj = SWIG_From_bool(static_cast< bool >(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_TlsInfo_protocol_set(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::TlsInfo *arg1 = (pj::TlsInfo *) 0 ;
  unsigned int arg2 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  unsigned int val2 ;
  int ecode2 = 0 ;
  PyObject *swig_obj[2] ;
  
  if (!SWIG_Python_UnpackTuple(args, "TlsInfo_protocol_set", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__TlsInfo, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "TlsInfo_protocol_set" "', argument " "1"" of type '" "pj::TlsInfo *""'"); 
  }
  arg1 = reinterpret_cast< pj::TlsInfo * >(argp1);
  ecode2 = SWIG_AsVal_unsigned_SS_int(swig_obj[1], &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "TlsInfo_protocol_set" "', argument " "2"" of type '" "unsigned int""'");
  } 
  arg2 = static_cast< unsigned int >(val2);
  if (arg1) (arg1)->protocol = arg2;
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_TlsInfo_protocol_get(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::TlsInfo *arg1 = (pj::TlsInfo *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  unsigned int result;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__TlsInfo, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "TlsInfo_protocol_get" "', argument " "1"" of type '" "pj::TlsInfo *""'"); 
  }
  arg1 = reinterpret_cast< pj::TlsInfo * >(argp1);
  result = (unsigned int) ((arg1)->protocol);
  resultobj = SWIG_From_unsigned_SS_int(static_cast< unsigned int >(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_TlsInfo_cipher_set(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::TlsInfo *arg1 = (pj::TlsInfo *) 0 ;
  pj_ssl_cipher arg2 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  int val2 ;
  int ecode2 = 0 ;
  PyObject *swig_obj[2] ;
  
  if (!SWIG_Python_UnpackTuple(args, "TlsInfo_cipher_set", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__TlsInfo, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "TlsInfo_cipher_set" "', argument " "1"" of type '" "pj::TlsInfo *""'"); 
  }
  arg1 = reinterpret_cast< pj::TlsInfo * >(argp1);
  ecode2 = SWIG_AsVal_int(swig_obj[1], &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "TlsInfo_cipher_set" "', argument " "2"" of type '" "pj_ssl_cipher""'");
  } 
  arg2 = static_cast< pj_ssl_cipher >(val2);
  if (arg1) (arg1)->cipher = arg2;
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_TlsInfo_cipher_get(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::TlsInfo *arg1 = (pj::TlsInfo *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  pj_ssl_cipher result;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__TlsInfo, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "TlsInfo_cipher_get" "', argument " "1"" of type '" "pj::TlsInfo *""'"); 
  }
  arg1 = reinterpret_cast< pj::TlsInfo * >(argp1);
  result = (pj_ssl_cipher) ((arg1)->cipher);
  resultobj = SWIG_From_int(static_cast< int >(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_TlsInfo_cipherName_set(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::TlsInfo *arg1 = (pj::TlsInfo *) 0 ;
  pj::string *arg2 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  int res2 = SWIG_OLDOBJ ;
  PyObject *swig_obj[2] ;
  
  if (!SWIG_Python_UnpackTuple(args, "TlsInfo_cipherName_set", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__TlsInfo, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "TlsInfo_cipherName_set" "', argument " "1"" of type '" "pj::TlsInfo *""'"); 
  }
  arg1 = reinterpret_cast< pj::TlsInfo * >(argp1);
  {
    std::string *ptr = (std::string *)0;
    res2 = SWIG_AsPtr_std_string(swig_obj[1], &ptr);
    if (!SWIG_IsOK(res2)) {
      SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "TlsInfo_cipherName_set" "', argument " "2"" of type '" "pj::string const &""'"); 
    }
    if (!ptr) {
      SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "TlsInfo_cipherName_set" "', argument " "2"" of type '" "pj::string const &""'"); 
    }
    arg2 = ptr;
  }
  if (arg1) (arg1)->cipherName = *arg2;
  resultobj = SWIG_Py_Void();
  if (SWIG_IsNewObj(res2)) delete arg2;
  return resultobj;
fail:
  if (SWIG_IsNewObj(res2)) delete arg2;
  return NULL;
}


SWIGINTERN PyObject *_wrap_TlsInfo_cipherName_get(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::TlsInfo *arg1 = (pj::TlsInfo *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  pj::string *result = 0 ;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__TlsInfo, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "TlsInfo_cipherName_get" "', argument " "1"" of type '" "pj::TlsInfo *""'"); 
  }
  arg1 = reinterpret_cast< pj::TlsInfo * >(argp1);
  result = (pj::string *) & ((arg1)->cipherName);
  resultobj = SWIG_From_std_string(static_cast< std::string >(*result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_TlsInfo_localAddr_set(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::TlsInfo *arg1 = (pj::TlsInfo *) 0 ;
  pj::SocketAddress *arg2 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  int res2 = SWIG_OLDOBJ ;
  PyObject *swig_obj[2] ;
  
  if (!SWIG_Python_UnpackTuple(args, "TlsInfo_localAddr_set", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__TlsInfo, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "TlsInfo_localAddr_set" "', argument " "1"" of type '" "pj::TlsInfo *""'"); 
  }
  arg1 = reinterpret_cast< pj::TlsInfo * >(argp1);
  {
    std::string *ptr = (std::string *)0;
    res2 = SWIG_AsPtr_std_string(swig_obj[1], &ptr);
    if (!SWIG_IsOK(res2)) {
      SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "TlsInfo_localAddr_set" "', argument " "2"" of type '" "pj::SocketAddress const &""'"); 
    }
    if (!ptr) {
      SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "TlsInfo_localAddr_set" "', argument " "2"" of type '" "pj::SocketAddress const &""'"); 
    }
    arg2 = ptr;
  }
  if (arg1) (arg1)->localAddr = *arg2;
  resultobj = SWIG_Py_Void();
  if (SWIG_IsNewObj(res2)) delete arg2;
  return resultobj;
fail:
  if (SWIG_IsNewObj(res2)) delete arg2;
  return NULL;
}


SWIGINTERN PyObject *_wrap_TlsInfo_localAddr_get(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::TlsInfo *arg1 = (pj::TlsInfo *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  pj::SocketAddress *result = 0 ;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__TlsInfo, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "TlsInfo_localAddr_get" "', argument " "1"" of type '" "pj::TlsInfo *""'"); 
  }
  arg1 = reinterpret_cast< pj::TlsInfo * >(argp1);
  result = (pj::SocketAddress *) & ((arg1)->localAddr);
  resultobj = SWIG_From_std_string(static_cast< std::string >(*result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_TlsInfo_remoteAddr_set(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::TlsInfo *arg1 = (pj::TlsInfo *) 0 ;
  pj::SocketAddress *arg2 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  int res2 = SWIG_OLDOBJ ;
  PyObject *swig_obj[2] ;
  
  if (!SWIG_Python_UnpackTuple(args, "TlsInfo_remoteAddr_set", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__TlsInfo, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "TlsInfo_remoteAddr_set" "', argument " "1"" of type '" "pj::TlsInfo *""'"); 
  }
  arg1 = reinterpret_cast< pj::TlsInfo * >(argp1);
  {
    std::string *ptr = (std::string *)0;
    res2 = SWIG_AsPtr_std_string(swig_obj[1], &ptr);
    if (!SWIG_IsOK(res2)) {
      SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "TlsInfo_remoteAddr_set" "', argument " "2"" of type '" "pj::SocketAddress const &""'"); 
    }
    if (!ptr) {
      SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "TlsInfo_remoteAddr_set" "', argument " "2"" of type '" "pj::SocketAddress const &""'"); 
    }
    arg2 = ptr;
  }
  if (arg1) (arg1)->remoteAddr = *arg2;
  resultobj = SWIG_Py_Void();
  if (SWIG_IsNewObj(res2)) delete arg2;
  return resultobj;
fail:
  if (SWIG_IsNewObj(res2)) delete arg2;
  return NULL;
}


SWIGINTERN PyObject *_wrap_TlsInfo_remoteAddr_get(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::TlsInfo *arg1 = (pj::TlsInfo *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  pj::SocketAddress *result = 0 ;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__TlsInfo, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "TlsInfo_remoteAddr_get" "', argument " "1"" of type '" "pj::TlsInfo *""'"); 
  }
  arg1 = reinterpret_cast< pj::TlsInfo * >(argp1);
  result = (pj::SocketAddress *) & ((arg1)->remoteAddr);
  resultobj = SWIG_From_std_string(static_cast< std::string >(*result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_TlsInfo_localCertInfo_set(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::TlsInfo *arg1 = (pj::TlsInfo *) 0 ;
  pj::SslCertInfo *arg2 = (pj::SslCertInfo *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  void *argp2 = 0 ;
  int res2 = 0 ;
  PyObject *swig_obj[2] ;
  
  if (!SWIG_Python_UnpackTuple(args, "TlsInfo_localCertInfo_set", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__TlsInfo, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "TlsInfo_localCertInfo_set" "', argument " "1"" of type '" "pj::TlsInfo *""'"); 
  }
  arg1 = reinterpret_cast< pj::TlsInfo * >(argp1);
  res2 = SWIG_ConvertPtr(swig_obj[1], &argp2,SWIGTYPE_p_pj__SslCertInfo, 0 |  0 );
  if (!SWIG_IsOK(res2)) {
    SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "TlsInfo_localCertInfo_set" "', argument " "2"" of type '" "pj::SslCertInfo *""'"); 
  }
  arg2 = reinterpret_cast< pj::SslCertInfo * >(argp2);
  if (arg1) (arg1)->localCertInfo = *arg2;
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_TlsInfo_localCertInfo_get(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::TlsInfo *arg1 = (pj::TlsInfo *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  pj::SslCertInfo *result = 0 ;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__TlsInfo, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "TlsInfo_localCertInfo_get" "', argument " "1"" of type '" "pj::TlsInfo *""'"); 
  }
  arg1 = reinterpret_cast< pj::TlsInfo * >(argp1);
  result = (pj::SslCertInfo *)& ((arg1)->localCertInfo);
  resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(result), SWIGTYPE_p_pj__SslCertInfo, 0 |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_TlsInfo_remoteCertInfo_set(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::TlsInfo *arg1 = (pj::TlsInfo *) 0 ;
  pj::SslCertInfo *arg2 = (pj::SslCertInfo *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  void *argp2 = 0 ;
  int res2 = 0 ;
  PyObject *swig_obj[2] ;
  
  if (!SWIG_Python_UnpackTuple(args, "TlsInfo_remoteCertInfo_set", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__TlsInfo, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "TlsInfo_remoteCertInfo_set" "', argument " "1"" of type '" "pj::TlsInfo *""'"); 
  }
  arg1 = reinterpret_cast< pj::TlsInfo * >(argp1);
  res2 = SWIG_ConvertPtr(swig_obj[1], &argp2,SWIGTYPE_p_pj__SslCertInfo, 0 |  0 );
  if (!SWIG_IsOK(res2)) {
    SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "TlsInfo_remoteCertInfo_set" "', argument " "2"" of type '" "pj::SslCertInfo *""'"); 
  }
  arg2 = reinterpret_cast< pj::SslCertInfo * >(argp2);
  if (arg1) (arg1)->remoteCertInfo = *arg2;
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_TlsInfo_remoteCertInfo_get(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::TlsInfo *arg1 = (pj::TlsInfo *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  pj::SslCertInfo *result = 0 ;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__TlsInfo, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "TlsInfo_remoteCertInfo_get" "', argument " "1"" of type '" "pj::TlsInfo *""'"); 
  }
  arg1 = reinterpret_cast< pj::TlsInfo * >(argp1);
  result = (pj::SslCertInfo *)& ((arg1)->remoteCertInfo);
  resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(result), SWIGTYPE_p_pj__SslCertInfo, 0 |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_TlsInfo_verifyStatus_set(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::TlsInfo *arg1 = (pj::TlsInfo *) 0 ;
  unsigned int arg2 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  unsigned int val2 ;
  int ecode2 = 0 ;
  PyObject *swig_obj[2] ;
  
  if (!SWIG_Python_UnpackTuple(args, "TlsInfo_verifyStatus_set", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__TlsInfo, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "TlsInfo_verifyStatus_set" "', argument " "1"" of type '" "pj::TlsInfo *""'"); 
  }
  arg1 = reinterpret_cast< pj::TlsInfo * >(argp1);
  ecode2 = SWIG_AsVal_unsigned_SS_int(swig_obj[1], &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "TlsInfo_verifyStatus_set" "', argument " "2"" of type '" "unsigned int""'");
  } 
  arg2 = static_cast< unsigned int >(val2);
  if (arg1) (arg1)->verifyStatus = arg2;
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_TlsInfo_verifyStatus_get(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::TlsInfo *arg1 = (pj::TlsInfo *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  unsigned int result;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__TlsInfo, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "TlsInfo_verifyStatus_get" "', argument " "1"" of type '" "pj::TlsInfo *""'"); 
  }
  arg1 = reinterpret_cast< pj::TlsInfo * >(argp1);
  result = (unsigned int) ((arg1)->verifyStatus);
  resultobj = SWIG_From_unsigned_SS_int(static_cast< unsigned int >(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_TlsInfo_verifyMsgs_set(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::TlsInfo *arg1 = (pj::TlsInfo *) 0 ;
  pj::StringVector *arg2 = (pj::StringVector *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  void *argp2 = 0 ;
  int res2 = 0 ;
  PyObject *swig_obj[2] ;
  
  if (!SWIG_Python_UnpackTuple(args, "TlsInfo_verifyMsgs_set", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__TlsInfo, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "TlsInfo_verifyMsgs_set" "', argument " "1"" of type '" "pj::TlsInfo *""'"); 
  }
  arg1 = reinterpret_cast< pj::TlsInfo * >(argp1);
  res2 = SWIG_ConvertPtr(swig_obj[1], &argp2,SWIGTYPE_p_std__vectorT_std__string_std__allocatorT_std__string_t_t, 0 |  0 );
  if (!SWIG_IsOK(res2)) {
    SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "TlsInfo_verifyMsgs_set" "', argument " "2"" of type '" "pj::StringVector *""'"); 
  }
  arg2 = reinterpret_cast< pj::StringVector * >(argp2);
  if (arg1) (arg1)->verifyMsgs = *arg2;
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_TlsInfo_verifyMsgs_get(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::TlsInfo *arg1 = (pj::TlsInfo *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  pj::StringVector *result = 0 ;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__TlsInfo, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "TlsInfo_verifyMsgs_get" "', argument " "1"" of type '" "pj::TlsInfo *""'"); 
  }
  arg1 = reinterpret_cast< pj::TlsInfo * >(argp1);
  result = (pj::StringVector *)& ((arg1)->verifyMsgs);
  resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(result), SWIGTYPE_p_std__vectorT_std__string_std__allocatorT_std__string_t_t, 0 |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_new_TlsInfo(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::TlsInfo *result = 0 ;
  
  if (!SWIG_Python_UnpackTuple(args, "new_TlsInfo", 0, 0, 0)) SWIG_fail;
  result = (pj::TlsInfo *)new pj::TlsInfo();
  resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(result), SWIGTYPE_p_pj__TlsInfo, SWIG_POINTER_NEW |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_TlsInfo_isEmpty(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::TlsInfo *arg1 = (pj::TlsInfo *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  bool result;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__TlsInfo, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "TlsInfo_isEmpty" "', argument " "1"" of type '" "pj::TlsInfo const *""'"); 
  }
  arg1 = reinterpret_cast< pj::TlsInfo * >(argp1);
  result = (bool)((pj::TlsInfo const *)arg1)->isEmpty();
  resultobj = SWIG_From_bool(static_cast< bool >(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_delete_TlsInfo(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::TlsInfo *arg1 = (pj::TlsInfo *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__TlsInfo, SWIG_POINTER_DISOWN |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "delete_TlsInfo" "', argument " "1"" of type '" "pj::TlsInfo *""'"); 
  }
  arg1 = reinterpret_cast< pj::TlsInfo * >(argp1);
  delete arg1;
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *TlsInfo_swigregister(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *obj;
  if (!SWIG_Python_UnpackTuple(args, "swigregister", 1, 1, &obj)) return NULL;
  SWIG_TypeNewClientData(SWIGTYPE_p_pj__TlsInfo, SWIG_NewClientData(obj));
  return SWIG_Py_Void();
}

SWIGINTERN PyObject *TlsInfo_swiginit(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  return SWIG_Python_InitShadowInstance(args);
}

SWIGINTERN PyObject *_wrap_OnTransportStateParam_hnd_set(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::OnTransportStateParam *arg1 = (pj::OnTransportStateParam *) 0 ;
  pj::TransportHandle arg2 = (pj::TransportHandle) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  int res2 ;
  PyObject *swig_obj[2] ;
  
  if (!SWIG_Python_UnpackTuple(args, "OnTransportStateParam_hnd_set", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__OnTransportStateParam, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "OnTransportStateParam_hnd_set" "', argument " "1"" of type '" "pj::OnTransportStateParam *""'"); 
  }
  arg1 = reinterpret_cast< pj::OnTransportStateParam * >(argp1);
  res2 = SWIG_ConvertPtr(swig_obj[1],SWIG_as_voidptrptr(&arg2), 0, SWIG_POINTER_DISOWN);
  if (!SWIG_IsOK(res2)) {
    SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "OnTransportStateParam_hnd_set" "', argument " "2"" of type '" "pj::TransportHandle""'"); 
  }
  if (arg1) (arg1)->hnd = arg2;
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_OnTransportStateParam_hnd_get(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::OnTransportStateParam *arg1 = (pj::OnTransportStateParam *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  pj::TransportHandle result;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__OnTransportStateParam, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "OnTransportStateParam_hnd_get" "', argument " "1"" of type '" "pj::OnTransportStateParam *""'"); 
  }
  arg1 = reinterpret_cast< pj::OnTransportStateParam * >(argp1);
  result = (pj::TransportHandle) ((arg1)->hnd);
  resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(result), SWIGTYPE_p_void, 0 |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_OnTransportStateParam_type_set(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::OnTransportStateParam *arg1 = (pj::OnTransportStateParam *) 0 ;
  pj::string *arg2 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  int res2 = SWIG_OLDOBJ ;
  PyObject *swig_obj[2] ;
  
  if (!SWIG_Python_UnpackTuple(args, "OnTransportStateParam_type_set", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__OnTransportStateParam, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "OnTransportStateParam_type_set" "', argument " "1"" of type '" "pj::OnTransportStateParam *""'"); 
  }
  arg1 = reinterpret_cast< pj::OnTransportStateParam * >(argp1);
  {
    std::string *ptr = (std::string *)0;
    res2 = SWIG_AsPtr_std_string(swig_obj[1], &ptr);
    if (!SWIG_IsOK(res2)) {
      SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "OnTransportStateParam_type_set" "', argument " "2"" of type '" "pj::string const &""'"); 
    }
    if (!ptr) {
      SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "OnTransportStateParam_type_set" "', argument " "2"" of type '" "pj::string const &""'"); 
    }
    arg2 = ptr;
  }
  if (arg1) (arg1)->type = *arg2;
  resultobj = SWIG_Py_Void();
  if (SWIG_IsNewObj(res2)) delete arg2;
  return resultobj;
fail:
  if (SWIG_IsNewObj(res2)) delete arg2;
  return NULL;
}


SWIGINTERN PyObject *_wrap_OnTransportStateParam_type_get(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::OnTransportStateParam *arg1 = (pj::OnTransportStateParam *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  pj::string *result = 0 ;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__OnTransportStateParam, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "OnTransportStateParam_type_get" "', argument " "1"" of type '" "pj::OnTransportStateParam *""'"); 
  }
  arg1 = reinterpret_cast< pj::OnTransportStateParam * >(argp1);
  result = (pj::string *) & ((arg1)->type);
  resultobj = SWIG_From_std_string(static_cast< std::string >(*result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_OnTransportStateParam_state_set(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::OnTransportStateParam *arg1 = (pj::OnTransportStateParam *) 0 ;
  pjsip_transport_state arg2 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  int val2 ;
  int ecode2 = 0 ;
  PyObject *swig_obj[2] ;
  
  if (!SWIG_Python_UnpackTuple(args, "OnTransportStateParam_state_set", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__OnTransportStateParam, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "OnTransportStateParam_state_set" "', argument " "1"" of type '" "pj::OnTransportStateParam *""'"); 
  }
  arg1 = reinterpret_cast< pj::OnTransportStateParam * >(argp1);
  ecode2 = SWIG_AsVal_int(swig_obj[1], &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "OnTransportStateParam_state_set" "', argument " "2"" of type '" "pjsip_transport_state""'");
  } 
  arg2 = static_cast< pjsip_transport_state >(val2);
  if (arg1) (arg1)->state = arg2;
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_OnTransportStateParam_state_get(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::OnTransportStateParam *arg1 = (pj::OnTransportStateParam *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  pjsip_transport_state result;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__OnTransportStateParam, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "OnTransportStateParam_state_get" "', argument " "1"" of type '" "pj::OnTransportStateParam *""'"); 
  }
  arg1 = reinterpret_cast< pj::OnTransportStateParam * >(argp1);
  result = (pjsip_transport_state) ((arg1)->state);
  resultobj = SWIG_From_int(static_cast< int >(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_OnTransportStateParam_lastError_set(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::OnTransportStateParam *arg1 = (pj::OnTransportStateParam *) 0 ;
  pj_status_t arg2 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  int val2 ;
  int ecode2 = 0 ;
  PyObject *swig_obj[2] ;
  
  if (!SWIG_Python_UnpackTuple(args, "OnTransportStateParam_lastError_set", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__OnTransportStateParam, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "OnTransportStateParam_lastError_set" "', argument " "1"" of type '" "pj::OnTransportStateParam *""'"); 
  }
  arg1 = reinterpret_cast< pj::OnTransportStateParam * >(argp1);
  ecode2 = SWIG_AsVal_int(swig_obj[1], &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "OnTransportStateParam_lastError_set" "', argument " "2"" of type '" "pj_status_t""'");
  } 
  arg2 = static_cast< pj_status_t >(val2);
  if (arg1) (arg1)->lastError = arg2;
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_OnTransportStateParam_lastError_get(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::OnTransportStateParam *arg1 = (pj::OnTransportStateParam *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  pj_status_t result;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__OnTransportStateParam, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "OnTransportStateParam_lastError_get" "', argument " "1"" of type '" "pj::OnTransportStateParam *""'"); 
  }
  arg1 = reinterpret_cast< pj::OnTransportStateParam * >(argp1);
  result = (pj_status_t) ((arg1)->lastError);
  resultobj = SWIG_From_int(static_cast< int >(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_OnTransportStateParam_tlsInfo_set(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::OnTransportStateParam *arg1 = (pj::OnTransportStateParam *) 0 ;
  pj::TlsInfo *arg2 = (pj::TlsInfo *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  void *argp2 = 0 ;
  int res2 = 0 ;
  PyObject *swig_obj[2] ;
  
  if (!SWIG_Python_UnpackTuple(args, "OnTransportStateParam_tlsInfo_set", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__OnTransportStateParam, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "OnTransportStateParam_tlsInfo_set" "', argument " "1"" of type '" "pj::OnTransportStateParam *""'"); 
  }
  arg1 = reinterpret_cast< pj::OnTransportStateParam * >(argp1);
  res2 = SWIG_ConvertPtr(swig_obj[1], &argp2,SWIGTYPE_p_pj__TlsInfo, 0 |  0 );
  if (!SWIG_IsOK(res2)) {
    SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "OnTransportStateParam_tlsInfo_set" "', argument " "2"" of type '" "pj::TlsInfo *""'"); 
  }
  arg2 = reinterpret_cast< pj::TlsInfo * >(argp2);
  if (arg1) (arg1)->tlsInfo = *arg2;
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_OnTransportStateParam_tlsInfo_get(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::OnTransportStateParam *arg1 = (pj::OnTransportStateParam *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  pj::TlsInfo *result = 0 ;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__OnTransportStateParam, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "OnTransportStateParam_tlsInfo_get" "', argument " "1"" of type '" "pj::OnTransportStateParam *""'"); 
  }
  arg1 = reinterpret_cast< pj::OnTransportStateParam * >(argp1);
  result = (pj::TlsInfo *)& ((arg1)->tlsInfo);
  resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(result), SWIGTYPE_p_pj__TlsInfo, 0 |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_new_OnTransportStateParam(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::OnTransportStateParam *result = 0 ;
  
  if (!SWIG_Python_UnpackTuple(args, "new_OnTransportStateParam", 0, 0, 0)) SWIG_fail;
  result = (pj::OnTransportStateParam *)new pj::OnTransportStateParam();
  resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(result), SWIGTYPE_p_pj__OnTransportStateParam, SWIG_POINTER_NEW |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_delete_OnTransportStateParam(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::OnTransportStateParam *arg1 = (pj::OnTransportStateParam *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__OnTransportStateParam, SWIG_POINTER_DISOWN |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "delete_OnTransportStateParam" "', argument " "1"" of type '" "pj::OnTransportStateParam *""'"); 
  }
  arg1 = reinterpret_cast< pj::OnTransportStateParam * >(argp1);
  delete arg1;
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *OnTransportStateParam_swigregister(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *obj;
  if (!SWIG_Python_UnpackTuple(args, "swigregister", 1, 1, &obj)) return NULL;
  SWIG_TypeNewClientData(SWIGTYPE_p_pj__OnTransportStateParam, SWIG_NewClientData(obj));
  return SWIG_Py_Void();
}

SWIGINTERN PyObject *OnTransportStateParam_swiginit(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  return SWIG_Python_InitShadowInstance(args);
}

SWIGINTERN PyObject *_wrap_OnSelectAccountParam_rdata_set(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::OnSelectAccountParam *arg1 = (pj::OnSelectAccountParam *) 0 ;
  pj::SipRxData *arg2 = (pj::SipRxData *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  void *argp2 = 0 ;
  int res2 = 0 ;
  PyObject *swig_obj[2] ;
  
  if (!SWIG_Python_UnpackTuple(args, "OnSelectAccountParam_rdata_set", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__OnSelectAccountParam, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "OnSelectAccountParam_rdata_set" "', argument " "1"" of type '" "pj::OnSelectAccountParam *""'"); 
  }
  arg1 = reinterpret_cast< pj::OnSelectAccountParam * >(argp1);
  res2 = SWIG_ConvertPtr(swig_obj[1], &argp2,SWIGTYPE_p_pj__SipRxData, 0 |  0 );
  if (!SWIG_IsOK(res2)) {
    SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "OnSelectAccountParam_rdata_set" "', argument " "2"" of type '" "pj::SipRxData *""'"); 
  }
  arg2 = reinterpret_cast< pj::SipRxData * >(argp2);
  if (arg1) (arg1)->rdata = *arg2;
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_OnSelectAccountParam_rdata_get(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::OnSelectAccountParam *arg1 = (pj::OnSelectAccountParam *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  pj::SipRxData *result = 0 ;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__OnSelectAccountParam, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "OnSelectAccountParam_rdata_get" "', argument " "1"" of type '" "pj::OnSelectAccountParam *""'"); 
  }
  arg1 = reinterpret_cast< pj::OnSelectAccountParam * >(argp1);
  result = (pj::SipRxData *)& ((arg1)->rdata);
  resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(result), SWIGTYPE_p_pj__SipRxData, 0 |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_OnSelectAccountParam_accountIndex_set(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::OnSelectAccountParam *arg1 = (pj::OnSelectAccountParam *) 0 ;
  int arg2 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  int val2 ;
  int ecode2 = 0 ;
  PyObject *swig_obj[2] ;
  
  if (!SWIG_Python_UnpackTuple(args, "OnSelectAccountParam_accountIndex_set", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__OnSelectAccountParam, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "OnSelectAccountParam_accountIndex_set" "', argument " "1"" of type '" "pj::OnSelectAccountParam *""'"); 
  }
  arg1 = reinterpret_cast< pj::OnSelectAccountParam * >(argp1);
  ecode2 = SWIG_AsVal_int(swig_obj[1], &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "OnSelectAccountParam_accountIndex_set" "', argument " "2"" of type '" "int""'");
  } 
  arg2 = static_cast< int >(val2);
  if (arg1) (arg1)->accountIndex = arg2;
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_OnSelectAccountParam_accountIndex_get(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::OnSelectAccountParam *arg1 = (pj::OnSelectAccountParam *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  int result;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__OnSelectAccountParam, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "OnSelectAccountParam_accountIndex_get" "', argument " "1"" of type '" "pj::OnSelectAccountParam *""'"); 
  }
  arg1 = reinterpret_cast< pj::OnSelectAccountParam * >(argp1);
  result = (int) ((arg1)->accountIndex);
  resultobj = SWIG_From_int(static_cast< int >(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_new_OnSelectAccountParam(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::OnSelectAccountParam *result = 0 ;
  
  if (!SWIG_Python_UnpackTuple(args, "new_OnSelectAccountParam", 0, 0, 0)) SWIG_fail;
  result = (pj::OnSelectAccountParam *)new pj::OnSelectAccountParam();
  resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(result), SWIGTYPE_p_pj__OnSelectAccountParam, SWIG_POINTER_NEW |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_delete_OnSelectAccountParam(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::OnSelectAccountParam *arg1 = (pj::OnSelectAccountParam *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__OnSelectAccountParam, SWIG_POINTER_DISOWN |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "delete_OnSelectAccountParam" "', argument " "1"" of type '" "pj::OnSelectAccountParam *""'"); 
  }
  arg1 = reinterpret_cast< pj::OnSelectAccountParam * >(argp1);
  delete arg1;
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *OnSelectAccountParam_swigregister(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *obj;
  if (!SWIG_Python_UnpackTuple(args, "swigregister", 1, 1, &obj)) return NULL;
  SWIG_TypeNewClientData(SWIGTYPE_p_pj__OnSelectAccountParam, SWIG_NewClientData(obj));
  return SWIG_Py_Void();
}

SWIGINTERN PyObject *OnSelectAccountParam_swiginit(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  return SWIG_Python_InitShadowInstance(args);
}

SWIGINTERN PyObject *_wrap_IpChangeParam_restartListener_set(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::IpChangeParam *arg1 = (pj::IpChangeParam *) 0 ;
  bool arg2 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  bool val2 ;
  int ecode2 = 0 ;
  PyObject *swig_obj[2] ;
  
  if (!SWIG_Python_UnpackTuple(args, "IpChangeParam_restartListener_set", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__IpChangeParam, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "IpChangeParam_restartListener_set" "', argument " "1"" of type '" "pj::IpChangeParam *""'"); 
  }
  arg1 = reinterpret_cast< pj::IpChangeParam * >(argp1);
  ecode2 = SWIG_AsVal_bool(swig_obj[1], &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "IpChangeParam_restartListener_set" "', argument " "2"" of type '" "bool""'");
  } 
  arg2 = static_cast< bool >(val2);
  if (arg1) (arg1)->restartListener = arg2;
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_IpChangeParam_restartListener_get(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::IpChangeParam *arg1 = (pj::IpChangeParam *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  bool result;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__IpChangeParam, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "IpChangeParam_restartListener_get" "', argument " "1"" of type '" "pj::IpChangeParam *""'"); 
  }
  arg1 = reinterpret_cast< pj::IpChangeParam * >(argp1);
  result = (bool) ((arg1)->restartListener);
  resultobj = SWIG_From_bool(static_cast< bool >(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_IpChangeParam_restartLisDelay_set(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::IpChangeParam *arg1 = (pj::IpChangeParam *) 0 ;
  unsigned int arg2 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  unsigned int val2 ;
  int ecode2 = 0 ;
  PyObject *swig_obj[2] ;
  
  if (!SWIG_Python_UnpackTuple(args, "IpChangeParam_restartLisDelay_set", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__IpChangeParam, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "IpChangeParam_restartLisDelay_set" "', argument " "1"" of type '" "pj::IpChangeParam *""'"); 
  }
  arg1 = reinterpret_cast< pj::IpChangeParam * >(argp1);
  ecode2 = SWIG_AsVal_unsigned_SS_int(swig_obj[1], &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "IpChangeParam_restartLisDelay_set" "', argument " "2"" of type '" "unsigned int""'");
  } 
  arg2 = static_cast< unsigned int >(val2);
  if (arg1) (arg1)->restartLisDelay = arg2;
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_IpChangeParam_restartLisDelay_get(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::IpChangeParam *arg1 = (pj::IpChangeParam *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  unsigned int result;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__IpChangeParam, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "IpChangeParam_restartLisDelay_get" "', argument " "1"" of type '" "pj::IpChangeParam *""'"); 
  }
  arg1 = reinterpret_cast< pj::IpChangeParam * >(argp1);
  result = (unsigned int) ((arg1)->restartLisDelay);
  resultobj = SWIG_From_unsigned_SS_int(static_cast< unsigned int >(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_new_IpChangeParam(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::IpChangeParam *result = 0 ;
  
  if (!SWIG_Python_UnpackTuple(args, "new_IpChangeParam", 0, 0, 0)) SWIG_fail;
  result = (pj::IpChangeParam *)new pj::IpChangeParam();
  resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(result), SWIGTYPE_p_pj__IpChangeParam, SWIG_POINTER_NEW |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_delete_IpChangeParam(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::IpChangeParam *arg1 = (pj::IpChangeParam *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__IpChangeParam, SWIG_POINTER_DISOWN |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "delete_IpChangeParam" "', argument " "1"" of type '" "pj::IpChangeParam *""'"); 
  }
  arg1 = reinterpret_cast< pj::IpChangeParam * >(argp1);
  delete arg1;
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *IpChangeParam_swigregister(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *obj;
  if (!SWIG_Python_UnpackTuple(args, "swigregister", 1, 1, &obj)) return NULL;
  SWIG_TypeNewClientData(SWIGTYPE_p_pj__IpChangeParam, SWIG_NewClientData(obj));
  return SWIG_Py_Void();
}

SWIGINTERN PyObject *IpChangeParam_swiginit(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  return SWIG_Python_InitShadowInstance(args);
}

SWIGINTERN PyObject *_wrap_RegProgressParam_isRegister_set(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::RegProgressParam *arg1 = (pj::RegProgressParam *) 0 ;
  bool arg2 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  bool val2 ;
  int ecode2 = 0 ;
  PyObject *swig_obj[2] ;
  
  if (!SWIG_Python_UnpackTuple(args, "RegProgressParam_isRegister_set", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__RegProgressParam, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "RegProgressParam_isRegister_set" "', argument " "1"" of type '" "pj::RegProgressParam *""'"); 
  }
  arg1 = reinterpret_cast< pj::RegProgressParam * >(argp1);
  ecode2 = SWIG_AsVal_bool(swig_obj[1], &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "RegProgressParam_isRegister_set" "', argument " "2"" of type '" "bool""'");
  } 
  arg2 = static_cast< bool >(val2);
  if (arg1) (arg1)->isRegister = arg2;
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_RegProgressParam_isRegister_get(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::RegProgressParam *arg1 = (pj::RegProgressParam *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  bool result;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__RegProgressParam, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "RegProgressParam_isRegister_get" "', argument " "1"" of type '" "pj::RegProgressParam *""'"); 
  }
  arg1 = reinterpret_cast< pj::RegProgressParam * >(argp1);
  result = (bool) ((arg1)->isRegister);
  resultobj = SWIG_From_bool(static_cast< bool >(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_RegProgressParam_code_set(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::RegProgressParam *arg1 = (pj::RegProgressParam *) 0 ;
  int arg2 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  int val2 ;
  int ecode2 = 0 ;
  PyObject *swig_obj[2] ;
  
  if (!SWIG_Python_UnpackTuple(args, "RegProgressParam_code_set", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__RegProgressParam, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "RegProgressParam_code_set" "', argument " "1"" of type '" "pj::RegProgressParam *""'"); 
  }
  arg1 = reinterpret_cast< pj::RegProgressParam * >(argp1);
  ecode2 = SWIG_AsVal_int(swig_obj[1], &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "RegProgressParam_code_set" "', argument " "2"" of type '" "int""'");
  } 
  arg2 = static_cast< int >(val2);
  if (arg1) (arg1)->code = arg2;
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_RegProgressParam_code_get(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::RegProgressParam *arg1 = (pj::RegProgressParam *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  int result;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__RegProgressParam, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "RegProgressParam_code_get" "', argument " "1"" of type '" "pj::RegProgressParam *""'"); 
  }
  arg1 = reinterpret_cast< pj::RegProgressParam * >(argp1);
  result = (int) ((arg1)->code);
  resultobj = SWIG_From_int(static_cast< int >(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_new_RegProgressParam(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::RegProgressParam *result = 0 ;
  
  if (!SWIG_Python_UnpackTuple(args, "new_RegProgressParam", 0, 0, 0)) SWIG_fail;
  result = (pj::RegProgressParam *)new pj::RegProgressParam();
  resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(result), SWIGTYPE_p_pj__RegProgressParam, SWIG_POINTER_NEW |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_delete_RegProgressParam(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::RegProgressParam *arg1 = (pj::RegProgressParam *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__RegProgressParam, SWIG_POINTER_DISOWN |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "delete_RegProgressParam" "', argument " "1"" of type '" "pj::RegProgressParam *""'"); 
  }
  arg1 = reinterpret_cast< pj::RegProgressParam * >(argp1);
  delete arg1;
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *RegProgressParam_swigregister(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *obj;
  if (!SWIG_Python_UnpackTuple(args, "swigregister", 1, 1, &obj)) return NULL;
  SWIG_TypeNewClientData(SWIGTYPE_p_pj__RegProgressParam, SWIG_NewClientData(obj));
  return SWIG_Py_Void();
}

SWIGINTERN PyObject *RegProgressParam_swiginit(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  return SWIG_Python_InitShadowInstance(args);
}

SWIGINTERN PyObject *_wrap_OnIpChangeProgressParam_op_set(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::OnIpChangeProgressParam *arg1 = (pj::OnIpChangeProgressParam *) 0 ;
  pjsua_ip_change_op arg2 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  int val2 ;
  int ecode2 = 0 ;
  PyObject *swig_obj[2] ;
  
  if (!SWIG_Python_UnpackTuple(args, "OnIpChangeProgressParam_op_set", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__OnIpChangeProgressParam, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "OnIpChangeProgressParam_op_set" "', argument " "1"" of type '" "pj::OnIpChangeProgressParam *""'"); 
  }
  arg1 = reinterpret_cast< pj::OnIpChangeProgressParam * >(argp1);
  ecode2 = SWIG_AsVal_int(swig_obj[1], &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "OnIpChangeProgressParam_op_set" "', argument " "2"" of type '" "pjsua_ip_change_op""'");
  } 
  arg2 = static_cast< pjsua_ip_change_op >(val2);
  if (arg1) (arg1)->op = arg2;
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_OnIpChangeProgressParam_op_get(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::OnIpChangeProgressParam *arg1 = (pj::OnIpChangeProgressParam *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  pjsua_ip_change_op result;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__OnIpChangeProgressParam, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "OnIpChangeProgressParam_op_get" "', argument " "1"" of type '" "pj::OnIpChangeProgressParam *""'"); 
  }
  arg1 = reinterpret_cast< pj::OnIpChangeProgressParam * >(argp1);
  result = (pjsua_ip_change_op) ((arg1)->op);
  resultobj = SWIG_From_int(static_cast< int >(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_OnIpChangeProgressParam_status_set(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::OnIpChangeProgressParam *arg1 = (pj::OnIpChangeProgressParam *) 0 ;
  pj_status_t arg2 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  int val2 ;
  int ecode2 = 0 ;
  PyObject *swig_obj[2] ;
  
  if (!SWIG_Python_UnpackTuple(args, "OnIpChangeProgressParam_status_set", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__OnIpChangeProgressParam, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "OnIpChangeProgressParam_status_set" "', argument " "1"" of type '" "pj::OnIpChangeProgressParam *""'"); 
  }
  arg1 = reinterpret_cast< pj::OnIpChangeProgressParam * >(argp1);
  ecode2 = SWIG_AsVal_int(swig_obj[1], &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "OnIpChangeProgressParam_status_set" "', argument " "2"" of type '" "pj_status_t""'");
  } 
  arg2 = static_cast< pj_status_t >(val2);
  if (arg1) (arg1)->status = arg2;
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_OnIpChangeProgressParam_status_get(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::OnIpChangeProgressParam *arg1 = (pj::OnIpChangeProgressParam *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  pj_status_t result;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__OnIpChangeProgressParam, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "OnIpChangeProgressParam_status_get" "', argument " "1"" of type '" "pj::OnIpChangeProgressParam *""'"); 
  }
  arg1 = reinterpret_cast< pj::OnIpChangeProgressParam * >(argp1);
  result = (pj_status_t) ((arg1)->status);
  resultobj = SWIG_From_int(static_cast< int >(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_OnIpChangeProgressParam_transportId_set(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::OnIpChangeProgressParam *arg1 = (pj::OnIpChangeProgressParam *) 0 ;
  pj::TransportId arg2 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  int val2 ;
  int ecode2 = 0 ;
  PyObject *swig_obj[2] ;
  
  if (!SWIG_Python_UnpackTuple(args, "OnIpChangeProgressParam_transportId_set", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__OnIpChangeProgressParam, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "OnIpChangeProgressParam_transportId_set" "', argument " "1"" of type '" "pj::OnIpChangeProgressParam *""'"); 
  }
  arg1 = reinterpret_cast< pj::OnIpChangeProgressParam * >(argp1);
  ecode2 = SWIG_AsVal_int(swig_obj[1], &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "OnIpChangeProgressParam_transportId_set" "', argument " "2"" of type '" "pj::TransportId""'");
  } 
  arg2 = static_cast< pj::TransportId >(val2);
  if (arg1) (arg1)->transportId = arg2;
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_OnIpChangeProgressParam_transportId_get(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::OnIpChangeProgressParam *arg1 = (pj::OnIpChangeProgressParam *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  pj::TransportId result;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__OnIpChangeProgressParam, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "OnIpChangeProgressParam_transportId_get" "', argument " "1"" of type '" "pj::OnIpChangeProgressParam *""'"); 
  }
  arg1 = reinterpret_cast< pj::OnIpChangeProgressParam * >(argp1);
  result = (pj::TransportId) ((arg1)->transportId);
  resultobj = SWIG_From_int(static_cast< int >(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_OnIpChangeProgressParam_accId_set(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::OnIpChangeProgressParam *arg1 = (pj::OnIpChangeProgressParam *) 0 ;
  int arg2 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  int val2 ;
  int ecode2 = 0 ;
  PyObject *swig_obj[2] ;
  
  if (!SWIG_Python_UnpackTuple(args, "OnIpChangeProgressParam_accId_set", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__OnIpChangeProgressParam, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "OnIpChangeProgressParam_accId_set" "', argument " "1"" of type '" "pj::OnIpChangeProgressParam *""'"); 
  }
  arg1 = reinterpret_cast< pj::OnIpChangeProgressParam * >(argp1);
  ecode2 = SWIG_AsVal_int(swig_obj[1], &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "OnIpChangeProgressParam_accId_set" "', argument " "2"" of type '" "int""'");
  } 
  arg2 = static_cast< int >(val2);
  if (arg1) (arg1)->accId = arg2;
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_OnIpChangeProgressParam_accId_get(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::OnIpChangeProgressParam *arg1 = (pj::OnIpChangeProgressParam *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  int result;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__OnIpChangeProgressParam, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "OnIpChangeProgressParam_accId_get" "', argument " "1"" of type '" "pj::OnIpChangeProgressParam *""'"); 
  }
  arg1 = reinterpret_cast< pj::OnIpChangeProgressParam * >(argp1);
  result = (int) ((arg1)->accId);
  resultobj = SWIG_From_int(static_cast< int >(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_OnIpChangeProgressParam_callId_set(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::OnIpChangeProgressParam *arg1 = (pj::OnIpChangeProgressParam *) 0 ;
  int arg2 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  int val2 ;
  int ecode2 = 0 ;
  PyObject *swig_obj[2] ;
  
  if (!SWIG_Python_UnpackTuple(args, "OnIpChangeProgressParam_callId_set", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__OnIpChangeProgressParam, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "OnIpChangeProgressParam_callId_set" "', argument " "1"" of type '" "pj::OnIpChangeProgressParam *""'"); 
  }
  arg1 = reinterpret_cast< pj::OnIpChangeProgressParam * >(argp1);
  ecode2 = SWIG_AsVal_int(swig_obj[1], &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "OnIpChangeProgressParam_callId_set" "', argument " "2"" of type '" "int""'");
  } 
  arg2 = static_cast< int >(val2);
  if (arg1) (arg1)->callId = arg2;
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_OnIpChangeProgressParam_callId_get(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::OnIpChangeProgressParam *arg1 = (pj::OnIpChangeProgressParam *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  int result;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__OnIpChangeProgressParam, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "OnIpChangeProgressParam_callId_get" "', argument " "1"" of type '" "pj::OnIpChangeProgressParam *""'"); 
  }
  arg1 = reinterpret_cast< pj::OnIpChangeProgressParam * >(argp1);
  result = (int) ((arg1)->callId);
  resultobj = SWIG_From_int(static_cast< int >(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_OnIpChangeProgressParam_regInfo_set(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::OnIpChangeProgressParam *arg1 = (pj::OnIpChangeProgressParam *) 0 ;
  pj::RegProgressParam *arg2 = (pj::RegProgressParam *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  void *argp2 = 0 ;
  int res2 = 0 ;
  PyObject *swig_obj[2] ;
  
  if (!SWIG_Python_UnpackTuple(args, "OnIpChangeProgressParam_regInfo_set", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__OnIpChangeProgressParam, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "OnIpChangeProgressParam_regInfo_set" "', argument " "1"" of type '" "pj::OnIpChangeProgressParam *""'"); 
  }
  arg1 = reinterpret_cast< pj::OnIpChangeProgressParam * >(argp1);
  res2 = SWIG_ConvertPtr(swig_obj[1], &argp2,SWIGTYPE_p_pj__RegProgressParam, 0 |  0 );
  if (!SWIG_IsOK(res2)) {
    SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "OnIpChangeProgressParam_regInfo_set" "', argument " "2"" of type '" "pj::RegProgressParam *""'"); 
  }
  arg2 = reinterpret_cast< pj::RegProgressParam * >(argp2);
  if (arg1) (arg1)->regInfo = *arg2;
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_OnIpChangeProgressParam_regInfo_get(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::OnIpChangeProgressParam *arg1 = (pj::OnIpChangeProgressParam *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  pj::RegProgressParam *result = 0 ;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__OnIpChangeProgressParam, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "OnIpChangeProgressParam_regInfo_get" "', argument " "1"" of type '" "pj::OnIpChangeProgressParam *""'"); 
  }
  arg1 = reinterpret_cast< pj::OnIpChangeProgressParam * >(argp1);
  result = (pj::RegProgressParam *)& ((arg1)->regInfo);
  resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(result), SWIGTYPE_p_pj__RegProgressParam, 0 |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_new_OnIpChangeProgressParam(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::OnIpChangeProgressParam *result = 0 ;
  
  if (!SWIG_Python_UnpackTuple(args, "new_OnIpChangeProgressParam", 0, 0, 0)) SWIG_fail;
  result = (pj::OnIpChangeProgressParam *)new pj::OnIpChangeProgressParam();
  resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(result), SWIGTYPE_p_pj__OnIpChangeProgressParam, SWIG_POINTER_NEW |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_delete_OnIpChangeProgressParam(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::OnIpChangeProgressParam *arg1 = (pj::OnIpChangeProgressParam *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__OnIpChangeProgressParam, SWIG_POINTER_DISOWN |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "delete_OnIpChangeProgressParam" "', argument " "1"" of type '" "pj::OnIpChangeProgressParam *""'"); 
  }
  arg1 = reinterpret_cast< pj::OnIpChangeProgressParam * >(argp1);
  delete arg1;
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *OnIpChangeProgressParam_swigregister(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *obj;
  if (!SWIG_Python_UnpackTuple(args, "swigregister", 1, 1, &obj)) return NULL;
  SWIG_TypeNewClientData(SWIGTYPE_p_pj__OnIpChangeProgressParam, SWIG_NewClientData(obj));
  return SWIG_Py_Void();
}

SWIGINTERN PyObject *OnIpChangeProgressParam_swiginit(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  return SWIG_Python_InitShadowInstance(args);
}

SWIGINTERN PyObject *_wrap_OnMediaEventParam_ev_set(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::OnMediaEventParam *arg1 = (pj::OnMediaEventParam *) 0 ;
  pj::MediaEvent *arg2 = (pj::MediaEvent *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  void *argp2 = 0 ;
  int res2 = 0 ;
  PyObject *swig_obj[2] ;
  
  if (!SWIG_Python_UnpackTuple(args, "OnMediaEventParam_ev_set", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__OnMediaEventParam, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "OnMediaEventParam_ev_set" "', argument " "1"" of type '" "pj::OnMediaEventParam *""'"); 
  }
  arg1 = reinterpret_cast< pj::OnMediaEventParam * >(argp1);
  res2 = SWIG_ConvertPtr(swig_obj[1], &argp2,SWIGTYPE_p_pj__MediaEvent, 0 |  0 );
  if (!SWIG_IsOK(res2)) {
    SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "OnMediaEventParam_ev_set" "', argument " "2"" of type '" "pj::MediaEvent *""'"); 
  }
  arg2 = reinterpret_cast< pj::MediaEvent * >(argp2);
  if (arg1) (arg1)->ev = *arg2;
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_OnMediaEventParam_ev_get(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::OnMediaEventParam *arg1 = (pj::OnMediaEventParam *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  pj::MediaEvent *result = 0 ;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__OnMediaEventParam, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "OnMediaEventParam_ev_get" "', argument " "1"" of type '" "pj::OnMediaEventParam *""'"); 
  }
  arg1 = reinterpret_cast< pj::OnMediaEventParam * >(argp1);
  result = (pj::MediaEvent *)& ((arg1)->ev);
  resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(result), SWIGTYPE_p_pj__MediaEvent, 0 |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_new_OnMediaEventParam(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::OnMediaEventParam *result = 0 ;
  
  if (!SWIG_Python_UnpackTuple(args, "new_OnMediaEventParam", 0, 0, 0)) SWIG_fail;
  result = (pj::OnMediaEventParam *)new pj::OnMediaEventParam();
  resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(result), SWIGTYPE_p_pj__OnMediaEventParam, SWIG_POINTER_NEW |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_delete_OnMediaEventParam(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::OnMediaEventParam *arg1 = (pj::OnMediaEventParam *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__OnMediaEventParam, SWIG_POINTER_DISOWN |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "delete_OnMediaEventParam" "', argument " "1"" of type '" "pj::OnMediaEventParam *""'"); 
  }
  arg1 = reinterpret_cast< pj::OnMediaEventParam * >(argp1);
  delete arg1;
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *OnMediaEventParam_swigregister(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *obj;
  if (!SWIG_Python_UnpackTuple(args, "swigregister", 1, 1, &obj)) return NULL;
  SWIG_TypeNewClientData(SWIGTYPE_p_pj__OnMediaEventParam, SWIG_NewClientData(obj));
  return SWIG_Py_Void();
}

SWIGINTERN PyObject *OnMediaEventParam_swiginit(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  return SWIG_Python_InitShadowInstance(args);
}

SWIGINTERN PyObject *_wrap_DigestChallenge_realm_set(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::DigestChallenge *arg1 = (pj::DigestChallenge *) 0 ;
  std::string *arg2 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  int res2 = SWIG_OLDOBJ ;
  PyObject *swig_obj[2] ;
  
  if (!SWIG_Python_UnpackTuple(args, "DigestChallenge_realm_set", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__DigestChallenge, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "DigestChallenge_realm_set" "', argument " "1"" of type '" "pj::DigestChallenge *""'"); 
  }
  arg1 = reinterpret_cast< pj::DigestChallenge * >(argp1);
  {
    std::string *ptr = (std::string *)0;
    res2 = SWIG_AsPtr_std_string(swig_obj[1], &ptr);
    if (!SWIG_IsOK(res2)) {
      SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "DigestChallenge_realm_set" "', argument " "2"" of type '" "std::string const &""'"); 
    }
    if (!ptr) {
      SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "DigestChallenge_realm_set" "', argument " "2"" of type '" "std::string const &""'"); 
    }
    arg2 = ptr;
  }
  if (arg1) (arg1)->realm = *arg2;
  resultobj = SWIG_Py_Void();
  if (SWIG_IsNewObj(res2)) delete arg2;
  return resultobj;
fail:
  if (SWIG_IsNewObj(res2)) delete arg2;
  return NULL;
}


SWIGINTERN PyObject *_wrap_DigestChallenge_realm_get(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::DigestChallenge *arg1 = (pj::DigestChallenge *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  std::string *result = 0 ;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__DigestChallenge, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "DigestChallenge_realm_get" "', argument " "1"" of type '" "pj::DigestChallenge *""'"); 
  }
  arg1 = reinterpret_cast< pj::DigestChallenge * >(argp1);
  result = (std::string *) & ((arg1)->realm);
  resultobj = SWIG_From_std_string(static_cast< std::string >(*result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_DigestChallenge_otherParam_set(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::DigestChallenge *arg1 = (pj::DigestChallenge *) 0 ;
  pj::StringToStringMap *arg2 = (pj::StringToStringMap *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  void *argp2 = 0 ;
  int res2 = 0 ;
  PyObject *swig_obj[2] ;
  
  if (!SWIG_Python_UnpackTuple(args, "DigestChallenge_otherParam_set", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__DigestChallenge, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "DigestChallenge_otherParam_set" "', argument " "1"" of type '" "pj::DigestChallenge *""'"); 
  }
  arg1 = reinterpret_cast< pj::DigestChallenge * >(argp1);
  res2 = SWIG_ConvertPtr(swig_obj[1], &argp2,SWIGTYPE_p_std__mapT_std__string_std__string_std__lessT_std__string_t_std__allocatorT_std__pairT_std__string_const_std__string_t_t_t, 0 |  0 );
  if (!SWIG_IsOK(res2)) {
    SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "DigestChallenge_otherParam_set" "', argument " "2"" of type '" "pj::StringToStringMap *""'"); 
  }
  arg2 = reinterpret_cast< pj::StringToStringMap * >(argp2);
  if (arg1) (arg1)->otherParam = *arg2;
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_DigestChallenge_otherParam_get(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::DigestChallenge *arg1 = (pj::DigestChallenge *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  pj::StringToStringMap *result = 0 ;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__DigestChallenge, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "DigestChallenge_otherParam_get" "', argument " "1"" of type '" "pj::DigestChallenge *""'"); 
  }
  arg1 = reinterpret_cast< pj::DigestChallenge * >(argp1);
  result = (pj::StringToStringMap *)& ((arg1)->otherParam);
  resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(result), SWIGTYPE_p_std__mapT_std__string_std__string_std__lessT_std__string_t_std__allocatorT_std__pairT_std__string_const_std__string_t_t_t, 0 |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_DigestChallenge_domain_set(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::DigestChallenge *arg1 = (pj::DigestChallenge *) 0 ;
  std::string *arg2 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  int res2 = SWIG_OLDOBJ ;
  PyObject *swig_obj[2] ;
  
  if (!SWIG_Python_UnpackTuple(args, "DigestChallenge_domain_set", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__DigestChallenge, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "DigestChallenge_domain_set" "', argument " "1"" of type '" "pj::DigestChallenge *""'"); 
  }
  arg1 = reinterpret_cast< pj::DigestChallenge * >(argp1);
  {
    std::string *ptr = (std::string *)0;
    res2 = SWIG_AsPtr_std_string(swig_obj[1], &ptr);
    if (!SWIG_IsOK(res2)) {
      SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "DigestChallenge_domain_set" "', argument " "2"" of type '" "std::string const &""'"); 
    }
    if (!ptr) {
      SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "DigestChallenge_domain_set" "', argument " "2"" of type '" "std::string const &""'"); 
    }
    arg2 = ptr;
  }
  if (arg1) (arg1)->domain = *arg2;
  resultobj = SWIG_Py_Void();
  if (SWIG_IsNewObj(res2)) delete arg2;
  return resultobj;
fail:
  if (SWIG_IsNewObj(res2)) delete arg2;
  return NULL;
}


SWIGINTERN PyObject *_wrap_DigestChallenge_domain_get(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::DigestChallenge *arg1 = (pj::DigestChallenge *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  std::string *result = 0 ;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__DigestChallenge, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "DigestChallenge_domain_get" "', argument " "1"" of type '" "pj::DigestChallenge *""'"); 
  }
  arg1 = reinterpret_cast< pj::DigestChallenge * >(argp1);
  result = (std::string *) & ((arg1)->domain);
  resultobj = SWIG_From_std_string(static_cast< std::string >(*result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_DigestChallenge_nonce_set(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::DigestChallenge *arg1 = (pj::DigestChallenge *) 0 ;
  std::string *arg2 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  int res2 = SWIG_OLDOBJ ;
  PyObject *swig_obj[2] ;
  
  if (!SWIG_Python_UnpackTuple(args, "DigestChallenge_nonce_set", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__DigestChallenge, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "DigestChallenge_nonce_set" "', argument " "1"" of type '" "pj::DigestChallenge *""'"); 
  }
  arg1 = reinterpret_cast< pj::DigestChallenge * >(argp1);
  {
    std::string *ptr = (std::string *)0;
    res2 = SWIG_AsPtr_std_string(swig_obj[1], &ptr);
    if (!SWIG_IsOK(res2)) {
      SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "DigestChallenge_nonce_set" "', argument " "2"" of type '" "std::string const &""'"); 
    }
    if (!ptr) {
      SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "DigestChallenge_nonce_set" "', argument " "2"" of type '" "std::string const &""'"); 
    }
    arg2 = ptr;
  }
  if (arg1) (arg1)->nonce = *arg2;
  resultobj = SWIG_Py_Void();
  if (SWIG_IsNewObj(res2)) delete arg2;
  return resultobj;
fail:
  if (SWIG_IsNewObj(res2)) delete arg2;
  return NULL;
}


SWIGINTERN PyObject *_wrap_DigestChallenge_nonce_get(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::DigestChallenge *arg1 = (pj::DigestChallenge *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  std::string *result = 0 ;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__DigestChallenge, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "DigestChallenge_nonce_get" "', argument " "1"" of type '" "pj::DigestChallenge *""'"); 
  }
  arg1 = reinterpret_cast< pj::DigestChallenge * >(argp1);
  result = (std::string *) & ((arg1)->nonce);
  resultobj = SWIG_From_std_string(static_cast< std::string >(*result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_DigestChallenge_opaque_set(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::DigestChallenge *arg1 = (pj::DigestChallenge *) 0 ;
  std::string *arg2 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  int res2 = SWIG_OLDOBJ ;
  PyObject *swig_obj[2] ;
  
  if (!SWIG_Python_UnpackTuple(args, "DigestChallenge_opaque_set", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__DigestChallenge, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "DigestChallenge_opaque_set" "', argument " "1"" of type '" "pj::DigestChallenge *""'"); 
  }
  arg1 = reinterpret_cast< pj::DigestChallenge * >(argp1);
  {
    std::string *ptr = (std::string *)0;
    res2 = SWIG_AsPtr_std_string(swig_obj[1], &ptr);
    if (!SWIG_IsOK(res2)) {
      SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "DigestChallenge_opaque_set" "', argument " "2"" of type '" "std::string const &""'"); 
    }
    if (!ptr) {
      SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "DigestChallenge_opaque_set" "', argument " "2"" of type '" "std::string const &""'"); 
    }
    arg2 = ptr;
  }
  if (arg1) (arg1)->opaque = *arg2;
  resultobj = SWIG_Py_Void();
  if (SWIG_IsNewObj(res2)) delete arg2;
  return resultobj;
fail:
  if (SWIG_IsNewObj(res2)) delete arg2;
  return NULL;
}


SWIGINTERN PyObject *_wrap_DigestChallenge_opaque_get(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::DigestChallenge *arg1 = (pj::DigestChallenge *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  std::string *result = 0 ;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__DigestChallenge, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "DigestChallenge_opaque_get" "', argument " "1"" of type '" "pj::DigestChallenge *""'"); 
  }
  arg1 = reinterpret_cast< pj::DigestChallenge * >(argp1);
  result = (std::string *) & ((arg1)->opaque);
  resultobj = SWIG_From_std_string(static_cast< std::string >(*result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_DigestChallenge_stale_set(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::DigestChallenge *arg1 = (pj::DigestChallenge *) 0 ;
  int arg2 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  int val2 ;
  int ecode2 = 0 ;
  PyObject *swig_obj[2] ;
  
  if (!SWIG_Python_UnpackTuple(args, "DigestChallenge_stale_set", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__DigestChallenge, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "DigestChallenge_stale_set" "', argument " "1"" of type '" "pj::DigestChallenge *""'"); 
  }
  arg1 = reinterpret_cast< pj::DigestChallenge * >(argp1);
  ecode2 = SWIG_AsVal_int(swig_obj[1], &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "DigestChallenge_stale_set" "', argument " "2"" of type '" "int""'");
  } 
  arg2 = static_cast< int >(val2);
  if (arg1) (arg1)->stale = arg2;
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_DigestChallenge_stale_get(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::DigestChallenge *arg1 = (pj::DigestChallenge *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  int result;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__DigestChallenge, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "DigestChallenge_stale_get" "', argument " "1"" of type '" "pj::DigestChallenge *""'"); 
  }
  arg1 = reinterpret_cast< pj::DigestChallenge * >(argp1);
  result = (int) ((arg1)->stale);
  resultobj = SWIG_From_int(static_cast< int >(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_DigestChallenge_algorithm_set(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::DigestChallenge *arg1 = (pj::DigestChallenge *) 0 ;
  std::string *arg2 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  int res2 = SWIG_OLDOBJ ;
  PyObject *swig_obj[2] ;
  
  if (!SWIG_Python_UnpackTuple(args, "DigestChallenge_algorithm_set", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__DigestChallenge, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "DigestChallenge_algorithm_set" "', argument " "1"" of type '" "pj::DigestChallenge *""'"); 
  }
  arg1 = reinterpret_cast< pj::DigestChallenge * >(argp1);
  {
    std::string *ptr = (std::string *)0;
    res2 = SWIG_AsPtr_std_string(swig_obj[1], &ptr);
    if (!SWIG_IsOK(res2)) {
      SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "DigestChallenge_algorithm_set" "', argument " "2"" of type '" "std::string const &""'"); 
    }
    if (!ptr) {
      SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "DigestChallenge_algorithm_set" "', argument " "2"" of type '" "std::string const &""'"); 
    }
    arg2 = ptr;
  }
  if (arg1) (arg1)->algorithm = *arg2;
  resultobj = SWIG_Py_Void();
  if (SWIG_IsNewObj(res2)) delete arg2;
  return resultobj;
fail:
  if (SWIG_IsNewObj(res2)) delete arg2;
  return NULL;
}


SWIGINTERN PyObject *_wrap_DigestChallenge_algorithm_get(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::DigestChallenge *arg1 = (pj::DigestChallenge *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  std::string *result = 0 ;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__DigestChallenge, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "DigestChallenge_algorithm_get" "', argument " "1"" of type '" "pj::DigestChallenge *""'"); 
  }
  arg1 = reinterpret_cast< pj::DigestChallenge * >(argp1);
  result = (std::string *) & ((arg1)->algorithm);
  resultobj = SWIG_From_std_string(static_cast< std::string >(*result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_DigestChallenge_qop_set(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::DigestChallenge *arg1 = (pj::DigestChallenge *) 0 ;
  std::string *arg2 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  int res2 = SWIG_OLDOBJ ;
  PyObject *swig_obj[2] ;
  
  if (!SWIG_Python_UnpackTuple(args, "DigestChallenge_qop_set", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__DigestChallenge, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "DigestChallenge_qop_set" "', argument " "1"" of type '" "pj::DigestChallenge *""'"); 
  }
  arg1 = reinterpret_cast< pj::DigestChallenge * >(argp1);
  {
    std::string *ptr = (std::string *)0;
    res2 = SWIG_AsPtr_std_string(swig_obj[1], &ptr);
    if (!SWIG_IsOK(res2)) {
      SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "DigestChallenge_qop_set" "', argument " "2"" of type '" "std::string const &""'"); 
    }
    if (!ptr) {
      SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "DigestChallenge_qop_set" "', argument " "2"" of type '" "std::string const &""'"); 
    }
    arg2 = ptr;
  }
  if (arg1) (arg1)->qop = *arg2;
  resultobj = SWIG_Py_Void();
  if (SWIG_IsNewObj(res2)) delete arg2;
  return resultobj;
fail:
  if (SWIG_IsNewObj(res2)) delete arg2;
  return NULL;
}


SWIGINTERN PyObject *_wrap_DigestChallenge_qop_get(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::DigestChallenge *arg1 = (pj::DigestChallenge *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  std::string *result = 0 ;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__DigestChallenge, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "DigestChallenge_qop_get" "', argument " "1"" of type '" "pj::DigestChallenge *""'"); 
  }
  arg1 = reinterpret_cast< pj::DigestChallenge * >(argp1);
  result = (std::string *) & ((arg1)->qop);
  resultobj = SWIG_From_std_string(static_cast< std::string >(*result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_new_DigestChallenge(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::DigestChallenge *result = 0 ;
  
  if (!SWIG_Python_UnpackTuple(args, "new_DigestChallenge", 0, 0, 0)) SWIG_fail;
  result = (pj::DigestChallenge *)new pj::DigestChallenge();
  resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(result), SWIGTYPE_p_pj__DigestChallenge, SWIG_POINTER_NEW |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_delete_DigestChallenge(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::DigestChallenge *arg1 = (pj::DigestChallenge *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__DigestChallenge, SWIG_POINTER_DISOWN |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "delete_DigestChallenge" "', argument " "1"" of type '" "pj::DigestChallenge *""'"); 
  }
  arg1 = reinterpret_cast< pj::DigestChallenge * >(argp1);
  delete arg1;
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *DigestChallenge_swigregister(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *obj;
  if (!SWIG_Python_UnpackTuple(args, "swigregister", 1, 1, &obj)) return NULL;
  SWIG_TypeNewClientData(SWIGTYPE_p_pj__DigestChallenge, SWIG_NewClientData(obj));
  return SWIG_Py_Void();
}

SWIGINTERN PyObject *DigestChallenge_swiginit(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  return SWIG_Python_InitShadowInstance(args);
}

SWIGINTERN PyObject *_wrap_DigestCredential_realm_set(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::DigestCredential *arg1 = (pj::DigestCredential *) 0 ;
  std::string *arg2 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  int res2 = SWIG_OLDOBJ ;
  PyObject *swig_obj[2] ;
  
  if (!SWIG_Python_UnpackTuple(args, "DigestCredential_realm_set", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__DigestCredential, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "DigestCredential_realm_set" "', argument " "1"" of type '" "pj::DigestCredential *""'"); 
  }
  arg1 = reinterpret_cast< pj::DigestCredential * >(argp1);
  {
    std::string *ptr = (std::string *)0;
    res2 = SWIG_AsPtr_std_string(swig_obj[1], &ptr);
    if (!SWIG_IsOK(res2)) {
      SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "DigestCredential_realm_set" "', argument " "2"" of type '" "std::string const &""'"); 
    }
    if (!ptr) {
      SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "DigestCredential_realm_set" "', argument " "2"" of type '" "std::string const &""'"); 
    }
    arg2 = ptr;
  }
  if (arg1) (arg1)->realm = *arg2;
  resultobj = SWIG_Py_Void();
  if (SWIG_IsNewObj(res2)) delete arg2;
  return resultobj;
fail:
  if (SWIG_IsNewObj(res2)) delete arg2;
  return NULL;
}


SWIGINTERN PyObject *_wrap_DigestCredential_realm_get(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::DigestCredential *arg1 = (pj::DigestCredential *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  std::string *result = 0 ;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__DigestCredential, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "DigestCredential_realm_get" "', argument " "1"" of type '" "pj::DigestCredential *""'"); 
  }
  arg1 = reinterpret_cast< pj::DigestCredential * >(argp1);
  result = (std::string *) & ((arg1)->realm);
  resultobj = SWIG_From_std_string(static_cast< std::string >(*result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_DigestCredential_otherParam_set(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::DigestCredential *arg1 = (pj::DigestCredential *) 0 ;
  pj::StringToStringMap *arg2 = (pj::StringToStringMap *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  void *argp2 = 0 ;
  int res2 = 0 ;
  PyObject *swig_obj[2] ;
  
  if (!SWIG_Python_UnpackTuple(args, "DigestCredential_otherParam_set", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__DigestCredential, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "DigestCredential_otherParam_set" "', argument " "1"" of type '" "pj::DigestCredential *""'"); 
  }
  arg1 = reinterpret_cast< pj::DigestCredential * >(argp1);
  res2 = SWIG_ConvertPtr(swig_obj[1], &argp2,SWIGTYPE_p_std__mapT_std__string_std__string_std__lessT_std__string_t_std__allocatorT_std__pairT_std__string_const_std__string_t_t_t, 0 |  0 );
  if (!SWIG_IsOK(res2)) {
    SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "DigestCredential_otherParam_set" "', argument " "2"" of type '" "pj::StringToStringMap *""'"); 
  }
  arg2 = reinterpret_cast< pj::StringToStringMap * >(argp2);
  if (arg1) (arg1)->otherParam = *arg2;
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_DigestCredential_otherParam_get(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::DigestCredential *arg1 = (pj::DigestCredential *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  pj::StringToStringMap *result = 0 ;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__DigestCredential, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "DigestCredential_otherParam_get" "', argument " "1"" of type '" "pj::DigestCredential *""'"); 
  }
  arg1 = reinterpret_cast< pj::DigestCredential * >(argp1);
  result = (pj::StringToStringMap *)& ((arg1)->otherParam);
  resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(result), SWIGTYPE_p_std__mapT_std__string_std__string_std__lessT_std__string_t_std__allocatorT_std__pairT_std__string_const_std__string_t_t_t, 0 |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_DigestCredential_username_set(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::DigestCredential *arg1 = (pj::DigestCredential *) 0 ;
  std::string *arg2 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  int res2 = SWIG_OLDOBJ ;
  PyObject *swig_obj[2] ;
  
  if (!SWIG_Python_UnpackTuple(args, "DigestCredential_username_set", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__DigestCredential, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "DigestCredential_username_set" "', argument " "1"" of type '" "pj::DigestCredential *""'"); 
  }
  arg1 = reinterpret_cast< pj::DigestCredential * >(argp1);
  {
    std::string *ptr = (std::string *)0;
    res2 = SWIG_AsPtr_std_string(swig_obj[1], &ptr);
    if (!SWIG_IsOK(res2)) {
      SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "DigestCredential_username_set" "', argument " "2"" of type '" "std::string const &""'"); 
    }
    if (!ptr) {
      SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "DigestCredential_username_set" "', argument " "2"" of type '" "std::string const &""'"); 
    }
    arg2 = ptr;
  }
  if (arg1) (arg1)->username = *arg2;
  resultobj = SWIG_Py_Void();
  if (SWIG_IsNewObj(res2)) delete arg2;
  return resultobj;
fail:
  if (SWIG_IsNewObj(res2)) delete arg2;
  return NULL;
}


SWIGINTERN PyObject *_wrap_DigestCredential_username_get(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::DigestCredential *arg1 = (pj::DigestCredential *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  std::string *result = 0 ;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__DigestCredential, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "DigestCredential_username_get" "', argument " "1"" of type '" "pj::DigestCredential *""'"); 
  }
  arg1 = reinterpret_cast< pj::DigestCredential * >(argp1);
  result = (std::string *) & ((arg1)->username);
  resultobj = SWIG_From_std_string(static_cast< std::string >(*result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_DigestCredential_nonce_set(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::DigestCredential *arg1 = (pj::DigestCredential *) 0 ;
  std::string *arg2 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  int res2 = SWIG_OLDOBJ ;
  PyObject *swig_obj[2] ;
  
  if (!SWIG_Python_UnpackTuple(args, "DigestCredential_nonce_set", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__DigestCredential, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "DigestCredential_nonce_set" "', argument " "1"" of type '" "pj::DigestCredential *""'"); 
  }
  arg1 = reinterpret_cast< pj::DigestCredential * >(argp1);
  {
    std::string *ptr = (std::string *)0;
    res2 = SWIG_AsPtr_std_string(swig_obj[1], &ptr);
    if (!SWIG_IsOK(res2)) {
      SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "DigestCredential_nonce_set" "', argument " "2"" of type '" "std::string const &""'"); 
    }
    if (!ptr) {
      SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "DigestCredential_nonce_set" "', argument " "2"" of type '" "std::string const &""'"); 
    }
    arg2 = ptr;
  }
  if (arg1) (arg1)->nonce = *arg2;
  resultobj = SWIG_Py_Void();
  if (SWIG_IsNewObj(res2)) delete arg2;
  return resultobj;
fail:
  if (SWIG_IsNewObj(res2)) delete arg2;
  return NULL;
}


SWIGINTERN PyObject *_wrap_DigestCredential_nonce_get(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::DigestCredential *arg1 = (pj::DigestCredential *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  std::string *result = 0 ;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__DigestCredential, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "DigestCredential_nonce_get" "', argument " "1"" of type '" "pj::DigestCredential *""'"); 
  }
  arg1 = reinterpret_cast< pj::DigestCredential * >(argp1);
  result = (std::string *) & ((arg1)->nonce);
  resultobj = SWIG_From_std_string(static_cast< std::string >(*result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_DigestCredential_uri_set(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::DigestCredential *arg1 = (pj::DigestCredential *) 0 ;
  std::string *arg2 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  int res2 = SWIG_OLDOBJ ;
  PyObject *swig_obj[2] ;
  
  if (!SWIG_Python_UnpackTuple(args, "DigestCredential_uri_set", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__DigestCredential, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "DigestCredential_uri_set" "', argument " "1"" of type '" "pj::DigestCredential *""'"); 
  }
  arg1 = reinterpret_cast< pj::DigestCredential * >(argp1);
  {
    std::string *ptr = (std::string *)0;
    res2 = SWIG_AsPtr_std_string(swig_obj[1], &ptr);
    if (!SWIG_IsOK(res2)) {
      SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "DigestCredential_uri_set" "', argument " "2"" of type '" "std::string const &""'"); 
    }
    if (!ptr) {
      SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "DigestCredential_uri_set" "', argument " "2"" of type '" "std::string const &""'"); 
    }
    arg2 = ptr;
  }
  if (arg1) (arg1)->uri = *arg2;
  resultobj = SWIG_Py_Void();
  if (SWIG_IsNewObj(res2)) delete arg2;
  return resultobj;
fail:
  if (SWIG_IsNewObj(res2)) delete arg2;
  return NULL;
}


SWIGINTERN PyObject *_wrap_DigestCredential_uri_get(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::DigestCredential *arg1 = (pj::DigestCredential *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  std::string *result = 0 ;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__DigestCredential, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "DigestCredential_uri_get" "', argument " "1"" of type '" "pj::DigestCredential *""'"); 
  }
  arg1 = reinterpret_cast< pj::DigestCredential * >(argp1);
  result = (std::string *) & ((arg1)->uri);
  resultobj = SWIG_From_std_string(static_cast< std::string >(*result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_DigestCredential_response_set(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::DigestCredential *arg1 = (pj::DigestCredential *) 0 ;
  std::string *arg2 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  int res2 = SWIG_OLDOBJ ;
  PyObject *swig_obj[2] ;
  
  if (!SWIG_Python_UnpackTuple(args, "DigestCredential_response_set", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__DigestCredential, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "DigestCredential_response_set" "', argument " "1"" of type '" "pj::DigestCredential *""'"); 
  }
  arg1 = reinterpret_cast< pj::DigestCredential * >(argp1);
  {
    std::string *ptr = (std::string *)0;
    res2 = SWIG_AsPtr_std_string(swig_obj[1], &ptr);
    if (!SWIG_IsOK(res2)) {
      SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "DigestCredential_response_set" "', argument " "2"" of type '" "std::string const &""'"); 
    }
    if (!ptr) {
      SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "DigestCredential_response_set" "', argument " "2"" of type '" "std::string const &""'"); 
    }
    arg2 = ptr;
  }
  if (arg1) (arg1)->response = *arg2;
  resultobj = SWIG_Py_Void();
  if (SWIG_IsNewObj(res2)) delete arg2;
  return resultobj;
fail:
  if (SWIG_IsNewObj(res2)) delete arg2;
  return NULL;
}


SWIGINTERN PyObject *_wrap_DigestCredential_response_get(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::DigestCredential *arg1 = (pj::DigestCredential *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  std::string *result = 0 ;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__DigestCredential, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "DigestCredential_response_get" "', argument " "1"" of type '" "pj::DigestCredential *""'"); 
  }
  arg1 = reinterpret_cast< pj::DigestCredential * >(argp1);
  result = (std::string *) & ((arg1)->response);
  resultobj = SWIG_From_std_string(static_cast< std::string >(*result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_DigestCredential_algorithm_set(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::DigestCredential *arg1 = (pj::DigestCredential *) 0 ;
  std::string *arg2 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  int res2 = SWIG_OLDOBJ ;
  PyObject *swig_obj[2] ;
  
  if (!SWIG_Python_UnpackTuple(args, "DigestCredential_algorithm_set", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__DigestCredential, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "DigestCredential_algorithm_set" "', argument " "1"" of type '" "pj::DigestCredential *""'"); 
  }
  arg1 = reinterpret_cast< pj::DigestCredential * >(argp1);
  {
    std::string *ptr = (std::string *)0;
    res2 = SWIG_AsPtr_std_string(swig_obj[1], &ptr);
    if (!SWIG_IsOK(res2)) {
      SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "DigestCredential_algorithm_set" "', argument " "2"" of type '" "std::string const &""'"); 
    }
    if (!ptr) {
      SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "DigestCredential_algorithm_set" "', argument " "2"" of type '" "std::string const &""'"); 
    }
    arg2 = ptr;
  }
  if (arg1) (arg1)->algorithm = *arg2;
  resultobj = SWIG_Py_Void();
  if (SWIG_IsNewObj(res2)) delete arg2;
  return resultobj;
fail:
  if (SWIG_IsNewObj(res2)) delete arg2;
  return NULL;
}


SWIGINTERN PyObject *_wrap_DigestCredential_algorithm_get(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::DigestCredential *arg1 = (pj::DigestCredential *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  std::string *result = 0 ;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__DigestCredential, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "DigestCredential_algorithm_get" "', argument " "1"" of type '" "pj::DigestCredential *""'"); 
  }
  arg1 = reinterpret_cast< pj::DigestCredential * >(argp1);
  result = (std::string *) & ((arg1)->algorithm);
  resultobj = SWIG_From_std_string(static_cast< std::string >(*result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_DigestCredential_cnonce_set(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::DigestCredential *arg1 = (pj::DigestCredential *) 0 ;
  std::string *arg2 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  int res2 = SWIG_OLDOBJ ;
  PyObject *swig_obj[2] ;
  
  if (!SWIG_Python_UnpackTuple(args, "DigestCredential_cnonce_set", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__DigestCredential, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "DigestCredential_cnonce_set" "', argument " "1"" of type '" "pj::DigestCredential *""'"); 
  }
  arg1 = reinterpret_cast< pj::DigestCredential * >(argp1);
  {
    std::string *ptr = (std::string *)0;
    res2 = SWIG_AsPtr_std_string(swig_obj[1], &ptr);
    if (!SWIG_IsOK(res2)) {
      SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "DigestCredential_cnonce_set" "', argument " "2"" of type '" "std::string const &""'"); 
    }
    if (!ptr) {
      SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "DigestCredential_cnonce_set" "', argument " "2"" of type '" "std::string const &""'"); 
    }
    arg2 = ptr;
  }
  if (arg1) (arg1)->cnonce = *arg2;
  resultobj = SWIG_Py_Void();
  if (SWIG_IsNewObj(res2)) delete arg2;
  return resultobj;
fail:
  if (SWIG_IsNewObj(res2)) delete arg2;
  return NULL;
}


SWIGINTERN PyObject *_wrap_DigestCredential_cnonce_get(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::DigestCredential *arg1 = (pj::DigestCredential *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  std::string *result = 0 ;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__DigestCredential, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "DigestCredential_cnonce_get" "', argument " "1"" of type '" "pj::DigestCredential *""'"); 
  }
  arg1 = reinterpret_cast< pj::DigestCredential * >(argp1);
  result = (std::string *) & ((arg1)->cnonce);
  resultobj = SWIG_From_std_string(static_cast< std::string >(*result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_DigestCredential_opaque_set(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::DigestCredential *arg1 = (pj::DigestCredential *) 0 ;
  std::string *arg2 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  int res2 = SWIG_OLDOBJ ;
  PyObject *swig_obj[2] ;
  
  if (!SWIG_Python_UnpackTuple(args, "DigestCredential_opaque_set", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__DigestCredential, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "DigestCredential_opaque_set" "', argument " "1"" of type '" "pj::DigestCredential *""'"); 
  }
  arg1 = reinterpret_cast< pj::DigestCredential * >(argp1);
  {
    std::string *ptr = (std::string *)0;
    res2 = SWIG_AsPtr_std_string(swig_obj[1], &ptr);
    if (!SWIG_IsOK(res2)) {
      SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "DigestCredential_opaque_set" "', argument " "2"" of type '" "std::string const &""'"); 
    }
    if (!ptr) {
      SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "DigestCredential_opaque_set" "', argument " "2"" of type '" "std::string const &""'"); 
    }
    arg2 = ptr;
  }
  if (arg1) (arg1)->opaque = *arg2;
  resultobj = SWIG_Py_Void();
  if (SWIG_IsNewObj(res2)) delete arg2;
  return resultobj;
fail:
  if (SWIG_IsNewObj(res2)) delete arg2;
  return NULL;
}


SWIGINTERN PyObject *_wrap_DigestCredential_opaque_get(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::DigestCredential *arg1 = (pj::DigestCredential *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  std::string *result = 0 ;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__DigestCredential, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "DigestCredential_opaque_get" "', argument " "1"" of type '" "pj::DigestCredential *""'"); 
  }
  arg1 = reinterpret_cast< pj::DigestCredential * >(argp1);
  result = (std::string *) & ((arg1)->opaque);
  resultobj = SWIG_From_std_string(static_cast< std::string >(*result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_DigestCredential_qop_set(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::DigestCredential *arg1 = (pj::DigestCredential *) 0 ;
  std::string *arg2 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  int res2 = SWIG_OLDOBJ ;
  PyObject *swig_obj[2] ;
  
  if (!SWIG_Python_UnpackTuple(args, "DigestCredential_qop_set", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__DigestCredential, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "DigestCredential_qop_set" "', argument " "1"" of type '" "pj::DigestCredential *""'"); 
  }
  arg1 = reinterpret_cast< pj::DigestCredential * >(argp1);
  {
    std::string *ptr = (std::string *)0;
    res2 = SWIG_AsPtr_std_string(swig_obj[1], &ptr);
    if (!SWIG_IsOK(res2)) {
      SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "DigestCredential_qop_set" "', argument " "2"" of type '" "std::string const &""'"); 
    }
    if (!ptr) {
      SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "DigestCredential_qop_set" "', argument " "2"" of type '" "std::string const &""'"); 
    }
    arg2 = ptr;
  }
  if (arg1) (arg1)->qop = *arg2;
  resultobj = SWIG_Py_Void();
  if (SWIG_IsNewObj(res2)) delete arg2;
  return resultobj;
fail:
  if (SWIG_IsNewObj(res2)) delete arg2;
  return NULL;
}


SWIGINTERN PyObject *_wrap_DigestCredential_qop_get(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::DigestCredential *arg1 = (pj::DigestCredential *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  std::string *result = 0 ;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__DigestCredential, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "DigestCredential_qop_get" "', argument " "1"" of type '" "pj::DigestCredential *""'"); 
  }
  arg1 = reinterpret_cast< pj::DigestCredential * >(argp1);
  result = (std::string *) & ((arg1)->qop);
  resultobj = SWIG_From_std_string(static_cast< std::string >(*result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_DigestCredential_nc_set(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::DigestCredential *arg1 = (pj::DigestCredential *) 0 ;
  std::string *arg2 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  int res2 = SWIG_OLDOBJ ;
  PyObject *swig_obj[2] ;
  
  if (!SWIG_Python_UnpackTuple(args, "DigestCredential_nc_set", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__DigestCredential, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "DigestCredential_nc_set" "', argument " "1"" of type '" "pj::DigestCredential *""'"); 
  }
  arg1 = reinterpret_cast< pj::DigestCredential * >(argp1);
  {
    std::string *ptr = (std::string *)0;
    res2 = SWIG_AsPtr_std_string(swig_obj[1], &ptr);
    if (!SWIG_IsOK(res2)) {
      SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "DigestCredential_nc_set" "', argument " "2"" of type '" "std::string const &""'"); 
    }
    if (!ptr) {
      SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "DigestCredential_nc_set" "', argument " "2"" of type '" "std::string const &""'"); 
    }
    arg2 = ptr;
  }
  if (arg1) (arg1)->nc = *arg2;
  resultobj = SWIG_Py_Void();
  if (SWIG_IsNewObj(res2)) delete arg2;
  return resultobj;
fail:
  if (SWIG_IsNewObj(res2)) delete arg2;
  return NULL;
}


SWIGINTERN PyObject *_wrap_DigestCredential_nc_get(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::DigestCredential *arg1 = (pj::DigestCredential *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  std::string *result = 0 ;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__DigestCredential, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "DigestCredential_nc_get" "', argument " "1"" of type '" "pj::DigestCredential *""'"); 
  }
  arg1 = reinterpret_cast< pj::DigestCredential * >(argp1);
  result = (std::string *) & ((arg1)->nc);
  resultobj = SWIG_From_std_string(static_cast< std::string >(*result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_new_DigestCredential(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::DigestCredential *result = 0 ;
  
  if (!SWIG_Python_UnpackTuple(args, "new_DigestCredential", 0, 0, 0)) SWIG_fail;
  result = (pj::DigestCredential *)new pj::DigestCredential();
  resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(result), SWIGTYPE_p_pj__DigestCredential, SWIG_POINTER_NEW |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_delete_DigestCredential(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::DigestCredential *arg1 = (pj::DigestCredential *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__DigestCredential, SWIG_POINTER_DISOWN |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "delete_DigestCredential" "', argument " "1"" of type '" "pj::DigestCredential *""'"); 
  }
  arg1 = reinterpret_cast< pj::DigestCredential * >(argp1);
  delete arg1;
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *DigestCredential_swigregister(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *obj;
  if (!SWIG_Python_UnpackTuple(args, "swigregister", 1, 1, &obj)) return NULL;
  SWIG_TypeNewClientData(SWIGTYPE_p_pj__DigestCredential, SWIG_NewClientData(obj));
  return SWIG_Py_Void();
}

SWIGINTERN PyObject *DigestCredential_swiginit(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  return SWIG_Python_InitShadowInstance(args);
}

SWIGINTERN PyObject *_wrap_OnCredAuthParam_digestChallenge_set(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::OnCredAuthParam *arg1 = (pj::OnCredAuthParam *) 0 ;
  pj::DigestChallenge *arg2 = (pj::DigestChallenge *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  void *argp2 = 0 ;
  int res2 = 0 ;
  PyObject *swig_obj[2] ;
  
  if (!SWIG_Python_UnpackTuple(args, "OnCredAuthParam_digestChallenge_set", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__OnCredAuthParam, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "OnCredAuthParam_digestChallenge_set" "', argument " "1"" of type '" "pj::OnCredAuthParam *""'"); 
  }
  arg1 = reinterpret_cast< pj::OnCredAuthParam * >(argp1);
  res2 = SWIG_ConvertPtr(swig_obj[1], &argp2,SWIGTYPE_p_pj__DigestChallenge, 0 |  0 );
  if (!SWIG_IsOK(res2)) {
    SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "OnCredAuthParam_digestChallenge_set" "', argument " "2"" of type '" "pj::DigestChallenge *""'"); 
  }
  arg2 = reinterpret_cast< pj::DigestChallenge * >(argp2);
  if (arg1) (arg1)->digestChallenge = *arg2;
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_OnCredAuthParam_digestChallenge_get(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::OnCredAuthParam *arg1 = (pj::OnCredAuthParam *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  pj::DigestChallenge *result = 0 ;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__OnCredAuthParam, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "OnCredAuthParam_digestChallenge_get" "', argument " "1"" of type '" "pj::OnCredAuthParam *""'"); 
  }
  arg1 = reinterpret_cast< pj::OnCredAuthParam * >(argp1);
  result = (pj::DigestChallenge *)& ((arg1)->digestChallenge);
  resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(result), SWIGTYPE_p_pj__DigestChallenge, 0 |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_OnCredAuthParam_credentialInfo_set(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::OnCredAuthParam *arg1 = (pj::OnCredAuthParam *) 0 ;
  pj::AuthCredInfo *arg2 = (pj::AuthCredInfo *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  void *argp2 = 0 ;
  int res2 = 0 ;
  PyObject *swig_obj[2] ;
  
  if (!SWIG_Python_UnpackTuple(args, "OnCredAuthParam_credentialInfo_set", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__OnCredAuthParam, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "OnCredAuthParam_credentialInfo_set" "', argument " "1"" of type '" "pj::OnCredAuthParam *""'"); 
  }
  arg1 = reinterpret_cast< pj::OnCredAuthParam * >(argp1);
  res2 = SWIG_ConvertPtr(swig_obj[1], &argp2,SWIGTYPE_p_pj__AuthCredInfo, 0 |  0 );
  if (!SWIG_IsOK(res2)) {
    SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "OnCredAuthParam_credentialInfo_set" "', argument " "2"" of type '" "pj::AuthCredInfo *""'"); 
  }
  arg2 = reinterpret_cast< pj::AuthCredInfo * >(argp2);
  if (arg1) (arg1)->credentialInfo = *arg2;
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_OnCredAuthParam_credentialInfo_get(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::OnCredAuthParam *arg1 = (pj::OnCredAuthParam *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  pj::AuthCredInfo *result = 0 ;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__OnCredAuthParam, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "OnCredAuthParam_credentialInfo_get" "', argument " "1"" of type '" "pj::OnCredAuthParam *""'"); 
  }
  arg1 = reinterpret_cast< pj::OnCredAuthParam * >(argp1);
  result = (pj::AuthCredInfo *)& ((arg1)->credentialInfo);
  resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(result), SWIGTYPE_p_pj__AuthCredInfo, 0 |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_OnCredAuthParam_method_set(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::OnCredAuthParam *arg1 = (pj::OnCredAuthParam *) 0 ;
  std::string *arg2 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  int res2 = SWIG_OLDOBJ ;
  PyObject *swig_obj[2] ;
  
  if (!SWIG_Python_UnpackTuple(args, "OnCredAuthParam_method_set", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__OnCredAuthParam, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "OnCredAuthParam_method_set" "', argument " "1"" of type '" "pj::OnCredAuthParam *""'"); 
  }
  arg1 = reinterpret_cast< pj::OnCredAuthParam * >(argp1);
  {
    std::string *ptr = (std::string *)0;
    res2 = SWIG_AsPtr_std_string(swig_obj[1], &ptr);
    if (!SWIG_IsOK(res2)) {
      SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "OnCredAuthParam_method_set" "', argument " "2"" of type '" "std::string const &""'"); 
    }
    if (!ptr) {
      SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "OnCredAuthParam_method_set" "', argument " "2"" of type '" "std::string const &""'"); 
    }
    arg2 = ptr;
  }
  if (arg1) (arg1)->method = *arg2;
  resultobj = SWIG_Py_Void();
  if (SWIG_IsNewObj(res2)) delete arg2;
  return resultobj;
fail:
  if (SWIG_IsNewObj(res2)) delete arg2;
  return NULL;
}


SWIGINTERN PyObject *_wrap_OnCredAuthParam_method_get(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::OnCredAuthParam *arg1 = (pj::OnCredAuthParam *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  std::string *result = 0 ;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__OnCredAuthParam, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "OnCredAuthParam_method_get" "', argument " "1"" of type '" "pj::OnCredAuthParam *""'"); 
  }
  arg1 = reinterpret_cast< pj::OnCredAuthParam * >(argp1);
  result = (std::string *) & ((arg1)->method);
  resultobj = SWIG_From_std_string(static_cast< std::string >(*result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_OnCredAuthParam_digestCredential_set(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::OnCredAuthParam *arg1 = (pj::OnCredAuthParam *) 0 ;
  pj::DigestCredential *arg2 = (pj::DigestCredential *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  void *argp2 = 0 ;
  int res2 = 0 ;
  PyObject *swig_obj[2] ;
  
  if (!SWIG_Python_UnpackTuple(args, "OnCredAuthParam_digestCredential_set", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__OnCredAuthParam, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "OnCredAuthParam_digestCredential_set" "', argument " "1"" of type '" "pj::OnCredAuthParam *""'"); 
  }
  arg1 = reinterpret_cast< pj::OnCredAuthParam * >(argp1);
  res2 = SWIG_ConvertPtr(swig_obj[1], &argp2,SWIGTYPE_p_pj__DigestCredential, 0 |  0 );
  if (!SWIG_IsOK(res2)) {
    SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "OnCredAuthParam_digestCredential_set" "', argument " "2"" of type '" "pj::DigestCredential *""'"); 
  }
  arg2 = reinterpret_cast< pj::DigestCredential * >(argp2);
  if (arg1) (arg1)->digestCredential = *arg2;
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_OnCredAuthParam_digestCredential_get(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::OnCredAuthParam *arg1 = (pj::OnCredAuthParam *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  pj::DigestCredential *result = 0 ;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__OnCredAuthParam, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "OnCredAuthParam_digestCredential_get" "', argument " "1"" of type '" "pj::OnCredAuthParam *""'"); 
  }
  arg1 = reinterpret_cast< pj::OnCredAuthParam * >(argp1);
  result = (pj::DigestCredential *)& ((arg1)->digestCredential);
  resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(result), SWIGTYPE_p_pj__DigestCredential, 0 |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_new_OnCredAuthParam(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::OnCredAuthParam *result = 0 ;
  
  if (!SWIG_Python_UnpackTuple(args, "new_OnCredAuthParam", 0, 0, 0)) SWIG_fail;
  result = (pj::OnCredAuthParam *)new pj::OnCredAuthParam();
  resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(result), SWIGTYPE_p_pj__OnCredAuthParam, SWIG_POINTER_NEW |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_delete_OnCredAuthParam(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::OnCredAuthParam *arg1 = (pj::OnCredAuthParam *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__OnCredAuthParam, SWIG_POINTER_DISOWN |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "delete_OnCredAuthParam" "', argument " "1"" of type '" "pj::OnCredAuthParam *""'"); 
  }
  arg1 = reinterpret_cast< pj::OnCredAuthParam * >(argp1);
  delete arg1;
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *OnCredAuthParam_swigregister(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *obj;
  if (!SWIG_Python_UnpackTuple(args, "swigregister", 1, 1, &obj)) return NULL;
  SWIG_TypeNewClientData(SWIGTYPE_p_pj__OnCredAuthParam, SWIG_NewClientData(obj));
  return SWIG_Py_Void();
}

SWIGINTERN PyObject *OnCredAuthParam_swiginit(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  return SWIG_Python_InitShadowInstance(args);
}

SWIGINTERN PyObject *_wrap_UaConfig_maxCalls_set(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::UaConfig *arg1 = (pj::UaConfig *) 0 ;
  unsigned int arg2 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  unsigned int val2 ;
  int ecode2 = 0 ;
  PyObject *swig_obj[2] ;
  
  if (!SWIG_Python_UnpackTuple(args, "UaConfig_maxCalls_set", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__UaConfig, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "UaConfig_maxCalls_set" "', argument " "1"" of type '" "pj::UaConfig *""'"); 
  }
  arg1 = reinterpret_cast< pj::UaConfig * >(argp1);
  ecode2 = SWIG_AsVal_unsigned_SS_int(swig_obj[1], &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "UaConfig_maxCalls_set" "', argument " "2"" of type '" "unsigned int""'");
  } 
  arg2 = static_cast< unsigned int >(val2);
  if (arg1) (arg1)->maxCalls = arg2;
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_UaConfig_maxCalls_get(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::UaConfig *arg1 = (pj::UaConfig *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  unsigned int result;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__UaConfig, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "UaConfig_maxCalls_get" "', argument " "1"" of type '" "pj::UaConfig *""'"); 
  }
  arg1 = reinterpret_cast< pj::UaConfig * >(argp1);
  result = (unsigned int) ((arg1)->maxCalls);
  resultobj = SWIG_From_unsigned_SS_int(static_cast< unsigned int >(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_UaConfig_threadCnt_set(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::UaConfig *arg1 = (pj::UaConfig *) 0 ;
  unsigned int arg2 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  unsigned int val2 ;
  int ecode2 = 0 ;
  PyObject *swig_obj[2] ;
  
  if (!SWIG_Python_UnpackTuple(args, "UaConfig_threadCnt_set", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__UaConfig, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "UaConfig_threadCnt_set" "', argument " "1"" of type '" "pj::UaConfig *""'"); 
  }
  arg1 = reinterpret_cast< pj::UaConfig * >(argp1);
  ecode2 = SWIG_AsVal_unsigned_SS_int(swig_obj[1], &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "UaConfig_threadCnt_set" "', argument " "2"" of type '" "unsigned int""'");
  } 
  arg2 = static_cast< unsigned int >(val2);
  if (arg1) (arg1)->threadCnt = arg2;
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_UaConfig_threadCnt_get(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::UaConfig *arg1 = (pj::UaConfig *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  unsigned int result;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__UaConfig, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "UaConfig_threadCnt_get" "', argument " "1"" of type '" "pj::UaConfig *""'"); 
  }
  arg1 = reinterpret_cast< pj::UaConfig * >(argp1);
  result = (unsigned int) ((arg1)->threadCnt);
  resultobj = SWIG_From_unsigned_SS_int(static_cast< unsigned int >(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_UaConfig_mainThreadOnly_set(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::UaConfig *arg1 = (pj::UaConfig *) 0 ;
  bool arg2 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  bool val2 ;
  int ecode2 = 0 ;
  PyObject *swig_obj[2] ;
  
  if (!SWIG_Python_UnpackTuple(args, "UaConfig_mainThreadOnly_set", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__UaConfig, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "UaConfig_mainThreadOnly_set" "', argument " "1"" of type '" "pj::UaConfig *""'"); 
  }
  arg1 = reinterpret_cast< pj::UaConfig * >(argp1);
  ecode2 = SWIG_AsVal_bool(swig_obj[1], &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "UaConfig_mainThreadOnly_set" "', argument " "2"" of type '" "bool""'");
  } 
  arg2 = static_cast< bool >(val2);
  if (arg1) (arg1)->mainThreadOnly = arg2;
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_UaConfig_mainThreadOnly_get(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::UaConfig *arg1 = (pj::UaConfig *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  bool result;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__UaConfig, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "UaConfig_mainThreadOnly_get" "', argument " "1"" of type '" "pj::UaConfig *""'"); 
  }
  arg1 = reinterpret_cast< pj::UaConfig * >(argp1);
  result = (bool) ((arg1)->mainThreadOnly);
  resultobj = SWIG_From_bool(static_cast< bool >(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_UaConfig_nameserver_set(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::UaConfig *arg1 = (pj::UaConfig *) 0 ;
  pj::StringVector *arg2 = (pj::StringVector *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  void *argp2 = 0 ;
  int res2 = 0 ;
  PyObject *swig_obj[2] ;
  
  if (!SWIG_Python_UnpackTuple(args, "UaConfig_nameserver_set", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__UaConfig, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "UaConfig_nameserver_set" "', argument " "1"" of type '" "pj::UaConfig *""'"); 
  }
  arg1 = reinterpret_cast< pj::UaConfig * >(argp1);
  res2 = SWIG_ConvertPtr(swig_obj[1], &argp2,SWIGTYPE_p_std__vectorT_std__string_std__allocatorT_std__string_t_t, 0 |  0 );
  if (!SWIG_IsOK(res2)) {
    SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "UaConfig_nameserver_set" "', argument " "2"" of type '" "pj::StringVector *""'"); 
  }
  arg2 = reinterpret_cast< pj::StringVector * >(argp2);
  if (arg1) (arg1)->nameserver = *arg2;
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_UaConfig_nameserver_get(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::UaConfig *arg1 = (pj::UaConfig *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  pj::StringVector *result = 0 ;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__UaConfig, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "UaConfig_nameserver_get" "', argument " "1"" of type '" "pj::UaConfig *""'"); 
  }
  arg1 = reinterpret_cast< pj::UaConfig * >(argp1);
  result = (pj::StringVector *)& ((arg1)->nameserver);
  resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(result), SWIGTYPE_p_std__vectorT_std__string_std__allocatorT_std__string_t_t, 0 |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_UaConfig_outboundProxies_set(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::UaConfig *arg1 = (pj::UaConfig *) 0 ;
  pj::StringVector *arg2 = (pj::StringVector *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  void *argp2 = 0 ;
  int res2 = 0 ;
  PyObject *swig_obj[2] ;
  
  if (!SWIG_Python_UnpackTuple(args, "UaConfig_outboundProxies_set", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__UaConfig, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "UaConfig_outboundProxies_set" "', argument " "1"" of type '" "pj::UaConfig *""'"); 
  }
  arg1 = reinterpret_cast< pj::UaConfig * >(argp1);
  res2 = SWIG_ConvertPtr(swig_obj[1], &argp2,SWIGTYPE_p_std__vectorT_std__string_std__allocatorT_std__string_t_t, 0 |  0 );
  if (!SWIG_IsOK(res2)) {
    SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "UaConfig_outboundProxies_set" "', argument " "2"" of type '" "pj::StringVector *""'"); 
  }
  arg2 = reinterpret_cast< pj::StringVector * >(argp2);
  if (arg1) (arg1)->outboundProxies = *arg2;
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_UaConfig_outboundProxies_get(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::UaConfig *arg1 = (pj::UaConfig *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  pj::StringVector *result = 0 ;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__UaConfig, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "UaConfig_outboundProxies_get" "', argument " "1"" of type '" "pj::UaConfig *""'"); 
  }
  arg1 = reinterpret_cast< pj::UaConfig * >(argp1);
  result = (pj::StringVector *)& ((arg1)->outboundProxies);
  resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(result), SWIGTYPE_p_std__vectorT_std__string_std__allocatorT_std__string_t_t, 0 |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_UaConfig_userAgent_set(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::UaConfig *arg1 = (pj::UaConfig *) 0 ;
  pj::string *arg2 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  int res2 = SWIG_OLDOBJ ;
  PyObject *swig_obj[2] ;
  
  if (!SWIG_Python_UnpackTuple(args, "UaConfig_userAgent_set", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__UaConfig, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "UaConfig_userAgent_set" "', argument " "1"" of type '" "pj::UaConfig *""'"); 
  }
  arg1 = reinterpret_cast< pj::UaConfig * >(argp1);
  {
    std::string *ptr = (std::string *)0;
    res2 = SWIG_AsPtr_std_string(swig_obj[1], &ptr);
    if (!SWIG_IsOK(res2)) {
      SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "UaConfig_userAgent_set" "', argument " "2"" of type '" "pj::string const &""'"); 
    }
    if (!ptr) {
      SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "UaConfig_userAgent_set" "', argument " "2"" of type '" "pj::string const &""'"); 
    }
    arg2 = ptr;
  }
  if (arg1) (arg1)->userAgent = *arg2;
  resultobj = SWIG_Py_Void();
  if (SWIG_IsNewObj(res2)) delete arg2;
  return resultobj;
fail:
  if (SWIG_IsNewObj(res2)) delete arg2;
  return NULL;
}


SWIGINTERN PyObject *_wrap_UaConfig_userAgent_get(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::UaConfig *arg1 = (pj::UaConfig *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  pj::string *result = 0 ;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__UaConfig, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "UaConfig_userAgent_get" "', argument " "1"" of type '" "pj::UaConfig *""'"); 
  }
  arg1 = reinterpret_cast< pj::UaConfig * >(argp1);
  result = (pj::string *) & ((arg1)->userAgent);
  resultobj = SWIG_From_std_string(static_cast< std::string >(*result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_UaConfig_stunServer_set(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::UaConfig *arg1 = (pj::UaConfig *) 0 ;
  pj::StringVector *arg2 = (pj::StringVector *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  void *argp2 = 0 ;
  int res2 = 0 ;
  PyObject *swig_obj[2] ;
  
  if (!SWIG_Python_UnpackTuple(args, "UaConfig_stunServer_set", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__UaConfig, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "UaConfig_stunServer_set" "', argument " "1"" of type '" "pj::UaConfig *""'"); 
  }
  arg1 = reinterpret_cast< pj::UaConfig * >(argp1);
  res2 = SWIG_ConvertPtr(swig_obj[1], &argp2,SWIGTYPE_p_std__vectorT_std__string_std__allocatorT_std__string_t_t, 0 |  0 );
  if (!SWIG_IsOK(res2)) {
    SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "UaConfig_stunServer_set" "', argument " "2"" of type '" "pj::StringVector *""'"); 
  }
  arg2 = reinterpret_cast< pj::StringVector * >(argp2);
  if (arg1) (arg1)->stunServer = *arg2;
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_UaConfig_stunServer_get(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::UaConfig *arg1 = (pj::UaConfig *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  pj::StringVector *result = 0 ;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__UaConfig, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "UaConfig_stunServer_get" "', argument " "1"" of type '" "pj::UaConfig *""'"); 
  }
  arg1 = reinterpret_cast< pj::UaConfig * >(argp1);
  result = (pj::StringVector *)& ((arg1)->stunServer);
  resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(result), SWIGTYPE_p_std__vectorT_std__string_std__allocatorT_std__string_t_t, 0 |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_UaConfig_stunTryIpv6_set(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::UaConfig *arg1 = (pj::UaConfig *) 0 ;
  bool arg2 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  bool val2 ;
  int ecode2 = 0 ;
  PyObject *swig_obj[2] ;
  
  if (!SWIG_Python_UnpackTuple(args, "UaConfig_stunTryIpv6_set", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__UaConfig, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "UaConfig_stunTryIpv6_set" "', argument " "1"" of type '" "pj::UaConfig *""'"); 
  }
  arg1 = reinterpret_cast< pj::UaConfig * >(argp1);
  ecode2 = SWIG_AsVal_bool(swig_obj[1], &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "UaConfig_stunTryIpv6_set" "', argument " "2"" of type '" "bool""'");
  } 
  arg2 = static_cast< bool >(val2);
  if (arg1) (arg1)->stunTryIpv6 = arg2;
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_UaConfig_stunTryIpv6_get(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::UaConfig *arg1 = (pj::UaConfig *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  bool result;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__UaConfig, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "UaConfig_stunTryIpv6_get" "', argument " "1"" of type '" "pj::UaConfig *""'"); 
  }
  arg1 = reinterpret_cast< pj::UaConfig * >(argp1);
  result = (bool) ((arg1)->stunTryIpv6);
  resultobj = SWIG_From_bool(static_cast< bool >(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_UaConfig_stunIgnoreFailure_set(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::UaConfig *arg1 = (pj::UaConfig *) 0 ;
  bool arg2 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  bool val2 ;
  int ecode2 = 0 ;
  PyObject *swig_obj[2] ;
  
  if (!SWIG_Python_UnpackTuple(args, "UaConfig_stunIgnoreFailure_set", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__UaConfig, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "UaConfig_stunIgnoreFailure_set" "', argument " "1"" of type '" "pj::UaConfig *""'"); 
  }
  arg1 = reinterpret_cast< pj::UaConfig * >(argp1);
  ecode2 = SWIG_AsVal_bool(swig_obj[1], &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "UaConfig_stunIgnoreFailure_set" "', argument " "2"" of type '" "bool""'");
  } 
  arg2 = static_cast< bool >(val2);
  if (arg1) (arg1)->stunIgnoreFailure = arg2;
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_UaConfig_stunIgnoreFailure_get(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::UaConfig *arg1 = (pj::UaConfig *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  bool result;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__UaConfig, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "UaConfig_stunIgnoreFailure_get" "', argument " "1"" of type '" "pj::UaConfig *""'"); 
  }
  arg1 = reinterpret_cast< pj::UaConfig * >(argp1);
  result = (bool) ((arg1)->stunIgnoreFailure);
  resultobj = SWIG_From_bool(static_cast< bool >(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_UaConfig_natTypeInSdp_set(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::UaConfig *arg1 = (pj::UaConfig *) 0 ;
  int arg2 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  int val2 ;
  int ecode2 = 0 ;
  PyObject *swig_obj[2] ;
  
  if (!SWIG_Python_UnpackTuple(args, "UaConfig_natTypeInSdp_set", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__UaConfig, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "UaConfig_natTypeInSdp_set" "', argument " "1"" of type '" "pj::UaConfig *""'"); 
  }
  arg1 = reinterpret_cast< pj::UaConfig * >(argp1);
  ecode2 = SWIG_AsVal_int(swig_obj[1], &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "UaConfig_natTypeInSdp_set" "', argument " "2"" of type '" "int""'");
  } 
  arg2 = static_cast< int >(val2);
  if (arg1) (arg1)->natTypeInSdp = arg2;
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_UaConfig_natTypeInSdp_get(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::UaConfig *arg1 = (pj::UaConfig *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  int result;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__UaConfig, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "UaConfig_natTypeInSdp_get" "', argument " "1"" of type '" "pj::UaConfig *""'"); 
  }
  arg1 = reinterpret_cast< pj::UaConfig * >(argp1);
  result = (int) ((arg1)->natTypeInSdp);
  resultobj = SWIG_From_int(static_cast< int >(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_UaConfig_mwiUnsolicitedEnabled_set(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::UaConfig *arg1 = (pj::UaConfig *) 0 ;
  bool arg2 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  bool val2 ;
  int ecode2 = 0 ;
  PyObject *swig_obj[2] ;
  
  if (!SWIG_Python_UnpackTuple(args, "UaConfig_mwiUnsolicitedEnabled_set", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__UaConfig, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "UaConfig_mwiUnsolicitedEnabled_set" "', argument " "1"" of type '" "pj::UaConfig *""'"); 
  }
  arg1 = reinterpret_cast< pj::UaConfig * >(argp1);
  ecode2 = SWIG_AsVal_bool(swig_obj[1], &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "UaConfig_mwiUnsolicitedEnabled_set" "', argument " "2"" of type '" "bool""'");
  } 
  arg2 = static_cast< bool >(val2);
  if (arg1) (arg1)->mwiUnsolicitedEnabled = arg2;
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_UaConfig_mwiUnsolicitedEnabled_get(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::UaConfig *arg1 = (pj::UaConfig *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  bool result;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__UaConfig, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "UaConfig_mwiUnsolicitedEnabled_get" "', argument " "1"" of type '" "pj::UaConfig *""'"); 
  }
  arg1 = reinterpret_cast< pj::UaConfig * >(argp1);
  result = (bool) ((arg1)->mwiUnsolicitedEnabled);
  resultobj = SWIG_From_bool(static_cast< bool >(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_new_UaConfig(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::UaConfig *result = 0 ;
  
  if (!SWIG_Python_UnpackTuple(args, "new_UaConfig", 0, 0, 0)) SWIG_fail;
  result = (pj::UaConfig *)new pj::UaConfig();
  resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(result), SWIGTYPE_p_pj__UaConfig, SWIG_POINTER_NEW |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_UaConfig_readObject(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::UaConfig *arg1 = (pj::UaConfig *) 0 ;
  pj::ContainerNode *arg2 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  void *argp2 = 0 ;
  int res2 = 0 ;
  PyObject *swig_obj[2] ;
  
  if (!SWIG_Python_UnpackTuple(args, "UaConfig_readObject", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__UaConfig, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "UaConfig_readObject" "', argument " "1"" of type '" "pj::UaConfig *""'"); 
  }
  arg1 = reinterpret_cast< pj::UaConfig * >(argp1);
  res2 = SWIG_ConvertPtr(swig_obj[1], &argp2, SWIGTYPE_p_pj__ContainerNode,  0  | 0);
  if (!SWIG_IsOK(res2)) {
    SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "UaConfig_readObject" "', argument " "2"" of type '" "pj::ContainerNode const &""'"); 
  }
  if (!argp2) {
    SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "UaConfig_readObject" "', argument " "2"" of type '" "pj::ContainerNode const &""'"); 
  }
  arg2 = reinterpret_cast< pj::ContainerNode * >(argp2);
  try {
    (arg1)->readObject((pj::ContainerNode const &)*arg2);
  } catch(pj::Error &_e) {
    SWIG_Python_Raise(SWIG_NewPointerObj((new pj::Error(static_cast< const pj::Error& >(_e))),SWIGTYPE_p_pj__Error,SWIG_POINTER_OWN), "pj::Error", SWIGTYPE_p_pj__Error); SWIG_fail;
  }
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_UaConfig_writeObject(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::UaConfig *arg1 = (pj::UaConfig *) 0 ;
  pj::ContainerNode *arg2 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  void *argp2 = 0 ;
  int res2 = 0 ;
  PyObject *swig_obj[2] ;
  
  if (!SWIG_Python_UnpackTuple(args, "UaConfig_writeObject", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__UaConfig, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "UaConfig_writeObject" "', argument " "1"" of type '" "pj::UaConfig const *""'"); 
  }
  arg1 = reinterpret_cast< pj::UaConfig * >(argp1);
  res2 = SWIG_ConvertPtr(swig_obj[1], &argp2, SWIGTYPE_p_pj__ContainerNode,  0 );
  if (!SWIG_IsOK(res2)) {
    SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "UaConfig_writeObject" "', argument " "2"" of type '" "pj::ContainerNode &""'"); 
  }
  if (!argp2) {
    SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "UaConfig_writeObject" "', argument " "2"" of type '" "pj::ContainerNode &""'"); 
  }
  arg2 = reinterpret_cast< pj::ContainerNode * >(argp2);
  try {
    ((pj::UaConfig const *)arg1)->writeObject(*arg2);
  } catch(pj::Error &_e) {
    SWIG_Python_Raise(SWIG_NewPointerObj((new pj::Error(static_cast< const pj::Error& >(_e))),SWIGTYPE_p_pj__Error,SWIG_POINTER_OWN), "pj::Error", SWIGTYPE_p_pj__Error); SWIG_fail;
  }
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_delete_UaConfig(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::UaConfig *arg1 = (pj::UaConfig *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__UaConfig, SWIG_POINTER_DISOWN |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "delete_UaConfig" "', argument " "1"" of type '" "pj::UaConfig *""'"); 
  }
  arg1 = reinterpret_cast< pj::UaConfig * >(argp1);
  delete arg1;
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *UaConfig_swigregister(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *obj;
  if (!SWIG_Python_UnpackTuple(args, "swigregister", 1, 1, &obj)) return NULL;
  SWIG_TypeNewClientData(SWIGTYPE_p_pj__UaConfig, SWIG_NewClientData(obj));
  return SWIG_Py_Void();
}

SWIGINTERN PyObject *UaConfig_swiginit(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  return SWIG_Python_InitShadowInstance(args);
}

SWIGINTERN PyObject *_wrap_LogEntry_level_set(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::LogEntry *arg1 = (pj::LogEntry *) 0 ;
  int arg2 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  int val2 ;
  int ecode2 = 0 ;
  PyObject *swig_obj[2] ;
  
  if (!SWIG_Python_UnpackTuple(args, "LogEntry_level_set", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__LogEntry, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "LogEntry_level_set" "', argument " "1"" of type '" "pj::LogEntry *""'"); 
  }
  arg1 = reinterpret_cast< pj::LogEntry * >(argp1);
  ecode2 = SWIG_AsVal_int(swig_obj[1], &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "LogEntry_level_set" "', argument " "2"" of type '" "int""'");
  } 
  arg2 = static_cast< int >(val2);
  if (arg1) (arg1)->level = arg2;
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_LogEntry_level_get(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::LogEntry *arg1 = (pj::LogEntry *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  int result;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__LogEntry, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "LogEntry_level_get" "', argument " "1"" of type '" "pj::LogEntry *""'"); 
  }
  arg1 = reinterpret_cast< pj::LogEntry * >(argp1);
  result = (int) ((arg1)->level);
  resultobj = SWIG_From_int(static_cast< int >(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_LogEntry_msg_set(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::LogEntry *arg1 = (pj::LogEntry *) 0 ;
  pj::string *arg2 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  int res2 = SWIG_OLDOBJ ;
  PyObject *swig_obj[2] ;
  
  if (!SWIG_Python_UnpackTuple(args, "LogEntry_msg_set", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__LogEntry, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "LogEntry_msg_set" "', argument " "1"" of type '" "pj::LogEntry *""'"); 
  }
  arg1 = reinterpret_cast< pj::LogEntry * >(argp1);
  {
    std::string *ptr = (std::string *)0;
    res2 = SWIG_AsPtr_std_string(swig_obj[1], &ptr);
    if (!SWIG_IsOK(res2)) {
      SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "LogEntry_msg_set" "', argument " "2"" of type '" "pj::string const &""'"); 
    }
    if (!ptr) {
      SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "LogEntry_msg_set" "', argument " "2"" of type '" "pj::string const &""'"); 
    }
    arg2 = ptr;
  }
  if (arg1) (arg1)->msg = *arg2;
  resultobj = SWIG_Py_Void();
  if (SWIG_IsNewObj(res2)) delete arg2;
  return resultobj;
fail:
  if (SWIG_IsNewObj(res2)) delete arg2;
  return NULL;
}


SWIGINTERN PyObject *_wrap_LogEntry_msg_get(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::LogEntry *arg1 = (pj::LogEntry *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  pj::string *result = 0 ;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__LogEntry, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "LogEntry_msg_get" "', argument " "1"" of type '" "pj::LogEntry *""'"); 
  }
  arg1 = reinterpret_cast< pj::LogEntry * >(argp1);
  result = (pj::string *) & ((arg1)->msg);
  resultobj = SWIG_From_std_string(static_cast< std::string >(*result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_LogEntry_threadId_set(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::LogEntry *arg1 = (pj::LogEntry *) 0 ;
  long arg2 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  long val2 ;
  int ecode2 = 0 ;
  PyObject *swig_obj[2] ;
  
  if (!SWIG_Python_UnpackTuple(args, "LogEntry_threadId_set", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__LogEntry, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "LogEntry_threadId_set" "', argument " "1"" of type '" "pj::LogEntry *""'"); 
  }
  arg1 = reinterpret_cast< pj::LogEntry * >(argp1);
  ecode2 = SWIG_AsVal_long(swig_obj[1], &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "LogEntry_threadId_set" "', argument " "2"" of type '" "long""'");
  } 
  arg2 = static_cast< long >(val2);
  if (arg1) (arg1)->threadId = arg2;
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_LogEntry_threadId_get(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::LogEntry *arg1 = (pj::LogEntry *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  long result;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__LogEntry, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "LogEntry_threadId_get" "', argument " "1"" of type '" "pj::LogEntry *""'"); 
  }
  arg1 = reinterpret_cast< pj::LogEntry * >(argp1);
  result = (long) ((arg1)->threadId);
  resultobj = SWIG_From_long(static_cast< long >(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_LogEntry_threadName_set(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::LogEntry *arg1 = (pj::LogEntry *) 0 ;
  pj::string *arg2 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  int res2 = SWIG_OLDOBJ ;
  PyObject *swig_obj[2] ;
  
  if (!SWIG_Python_UnpackTuple(args, "LogEntry_threadName_set", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__LogEntry, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "LogEntry_threadName_set" "', argument " "1"" of type '" "pj::LogEntry *""'"); 
  }
  arg1 = reinterpret_cast< pj::LogEntry * >(argp1);
  {
    std::string *ptr = (std::string *)0;
    res2 = SWIG_AsPtr_std_string(swig_obj[1], &ptr);
    if (!SWIG_IsOK(res2)) {
      SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "LogEntry_threadName_set" "', argument " "2"" of type '" "pj::string const &""'"); 
    }
    if (!ptr) {
      SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "LogEntry_threadName_set" "', argument " "2"" of type '" "pj::string const &""'"); 
    }
    arg2 = ptr;
  }
  if (arg1) (arg1)->threadName = *arg2;
  resultobj = SWIG_Py_Void();
  if (SWIG_IsNewObj(res2)) delete arg2;
  return resultobj;
fail:
  if (SWIG_IsNewObj(res2)) delete arg2;
  return NULL;
}


SWIGINTERN PyObject *_wrap_LogEntry_threadName_get(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::LogEntry *arg1 = (pj::LogEntry *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  pj::string *result = 0 ;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__LogEntry, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "LogEntry_threadName_get" "', argument " "1"" of type '" "pj::LogEntry *""'"); 
  }
  arg1 = reinterpret_cast< pj::LogEntry * >(argp1);
  result = (pj::string *) & ((arg1)->threadName);
  resultobj = SWIG_From_std_string(static_cast< std::string >(*result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_new_LogEntry(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::LogEntry *result = 0 ;
  
  if (!SWIG_Python_UnpackTuple(args, "new_LogEntry", 0, 0, 0)) SWIG_fail;
  result = (pj::LogEntry *)new pj::LogEntry();
  resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(result), SWIGTYPE_p_pj__LogEntry, SWIG_POINTER_NEW |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_delete_LogEntry(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::LogEntry *arg1 = (pj::LogEntry *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__LogEntry, SWIG_POINTER_DISOWN |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "delete_LogEntry" "', argument " "1"" of type '" "pj::LogEntry *""'"); 
  }
  arg1 = reinterpret_cast< pj::LogEntry * >(argp1);
  delete arg1;
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *LogEntry_swigregister(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *obj;
  if (!SWIG_Python_UnpackTuple(args, "swigregister", 1, 1, &obj)) return NULL;
  SWIG_TypeNewClientData(SWIGTYPE_p_pj__LogEntry, SWIG_NewClientData(obj));
  return SWIG_Py_Void();
}

SWIGINTERN PyObject *LogEntry_swiginit(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  return SWIG_Python_InitShadowInstance(args);
}

SWIGINTERN PyObject *_wrap_delete_LogWriter(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::LogWriter *arg1 = (pj::LogWriter *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__LogWriter, SWIG_POINTER_DISOWN |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "delete_LogWriter" "', argument " "1"" of type '" "pj::LogWriter *""'"); 
  }
  arg1 = reinterpret_cast< pj::LogWriter * >(argp1);
  delete arg1;
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_LogWriter_write(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::LogWriter *arg1 = (pj::LogWriter *) 0 ;
  pj::LogEntry *arg2 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  void *argp2 = 0 ;
  int res2 = 0 ;
  PyObject *swig_obj[2] ;
  Swig::Director *director = 0;
  bool upcall = false;
  
  if (!SWIG_Python_UnpackTuple(args, "LogWriter_write", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__LogWriter, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "LogWriter_write" "', argument " "1"" of type '" "pj::LogWriter *""'"); 
  }
  arg1 = reinterpret_cast< pj::LogWriter * >(argp1);
  res2 = SWIG_ConvertPtr(swig_obj[1], &argp2, SWIGTYPE_p_pj__LogEntry,  0  | 0);
  if (!SWIG_IsOK(res2)) {
    SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "LogWriter_write" "', argument " "2"" of type '" "pj::LogEntry const &""'"); 
  }
  if (!argp2) {
    SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "LogWriter_write" "', argument " "2"" of type '" "pj::LogEntry const &""'"); 
  }
  arg2 = reinterpret_cast< pj::LogEntry * >(argp2);
  director = SWIG_DIRECTOR_CAST(arg1);
  upcall = (director && (director->swig_get_self()==swig_obj[0]));
  try {
    if (upcall) {
      Swig::DirectorPureVirtualException::raise("pj::LogWriter::write");
    } else {
      (arg1)->write((pj::LogEntry const &)*arg2);
    }
  } catch (Swig::DirectorException&) {
    SWIG_fail;
  }
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_new_LogWriter(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  PyObject *arg1 = (PyObject *) 0 ;
  PyObject *swig_obj[1] ;
  pj::LogWriter *result = 0 ;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  arg1 = swig_obj[0];
  if ( arg1 != Py_None ) {
    /* subclassed */
    result = (pj::LogWriter *)new SwigDirector_LogWriter(arg1); 
  } else {
    SWIG_SetErrorMsg(PyExc_RuntimeError,"accessing abstract class or protected constructor"); 
    SWIG_fail;
  }
  
  resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(result), SWIGTYPE_p_pj__LogWriter, SWIG_POINTER_NEW |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_disown_LogWriter(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::LogWriter *arg1 = (pj::LogWriter *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__LogWriter, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "disown_LogWriter" "', argument " "1"" of type '" "pj::LogWriter *""'"); 
  }
  arg1 = reinterpret_cast< pj::LogWriter * >(argp1);
  {
    Swig::Director *director = SWIG_DIRECTOR_CAST(arg1);
    if (director) director->swig_disown();
  }
  
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *LogWriter_swigregister(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *obj;
  if (!SWIG_Python_UnpackTuple(args, "swigregister", 1, 1, &obj)) return NULL;
  SWIG_TypeNewClientData(SWIGTYPE_p_pj__LogWriter, SWIG_NewClientData(obj));
  return SWIG_Py_Void();
}

SWIGINTERN PyObject *LogWriter_swiginit(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  return SWIG_Python_InitShadowInstance(args);
}

SWIGINTERN PyObject *_wrap_LogConfig_msgLogging_set(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::LogConfig *arg1 = (pj::LogConfig *) 0 ;
  unsigned int arg2 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  unsigned int val2 ;
  int ecode2 = 0 ;
  PyObject *swig_obj[2] ;
  
  if (!SWIG_Python_UnpackTuple(args, "LogConfig_msgLogging_set", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__LogConfig, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "LogConfig_msgLogging_set" "', argument " "1"" of type '" "pj::LogConfig *""'"); 
  }
  arg1 = reinterpret_cast< pj::LogConfig * >(argp1);
  ecode2 = SWIG_AsVal_unsigned_SS_int(swig_obj[1], &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "LogConfig_msgLogging_set" "', argument " "2"" of type '" "unsigned int""'");
  } 
  arg2 = static_cast< unsigned int >(val2);
  if (arg1) (arg1)->msgLogging = arg2;
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_LogConfig_msgLogging_get(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::LogConfig *arg1 = (pj::LogConfig *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  unsigned int result;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__LogConfig, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "LogConfig_msgLogging_get" "', argument " "1"" of type '" "pj::LogConfig *""'"); 
  }
  arg1 = reinterpret_cast< pj::LogConfig * >(argp1);
  result = (unsigned int) ((arg1)->msgLogging);
  resultobj = SWIG_From_unsigned_SS_int(static_cast< unsigned int >(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_LogConfig_level_set(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::LogConfig *arg1 = (pj::LogConfig *) 0 ;
  unsigned int arg2 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  unsigned int val2 ;
  int ecode2 = 0 ;
  PyObject *swig_obj[2] ;
  
  if (!SWIG_Python_UnpackTuple(args, "LogConfig_level_set", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__LogConfig, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "LogConfig_level_set" "', argument " "1"" of type '" "pj::LogConfig *""'"); 
  }
  arg1 = reinterpret_cast< pj::LogConfig * >(argp1);
  ecode2 = SWIG_AsVal_unsigned_SS_int(swig_obj[1], &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "LogConfig_level_set" "', argument " "2"" of type '" "unsigned int""'");
  } 
  arg2 = static_cast< unsigned int >(val2);
  if (arg1) (arg1)->level = arg2;
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_LogConfig_level_get(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::LogConfig *arg1 = (pj::LogConfig *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  unsigned int result;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__LogConfig, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "LogConfig_level_get" "', argument " "1"" of type '" "pj::LogConfig *""'"); 
  }
  arg1 = reinterpret_cast< pj::LogConfig * >(argp1);
  result = (unsigned int) ((arg1)->level);
  resultobj = SWIG_From_unsigned_SS_int(static_cast< unsigned int >(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_LogConfig_consoleLevel_set(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::LogConfig *arg1 = (pj::LogConfig *) 0 ;
  unsigned int arg2 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  unsigned int val2 ;
  int ecode2 = 0 ;
  PyObject *swig_obj[2] ;
  
  if (!SWIG_Python_UnpackTuple(args, "LogConfig_consoleLevel_set", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__LogConfig, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "LogConfig_consoleLevel_set" "', argument " "1"" of type '" "pj::LogConfig *""'"); 
  }
  arg1 = reinterpret_cast< pj::LogConfig * >(argp1);
  ecode2 = SWIG_AsVal_unsigned_SS_int(swig_obj[1], &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "LogConfig_consoleLevel_set" "', argument " "2"" of type '" "unsigned int""'");
  } 
  arg2 = static_cast< unsigned int >(val2);
  if (arg1) (arg1)->consoleLevel = arg2;
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_LogConfig_consoleLevel_get(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::LogConfig *arg1 = (pj::LogConfig *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  unsigned int result;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__LogConfig, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "LogConfig_consoleLevel_get" "', argument " "1"" of type '" "pj::LogConfig *""'"); 
  }
  arg1 = reinterpret_cast< pj::LogConfig * >(argp1);
  result = (unsigned int) ((arg1)->consoleLevel);
  resultobj = SWIG_From_unsigned_SS_int(static_cast< unsigned int >(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_LogConfig_decor_set(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::LogConfig *arg1 = (pj::LogConfig *) 0 ;
  unsigned int arg2 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  unsigned int val2 ;
  int ecode2 = 0 ;
  PyObject *swig_obj[2] ;
  
  if (!SWIG_Python_UnpackTuple(args, "LogConfig_decor_set", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__LogConfig, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "LogConfig_decor_set" "', argument " "1"" of type '" "pj::LogConfig *""'"); 
  }
  arg1 = reinterpret_cast< pj::LogConfig * >(argp1);
  ecode2 = SWIG_AsVal_unsigned_SS_int(swig_obj[1], &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "LogConfig_decor_set" "', argument " "2"" of type '" "unsigned int""'");
  } 
  arg2 = static_cast< unsigned int >(val2);
  if (arg1) (arg1)->decor = arg2;
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_LogConfig_decor_get(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::LogConfig *arg1 = (pj::LogConfig *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  unsigned int result;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__LogConfig, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "LogConfig_decor_get" "', argument " "1"" of type '" "pj::LogConfig *""'"); 
  }
  arg1 = reinterpret_cast< pj::LogConfig * >(argp1);
  result = (unsigned int) ((arg1)->decor);
  resultobj = SWIG_From_unsigned_SS_int(static_cast< unsigned int >(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_LogConfig_filename_set(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::LogConfig *arg1 = (pj::LogConfig *) 0 ;
  pj::string *arg2 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  int res2 = SWIG_OLDOBJ ;
  PyObject *swig_obj[2] ;
  
  if (!SWIG_Python_UnpackTuple(args, "LogConfig_filename_set", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__LogConfig, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "LogConfig_filename_set" "', argument " "1"" of type '" "pj::LogConfig *""'"); 
  }
  arg1 = reinterpret_cast< pj::LogConfig * >(argp1);
  {
    std::string *ptr = (std::string *)0;
    res2 = SWIG_AsPtr_std_string(swig_obj[1], &ptr);
    if (!SWIG_IsOK(res2)) {
      SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "LogConfig_filename_set" "', argument " "2"" of type '" "pj::string const &""'"); 
    }
    if (!ptr) {
      SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "LogConfig_filename_set" "', argument " "2"" of type '" "pj::string const &""'"); 
    }
    arg2 = ptr;
  }
  if (arg1) (arg1)->filename = *arg2;
  resultobj = SWIG_Py_Void();
  if (SWIG_IsNewObj(res2)) delete arg2;
  return resultobj;
fail:
  if (SWIG_IsNewObj(res2)) delete arg2;
  return NULL;
}


SWIGINTERN PyObject *_wrap_LogConfig_filename_get(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::LogConfig *arg1 = (pj::LogConfig *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  pj::string *result = 0 ;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__LogConfig, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "LogConfig_filename_get" "', argument " "1"" of type '" "pj::LogConfig *""'"); 
  }
  arg1 = reinterpret_cast< pj::LogConfig * >(argp1);
  result = (pj::string *) & ((arg1)->filename);
  resultobj = SWIG_From_std_string(static_cast< std::string >(*result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_LogConfig_fileFlags_set(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::LogConfig *arg1 = (pj::LogConfig *) 0 ;
  unsigned int arg2 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  unsigned int val2 ;
  int ecode2 = 0 ;
  PyObject *swig_obj[2] ;
  
  if (!SWIG_Python_UnpackTuple(args, "LogConfig_fileFlags_set", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__LogConfig, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "LogConfig_fileFlags_set" "', argument " "1"" of type '" "pj::LogConfig *""'"); 
  }
  arg1 = reinterpret_cast< pj::LogConfig * >(argp1);
  ecode2 = SWIG_AsVal_unsigned_SS_int(swig_obj[1], &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "LogConfig_fileFlags_set" "', argument " "2"" of type '" "unsigned int""'");
  } 
  arg2 = static_cast< unsigned int >(val2);
  if (arg1) (arg1)->fileFlags = arg2;
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_LogConfig_fileFlags_get(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::LogConfig *arg1 = (pj::LogConfig *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  unsigned int result;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__LogConfig, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "LogConfig_fileFlags_get" "', argument " "1"" of type '" "pj::LogConfig *""'"); 
  }
  arg1 = reinterpret_cast< pj::LogConfig * >(argp1);
  result = (unsigned int) ((arg1)->fileFlags);
  resultobj = SWIG_From_unsigned_SS_int(static_cast< unsigned int >(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_LogConfig_writer_set(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::LogConfig *arg1 = (pj::LogConfig *) 0 ;
  pj::LogWriter *arg2 = (pj::LogWriter *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  void *argp2 = 0 ;
  int res2 = 0 ;
  PyObject *swig_obj[2] ;
  
  if (!SWIG_Python_UnpackTuple(args, "LogConfig_writer_set", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__LogConfig, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "LogConfig_writer_set" "', argument " "1"" of type '" "pj::LogConfig *""'"); 
  }
  arg1 = reinterpret_cast< pj::LogConfig * >(argp1);
  res2 = SWIG_ConvertPtr(swig_obj[1], &argp2,SWIGTYPE_p_pj__LogWriter, SWIG_POINTER_DISOWN |  0 );
  if (!SWIG_IsOK(res2)) {
    SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "LogConfig_writer_set" "', argument " "2"" of type '" "pj::LogWriter *""'"); 
  }
  arg2 = reinterpret_cast< pj::LogWriter * >(argp2);
  if (arg1) (arg1)->writer = arg2;
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_LogConfig_writer_get(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::LogConfig *arg1 = (pj::LogConfig *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  pj::LogWriter *result = 0 ;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__LogConfig, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "LogConfig_writer_get" "', argument " "1"" of type '" "pj::LogConfig *""'"); 
  }
  arg1 = reinterpret_cast< pj::LogConfig * >(argp1);
  result = (pj::LogWriter *) ((arg1)->writer);
  resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(result), SWIGTYPE_p_pj__LogWriter, 0 |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_new_LogConfig(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::LogConfig *result = 0 ;
  
  if (!SWIG_Python_UnpackTuple(args, "new_LogConfig", 0, 0, 0)) SWIG_fail;
  result = (pj::LogConfig *)new pj::LogConfig();
  resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(result), SWIGTYPE_p_pj__LogConfig, SWIG_POINTER_NEW |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_LogConfig_readObject(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::LogConfig *arg1 = (pj::LogConfig *) 0 ;
  pj::ContainerNode *arg2 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  void *argp2 = 0 ;
  int res2 = 0 ;
  PyObject *swig_obj[2] ;
  
  if (!SWIG_Python_UnpackTuple(args, "LogConfig_readObject", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__LogConfig, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "LogConfig_readObject" "', argument " "1"" of type '" "pj::LogConfig *""'"); 
  }
  arg1 = reinterpret_cast< pj::LogConfig * >(argp1);
  res2 = SWIG_ConvertPtr(swig_obj[1], &argp2, SWIGTYPE_p_pj__ContainerNode,  0  | 0);
  if (!SWIG_IsOK(res2)) {
    SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "LogConfig_readObject" "', argument " "2"" of type '" "pj::ContainerNode const &""'"); 
  }
  if (!argp2) {
    SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "LogConfig_readObject" "', argument " "2"" of type '" "pj::ContainerNode const &""'"); 
  }
  arg2 = reinterpret_cast< pj::ContainerNode * >(argp2);
  try {
    (arg1)->readObject((pj::ContainerNode const &)*arg2);
  } catch(pj::Error &_e) {
    SWIG_Python_Raise(SWIG_NewPointerObj((new pj::Error(static_cast< const pj::Error& >(_e))),SWIGTYPE_p_pj__Error,SWIG_POINTER_OWN), "pj::Error", SWIGTYPE_p_pj__Error); SWIG_fail;
  }
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_LogConfig_writeObject(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::LogConfig *arg1 = (pj::LogConfig *) 0 ;
  pj::ContainerNode *arg2 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  void *argp2 = 0 ;
  int res2 = 0 ;
  PyObject *swig_obj[2] ;
  
  if (!SWIG_Python_UnpackTuple(args, "LogConfig_writeObject", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__LogConfig, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "LogConfig_writeObject" "', argument " "1"" of type '" "pj::LogConfig const *""'"); 
  }
  arg1 = reinterpret_cast< pj::LogConfig * >(argp1);
  res2 = SWIG_ConvertPtr(swig_obj[1], &argp2, SWIGTYPE_p_pj__ContainerNode,  0 );
  if (!SWIG_IsOK(res2)) {
    SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "LogConfig_writeObject" "', argument " "2"" of type '" "pj::ContainerNode &""'"); 
  }
  if (!argp2) {
    SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "LogConfig_writeObject" "', argument " "2"" of type '" "pj::ContainerNode &""'"); 
  }
  arg2 = reinterpret_cast< pj::ContainerNode * >(argp2);
  try {
    ((pj::LogConfig const *)arg1)->writeObject(*arg2);
  } catch(pj::Error &_e) {
    SWIG_Python_Raise(SWIG_NewPointerObj((new pj::Error(static_cast< const pj::Error& >(_e))),SWIGTYPE_p_pj__Error,SWIG_POINTER_OWN), "pj::Error", SWIGTYPE_p_pj__Error); SWIG_fail;
  }
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_delete_LogConfig(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::LogConfig *arg1 = (pj::LogConfig *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__LogConfig, SWIG_POINTER_DISOWN |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "delete_LogConfig" "', argument " "1"" of type '" "pj::LogConfig *""'"); 
  }
  arg1 = reinterpret_cast< pj::LogConfig * >(argp1);
  delete arg1;
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *LogConfig_swigregister(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *obj;
  if (!SWIG_Python_UnpackTuple(args, "swigregister", 1, 1, &obj)) return NULL;
  SWIG_TypeNewClientData(SWIGTYPE_p_pj__LogConfig, SWIG_NewClientData(obj));
  return SWIG_Py_Void();
}

SWIGINTERN PyObject *LogConfig_swiginit(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  return SWIG_Python_InitShadowInstance(args);
}

SWIGINTERN PyObject *_wrap_MediaConfig_clockRate_set(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::MediaConfig *arg1 = (pj::MediaConfig *) 0 ;
  unsigned int arg2 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  unsigned int val2 ;
  int ecode2 = 0 ;
  PyObject *swig_obj[2] ;
  
  if (!SWIG_Python_UnpackTuple(args, "MediaConfig_clockRate_set", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__MediaConfig, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "MediaConfig_clockRate_set" "', argument " "1"" of type '" "pj::MediaConfig *""'"); 
  }
  arg1 = reinterpret_cast< pj::MediaConfig * >(argp1);
  ecode2 = SWIG_AsVal_unsigned_SS_int(swig_obj[1], &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "MediaConfig_clockRate_set" "', argument " "2"" of type '" "unsigned int""'");
  } 
  arg2 = static_cast< unsigned int >(val2);
  if (arg1) (arg1)->clockRate = arg2;
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_MediaConfig_clockRate_get(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::MediaConfig *arg1 = (pj::MediaConfig *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  unsigned int result;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__MediaConfig, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "MediaConfig_clockRate_get" "', argument " "1"" of type '" "pj::MediaConfig *""'"); 
  }
  arg1 = reinterpret_cast< pj::MediaConfig * >(argp1);
  result = (unsigned int) ((arg1)->clockRate);
  resultobj = SWIG_From_unsigned_SS_int(static_cast< unsigned int >(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_MediaConfig_sndClockRate_set(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::MediaConfig *arg1 = (pj::MediaConfig *) 0 ;
  unsigned int arg2 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  unsigned int val2 ;
  int ecode2 = 0 ;
  PyObject *swig_obj[2] ;
  
  if (!SWIG_Python_UnpackTuple(args, "MediaConfig_sndClockRate_set", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__MediaConfig, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "MediaConfig_sndClockRate_set" "', argument " "1"" of type '" "pj::MediaConfig *""'"); 
  }
  arg1 = reinterpret_cast< pj::MediaConfig * >(argp1);
  ecode2 = SWIG_AsVal_unsigned_SS_int(swig_obj[1], &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "MediaConfig_sndClockRate_set" "', argument " "2"" of type '" "unsigned int""'");
  } 
  arg2 = static_cast< unsigned int >(val2);
  if (arg1) (arg1)->sndClockRate = arg2;
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_MediaConfig_sndClockRate_get(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::MediaConfig *arg1 = (pj::MediaConfig *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  unsigned int result;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__MediaConfig, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "MediaConfig_sndClockRate_get" "', argument " "1"" of type '" "pj::MediaConfig *""'"); 
  }
  arg1 = reinterpret_cast< pj::MediaConfig * >(argp1);
  result = (unsigned int) ((arg1)->sndClockRate);
  resultobj = SWIG_From_unsigned_SS_int(static_cast< unsigned int >(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_MediaConfig_channelCount_set(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::MediaConfig *arg1 = (pj::MediaConfig *) 0 ;
  unsigned int arg2 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  unsigned int val2 ;
  int ecode2 = 0 ;
  PyObject *swig_obj[2] ;
  
  if (!SWIG_Python_UnpackTuple(args, "MediaConfig_channelCount_set", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__MediaConfig, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "MediaConfig_channelCount_set" "', argument " "1"" of type '" "pj::MediaConfig *""'"); 
  }
  arg1 = reinterpret_cast< pj::MediaConfig * >(argp1);
  ecode2 = SWIG_AsVal_unsigned_SS_int(swig_obj[1], &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "MediaConfig_channelCount_set" "', argument " "2"" of type '" "unsigned int""'");
  } 
  arg2 = static_cast< unsigned int >(val2);
  if (arg1) (arg1)->channelCount = arg2;
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_MediaConfig_channelCount_get(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::MediaConfig *arg1 = (pj::MediaConfig *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  unsigned int result;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__MediaConfig, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "MediaConfig_channelCount_get" "', argument " "1"" of type '" "pj::MediaConfig *""'"); 
  }
  arg1 = reinterpret_cast< pj::MediaConfig * >(argp1);
  result = (unsigned int) ((arg1)->channelCount);
  resultobj = SWIG_From_unsigned_SS_int(static_cast< unsigned int >(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_MediaConfig_audioFramePtime_set(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::MediaConfig *arg1 = (pj::MediaConfig *) 0 ;
  unsigned int arg2 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  unsigned int val2 ;
  int ecode2 = 0 ;
  PyObject *swig_obj[2] ;
  
  if (!SWIG_Python_UnpackTuple(args, "MediaConfig_audioFramePtime_set", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__MediaConfig, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "MediaConfig_audioFramePtime_set" "', argument " "1"" of type '" "pj::MediaConfig *""'"); 
  }
  arg1 = reinterpret_cast< pj::MediaConfig * >(argp1);
  ecode2 = SWIG_AsVal_unsigned_SS_int(swig_obj[1], &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "MediaConfig_audioFramePtime_set" "', argument " "2"" of type '" "unsigned int""'");
  } 
  arg2 = static_cast< unsigned int >(val2);
  if (arg1) (arg1)->audioFramePtime = arg2;
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_MediaConfig_audioFramePtime_get(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::MediaConfig *arg1 = (pj::MediaConfig *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  unsigned int result;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__MediaConfig, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "MediaConfig_audioFramePtime_get" "', argument " "1"" of type '" "pj::MediaConfig *""'"); 
  }
  arg1 = reinterpret_cast< pj::MediaConfig * >(argp1);
  result = (unsigned int) ((arg1)->audioFramePtime);
  resultobj = SWIG_From_unsigned_SS_int(static_cast< unsigned int >(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_MediaConfig_maxMediaPorts_set(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::MediaConfig *arg1 = (pj::MediaConfig *) 0 ;
  unsigned int arg2 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  unsigned int val2 ;
  int ecode2 = 0 ;
  PyObject *swig_obj[2] ;
  
  if (!SWIG_Python_UnpackTuple(args, "MediaConfig_maxMediaPorts_set", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__MediaConfig, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "MediaConfig_maxMediaPorts_set" "', argument " "1"" of type '" "pj::MediaConfig *""'"); 
  }
  arg1 = reinterpret_cast< pj::MediaConfig * >(argp1);
  ecode2 = SWIG_AsVal_unsigned_SS_int(swig_obj[1], &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "MediaConfig_maxMediaPorts_set" "', argument " "2"" of type '" "unsigned int""'");
  } 
  arg2 = static_cast< unsigned int >(val2);
  if (arg1) (arg1)->maxMediaPorts = arg2;
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_MediaConfig_maxMediaPorts_get(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::MediaConfig *arg1 = (pj::MediaConfig *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  unsigned int result;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__MediaConfig, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "MediaConfig_maxMediaPorts_get" "', argument " "1"" of type '" "pj::MediaConfig *""'"); 
  }
  arg1 = reinterpret_cast< pj::MediaConfig * >(argp1);
  result = (unsigned int) ((arg1)->maxMediaPorts);
  resultobj = SWIG_From_unsigned_SS_int(static_cast< unsigned int >(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_MediaConfig_hasIoqueue_set(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::MediaConfig *arg1 = (pj::MediaConfig *) 0 ;
  bool arg2 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  bool val2 ;
  int ecode2 = 0 ;
  PyObject *swig_obj[2] ;
  
  if (!SWIG_Python_UnpackTuple(args, "MediaConfig_hasIoqueue_set", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__MediaConfig, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "MediaConfig_hasIoqueue_set" "', argument " "1"" of type '" "pj::MediaConfig *""'"); 
  }
  arg1 = reinterpret_cast< pj::MediaConfig * >(argp1);
  ecode2 = SWIG_AsVal_bool(swig_obj[1], &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "MediaConfig_hasIoqueue_set" "', argument " "2"" of type '" "bool""'");
  } 
  arg2 = static_cast< bool >(val2);
  if (arg1) (arg1)->hasIoqueue = arg2;
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_MediaConfig_hasIoqueue_get(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::MediaConfig *arg1 = (pj::MediaConfig *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  bool result;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__MediaConfig, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "MediaConfig_hasIoqueue_get" "', argument " "1"" of type '" "pj::MediaConfig *""'"); 
  }
  arg1 = reinterpret_cast< pj::MediaConfig * >(argp1);
  result = (bool) ((arg1)->hasIoqueue);
  resultobj = SWIG_From_bool(static_cast< bool >(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_MediaConfig_threadCnt_set(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::MediaConfig *arg1 = (pj::MediaConfig *) 0 ;
  unsigned int arg2 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  unsigned int val2 ;
  int ecode2 = 0 ;
  PyObject *swig_obj[2] ;
  
  if (!SWIG_Python_UnpackTuple(args, "MediaConfig_threadCnt_set", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__MediaConfig, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "MediaConfig_threadCnt_set" "', argument " "1"" of type '" "pj::MediaConfig *""'"); 
  }
  arg1 = reinterpret_cast< pj::MediaConfig * >(argp1);
  ecode2 = SWIG_AsVal_unsigned_SS_int(swig_obj[1], &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "MediaConfig_threadCnt_set" "', argument " "2"" of type '" "unsigned int""'");
  } 
  arg2 = static_cast< unsigned int >(val2);
  if (arg1) (arg1)->threadCnt = arg2;
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_MediaConfig_threadCnt_get(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::MediaConfig *arg1 = (pj::MediaConfig *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  unsigned int result;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__MediaConfig, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "MediaConfig_threadCnt_get" "', argument " "1"" of type '" "pj::MediaConfig *""'"); 
  }
  arg1 = reinterpret_cast< pj::MediaConfig * >(argp1);
  result = (unsigned int) ((arg1)->threadCnt);
  resultobj = SWIG_From_unsigned_SS_int(static_cast< unsigned int >(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_MediaConfig_quality_set(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::MediaConfig *arg1 = (pj::MediaConfig *) 0 ;
  unsigned int arg2 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  unsigned int val2 ;
  int ecode2 = 0 ;
  PyObject *swig_obj[2] ;
  
  if (!SWIG_Python_UnpackTuple(args, "MediaConfig_quality_set", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__MediaConfig, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "MediaConfig_quality_set" "', argument " "1"" of type '" "pj::MediaConfig *""'"); 
  }
  arg1 = reinterpret_cast< pj::MediaConfig * >(argp1);
  ecode2 = SWIG_AsVal_unsigned_SS_int(swig_obj[1], &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "MediaConfig_quality_set" "', argument " "2"" of type '" "unsigned int""'");
  } 
  arg2 = static_cast< unsigned int >(val2);
  if (arg1) (arg1)->quality = arg2;
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_MediaConfig_quality_get(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::MediaConfig *arg1 = (pj::MediaConfig *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  unsigned int result;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__MediaConfig, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "MediaConfig_quality_get" "', argument " "1"" of type '" "pj::MediaConfig *""'"); 
  }
  arg1 = reinterpret_cast< pj::MediaConfig * >(argp1);
  result = (unsigned int) ((arg1)->quality);
  resultobj = SWIG_From_unsigned_SS_int(static_cast< unsigned int >(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_MediaConfig_ptime_set(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::MediaConfig *arg1 = (pj::MediaConfig *) 0 ;
  unsigned int arg2 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  unsigned int val2 ;
  int ecode2 = 0 ;
  PyObject *swig_obj[2] ;
  
  if (!SWIG_Python_UnpackTuple(args, "MediaConfig_ptime_set", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__MediaConfig, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "MediaConfig_ptime_set" "', argument " "1"" of type '" "pj::MediaConfig *""'"); 
  }
  arg1 = reinterpret_cast< pj::MediaConfig * >(argp1);
  ecode2 = SWIG_AsVal_unsigned_SS_int(swig_obj[1], &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "MediaConfig_ptime_set" "', argument " "2"" of type '" "unsigned int""'");
  } 
  arg2 = static_cast< unsigned int >(val2);
  if (arg1) (arg1)->ptime = arg2;
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_MediaConfig_ptime_get(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::MediaConfig *arg1 = (pj::MediaConfig *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  unsigned int result;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__MediaConfig, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "MediaConfig_ptime_get" "', argument " "1"" of type '" "pj::MediaConfig *""'"); 
  }
  arg1 = reinterpret_cast< pj::MediaConfig * >(argp1);
  result = (unsigned int) ((arg1)->ptime);
  resultobj = SWIG_From_unsigned_SS_int(static_cast< unsigned int >(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_MediaConfig_noVad_set(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::MediaConfig *arg1 = (pj::MediaConfig *) 0 ;
  bool arg2 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  bool val2 ;
  int ecode2 = 0 ;
  PyObject *swig_obj[2] ;
  
  if (!SWIG_Python_UnpackTuple(args, "MediaConfig_noVad_set", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__MediaConfig, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "MediaConfig_noVad_set" "', argument " "1"" of type '" "pj::MediaConfig *""'"); 
  }
  arg1 = reinterpret_cast< pj::MediaConfig * >(argp1);
  ecode2 = SWIG_AsVal_bool(swig_obj[1], &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "MediaConfig_noVad_set" "', argument " "2"" of type '" "bool""'");
  } 
  arg2 = static_cast< bool >(val2);
  if (arg1) (arg1)->noVad = arg2;
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_MediaConfig_noVad_get(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::MediaConfig *arg1 = (pj::MediaConfig *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  bool result;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__MediaConfig, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "MediaConfig_noVad_get" "', argument " "1"" of type '" "pj::MediaConfig *""'"); 
  }
  arg1 = reinterpret_cast< pj::MediaConfig * >(argp1);
  result = (bool) ((arg1)->noVad);
  resultobj = SWIG_From_bool(static_cast< bool >(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_MediaConfig_ilbcMode_set(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::MediaConfig *arg1 = (pj::MediaConfig *) 0 ;
  unsigned int arg2 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  unsigned int val2 ;
  int ecode2 = 0 ;
  PyObject *swig_obj[2] ;
  
  if (!SWIG_Python_UnpackTuple(args, "MediaConfig_ilbcMode_set", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__MediaConfig, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "MediaConfig_ilbcMode_set" "', argument " "1"" of type '" "pj::MediaConfig *""'"); 
  }
  arg1 = reinterpret_cast< pj::MediaConfig * >(argp1);
  ecode2 = SWIG_AsVal_unsigned_SS_int(swig_obj[1], &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "MediaConfig_ilbcMode_set" "', argument " "2"" of type '" "unsigned int""'");
  } 
  arg2 = static_cast< unsigned int >(val2);
  if (arg1) (arg1)->ilbcMode = arg2;
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_MediaConfig_ilbcMode_get(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::MediaConfig *arg1 = (pj::MediaConfig *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  unsigned int result;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__MediaConfig, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "MediaConfig_ilbcMode_get" "', argument " "1"" of type '" "pj::MediaConfig *""'"); 
  }
  arg1 = reinterpret_cast< pj::MediaConfig * >(argp1);
  result = (unsigned int) ((arg1)->ilbcMode);
  resultobj = SWIG_From_unsigned_SS_int(static_cast< unsigned int >(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_MediaConfig_txDropPct_set(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::MediaConfig *arg1 = (pj::MediaConfig *) 0 ;
  unsigned int arg2 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  unsigned int val2 ;
  int ecode2 = 0 ;
  PyObject *swig_obj[2] ;
  
  if (!SWIG_Python_UnpackTuple(args, "MediaConfig_txDropPct_set", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__MediaConfig, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "MediaConfig_txDropPct_set" "', argument " "1"" of type '" "pj::MediaConfig *""'"); 
  }
  arg1 = reinterpret_cast< pj::MediaConfig * >(argp1);
  ecode2 = SWIG_AsVal_unsigned_SS_int(swig_obj[1], &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "MediaConfig_txDropPct_set" "', argument " "2"" of type '" "unsigned int""'");
  } 
  arg2 = static_cast< unsigned int >(val2);
  if (arg1) (arg1)->txDropPct = arg2;
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_MediaConfig_txDropPct_get(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::MediaConfig *arg1 = (pj::MediaConfig *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  unsigned int result;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__MediaConfig, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "MediaConfig_txDropPct_get" "', argument " "1"" of type '" "pj::MediaConfig *""'"); 
  }
  arg1 = reinterpret_cast< pj::MediaConfig * >(argp1);
  result = (unsigned int) ((arg1)->txDropPct);
  resultobj = SWIG_From_unsigned_SS_int(static_cast< unsigned int >(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_MediaConfig_rxDropPct_set(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::MediaConfig *arg1 = (pj::MediaConfig *) 0 ;
  unsigned int arg2 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  unsigned int val2 ;
  int ecode2 = 0 ;
  PyObject *swig_obj[2] ;
  
  if (!SWIG_Python_UnpackTuple(args, "MediaConfig_rxDropPct_set", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__MediaConfig, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "MediaConfig_rxDropPct_set" "', argument " "1"" of type '" "pj::MediaConfig *""'"); 
  }
  arg1 = reinterpret_cast< pj::MediaConfig * >(argp1);
  ecode2 = SWIG_AsVal_unsigned_SS_int(swig_obj[1], &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "MediaConfig_rxDropPct_set" "', argument " "2"" of type '" "unsigned int""'");
  } 
  arg2 = static_cast< unsigned int >(val2);
  if (arg1) (arg1)->rxDropPct = arg2;
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_MediaConfig_rxDropPct_get(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::MediaConfig *arg1 = (pj::MediaConfig *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  unsigned int result;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__MediaConfig, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "MediaConfig_rxDropPct_get" "', argument " "1"" of type '" "pj::MediaConfig *""'"); 
  }
  arg1 = reinterpret_cast< pj::MediaConfig * >(argp1);
  result = (unsigned int) ((arg1)->rxDropPct);
  resultobj = SWIG_From_unsigned_SS_int(static_cast< unsigned int >(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_MediaConfig_ecOptions_set(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::MediaConfig *arg1 = (pj::MediaConfig *) 0 ;
  unsigned int arg2 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  unsigned int val2 ;
  int ecode2 = 0 ;
  PyObject *swig_obj[2] ;
  
  if (!SWIG_Python_UnpackTuple(args, "MediaConfig_ecOptions_set", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__MediaConfig, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "MediaConfig_ecOptions_set" "', argument " "1"" of type '" "pj::MediaConfig *""'"); 
  }
  arg1 = reinterpret_cast< pj::MediaConfig * >(argp1);
  ecode2 = SWIG_AsVal_unsigned_SS_int(swig_obj[1], &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "MediaConfig_ecOptions_set" "', argument " "2"" of type '" "unsigned int""'");
  } 
  arg2 = static_cast< unsigned int >(val2);
  if (arg1) (arg1)->ecOptions = arg2;
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_MediaConfig_ecOptions_get(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::MediaConfig *arg1 = (pj::MediaConfig *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  unsigned int result;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__MediaConfig, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "MediaConfig_ecOptions_get" "', argument " "1"" of type '" "pj::MediaConfig *""'"); 
  }
  arg1 = reinterpret_cast< pj::MediaConfig * >(argp1);
  result = (unsigned int) ((arg1)->ecOptions);
  resultobj = SWIG_From_unsigned_SS_int(static_cast< unsigned int >(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_MediaConfig_ecTailLen_set(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::MediaConfig *arg1 = (pj::MediaConfig *) 0 ;
  unsigned int arg2 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  unsigned int val2 ;
  int ecode2 = 0 ;
  PyObject *swig_obj[2] ;
  
  if (!SWIG_Python_UnpackTuple(args, "MediaConfig_ecTailLen_set", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__MediaConfig, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "MediaConfig_ecTailLen_set" "', argument " "1"" of type '" "pj::MediaConfig *""'"); 
  }
  arg1 = reinterpret_cast< pj::MediaConfig * >(argp1);
  ecode2 = SWIG_AsVal_unsigned_SS_int(swig_obj[1], &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "MediaConfig_ecTailLen_set" "', argument " "2"" of type '" "unsigned int""'");
  } 
  arg2 = static_cast< unsigned int >(val2);
  if (arg1) (arg1)->ecTailLen = arg2;
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_MediaConfig_ecTailLen_get(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::MediaConfig *arg1 = (pj::MediaConfig *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  unsigned int result;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__MediaConfig, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "MediaConfig_ecTailLen_get" "', argument " "1"" of type '" "pj::MediaConfig *""'"); 
  }
  arg1 = reinterpret_cast< pj::MediaConfig * >(argp1);
  result = (unsigned int) ((arg1)->ecTailLen);
  resultobj = SWIG_From_unsigned_SS_int(static_cast< unsigned int >(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_MediaConfig_sndRecLatency_set(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::MediaConfig *arg1 = (pj::MediaConfig *) 0 ;
  unsigned int arg2 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  unsigned int val2 ;
  int ecode2 = 0 ;
  PyObject *swig_obj[2] ;
  
  if (!SWIG_Python_UnpackTuple(args, "MediaConfig_sndRecLatency_set", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__MediaConfig, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "MediaConfig_sndRecLatency_set" "', argument " "1"" of type '" "pj::MediaConfig *""'"); 
  }
  arg1 = reinterpret_cast< pj::MediaConfig * >(argp1);
  ecode2 = SWIG_AsVal_unsigned_SS_int(swig_obj[1], &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "MediaConfig_sndRecLatency_set" "', argument " "2"" of type '" "unsigned int""'");
  } 
  arg2 = static_cast< unsigned int >(val2);
  if (arg1) (arg1)->sndRecLatency = arg2;
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_MediaConfig_sndRecLatency_get(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::MediaConfig *arg1 = (pj::MediaConfig *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  unsigned int result;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__MediaConfig, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "MediaConfig_sndRecLatency_get" "', argument " "1"" of type '" "pj::MediaConfig *""'"); 
  }
  arg1 = reinterpret_cast< pj::MediaConfig * >(argp1);
  result = (unsigned int) ((arg1)->sndRecLatency);
  resultobj = SWIG_From_unsigned_SS_int(static_cast< unsigned int >(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_MediaConfig_sndPlayLatency_set(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::MediaConfig *arg1 = (pj::MediaConfig *) 0 ;
  unsigned int arg2 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  unsigned int val2 ;
  int ecode2 = 0 ;
  PyObject *swig_obj[2] ;
  
  if (!SWIG_Python_UnpackTuple(args, "MediaConfig_sndPlayLatency_set", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__MediaConfig, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "MediaConfig_sndPlayLatency_set" "', argument " "1"" of type '" "pj::MediaConfig *""'"); 
  }
  arg1 = reinterpret_cast< pj::MediaConfig * >(argp1);
  ecode2 = SWIG_AsVal_unsigned_SS_int(swig_obj[1], &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "MediaConfig_sndPlayLatency_set" "', argument " "2"" of type '" "unsigned int""'");
  } 
  arg2 = static_cast< unsigned int >(val2);
  if (arg1) (arg1)->sndPlayLatency = arg2;
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_MediaConfig_sndPlayLatency_get(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::MediaConfig *arg1 = (pj::MediaConfig *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  unsigned int result;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__MediaConfig, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "MediaConfig_sndPlayLatency_get" "', argument " "1"" of type '" "pj::MediaConfig *""'"); 
  }
  arg1 = reinterpret_cast< pj::MediaConfig * >(argp1);
  result = (unsigned int) ((arg1)->sndPlayLatency);
  resultobj = SWIG_From_unsigned_SS_int(static_cast< unsigned int >(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_MediaConfig_jbInit_set(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::MediaConfig *arg1 = (pj::MediaConfig *) 0 ;
  int arg2 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  int val2 ;
  int ecode2 = 0 ;
  PyObject *swig_obj[2] ;
  
  if (!SWIG_Python_UnpackTuple(args, "MediaConfig_jbInit_set", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__MediaConfig, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "MediaConfig_jbInit_set" "', argument " "1"" of type '" "pj::MediaConfig *""'"); 
  }
  arg1 = reinterpret_cast< pj::MediaConfig * >(argp1);
  ecode2 = SWIG_AsVal_int(swig_obj[1], &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "MediaConfig_jbInit_set" "', argument " "2"" of type '" "int""'");
  } 
  arg2 = static_cast< int >(val2);
  if (arg1) (arg1)->jbInit = arg2;
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_MediaConfig_jbInit_get(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::MediaConfig *arg1 = (pj::MediaConfig *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  int result;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__MediaConfig, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "MediaConfig_jbInit_get" "', argument " "1"" of type '" "pj::MediaConfig *""'"); 
  }
  arg1 = reinterpret_cast< pj::MediaConfig * >(argp1);
  result = (int) ((arg1)->jbInit);
  resultobj = SWIG_From_int(static_cast< int >(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_MediaConfig_jbMinPre_set(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::MediaConfig *arg1 = (pj::MediaConfig *) 0 ;
  int arg2 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  int val2 ;
  int ecode2 = 0 ;
  PyObject *swig_obj[2] ;
  
  if (!SWIG_Python_UnpackTuple(args, "MediaConfig_jbMinPre_set", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__MediaConfig, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "MediaConfig_jbMinPre_set" "', argument " "1"" of type '" "pj::MediaConfig *""'"); 
  }
  arg1 = reinterpret_cast< pj::MediaConfig * >(argp1);
  ecode2 = SWIG_AsVal_int(swig_obj[1], &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "MediaConfig_jbMinPre_set" "', argument " "2"" of type '" "int""'");
  } 
  arg2 = static_cast< int >(val2);
  if (arg1) (arg1)->jbMinPre = arg2;
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_MediaConfig_jbMinPre_get(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::MediaConfig *arg1 = (pj::MediaConfig *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  int result;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__MediaConfig, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "MediaConfig_jbMinPre_get" "', argument " "1"" of type '" "pj::MediaConfig *""'"); 
  }
  arg1 = reinterpret_cast< pj::MediaConfig * >(argp1);
  result = (int) ((arg1)->jbMinPre);
  resultobj = SWIG_From_int(static_cast< int >(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_MediaConfig_jbMaxPre_set(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::MediaConfig *arg1 = (pj::MediaConfig *) 0 ;
  int arg2 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  int val2 ;
  int ecode2 = 0 ;
  PyObject *swig_obj[2] ;
  
  if (!SWIG_Python_UnpackTuple(args, "MediaConfig_jbMaxPre_set", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__MediaConfig, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "MediaConfig_jbMaxPre_set" "', argument " "1"" of type '" "pj::MediaConfig *""'"); 
  }
  arg1 = reinterpret_cast< pj::MediaConfig * >(argp1);
  ecode2 = SWIG_AsVal_int(swig_obj[1], &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "MediaConfig_jbMaxPre_set" "', argument " "2"" of type '" "int""'");
  } 
  arg2 = static_cast< int >(val2);
  if (arg1) (arg1)->jbMaxPre = arg2;
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_MediaConfig_jbMaxPre_get(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::MediaConfig *arg1 = (pj::MediaConfig *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  int result;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__MediaConfig, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "MediaConfig_jbMaxPre_get" "', argument " "1"" of type '" "pj::MediaConfig *""'"); 
  }
  arg1 = reinterpret_cast< pj::MediaConfig * >(argp1);
  result = (int) ((arg1)->jbMaxPre);
  resultobj = SWIG_From_int(static_cast< int >(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_MediaConfig_jbMax_set(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::MediaConfig *arg1 = (pj::MediaConfig *) 0 ;
  int arg2 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  int val2 ;
  int ecode2 = 0 ;
  PyObject *swig_obj[2] ;
  
  if (!SWIG_Python_UnpackTuple(args, "MediaConfig_jbMax_set", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__MediaConfig, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "MediaConfig_jbMax_set" "', argument " "1"" of type '" "pj::MediaConfig *""'"); 
  }
  arg1 = reinterpret_cast< pj::MediaConfig * >(argp1);
  ecode2 = SWIG_AsVal_int(swig_obj[1], &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "MediaConfig_jbMax_set" "', argument " "2"" of type '" "int""'");
  } 
  arg2 = static_cast< int >(val2);
  if (arg1) (arg1)->jbMax = arg2;
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_MediaConfig_jbMax_get(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::MediaConfig *arg1 = (pj::MediaConfig *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  int result;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__MediaConfig, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "MediaConfig_jbMax_get" "', argument " "1"" of type '" "pj::MediaConfig *""'"); 
  }
  arg1 = reinterpret_cast< pj::MediaConfig * >(argp1);
  result = (int) ((arg1)->jbMax);
  resultobj = SWIG_From_int(static_cast< int >(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_MediaConfig_jbDiscardAlgo_set(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::MediaConfig *arg1 = (pj::MediaConfig *) 0 ;
  pjmedia_jb_discard_algo arg2 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  void *argp2 ;
  int res2 = 0 ;
  PyObject *swig_obj[2] ;
  
  if (!SWIG_Python_UnpackTuple(args, "MediaConfig_jbDiscardAlgo_set", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__MediaConfig, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "MediaConfig_jbDiscardAlgo_set" "', argument " "1"" of type '" "pj::MediaConfig *""'"); 
  }
  arg1 = reinterpret_cast< pj::MediaConfig * >(argp1);
  {
    res2 = SWIG_ConvertPtr(swig_obj[1], &argp2, SWIGTYPE_p_pjmedia_jb_discard_algo,  0  | 0);
    if (!SWIG_IsOK(res2)) {
      SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "MediaConfig_jbDiscardAlgo_set" "', argument " "2"" of type '" "pjmedia_jb_discard_algo""'"); 
    }  
    if (!argp2) {
      SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "MediaConfig_jbDiscardAlgo_set" "', argument " "2"" of type '" "pjmedia_jb_discard_algo""'");
    } else {
      pjmedia_jb_discard_algo * temp = reinterpret_cast< pjmedia_jb_discard_algo * >(argp2);
      arg2 = *temp;
      if (SWIG_IsNewObj(res2)) delete temp;
    }
  }
  if (arg1) (arg1)->jbDiscardAlgo = arg2;
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_MediaConfig_jbDiscardAlgo_get(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::MediaConfig *arg1 = (pj::MediaConfig *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  pjmedia_jb_discard_algo result;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__MediaConfig, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "MediaConfig_jbDiscardAlgo_get" "', argument " "1"" of type '" "pj::MediaConfig *""'"); 
  }
  arg1 = reinterpret_cast< pj::MediaConfig * >(argp1);
  result =  ((arg1)->jbDiscardAlgo);
  resultobj = SWIG_NewPointerObj((new pjmedia_jb_discard_algo(static_cast< const pjmedia_jb_discard_algo& >(result))), SWIGTYPE_p_pjmedia_jb_discard_algo, SWIG_POINTER_OWN |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_MediaConfig_sndAutoCloseTime_set(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::MediaConfig *arg1 = (pj::MediaConfig *) 0 ;
  int arg2 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  int val2 ;
  int ecode2 = 0 ;
  PyObject *swig_obj[2] ;
  
  if (!SWIG_Python_UnpackTuple(args, "MediaConfig_sndAutoCloseTime_set", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__MediaConfig, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "MediaConfig_sndAutoCloseTime_set" "', argument " "1"" of type '" "pj::MediaConfig *""'"); 
  }
  arg1 = reinterpret_cast< pj::MediaConfig * >(argp1);
  ecode2 = SWIG_AsVal_int(swig_obj[1], &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "MediaConfig_sndAutoCloseTime_set" "', argument " "2"" of type '" "int""'");
  } 
  arg2 = static_cast< int >(val2);
  if (arg1) (arg1)->sndAutoCloseTime = arg2;
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_MediaConfig_sndAutoCloseTime_get(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::MediaConfig *arg1 = (pj::MediaConfig *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  int result;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__MediaConfig, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "MediaConfig_sndAutoCloseTime_get" "', argument " "1"" of type '" "pj::MediaConfig *""'"); 
  }
  arg1 = reinterpret_cast< pj::MediaConfig * >(argp1);
  result = (int) ((arg1)->sndAutoCloseTime);
  resultobj = SWIG_From_int(static_cast< int >(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_MediaConfig_vidPreviewEnableNative_set(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::MediaConfig *arg1 = (pj::MediaConfig *) 0 ;
  bool arg2 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  bool val2 ;
  int ecode2 = 0 ;
  PyObject *swig_obj[2] ;
  
  if (!SWIG_Python_UnpackTuple(args, "MediaConfig_vidPreviewEnableNative_set", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__MediaConfig, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "MediaConfig_vidPreviewEnableNative_set" "', argument " "1"" of type '" "pj::MediaConfig *""'"); 
  }
  arg1 = reinterpret_cast< pj::MediaConfig * >(argp1);
  ecode2 = SWIG_AsVal_bool(swig_obj[1], &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "MediaConfig_vidPreviewEnableNative_set" "', argument " "2"" of type '" "bool""'");
  } 
  arg2 = static_cast< bool >(val2);
  if (arg1) (arg1)->vidPreviewEnableNative = arg2;
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_MediaConfig_vidPreviewEnableNative_get(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::MediaConfig *arg1 = (pj::MediaConfig *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  bool result;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__MediaConfig, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "MediaConfig_vidPreviewEnableNative_get" "', argument " "1"" of type '" "pj::MediaConfig *""'"); 
  }
  arg1 = reinterpret_cast< pj::MediaConfig * >(argp1);
  result = (bool) ((arg1)->vidPreviewEnableNative);
  resultobj = SWIG_From_bool(static_cast< bool >(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_new_MediaConfig(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::MediaConfig *result = 0 ;
  
  if (!SWIG_Python_UnpackTuple(args, "new_MediaConfig", 0, 0, 0)) SWIG_fail;
  result = (pj::MediaConfig *)new pj::MediaConfig();
  resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(result), SWIGTYPE_p_pj__MediaConfig, SWIG_POINTER_NEW |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_MediaConfig_readObject(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::MediaConfig *arg1 = (pj::MediaConfig *) 0 ;
  pj::ContainerNode *arg2 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  void *argp2 = 0 ;
  int res2 = 0 ;
  PyObject *swig_obj[2] ;
  
  if (!SWIG_Python_UnpackTuple(args, "MediaConfig_readObject", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__MediaConfig, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "MediaConfig_readObject" "', argument " "1"" of type '" "pj::MediaConfig *""'"); 
  }
  arg1 = reinterpret_cast< pj::MediaConfig * >(argp1);
  res2 = SWIG_ConvertPtr(swig_obj[1], &argp2, SWIGTYPE_p_pj__ContainerNode,  0  | 0);
  if (!SWIG_IsOK(res2)) {
    SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "MediaConfig_readObject" "', argument " "2"" of type '" "pj::ContainerNode const &""'"); 
  }
  if (!argp2) {
    SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "MediaConfig_readObject" "', argument " "2"" of type '" "pj::ContainerNode const &""'"); 
  }
  arg2 = reinterpret_cast< pj::ContainerNode * >(argp2);
  try {
    (arg1)->readObject((pj::ContainerNode const &)*arg2);
  } catch(pj::Error &_e) {
    SWIG_Python_Raise(SWIG_NewPointerObj((new pj::Error(static_cast< const pj::Error& >(_e))),SWIGTYPE_p_pj__Error,SWIG_POINTER_OWN), "pj::Error", SWIGTYPE_p_pj__Error); SWIG_fail;
  }
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_MediaConfig_writeObject(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::MediaConfig *arg1 = (pj::MediaConfig *) 0 ;
  pj::ContainerNode *arg2 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  void *argp2 = 0 ;
  int res2 = 0 ;
  PyObject *swig_obj[2] ;
  
  if (!SWIG_Python_UnpackTuple(args, "MediaConfig_writeObject", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__MediaConfig, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "MediaConfig_writeObject" "', argument " "1"" of type '" "pj::MediaConfig const *""'"); 
  }
  arg1 = reinterpret_cast< pj::MediaConfig * >(argp1);
  res2 = SWIG_ConvertPtr(swig_obj[1], &argp2, SWIGTYPE_p_pj__ContainerNode,  0 );
  if (!SWIG_IsOK(res2)) {
    SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "MediaConfig_writeObject" "', argument " "2"" of type '" "pj::ContainerNode &""'"); 
  }
  if (!argp2) {
    SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "MediaConfig_writeObject" "', argument " "2"" of type '" "pj::ContainerNode &""'"); 
  }
  arg2 = reinterpret_cast< pj::ContainerNode * >(argp2);
  try {
    ((pj::MediaConfig const *)arg1)->writeObject(*arg2);
  } catch(pj::Error &_e) {
    SWIG_Python_Raise(SWIG_NewPointerObj((new pj::Error(static_cast< const pj::Error& >(_e))),SWIGTYPE_p_pj__Error,SWIG_POINTER_OWN), "pj::Error", SWIGTYPE_p_pj__Error); SWIG_fail;
  }
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_delete_MediaConfig(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::MediaConfig *arg1 = (pj::MediaConfig *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__MediaConfig, SWIG_POINTER_DISOWN |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "delete_MediaConfig" "', argument " "1"" of type '" "pj::MediaConfig *""'"); 
  }
  arg1 = reinterpret_cast< pj::MediaConfig * >(argp1);
  delete arg1;
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *MediaConfig_swigregister(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *obj;
  if (!SWIG_Python_UnpackTuple(args, "swigregister", 1, 1, &obj)) return NULL;
  SWIG_TypeNewClientData(SWIGTYPE_p_pj__MediaConfig, SWIG_NewClientData(obj));
  return SWIG_Py_Void();
}

SWIGINTERN PyObject *MediaConfig_swiginit(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  return SWIG_Python_InitShadowInstance(args);
}

SWIGINTERN PyObject *_wrap_EpConfig_uaConfig_set(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::EpConfig *arg1 = (pj::EpConfig *) 0 ;
  pj::UaConfig *arg2 = (pj::UaConfig *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  void *argp2 = 0 ;
  int res2 = 0 ;
  PyObject *swig_obj[2] ;
  
  if (!SWIG_Python_UnpackTuple(args, "EpConfig_uaConfig_set", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__EpConfig, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "EpConfig_uaConfig_set" "', argument " "1"" of type '" "pj::EpConfig *""'"); 
  }
  arg1 = reinterpret_cast< pj::EpConfig * >(argp1);
  res2 = SWIG_ConvertPtr(swig_obj[1], &argp2,SWIGTYPE_p_pj__UaConfig, 0 |  0 );
  if (!SWIG_IsOK(res2)) {
    SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "EpConfig_uaConfig_set" "', argument " "2"" of type '" "pj::UaConfig *""'"); 
  }
  arg2 = reinterpret_cast< pj::UaConfig * >(argp2);
  if (arg1) (arg1)->uaConfig = *arg2;
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_EpConfig_uaConfig_get(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::EpConfig *arg1 = (pj::EpConfig *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  pj::UaConfig *result = 0 ;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__EpConfig, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "EpConfig_uaConfig_get" "', argument " "1"" of type '" "pj::EpConfig *""'"); 
  }
  arg1 = reinterpret_cast< pj::EpConfig * >(argp1);
  result = (pj::UaConfig *)& ((arg1)->uaConfig);
  resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(result), SWIGTYPE_p_pj__UaConfig, 0 |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_EpConfig_logConfig_set(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::EpConfig *arg1 = (pj::EpConfig *) 0 ;
  pj::LogConfig *arg2 = (pj::LogConfig *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  void *argp2 = 0 ;
  int res2 = 0 ;
  PyObject *swig_obj[2] ;
  
  if (!SWIG_Python_UnpackTuple(args, "EpConfig_logConfig_set", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__EpConfig, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "EpConfig_logConfig_set" "', argument " "1"" of type '" "pj::EpConfig *""'"); 
  }
  arg1 = reinterpret_cast< pj::EpConfig * >(argp1);
  res2 = SWIG_ConvertPtr(swig_obj[1], &argp2,SWIGTYPE_p_pj__LogConfig, 0 |  0 );
  if (!SWIG_IsOK(res2)) {
    SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "EpConfig_logConfig_set" "', argument " "2"" of type '" "pj::LogConfig *""'"); 
  }
  arg2 = reinterpret_cast< pj::LogConfig * >(argp2);
  if (arg1) (arg1)->logConfig = *arg2;
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_EpConfig_logConfig_get(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::EpConfig *arg1 = (pj::EpConfig *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  pj::LogConfig *result = 0 ;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__EpConfig, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "EpConfig_logConfig_get" "', argument " "1"" of type '" "pj::EpConfig *""'"); 
  }
  arg1 = reinterpret_cast< pj::EpConfig * >(argp1);
  result = (pj::LogConfig *)& ((arg1)->logConfig);
  resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(result), SWIGTYPE_p_pj__LogConfig, 0 |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_EpConfig_medConfig_set(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::EpConfig *arg1 = (pj::EpConfig *) 0 ;
  pj::MediaConfig *arg2 = (pj::MediaConfig *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  void *argp2 = 0 ;
  int res2 = 0 ;
  PyObject *swig_obj[2] ;
  
  if (!SWIG_Python_UnpackTuple(args, "EpConfig_medConfig_set", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__EpConfig, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "EpConfig_medConfig_set" "', argument " "1"" of type '" "pj::EpConfig *""'"); 
  }
  arg1 = reinterpret_cast< pj::EpConfig * >(argp1);
  res2 = SWIG_ConvertPtr(swig_obj[1], &argp2,SWIGTYPE_p_pj__MediaConfig, 0 |  0 );
  if (!SWIG_IsOK(res2)) {
    SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "EpConfig_medConfig_set" "', argument " "2"" of type '" "pj::MediaConfig *""'"); 
  }
  arg2 = reinterpret_cast< pj::MediaConfig * >(argp2);
  if (arg1) (arg1)->medConfig = *arg2;
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_EpConfig_medConfig_get(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::EpConfig *arg1 = (pj::EpConfig *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  pj::MediaConfig *result = 0 ;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__EpConfig, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "EpConfig_medConfig_get" "', argument " "1"" of type '" "pj::EpConfig *""'"); 
  }
  arg1 = reinterpret_cast< pj::EpConfig * >(argp1);
  result = (pj::MediaConfig *)& ((arg1)->medConfig);
  resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(result), SWIGTYPE_p_pj__MediaConfig, 0 |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_EpConfig_readObject(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::EpConfig *arg1 = (pj::EpConfig *) 0 ;
  pj::ContainerNode *arg2 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  void *argp2 = 0 ;
  int res2 = 0 ;
  PyObject *swig_obj[2] ;
  
  if (!SWIG_Python_UnpackTuple(args, "EpConfig_readObject", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__EpConfig, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "EpConfig_readObject" "', argument " "1"" of type '" "pj::EpConfig *""'"); 
  }
  arg1 = reinterpret_cast< pj::EpConfig * >(argp1);
  res2 = SWIG_ConvertPtr(swig_obj[1], &argp2, SWIGTYPE_p_pj__ContainerNode,  0  | 0);
  if (!SWIG_IsOK(res2)) {
    SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "EpConfig_readObject" "', argument " "2"" of type '" "pj::ContainerNode const &""'"); 
  }
  if (!argp2) {
    SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "EpConfig_readObject" "', argument " "2"" of type '" "pj::ContainerNode const &""'"); 
  }
  arg2 = reinterpret_cast< pj::ContainerNode * >(argp2);
  try {
    (arg1)->readObject((pj::ContainerNode const &)*arg2);
  } catch(pj::Error &_e) {
    SWIG_Python_Raise(SWIG_NewPointerObj((new pj::Error(static_cast< const pj::Error& >(_e))),SWIGTYPE_p_pj__Error,SWIG_POINTER_OWN), "pj::Error", SWIGTYPE_p_pj__Error); SWIG_fail;
  }
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_EpConfig_writeObject(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::EpConfig *arg1 = (pj::EpConfig *) 0 ;
  pj::ContainerNode *arg2 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  void *argp2 = 0 ;
  int res2 = 0 ;
  PyObject *swig_obj[2] ;
  
  if (!SWIG_Python_UnpackTuple(args, "EpConfig_writeObject", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__EpConfig, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "EpConfig_writeObject" "', argument " "1"" of type '" "pj::EpConfig const *""'"); 
  }
  arg1 = reinterpret_cast< pj::EpConfig * >(argp1);
  res2 = SWIG_ConvertPtr(swig_obj[1], &argp2, SWIGTYPE_p_pj__ContainerNode,  0 );
  if (!SWIG_IsOK(res2)) {
    SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "EpConfig_writeObject" "', argument " "2"" of type '" "pj::ContainerNode &""'"); 
  }
  if (!argp2) {
    SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "EpConfig_writeObject" "', argument " "2"" of type '" "pj::ContainerNode &""'"); 
  }
  arg2 = reinterpret_cast< pj::ContainerNode * >(argp2);
  try {
    ((pj::EpConfig const *)arg1)->writeObject(*arg2);
  } catch(pj::Error &_e) {
    SWIG_Python_Raise(SWIG_NewPointerObj((new pj::Error(static_cast< const pj::Error& >(_e))),SWIGTYPE_p_pj__Error,SWIG_POINTER_OWN), "pj::Error", SWIGTYPE_p_pj__Error); SWIG_fail;
  }
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_new_EpConfig(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::EpConfig *result = 0 ;
  
  if (!SWIG_Python_UnpackTuple(args, "new_EpConfig", 0, 0, 0)) SWIG_fail;
  result = (pj::EpConfig *)new pj::EpConfig();
  resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(result), SWIGTYPE_p_pj__EpConfig, SWIG_POINTER_NEW |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_delete_EpConfig(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::EpConfig *arg1 = (pj::EpConfig *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__EpConfig, SWIG_POINTER_DISOWN |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "delete_EpConfig" "', argument " "1"" of type '" "pj::EpConfig *""'"); 
  }
  arg1 = reinterpret_cast< pj::EpConfig * >(argp1);
  delete arg1;
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *EpConfig_swigregister(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *obj;
  if (!SWIG_Python_UnpackTuple(args, "swigregister", 1, 1, &obj)) return NULL;
  SWIG_TypeNewClientData(SWIGTYPE_p_pj__EpConfig, SWIG_NewClientData(obj));
  return SWIG_Py_Void();
}

SWIGINTERN PyObject *EpConfig_swiginit(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  return SWIG_Python_InitShadowInstance(args);
}

SWIGINTERN PyObject *_wrap_PendingJob_execute(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::PendingJob *arg1 = (pj::PendingJob *) 0 ;
  bool arg2 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  bool val2 ;
  int ecode2 = 0 ;
  PyObject *swig_obj[2] ;
  
  if (!SWIG_Python_UnpackTuple(args, "PendingJob_execute", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__PendingJob, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "PendingJob_execute" "', argument " "1"" of type '" "pj::PendingJob *""'"); 
  }
  arg1 = reinterpret_cast< pj::PendingJob * >(argp1);
  ecode2 = SWIG_AsVal_bool(swig_obj[1], &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "PendingJob_execute" "', argument " "2"" of type '" "bool""'");
  } 
  arg2 = static_cast< bool >(val2);
  (arg1)->execute(arg2);
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_delete_PendingJob(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::PendingJob *arg1 = (pj::PendingJob *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__PendingJob, SWIG_POINTER_DISOWN |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "delete_PendingJob" "', argument " "1"" of type '" "pj::PendingJob *""'"); 
  }
  arg1 = reinterpret_cast< pj::PendingJob * >(argp1);
  delete arg1;
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *PendingJob_swigregister(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *obj;
  if (!SWIG_Python_UnpackTuple(args, "swigregister", 1, 1, &obj)) return NULL;
  SWIG_TypeNewClientData(SWIGTYPE_p_pj__PendingJob, SWIG_NewClientData(obj));
  return SWIG_Py_Void();
}

SWIGINTERN PyObject *_wrap_Endpoint_instance(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  Swig::Director *director = 0;
  pj::Endpoint *result = 0 ;
  
  if (!SWIG_Python_UnpackTuple(args, "Endpoint_instance", 0, 0, 0)) SWIG_fail;
  try {
    result = (pj::Endpoint *) &pj::Endpoint::instance();
  } catch(pj::Error &_e) {
    SWIG_Python_Raise(SWIG_NewPointerObj((new pj::Error(static_cast< const pj::Error& >(_e))),SWIGTYPE_p_pj__Error,SWIG_POINTER_OWN), "pj::Error", SWIGTYPE_p_pj__Error); SWIG_fail;
  }
  director = SWIG_DIRECTOR_CAST(result);
  if (director) {
    resultobj = director->swig_get_self();
    Py_INCREF(resultobj);
  } else {
    resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(result), SWIGTYPE_p_pj__Endpoint, 0 |  0 );
  }
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_new_Endpoint(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  PyObject *arg1 = (PyObject *) 0 ;
  PyObject *swig_obj[1] ;
  pj::Endpoint *result = 0 ;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  arg1 = swig_obj[0];
  if ( arg1 != Py_None ) {
    /* subclassed */
    result = (pj::Endpoint *)new SwigDirector_Endpoint(arg1); 
  } else {
    result = (pj::Endpoint *)new pj::Endpoint(); 
  }
  
  resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(result), SWIGTYPE_p_pj__Endpoint, SWIG_POINTER_NEW |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_delete_Endpoint(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::Endpoint *arg1 = (pj::Endpoint *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__Endpoint, SWIG_POINTER_DISOWN |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "delete_Endpoint" "', argument " "1"" of type '" "pj::Endpoint *""'"); 
  }
  arg1 = reinterpret_cast< pj::Endpoint * >(argp1);
  delete arg1;
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_Endpoint_libVersion(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::Endpoint *arg1 = (pj::Endpoint *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  pj::Version result;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__Endpoint, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "Endpoint_libVersion" "', argument " "1"" of type '" "pj::Endpoint const *""'"); 
  }
  arg1 = reinterpret_cast< pj::Endpoint * >(argp1);
  result = ((pj::Endpoint const *)arg1)->libVersion();
  resultobj = SWIG_NewPointerObj((new pj::Version(static_cast< const pj::Version& >(result))), SWIGTYPE_p_pj__Version, SWIG_POINTER_OWN |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_Endpoint_libCreate(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::Endpoint *arg1 = (pj::Endpoint *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__Endpoint, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "Endpoint_libCreate" "', argument " "1"" of type '" "pj::Endpoint *""'"); 
  }
  arg1 = reinterpret_cast< pj::Endpoint * >(argp1);
  try {
    (arg1)->libCreate();
  } catch(pj::Error &_e) {
    SWIG_Python_Raise(SWIG_NewPointerObj((new pj::Error(static_cast< const pj::Error& >(_e))),SWIGTYPE_p_pj__Error,SWIG_POINTER_OWN), "pj::Error", SWIGTYPE_p_pj__Error); SWIG_fail;
  }
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_Endpoint_libGetState(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::Endpoint *arg1 = (pj::Endpoint *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  pjsua_state result;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__Endpoint, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "Endpoint_libGetState" "', argument " "1"" of type '" "pj::Endpoint const *""'"); 
  }
  arg1 = reinterpret_cast< pj::Endpoint * >(argp1);
  result = (pjsua_state)((pj::Endpoint const *)arg1)->libGetState();
  resultobj = SWIG_From_int(static_cast< int >(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_Endpoint_libInit(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::Endpoint *arg1 = (pj::Endpoint *) 0 ;
  pj::EpConfig *arg2 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  void *argp2 = 0 ;
  int res2 = 0 ;
  PyObject *swig_obj[2] ;
  
  if (!SWIG_Python_UnpackTuple(args, "Endpoint_libInit", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__Endpoint, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "Endpoint_libInit" "', argument " "1"" of type '" "pj::Endpoint *""'"); 
  }
  arg1 = reinterpret_cast< pj::Endpoint * >(argp1);
  res2 = SWIG_ConvertPtr(swig_obj[1], &argp2, SWIGTYPE_p_pj__EpConfig,  0  | 0);
  if (!SWIG_IsOK(res2)) {
    SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "Endpoint_libInit" "', argument " "2"" of type '" "pj::EpConfig const &""'"); 
  }
  if (!argp2) {
    SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "Endpoint_libInit" "', argument " "2"" of type '" "pj::EpConfig const &""'"); 
  }
  arg2 = reinterpret_cast< pj::EpConfig * >(argp2);
  try {
    (arg1)->libInit((pj::EpConfig const &)*arg2);
  } catch(pj::Error &_e) {
    SWIG_Python_Raise(SWIG_NewPointerObj((new pj::Error(static_cast< const pj::Error& >(_e))),SWIGTYPE_p_pj__Error,SWIG_POINTER_OWN), "pj::Error", SWIGTYPE_p_pj__Error); SWIG_fail;
  }
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_Endpoint_libStart(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::Endpoint *arg1 = (pj::Endpoint *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__Endpoint, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "Endpoint_libStart" "', argument " "1"" of type '" "pj::Endpoint *""'"); 
  }
  arg1 = reinterpret_cast< pj::Endpoint * >(argp1);
  try {
    (arg1)->libStart();
  } catch(pj::Error &_e) {
    SWIG_Python_Raise(SWIG_NewPointerObj((new pj::Error(static_cast< const pj::Error& >(_e))),SWIGTYPE_p_pj__Error,SWIG_POINTER_OWN), "pj::Error", SWIGTYPE_p_pj__Error); SWIG_fail;
  }
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_Endpoint_libRegisterThread(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::Endpoint *arg1 = (pj::Endpoint *) 0 ;
  pj::string *arg2 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  int res2 = SWIG_OLDOBJ ;
  PyObject *swig_obj[2] ;
  
  if (!SWIG_Python_UnpackTuple(args, "Endpoint_libRegisterThread", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__Endpoint, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "Endpoint_libRegisterThread" "', argument " "1"" of type '" "pj::Endpoint *""'"); 
  }
  arg1 = reinterpret_cast< pj::Endpoint * >(argp1);
  {
    std::string *ptr = (std::string *)0;
    res2 = SWIG_AsPtr_std_string(swig_obj[1], &ptr);
    if (!SWIG_IsOK(res2)) {
      SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "Endpoint_libRegisterThread" "', argument " "2"" of type '" "pj::string const &""'"); 
    }
    if (!ptr) {
      SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "Endpoint_libRegisterThread" "', argument " "2"" of type '" "pj::string const &""'"); 
    }
    arg2 = ptr;
  }
  try {
    (arg1)->libRegisterThread((pj::string const &)*arg2);
  } catch(pj::Error &_e) {
    SWIG_Python_Raise(SWIG_NewPointerObj((new pj::Error(static_cast< const pj::Error& >(_e))),SWIGTYPE_p_pj__Error,SWIG_POINTER_OWN), "pj::Error", SWIGTYPE_p_pj__Error); SWIG_fail;
  }
  resultobj = SWIG_Py_Void();
  if (SWIG_IsNewObj(res2)) delete arg2;
  return resultobj;
fail:
  if (SWIG_IsNewObj(res2)) delete arg2;
  return NULL;
}


SWIGINTERN PyObject *_wrap_Endpoint_libIsThreadRegistered(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::Endpoint *arg1 = (pj::Endpoint *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  bool result;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__Endpoint, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "Endpoint_libIsThreadRegistered" "', argument " "1"" of type '" "pj::Endpoint *""'"); 
  }
  arg1 = reinterpret_cast< pj::Endpoint * >(argp1);
  result = (bool)(arg1)->libIsThreadRegistered();
  resultobj = SWIG_From_bool(static_cast< bool >(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_Endpoint_libStopWorkerThreads(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::Endpoint *arg1 = (pj::Endpoint *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__Endpoint, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "Endpoint_libStopWorkerThreads" "', argument " "1"" of type '" "pj::Endpoint *""'"); 
  }
  arg1 = reinterpret_cast< pj::Endpoint * >(argp1);
  (arg1)->libStopWorkerThreads();
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_Endpoint_libHandleEvents(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::Endpoint *arg1 = (pj::Endpoint *) 0 ;
  unsigned int arg2 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  unsigned int val2 ;
  int ecode2 = 0 ;
  PyObject *swig_obj[2] ;
  int result;
  
  if (!SWIG_Python_UnpackTuple(args, "Endpoint_libHandleEvents", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__Endpoint, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "Endpoint_libHandleEvents" "', argument " "1"" of type '" "pj::Endpoint *""'"); 
  }
  arg1 = reinterpret_cast< pj::Endpoint * >(argp1);
  ecode2 = SWIG_AsVal_unsigned_SS_int(swig_obj[1], &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "Endpoint_libHandleEvents" "', argument " "2"" of type '" "unsigned int""'");
  } 
  arg2 = static_cast< unsigned int >(val2);
  result = (int)(arg1)->libHandleEvents(arg2);
  resultobj = SWIG_From_int(static_cast< int >(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_Endpoint_libDestroy__SWIG_0(PyObject *SWIGUNUSEDPARM(self), Py_ssize_t nobjs, PyObject **swig_obj) {
  PyObject *resultobj = 0;
  pj::Endpoint *arg1 = (pj::Endpoint *) 0 ;
  unsigned int arg2 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  unsigned int val2 ;
  int ecode2 = 0 ;
  
  if ((nobjs < 2) || (nobjs > 2)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__Endpoint, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "Endpoint_libDestroy" "', argument " "1"" of type '" "pj::Endpoint *""'"); 
  }
  arg1 = reinterpret_cast< pj::Endpoint * >(argp1);
  ecode2 = SWIG_AsVal_unsigned_SS_int(swig_obj[1], &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "Endpoint_libDestroy" "', argument " "2"" of type '" "unsigned int""'");
  } 
  arg2 = static_cast< unsigned int >(val2);
  try {
    (arg1)->libDestroy(arg2);
  } catch(pj::Error &_e) {
    SWIG_Python_Raise(SWIG_NewPointerObj((new pj::Error(static_cast< const pj::Error& >(_e))),SWIGTYPE_p_pj__Error,SWIG_POINTER_OWN), "pj::Error", SWIGTYPE_p_pj__Error); SWIG_fail;
  }
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_Endpoint_libDestroy__SWIG_1(PyObject *SWIGUNUSEDPARM(self), Py_ssize_t nobjs, PyObject **swig_obj) {
  PyObject *resultobj = 0;
  pj::Endpoint *arg1 = (pj::Endpoint *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  
  if ((nobjs < 1) || (nobjs > 1)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__Endpoint, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "Endpoint_libDestroy" "', argument " "1"" of type '" "pj::Endpoint *""'"); 
  }
  arg1 = reinterpret_cast< pj::Endpoint * >(argp1);
  try {
    (arg1)->libDestroy();
  } catch(pj::Error &_e) {
    SWIG_Python_Raise(SWIG_NewPointerObj((new pj::Error(static_cast< const pj::Error& >(_e))),SWIGTYPE_p_pj__Error,SWIG_POINTER_OWN), "pj::Error", SWIGTYPE_p_pj__Error); SWIG_fail;
  }
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_Endpoint_libDestroy(PyObject *self, PyObject *args) {
  Py_ssize_t argc;
  PyObject *argv[3] = {
    0
  };
  
  if (!(argc = SWIG_Python_UnpackTuple(args, "Endpoint_libDestroy", 0, 2, argv))) SWIG_fail;
  --argc;
  if (argc == 1) {
    int _v;
    void *vptr = 0;
    int res = SWIG_ConvertPtr(argv[0], &vptr, SWIGTYPE_p_pj__Endpoint, 0);
    _v = SWIG_CheckState(res);
    if (_v) {
      return _wrap_Endpoint_libDestroy__SWIG_1(self, argc, argv);
    }
  }
  if (argc == 2) {
    int _v;
    void *vptr = 0;
    int res = SWIG_ConvertPtr(argv[0], &vptr, SWIGTYPE_p_pj__Endpoint, 0);
    _v = SWIG_CheckState(res);
    if (_v) {
      {
        int res = SWIG_AsVal_unsigned_SS_int(argv[1], NULL);
        _v = SWIG_CheckState(res);
      }
      if (_v) {
        return _wrap_Endpoint_libDestroy__SWIG_0(self, argc, argv);
      }
    }
  }
  
fail:
  SWIG_Python_RaiseOrModifyTypeError("Wrong number or type of arguments for overloaded function 'Endpoint_libDestroy'.\n"
    "  Possible C/C++ prototypes are:\n"
    "    pj::Endpoint::libDestroy(unsigned int)\n"
    "    pj::Endpoint::libDestroy()\n");
  return 0;
}


SWIGINTERN PyObject *_wrap_Endpoint_utilStrError(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::Endpoint *arg1 = (pj::Endpoint *) 0 ;
  pj_status_t arg2 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  int val2 ;
  int ecode2 = 0 ;
  PyObject *swig_obj[2] ;
  pj::string result;
  
  if (!SWIG_Python_UnpackTuple(args, "Endpoint_utilStrError", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__Endpoint, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "Endpoint_utilStrError" "', argument " "1"" of type '" "pj::Endpoint *""'"); 
  }
  arg1 = reinterpret_cast< pj::Endpoint * >(argp1);
  ecode2 = SWIG_AsVal_int(swig_obj[1], &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "Endpoint_utilStrError" "', argument " "2"" of type '" "pj_status_t""'");
  } 
  arg2 = static_cast< pj_status_t >(val2);
  result = (arg1)->utilStrError(arg2);
  resultobj = SWIG_From_std_string(static_cast< std::string >(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_Endpoint_utilLogWrite__SWIG_0(PyObject *SWIGUNUSEDPARM(self), Py_ssize_t nobjs, PyObject **swig_obj) {
  PyObject *resultobj = 0;
  pj::Endpoint *arg1 = (pj::Endpoint *) 0 ;
  int arg2 ;
  pj::string *arg3 = 0 ;
  pj::string *arg4 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  int val2 ;
  int ecode2 = 0 ;
  int res3 = SWIG_OLDOBJ ;
  int res4 = SWIG_OLDOBJ ;
  
  if ((nobjs < 4) || (nobjs > 4)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__Endpoint, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "Endpoint_utilLogWrite" "', argument " "1"" of type '" "pj::Endpoint *""'"); 
  }
  arg1 = reinterpret_cast< pj::Endpoint * >(argp1);
  ecode2 = SWIG_AsVal_int(swig_obj[1], &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "Endpoint_utilLogWrite" "', argument " "2"" of type '" "int""'");
  } 
  arg2 = static_cast< int >(val2);
  {
    std::string *ptr = (std::string *)0;
    res3 = SWIG_AsPtr_std_string(swig_obj[2], &ptr);
    if (!SWIG_IsOK(res3)) {
      SWIG_exception_fail(SWIG_ArgError(res3), "in method '" "Endpoint_utilLogWrite" "', argument " "3"" of type '" "pj::string const &""'"); 
    }
    if (!ptr) {
      SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "Endpoint_utilLogWrite" "', argument " "3"" of type '" "pj::string const &""'"); 
    }
    arg3 = ptr;
  }
  {
    std::string *ptr = (std::string *)0;
    res4 = SWIG_AsPtr_std_string(swig_obj[3], &ptr);
    if (!SWIG_IsOK(res4)) {
      SWIG_exception_fail(SWIG_ArgError(res4), "in method '" "Endpoint_utilLogWrite" "', argument " "4"" of type '" "pj::string const &""'"); 
    }
    if (!ptr) {
      SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "Endpoint_utilLogWrite" "', argument " "4"" of type '" "pj::string const &""'"); 
    }
    arg4 = ptr;
  }
  (arg1)->utilLogWrite(arg2,(pj::string const &)*arg3,(pj::string const &)*arg4);
  resultobj = SWIG_Py_Void();
  if (SWIG_IsNewObj(res3)) delete arg3;
  if (SWIG_IsNewObj(res4)) delete arg4;
  return resultobj;
fail:
  if (SWIG_IsNewObj(res3)) delete arg3;
  if (SWIG_IsNewObj(res4)) delete arg4;
  return NULL;
}


SWIGINTERN PyObject *_wrap_Endpoint_utilLogWrite__SWIG_1(PyObject *SWIGUNUSEDPARM(self), Py_ssize_t nobjs, PyObject **swig_obj) {
  PyObject *resultobj = 0;
  pj::Endpoint *arg1 = (pj::Endpoint *) 0 ;
  pj::LogEntry *arg2 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  void *argp2 = 0 ;
  int res2 = 0 ;
  
  if ((nobjs < 2) || (nobjs > 2)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__Endpoint, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "Endpoint_utilLogWrite" "', argument " "1"" of type '" "pj::Endpoint *""'"); 
  }
  arg1 = reinterpret_cast< pj::Endpoint * >(argp1);
  res2 = SWIG_ConvertPtr(swig_obj[1], &argp2, SWIGTYPE_p_pj__LogEntry,  0 );
  if (!SWIG_IsOK(res2)) {
    SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "Endpoint_utilLogWrite" "', argument " "2"" of type '" "pj::LogEntry &""'"); 
  }
  if (!argp2) {
    SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "Endpoint_utilLogWrite" "', argument " "2"" of type '" "pj::LogEntry &""'"); 
  }
  arg2 = reinterpret_cast< pj::LogEntry * >(argp2);
  (arg1)->utilLogWrite(*arg2);
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_Endpoint_utilLogWrite(PyObject *self, PyObject *args) {
  Py_ssize_t argc;
  PyObject *argv[5] = {
    0
  };
  
  if (!(argc = SWIG_Python_UnpackTuple(args, "Endpoint_utilLogWrite", 0, 4, argv))) SWIG_fail;
  --argc;
  if (argc == 2) {
    int _v;
    void *vptr = 0;
    int res = SWIG_ConvertPtr(argv[0], &vptr, SWIGTYPE_p_pj__Endpoint, 0);
    _v = SWIG_CheckState(res);
    if (_v) {
      void *vptr = 0;
      int res = SWIG_ConvertPtr(argv[1], &vptr, SWIGTYPE_p_pj__LogEntry, SWIG_POINTER_NO_NULL);
      _v = SWIG_CheckState(res);
      if (_v) {
        return _wrap_Endpoint_utilLogWrite__SWIG_1(self, argc, argv);
      }
    }
  }
  if (argc == 4) {
    int _v;
    void *vptr = 0;
    int res = SWIG_ConvertPtr(argv[0], &vptr, SWIGTYPE_p_pj__Endpoint, 0);
    _v = SWIG_CheckState(res);
    if (_v) {
      {
        int res = SWIG_AsVal_int(argv[1], NULL);
        _v = SWIG_CheckState(res);
      }
      if (_v) {
        int res = SWIG_AsPtr_std_string(argv[2], (std::string**)(0));
        _v = SWIG_CheckState(res);
        if (_v) {
          int res = SWIG_AsPtr_std_string(argv[3], (std::string**)(0));
          _v = SWIG_CheckState(res);
          if (_v) {
            return _wrap_Endpoint_utilLogWrite__SWIG_0(self, argc, argv);
          }
        }
      }
    }
  }
  
fail:
  SWIG_Python_RaiseOrModifyTypeError("Wrong number or type of arguments for overloaded function 'Endpoint_utilLogWrite'.\n"
    "  Possible C/C++ prototypes are:\n"
    "    pj::Endpoint::utilLogWrite(int,pj::string const &,pj::string const &)\n"
    "    pj::Endpoint::utilLogWrite(pj::LogEntry &)\n");
  return 0;
}


SWIGINTERN PyObject *_wrap_Endpoint_utilVerifySipUri(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::Endpoint *arg1 = (pj::Endpoint *) 0 ;
  pj::string *arg2 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  int res2 = SWIG_OLDOBJ ;
  PyObject *swig_obj[2] ;
  pj_status_t result;
  
  if (!SWIG_Python_UnpackTuple(args, "Endpoint_utilVerifySipUri", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__Endpoint, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "Endpoint_utilVerifySipUri" "', argument " "1"" of type '" "pj::Endpoint *""'"); 
  }
  arg1 = reinterpret_cast< pj::Endpoint * >(argp1);
  {
    std::string *ptr = (std::string *)0;
    res2 = SWIG_AsPtr_std_string(swig_obj[1], &ptr);
    if (!SWIG_IsOK(res2)) {
      SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "Endpoint_utilVerifySipUri" "', argument " "2"" of type '" "pj::string const &""'"); 
    }
    if (!ptr) {
      SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "Endpoint_utilVerifySipUri" "', argument " "2"" of type '" "pj::string const &""'"); 
    }
    arg2 = ptr;
  }
  result = (pj_status_t)(arg1)->utilVerifySipUri((pj::string const &)*arg2);
  resultobj = SWIG_From_int(static_cast< int >(result));
  if (SWIG_IsNewObj(res2)) delete arg2;
  return resultobj;
fail:
  if (SWIG_IsNewObj(res2)) delete arg2;
  return NULL;
}


SWIGINTERN PyObject *_wrap_Endpoint_utilVerifyUri(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::Endpoint *arg1 = (pj::Endpoint *) 0 ;
  pj::string *arg2 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  int res2 = SWIG_OLDOBJ ;
  PyObject *swig_obj[2] ;
  pj_status_t result;
  
  if (!SWIG_Python_UnpackTuple(args, "Endpoint_utilVerifyUri", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__Endpoint, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "Endpoint_utilVerifyUri" "', argument " "1"" of type '" "pj::Endpoint *""'"); 
  }
  arg1 = reinterpret_cast< pj::Endpoint * >(argp1);
  {
    std::string *ptr = (std::string *)0;
    res2 = SWIG_AsPtr_std_string(swig_obj[1], &ptr);
    if (!SWIG_IsOK(res2)) {
      SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "Endpoint_utilVerifyUri" "', argument " "2"" of type '" "pj::string const &""'"); 
    }
    if (!ptr) {
      SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "Endpoint_utilVerifyUri" "', argument " "2"" of type '" "pj::string const &""'"); 
    }
    arg2 = ptr;
  }
  result = (pj_status_t)(arg1)->utilVerifyUri((pj::string const &)*arg2);
  resultobj = SWIG_From_int(static_cast< int >(result));
  if (SWIG_IsNewObj(res2)) delete arg2;
  return resultobj;
fail:
  if (SWIG_IsNewObj(res2)) delete arg2;
  return NULL;
}


SWIGINTERN PyObject *_wrap_Endpoint_utilTimerSchedule(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::Endpoint *arg1 = (pj::Endpoint *) 0 ;
  unsigned int arg2 ;
  pj::Token arg3 = (pj::Token) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  unsigned int val2 ;
  int ecode2 = 0 ;
  int res3 ;
  PyObject *swig_obj[3] ;
  pj::Token result;
  
  if (!SWIG_Python_UnpackTuple(args, "Endpoint_utilTimerSchedule", 3, 3, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__Endpoint, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "Endpoint_utilTimerSchedule" "', argument " "1"" of type '" "pj::Endpoint *""'"); 
  }
  arg1 = reinterpret_cast< pj::Endpoint * >(argp1);
  ecode2 = SWIG_AsVal_unsigned_SS_int(swig_obj[1], &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "Endpoint_utilTimerSchedule" "', argument " "2"" of type '" "unsigned int""'");
  } 
  arg2 = static_cast< unsigned int >(val2);
  res3 = SWIG_ConvertPtr(swig_obj[2],SWIG_as_voidptrptr(&arg3), 0, 0);
  if (!SWIG_IsOK(res3)) {
    SWIG_exception_fail(SWIG_ArgError(res3), "in method '" "Endpoint_utilTimerSchedule" "', argument " "3"" of type '" "pj::Token""'"); 
  }
  try {
    result = (pj::Token)(arg1)->utilTimerSchedule(arg2,arg3);
  } catch(pj::Error &_e) {
    SWIG_Python_Raise(SWIG_NewPointerObj((new pj::Error(static_cast< const pj::Error& >(_e))),SWIGTYPE_p_pj__Error,SWIG_POINTER_OWN), "pj::Error", SWIGTYPE_p_pj__Error); SWIG_fail;
  }
  resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(result), SWIGTYPE_p_void, 0 |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_Endpoint_utilTimerCancel(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::Endpoint *arg1 = (pj::Endpoint *) 0 ;
  pj::Token arg2 = (pj::Token) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  int res2 ;
  PyObject *swig_obj[2] ;
  
  if (!SWIG_Python_UnpackTuple(args, "Endpoint_utilTimerCancel", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__Endpoint, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "Endpoint_utilTimerCancel" "', argument " "1"" of type '" "pj::Endpoint *""'"); 
  }
  arg1 = reinterpret_cast< pj::Endpoint * >(argp1);
  res2 = SWIG_ConvertPtr(swig_obj[1],SWIG_as_voidptrptr(&arg2), 0, 0);
  if (!SWIG_IsOK(res2)) {
    SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "Endpoint_utilTimerCancel" "', argument " "2"" of type '" "pj::Token""'"); 
  }
  (arg1)->utilTimerCancel(arg2);
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_Endpoint_utilAddPendingJob(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::Endpoint *arg1 = (pj::Endpoint *) 0 ;
  pj::PendingJob *arg2 = (pj::PendingJob *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  void *argp2 = 0 ;
  int res2 = 0 ;
  PyObject *swig_obj[2] ;
  
  if (!SWIG_Python_UnpackTuple(args, "Endpoint_utilAddPendingJob", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__Endpoint, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "Endpoint_utilAddPendingJob" "', argument " "1"" of type '" "pj::Endpoint *""'"); 
  }
  arg1 = reinterpret_cast< pj::Endpoint * >(argp1);
  res2 = SWIG_ConvertPtr(swig_obj[1], &argp2,SWIGTYPE_p_pj__PendingJob, 0 |  0 );
  if (!SWIG_IsOK(res2)) {
    SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "Endpoint_utilAddPendingJob" "', argument " "2"" of type '" "pj::PendingJob *""'"); 
  }
  arg2 = reinterpret_cast< pj::PendingJob * >(argp2);
  (arg1)->utilAddPendingJob(arg2);
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_Endpoint_utilSslGetAvailableCiphers(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::Endpoint *arg1 = (pj::Endpoint *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  pj::IntVector result;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__Endpoint, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "Endpoint_utilSslGetAvailableCiphers" "', argument " "1"" of type '" "pj::Endpoint *""'"); 
  }
  arg1 = reinterpret_cast< pj::Endpoint * >(argp1);
  try {
    result = (arg1)->utilSslGetAvailableCiphers();
  } catch(pj::Error &_e) {
    SWIG_Python_Raise(SWIG_NewPointerObj((new pj::Error(static_cast< const pj::Error& >(_e))),SWIGTYPE_p_pj__Error,SWIG_POINTER_OWN), "pj::Error", SWIGTYPE_p_pj__Error); SWIG_fail;
  }
  resultobj = swig::from(static_cast< std::vector< int,std::allocator< int > > >(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_Endpoint_natDetectType(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::Endpoint *arg1 = (pj::Endpoint *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__Endpoint, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "Endpoint_natDetectType" "', argument " "1"" of type '" "pj::Endpoint *""'"); 
  }
  arg1 = reinterpret_cast< pj::Endpoint * >(argp1);
  try {
    (arg1)->natDetectType();
  } catch(pj::Error &_e) {
    SWIG_Python_Raise(SWIG_NewPointerObj((new pj::Error(static_cast< const pj::Error& >(_e))),SWIGTYPE_p_pj__Error,SWIG_POINTER_OWN), "pj::Error", SWIGTYPE_p_pj__Error); SWIG_fail;
  }
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_Endpoint_natGetType(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::Endpoint *arg1 = (pj::Endpoint *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  pj_stun_nat_type result;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__Endpoint, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "Endpoint_natGetType" "', argument " "1"" of type '" "pj::Endpoint *""'"); 
  }
  arg1 = reinterpret_cast< pj::Endpoint * >(argp1);
  try {
    result = (pj_stun_nat_type)(arg1)->natGetType();
  } catch(pj::Error &_e) {
    SWIG_Python_Raise(SWIG_NewPointerObj((new pj::Error(static_cast< const pj::Error& >(_e))),SWIGTYPE_p_pj__Error,SWIG_POINTER_OWN), "pj::Error", SWIGTYPE_p_pj__Error); SWIG_fail;
  }
  resultobj = SWIG_From_int(static_cast< int >(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_Endpoint_natUpdateStunServers(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::Endpoint *arg1 = (pj::Endpoint *) 0 ;
  pj::StringVector *arg2 = 0 ;
  bool arg3 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  int res2 = SWIG_OLDOBJ ;
  bool val3 ;
  int ecode3 = 0 ;
  PyObject *swig_obj[3] ;
  
  if (!SWIG_Python_UnpackTuple(args, "Endpoint_natUpdateStunServers", 3, 3, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__Endpoint, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "Endpoint_natUpdateStunServers" "', argument " "1"" of type '" "pj::Endpoint *""'"); 
  }
  arg1 = reinterpret_cast< pj::Endpoint * >(argp1);
  {
    std::vector< std::string,std::allocator< std::string > > *ptr = (std::vector< std::string,std::allocator< std::string > > *)0;
    res2 = swig::asptr(swig_obj[1], &ptr);
    if (!SWIG_IsOK(res2)) {
      SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "Endpoint_natUpdateStunServers" "', argument " "2"" of type '" "pj::StringVector const &""'"); 
    }
    if (!ptr) {
      SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "Endpoint_natUpdateStunServers" "', argument " "2"" of type '" "pj::StringVector const &""'"); 
    }
    arg2 = ptr;
  }
  ecode3 = SWIG_AsVal_bool(swig_obj[2], &val3);
  if (!SWIG_IsOK(ecode3)) {
    SWIG_exception_fail(SWIG_ArgError(ecode3), "in method '" "Endpoint_natUpdateStunServers" "', argument " "3"" of type '" "bool""'");
  } 
  arg3 = static_cast< bool >(val3);
  try {
    (arg1)->natUpdateStunServers((pj::StringVector const &)*arg2,arg3);
  } catch(pj::Error &_e) {
    SWIG_Python_Raise(SWIG_NewPointerObj((new pj::Error(static_cast< const pj::Error& >(_e))),SWIGTYPE_p_pj__Error,SWIG_POINTER_OWN), "pj::Error", SWIGTYPE_p_pj__Error); SWIG_fail;
  }
  resultobj = SWIG_Py_Void();
  if (SWIG_IsNewObj(res2)) delete arg2;
  return resultobj;
fail:
  if (SWIG_IsNewObj(res2)) delete arg2;
  return NULL;
}


SWIGINTERN PyObject *_wrap_Endpoint_natCheckStunServers(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::Endpoint *arg1 = (pj::Endpoint *) 0 ;
  pj::StringVector *arg2 = 0 ;
  bool arg3 ;
  pj::Token arg4 = (pj::Token) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  int res2 = SWIG_OLDOBJ ;
  bool val3 ;
  int ecode3 = 0 ;
  int res4 ;
  PyObject *swig_obj[4] ;
  
  if (!SWIG_Python_UnpackTuple(args, "Endpoint_natCheckStunServers", 4, 4, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__Endpoint, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "Endpoint_natCheckStunServers" "', argument " "1"" of type '" "pj::Endpoint *""'"); 
  }
  arg1 = reinterpret_cast< pj::Endpoint * >(argp1);
  {
    std::vector< std::string,std::allocator< std::string > > *ptr = (std::vector< std::string,std::allocator< std::string > > *)0;
    res2 = swig::asptr(swig_obj[1], &ptr);
    if (!SWIG_IsOK(res2)) {
      SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "Endpoint_natCheckStunServers" "', argument " "2"" of type '" "pj::StringVector const &""'"); 
    }
    if (!ptr) {
      SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "Endpoint_natCheckStunServers" "', argument " "2"" of type '" "pj::StringVector const &""'"); 
    }
    arg2 = ptr;
  }
  ecode3 = SWIG_AsVal_bool(swig_obj[2], &val3);
  if (!SWIG_IsOK(ecode3)) {
    SWIG_exception_fail(SWIG_ArgError(ecode3), "in method '" "Endpoint_natCheckStunServers" "', argument " "3"" of type '" "bool""'");
  } 
  arg3 = static_cast< bool >(val3);
  res4 = SWIG_ConvertPtr(swig_obj[3],SWIG_as_voidptrptr(&arg4), 0, 0);
  if (!SWIG_IsOK(res4)) {
    SWIG_exception_fail(SWIG_ArgError(res4), "in method '" "Endpoint_natCheckStunServers" "', argument " "4"" of type '" "pj::Token""'"); 
  }
  try {
    (arg1)->natCheckStunServers((pj::StringVector const &)*arg2,arg3,arg4);
  } catch(pj::Error &_e) {
    SWIG_Python_Raise(SWIG_NewPointerObj((new pj::Error(static_cast< const pj::Error& >(_e))),SWIGTYPE_p_pj__Error,SWIG_POINTER_OWN), "pj::Error", SWIGTYPE_p_pj__Error); SWIG_fail;
  }
  resultobj = SWIG_Py_Void();
  if (SWIG_IsNewObj(res2)) delete arg2;
  return resultobj;
fail:
  if (SWIG_IsNewObj(res2)) delete arg2;
  return NULL;
}


SWIGINTERN PyObject *_wrap_Endpoint_natCancelCheckStunServers__SWIG_0(PyObject *SWIGUNUSEDPARM(self), Py_ssize_t nobjs, PyObject **swig_obj) {
  PyObject *resultobj = 0;
  pj::Endpoint *arg1 = (pj::Endpoint *) 0 ;
  pj::Token arg2 = (pj::Token) 0 ;
  bool arg3 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  int res2 ;
  bool val3 ;
  int ecode3 = 0 ;
  
  if ((nobjs < 3) || (nobjs > 3)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__Endpoint, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "Endpoint_natCancelCheckStunServers" "', argument " "1"" of type '" "pj::Endpoint *""'"); 
  }
  arg1 = reinterpret_cast< pj::Endpoint * >(argp1);
  res2 = SWIG_ConvertPtr(swig_obj[1],SWIG_as_voidptrptr(&arg2), 0, 0);
  if (!SWIG_IsOK(res2)) {
    SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "Endpoint_natCancelCheckStunServers" "', argument " "2"" of type '" "pj::Token""'"); 
  }
  ecode3 = SWIG_AsVal_bool(swig_obj[2], &val3);
  if (!SWIG_IsOK(ecode3)) {
    SWIG_exception_fail(SWIG_ArgError(ecode3), "in method '" "Endpoint_natCancelCheckStunServers" "', argument " "3"" of type '" "bool""'");
  } 
  arg3 = static_cast< bool >(val3);
  try {
    (arg1)->natCancelCheckStunServers(arg2,arg3);
  } catch(pj::Error &_e) {
    SWIG_Python_Raise(SWIG_NewPointerObj((new pj::Error(static_cast< const pj::Error& >(_e))),SWIGTYPE_p_pj__Error,SWIG_POINTER_OWN), "pj::Error", SWIGTYPE_p_pj__Error); SWIG_fail;
  }
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_Endpoint_natCancelCheckStunServers__SWIG_1(PyObject *SWIGUNUSEDPARM(self), Py_ssize_t nobjs, PyObject **swig_obj) {
  PyObject *resultobj = 0;
  pj::Endpoint *arg1 = (pj::Endpoint *) 0 ;
  pj::Token arg2 = (pj::Token) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  int res2 ;
  
  if ((nobjs < 2) || (nobjs > 2)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__Endpoint, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "Endpoint_natCancelCheckStunServers" "', argument " "1"" of type '" "pj::Endpoint *""'"); 
  }
  arg1 = reinterpret_cast< pj::Endpoint * >(argp1);
  res2 = SWIG_ConvertPtr(swig_obj[1],SWIG_as_voidptrptr(&arg2), 0, 0);
  if (!SWIG_IsOK(res2)) {
    SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "Endpoint_natCancelCheckStunServers" "', argument " "2"" of type '" "pj::Token""'"); 
  }
  try {
    (arg1)->natCancelCheckStunServers(arg2);
  } catch(pj::Error &_e) {
    SWIG_Python_Raise(SWIG_NewPointerObj((new pj::Error(static_cast< const pj::Error& >(_e))),SWIGTYPE_p_pj__Error,SWIG_POINTER_OWN), "pj::Error", SWIGTYPE_p_pj__Error); SWIG_fail;
  }
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_Endpoint_natCancelCheckStunServers(PyObject *self, PyObject *args) {
  Py_ssize_t argc;
  PyObject *argv[4] = {
    0
  };
  
  if (!(argc = SWIG_Python_UnpackTuple(args, "Endpoint_natCancelCheckStunServers", 0, 3, argv))) SWIG_fail;
  --argc;
  if (argc == 2) {
    int _v;
    void *vptr = 0;
    int res = SWIG_ConvertPtr(argv[0], &vptr, SWIGTYPE_p_pj__Endpoint, 0);
    _v = SWIG_CheckState(res);
    if (_v) {
      void *ptr = 0;
      int res = SWIG_ConvertPtr(argv[1], &ptr, 0, 0);
      _v = SWIG_CheckState(res);
      if (_v) {
        return _wrap_Endpoint_natCancelCheckStunServers__SWIG_1(self, argc, argv);
      }
    }
  }
  if (argc == 3) {
    int _v;
    void *vptr = 0;
    int res = SWIG_ConvertPtr(argv[0], &vptr, SWIGTYPE_p_pj__Endpoint, 0);
    _v = SWIG_CheckState(res);
    if (_v) {
      void *ptr = 0;
      int res = SWIG_ConvertPtr(argv[1], &ptr, 0, 0);
      _v = SWIG_CheckState(res);
      if (_v) {
        {
          int res = SWIG_AsVal_bool(argv[2], NULL);
          _v = SWIG_CheckState(res);
        }
        if (_v) {
          return _wrap_Endpoint_natCancelCheckStunServers__SWIG_0(self, argc, argv);
        }
      }
    }
  }
  
fail:
  SWIG_Python_RaiseOrModifyTypeError("Wrong number or type of arguments for overloaded function 'Endpoint_natCancelCheckStunServers'.\n"
    "  Possible C/C++ prototypes are:\n"
    "    pj::Endpoint::natCancelCheckStunServers(pj::Token,bool)\n"
    "    pj::Endpoint::natCancelCheckStunServers(pj::Token)\n");
  return 0;
}


SWIGINTERN PyObject *_wrap_Endpoint_transportCreate(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::Endpoint *arg1 = (pj::Endpoint *) 0 ;
  pjsip_transport_type_e arg2 ;
  pj::TransportConfig *arg3 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  int val2 ;
  int ecode2 = 0 ;
  void *argp3 = 0 ;
  int res3 = 0 ;
  PyObject *swig_obj[3] ;
  pj::TransportId result;
  
  if (!SWIG_Python_UnpackTuple(args, "Endpoint_transportCreate", 3, 3, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__Endpoint, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "Endpoint_transportCreate" "', argument " "1"" of type '" "pj::Endpoint *""'"); 
  }
  arg1 = reinterpret_cast< pj::Endpoint * >(argp1);
  ecode2 = SWIG_AsVal_int(swig_obj[1], &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "Endpoint_transportCreate" "', argument " "2"" of type '" "pjsip_transport_type_e""'");
  } 
  arg2 = static_cast< pjsip_transport_type_e >(val2);
  res3 = SWIG_ConvertPtr(swig_obj[2], &argp3, SWIGTYPE_p_pj__TransportConfig,  0  | 0);
  if (!SWIG_IsOK(res3)) {
    SWIG_exception_fail(SWIG_ArgError(res3), "in method '" "Endpoint_transportCreate" "', argument " "3"" of type '" "pj::TransportConfig const &""'"); 
  }
  if (!argp3) {
    SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "Endpoint_transportCreate" "', argument " "3"" of type '" "pj::TransportConfig const &""'"); 
  }
  arg3 = reinterpret_cast< pj::TransportConfig * >(argp3);
  try {
    result = (pj::TransportId)(arg1)->transportCreate(arg2,(pj::TransportConfig const &)*arg3);
  } catch(pj::Error &_e) {
    SWIG_Python_Raise(SWIG_NewPointerObj((new pj::Error(static_cast< const pj::Error& >(_e))),SWIGTYPE_p_pj__Error,SWIG_POINTER_OWN), "pj::Error", SWIGTYPE_p_pj__Error); SWIG_fail;
  }
  resultobj = SWIG_From_int(static_cast< int >(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_Endpoint_transportEnum(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::Endpoint *arg1 = (pj::Endpoint *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  pj::IntVector result;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__Endpoint, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "Endpoint_transportEnum" "', argument " "1"" of type '" "pj::Endpoint *""'"); 
  }
  arg1 = reinterpret_cast< pj::Endpoint * >(argp1);
  try {
    result = (arg1)->transportEnum();
  } catch(pj::Error &_e) {
    SWIG_Python_Raise(SWIG_NewPointerObj((new pj::Error(static_cast< const pj::Error& >(_e))),SWIGTYPE_p_pj__Error,SWIG_POINTER_OWN), "pj::Error", SWIGTYPE_p_pj__Error); SWIG_fail;
  }
  resultobj = swig::from(static_cast< std::vector< int,std::allocator< int > > >(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_Endpoint_transportGetInfo(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::Endpoint *arg1 = (pj::Endpoint *) 0 ;
  pj::TransportId arg2 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  int val2 ;
  int ecode2 = 0 ;
  PyObject *swig_obj[2] ;
  pj::TransportInfo result;
  
  if (!SWIG_Python_UnpackTuple(args, "Endpoint_transportGetInfo", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__Endpoint, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "Endpoint_transportGetInfo" "', argument " "1"" of type '" "pj::Endpoint *""'"); 
  }
  arg1 = reinterpret_cast< pj::Endpoint * >(argp1);
  ecode2 = SWIG_AsVal_int(swig_obj[1], &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "Endpoint_transportGetInfo" "', argument " "2"" of type '" "pj::TransportId""'");
  } 
  arg2 = static_cast< pj::TransportId >(val2);
  try {
    result = (arg1)->transportGetInfo(arg2);
  } catch(pj::Error &_e) {
    SWIG_Python_Raise(SWIG_NewPointerObj((new pj::Error(static_cast< const pj::Error& >(_e))),SWIGTYPE_p_pj__Error,SWIG_POINTER_OWN), "pj::Error", SWIGTYPE_p_pj__Error); SWIG_fail;
  }
  resultobj = SWIG_NewPointerObj((new pj::TransportInfo(static_cast< const pj::TransportInfo& >(result))), SWIGTYPE_p_pj__TransportInfo, SWIG_POINTER_OWN |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_Endpoint_transportSetEnable(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::Endpoint *arg1 = (pj::Endpoint *) 0 ;
  pj::TransportId arg2 ;
  bool arg3 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  int val2 ;
  int ecode2 = 0 ;
  bool val3 ;
  int ecode3 = 0 ;
  PyObject *swig_obj[3] ;
  
  if (!SWIG_Python_UnpackTuple(args, "Endpoint_transportSetEnable", 3, 3, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__Endpoint, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "Endpoint_transportSetEnable" "', argument " "1"" of type '" "pj::Endpoint *""'"); 
  }
  arg1 = reinterpret_cast< pj::Endpoint * >(argp1);
  ecode2 = SWIG_AsVal_int(swig_obj[1], &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "Endpoint_transportSetEnable" "', argument " "2"" of type '" "pj::TransportId""'");
  } 
  arg2 = static_cast< pj::TransportId >(val2);
  ecode3 = SWIG_AsVal_bool(swig_obj[2], &val3);
  if (!SWIG_IsOK(ecode3)) {
    SWIG_exception_fail(SWIG_ArgError(ecode3), "in method '" "Endpoint_transportSetEnable" "', argument " "3"" of type '" "bool""'");
  } 
  arg3 = static_cast< bool >(val3);
  try {
    (arg1)->transportSetEnable(arg2,arg3);
  } catch(pj::Error &_e) {
    SWIG_Python_Raise(SWIG_NewPointerObj((new pj::Error(static_cast< const pj::Error& >(_e))),SWIGTYPE_p_pj__Error,SWIG_POINTER_OWN), "pj::Error", SWIGTYPE_p_pj__Error); SWIG_fail;
  }
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_Endpoint_transportClose(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::Endpoint *arg1 = (pj::Endpoint *) 0 ;
  pj::TransportId arg2 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  int val2 ;
  int ecode2 = 0 ;
  PyObject *swig_obj[2] ;
  
  if (!SWIG_Python_UnpackTuple(args, "Endpoint_transportClose", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__Endpoint, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "Endpoint_transportClose" "', argument " "1"" of type '" "pj::Endpoint *""'"); 
  }
  arg1 = reinterpret_cast< pj::Endpoint * >(argp1);
  ecode2 = SWIG_AsVal_int(swig_obj[1], &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "Endpoint_transportClose" "', argument " "2"" of type '" "pj::TransportId""'");
  } 
  arg2 = static_cast< pj::TransportId >(val2);
  try {
    (arg1)->transportClose(arg2);
  } catch(pj::Error &_e) {
    SWIG_Python_Raise(SWIG_NewPointerObj((new pj::Error(static_cast< const pj::Error& >(_e))),SWIGTYPE_p_pj__Error,SWIG_POINTER_OWN), "pj::Error", SWIGTYPE_p_pj__Error); SWIG_fail;
  }
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_Endpoint_transportShutdown(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::Endpoint *arg1 = (pj::Endpoint *) 0 ;
  pj::TransportHandle arg2 = (pj::TransportHandle) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  int res2 ;
  PyObject *swig_obj[2] ;
  
  if (!SWIG_Python_UnpackTuple(args, "Endpoint_transportShutdown", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__Endpoint, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "Endpoint_transportShutdown" "', argument " "1"" of type '" "pj::Endpoint *""'"); 
  }
  arg1 = reinterpret_cast< pj::Endpoint * >(argp1);
  res2 = SWIG_ConvertPtr(swig_obj[1],SWIG_as_voidptrptr(&arg2), 0, 0);
  if (!SWIG_IsOK(res2)) {
    SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "Endpoint_transportShutdown" "', argument " "2"" of type '" "pj::TransportHandle""'"); 
  }
  try {
    (arg1)->transportShutdown(arg2);
  } catch(pj::Error &_e) {
    SWIG_Python_Raise(SWIG_NewPointerObj((new pj::Error(static_cast< const pj::Error& >(_e))),SWIGTYPE_p_pj__Error,SWIG_POINTER_OWN), "pj::Error", SWIGTYPE_p_pj__Error); SWIG_fail;
  }
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_Endpoint_hangupAllCalls(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::Endpoint *arg1 = (pj::Endpoint *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__Endpoint, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "Endpoint_hangupAllCalls" "', argument " "1"" of type '" "pj::Endpoint *""'"); 
  }
  arg1 = reinterpret_cast< pj::Endpoint * >(argp1);
  (arg1)->hangupAllCalls();
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_Endpoint_mediaAdd(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::Endpoint *arg1 = (pj::Endpoint *) 0 ;
  pj::AudioMedia *arg2 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  void *argp2 = 0 ;
  int res2 = 0 ;
  PyObject *swig_obj[2] ;
  
  if (!SWIG_Python_UnpackTuple(args, "Endpoint_mediaAdd", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__Endpoint, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "Endpoint_mediaAdd" "', argument " "1"" of type '" "pj::Endpoint *""'"); 
  }
  arg1 = reinterpret_cast< pj::Endpoint * >(argp1);
  res2 = SWIG_ConvertPtr(swig_obj[1], &argp2, SWIGTYPE_p_pj__AudioMedia,  0 );
  if (!SWIG_IsOK(res2)) {
    SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "Endpoint_mediaAdd" "', argument " "2"" of type '" "pj::AudioMedia &""'"); 
  }
  if (!argp2) {
    SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "Endpoint_mediaAdd" "', argument " "2"" of type '" "pj::AudioMedia &""'"); 
  }
  arg2 = reinterpret_cast< pj::AudioMedia * >(argp2);
  (arg1)->mediaAdd(*arg2);
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_Endpoint_mediaRemove(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::Endpoint *arg1 = (pj::Endpoint *) 0 ;
  pj::AudioMedia *arg2 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  void *argp2 = 0 ;
  int res2 = 0 ;
  PyObject *swig_obj[2] ;
  
  if (!SWIG_Python_UnpackTuple(args, "Endpoint_mediaRemove", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__Endpoint, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "Endpoint_mediaRemove" "', argument " "1"" of type '" "pj::Endpoint *""'"); 
  }
  arg1 = reinterpret_cast< pj::Endpoint * >(argp1);
  res2 = SWIG_ConvertPtr(swig_obj[1], &argp2, SWIGTYPE_p_pj__AudioMedia,  0 );
  if (!SWIG_IsOK(res2)) {
    SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "Endpoint_mediaRemove" "', argument " "2"" of type '" "pj::AudioMedia &""'"); 
  }
  if (!argp2) {
    SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "Endpoint_mediaRemove" "', argument " "2"" of type '" "pj::AudioMedia &""'"); 
  }
  arg2 = reinterpret_cast< pj::AudioMedia * >(argp2);
  (arg1)->mediaRemove(*arg2);
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_Endpoint_mediaExists(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::Endpoint *arg1 = (pj::Endpoint *) 0 ;
  pj::AudioMedia *arg2 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  void *argp2 = 0 ;
  int res2 = 0 ;
  PyObject *swig_obj[2] ;
  bool result;
  
  if (!SWIG_Python_UnpackTuple(args, "Endpoint_mediaExists", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__Endpoint, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "Endpoint_mediaExists" "', argument " "1"" of type '" "pj::Endpoint const *""'"); 
  }
  arg1 = reinterpret_cast< pj::Endpoint * >(argp1);
  res2 = SWIG_ConvertPtr(swig_obj[1], &argp2, SWIGTYPE_p_pj__AudioMedia,  0  | 0);
  if (!SWIG_IsOK(res2)) {
    SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "Endpoint_mediaExists" "', argument " "2"" of type '" "pj::AudioMedia const &""'"); 
  }
  if (!argp2) {
    SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "Endpoint_mediaExists" "', argument " "2"" of type '" "pj::AudioMedia const &""'"); 
  }
  arg2 = reinterpret_cast< pj::AudioMedia * >(argp2);
  result = (bool)((pj::Endpoint const *)arg1)->mediaExists((pj::AudioMedia const &)*arg2);
  resultobj = SWIG_From_bool(static_cast< bool >(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_Endpoint_mediaMaxPorts(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::Endpoint *arg1 = (pj::Endpoint *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  unsigned int result;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__Endpoint, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "Endpoint_mediaMaxPorts" "', argument " "1"" of type '" "pj::Endpoint const *""'"); 
  }
  arg1 = reinterpret_cast< pj::Endpoint * >(argp1);
  result = (unsigned int)((pj::Endpoint const *)arg1)->mediaMaxPorts();
  resultobj = SWIG_From_unsigned_SS_int(static_cast< unsigned int >(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_Endpoint_mediaActivePorts(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::Endpoint *arg1 = (pj::Endpoint *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  unsigned int result;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__Endpoint, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "Endpoint_mediaActivePorts" "', argument " "1"" of type '" "pj::Endpoint const *""'"); 
  }
  arg1 = reinterpret_cast< pj::Endpoint * >(argp1);
  result = (unsigned int)((pj::Endpoint const *)arg1)->mediaActivePorts();
  resultobj = SWIG_From_unsigned_SS_int(static_cast< unsigned int >(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_Endpoint_mediaEnumPorts2(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::Endpoint *arg1 = (pj::Endpoint *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  pj::AudioMediaVector2 result;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__Endpoint, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "Endpoint_mediaEnumPorts2" "', argument " "1"" of type '" "pj::Endpoint const *""'"); 
  }
  arg1 = reinterpret_cast< pj::Endpoint * >(argp1);
  try {
    result = ((pj::Endpoint const *)arg1)->mediaEnumPorts2();
  } catch(pj::Error &_e) {
    SWIG_Python_Raise(SWIG_NewPointerObj((new pj::Error(static_cast< const pj::Error& >(_e))),SWIGTYPE_p_pj__Error,SWIG_POINTER_OWN), "pj::Error", SWIGTYPE_p_pj__Error); SWIG_fail;
  }
  resultobj = swig::from(static_cast< std::vector< pj::AudioMedia,std::allocator< pj::AudioMedia > > >(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_Endpoint_mediaEnumVidPorts(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::Endpoint *arg1 = (pj::Endpoint *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  pj::VideoMediaVector result;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__Endpoint, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "Endpoint_mediaEnumVidPorts" "', argument " "1"" of type '" "pj::Endpoint const *""'"); 
  }
  arg1 = reinterpret_cast< pj::Endpoint * >(argp1);
  try {
    result = ((pj::Endpoint const *)arg1)->mediaEnumVidPorts();
  } catch(pj::Error &_e) {
    SWIG_Python_Raise(SWIG_NewPointerObj((new pj::Error(static_cast< const pj::Error& >(_e))),SWIGTYPE_p_pj__Error,SWIG_POINTER_OWN), "pj::Error", SWIGTYPE_p_pj__Error); SWIG_fail;
  }
  resultobj = swig::from(static_cast< std::vector< pj::VideoMedia,std::allocator< pj::VideoMedia > > >(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_Endpoint_audDevManager(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::Endpoint *arg1 = (pj::Endpoint *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  pj::AudDevManager *result = 0 ;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__Endpoint, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "Endpoint_audDevManager" "', argument " "1"" of type '" "pj::Endpoint *""'"); 
  }
  arg1 = reinterpret_cast< pj::Endpoint * >(argp1);
  result = (pj::AudDevManager *) &(arg1)->audDevManager();
  resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(result), SWIGTYPE_p_pj__AudDevManager, 0 |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_Endpoint_vidDevManager(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::Endpoint *arg1 = (pj::Endpoint *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  pj::VidDevManager *result = 0 ;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__Endpoint, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "Endpoint_vidDevManager" "', argument " "1"" of type '" "pj::Endpoint *""'"); 
  }
  arg1 = reinterpret_cast< pj::Endpoint * >(argp1);
  result = (pj::VidDevManager *) &(arg1)->vidDevManager();
  resultobj = SWIG_NewPointerObj(SWIG_as_voidptr(result), SWIGTYPE_p_pj__VidDevManager, 0 |  0 );
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_Endpoint_codecEnum2(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::Endpoint *arg1 = (pj::Endpoint *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  pj::CodecInfoVector2 result;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__Endpoint, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "Endpoint_codecEnum2" "', argument " "1"" of type '" "pj::Endpoint const *""'"); 
  }
  arg1 = reinterpret_cast< pj::Endpoint * >(argp1);
  try {
    result = ((pj::Endpoint const *)arg1)->codecEnum2();
  } catch(pj::Error &_e) {
    SWIG_Python_Raise(SWIG_NewPointerObj((new pj::Error(static_cast< const pj::Error& >(_e))),SWIGTYPE_p_pj__Error,SWIG_POINTER_OWN), "pj::Error", SWIGTYPE_p_pj__Error); SWIG_fail;
  }
  resultobj = swig::from(static_cast< std::vector< pj::CodecInfo,std::allocator< pj::CodecInfo > > >(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_Endpoint_codecSetPriority(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::Endpoint *arg1 = (pj::Endpoint *) 0 ;
  pj::string *arg2 = 0 ;
  pj_uint8_t arg3 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  int res2 = SWIG_OLDOBJ ;
  unsigned char val3 ;
  int ecode3 = 0 ;
  PyObject *swig_obj[3] ;
  
  if (!SWIG_Python_UnpackTuple(args, "Endpoint_codecSetPriority", 3, 3, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__Endpoint, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "Endpoint_codecSetPriority" "', argument " "1"" of type '" "pj::Endpoint *""'"); 
  }
  arg1 = reinterpret_cast< pj::Endpoint * >(argp1);
  {
    std::string *ptr = (std::string *)0;
    res2 = SWIG_AsPtr_std_string(swig_obj[1], &ptr);
    if (!SWIG_IsOK(res2)) {
      SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "Endpoint_codecSetPriority" "', argument " "2"" of type '" "pj::string const &""'"); 
    }
    if (!ptr) {
      SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "Endpoint_codecSetPriority" "', argument " "2"" of type '" "pj::string const &""'"); 
    }
    arg2 = ptr;
  }
  ecode3 = SWIG_AsVal_unsigned_SS_char(swig_obj[2], &val3);
  if (!SWIG_IsOK(ecode3)) {
    SWIG_exception_fail(SWIG_ArgError(ecode3), "in method '" "Endpoint_codecSetPriority" "', argument " "3"" of type '" "pj_uint8_t""'");
  } 
  arg3 = static_cast< pj_uint8_t >(val3);
  try {
    (arg1)->codecSetPriority((pj::string const &)*arg2,arg3);
  } catch(pj::Error &_e) {
    SWIG_Python_Raise(SWIG_NewPointerObj((new pj::Error(static_cast< const pj::Error& >(_e))),SWIGTYPE_p_pj__Error,SWIG_POINTER_OWN), "pj::Error", SWIGTYPE_p_pj__Error); SWIG_fail;
  }
  resultobj = SWIG_Py_Void();
  if (SWIG_IsNewObj(res2)) delete arg2;
  return resultobj;
fail:
  if (SWIG_IsNewObj(res2)) delete arg2;
  return NULL;
}


SWIGINTERN PyObject *_wrap_Endpoint_codecGetParam(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::Endpoint *arg1 = (pj::Endpoint *) 0 ;
  pj::string *arg2 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  int res2 = SWIG_OLDOBJ ;
  PyObject *swig_obj[2] ;
  pj::CodecParam result;
  
  if (!SWIG_Python_UnpackTuple(args, "Endpoint_codecGetParam", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__Endpoint, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "Endpoint_codecGetParam" "', argument " "1"" of type '" "pj::Endpoint const *""'"); 
  }
  arg1 = reinterpret_cast< pj::Endpoint * >(argp1);
  {
    std::string *ptr = (std::string *)0;
    res2 = SWIG_AsPtr_std_string(swig_obj[1], &ptr);
    if (!SWIG_IsOK(res2)) {
      SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "Endpoint_codecGetParam" "', argument " "2"" of type '" "pj::string const &""'"); 
    }
    if (!ptr) {
      SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "Endpoint_codecGetParam" "', argument " "2"" of type '" "pj::string const &""'"); 
    }
    arg2 = ptr;
  }
  try {
    result = ((pj::Endpoint const *)arg1)->codecGetParam((pj::string const &)*arg2);
  } catch(pj::Error &_e) {
    SWIG_Python_Raise(SWIG_NewPointerObj((new pj::Error(static_cast< const pj::Error& >(_e))),SWIGTYPE_p_pj__Error,SWIG_POINTER_OWN), "pj::Error", SWIGTYPE_p_pj__Error); SWIG_fail;
  }
  resultobj = SWIG_NewPointerObj((new pj::CodecParam(static_cast< const pj::CodecParam& >(result))), SWIGTYPE_p_pj__CodecParam, SWIG_POINTER_OWN |  0 );
  if (SWIG_IsNewObj(res2)) delete arg2;
  return resultobj;
fail:
  if (SWIG_IsNewObj(res2)) delete arg2;
  return NULL;
}


SWIGINTERN PyObject *_wrap_Endpoint_codecSetParam(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::Endpoint *arg1 = (pj::Endpoint *) 0 ;
  pj::string *arg2 = 0 ;
  pj::CodecParam arg3 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  int res2 = SWIG_OLDOBJ ;
  void *argp3 ;
  int res3 = 0 ;
  PyObject *swig_obj[3] ;
  
  if (!SWIG_Python_UnpackTuple(args, "Endpoint_codecSetParam", 3, 3, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__Endpoint, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "Endpoint_codecSetParam" "', argument " "1"" of type '" "pj::Endpoint *""'"); 
  }
  arg1 = reinterpret_cast< pj::Endpoint * >(argp1);
  {
    std::string *ptr = (std::string *)0;
    res2 = SWIG_AsPtr_std_string(swig_obj[1], &ptr);
    if (!SWIG_IsOK(res2)) {
      SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "Endpoint_codecSetParam" "', argument " "2"" of type '" "pj::string const &""'"); 
    }
    if (!ptr) {
      SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "Endpoint_codecSetParam" "', argument " "2"" of type '" "pj::string const &""'"); 
    }
    arg2 = ptr;
  }
  {
    res3 = SWIG_ConvertPtr(swig_obj[2], &argp3, SWIGTYPE_p_pj__CodecParam,  0  | 0);
    if (!SWIG_IsOK(res3)) {
      SWIG_exception_fail(SWIG_ArgError(res3), "in method '" "Endpoint_codecSetParam" "', argument " "3"" of type '" "pj::CodecParam const""'"); 
    }  
    if (!argp3) {
      SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "Endpoint_codecSetParam" "', argument " "3"" of type '" "pj::CodecParam const""'");
    } else {
      pj::CodecParam * temp = reinterpret_cast< pj::CodecParam * >(argp3);
      arg3 = *temp;
      if (SWIG_IsNewObj(res3)) delete temp;
    }
  }
  try {
    (arg1)->codecSetParam((pj::string const &)*arg2,arg3);
  } catch(pj::Error &_e) {
    SWIG_Python_Raise(SWIG_NewPointerObj((new pj::Error(static_cast< const pj::Error& >(_e))),SWIGTYPE_p_pj__Error,SWIG_POINTER_OWN), "pj::Error", SWIGTYPE_p_pj__Error); SWIG_fail;
  }
  resultobj = SWIG_Py_Void();
  if (SWIG_IsNewObj(res2)) delete arg2;
  return resultobj;
fail:
  if (SWIG_IsNewObj(res2)) delete arg2;
  return NULL;
}


SWIGINTERN PyObject *_wrap_Endpoint_videoCodecEnum2(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::Endpoint *arg1 = (pj::Endpoint *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  pj::CodecInfoVector2 result;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__Endpoint, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "Endpoint_videoCodecEnum2" "', argument " "1"" of type '" "pj::Endpoint const *""'"); 
  }
  arg1 = reinterpret_cast< pj::Endpoint * >(argp1);
  try {
    result = ((pj::Endpoint const *)arg1)->videoCodecEnum2();
  } catch(pj::Error &_e) {
    SWIG_Python_Raise(SWIG_NewPointerObj((new pj::Error(static_cast< const pj::Error& >(_e))),SWIGTYPE_p_pj__Error,SWIG_POINTER_OWN), "pj::Error", SWIGTYPE_p_pj__Error); SWIG_fail;
  }
  resultobj = swig::from(static_cast< std::vector< pj::CodecInfo,std::allocator< pj::CodecInfo > > >(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_Endpoint_videoCodecSetPriority(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::Endpoint *arg1 = (pj::Endpoint *) 0 ;
  pj::string *arg2 = 0 ;
  pj_uint8_t arg3 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  int res2 = SWIG_OLDOBJ ;
  unsigned char val3 ;
  int ecode3 = 0 ;
  PyObject *swig_obj[3] ;
  
  if (!SWIG_Python_UnpackTuple(args, "Endpoint_videoCodecSetPriority", 3, 3, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__Endpoint, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "Endpoint_videoCodecSetPriority" "', argument " "1"" of type '" "pj::Endpoint *""'"); 
  }
  arg1 = reinterpret_cast< pj::Endpoint * >(argp1);
  {
    std::string *ptr = (std::string *)0;
    res2 = SWIG_AsPtr_std_string(swig_obj[1], &ptr);
    if (!SWIG_IsOK(res2)) {
      SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "Endpoint_videoCodecSetPriority" "', argument " "2"" of type '" "pj::string const &""'"); 
    }
    if (!ptr) {
      SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "Endpoint_videoCodecSetPriority" "', argument " "2"" of type '" "pj::string const &""'"); 
    }
    arg2 = ptr;
  }
  ecode3 = SWIG_AsVal_unsigned_SS_char(swig_obj[2], &val3);
  if (!SWIG_IsOK(ecode3)) {
    SWIG_exception_fail(SWIG_ArgError(ecode3), "in method '" "Endpoint_videoCodecSetPriority" "', argument " "3"" of type '" "pj_uint8_t""'");
  } 
  arg3 = static_cast< pj_uint8_t >(val3);
  try {
    (arg1)->videoCodecSetPriority((pj::string const &)*arg2,arg3);
  } catch(pj::Error &_e) {
    SWIG_Python_Raise(SWIG_NewPointerObj((new pj::Error(static_cast< const pj::Error& >(_e))),SWIGTYPE_p_pj__Error,SWIG_POINTER_OWN), "pj::Error", SWIGTYPE_p_pj__Error); SWIG_fail;
  }
  resultobj = SWIG_Py_Void();
  if (SWIG_IsNewObj(res2)) delete arg2;
  return resultobj;
fail:
  if (SWIG_IsNewObj(res2)) delete arg2;
  return NULL;
}


SWIGINTERN PyObject *_wrap_Endpoint_getVideoCodecParam(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::Endpoint *arg1 = (pj::Endpoint *) 0 ;
  pj::string *arg2 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  int res2 = SWIG_OLDOBJ ;
  PyObject *swig_obj[2] ;
  pj::VidCodecParam result;
  
  if (!SWIG_Python_UnpackTuple(args, "Endpoint_getVideoCodecParam", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__Endpoint, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "Endpoint_getVideoCodecParam" "', argument " "1"" of type '" "pj::Endpoint const *""'"); 
  }
  arg1 = reinterpret_cast< pj::Endpoint * >(argp1);
  {
    std::string *ptr = (std::string *)0;
    res2 = SWIG_AsPtr_std_string(swig_obj[1], &ptr);
    if (!SWIG_IsOK(res2)) {
      SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "Endpoint_getVideoCodecParam" "', argument " "2"" of type '" "pj::string const &""'"); 
    }
    if (!ptr) {
      SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "Endpoint_getVideoCodecParam" "', argument " "2"" of type '" "pj::string const &""'"); 
    }
    arg2 = ptr;
  }
  try {
    result = ((pj::Endpoint const *)arg1)->getVideoCodecParam((pj::string const &)*arg2);
  } catch(pj::Error &_e) {
    SWIG_Python_Raise(SWIG_NewPointerObj((new pj::Error(static_cast< const pj::Error& >(_e))),SWIGTYPE_p_pj__Error,SWIG_POINTER_OWN), "pj::Error", SWIGTYPE_p_pj__Error); SWIG_fail;
  }
  resultobj = SWIG_NewPointerObj((new pj::VidCodecParam(static_cast< const pj::VidCodecParam& >(result))), SWIGTYPE_p_pj__VidCodecParam, SWIG_POINTER_OWN |  0 );
  if (SWIG_IsNewObj(res2)) delete arg2;
  return resultobj;
fail:
  if (SWIG_IsNewObj(res2)) delete arg2;
  return NULL;
}


SWIGINTERN PyObject *_wrap_Endpoint_setVideoCodecParam(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::Endpoint *arg1 = (pj::Endpoint *) 0 ;
  pj::string *arg2 = 0 ;
  pj::VidCodecParam *arg3 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  int res2 = SWIG_OLDOBJ ;
  void *argp3 = 0 ;
  int res3 = 0 ;
  PyObject *swig_obj[3] ;
  
  if (!SWIG_Python_UnpackTuple(args, "Endpoint_setVideoCodecParam", 3, 3, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__Endpoint, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "Endpoint_setVideoCodecParam" "', argument " "1"" of type '" "pj::Endpoint *""'"); 
  }
  arg1 = reinterpret_cast< pj::Endpoint * >(argp1);
  {
    std::string *ptr = (std::string *)0;
    res2 = SWIG_AsPtr_std_string(swig_obj[1], &ptr);
    if (!SWIG_IsOK(res2)) {
      SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "Endpoint_setVideoCodecParam" "', argument " "2"" of type '" "pj::string const &""'"); 
    }
    if (!ptr) {
      SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "Endpoint_setVideoCodecParam" "', argument " "2"" of type '" "pj::string const &""'"); 
    }
    arg2 = ptr;
  }
  res3 = SWIG_ConvertPtr(swig_obj[2], &argp3, SWIGTYPE_p_pj__VidCodecParam,  0  | 0);
  if (!SWIG_IsOK(res3)) {
    SWIG_exception_fail(SWIG_ArgError(res3), "in method '" "Endpoint_setVideoCodecParam" "', argument " "3"" of type '" "pj::VidCodecParam const &""'"); 
  }
  if (!argp3) {
    SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "Endpoint_setVideoCodecParam" "', argument " "3"" of type '" "pj::VidCodecParam const &""'"); 
  }
  arg3 = reinterpret_cast< pj::VidCodecParam * >(argp3);
  try {
    (arg1)->setVideoCodecParam((pj::string const &)*arg2,(pj::VidCodecParam const &)*arg3);
  } catch(pj::Error &_e) {
    SWIG_Python_Raise(SWIG_NewPointerObj((new pj::Error(static_cast< const pj::Error& >(_e))),SWIGTYPE_p_pj__Error,SWIG_POINTER_OWN), "pj::Error", SWIGTYPE_p_pj__Error); SWIG_fail;
  }
  resultobj = SWIG_Py_Void();
  if (SWIG_IsNewObj(res2)) delete arg2;
  return resultobj;
fail:
  if (SWIG_IsNewObj(res2)) delete arg2;
  return NULL;
}


SWIGINTERN PyObject *_wrap_Endpoint_resetVideoCodecParam(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::Endpoint *arg1 = (pj::Endpoint *) 0 ;
  pj::string *arg2 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  int res2 = SWIG_OLDOBJ ;
  PyObject *swig_obj[2] ;
  
  if (!SWIG_Python_UnpackTuple(args, "Endpoint_resetVideoCodecParam", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__Endpoint, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "Endpoint_resetVideoCodecParam" "', argument " "1"" of type '" "pj::Endpoint *""'"); 
  }
  arg1 = reinterpret_cast< pj::Endpoint * >(argp1);
  {
    std::string *ptr = (std::string *)0;
    res2 = SWIG_AsPtr_std_string(swig_obj[1], &ptr);
    if (!SWIG_IsOK(res2)) {
      SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "Endpoint_resetVideoCodecParam" "', argument " "2"" of type '" "pj::string const &""'"); 
    }
    if (!ptr) {
      SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "Endpoint_resetVideoCodecParam" "', argument " "2"" of type '" "pj::string const &""'"); 
    }
    arg2 = ptr;
  }
  try {
    (arg1)->resetVideoCodecParam((pj::string const &)*arg2);
  } catch(pj::Error &_e) {
    SWIG_Python_Raise(SWIG_NewPointerObj((new pj::Error(static_cast< const pj::Error& >(_e))),SWIGTYPE_p_pj__Error,SWIG_POINTER_OWN), "pj::Error", SWIGTYPE_p_pj__Error); SWIG_fail;
  }
  resultobj = SWIG_Py_Void();
  if (SWIG_IsNewObj(res2)) delete arg2;
  return resultobj;
fail:
  if (SWIG_IsNewObj(res2)) delete arg2;
  return NULL;
}


SWIGINTERN PyObject *_wrap_Endpoint_srtpCryptoEnum(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::Endpoint *arg1 = (pj::Endpoint *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  pj::StringVector result;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__Endpoint, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "Endpoint_srtpCryptoEnum" "', argument " "1"" of type '" "pj::Endpoint *""'"); 
  }
  arg1 = reinterpret_cast< pj::Endpoint * >(argp1);
  try {
    result = (arg1)->srtpCryptoEnum();
  } catch(pj::Error &_e) {
    SWIG_Python_Raise(SWIG_NewPointerObj((new pj::Error(static_cast< const pj::Error& >(_e))),SWIGTYPE_p_pj__Error,SWIG_POINTER_OWN), "pj::Error", SWIGTYPE_p_pj__Error); SWIG_fail;
  }
  resultobj = swig::from(static_cast< std::vector< std::string,std::allocator< std::string > > >(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_Endpoint_handleIpChange(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::Endpoint *arg1 = (pj::Endpoint *) 0 ;
  pj::IpChangeParam *arg2 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  void *argp2 = 0 ;
  int res2 = 0 ;
  PyObject *swig_obj[2] ;
  
  if (!SWIG_Python_UnpackTuple(args, "Endpoint_handleIpChange", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__Endpoint, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "Endpoint_handleIpChange" "', argument " "1"" of type '" "pj::Endpoint *""'"); 
  }
  arg1 = reinterpret_cast< pj::Endpoint * >(argp1);
  res2 = SWIG_ConvertPtr(swig_obj[1], &argp2, SWIGTYPE_p_pj__IpChangeParam,  0  | 0);
  if (!SWIG_IsOK(res2)) {
    SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "Endpoint_handleIpChange" "', argument " "2"" of type '" "pj::IpChangeParam const &""'"); 
  }
  if (!argp2) {
    SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "Endpoint_handleIpChange" "', argument " "2"" of type '" "pj::IpChangeParam const &""'"); 
  }
  arg2 = reinterpret_cast< pj::IpChangeParam * >(argp2);
  try {
    (arg1)->handleIpChange((pj::IpChangeParam const &)*arg2);
  } catch(pj::Error &_e) {
    SWIG_Python_Raise(SWIG_NewPointerObj((new pj::Error(static_cast< const pj::Error& >(_e))),SWIGTYPE_p_pj__Error,SWIG_POINTER_OWN), "pj::Error", SWIGTYPE_p_pj__Error); SWIG_fail;
  }
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_Endpoint_onNatDetectionComplete(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::Endpoint *arg1 = (pj::Endpoint *) 0 ;
  pj::OnNatDetectionCompleteParam *arg2 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  void *argp2 = 0 ;
  int res2 = 0 ;
  PyObject *swig_obj[2] ;
  Swig::Director *director = 0;
  bool upcall = false;
  
  if (!SWIG_Python_UnpackTuple(args, "Endpoint_onNatDetectionComplete", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__Endpoint, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "Endpoint_onNatDetectionComplete" "', argument " "1"" of type '" "pj::Endpoint *""'"); 
  }
  arg1 = reinterpret_cast< pj::Endpoint * >(argp1);
  res2 = SWIG_ConvertPtr(swig_obj[1], &argp2, SWIGTYPE_p_pj__OnNatDetectionCompleteParam,  0  | 0);
  if (!SWIG_IsOK(res2)) {
    SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "Endpoint_onNatDetectionComplete" "', argument " "2"" of type '" "pj::OnNatDetectionCompleteParam const &""'"); 
  }
  if (!argp2) {
    SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "Endpoint_onNatDetectionComplete" "', argument " "2"" of type '" "pj::OnNatDetectionCompleteParam const &""'"); 
  }
  arg2 = reinterpret_cast< pj::OnNatDetectionCompleteParam * >(argp2);
  director = SWIG_DIRECTOR_CAST(arg1);
  upcall = (director && (director->swig_get_self()==swig_obj[0]));
  try {
    if (upcall) {
      (arg1)->pj::Endpoint::onNatDetectionComplete((pj::OnNatDetectionCompleteParam const &)*arg2);
    } else {
      (arg1)->onNatDetectionComplete((pj::OnNatDetectionCompleteParam const &)*arg2);
    }
  } catch (Swig::DirectorException&) {
    SWIG_fail;
  }
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_Endpoint_onNatCheckStunServersComplete(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::Endpoint *arg1 = (pj::Endpoint *) 0 ;
  pj::OnNatCheckStunServersCompleteParam *arg2 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  void *argp2 = 0 ;
  int res2 = 0 ;
  PyObject *swig_obj[2] ;
  Swig::Director *director = 0;
  bool upcall = false;
  
  if (!SWIG_Python_UnpackTuple(args, "Endpoint_onNatCheckStunServersComplete", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__Endpoint, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "Endpoint_onNatCheckStunServersComplete" "', argument " "1"" of type '" "pj::Endpoint *""'"); 
  }
  arg1 = reinterpret_cast< pj::Endpoint * >(argp1);
  res2 = SWIG_ConvertPtr(swig_obj[1], &argp2, SWIGTYPE_p_pj__OnNatCheckStunServersCompleteParam,  0  | 0);
  if (!SWIG_IsOK(res2)) {
    SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "Endpoint_onNatCheckStunServersComplete" "', argument " "2"" of type '" "pj::OnNatCheckStunServersCompleteParam const &""'"); 
  }
  if (!argp2) {
    SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "Endpoint_onNatCheckStunServersComplete" "', argument " "2"" of type '" "pj::OnNatCheckStunServersCompleteParam const &""'"); 
  }
  arg2 = reinterpret_cast< pj::OnNatCheckStunServersCompleteParam * >(argp2);
  director = SWIG_DIRECTOR_CAST(arg1);
  upcall = (director && (director->swig_get_self()==swig_obj[0]));
  try {
    if (upcall) {
      (arg1)->pj::Endpoint::onNatCheckStunServersComplete((pj::OnNatCheckStunServersCompleteParam const &)*arg2);
    } else {
      (arg1)->onNatCheckStunServersComplete((pj::OnNatCheckStunServersCompleteParam const &)*arg2);
    }
  } catch (Swig::DirectorException&) {
    SWIG_fail;
  }
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_Endpoint_onTransportState(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::Endpoint *arg1 = (pj::Endpoint *) 0 ;
  pj::OnTransportStateParam *arg2 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  void *argp2 = 0 ;
  int res2 = 0 ;
  PyObject *swig_obj[2] ;
  Swig::Director *director = 0;
  bool upcall = false;
  
  if (!SWIG_Python_UnpackTuple(args, "Endpoint_onTransportState", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__Endpoint, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "Endpoint_onTransportState" "', argument " "1"" of type '" "pj::Endpoint *""'"); 
  }
  arg1 = reinterpret_cast< pj::Endpoint * >(argp1);
  res2 = SWIG_ConvertPtr(swig_obj[1], &argp2, SWIGTYPE_p_pj__OnTransportStateParam,  0  | 0);
  if (!SWIG_IsOK(res2)) {
    SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "Endpoint_onTransportState" "', argument " "2"" of type '" "pj::OnTransportStateParam const &""'"); 
  }
  if (!argp2) {
    SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "Endpoint_onTransportState" "', argument " "2"" of type '" "pj::OnTransportStateParam const &""'"); 
  }
  arg2 = reinterpret_cast< pj::OnTransportStateParam * >(argp2);
  director = SWIG_DIRECTOR_CAST(arg1);
  upcall = (director && (director->swig_get_self()==swig_obj[0]));
  try {
    if (upcall) {
      (arg1)->pj::Endpoint::onTransportState((pj::OnTransportStateParam const &)*arg2);
    } else {
      (arg1)->onTransportState((pj::OnTransportStateParam const &)*arg2);
    }
  } catch (Swig::DirectorException&) {
    SWIG_fail;
  }
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_Endpoint_onTimer(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::Endpoint *arg1 = (pj::Endpoint *) 0 ;
  pj::OnTimerParam *arg2 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  void *argp2 = 0 ;
  int res2 = 0 ;
  PyObject *swig_obj[2] ;
  Swig::Director *director = 0;
  bool upcall = false;
  
  if (!SWIG_Python_UnpackTuple(args, "Endpoint_onTimer", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__Endpoint, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "Endpoint_onTimer" "', argument " "1"" of type '" "pj::Endpoint *""'"); 
  }
  arg1 = reinterpret_cast< pj::Endpoint * >(argp1);
  res2 = SWIG_ConvertPtr(swig_obj[1], &argp2, SWIGTYPE_p_pj__OnTimerParam,  0  | 0);
  if (!SWIG_IsOK(res2)) {
    SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "Endpoint_onTimer" "', argument " "2"" of type '" "pj::OnTimerParam const &""'"); 
  }
  if (!argp2) {
    SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "Endpoint_onTimer" "', argument " "2"" of type '" "pj::OnTimerParam const &""'"); 
  }
  arg2 = reinterpret_cast< pj::OnTimerParam * >(argp2);
  director = SWIG_DIRECTOR_CAST(arg1);
  upcall = (director && (director->swig_get_self()==swig_obj[0]));
  try {
    if (upcall) {
      (arg1)->pj::Endpoint::onTimer((pj::OnTimerParam const &)*arg2);
    } else {
      (arg1)->onTimer((pj::OnTimerParam const &)*arg2);
    }
  } catch (Swig::DirectorException&) {
    SWIG_fail;
  }
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_Endpoint_onSelectAccount(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::Endpoint *arg1 = (pj::Endpoint *) 0 ;
  pj::OnSelectAccountParam *arg2 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  void *argp2 = 0 ;
  int res2 = 0 ;
  PyObject *swig_obj[2] ;
  Swig::Director *director = 0;
  bool upcall = false;
  
  if (!SWIG_Python_UnpackTuple(args, "Endpoint_onSelectAccount", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__Endpoint, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "Endpoint_onSelectAccount" "', argument " "1"" of type '" "pj::Endpoint *""'"); 
  }
  arg1 = reinterpret_cast< pj::Endpoint * >(argp1);
  res2 = SWIG_ConvertPtr(swig_obj[1], &argp2, SWIGTYPE_p_pj__OnSelectAccountParam,  0 );
  if (!SWIG_IsOK(res2)) {
    SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "Endpoint_onSelectAccount" "', argument " "2"" of type '" "pj::OnSelectAccountParam &""'"); 
  }
  if (!argp2) {
    SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "Endpoint_onSelectAccount" "', argument " "2"" of type '" "pj::OnSelectAccountParam &""'"); 
  }
  arg2 = reinterpret_cast< pj::OnSelectAccountParam * >(argp2);
  director = SWIG_DIRECTOR_CAST(arg1);
  upcall = (director && (director->swig_get_self()==swig_obj[0]));
  try {
    if (upcall) {
      (arg1)->pj::Endpoint::onSelectAccount(*arg2);
    } else {
      (arg1)->onSelectAccount(*arg2);
    }
  } catch (Swig::DirectorException&) {
    SWIG_fail;
  }
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_Endpoint_onIpChangeProgress(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::Endpoint *arg1 = (pj::Endpoint *) 0 ;
  pj::OnIpChangeProgressParam *arg2 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  void *argp2 = 0 ;
  int res2 = 0 ;
  PyObject *swig_obj[2] ;
  Swig::Director *director = 0;
  bool upcall = false;
  
  if (!SWIG_Python_UnpackTuple(args, "Endpoint_onIpChangeProgress", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__Endpoint, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "Endpoint_onIpChangeProgress" "', argument " "1"" of type '" "pj::Endpoint *""'"); 
  }
  arg1 = reinterpret_cast< pj::Endpoint * >(argp1);
  res2 = SWIG_ConvertPtr(swig_obj[1], &argp2, SWIGTYPE_p_pj__OnIpChangeProgressParam,  0 );
  if (!SWIG_IsOK(res2)) {
    SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "Endpoint_onIpChangeProgress" "', argument " "2"" of type '" "pj::OnIpChangeProgressParam &""'"); 
  }
  if (!argp2) {
    SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "Endpoint_onIpChangeProgress" "', argument " "2"" of type '" "pj::OnIpChangeProgressParam &""'"); 
  }
  arg2 = reinterpret_cast< pj::OnIpChangeProgressParam * >(argp2);
  director = SWIG_DIRECTOR_CAST(arg1);
  upcall = (director && (director->swig_get_self()==swig_obj[0]));
  try {
    if (upcall) {
      (arg1)->pj::Endpoint::onIpChangeProgress(*arg2);
    } else {
      (arg1)->onIpChangeProgress(*arg2);
    }
  } catch (Swig::DirectorException&) {
    SWIG_fail;
  }
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_Endpoint_onMediaEvent(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::Endpoint *arg1 = (pj::Endpoint *) 0 ;
  pj::OnMediaEventParam *arg2 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  void *argp2 = 0 ;
  int res2 = 0 ;
  PyObject *swig_obj[2] ;
  Swig::Director *director = 0;
  bool upcall = false;
  
  if (!SWIG_Python_UnpackTuple(args, "Endpoint_onMediaEvent", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__Endpoint, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "Endpoint_onMediaEvent" "', argument " "1"" of type '" "pj::Endpoint *""'"); 
  }
  arg1 = reinterpret_cast< pj::Endpoint * >(argp1);
  res2 = SWIG_ConvertPtr(swig_obj[1], &argp2, SWIGTYPE_p_pj__OnMediaEventParam,  0 );
  if (!SWIG_IsOK(res2)) {
    SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "Endpoint_onMediaEvent" "', argument " "2"" of type '" "pj::OnMediaEventParam &""'"); 
  }
  if (!argp2) {
    SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "Endpoint_onMediaEvent" "', argument " "2"" of type '" "pj::OnMediaEventParam &""'"); 
  }
  arg2 = reinterpret_cast< pj::OnMediaEventParam * >(argp2);
  director = SWIG_DIRECTOR_CAST(arg1);
  upcall = (director && (director->swig_get_self()==swig_obj[0]));
  try {
    if (upcall) {
      (arg1)->pj::Endpoint::onMediaEvent(*arg2);
    } else {
      (arg1)->onMediaEvent(*arg2);
    }
  } catch (Swig::DirectorException&) {
    SWIG_fail;
  }
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_Endpoint_onCredAuth(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::Endpoint *arg1 = (pj::Endpoint *) 0 ;
  pj::OnCredAuthParam *arg2 = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  void *argp2 = 0 ;
  int res2 = 0 ;
  PyObject *swig_obj[2] ;
  Swig::Director *director = 0;
  bool upcall = false;
  pj_status_t result;
  
  if (!SWIG_Python_UnpackTuple(args, "Endpoint_onCredAuth", 2, 2, swig_obj)) SWIG_fail;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__Endpoint, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "Endpoint_onCredAuth" "', argument " "1"" of type '" "pj::Endpoint *""'"); 
  }
  arg1 = reinterpret_cast< pj::Endpoint * >(argp1);
  res2 = SWIG_ConvertPtr(swig_obj[1], &argp2, SWIGTYPE_p_pj__OnCredAuthParam,  0 );
  if (!SWIG_IsOK(res2)) {
    SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "Endpoint_onCredAuth" "', argument " "2"" of type '" "pj::OnCredAuthParam &""'"); 
  }
  if (!argp2) {
    SWIG_exception_fail(SWIG_ValueError, "invalid null reference " "in method '" "Endpoint_onCredAuth" "', argument " "2"" of type '" "pj::OnCredAuthParam &""'"); 
  }
  arg2 = reinterpret_cast< pj::OnCredAuthParam * >(argp2);
  director = SWIG_DIRECTOR_CAST(arg1);
  upcall = (director && (director->swig_get_self()==swig_obj[0]));
  try {
    if (upcall) {
      result = (pj_status_t)(arg1)->pj::Endpoint::onCredAuth(*arg2);
    } else {
      result = (pj_status_t)(arg1)->onCredAuth(*arg2);
    }
  } catch (Swig::DirectorException&) {
    SWIG_fail;
  }
  resultobj = SWIG_From_int(static_cast< int >(result));
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *_wrap_disown_Endpoint(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *resultobj = 0;
  pj::Endpoint *arg1 = (pj::Endpoint *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  PyObject *swig_obj[1] ;
  
  if (!args) SWIG_fail;
  swig_obj[0] = args;
  res1 = SWIG_ConvertPtr(swig_obj[0], &argp1,SWIGTYPE_p_pj__Endpoint, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "disown_Endpoint" "', argument " "1"" of type '" "pj::Endpoint *""'"); 
  }
  arg1 = reinterpret_cast< pj::Endpoint * >(argp1);
  {
    Swig::Director *director = SWIG_DIRECTOR_CAST(arg1);
    if (director) director->swig_disown();
  }
  
  resultobj = SWIG_Py_Void();
  return resultobj;
fail:
  return NULL;
}


SWIGINTERN PyObject *Endpoint_swigregister(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  PyObject *obj;
  if (!SWIG_Python_UnpackTuple(args, "swigregister", 1, 1, &obj)) return NULL;
  SWIG_TypeNewClientData(SWIGTYPE_p_pj__Endpoint, SWIG_NewClientData(obj));
  return SWIG_Py_Void();
}

SWIGINTERN PyObject *Endpoint_swiginit(PyObject *SWIGUNUSEDPARM(self), PyObject *args) {
  return SWIG_Python_InitShadowInstance(args);
}

static PyMethodDef SwigMethods[] = {
	 { "SWIG_PyInstanceMethod_New", SWIG_PyInstanceMethod_New, METH_O, NULL},
	 { "pj_qos_params_flags_set", _wrap_pj_qos_params_flags_set, METH_VARARGS, NULL},
	 { "pj_qos_params_flags_get", _wrap_pj_qos_params_flags_get, METH_O, NULL},
	 { "pj_qos_params_dscp_val_set", _wrap_pj_qos_params_dscp_val_set, METH_VARARGS, NULL},
	 { "pj_qos_params_dscp_val_get", _wrap_pj_qos_params_dscp_val_get, METH_O, NULL},
	 { "pj_qos_params_so_prio_set", _wrap_pj_qos_params_so_prio_set, METH_VARARGS, NULL},
	 { "pj_qos_params_so_prio_get", _wrap_pj_qos_params_so_prio_get, METH_O, NULL},
	 { "pj_qos_params_wmm_prio_set", _wrap_pj_qos_params_wmm_prio_set, METH_VARARGS, NULL},
	 { "pj_qos_params_wmm_prio_get", _wrap_pj_qos_params_wmm_prio_get, METH_O, NULL},
	 { "new_pj_qos_params", _wrap_new_pj_qos_params, METH_NOARGS, NULL},
	 { "delete_pj_qos_params", _wrap_delete_pj_qos_params, METH_O, NULL},
	 { "pj_qos_params_swigregister", pj_qos_params_swigregister, METH_O, NULL},
	 { "pj_qos_params_swiginit", pj_qos_params_swiginit, METH_VARARGS, NULL},
	 { "pjmedia_tone_digit_digit_set", _wrap_pjmedia_tone_digit_digit_set, METH_VARARGS, NULL},
	 { "pjmedia_tone_digit_digit_get", _wrap_pjmedia_tone_digit_digit_get, METH_O, NULL},
	 { "pjmedia_tone_digit_on_msec_set", _wrap_pjmedia_tone_digit_on_msec_set, METH_VARARGS, NULL},
	 { "pjmedia_tone_digit_on_msec_get", _wrap_pjmedia_tone_digit_on_msec_get, METH_O, NULL},
	 { "pjmedia_tone_digit_off_msec_set", _wrap_pjmedia_tone_digit_off_msec_set, METH_VARARGS, NULL},
	 { "pjmedia_tone_digit_off_msec_get", _wrap_pjmedia_tone_digit_off_msec_get, METH_O, NULL},
	 { "pjmedia_tone_digit_volume_set", _wrap_pjmedia_tone_digit_volume_set, METH_VARARGS, NULL},
	 { "pjmedia_tone_digit_volume_get", _wrap_pjmedia_tone_digit_volume_get, METH_O, NULL},
	 { "new_pjmedia_tone_digit", _wrap_new_pjmedia_tone_digit, METH_NOARGS, NULL},
	 { "delete_pjmedia_tone_digit", _wrap_delete_pjmedia_tone_digit, METH_O, NULL},
	 { "pjmedia_tone_digit_swigregister", pjmedia_tone_digit_swigregister, METH_O, NULL},
	 { "pjmedia_tone_digit_swiginit", pjmedia_tone_digit_swiginit, METH_VARARGS, NULL},
	 { "pjmedia_tone_digit_map_count_set", _wrap_pjmedia_tone_digit_map_count_set, METH_VARARGS, NULL},
	 { "pjmedia_tone_digit_map_count_get", _wrap_pjmedia_tone_digit_map_count_get, METH_O, NULL},
	 { "new_pjmedia_tone_digit_map", _wrap_new_pjmedia_tone_digit_map, METH_NOARGS, NULL},
	 { "delete_pjmedia_tone_digit_map", _wrap_delete_pjmedia_tone_digit_map, METH_O, NULL},
	 { "pjmedia_tone_digit_map_swigregister", pjmedia_tone_digit_map_swigregister, METH_O, NULL},
	 { "pjmedia_tone_digit_map_swiginit", pjmedia_tone_digit_map_swiginit, METH_VARARGS, NULL},
	 { "pjmedia_tone_desc_freq1_set", _wrap_pjmedia_tone_desc_freq1_set, METH_VARARGS, NULL},
	 { "pjmedia_tone_desc_freq1_get", _wrap_pjmedia_tone_desc_freq1_get, METH_O, NULL},
	 { "pjmedia_tone_desc_freq2_set", _wrap_pjmedia_tone_desc_freq2_set, METH_VARARGS, NULL},
	 { "pjmedia_tone_desc_freq2_get", _wrap_pjmedia_tone_desc_freq2_get, METH_O, NULL},
	 { "pjmedia_tone_desc_on_msec_set", _wrap_pjmedia_tone_desc_on_msec_set, METH_VARARGS, NULL},
	 { "pjmedia_tone_desc_on_msec_get", _wrap_pjmedia_tone_desc_on_msec_get, METH_O, NULL},
	 { "pjmedia_tone_desc_off_msec_set", _wrap_pjmedia_tone_desc_off_msec_set, METH_VARARGS, NULL},
	 { "pjmedia_tone_desc_off_msec_get", _wrap_pjmedia_tone_desc_off_msec_get, METH_O, NULL},
	 { "pjmedia_tone_desc_volume_set", _wrap_pjmedia_tone_desc_volume_set, METH_VARARGS, NULL},
	 { "pjmedia_tone_desc_volume_get", _wrap_pjmedia_tone_desc_volume_get, METH_O, NULL},
	 { "pjmedia_tone_desc_flags_set", _wrap_pjmedia_tone_desc_flags_set, METH_VARARGS, NULL},
	 { "pjmedia_tone_desc_flags_get", _wrap_pjmedia_tone_desc_flags_get, METH_O, NULL},
	 { "new_pjmedia_tone_desc", _wrap_new_pjmedia_tone_desc, METH_NOARGS, NULL},
	 { "delete_pjmedia_tone_desc", _wrap_delete_pjmedia_tone_desc, METH_O, NULL},
	 { "pjmedia_tone_desc_swigregister", pjmedia_tone_desc_swigregister, METH_O, NULL},
	 { "pjmedia_tone_desc_swiginit", pjmedia_tone_desc_swiginit, METH_VARARGS, NULL},
	 { "delete_SwigPyIterator", _wrap_delete_SwigPyIterator, METH_O, NULL},
	 { "SwigPyIterator_value", _wrap_SwigPyIterator_value, METH_O, NULL},
	 { "SwigPyIterator_incr", _wrap_SwigPyIterator_incr, METH_VARARGS, NULL},
	 { "SwigPyIterator_decr", _wrap_SwigPyIterator_decr, METH_VARARGS, NULL},
	 { "SwigPyIterator_distance", _wrap_SwigPyIterator_distance, METH_VARARGS, NULL},
	 { "SwigPyIterator_equal", _wrap_SwigPyIterator_equal, METH_VARARGS, NULL},
	 { "SwigPyIterator_copy", _wrap_SwigPyIterator_copy, METH_O, NULL},
	 { "SwigPyIterator_next", _wrap_SwigPyIterator_next, METH_O, NULL},
	 { "SwigPyIterator___next__", _wrap_SwigPyIterator___next__, METH_O, NULL},
	 { "SwigPyIterator_previous", _wrap_SwigPyIterator_previous, METH_O, NULL},
	 { "SwigPyIterator_advance", _wrap_SwigPyIterator_advance, METH_VARARGS, NULL},
	 { "SwigPyIterator___eq__", _wrap_SwigPyIterator___eq__, METH_VARARGS, NULL},
	 { "SwigPyIterator___ne__", _wrap_SwigPyIterator___ne__, METH_VARARGS, NULL},
	 { "SwigPyIterator___iadd__", _wrap_SwigPyIterator___iadd__, METH_VARARGS, NULL},
	 { "SwigPyIterator___isub__", _wrap_SwigPyIterator___isub__, METH_VARARGS, NULL},
	 { "SwigPyIterator___add__", _wrap_SwigPyIterator___add__, METH_VARARGS, NULL},
	 { "SwigPyIterator___sub__", _wrap_SwigPyIterator___sub__, METH_VARARGS, NULL},
	 { "SwigPyIterator_swigregister", SwigPyIterator_swigregister, METH_O, NULL},
	 { "StringVector_iterator", _wrap_StringVector_iterator, METH_O, NULL},
	 { "StringVector___nonzero__", _wrap_StringVector___nonzero__, METH_O, NULL},
	 { "StringVector___bool__", _wrap_StringVector___bool__, METH_O, NULL},
	 { "StringVector___len__", _wrap_StringVector___len__, METH_O, NULL},
	 { "StringVector___getslice__", _wrap_StringVector___getslice__, METH_VARARGS, NULL},
	 { "StringVector___setslice__", _wrap_StringVector___setslice__, METH_VARARGS, NULL},
	 { "StringVector___delslice__", _wrap_StringVector___delslice__, METH_VARARGS, NULL},
	 { "StringVector___delitem__", _wrap_StringVector___delitem__, METH_VARARGS, NULL},
	 { "StringVector___getitem__", _wrap_StringVector___getitem__, METH_VARARGS, NULL},
	 { "StringVector___setitem__", _wrap_StringVector___setitem__, METH_VARARGS, NULL},
	 { "StringVector_pop", _wrap_StringVector_pop, METH_O, NULL},
	 { "StringVector_append", _wrap_StringVector_append, METH_VARARGS, NULL},
	 { "StringVector_empty", _wrap_StringVector_empty, METH_O, NULL},
	 { "StringVector_size", _wrap_StringVector_size, METH_O, NULL},
	 { "StringVector_swap", _wrap_StringVector_swap, METH_VARARGS, NULL},
	 { "StringVector_begin", _wrap_StringVector_begin, METH_O, NULL},
	 { "StringVector_end", _wrap_StringVector_end, METH_O, NULL},
	 { "StringVector_rbegin", _wrap_StringVector_rbegin, METH_O, NULL},
	 { "StringVector_rend", _wrap_StringVector_rend, METH_O, NULL},
	 { "StringVector_clear", _wrap_StringVector_clear, METH_O, NULL},
	 { "StringVector_get_allocator", _wrap_StringVector_get_allocator, METH_O, NULL},
	 { "StringVector_pop_back", _wrap_StringVector_pop_back, METH_O, NULL},
	 { "StringVector_erase", _wrap_StringVector_erase, METH_VARARGS, NULL},
	 { "new_StringVector", _wrap_new_StringVector, METH_VARARGS, NULL},
	 { "StringVector_push_back", _wrap_StringVector_push_back, METH_VARARGS, NULL},
	 { "StringVector_front", _wrap_StringVector_front, METH_O, NULL},
	 { "StringVector_back", _wrap_StringVector_back, METH_O, NULL},
	 { "StringVector_assign", _wrap_StringVector_assign, METH_VARARGS, NULL},
	 { "StringVector_resize", _wrap_StringVector_resize, METH_VARARGS, NULL},
	 { "StringVector_insert", _wrap_StringVector_insert, METH_VARARGS, NULL},
	 { "StringVector_reserve", _wrap_StringVector_reserve, METH_VARARGS, NULL},
	 { "StringVector_capacity", _wrap_StringVector_capacity, METH_O, NULL},
	 { "delete_StringVector", _wrap_delete_StringVector, METH_O, NULL},
	 { "StringVector_swigregister", StringVector_swigregister, METH_O, NULL},
	 { "StringVector_swiginit", StringVector_swiginit, METH_VARARGS, NULL},
	 { "IntVector_iterator", _wrap_IntVector_iterator, METH_O, NULL},
	 { "IntVector___nonzero__", _wrap_IntVector___nonzero__, METH_O, NULL},
	 { "IntVector___bool__", _wrap_IntVector___bool__, METH_O, NULL},
	 { "IntVector___len__", _wrap_IntVector___len__, METH_O, NULL},
	 { "IntVector___getslice__", _wrap_IntVector___getslice__, METH_VARARGS, NULL},
	 { "IntVector___setslice__", _wrap_IntVector___setslice__, METH_VARARGS, NULL},
	 { "IntVector___delslice__", _wrap_IntVector___delslice__, METH_VARARGS, NULL},
	 { "IntVector___delitem__", _wrap_IntVector___delitem__, METH_VARARGS, NULL},
	 { "IntVector___getitem__", _wrap_IntVector___getitem__, METH_VARARGS, NULL},
	 { "IntVector___setitem__", _wrap_IntVector___setitem__, METH_VARARGS, NULL},
	 { "IntVector_pop", _wrap_IntVector_pop, METH_O, NULL},
	 { "IntVector_append", _wrap_IntVector_append, METH_VARARGS, NULL},
	 { "IntVector_empty", _wrap_IntVector_empty, METH_O, NULL},
	 { "IntVector_size", _wrap_IntVector_size, METH_O, NULL},
	 { "IntVector_swap", _wrap_IntVector_swap, METH_VARARGS, NULL},
	 { "IntVector_begin", _wrap_IntVector_begin, METH_O, NULL},
	 { "IntVector_end", _wrap_IntVector_end, METH_O, NULL},
	 { "IntVector_rbegin", _wrap_IntVector_rbegin, METH_O, NULL},
	 { "IntVector_rend", _wrap_IntVector_rend, METH_O, NULL},
	 { "IntVector_clear", _wrap_IntVector_clear, METH_O, NULL},
	 { "IntVector_get_allocator", _wrap_IntVector_get_allocator, METH_O, NULL},
	 { "IntVector_pop_back", _wrap_IntVector_pop_back, METH_O, NULL},
	 { "IntVector_erase", _wrap_IntVector_erase, METH_VARARGS, NULL},
	 { "new_IntVector", _wrap_new_IntVector, METH_VARARGS, NULL},
	 { "IntVector_push_back", _wrap_IntVector_push_back, METH_VARARGS, NULL},
	 { "IntVector_front", _wrap_IntVector_front, METH_O, NULL},
	 { "IntVector_back", _wrap_IntVector_back, METH_O, NULL},
	 { "IntVector_assign", _wrap_IntVector_assign, METH_VARARGS, NULL},
	 { "IntVector_resize", _wrap_IntVector_resize, METH_VARARGS, NULL},
	 { "IntVector_insert", _wrap_IntVector_insert, METH_VARARGS, NULL},
	 { "IntVector_reserve", _wrap_IntVector_reserve, METH_VARARGS, NULL},
	 { "IntVector_capacity", _wrap_IntVector_capacity, METH_O, NULL},
	 { "delete_IntVector", _wrap_delete_IntVector, METH_O, NULL},
	 { "IntVector_swigregister", IntVector_swigregister, METH_O, NULL},
	 { "IntVector_swiginit", IntVector_swiginit, METH_VARARGS, NULL},
	 { "StringToStringMap_iterator", _wrap_StringToStringMap_iterator, METH_O, NULL},
	 { "StringToStringMap___nonzero__", _wrap_StringToStringMap___nonzero__, METH_O, NULL},
	 { "StringToStringMap___bool__", _wrap_StringToStringMap___bool__, METH_O, NULL},
	 { "StringToStringMap___len__", _wrap_StringToStringMap___len__, METH_O, NULL},
	 { "StringToStringMap___getitem__", _wrap_StringToStringMap___getitem__, METH_VARARGS, NULL},
	 { "StringToStringMap___delitem__", _wrap_StringToStringMap___delitem__, METH_VARARGS, NULL},
	 { "StringToStringMap_has_key", _wrap_StringToStringMap_has_key, METH_VARARGS, NULL},
	 { "StringToStringMap_keys", _wrap_StringToStringMap_keys, METH_O, NULL},
	 { "StringToStringMap_values", _wrap_StringToStringMap_values, METH_O, NULL},
	 { "StringToStringMap_items", _wrap_StringToStringMap_items, METH_O, NULL},
	 { "StringToStringMap___contains__", _wrap_StringToStringMap___contains__, METH_VARARGS, NULL},
	 { "StringToStringMap_key_iterator", _wrap_StringToStringMap_key_iterator, METH_O, NULL},
	 { "StringToStringMap_value_iterator", _wrap_StringToStringMap_value_iterator, METH_O, NULL},
	 { "StringToStringMap___setitem__", _wrap_StringToStringMap___setitem__, METH_VARARGS, NULL},
	 { "StringToStringMap_asdict", _wrap_StringToStringMap_asdict, METH_O, NULL},
	 { "new_StringToStringMap", _wrap_new_StringToStringMap, METH_VARARGS, NULL},
	 { "StringToStringMap_empty", _wrap_StringToStringMap_empty, METH_O, NULL},
	 { "StringToStringMap_size", _wrap_StringToStringMap_size, METH_O, NULL},
	 { "StringToStringMap_swap", _wrap_StringToStringMap_swap, METH_VARARGS, NULL},
	 { "StringToStringMap_begin", _wrap_StringToStringMap_begin, METH_O, NULL},
	 { "StringToStringMap_end", _wrap_StringToStringMap_end, METH_O, NULL},
	 { "StringToStringMap_rbegin", _wrap_StringToStringMap_rbegin, METH_O, NULL},
	 { "StringToStringMap_rend", _wrap_StringToStringMap_rend, METH_O, NULL},
	 { "StringToStringMap_clear", _wrap_StringToStringMap_clear, METH_O, NULL},
	 { "StringToStringMap_get_allocator", _wrap_StringToStringMap_get_allocator, METH_O, NULL},
	 { "StringToStringMap_count", _wrap_StringToStringMap_count, METH_VARARGS, NULL},
	 { "StringToStringMap_erase", _wrap_StringToStringMap_erase, METH_VARARGS, NULL},
	 { "StringToStringMap_find", _wrap_StringToStringMap_find, METH_VARARGS, NULL},
	 { "StringToStringMap_lower_bound", _wrap_StringToStringMap_lower_bound, METH_VARARGS, NULL},
	 { "StringToStringMap_upper_bound", _wrap_StringToStringMap_upper_bound, METH_VARARGS, NULL},
	 { "delete_StringToStringMap", _wrap_delete_StringToStringMap, METH_O, NULL},
	 { "StringToStringMap_swigregister", StringToStringMap_swigregister, METH_O, NULL},
	 { "StringToStringMap_swiginit", StringToStringMap_swiginit, METH_VARARGS, NULL},
	 { "Error_status_set", _wrap_Error_status_set, METH_VARARGS, NULL},
	 { "Error_status_get", _wrap_Error_status_get, METH_O, NULL},
	 { "Error_title_set", _wrap_Error_title_set, METH_VARARGS, NULL},
	 { "Error_title_get", _wrap_Error_title_get, METH_O, NULL},
	 { "Error_reason_set", _wrap_Error_reason_set, METH_VARARGS, NULL},
	 { "Error_reason_get", _wrap_Error_reason_get, METH_O, NULL},
	 { "Error_srcFile_set", _wrap_Error_srcFile_set, METH_VARARGS, NULL},
	 { "Error_srcFile_get", _wrap_Error_srcFile_get, METH_O, NULL},
	 { "Error_srcLine_set", _wrap_Error_srcLine_set, METH_VARARGS, NULL},
	 { "Error_srcLine_get", _wrap_Error_srcLine_get, METH_O, NULL},
	 { "Error_info", _wrap_Error_info, METH_VARARGS, NULL},
	 { "new_Error", _wrap_new_Error, METH_VARARGS, NULL},
	 { "delete_Error", _wrap_delete_Error, METH_O, NULL},
	 { "Error_swigregister", Error_swigregister, METH_O, NULL},
	 { "Error_swiginit", Error_swiginit, METH_VARARGS, NULL},
	 { "Version_major_set", _wrap_Version_major_set, METH_VARARGS, NULL},
	 { "Version_major_get", _wrap_Version_major_get, METH_O, NULL},
	 { "Version_minor_set", _wrap_Version_minor_set, METH_VARARGS, NULL},
	 { "Version_minor_get", _wrap_Version_minor_get, METH_O, NULL},
	 { "Version_rev_set", _wrap_Version_rev_set, METH_VARARGS, NULL},
	 { "Version_rev_get", _wrap_Version_rev_get, METH_O, NULL},
	 { "Version_suffix_set", _wrap_Version_suffix_set, METH_VARARGS, NULL},
	 { "Version_suffix_get", _wrap_Version_suffix_get, METH_O, NULL},
	 { "Version_full_set", _wrap_Version_full_set, METH_VARARGS, NULL},
	 { "Version_full_get", _wrap_Version_full_get, METH_O, NULL},
	 { "Version_numeric_set", _wrap_Version_numeric_set, METH_VARARGS, NULL},
	 { "Version_numeric_get", _wrap_Version_numeric_get, METH_O, NULL},
	 { "new_Version", _wrap_new_Version, METH_NOARGS, NULL},
	 { "delete_Version", _wrap_delete_Version, METH_O, NULL},
	 { "Version_swigregister", Version_swigregister, METH_O, NULL},
	 { "Version_swiginit", Version_swiginit, METH_VARARGS, NULL},
	 { "TimeVal_sec_set", _wrap_TimeVal_sec_set, METH_VARARGS, NULL},
	 { "TimeVal_sec_get", _wrap_TimeVal_sec_get, METH_O, NULL},
	 { "TimeVal_msec_set", _wrap_TimeVal_msec_set, METH_VARARGS, NULL},
	 { "TimeVal_msec_get", _wrap_TimeVal_msec_get, METH_O, NULL},
	 { "new_TimeVal", _wrap_new_TimeVal, METH_NOARGS, NULL},
	 { "delete_TimeVal", _wrap_delete_TimeVal, METH_O, NULL},
	 { "TimeVal_swigregister", TimeVal_swigregister, METH_O, NULL},
	 { "TimeVal_swiginit", TimeVal_swiginit, METH_VARARGS, NULL},
	 { "delete_PersistentObject", _wrap_delete_PersistentObject, METH_O, NULL},
	 { "PersistentObject_readObject", _wrap_PersistentObject_readObject, METH_VARARGS, NULL},
	 { "PersistentObject_writeObject", _wrap_PersistentObject_writeObject, METH_VARARGS, NULL},
	 { "PersistentObject_swigregister", PersistentObject_swigregister, METH_O, NULL},
	 { "delete_PersistentDocument", _wrap_delete_PersistentDocument, METH_O, NULL},
	 { "PersistentDocument_loadFile", _wrap_PersistentDocument_loadFile, METH_VARARGS, NULL},
	 { "PersistentDocument_loadString", _wrap_PersistentDocument_loadString, METH_VARARGS, NULL},
	 { "PersistentDocument_saveFile", _wrap_PersistentDocument_saveFile, METH_VARARGS, NULL},
	 { "PersistentDocument_saveString", _wrap_PersistentDocument_saveString, METH_O, NULL},
	 { "PersistentDocument_getRootContainer", _wrap_PersistentDocument_getRootContainer, METH_O, NULL},
	 { "PersistentDocument_hasUnread", _wrap_PersistentDocument_hasUnread, METH_O, NULL},
	 { "PersistentDocument_unreadName", _wrap_PersistentDocument_unreadName, METH_O, NULL},
	 { "PersistentDocument_readInt", _wrap_PersistentDocument_readInt, METH_VARARGS, NULL},
	 { "PersistentDocument_readNumber", _wrap_PersistentDocument_readNumber, METH_VARARGS, NULL},
	 { "PersistentDocument_readBool", _wrap_PersistentDocument_readBool, METH_VARARGS, NULL},
	 { "PersistentDocument_readString", _wrap_PersistentDocument_readString, METH_VARARGS, NULL},
	 { "PersistentDocument_readStringVector", _wrap_PersistentDocument_readStringVector, METH_VARARGS, NULL},
	 { "PersistentDocument_readObject", _wrap_PersistentDocument_readObject, METH_VARARGS, NULL},
	 { "PersistentDocument_readContainer", _wrap_PersistentDocument_readContainer, METH_VARARGS, NULL},
	 { "PersistentDocument_readArray", _wrap_PersistentDocument_readArray, METH_VARARGS, NULL},
	 { "PersistentDocument_writeNumber", _wrap_PersistentDocument_writeNumber, METH_VARARGS, NULL},
	 { "PersistentDocument_writeInt", _wrap_PersistentDocument_writeInt, METH_VARARGS, NULL},
	 { "PersistentDocument_writeBool", _wrap_PersistentDocument_writeBool, METH_VARARGS, NULL},
	 { "PersistentDocument_writeString", _wrap_PersistentDocument_writeString, METH_VARARGS, NULL},
	 { "PersistentDocument_writeStringVector", _wrap_PersistentDocument_writeStringVector, METH_VARARGS, NULL},
	 { "PersistentDocument_writeObject", _wrap_PersistentDocument_writeObject, METH_VARARGS, NULL},
	 { "PersistentDocument_writeNewContainer", _wrap_PersistentDocument_writeNewContainer, METH_VARARGS, NULL},
	 { "PersistentDocument_writeNewArray", _wrap_PersistentDocument_writeNewArray, METH_VARARGS, NULL},
	 { "PersistentDocument_swigregister", PersistentDocument_swigregister, METH_O, NULL},
	 { "ContainerNode_hasUnread", _wrap_ContainerNode_hasUnread, METH_O, NULL},
	 { "ContainerNode_unreadName", _wrap_ContainerNode_unreadName, METH_O, NULL},
	 { "ContainerNode_readInt", _wrap_ContainerNode_readInt, METH_VARARGS, NULL},
	 { "ContainerNode_readNumber", _wrap_ContainerNode_readNumber, METH_VARARGS, NULL},
	 { "ContainerNode_readBool", _wrap_ContainerNode_readBool, METH_VARARGS, NULL},
	 { "ContainerNode_readString", _wrap_ContainerNode_readString, METH_VARARGS, NULL},
	 { "ContainerNode_readStringVector", _wrap_ContainerNode_readStringVector, METH_VARARGS, NULL},
	 { "ContainerNode_readObject", _wrap_ContainerNode_readObject, METH_VARARGS, NULL},
	 { "ContainerNode_readContainer", _wrap_ContainerNode_readContainer, METH_VARARGS, NULL},
	 { "ContainerNode_readArray", _wrap_ContainerNode_readArray, METH_VARARGS, NULL},
	 { "ContainerNode_writeNumber", _wrap_ContainerNode_writeNumber, METH_VARARGS, NULL},
	 { "ContainerNode_writeInt", _wrap_ContainerNode_writeInt, METH_VARARGS, NULL},
	 { "ContainerNode_writeBool", _wrap_ContainerNode_writeBool, METH_VARARGS, NULL},
	 { "ContainerNode_writeString", _wrap_ContainerNode_writeString, METH_VARARGS, NULL},
	 { "ContainerNode_writeStringVector", _wrap_ContainerNode_writeStringVector, METH_VARARGS, NULL},
	 { "ContainerNode_writeObject", _wrap_ContainerNode_writeObject, METH_VARARGS, NULL},
	 { "ContainerNode_writeNewContainer", _wrap_ContainerNode_writeNewContainer, METH_VARARGS, NULL},
	 { "ContainerNode_writeNewArray", _wrap_ContainerNode_writeNewArray, METH_VARARGS, NULL},
	 { "new_ContainerNode", _wrap_new_ContainerNode, METH_NOARGS, NULL},
	 { "delete_ContainerNode", _wrap_delete_ContainerNode, METH_O, NULL},
	 { "ContainerNode_swigregister", ContainerNode_swigregister, METH_O, NULL},
	 { "ContainerNode_swiginit", ContainerNode_swiginit, METH_VARARGS, NULL},
	 { "AuthCredInfo_scheme_set", _wrap_AuthCredInfo_scheme_set, METH_VARARGS, NULL},
	 { "AuthCredInfo_scheme_get", _wrap_AuthCredInfo_scheme_get, METH_O, NULL},
	 { "AuthCredInfo_realm_set", _wrap_AuthCredInfo_realm_set, METH_VARARGS, NULL},
	 { "AuthCredInfo_realm_get", _wrap_AuthCredInfo_realm_get, METH_O, NULL},
	 { "AuthCredInfo_username_set", _wrap_AuthCredInfo_username_set, METH_VARARGS, NULL},
	 { "AuthCredInfo_username_get", _wrap_AuthCredInfo_username_get, METH_O, NULL},
	 { "AuthCredInfo_dataType_set", _wrap_AuthCredInfo_dataType_set, METH_VARARGS, NULL},
	 { "AuthCredInfo_dataType_get", _wrap_AuthCredInfo_dataType_get, METH_O, NULL},
	 { "AuthCredInfo_data_set", _wrap_AuthCredInfo_data_set, METH_VARARGS, NULL},
	 { "AuthCredInfo_data_get", _wrap_AuthCredInfo_data_get, METH_O, NULL},
	 { "AuthCredInfo_akaK_set", _wrap_AuthCredInfo_akaK_set, METH_VARARGS, NULL},
	 { "AuthCredInfo_akaK_get", _wrap_AuthCredInfo_akaK_get, METH_O, NULL},
	 { "AuthCredInfo_akaOp_set", _wrap_AuthCredInfo_akaOp_set, METH_VARARGS, NULL},
	 { "AuthCredInfo_akaOp_get", _wrap_AuthCredInfo_akaOp_get, METH_O, NULL},
	 { "AuthCredInfo_akaAmf_set", _wrap_AuthCredInfo_akaAmf_set, METH_VARARGS, NULL},
	 { "AuthCredInfo_akaAmf_get", _wrap_AuthCredInfo_akaAmf_get, METH_O, NULL},
	 { "new_AuthCredInfo", _wrap_new_AuthCredInfo, METH_VARARGS, NULL},
	 { "AuthCredInfo_readObject", _wrap_AuthCredInfo_readObject, METH_VARARGS, NULL},
	 { "AuthCredInfo_writeObject", _wrap_AuthCredInfo_writeObject, METH_VARARGS, NULL},
	 { "delete_AuthCredInfo", _wrap_delete_AuthCredInfo, METH_O, NULL},
	 { "AuthCredInfo_swigregister", AuthCredInfo_swigregister, METH_O, NULL},
	 { "AuthCredInfo_swiginit", AuthCredInfo_swiginit, METH_VARARGS, NULL},
	 { "TlsConfig_CaListFile_set", _wrap_TlsConfig_CaListFile_set, METH_VARARGS, NULL},
	 { "TlsConfig_CaListFile_get", _wrap_TlsConfig_CaListFile_get, METH_O, NULL},
	 { "TlsConfig_certFile_set", _wrap_TlsConfig_certFile_set, METH_VARARGS, NULL},
	 { "TlsConfig_certFile_get", _wrap_TlsConfig_certFile_get, METH_O, NULL},
	 { "TlsConfig_privKeyFile_set", _wrap_TlsConfig_privKeyFile_set, METH_VARARGS, NULL},
	 { "TlsConfig_privKeyFile_get", _wrap_TlsConfig_privKeyFile_get, METH_O, NULL},
	 { "TlsConfig_password_set", _wrap_TlsConfig_password_set, METH_VARARGS, NULL},
	 { "TlsConfig_password_get", _wrap_TlsConfig_password_get, METH_O, NULL},
	 { "TlsConfig_CaBuf_set", _wrap_TlsConfig_CaBuf_set, METH_VARARGS, NULL},
	 { "TlsConfig_CaBuf_get", _wrap_TlsConfig_CaBuf_get, METH_O, NULL},
	 { "TlsConfig_certBuf_set", _wrap_TlsConfig_certBuf_set, METH_VARARGS, NULL},
	 { "TlsConfig_certBuf_get", _wrap_TlsConfig_certBuf_get, METH_O, NULL},
	 { "TlsConfig_privKeyBuf_set", _wrap_TlsConfig_privKeyBuf_set, METH_VARARGS, NULL},
	 { "TlsConfig_privKeyBuf_get", _wrap_TlsConfig_privKeyBuf_get, METH_O, NULL},
	 { "TlsConfig_method_set", _wrap_TlsConfig_method_set, METH_VARARGS, NULL},
	 { "TlsConfig_method_get", _wrap_TlsConfig_method_get, METH_O, NULL},
	 { "TlsConfig_proto_set", _wrap_TlsConfig_proto_set, METH_VARARGS, NULL},
	 { "TlsConfig_proto_get", _wrap_TlsConfig_proto_get, METH_O, NULL},
	 { "TlsConfig_ciphers_set", _wrap_TlsConfig_ciphers_set, METH_VARARGS, NULL},
	 { "TlsConfig_ciphers_get", _wrap_TlsConfig_ciphers_get, METH_O, NULL},
	 { "TlsConfig_verifyServer_set", _wrap_TlsConfig_verifyServer_set, METH_VARARGS, NULL},
	 { "TlsConfig_verifyServer_get", _wrap_TlsConfig_verifyServer_get, METH_O, NULL},
	 { "TlsConfig_verifyClient_set", _wrap_TlsConfig_verifyClient_set, METH_VARARGS, NULL},
	 { "TlsConfig_verifyClient_get", _wrap_TlsConfig_verifyClient_get, METH_O, NULL},
	 { "TlsConfig_requireClientCert_set", _wrap_TlsConfig_requireClientCert_set, METH_VARARGS, NULL},
	 { "TlsConfig_requireClientCert_get", _wrap_TlsConfig_requireClientCert_get, METH_O, NULL},
	 { "TlsConfig_msecTimeout_set", _wrap_TlsConfig_msecTimeout_set, METH_VARARGS, NULL},
	 { "TlsConfig_msecTimeout_get", _wrap_TlsConfig_msecTimeout_get, METH_O, NULL},
	 { "TlsConfig_qosType_set", _wrap_TlsConfig_qosType_set, METH_VARARGS, NULL},
	 { "TlsConfig_qosType_get", _wrap_TlsConfig_qosType_get, METH_O, NULL},
	 { "TlsConfig_qosParams_set", _wrap_TlsConfig_qosParams_set, METH_VARARGS, NULL},
	 { "TlsConfig_qosParams_get", _wrap_TlsConfig_qosParams_get, METH_O, NULL},
	 { "TlsConfig_qosIgnoreError_set", _wrap_TlsConfig_qosIgnoreError_set, METH_VARARGS, NULL},
	 { "TlsConfig_qosIgnoreError_get", _wrap_TlsConfig_qosIgnoreError_get, METH_O, NULL},
	 { "new_TlsConfig", _wrap_new_TlsConfig, METH_NOARGS, NULL},
	 { "TlsConfig_readObject", _wrap_TlsConfig_readObject, METH_VARARGS, NULL},
	 { "TlsConfig_writeObject", _wrap_TlsConfig_writeObject, METH_VARARGS, NULL},
	 { "delete_TlsConfig", _wrap_delete_TlsConfig, METH_O, NULL},
	 { "TlsConfig_swigregister", TlsConfig_swigregister, METH_O, NULL},
	 { "TlsConfig_swiginit", TlsConfig_swiginit, METH_VARARGS, NULL},
	 { "TransportConfig_port_set", _wrap_TransportConfig_port_set, METH_VARARGS, NULL},
	 { "TransportConfig_port_get", _wrap_TransportConfig_port_get, METH_O, NULL},
	 { "TransportConfig_portRange_set", _wrap_TransportConfig_portRange_set, METH_VARARGS, NULL},
	 { "TransportConfig_portRange_get", _wrap_TransportConfig_portRange_get, METH_O, NULL},
	 { "TransportConfig_publicAddress_set", _wrap_TransportConfig_publicAddress_set, METH_VARARGS, NULL},
	 { "TransportConfig_publicAddress_get", _wrap_TransportConfig_publicAddress_get, METH_O, NULL},
	 { "TransportConfig_boundAddress_set", _wrap_TransportConfig_boundAddress_set, METH_VARARGS, NULL},
	 { "TransportConfig_boundAddress_get", _wrap_TransportConfig_boundAddress_get, METH_O, NULL},
	 { "TransportConfig_tlsConfig_set", _wrap_TransportConfig_tlsConfig_set, METH_VARARGS, NULL},
	 { "TransportConfig_tlsConfig_get", _wrap_TransportConfig_tlsConfig_get, METH_O, NULL},
	 { "TransportConfig_qosType_set", _wrap_TransportConfig_qosType_set, METH_VARARGS, NULL},
	 { "TransportConfig_qosType_get", _wrap_TransportConfig_qosType_get, METH_O, NULL},
	 { "TransportConfig_qosParams_set", _wrap_TransportConfig_qosParams_set, METH_VARARGS, NULL},
	 { "TransportConfig_qosParams_get", _wrap_TransportConfig_qosParams_get, METH_O, NULL},
	 { "new_TransportConfig", _wrap_new_TransportConfig, METH_NOARGS, NULL},
	 { "TransportConfig_readObject", _wrap_TransportConfig_readObject, METH_VARARGS, NULL},
	 { "TransportConfig_writeObject", _wrap_TransportConfig_writeObject, METH_VARARGS, NULL},
	 { "delete_TransportConfig", _wrap_delete_TransportConfig, METH_O, NULL},
	 { "TransportConfig_swigregister", TransportConfig_swigregister, METH_O, NULL},
	 { "TransportConfig_swiginit", TransportConfig_swiginit, METH_VARARGS, NULL},
	 { "TransportInfo_id_set", _wrap_TransportInfo_id_set, METH_VARARGS, NULL},
	 { "TransportInfo_id_get", _wrap_TransportInfo_id_get, METH_O, NULL},
	 { "TransportInfo_type_set", _wrap_TransportInfo_type_set, METH_VARARGS, NULL},
	 { "TransportInfo_type_get", _wrap_TransportInfo_type_get, METH_O, NULL},
	 { "TransportInfo_typeName_set", _wrap_TransportInfo_typeName_set, METH_VARARGS, NULL},
	 { "TransportInfo_typeName_get", _wrap_TransportInfo_typeName_get, METH_O, NULL},
	 { "TransportInfo_info_set", _wrap_TransportInfo_info_set, METH_VARARGS, NULL},
	 { "TransportInfo_info_get", _wrap_TransportInfo_info_get, METH_O, NULL},
	 { "TransportInfo_flags_set", _wrap_TransportInfo_flags_set, METH_VARARGS, NULL},
	 { "TransportInfo_flags_get", _wrap_TransportInfo_flags_get, METH_O, NULL},
	 { "TransportInfo_localAddress_set", _wrap_TransportInfo_localAddress_set, METH_VARARGS, NULL},
	 { "TransportInfo_localAddress_get", _wrap_TransportInfo_localAddress_get, METH_O, NULL},
	 { "TransportInfo_localName_set", _wrap_TransportInfo_localName_set, METH_VARARGS, NULL},
	 { "TransportInfo_localName_get", _wrap_TransportInfo_localName_get, METH_O, NULL},
	 { "TransportInfo_usageCount_set", _wrap_TransportInfo_usageCount_set, METH_VARARGS, NULL},
	 { "TransportInfo_usageCount_get", _wrap_TransportInfo_usageCount_get, METH_O, NULL},
	 { "new_TransportInfo", _wrap_new_TransportInfo, METH_NOARGS, NULL},
	 { "delete_TransportInfo", _wrap_delete_TransportInfo, METH_O, NULL},
	 { "TransportInfo_swigregister", TransportInfo_swigregister, METH_O, NULL},
	 { "TransportInfo_swiginit", TransportInfo_swiginit, METH_VARARGS, NULL},
	 { "SipRxData_info_set", _wrap_SipRxData_info_set, METH_VARARGS, NULL},
	 { "SipRxData_info_get", _wrap_SipRxData_info_get, METH_O, NULL},
	 { "SipRxData_wholeMsg_set", _wrap_SipRxData_wholeMsg_set, METH_VARARGS, NULL},
	 { "SipRxData_wholeMsg_get", _wrap_SipRxData_wholeMsg_get, METH_O, NULL},
	 { "SipRxData_srcAddress_set", _wrap_SipRxData_srcAddress_set, METH_VARARGS, NULL},
	 { "SipRxData_srcAddress_get", _wrap_SipRxData_srcAddress_get, METH_O, NULL},
	 { "SipRxData_pjRxData_set", _wrap_SipRxData_pjRxData_set, METH_VARARGS, NULL},
	 { "SipRxData_pjRxData_get", _wrap_SipRxData_pjRxData_get, METH_O, NULL},
	 { "new_SipRxData", _wrap_new_SipRxData, METH_NOARGS, NULL},
	 { "delete_SipRxData", _wrap_delete_SipRxData, METH_O, NULL},
	 { "SipRxData_swigregister", SipRxData_swigregister, METH_O, NULL},
	 { "SipRxData_swiginit", SipRxData_swiginit, METH_VARARGS, NULL},
	 { "SipTxData_info_set", _wrap_SipTxData_info_set, METH_VARARGS, NULL},
	 { "SipTxData_info_get", _wrap_SipTxData_info_get, METH_O, NULL},
	 { "SipTxData_wholeMsg_set", _wrap_SipTxData_wholeMsg_set, METH_VARARGS, NULL},
	 { "SipTxData_wholeMsg_get", _wrap_SipTxData_wholeMsg_get, METH_O, NULL},
	 { "SipTxData_dstAddress_set", _wrap_SipTxData_dstAddress_set, METH_VARARGS, NULL},
	 { "SipTxData_dstAddress_get", _wrap_SipTxData_dstAddress_get, METH_O, NULL},
	 { "SipTxData_pjTxData_set", _wrap_SipTxData_pjTxData_set, METH_VARARGS, NULL},
	 { "SipTxData_pjTxData_get", _wrap_SipTxData_pjTxData_get, METH_O, NULL},
	 { "new_SipTxData", _wrap_new_SipTxData, METH_NOARGS, NULL},
	 { "delete_SipTxData", _wrap_delete_SipTxData, METH_O, NULL},
	 { "SipTxData_swigregister", SipTxData_swigregister, METH_O, NULL},
	 { "SipTxData_swiginit", SipTxData_swiginit, METH_VARARGS, NULL},
	 { "SipTransaction_role_set", _wrap_SipTransaction_role_set, METH_VARARGS, NULL},
	 { "SipTransaction_role_get", _wrap_SipTransaction_role_get, METH_O, NULL},
	 { "SipTransaction_method_set", _wrap_SipTransaction_method_set, METH_VARARGS, NULL},
	 { "SipTransaction_method_get", _wrap_SipTransaction_method_get, METH_O, NULL},
	 { "SipTransaction_statusCode_set", _wrap_SipTransaction_statusCode_set, METH_VARARGS, NULL},
	 { "SipTransaction_statusCode_get", _wrap_SipTransaction_statusCode_get, METH_O, NULL},
	 { "SipTransaction_statusText_set", _wrap_SipTransaction_statusText_set, METH_VARARGS, NULL},
	 { "SipTransaction_statusText_get", _wrap_SipTransaction_statusText_get, METH_O, NULL},
	 { "SipTransaction_state_set", _wrap_SipTransaction_state_set, METH_VARARGS, NULL},
	 { "SipTransaction_state_get", _wrap_SipTransaction_state_get, METH_O, NULL},
	 { "SipTransaction_lastTx_set", _wrap_SipTransaction_lastTx_set, METH_VARARGS, NULL},
	 { "SipTransaction_lastTx_get", _wrap_SipTransaction_lastTx_get, METH_O, NULL},
	 { "SipTransaction_pjTransaction_set", _wrap_SipTransaction_pjTransaction_set, METH_VARARGS, NULL},
	 { "SipTransaction_pjTransaction_get", _wrap_SipTransaction_pjTransaction_get, METH_O, NULL},
	 { "new_SipTransaction", _wrap_new_SipTransaction, METH_NOARGS, NULL},
	 { "delete_SipTransaction", _wrap_delete_SipTransaction, METH_O, NULL},
	 { "SipTransaction_swigregister", SipTransaction_swigregister, METH_O, NULL},
	 { "SipTransaction_swiginit", SipTransaction_swiginit, METH_VARARGS, NULL},
	 { "TimerEvent_entry_set", _wrap_TimerEvent_entry_set, METH_VARARGS, NULL},
	 { "TimerEvent_entry_get", _wrap_TimerEvent_entry_get, METH_O, NULL},
	 { "new_TimerEvent", _wrap_new_TimerEvent, METH_NOARGS, NULL},
	 { "delete_TimerEvent", _wrap_delete_TimerEvent, METH_O, NULL},
	 { "TimerEvent_swigregister", TimerEvent_swigregister, METH_O, NULL},
	 { "TimerEvent_swiginit", TimerEvent_swiginit, METH_VARARGS, NULL},
	 { "TsxStateEventSrc_rdata_set", _wrap_TsxStateEventSrc_rdata_set, METH_VARARGS, NULL},
	 { "TsxStateEventSrc_rdata_get", _wrap_TsxStateEventSrc_rdata_get, METH_O, NULL},
	 { "TsxStateEventSrc_tdata_set", _wrap_TsxStateEventSrc_tdata_set, METH_VARARGS, NULL},
	 { "TsxStateEventSrc_tdata_get", _wrap_TsxStateEventSrc_tdata_get, METH_O, NULL},
	 { "TsxStateEventSrc_timer_set", _wrap_TsxStateEventSrc_timer_set, METH_VARARGS, NULL},
	 { "TsxStateEventSrc_timer_get", _wrap_TsxStateEventSrc_timer_get, METH_O, NULL},
	 { "TsxStateEventSrc_status_set", _wrap_TsxStateEventSrc_status_set, METH_VARARGS, NULL},
	 { "TsxStateEventSrc_status_get", _wrap_TsxStateEventSrc_status_get, METH_O, NULL},
	 { "TsxStateEventSrc_data_set", _wrap_TsxStateEventSrc_data_set, METH_VARARGS, NULL},
	 { "TsxStateEventSrc_data_get", _wrap_TsxStateEventSrc_data_get, METH_O, NULL},
	 { "new_TsxStateEventSrc", _wrap_new_TsxStateEventSrc, METH_NOARGS, NULL},
	 { "delete_TsxStateEventSrc", _wrap_delete_TsxStateEventSrc, METH_O, NULL},
	 { "TsxStateEventSrc_swigregister", TsxStateEventSrc_swigregister, METH_O, NULL},
	 { "TsxStateEventSrc_swiginit", TsxStateEventSrc_swiginit, METH_VARARGS, NULL},
	 { "TsxStateEvent_src_set", _wrap_TsxStateEvent_src_set, METH_VARARGS, NULL},
	 { "TsxStateEvent_src_get", _wrap_TsxStateEvent_src_get, METH_O, NULL},
	 { "TsxStateEvent_tsx_set", _wrap_TsxStateEvent_tsx_set, METH_VARARGS, NULL},
	 { "TsxStateEvent_tsx_get", _wrap_TsxStateEvent_tsx_get, METH_O, NULL},
	 { "TsxStateEvent_prevState_set", _wrap_TsxStateEvent_prevState_set, METH_VARARGS, NULL},
	 { "TsxStateEvent_prevState_get", _wrap_TsxStateEvent_prevState_get, METH_O, NULL},
	 { "TsxStateEvent_type_set", _wrap_TsxStateEvent_type_set, METH_VARARGS, NULL},
	 { "TsxStateEvent_type_get", _wrap_TsxStateEvent_type_get, METH_O, NULL},
	 { "new_TsxStateEvent", _wrap_new_TsxStateEvent, METH_NOARGS, NULL},
	 { "delete_TsxStateEvent", _wrap_delete_TsxStateEvent, METH_O, NULL},
	 { "TsxStateEvent_swigregister", TsxStateEvent_swigregister, METH_O, NULL},
	 { "TsxStateEvent_swiginit", TsxStateEvent_swiginit, METH_VARARGS, NULL},
	 { "TxMsgEvent_tdata_set", _wrap_TxMsgEvent_tdata_set, METH_VARARGS, NULL},
	 { "TxMsgEvent_tdata_get", _wrap_TxMsgEvent_tdata_get, METH_O, NULL},
	 { "new_TxMsgEvent", _wrap_new_TxMsgEvent, METH_NOARGS, NULL},
	 { "delete_TxMsgEvent", _wrap_delete_TxMsgEvent, METH_O, NULL},
	 { "TxMsgEvent_swigregister", TxMsgEvent_swigregister, METH_O, NULL},
	 { "TxMsgEvent_swiginit", TxMsgEvent_swiginit, METH_VARARGS, NULL},
	 { "TxErrorEvent_tdata_set", _wrap_TxErrorEvent_tdata_set, METH_VARARGS, NULL},
	 { "TxErrorEvent_tdata_get", _wrap_TxErrorEvent_tdata_get, METH_O, NULL},
	 { "TxErrorEvent_tsx_set", _wrap_TxErrorEvent_tsx_set, METH_VARARGS, NULL},
	 { "TxErrorEvent_tsx_get", _wrap_TxErrorEvent_tsx_get, METH_O, NULL},
	 { "new_TxErrorEvent", _wrap_new_TxErrorEvent, METH_NOARGS, NULL},
	 { "delete_TxErrorEvent", _wrap_delete_TxErrorEvent, METH_O, NULL},
	 { "TxErrorEvent_swigregister", TxErrorEvent_swigregister, METH_O, NULL},
	 { "TxErrorEvent_swiginit", TxErrorEvent_swiginit, METH_VARARGS, NULL},
	 { "RxMsgEvent_rdata_set", _wrap_RxMsgEvent_rdata_set, METH_VARARGS, NULL},
	 { "RxMsgEvent_rdata_get", _wrap_RxMsgEvent_rdata_get, METH_O, NULL},
	 { "new_RxMsgEvent", _wrap_new_RxMsgEvent, METH_NOARGS, NULL},
	 { "delete_RxMsgEvent", _wrap_delete_RxMsgEvent, METH_O, NULL},
	 { "RxMsgEvent_swigregister", RxMsgEvent_swigregister, METH_O, NULL},
	 { "RxMsgEvent_swiginit", RxMsgEvent_swiginit, METH_VARARGS, NULL},
	 { "UserEvent_user1_set", _wrap_UserEvent_user1_set, METH_VARARGS, NULL},
	 { "UserEvent_user1_get", _wrap_UserEvent_user1_get, METH_O, NULL},
	 { "UserEvent_user2_set", _wrap_UserEvent_user2_set, METH_VARARGS, NULL},
	 { "UserEvent_user2_get", _wrap_UserEvent_user2_get, METH_O, NULL},
	 { "UserEvent_user3_set", _wrap_UserEvent_user3_set, METH_VARARGS, NULL},
	 { "UserEvent_user3_get", _wrap_UserEvent_user3_get, METH_O, NULL},
	 { "UserEvent_user4_set", _wrap_UserEvent_user4_set, METH_VARARGS, NULL},
	 { "UserEvent_user4_get", _wrap_UserEvent_user4_get, METH_O, NULL},
	 { "new_UserEvent", _wrap_new_UserEvent, METH_NOARGS, NULL},
	 { "delete_UserEvent", _wrap_delete_UserEvent, METH_O, NULL},
	 { "UserEvent_swigregister", UserEvent_swigregister, METH_O, NULL},
	 { "UserEvent_swiginit", UserEvent_swiginit, METH_VARARGS, NULL},
	 { "SipEventBody_timer_set", _wrap_SipEventBody_timer_set, METH_VARARGS, NULL},
	 { "SipEventBody_timer_get", _wrap_SipEventBody_timer_get, METH_O, NULL},
	 { "SipEventBody_tsxState_set", _wrap_SipEventBody_tsxState_set, METH_VARARGS, NULL},
	 { "SipEventBody_tsxState_get", _wrap_SipEventBody_tsxState_get, METH_O, NULL},
	 { "SipEventBody_txMsg_set", _wrap_SipEventBody_txMsg_set, METH_VARARGS, NULL},
	 { "SipEventBody_txMsg_get", _wrap_SipEventBody_txMsg_get, METH_O, NULL},
	 { "SipEventBody_txError_set", _wrap_SipEventBody_txError_set, METH_VARARGS, NULL},
	 { "SipEventBody_txError_get", _wrap_SipEventBody_txError_get, METH_O, NULL},
	 { "SipEventBody_rxMsg_set", _wrap_SipEventBody_rxMsg_set, METH_VARARGS, NULL},
	 { "SipEventBody_rxMsg_get", _wrap_SipEventBody_rxMsg_get, METH_O, NULL},
	 { "SipEventBody_user_set", _wrap_SipEventBody_user_set, METH_VARARGS, NULL},
	 { "SipEventBody_user_get", _wrap_SipEventBody_user_get, METH_O, NULL},
	 { "new_SipEventBody", _wrap_new_SipEventBody, METH_NOARGS, NULL},
	 { "delete_SipEventBody", _wrap_delete_SipEventBody, METH_O, NULL},
	 { "SipEventBody_swigregister", SipEventBody_swigregister, METH_O, NULL},
	 { "SipEventBody_swiginit", SipEventBody_swiginit, METH_VARARGS, NULL},
	 { "SipEvent_type_set", _wrap_SipEvent_type_set, METH_VARARGS, NULL},
	 { "SipEvent_type_get", _wrap_SipEvent_type_get, METH_O, NULL},
	 { "SipEvent_body_set", _wrap_SipEvent_body_set, METH_VARARGS, NULL},
	 { "SipEvent_body_get", _wrap_SipEvent_body_get, METH_O, NULL},
	 { "SipEvent_pjEvent_set", _wrap_SipEvent_pjEvent_set, METH_VARARGS, NULL},
	 { "SipEvent_pjEvent_get", _wrap_SipEvent_pjEvent_get, METH_O, NULL},
	 { "new_SipEvent", _wrap_new_SipEvent, METH_NOARGS, NULL},
	 { "delete_SipEvent", _wrap_delete_SipEvent, METH_O, NULL},
	 { "SipEvent_swigregister", SipEvent_swigregister, METH_O, NULL},
	 { "SipEvent_swiginit", SipEvent_swiginit, METH_VARARGS, NULL},
	 { "SipMediaType_type_set", _wrap_SipMediaType_type_set, METH_VARARGS, NULL},
	 { "SipMediaType_type_get", _wrap_SipMediaType_type_get, METH_O, NULL},
	 { "SipMediaType_subType_set", _wrap_SipMediaType_subType_set, METH_VARARGS, NULL},
	 { "SipMediaType_subType_get", _wrap_SipMediaType_subType_get, METH_O, NULL},
	 { "new_SipMediaType", _wrap_new_SipMediaType, METH_NOARGS, NULL},
	 { "delete_SipMediaType", _wrap_delete_SipMediaType, METH_O, NULL},
	 { "SipMediaType_swigregister", SipMediaType_swigregister, METH_O, NULL},
	 { "SipMediaType_swiginit", SipMediaType_swiginit, METH_VARARGS, NULL},
	 { "SipHeader_hName_set", _wrap_SipHeader_hName_set, METH_VARARGS, NULL},
	 { "SipHeader_hName_get", _wrap_SipHeader_hName_get, METH_O, NULL},
	 { "SipHeader_hValue_set", _wrap_SipHeader_hValue_set, METH_VARARGS, NULL},
	 { "SipHeader_hValue_get", _wrap_SipHeader_hValue_get, METH_O, NULL},
	 { "new_SipHeader", _wrap_new_SipHeader, METH_NOARGS, NULL},
	 { "delete_SipHeader", _wrap_delete_SipHeader, METH_O, NULL},
	 { "SipHeader_swigregister", SipHeader_swigregister, METH_O, NULL},
	 { "SipHeader_swiginit", SipHeader_swiginit, METH_VARARGS, NULL},
	 { "SipMultipartPart_headers_set", _wrap_SipMultipartPart_headers_set, METH_VARARGS, NULL},
	 { "SipMultipartPart_headers_get", _wrap_SipMultipartPart_headers_get, METH_O, NULL},
	 { "SipMultipartPart_contentType_set", _wrap_SipMultipartPart_contentType_set, METH_VARARGS, NULL},
	 { "SipMultipartPart_contentType_get", _wrap_SipMultipartPart_contentType_get, METH_O, NULL},
	 { "SipMultipartPart_body_set", _wrap_SipMultipartPart_body_set, METH_VARARGS, NULL},
	 { "SipMultipartPart_body_get", _wrap_SipMultipartPart_body_get, METH_O, NULL},
	 { "new_SipMultipartPart", _wrap_new_SipMultipartPart, METH_NOARGS, NULL},
	 { "delete_SipMultipartPart", _wrap_delete_SipMultipartPart, METH_O, NULL},
	 { "SipMultipartPart_swigregister", SipMultipartPart_swigregister, METH_O, NULL},
	 { "SipMultipartPart_swiginit", SipMultipartPart_swiginit, METH_VARARGS, NULL},
	 { "SipTxOption_targetUri_set", _wrap_SipTxOption_targetUri_set, METH_VARARGS, NULL},
	 { "SipTxOption_targetUri_get", _wrap_SipTxOption_targetUri_get, METH_O, NULL},
	 { "SipTxOption_headers_set", _wrap_SipTxOption_headers_set, METH_VARARGS, NULL},
	 { "SipTxOption_headers_get", _wrap_SipTxOption_headers_get, METH_O, NULL},
	 { "SipTxOption_contentType_set", _wrap_SipTxOption_contentType_set, METH_VARARGS, NULL},
	 { "SipTxOption_contentType_get", _wrap_SipTxOption_contentType_get, METH_O, NULL},
	 { "SipTxOption_msgBody_set", _wrap_SipTxOption_msgBody_set, METH_VARARGS, NULL},
	 { "SipTxOption_msgBody_get", _wrap_SipTxOption_msgBody_get, METH_O, NULL},
	 { "SipTxOption_multipartContentType_set", _wrap_SipTxOption_multipartContentType_set, METH_VARARGS, NULL},
	 { "SipTxOption_multipartContentType_get", _wrap_SipTxOption_multipartContentType_get, METH_O, NULL},
	 { "SipTxOption_multipartParts_set", _wrap_SipTxOption_multipartParts_set, METH_VARARGS, NULL},
	 { "SipTxOption_multipartParts_get", _wrap_SipTxOption_multipartParts_get, METH_O, NULL},
	 { "SipTxOption_isEmpty", _wrap_SipTxOption_isEmpty, METH_O, NULL},
	 { "new_SipTxOption", _wrap_new_SipTxOption, METH_NOARGS, NULL},
	 { "delete_SipTxOption", _wrap_delete_SipTxOption, METH_O, NULL},
	 { "SipTxOption_swigregister", SipTxOption_swigregister, METH_O, NULL},
	 { "SipTxOption_swiginit", SipTxOption_swiginit, METH_VARARGS, NULL},
	 { "SendInstantMessageParam_contentType_set", _wrap_SendInstantMessageParam_contentType_set, METH_VARARGS, NULL},
	 { "SendInstantMessageParam_contentType_get", _wrap_SendInstantMessageParam_contentType_get, METH_O, NULL},
	 { "SendInstantMessageParam_content_set", _wrap_SendInstantMessageParam_content_set, METH_VARARGS, NULL},
	 { "SendInstantMessageParam_content_get", _wrap_SendInstantMessageParam_content_get, METH_O, NULL},
	 { "SendInstantMessageParam_txOption_set", _wrap_SendInstantMessageParam_txOption_set, METH_VARARGS, NULL},
	 { "SendInstantMessageParam_txOption_get", _wrap_SendInstantMessageParam_txOption_get, METH_O, NULL},
	 { "SendInstantMessageParam_userData_set", _wrap_SendInstantMessageParam_userData_set, METH_VARARGS, NULL},
	 { "SendInstantMessageParam_userData_get", _wrap_SendInstantMessageParam_userData_get, METH_O, NULL},
	 { "new_SendInstantMessageParam", _wrap_new_SendInstantMessageParam, METH_NOARGS, NULL},
	 { "delete_SendInstantMessageParam", _wrap_delete_SendInstantMessageParam, METH_O, NULL},
	 { "SendInstantMessageParam_swigregister", SendInstantMessageParam_swigregister, METH_O, NULL},
	 { "SendInstantMessageParam_swiginit", SendInstantMessageParam_swiginit, METH_VARARGS, NULL},
	 { "SendTypingIndicationParam_isTyping_set", _wrap_SendTypingIndicationParam_isTyping_set, METH_VARARGS, NULL},
	 { "SendTypingIndicationParam_isTyping_get", _wrap_SendTypingIndicationParam_isTyping_get, METH_O, NULL},
	 { "SendTypingIndicationParam_txOption_set", _wrap_SendTypingIndicationParam_txOption_set, METH_VARARGS, NULL},
	 { "SendTypingIndicationParam_txOption_get", _wrap_SendTypingIndicationParam_txOption_get, METH_O, NULL},
	 { "new_SendTypingIndicationParam", _wrap_new_SendTypingIndicationParam, METH_NOARGS, NULL},
	 { "delete_SendTypingIndicationParam", _wrap_delete_SendTypingIndicationParam, METH_O, NULL},
	 { "SendTypingIndicationParam_swigregister", SendTypingIndicationParam_swigregister, METH_O, NULL},
	 { "SendTypingIndicationParam_swiginit", SendTypingIndicationParam_swiginit, METH_VARARGS, NULL},
	 { "SipHeaderVector_iterator", _wrap_SipHeaderVector_iterator, METH_O, NULL},
	 { "SipHeaderVector___nonzero__", _wrap_SipHeaderVector___nonzero__, METH_O, NULL},
	 { "SipHeaderVector___bool__", _wrap_SipHeaderVector___bool__, METH_O, NULL},
	 { "SipHeaderVector___len__", _wrap_SipHeaderVector___len__, METH_O, NULL},
	 { "SipHeaderVector___getslice__", _wrap_SipHeaderVector___getslice__, METH_VARARGS, NULL},
	 { "SipHeaderVector___setslice__", _wrap_SipHeaderVector___setslice__, METH_VARARGS, NULL},
	 { "SipHeaderVector___delslice__", _wrap_SipHeaderVector___delslice__, METH_VARARGS, NULL},
	 { "SipHeaderVector___delitem__", _wrap_SipHeaderVector___delitem__, METH_VARARGS, NULL},
	 { "SipHeaderVector___getitem__", _wrap_SipHeaderVector___getitem__, METH_VARARGS, NULL},
	 { "SipHeaderVector___setitem__", _wrap_SipHeaderVector___setitem__, METH_VARARGS, NULL},
	 { "SipHeaderVector_pop", _wrap_SipHeaderVector_pop, METH_O, NULL},
	 { "SipHeaderVector_append", _wrap_SipHeaderVector_append, METH_VARARGS, NULL},
	 { "SipHeaderVector_empty", _wrap_SipHeaderVector_empty, METH_O, NULL},
	 { "SipHeaderVector_size", _wrap_SipHeaderVector_size, METH_O, NULL},
	 { "SipHeaderVector_swap", _wrap_SipHeaderVector_swap, METH_VARARGS, NULL},
	 { "SipHeaderVector_begin", _wrap_SipHeaderVector_begin, METH_O, NULL},
	 { "SipHeaderVector_end", _wrap_SipHeaderVector_end, METH_O, NULL},
	 { "SipHeaderVector_rbegin", _wrap_SipHeaderVector_rbegin, METH_O, NULL},
	 { "SipHeaderVector_rend", _wrap_SipHeaderVector_rend, METH_O, NULL},
	 { "SipHeaderVector_clear", _wrap_SipHeaderVector_clear, METH_O, NULL},
	 { "SipHeaderVector_get_allocator", _wrap_SipHeaderVector_get_allocator, METH_O, NULL},
	 { "SipHeaderVector_pop_back", _wrap_SipHeaderVector_pop_back, METH_O, NULL},
	 { "SipHeaderVector_erase", _wrap_SipHeaderVector_erase, METH_VARARGS, NULL},
	 { "new_SipHeaderVector", _wrap_new_SipHeaderVector, METH_VARARGS, NULL},
	 { "SipHeaderVector_push_back", _wrap_SipHeaderVector_push_back, METH_VARARGS, NULL},
	 { "SipHeaderVector_front", _wrap_SipHeaderVector_front, METH_O, NULL},
	 { "SipHeaderVector_back", _wrap_SipHeaderVector_back, METH_O, NULL},
	 { "SipHeaderVector_assign", _wrap_SipHeaderVector_assign, METH_VARARGS, NULL},
	 { "SipHeaderVector_resize", _wrap_SipHeaderVector_resize, METH_VARARGS, NULL},
	 { "SipHeaderVector_insert", _wrap_SipHeaderVector_insert, METH_VARARGS, NULL},
	 { "SipHeaderVector_reserve", _wrap_SipHeaderVector_reserve, METH_VARARGS, NULL},
	 { "SipHeaderVector_capacity", _wrap_SipHeaderVector_capacity, METH_O, NULL},
	 { "delete_SipHeaderVector", _wrap_delete_SipHeaderVector, METH_O, NULL},
	 { "SipHeaderVector_swigregister", SipHeaderVector_swigregister, METH_O, NULL},
	 { "SipHeaderVector_swiginit", SipHeaderVector_swiginit, METH_VARARGS, NULL},
	 { "AuthCredInfoVector_iterator", _wrap_AuthCredInfoVector_iterator, METH_O, NULL},
	 { "AuthCredInfoVector___nonzero__", _wrap_AuthCredInfoVector___nonzero__, METH_O, NULL},
	 { "AuthCredInfoVector___bool__", _wrap_AuthCredInfoVector___bool__, METH_O, NULL},
	 { "AuthCredInfoVector___len__", _wrap_AuthCredInfoVector___len__, METH_O, NULL},
	 { "AuthCredInfoVector___getslice__", _wrap_AuthCredInfoVector___getslice__, METH_VARARGS, NULL},
	 { "AuthCredInfoVector___setslice__", _wrap_AuthCredInfoVector___setslice__, METH_VARARGS, NULL},
	 { "AuthCredInfoVector___delslice__", _wrap_AuthCredInfoVector___delslice__, METH_VARARGS, NULL},
	 { "AuthCredInfoVector___delitem__", _wrap_AuthCredInfoVector___delitem__, METH_VARARGS, NULL},
	 { "AuthCredInfoVector___getitem__", _wrap_AuthCredInfoVector___getitem__, METH_VARARGS, NULL},
	 { "AuthCredInfoVector___setitem__", _wrap_AuthCredInfoVector___setitem__, METH_VARARGS, NULL},
	 { "AuthCredInfoVector_pop", _wrap_AuthCredInfoVector_pop, METH_O, NULL},
	 { "AuthCredInfoVector_append", _wrap_AuthCredInfoVector_append, METH_VARARGS, NULL},
	 { "AuthCredInfoVector_empty", _wrap_AuthCredInfoVector_empty, METH_O, NULL},
	 { "AuthCredInfoVector_size", _wrap_AuthCredInfoVector_size, METH_O, NULL},
	 { "AuthCredInfoVector_swap", _wrap_AuthCredInfoVector_swap, METH_VARARGS, NULL},
	 { "AuthCredInfoVector_begin", _wrap_AuthCredInfoVector_begin, METH_O, NULL},
	 { "AuthCredInfoVector_end", _wrap_AuthCredInfoVector_end, METH_O, NULL},
	 { "AuthCredInfoVector_rbegin", _wrap_AuthCredInfoVector_rbegin, METH_O, NULL},
	 { "AuthCredInfoVector_rend", _wrap_AuthCredInfoVector_rend, METH_O, NULL},
	 { "AuthCredInfoVector_clear", _wrap_AuthCredInfoVector_clear, METH_O, NULL},
	 { "AuthCredInfoVector_get_allocator", _wrap_AuthCredInfoVector_get_allocator, METH_O, NULL},
	 { "AuthCredInfoVector_pop_back", _wrap_AuthCredInfoVector_pop_back, METH_O, NULL},
	 { "AuthCredInfoVector_erase", _wrap_AuthCredInfoVector_erase, METH_VARARGS, NULL},
	 { "new_AuthCredInfoVector", _wrap_new_AuthCredInfoVector, METH_VARARGS, NULL},
	 { "AuthCredInfoVector_push_back", _wrap_AuthCredInfoVector_push_back, METH_VARARGS, NULL},
	 { "AuthCredInfoVector_front", _wrap_AuthCredInfoVector_front, METH_O, NULL},
	 { "AuthCredInfoVector_back", _wrap_AuthCredInfoVector_back, METH_O, NULL},
	 { "AuthCredInfoVector_assign", _wrap_AuthCredInfoVector_assign, METH_VARARGS, NULL},
	 { "AuthCredInfoVector_resize", _wrap_AuthCredInfoVector_resize, METH_VARARGS, NULL},
	 { "AuthCredInfoVector_insert", _wrap_AuthCredInfoVector_insert, METH_VARARGS, NULL},
	 { "AuthCredInfoVector_reserve", _wrap_AuthCredInfoVector_reserve, METH_VARARGS, NULL},
	 { "AuthCredInfoVector_capacity", _wrap_AuthCredInfoVector_capacity, METH_O, NULL},
	 { "delete_AuthCredInfoVector", _wrap_delete_AuthCredInfoVector, METH_O, NULL},
	 { "AuthCredInfoVector_swigregister", AuthCredInfoVector_swigregister, METH_O, NULL},
	 { "AuthCredInfoVector_swiginit", AuthCredInfoVector_swiginit, METH_VARARGS, NULL},
	 { "SrtpCryptoVector_iterator", _wrap_SrtpCryptoVector_iterator, METH_O, NULL},
	 { "SrtpCryptoVector___nonzero__", _wrap_SrtpCryptoVector___nonzero__, METH_O, NULL},
	 { "SrtpCryptoVector___bool__", _wrap_SrtpCryptoVector___bool__, METH_O, NULL},
	 { "SrtpCryptoVector___len__", _wrap_SrtpCryptoVector___len__, METH_O, NULL},
	 { "SrtpCryptoVector___getslice__", _wrap_SrtpCryptoVector___getslice__, METH_VARARGS, NULL},
	 { "SrtpCryptoVector___setslice__", _wrap_SrtpCryptoVector___setslice__, METH_VARARGS, NULL},
	 { "SrtpCryptoVector___delslice__", _wrap_SrtpCryptoVector___delslice__, METH_VARARGS, NULL},
	 { "SrtpCryptoVector___delitem__", _wrap_SrtpCryptoVector___delitem__, METH_VARARGS, NULL},
	 { "SrtpCryptoVector___getitem__", _wrap_SrtpCryptoVector___getitem__, METH_VARARGS, NULL},
	 { "SrtpCryptoVector___setitem__", _wrap_SrtpCryptoVector___setitem__, METH_VARARGS, NULL},
	 { "SrtpCryptoVector_pop", _wrap_SrtpCryptoVector_pop, METH_O, NULL},
	 { "SrtpCryptoVector_append", _wrap_SrtpCryptoVector_append, METH_VARARGS, NULL},
	 { "SrtpCryptoVector_empty", _wrap_SrtpCryptoVector_empty, METH_O, NULL},
	 { "SrtpCryptoVector_size", _wrap_SrtpCryptoVector_size, METH_O, NULL},
	 { "SrtpCryptoVector_swap", _wrap_SrtpCryptoVector_swap, METH_VARARGS, NULL},
	 { "SrtpCryptoVector_begin", _wrap_SrtpCryptoVector_begin, METH_O, NULL},
	 { "SrtpCryptoVector_end", _wrap_SrtpCryptoVector_end, METH_O, NULL},
	 { "SrtpCryptoVector_rbegin", _wrap_SrtpCryptoVector_rbegin, METH_O, NULL},
	 { "SrtpCryptoVector_rend", _wrap_SrtpCryptoVector_rend, METH_O, NULL},
	 { "SrtpCryptoVector_clear", _wrap_SrtpCryptoVector_clear, METH_O, NULL},
	 { "SrtpCryptoVector_get_allocator", _wrap_SrtpCryptoVector_get_allocator, METH_O, NULL},
	 { "SrtpCryptoVector_pop_back", _wrap_SrtpCryptoVector_pop_back, METH_O, NULL},
	 { "SrtpCryptoVector_erase", _wrap_SrtpCryptoVector_erase, METH_VARARGS, NULL},
	 { "new_SrtpCryptoVector", _wrap_new_SrtpCryptoVector, METH_VARARGS, NULL},
	 { "SrtpCryptoVector_push_back", _wrap_SrtpCryptoVector_push_back, METH_VARARGS, NULL},
	 { "SrtpCryptoVector_front", _wrap_SrtpCryptoVector_front, METH_O, NULL},
	 { "SrtpCryptoVector_back", _wrap_SrtpCryptoVector_back, METH_O, NULL},
	 { "SrtpCryptoVector_assign", _wrap_SrtpCryptoVector_assign, METH_VARARGS, NULL},
	 { "SrtpCryptoVector_resize", _wrap_SrtpCryptoVector_resize, METH_VARARGS, NULL},
	 { "SrtpCryptoVector_insert", _wrap_SrtpCryptoVector_insert, METH_VARARGS, NULL},
	 { "SrtpCryptoVector_reserve", _wrap_SrtpCryptoVector_reserve, METH_VARARGS, NULL},
	 { "SrtpCryptoVector_capacity", _wrap_SrtpCryptoVector_capacity, METH_O, NULL},
	 { "delete_SrtpCryptoVector", _wrap_delete_SrtpCryptoVector, METH_O, NULL},
	 { "SrtpCryptoVector_swigregister", SrtpCryptoVector_swigregister, METH_O, NULL},
	 { "SrtpCryptoVector_swiginit", SrtpCryptoVector_swiginit, METH_VARARGS, NULL},
	 { "SipMultipartPartVector_iterator", _wrap_SipMultipartPartVector_iterator, METH_O, NULL},
	 { "SipMultipartPartVector___nonzero__", _wrap_SipMultipartPartVector___nonzero__, METH_O, NULL},
	 { "SipMultipartPartVector___bool__", _wrap_SipMultipartPartVector___bool__, METH_O, NULL},
	 { "SipMultipartPartVector___len__", _wrap_SipMultipartPartVector___len__, METH_O, NULL},
	 { "SipMultipartPartVector___getslice__", _wrap_SipMultipartPartVector___getslice__, METH_VARARGS, NULL},
	 { "SipMultipartPartVector___setslice__", _wrap_SipMultipartPartVector___setslice__, METH_VARARGS, NULL},
	 { "SipMultipartPartVector___delslice__", _wrap_SipMultipartPartVector___delslice__, METH_VARARGS, NULL},
	 { "SipMultipartPartVector___delitem__", _wrap_SipMultipartPartVector___delitem__, METH_VARARGS, NULL},
	 { "SipMultipartPartVector___getitem__", _wrap_SipMultipartPartVector___getitem__, METH_VARARGS, NULL},
	 { "SipMultipartPartVector___setitem__", _wrap_SipMultipartPartVector___setitem__, METH_VARARGS, NULL},
	 { "SipMultipartPartVector_pop", _wrap_SipMultipartPartVector_pop, METH_O, NULL},
	 { "SipMultipartPartVector_append", _wrap_SipMultipartPartVector_append, METH_VARARGS, NULL},
	 { "SipMultipartPartVector_empty", _wrap_SipMultipartPartVector_empty, METH_O, NULL},
	 { "SipMultipartPartVector_size", _wrap_SipMultipartPartVector_size, METH_O, NULL},
	 { "SipMultipartPartVector_swap", _wrap_SipMultipartPartVector_swap, METH_VARARGS, NULL},
	 { "SipMultipartPartVector_begin", _wrap_SipMultipartPartVector_begin, METH_O, NULL},
	 { "SipMultipartPartVector_end", _wrap_SipMultipartPartVector_end, METH_O, NULL},
	 { "SipMultipartPartVector_rbegin", _wrap_SipMultipartPartVector_rbegin, METH_O, NULL},
	 { "SipMultipartPartVector_rend", _wrap_SipMultipartPartVector_rend, METH_O, NULL},
	 { "SipMultipartPartVector_clear", _wrap_SipMultipartPartVector_clear, METH_O, NULL},
	 { "SipMultipartPartVector_get_allocator", _wrap_SipMultipartPartVector_get_allocator, METH_O, NULL},
	 { "SipMultipartPartVector_pop_back", _wrap_SipMultipartPartVector_pop_back, METH_O, NULL},
	 { "SipMultipartPartVector_erase", _wrap_SipMultipartPartVector_erase, METH_VARARGS, NULL},
	 { "new_SipMultipartPartVector", _wrap_new_SipMultipartPartVector, METH_VARARGS, NULL},
	 { "SipMultipartPartVector_push_back", _wrap_SipMultipartPartVector_push_back, METH_VARARGS, NULL},
	 { "SipMultipartPartVector_front", _wrap_SipMultipartPartVector_front, METH_O, NULL},
	 { "SipMultipartPartVector_back", _wrap_SipMultipartPartVector_back, METH_O, NULL},
	 { "SipMultipartPartVector_assign", _wrap_SipMultipartPartVector_assign, METH_VARARGS, NULL},
	 { "SipMultipartPartVector_resize", _wrap_SipMultipartPartVector_resize, METH_VARARGS, NULL},
	 { "SipMultipartPartVector_insert", _wrap_SipMultipartPartVector_insert, METH_VARARGS, NULL},
	 { "SipMultipartPartVector_reserve", _wrap_SipMultipartPartVector_reserve, METH_VARARGS, NULL},
	 { "SipMultipartPartVector_capacity", _wrap_SipMultipartPartVector_capacity, METH_O, NULL},
	 { "delete_SipMultipartPartVector", _wrap_delete_SipMultipartPartVector, METH_O, NULL},
	 { "SipMultipartPartVector_swigregister", SipMultipartPartVector_swigregister, METH_O, NULL},
	 { "SipMultipartPartVector_swiginit", SipMultipartPartVector_swiginit, METH_VARARGS, NULL},
	 { "BuddyVector_iterator", _wrap_BuddyVector_iterator, METH_O, NULL},
	 { "BuddyVector___nonzero__", _wrap_BuddyVector___nonzero__, METH_O, NULL},
	 { "BuddyVector___bool__", _wrap_BuddyVector___bool__, METH_O, NULL},
	 { "BuddyVector___len__", _wrap_BuddyVector___len__, METH_O, NULL},
	 { "BuddyVector___getslice__", _wrap_BuddyVector___getslice__, METH_VARARGS, NULL},
	 { "BuddyVector___setslice__", _wrap_BuddyVector___setslice__, METH_VARARGS, NULL},
	 { "BuddyVector___delslice__", _wrap_BuddyVector___delslice__, METH_VARARGS, NULL},
	 { "BuddyVector___delitem__", _wrap_BuddyVector___delitem__, METH_VARARGS, NULL},
	 { "BuddyVector___getitem__", _wrap_BuddyVector___getitem__, METH_VARARGS, NULL},
	 { "BuddyVector___setitem__", _wrap_BuddyVector___setitem__, METH_VARARGS, NULL},
	 { "BuddyVector_pop", _wrap_BuddyVector_pop, METH_O, NULL},
	 { "BuddyVector_append", _wrap_BuddyVector_append, METH_VARARGS, NULL},
	 { "BuddyVector_empty", _wrap_BuddyVector_empty, METH_O, NULL},
	 { "BuddyVector_size", _wrap_BuddyVector_size, METH_O, NULL},
	 { "BuddyVector_swap", _wrap_BuddyVector_swap, METH_VARARGS, NULL},
	 { "BuddyVector_begin", _wrap_BuddyVector_begin, METH_O, NULL},
	 { "BuddyVector_end", _wrap_BuddyVector_end, METH_O, NULL},
	 { "BuddyVector_rbegin", _wrap_BuddyVector_rbegin, METH_O, NULL},
	 { "BuddyVector_rend", _wrap_BuddyVector_rend, METH_O, NULL},
	 { "BuddyVector_clear", _wrap_BuddyVector_clear, METH_O, NULL},
	 { "BuddyVector_get_allocator", _wrap_BuddyVector_get_allocator, METH_O, NULL},
	 { "BuddyVector_pop_back", _wrap_BuddyVector_pop_back, METH_O, NULL},
	 { "BuddyVector_erase", _wrap_BuddyVector_erase, METH_VARARGS, NULL},
	 { "new_BuddyVector", _wrap_new_BuddyVector, METH_VARARGS, NULL},
	 { "BuddyVector_push_back", _wrap_BuddyVector_push_back, METH_VARARGS, NULL},
	 { "BuddyVector_front", _wrap_BuddyVector_front, METH_O, NULL},
	 { "BuddyVector_back", _wrap_BuddyVector_back, METH_O, NULL},
	 { "BuddyVector_assign", _wrap_BuddyVector_assign, METH_VARARGS, NULL},
	 { "BuddyVector_resize", _wrap_BuddyVector_resize, METH_VARARGS, NULL},
	 { "BuddyVector_insert", _wrap_BuddyVector_insert, METH_VARARGS, NULL},
	 { "BuddyVector_reserve", _wrap_BuddyVector_reserve, METH_VARARGS, NULL},
	 { "BuddyVector_capacity", _wrap_BuddyVector_capacity, METH_O, NULL},
	 { "delete_BuddyVector", _wrap_delete_BuddyVector, METH_O, NULL},
	 { "BuddyVector_swigregister", BuddyVector_swigregister, METH_O, NULL},
	 { "BuddyVector_swiginit", BuddyVector_swiginit, METH_VARARGS, NULL},
	 { "BuddyVector2_iterator", _wrap_BuddyVector2_iterator, METH_O, NULL},
	 { "BuddyVector2___nonzero__", _wrap_BuddyVector2___nonzero__, METH_O, NULL},
	 { "BuddyVector2___bool__", _wrap_BuddyVector2___bool__, METH_O, NULL},
	 { "BuddyVector2___len__", _wrap_BuddyVector2___len__, METH_O, NULL},
	 { "BuddyVector2___getslice__", _wrap_BuddyVector2___getslice__, METH_VARARGS, NULL},
	 { "BuddyVector2___setslice__", _wrap_BuddyVector2___setslice__, METH_VARARGS, NULL},
	 { "BuddyVector2___delslice__", _wrap_BuddyVector2___delslice__, METH_VARARGS, NULL},
	 { "BuddyVector2___delitem__", _wrap_BuddyVector2___delitem__, METH_VARARGS, NULL},
	 { "BuddyVector2___getitem__", _wrap_BuddyVector2___getitem__, METH_VARARGS, NULL},
	 { "BuddyVector2___setitem__", _wrap_BuddyVector2___setitem__, METH_VARARGS, NULL},
	 { "BuddyVector2_pop", _wrap_BuddyVector2_pop, METH_O, NULL},
	 { "BuddyVector2_append", _wrap_BuddyVector2_append, METH_VARARGS, NULL},
	 { "BuddyVector2_empty", _wrap_BuddyVector2_empty, METH_O, NULL},
	 { "BuddyVector2_size", _wrap_BuddyVector2_size, METH_O, NULL},
	 { "BuddyVector2_swap", _wrap_BuddyVector2_swap, METH_VARARGS, NULL},
	 { "BuddyVector2_begin", _wrap_BuddyVector2_begin, METH_O, NULL},
	 { "BuddyVector2_end", _wrap_BuddyVector2_end, METH_O, NULL},
	 { "BuddyVector2_rbegin", _wrap_BuddyVector2_rbegin, METH_O, NULL},
	 { "BuddyVector2_rend", _wrap_BuddyVector2_rend, METH_O, NULL},
	 { "BuddyVector2_clear", _wrap_BuddyVector2_clear, METH_O, NULL},
	 { "BuddyVector2_get_allocator", _wrap_BuddyVector2_get_allocator, METH_O, NULL},
	 { "BuddyVector2_pop_back", _wrap_BuddyVector2_pop_back, METH_O, NULL},
	 { "BuddyVector2_erase", _wrap_BuddyVector2_erase, METH_VARARGS, NULL},
	 { "new_BuddyVector2", _wrap_new_BuddyVector2, METH_VARARGS, NULL},
	 { "BuddyVector2_push_back", _wrap_BuddyVector2_push_back, METH_VARARGS, NULL},
	 { "BuddyVector2_front", _wrap_BuddyVector2_front, METH_O, NULL},
	 { "BuddyVector2_back", _wrap_BuddyVector2_back, METH_O, NULL},
	 { "BuddyVector2_assign", _wrap_BuddyVector2_assign, METH_VARARGS, NULL},
	 { "BuddyVector2_resize", _wrap_BuddyVector2_resize, METH_VARARGS, NULL},
	 { "BuddyVector2_insert", _wrap_BuddyVector2_insert, METH_VARARGS, NULL},
	 { "BuddyVector2_reserve", _wrap_BuddyVector2_reserve, METH_VARARGS, NULL},
	 { "BuddyVector2_capacity", _wrap_BuddyVector2_capacity, METH_O, NULL},
	 { "delete_BuddyVector2", _wrap_delete_BuddyVector2, METH_O, NULL},
	 { "BuddyVector2_swigregister", BuddyVector2_swigregister, METH_O, NULL},
	 { "BuddyVector2_swiginit", BuddyVector2_swiginit, METH_VARARGS, NULL},
	 { "AudioMediaVector_iterator", _wrap_AudioMediaVector_iterator, METH_O, NULL},
	 { "AudioMediaVector___nonzero__", _wrap_AudioMediaVector___nonzero__, METH_O, NULL},
	 { "AudioMediaVector___bool__", _wrap_AudioMediaVector___bool__, METH_O, NULL},
	 { "AudioMediaVector___len__", _wrap_AudioMediaVector___len__, METH_O, NULL},
	 { "AudioMediaVector___getslice__", _wrap_AudioMediaVector___getslice__, METH_VARARGS, NULL},
	 { "AudioMediaVector___setslice__", _wrap_AudioMediaVector___setslice__, METH_VARARGS, NULL},
	 { "AudioMediaVector___delslice__", _wrap_AudioMediaVector___delslice__, METH_VARARGS, NULL},
	 { "AudioMediaVector___delitem__", _wrap_AudioMediaVector___delitem__, METH_VARARGS, NULL},
	 { "AudioMediaVector___getitem__", _wrap_AudioMediaVector___getitem__, METH_VARARGS, NULL},
	 { "AudioMediaVector___setitem__", _wrap_AudioMediaVector___setitem__, METH_VARARGS, NULL},
	 { "AudioMediaVector_pop", _wrap_AudioMediaVector_pop, METH_O, NULL},
	 { "AudioMediaVector_append", _wrap_AudioMediaVector_append, METH_VARARGS, NULL},
	 { "AudioMediaVector_empty", _wrap_AudioMediaVector_empty, METH_O, NULL},
	 { "AudioMediaVector_size", _wrap_AudioMediaVector_size, METH_O, NULL},
	 { "AudioMediaVector_swap", _wrap_AudioMediaVector_swap, METH_VARARGS, NULL},
	 { "AudioMediaVector_begin", _wrap_AudioMediaVector_begin, METH_O, NULL},
	 { "AudioMediaVector_end", _wrap_AudioMediaVector_end, METH_O, NULL},
	 { "AudioMediaVector_rbegin", _wrap_AudioMediaVector_rbegin, METH_O, NULL},
	 { "AudioMediaVector_rend", _wrap_AudioMediaVector_rend, METH_O, NULL},
	 { "AudioMediaVector_clear", _wrap_AudioMediaVector_clear, METH_O, NULL},
	 { "AudioMediaVector_get_allocator", _wrap_AudioMediaVector_get_allocator, METH_O, NULL},
	 { "AudioMediaVector_pop_back", _wrap_AudioMediaVector_pop_back, METH_O, NULL},
	 { "AudioMediaVector_erase", _wrap_AudioMediaVector_erase, METH_VARARGS, NULL},
	 { "new_AudioMediaVector", _wrap_new_AudioMediaVector, METH_VARARGS, NULL},
	 { "AudioMediaVector_push_back", _wrap_AudioMediaVector_push_back, METH_VARARGS, NULL},
	 { "AudioMediaVector_front", _wrap_AudioMediaVector_front, METH_O, NULL},
	 { "AudioMediaVector_back", _wrap_AudioMediaVector_back, METH_O, NULL},
	 { "AudioMediaVector_assign", _wrap_AudioMediaVector_assign, METH_VARARGS, NULL},
	 { "AudioMediaVector_resize", _wrap_AudioMediaVector_resize, METH_VARARGS, NULL},
	 { "AudioMediaVector_insert", _wrap_AudioMediaVector_insert, METH_VARARGS, NULL},
	 { "AudioMediaVector_reserve", _wrap_AudioMediaVector_reserve, METH_VARARGS, NULL},
	 { "AudioMediaVector_capacity", _wrap_AudioMediaVector_capacity, METH_O, NULL},
	 { "delete_AudioMediaVector", _wrap_delete_AudioMediaVector, METH_O, NULL},
	 { "AudioMediaVector_swigregister", AudioMediaVector_swigregister, METH_O, NULL},
	 { "AudioMediaVector_swiginit", AudioMediaVector_swiginit, METH_VARARGS, NULL},
	 { "AudioMediaVector2_iterator", _wrap_AudioMediaVector2_iterator, METH_O, NULL},
	 { "AudioMediaVector2___nonzero__", _wrap_AudioMediaVector2___nonzero__, METH_O, NULL},
	 { "AudioMediaVector2___bool__", _wrap_AudioMediaVector2___bool__, METH_O, NULL},
	 { "AudioMediaVector2___len__", _wrap_AudioMediaVector2___len__, METH_O, NULL},
	 { "AudioMediaVector2___getslice__", _wrap_AudioMediaVector2___getslice__, METH_VARARGS, NULL},
	 { "AudioMediaVector2___setslice__", _wrap_AudioMediaVector2___setslice__, METH_VARARGS, NULL},
	 { "AudioMediaVector2___delslice__", _wrap_AudioMediaVector2___delslice__, METH_VARARGS, NULL},
	 { "AudioMediaVector2___delitem__", _wrap_AudioMediaVector2___delitem__, METH_VARARGS, NULL},
	 { "AudioMediaVector2___getitem__", _wrap_AudioMediaVector2___getitem__, METH_VARARGS, NULL},
	 { "AudioMediaVector2___setitem__", _wrap_AudioMediaVector2___setitem__, METH_VARARGS, NULL},
	 { "AudioMediaVector2_pop", _wrap_AudioMediaVector2_pop, METH_O, NULL},
	 { "AudioMediaVector2_append", _wrap_AudioMediaVector2_append, METH_VARARGS, NULL},
	 { "AudioMediaVector2_empty", _wrap_AudioMediaVector2_empty, METH_O, NULL},
	 { "AudioMediaVector2_size", _wrap_AudioMediaVector2_size, METH_O, NULL},
	 { "AudioMediaVector2_swap", _wrap_AudioMediaVector2_swap, METH_VARARGS, NULL},
	 { "AudioMediaVector2_begin", _wrap_AudioMediaVector2_begin, METH_O, NULL},
	 { "AudioMediaVector2_end", _wrap_AudioMediaVector2_end, METH_O, NULL},
	 { "AudioMediaVector2_rbegin", _wrap_AudioMediaVector2_rbegin, METH_O, NULL},
	 { "AudioMediaVector2_rend", _wrap_AudioMediaVector2_rend, METH_O, NULL},
	 { "AudioMediaVector2_clear", _wrap_AudioMediaVector2_clear, METH_O, NULL},
	 { "AudioMediaVector2_get_allocator", _wrap_AudioMediaVector2_get_allocator, METH_O, NULL},
	 { "AudioMediaVector2_pop_back", _wrap_AudioMediaVector2_pop_back, METH_O, NULL},
	 { "AudioMediaVector2_erase", _wrap_AudioMediaVector2_erase, METH_VARARGS, NULL},
	 { "new_AudioMediaVector2", _wrap_new_AudioMediaVector2, METH_VARARGS, NULL},
	 { "AudioMediaVector2_push_back", _wrap_AudioMediaVector2_push_back, METH_VARARGS, NULL},
	 { "AudioMediaVector2_front", _wrap_AudioMediaVector2_front, METH_O, NULL},
	 { "AudioMediaVector2_back", _wrap_AudioMediaVector2_back, METH_O, NULL},
	 { "AudioMediaVector2_assign", _wrap_AudioMediaVector2_assign, METH_VARARGS, NULL},
	 { "AudioMediaVector2_resize", _wrap_AudioMediaVector2_resize, METH_VARARGS, NULL},
	 { "AudioMediaVector2_insert", _wrap_AudioMediaVector2_insert, METH_VARARGS, NULL},
	 { "AudioMediaVector2_reserve", _wrap_AudioMediaVector2_reserve, METH_VARARGS, NULL},
	 { "AudioMediaVector2_capacity", _wrap_AudioMediaVector2_capacity, METH_O, NULL},
	 { "delete_AudioMediaVector2", _wrap_delete_AudioMediaVector2, METH_O, NULL},
	 { "AudioMediaVector2_swigregister", AudioMediaVector2_swigregister, METH_O, NULL},
	 { "AudioMediaVector2_swiginit", AudioMediaVector2_swiginit, METH_VARARGS, NULL},
	 { "VideoMediaVector_iterator", _wrap_VideoMediaVector_iterator, METH_O, NULL},
	 { "VideoMediaVector___nonzero__", _wrap_VideoMediaVector___nonzero__, METH_O, NULL},
	 { "VideoMediaVector___bool__", _wrap_VideoMediaVector___bool__, METH_O, NULL},
	 { "VideoMediaVector___len__", _wrap_VideoMediaVector___len__, METH_O, NULL},
	 { "VideoMediaVector___getslice__", _wrap_VideoMediaVector___getslice__, METH_VARARGS, NULL},
	 { "VideoMediaVector___setslice__", _wrap_VideoMediaVector___setslice__, METH_VARARGS, NULL},
	 { "VideoMediaVector___delslice__", _wrap_VideoMediaVector___delslice__, METH_VARARGS, NULL},
	 { "VideoMediaVector___delitem__", _wrap_VideoMediaVector___delitem__, METH_VARARGS, NULL},
	 { "VideoMediaVector___getitem__", _wrap_VideoMediaVector___getitem__, METH_VARARGS, NULL},
	 { "VideoMediaVector___setitem__", _wrap_VideoMediaVector___setitem__, METH_VARARGS, NULL},
	 { "VideoMediaVector_pop", _wrap_VideoMediaVector_pop, METH_O, NULL},
	 { "VideoMediaVector_append", _wrap_VideoMediaVector_append, METH_VARARGS, NULL},
	 { "VideoMediaVector_empty", _wrap_VideoMediaVector_empty, METH_O, NULL},
	 { "VideoMediaVector_size", _wrap_VideoMediaVector_size, METH_O, NULL},
	 { "VideoMediaVector_swap", _wrap_VideoMediaVector_swap, METH_VARARGS, NULL},
	 { "VideoMediaVector_begin", _wrap_VideoMediaVector_begin, METH_O, NULL},
	 { "VideoMediaVector_end", _wrap_VideoMediaVector_end, METH_O, NULL},
	 { "VideoMediaVector_rbegin", _wrap_VideoMediaVector_rbegin, METH_O, NULL},
	 { "VideoMediaVector_rend", _wrap_VideoMediaVector_rend, METH_O, NULL},
	 { "VideoMediaVector_clear", _wrap_VideoMediaVector_clear, METH_O, NULL},
	 { "VideoMediaVector_get_allocator", _wrap_VideoMediaVector_get_allocator, METH_O, NULL},
	 { "VideoMediaVector_pop_back", _wrap_VideoMediaVector_pop_back, METH_O, NULL},
	 { "VideoMediaVector_erase", _wrap_VideoMediaVector_erase, METH_VARARGS, NULL},
	 { "new_VideoMediaVector", _wrap_new_VideoMediaVector, METH_VARARGS, NULL},
	 { "VideoMediaVector_push_back", _wrap_VideoMediaVector_push_back, METH_VARARGS, NULL},
	 { "VideoMediaVector_front", _wrap_VideoMediaVector_front, METH_O, NULL},
	 { "VideoMediaVector_back", _wrap_VideoMediaVector_back, METH_O, NULL},
	 { "VideoMediaVector_assign", _wrap_VideoMediaVector_assign, METH_VARARGS, NULL},
	 { "VideoMediaVector_resize", _wrap_VideoMediaVector_resize, METH_VARARGS, NULL},
	 { "VideoMediaVector_insert", _wrap_VideoMediaVector_insert, METH_VARARGS, NULL},
	 { "VideoMediaVector_reserve", _wrap_VideoMediaVector_reserve, METH_VARARGS, NULL},
	 { "VideoMediaVector_capacity", _wrap_VideoMediaVector_capacity, METH_O, NULL},
	 { "delete_VideoMediaVector", _wrap_delete_VideoMediaVector, METH_O, NULL},
	 { "VideoMediaVector_swigregister", VideoMediaVector_swigregister, METH_O, NULL},
	 { "VideoMediaVector_swiginit", VideoMediaVector_swiginit, METH_VARARGS, NULL},
	 { "ToneDescVector_iterator", _wrap_ToneDescVector_iterator, METH_O, NULL},
	 { "ToneDescVector___nonzero__", _wrap_ToneDescVector___nonzero__, METH_O, NULL},
	 { "ToneDescVector___bool__", _wrap_ToneDescVector___bool__, METH_O, NULL},
	 { "ToneDescVector___len__", _wrap_ToneDescVector___len__, METH_O, NULL},
	 { "ToneDescVector___getslice__", _wrap_ToneDescVector___getslice__, METH_VARARGS, NULL},
	 { "ToneDescVector___setslice__", _wrap_ToneDescVector___setslice__, METH_VARARGS, NULL},
	 { "ToneDescVector___delslice__", _wrap_ToneDescVector___delslice__, METH_VARARGS, NULL},
	 { "ToneDescVector___delitem__", _wrap_ToneDescVector___delitem__, METH_VARARGS, NULL},
	 { "ToneDescVector___getitem__", _wrap_ToneDescVector___getitem__, METH_VARARGS, NULL},
	 { "ToneDescVector___setitem__", _wrap_ToneDescVector___setitem__, METH_VARARGS, NULL},
	 { "ToneDescVector_pop", _wrap_ToneDescVector_pop, METH_O, NULL},
	 { "ToneDescVector_append", _wrap_ToneDescVector_append, METH_VARARGS, NULL},
	 { "ToneDescVector_empty", _wrap_ToneDescVector_empty, METH_O, NULL},
	 { "ToneDescVector_size", _wrap_ToneDescVector_size, METH_O, NULL},
	 { "ToneDescVector_swap", _wrap_ToneDescVector_swap, METH_VARARGS, NULL},
	 { "ToneDescVector_begin", _wrap_ToneDescVector_begin, METH_O, NULL},
	 { "ToneDescVector_end", _wrap_ToneDescVector_end, METH_O, NULL},
	 { "ToneDescVector_rbegin", _wrap_ToneDescVector_rbegin, METH_O, NULL},
	 { "ToneDescVector_rend", _wrap_ToneDescVector_rend, METH_O, NULL},
	 { "ToneDescVector_clear", _wrap_ToneDescVector_clear, METH_O, NULL},
	 { "ToneDescVector_get_allocator", _wrap_ToneDescVector_get_allocator, METH_O, NULL},
	 { "ToneDescVector_pop_back", _wrap_ToneDescVector_pop_back, METH_O, NULL},
	 { "ToneDescVector_erase", _wrap_ToneDescVector_erase, METH_VARARGS, NULL},
	 { "new_ToneDescVector", _wrap_new_ToneDescVector, METH_VARARGS, NULL},
	 { "ToneDescVector_push_back", _wrap_ToneDescVector_push_back, METH_VARARGS, NULL},
	 { "ToneDescVector_front", _wrap_ToneDescVector_front, METH_O, NULL},
	 { "ToneDescVector_back", _wrap_ToneDescVector_back, METH_O, NULL},
	 { "ToneDescVector_assign", _wrap_ToneDescVector_assign, METH_VARARGS, NULL},
	 { "ToneDescVector_resize", _wrap_ToneDescVector_resize, METH_VARARGS, NULL},
	 { "ToneDescVector_insert", _wrap_ToneDescVector_insert, METH_VARARGS, NULL},
	 { "ToneDescVector_reserve", _wrap_ToneDescVector_reserve, METH_VARARGS, NULL},
	 { "ToneDescVector_capacity", _wrap_ToneDescVector_capacity, METH_O, NULL},
	 { "delete_ToneDescVector", _wrap_delete_ToneDescVector, METH_O, NULL},
	 { "ToneDescVector_swigregister", ToneDescVector_swigregister, METH_O, NULL},
	 { "ToneDescVector_swiginit", ToneDescVector_swiginit, METH_VARARGS, NULL},
	 { "ToneDigitVector_iterator", _wrap_ToneDigitVector_iterator, METH_O, NULL},
	 { "ToneDigitVector___nonzero__", _wrap_ToneDigitVector___nonzero__, METH_O, NULL},
	 { "ToneDigitVector___bool__", _wrap_ToneDigitVector___bool__, METH_O, NULL},
	 { "ToneDigitVector___len__", _wrap_ToneDigitVector___len__, METH_O, NULL},
	 { "ToneDigitVector___getslice__", _wrap_ToneDigitVector___getslice__, METH_VARARGS, NULL},
	 { "ToneDigitVector___setslice__", _wrap_ToneDigitVector___setslice__, METH_VARARGS, NULL},
	 { "ToneDigitVector___delslice__", _wrap_ToneDigitVector___delslice__, METH_VARARGS, NULL},
	 { "ToneDigitVector___delitem__", _wrap_ToneDigitVector___delitem__, METH_VARARGS, NULL},
	 { "ToneDigitVector___getitem__", _wrap_ToneDigitVector___getitem__, METH_VARARGS, NULL},
	 { "ToneDigitVector___setitem__", _wrap_ToneDigitVector___setitem__, METH_VARARGS, NULL},
	 { "ToneDigitVector_pop", _wrap_ToneDigitVector_pop, METH_O, NULL},
	 { "ToneDigitVector_append", _wrap_ToneDigitVector_append, METH_VARARGS, NULL},
	 { "ToneDigitVector_empty", _wrap_ToneDigitVector_empty, METH_O, NULL},
	 { "ToneDigitVector_size", _wrap_ToneDigitVector_size, METH_O, NULL},
	 { "ToneDigitVector_swap", _wrap_ToneDigitVector_swap, METH_VARARGS, NULL},
	 { "ToneDigitVector_begin", _wrap_ToneDigitVector_begin, METH_O, NULL},
	 { "ToneDigitVector_end", _wrap_ToneDigitVector_end, METH_O, NULL},
	 { "ToneDigitVector_rbegin", _wrap_ToneDigitVector_rbegin, METH_O, NULL},
	 { "ToneDigitVector_rend", _wrap_ToneDigitVector_rend, METH_O, NULL},
	 { "ToneDigitVector_clear", _wrap_ToneDigitVector_clear, METH_O, NULL},
	 { "ToneDigitVector_get_allocator", _wrap_ToneDigitVector_get_allocator, METH_O, NULL},
	 { "ToneDigitVector_pop_back", _wrap_ToneDigitVector_pop_back, METH_O, NULL},
	 { "ToneDigitVector_erase", _wrap_ToneDigitVector_erase, METH_VARARGS, NULL},
	 { "new_ToneDigitVector", _wrap_new_ToneDigitVector, METH_VARARGS, NULL},
	 { "ToneDigitVector_push_back", _wrap_ToneDigitVector_push_back, METH_VARARGS, NULL},
	 { "ToneDigitVector_front", _wrap_ToneDigitVector_front, METH_O, NULL},
	 { "ToneDigitVector_back", _wrap_ToneDigitVector_back, METH_O, NULL},
	 { "ToneDigitVector_assign", _wrap_ToneDigitVector_assign, METH_VARARGS, NULL},
	 { "ToneDigitVector_resize", _wrap_ToneDigitVector_resize, METH_VARARGS, NULL},
	 { "ToneDigitVector_insert", _wrap_ToneDigitVector_insert, METH_VARARGS, NULL},
	 { "ToneDigitVector_reserve", _wrap_ToneDigitVector_reserve, METH_VARARGS, NULL},
	 { "ToneDigitVector_capacity", _wrap_ToneDigitVector_capacity, METH_O, NULL},
	 { "delete_ToneDigitVector", _wrap_delete_ToneDigitVector, METH_O, NULL},
	 { "ToneDigitVector_swigregister", ToneDigitVector_swigregister, METH_O, NULL},
	 { "ToneDigitVector_swiginit", ToneDigitVector_swiginit, METH_VARARGS, NULL},
	 { "ToneDigitMapVector_iterator", _wrap_ToneDigitMapVector_iterator, METH_O, NULL},
	 { "ToneDigitMapVector___nonzero__", _wrap_ToneDigitMapVector___nonzero__, METH_O, NULL},
	 { "ToneDigitMapVector___bool__", _wrap_ToneDigitMapVector___bool__, METH_O, NULL},
	 { "ToneDigitMapVector___len__", _wrap_ToneDigitMapVector___len__, METH_O, NULL},
	 { "ToneDigitMapVector___getslice__", _wrap_ToneDigitMapVector___getslice__, METH_VARARGS, NULL},
	 { "ToneDigitMapVector___setslice__", _wrap_ToneDigitMapVector___setslice__, METH_VARARGS, NULL},
	 { "ToneDigitMapVector___delslice__", _wrap_ToneDigitMapVector___delslice__, METH_VARARGS, NULL},
	 { "ToneDigitMapVector___delitem__", _wrap_ToneDigitMapVector___delitem__, METH_VARARGS, NULL},
	 { "ToneDigitMapVector___getitem__", _wrap_ToneDigitMapVector___getitem__, METH_VARARGS, NULL},
	 { "ToneDigitMapVector___setitem__", _wrap_ToneDigitMapVector___setitem__, METH_VARARGS, NULL},
	 { "ToneDigitMapVector_pop", _wrap_ToneDigitMapVector_pop, METH_O, NULL},
	 { "ToneDigitMapVector_append", _wrap_ToneDigitMapVector_append, METH_VARARGS, NULL},
	 { "ToneDigitMapVector_empty", _wrap_ToneDigitMapVector_empty, METH_O, NULL},
	 { "ToneDigitMapVector_size", _wrap_ToneDigitMapVector_size, METH_O, NULL},
	 { "ToneDigitMapVector_swap", _wrap_ToneDigitMapVector_swap, METH_VARARGS, NULL},
	 { "ToneDigitMapVector_begin", _wrap_ToneDigitMapVector_begin, METH_O, NULL},
	 { "ToneDigitMapVector_end", _wrap_ToneDigitMapVector_end, METH_O, NULL},
	 { "ToneDigitMapVector_rbegin", _wrap_ToneDigitMapVector_rbegin, METH_O, NULL},
	 { "ToneDigitMapVector_rend", _wrap_ToneDigitMapVector_rend, METH_O, NULL},
	 { "ToneDigitMapVector_clear", _wrap_ToneDigitMapVector_clear, METH_O, NULL},
	 { "ToneDigitMapVector_get_allocator", _wrap_ToneDigitMapVector_get_allocator, METH_O, NULL},
	 { "ToneDigitMapVector_pop_back", _wrap_ToneDigitMapVector_pop_back, METH_O, NULL},
	 { "ToneDigitMapVector_erase", _wrap_ToneDigitMapVector_erase, METH_VARARGS, NULL},
	 { "new_ToneDigitMapVector", _wrap_new_ToneDigitMapVector, METH_VARARGS, NULL},
	 { "ToneDigitMapVector_push_back", _wrap_ToneDigitMapVector_push_back, METH_VARARGS, NULL},
	 { "ToneDigitMapVector_front", _wrap_ToneDigitMapVector_front, METH_O, NULL},
	 { "ToneDigitMapVector_back", _wrap_ToneDigitMapVector_back, METH_O, NULL},
	 { "ToneDigitMapVector_assign", _wrap_ToneDigitMapVector_assign, METH_VARARGS, NULL},
	 { "ToneDigitMapVector_resize", _wrap_ToneDigitMapVector_resize, METH_VARARGS, NULL},
	 { "ToneDigitMapVector_insert", _wrap_ToneDigitMapVector_insert, METH_VARARGS, NULL},
	 { "ToneDigitMapVector_reserve", _wrap_ToneDigitMapVector_reserve, METH_VARARGS, NULL},
	 { "ToneDigitMapVector_capacity", _wrap_ToneDigitMapVector_capacity, METH_O, NULL},
	 { "delete_ToneDigitMapVector", _wrap_delete_ToneDigitMapVector, METH_O, NULL},
	 { "ToneDigitMapVector_swigregister", ToneDigitMapVector_swigregister, METH_O, NULL},
	 { "ToneDigitMapVector_swiginit", ToneDigitMapVector_swiginit, METH_VARARGS, NULL},
	 { "AudioDevInfoVector_iterator", _wrap_AudioDevInfoVector_iterator, METH_O, NULL},
	 { "AudioDevInfoVector___nonzero__", _wrap_AudioDevInfoVector___nonzero__, METH_O, NULL},
	 { "AudioDevInfoVector___bool__", _wrap_AudioDevInfoVector___bool__, METH_O, NULL},
	 { "AudioDevInfoVector___len__", _wrap_AudioDevInfoVector___len__, METH_O, NULL},
	 { "AudioDevInfoVector___getslice__", _wrap_AudioDevInfoVector___getslice__, METH_VARARGS, NULL},
	 { "AudioDevInfoVector___setslice__", _wrap_AudioDevInfoVector___setslice__, METH_VARARGS, NULL},
	 { "AudioDevInfoVector___delslice__", _wrap_AudioDevInfoVector___delslice__, METH_VARARGS, NULL},
	 { "AudioDevInfoVector___delitem__", _wrap_AudioDevInfoVector___delitem__, METH_VARARGS, NULL},
	 { "AudioDevInfoVector___getitem__", _wrap_AudioDevInfoVector___getitem__, METH_VARARGS, NULL},
	 { "AudioDevInfoVector___setitem__", _wrap_AudioDevInfoVector___setitem__, METH_VARARGS, NULL},
	 { "AudioDevInfoVector_pop", _wrap_AudioDevInfoVector_pop, METH_O, NULL},
	 { "AudioDevInfoVector_append", _wrap_AudioDevInfoVector_append, METH_VARARGS, NULL},
	 { "AudioDevInfoVector_empty", _wrap_AudioDevInfoVector_empty, METH_O, NULL},
	 { "AudioDevInfoVector_size", _wrap_AudioDevInfoVector_size, METH_O, NULL},
	 { "AudioDevInfoVector_swap", _wrap_AudioDevInfoVector_swap, METH_VARARGS, NULL},
	 { "AudioDevInfoVector_begin", _wrap_AudioDevInfoVector_begin, METH_O, NULL},
	 { "AudioDevInfoVector_end", _wrap_AudioDevInfoVector_end, METH_O, NULL},
	 { "AudioDevInfoVector_rbegin", _wrap_AudioDevInfoVector_rbegin, METH_O, NULL},
	 { "AudioDevInfoVector_rend", _wrap_AudioDevInfoVector_rend, METH_O, NULL},
	 { "AudioDevInfoVector_clear", _wrap_AudioDevInfoVector_clear, METH_O, NULL},
	 { "AudioDevInfoVector_get_allocator", _wrap_AudioDevInfoVector_get_allocator, METH_O, NULL},
	 { "AudioDevInfoVector_pop_back", _wrap_AudioDevInfoVector_pop_back, METH_O, NULL},
	 { "AudioDevInfoVector_erase", _wrap_AudioDevInfoVector_erase, METH_VARARGS, NULL},
	 { "new_AudioDevInfoVector", _wrap_new_AudioDevInfoVector, METH_VARARGS, NULL},
	 { "AudioDevInfoVector_push_back", _wrap_AudioDevInfoVector_push_back, METH_VARARGS, NULL},
	 { "AudioDevInfoVector_front", _wrap_AudioDevInfoVector_front, METH_O, NULL},
	 { "AudioDevInfoVector_back", _wrap_AudioDevInfoVector_back, METH_O, NULL},
	 { "AudioDevInfoVector_assign", _wrap_AudioDevInfoVector_assign, METH_VARARGS, NULL},
	 { "AudioDevInfoVector_resize", _wrap_AudioDevInfoVector_resize, METH_VARARGS, NULL},
	 { "AudioDevInfoVector_insert", _wrap_AudioDevInfoVector_insert, METH_VARARGS, NULL},
	 { "AudioDevInfoVector_reserve", _wrap_AudioDevInfoVector_reserve, METH_VARARGS, NULL},
	 { "AudioDevInfoVector_capacity", _wrap_AudioDevInfoVector_capacity, METH_O, NULL},
	 { "delete_AudioDevInfoVector", _wrap_delete_AudioDevInfoVector, METH_O, NULL},
	 { "AudioDevInfoVector_swigregister", AudioDevInfoVector_swigregister, METH_O, NULL},
	 { "AudioDevInfoVector_swiginit", AudioDevInfoVector_swiginit, METH_VARARGS, NULL},
	 { "AudioDevInfoVector2_iterator", _wrap_AudioDevInfoVector2_iterator, METH_O, NULL},
	 { "AudioDevInfoVector2___nonzero__", _wrap_AudioDevInfoVector2___nonzero__, METH_O, NULL},
	 { "AudioDevInfoVector2___bool__", _wrap_AudioDevInfoVector2___bool__, METH_O, NULL},
	 { "AudioDevInfoVector2___len__", _wrap_AudioDevInfoVector2___len__, METH_O, NULL},
	 { "AudioDevInfoVector2___getslice__", _wrap_AudioDevInfoVector2___getslice__, METH_VARARGS, NULL},
	 { "AudioDevInfoVector2___setslice__", _wrap_AudioDevInfoVector2___setslice__, METH_VARARGS, NULL},
	 { "AudioDevInfoVector2___delslice__", _wrap_AudioDevInfoVector2___delslice__, METH_VARARGS, NULL},
	 { "AudioDevInfoVector2___delitem__", _wrap_AudioDevInfoVector2___delitem__, METH_VARARGS, NULL},
	 { "AudioDevInfoVector2___getitem__", _wrap_AudioDevInfoVector2___getitem__, METH_VARARGS, NULL},
	 { "AudioDevInfoVector2___setitem__", _wrap_AudioDevInfoVector2___setitem__, METH_VARARGS, NULL},
	 { "AudioDevInfoVector2_pop", _wrap_AudioDevInfoVector2_pop, METH_O, NULL},
	 { "AudioDevInfoVector2_append", _wrap_AudioDevInfoVector2_append, METH_VARARGS, NULL},
	 { "AudioDevInfoVector2_empty", _wrap_AudioDevInfoVector2_empty, METH_O, NULL},
	 { "AudioDevInfoVector2_size", _wrap_AudioDevInfoVector2_size, METH_O, NULL},
	 { "AudioDevInfoVector2_swap", _wrap_AudioDevInfoVector2_swap, METH_VARARGS, NULL},
	 { "AudioDevInfoVector2_begin", _wrap_AudioDevInfoVector2_begin, METH_O, NULL},
	 { "AudioDevInfoVector2_end", _wrap_AudioDevInfoVector2_end, METH_O, NULL},
	 { "AudioDevInfoVector2_rbegin", _wrap_AudioDevInfoVector2_rbegin, METH_O, NULL},
	 { "AudioDevInfoVector2_rend", _wrap_AudioDevInfoVector2_rend, METH_O, NULL},
	 { "AudioDevInfoVector2_clear", _wrap_AudioDevInfoVector2_clear, METH_O, NULL},
	 { "AudioDevInfoVector2_get_allocator", _wrap_AudioDevInfoVector2_get_allocator, METH_O, NULL},
	 { "AudioDevInfoVector2_pop_back", _wrap_AudioDevInfoVector2_pop_back, METH_O, NULL},
	 { "AudioDevInfoVector2_erase", _wrap_AudioDevInfoVector2_erase, METH_VARARGS, NULL},
	 { "new_AudioDevInfoVector2", _wrap_new_AudioDevInfoVector2, METH_VARARGS, NULL},
	 { "AudioDevInfoVector2_push_back", _wrap_AudioDevInfoVector2_push_back, METH_VARARGS, NULL},
	 { "AudioDevInfoVector2_front", _wrap_AudioDevInfoVector2_front, METH_O, NULL},
	 { "AudioDevInfoVector2_back", _wrap_AudioDevInfoVector2_back, METH_O, NULL},
	 { "AudioDevInfoVector2_assign", _wrap_AudioDevInfoVector2_assign, METH_VARARGS, NULL},
	 { "AudioDevInfoVector2_resize", _wrap_AudioDevInfoVector2_resize, METH_VARARGS, NULL},
	 { "AudioDevInfoVector2_insert", _wrap_AudioDevInfoVector2_insert, METH_VARARGS, NULL},
	 { "AudioDevInfoVector2_reserve", _wrap_AudioDevInfoVector2_reserve, METH_VARARGS, NULL},
	 { "AudioDevInfoVector2_capacity", _wrap_AudioDevInfoVector2_capacity, METH_O, NULL},
	 { "delete_AudioDevInfoVector2", _wrap_delete_AudioDevInfoVector2, METH_O, NULL},
	 { "AudioDevInfoVector2_swigregister", AudioDevInfoVector2_swigregister, METH_O, NULL},
	 { "AudioDevInfoVector2_swiginit", AudioDevInfoVector2_swiginit, METH_VARARGS, NULL},
	 { "CodecInfoVector_iterator", _wrap_CodecInfoVector_iterator, METH_O, NULL},
	 { "CodecInfoVector___nonzero__", _wrap_CodecInfoVector___nonzero__, METH_O, NULL},
	 { "CodecInfoVector___bool__", _wrap_CodecInfoVector___bool__, METH_O, NULL},
	 { "CodecInfoVector___len__", _wrap_CodecInfoVector___len__, METH_O, NULL},
	 { "CodecInfoVector___getslice__", _wrap_CodecInfoVector___getslice__, METH_VARARGS, NULL},
	 { "CodecInfoVector___setslice__", _wrap_CodecInfoVector___setslice__, METH_VARARGS, NULL},
	 { "CodecInfoVector___delslice__", _wrap_CodecInfoVector___delslice__, METH_VARARGS, NULL},
	 { "CodecInfoVector___delitem__", _wrap_CodecInfoVector___delitem__, METH_VARARGS, NULL},
	 { "CodecInfoVector___getitem__", _wrap_CodecInfoVector___getitem__, METH_VARARGS, NULL},
	 { "CodecInfoVector___setitem__", _wrap_CodecInfoVector___setitem__, METH_VARARGS, NULL},
	 { "CodecInfoVector_pop", _wrap_CodecInfoVector_pop, METH_O, NULL},
	 { "CodecInfoVector_append", _wrap_CodecInfoVector_append, METH_VARARGS, NULL},
	 { "CodecInfoVector_empty", _wrap_CodecInfoVector_empty, METH_O, NULL},
	 { "CodecInfoVector_size", _wrap_CodecInfoVector_size, METH_O, NULL},
	 { "CodecInfoVector_swap", _wrap_CodecInfoVector_swap, METH_VARARGS, NULL},
	 { "CodecInfoVector_begin", _wrap_CodecInfoVector_begin, METH_O, NULL},
	 { "CodecInfoVector_end", _wrap_CodecInfoVector_end, METH_O, NULL},
	 { "CodecInfoVector_rbegin", _wrap_CodecInfoVector_rbegin, METH_O, NULL},
	 { "CodecInfoVector_rend", _wrap_CodecInfoVector_rend, METH_O, NULL},
	 { "CodecInfoVector_clear", _wrap_CodecInfoVector_clear, METH_O, NULL},
	 { "CodecInfoVector_get_allocator", _wrap_CodecInfoVector_get_allocator, METH_O, NULL},
	 { "CodecInfoVector_pop_back", _wrap_CodecInfoVector_pop_back, METH_O, NULL},
	 { "CodecInfoVector_erase", _wrap_CodecInfoVector_erase, METH_VARARGS, NULL},
	 { "new_CodecInfoVector", _wrap_new_CodecInfoVector, METH_VARARGS, NULL},
	 { "CodecInfoVector_push_back", _wrap_CodecInfoVector_push_back, METH_VARARGS, NULL},
	 { "CodecInfoVector_front", _wrap_CodecInfoVector_front, METH_O, NULL},
	 { "CodecInfoVector_back", _wrap_CodecInfoVector_back, METH_O, NULL},
	 { "CodecInfoVector_assign", _wrap_CodecInfoVector_assign, METH_VARARGS, NULL},
	 { "CodecInfoVector_resize", _wrap_CodecInfoVector_resize, METH_VARARGS, NULL},
	 { "CodecInfoVector_insert", _wrap_CodecInfoVector_insert, METH_VARARGS, NULL},
	 { "CodecInfoVector_reserve", _wrap_CodecInfoVector_reserve, METH_VARARGS, NULL},
	 { "CodecInfoVector_capacity", _wrap_CodecInfoVector_capacity, METH_O, NULL},
	 { "delete_CodecInfoVector", _wrap_delete_CodecInfoVector, METH_O, NULL},
	 { "CodecInfoVector_swigregister", CodecInfoVector_swigregister, METH_O, NULL},
	 { "CodecInfoVector_swiginit", CodecInfoVector_swiginit, METH_VARARGS, NULL},
	 { "CodecInfoVector2_iterator", _wrap_CodecInfoVector2_iterator, METH_O, NULL},
	 { "CodecInfoVector2___nonzero__", _wrap_CodecInfoVector2___nonzero__, METH_O, NULL},
	 { "CodecInfoVector2___bool__", _wrap_CodecInfoVector2___bool__, METH_O, NULL},
	 { "CodecInfoVector2___len__", _wrap_CodecInfoVector2___len__, METH_O, NULL},
	 { "CodecInfoVector2___getslice__", _wrap_CodecInfoVector2___getslice__, METH_VARARGS, NULL},
	 { "CodecInfoVector2___setslice__", _wrap_CodecInfoVector2___setslice__, METH_VARARGS, NULL},
	 { "CodecInfoVector2___delslice__", _wrap_CodecInfoVector2___delslice__, METH_VARARGS, NULL},
	 { "CodecInfoVector2___delitem__", _wrap_CodecInfoVector2___delitem__, METH_VARARGS, NULL},
	 { "CodecInfoVector2___getitem__", _wrap_CodecInfoVector2___getitem__, METH_VARARGS, NULL},
	 { "CodecInfoVector2___setitem__", _wrap_CodecInfoVector2___setitem__, METH_VARARGS, NULL},
	 { "CodecInfoVector2_pop", _wrap_CodecInfoVector2_pop, METH_O, NULL},
	 { "CodecInfoVector2_append", _wrap_CodecInfoVector2_append, METH_VARARGS, NULL},
	 { "CodecInfoVector2_empty", _wrap_CodecInfoVector2_empty, METH_O, NULL},
	 { "CodecInfoVector2_size", _wrap_CodecInfoVector2_size, METH_O, NULL},
	 { "CodecInfoVector2_swap", _wrap_CodecInfoVector2_swap, METH_VARARGS, NULL},
	 { "CodecInfoVector2_begin", _wrap_CodecInfoVector2_begin, METH_O, NULL},
	 { "CodecInfoVector2_end", _wrap_CodecInfoVector2_end, METH_O, NULL},
	 { "CodecInfoVector2_rbegin", _wrap_CodecInfoVector2_rbegin, METH_O, NULL},
	 { "CodecInfoVector2_rend", _wrap_CodecInfoVector2_rend, METH_O, NULL},
	 { "CodecInfoVector2_clear", _wrap_CodecInfoVector2_clear, METH_O, NULL},
	 { "CodecInfoVector2_get_allocator", _wrap_CodecInfoVector2_get_allocator, METH_O, NULL},
	 { "CodecInfoVector2_pop_back", _wrap_CodecInfoVector2_pop_back, METH_O, NULL},
	 { "CodecInfoVector2_erase", _wrap_CodecInfoVector2_erase, METH_VARARGS, NULL},
	 { "new_CodecInfoVector2", _wrap_new_CodecInfoVector2, METH_VARARGS, NULL},
	 { "CodecInfoVector2_push_back", _wrap_CodecInfoVector2_push_back, METH_VARARGS, NULL},
	 { "CodecInfoVector2_front", _wrap_CodecInfoVector2_front, METH_O, NULL},
	 { "CodecInfoVector2_back", _wrap_CodecInfoVector2_back, METH_O, NULL},
	 { "CodecInfoVector2_assign", _wrap_CodecInfoVector2_assign, METH_VARARGS, NULL},
	 { "CodecInfoVector2_resize", _wrap_CodecInfoVector2_resize, METH_VARARGS, NULL},
	 { "CodecInfoVector2_insert", _wrap_CodecInfoVector2_insert, METH_VARARGS, NULL},
	 { "CodecInfoVector2_reserve", _wrap_CodecInfoVector2_reserve, METH_VARARGS, NULL},
	 { "CodecInfoVector2_capacity", _wrap_CodecInfoVector2_capacity, METH_O, NULL},
	 { "delete_CodecInfoVector2", _wrap_delete_CodecInfoVector2, METH_O, NULL},
	 { "CodecInfoVector2_swigregister", CodecInfoVector2_swigregister, METH_O, NULL},
	 { "CodecInfoVector2_swiginit", CodecInfoVector2_swiginit, METH_VARARGS, NULL},
	 { "VideoDevInfoVector_iterator", _wrap_VideoDevInfoVector_iterator, METH_O, NULL},
	 { "VideoDevInfoVector___nonzero__", _wrap_VideoDevInfoVector___nonzero__, METH_O, NULL},
	 { "VideoDevInfoVector___bool__", _wrap_VideoDevInfoVector___bool__, METH_O, NULL},
	 { "VideoDevInfoVector___len__", _wrap_VideoDevInfoVector___len__, METH_O, NULL},
	 { "VideoDevInfoVector___getslice__", _wrap_VideoDevInfoVector___getslice__, METH_VARARGS, NULL},
	 { "VideoDevInfoVector___setslice__", _wrap_VideoDevInfoVector___setslice__, METH_VARARGS, NULL},
	 { "VideoDevInfoVector___delslice__", _wrap_VideoDevInfoVector___delslice__, METH_VARARGS, NULL},
	 { "VideoDevInfoVector___delitem__", _wrap_VideoDevInfoVector___delitem__, METH_VARARGS, NULL},
	 { "VideoDevInfoVector___getitem__", _wrap_VideoDevInfoVector___getitem__, METH_VARARGS, NULL},
	 { "VideoDevInfoVector___setitem__", _wrap_VideoDevInfoVector___setitem__, METH_VARARGS, NULL},
	 { "VideoDevInfoVector_pop", _wrap_VideoDevInfoVector_pop, METH_O, NULL},
	 { "VideoDevInfoVector_append", _wrap_VideoDevInfoVector_append, METH_VARARGS, NULL},
	 { "VideoDevInfoVector_empty", _wrap_VideoDevInfoVector_empty, METH_O, NULL},
	 { "VideoDevInfoVector_size", _wrap_VideoDevInfoVector_size, METH_O, NULL},
	 { "VideoDevInfoVector_swap", _wrap_VideoDevInfoVector_swap, METH_VARARGS, NULL},
	 { "VideoDevInfoVector_begin", _wrap_VideoDevInfoVector_begin, METH_O, NULL},
	 { "VideoDevInfoVector_end", _wrap_VideoDevInfoVector_end, METH_O, NULL},
	 { "VideoDevInfoVector_rbegin", _wrap_VideoDevInfoVector_rbegin, METH_O, NULL},
	 { "VideoDevInfoVector_rend", _wrap_VideoDevInfoVector_rend, METH_O, NULL},
	 { "VideoDevInfoVector_clear", _wrap_VideoDevInfoVector_clear, METH_O, NULL},
	 { "VideoDevInfoVector_get_allocator", _wrap_VideoDevInfoVector_get_allocator, METH_O, NULL},
	 { "VideoDevInfoVector_pop_back", _wrap_VideoDevInfoVector_pop_back, METH_O, NULL},
	 { "VideoDevInfoVector_erase", _wrap_VideoDevInfoVector_erase, METH_VARARGS, NULL},
	 { "new_VideoDevInfoVector", _wrap_new_VideoDevInfoVector, METH_VARARGS, NULL},
	 { "VideoDevInfoVector_push_back", _wrap_VideoDevInfoVector_push_back, METH_VARARGS, NULL},
	 { "VideoDevInfoVector_front", _wrap_VideoDevInfoVector_front, METH_O, NULL},
	 { "VideoDevInfoVector_back", _wrap_VideoDevInfoVector_back, METH_O, NULL},
	 { "VideoDevInfoVector_assign", _wrap_VideoDevInfoVector_assign, METH_VARARGS, NULL},
	 { "VideoDevInfoVector_resize", _wrap_VideoDevInfoVector_resize, METH_VARARGS, NULL},
	 { "VideoDevInfoVector_insert", _wrap_VideoDevInfoVector_insert, METH_VARARGS, NULL},
	 { "VideoDevInfoVector_reserve", _wrap_VideoDevInfoVector_reserve, METH_VARARGS, NULL},
	 { "VideoDevInfoVector_capacity", _wrap_VideoDevInfoVector_capacity, METH_O, NULL},
	 { "delete_VideoDevInfoVector", _wrap_delete_VideoDevInfoVector, METH_O, NULL},
	 { "VideoDevInfoVector_swigregister", VideoDevInfoVector_swigregister, METH_O, NULL},
	 { "VideoDevInfoVector_swiginit", VideoDevInfoVector_swiginit, METH_VARARGS, NULL},
	 { "VideoDevInfoVector2_iterator", _wrap_VideoDevInfoVector2_iterator, METH_O, NULL},
	 { "VideoDevInfoVector2___nonzero__", _wrap_VideoDevInfoVector2___nonzero__, METH_O, NULL},
	 { "VideoDevInfoVector2___bool__", _wrap_VideoDevInfoVector2___bool__, METH_O, NULL},
	 { "VideoDevInfoVector2___len__", _wrap_VideoDevInfoVector2___len__, METH_O, NULL},
	 { "VideoDevInfoVector2___getslice__", _wrap_VideoDevInfoVector2___getslice__, METH_VARARGS, NULL},
	 { "VideoDevInfoVector2___setslice__", _wrap_VideoDevInfoVector2___setslice__, METH_VARARGS, NULL},
	 { "VideoDevInfoVector2___delslice__", _wrap_VideoDevInfoVector2___delslice__, METH_VARARGS, NULL},
	 { "VideoDevInfoVector2___delitem__", _wrap_VideoDevInfoVector2___delitem__, METH_VARARGS, NULL},
	 { "VideoDevInfoVector2___getitem__", _wrap_VideoDevInfoVector2___getitem__, METH_VARARGS, NULL},
	 { "VideoDevInfoVector2___setitem__", _wrap_VideoDevInfoVector2___setitem__, METH_VARARGS, NULL},
	 { "VideoDevInfoVector2_pop", _wrap_VideoDevInfoVector2_pop, METH_O, NULL},
	 { "VideoDevInfoVector2_append", _wrap_VideoDevInfoVector2_append, METH_VARARGS, NULL},
	 { "VideoDevInfoVector2_empty", _wrap_VideoDevInfoVector2_empty, METH_O, NULL},
	 { "VideoDevInfoVector2_size", _wrap_VideoDevInfoVector2_size, METH_O, NULL},
	 { "VideoDevInfoVector2_swap", _wrap_VideoDevInfoVector2_swap, METH_VARARGS, NULL},
	 { "VideoDevInfoVector2_begin", _wrap_VideoDevInfoVector2_begin, METH_O, NULL},
	 { "VideoDevInfoVector2_end", _wrap_VideoDevInfoVector2_end, METH_O, NULL},
	 { "VideoDevInfoVector2_rbegin", _wrap_VideoDevInfoVector2_rbegin, METH_O, NULL},
	 { "VideoDevInfoVector2_rend", _wrap_VideoDevInfoVector2_rend, METH_O, NULL},
	 { "VideoDevInfoVector2_clear", _wrap_VideoDevInfoVector2_clear, METH_O, NULL},
	 { "VideoDevInfoVector2_get_allocator", _wrap_VideoDevInfoVector2_get_allocator, METH_O, NULL},
	 { "VideoDevInfoVector2_pop_back", _wrap_VideoDevInfoVector2_pop_back, METH_O, NULL},
	 { "VideoDevInfoVector2_erase", _wrap_VideoDevInfoVector2_erase, METH_VARARGS, NULL},
	 { "new_VideoDevInfoVector2", _wrap_new_VideoDevInfoVector2, METH_VARARGS, NULL},
	 { "VideoDevInfoVector2_push_back", _wrap_VideoDevInfoVector2_push_back, METH_VARARGS, NULL},
	 { "VideoDevInfoVector2_front", _wrap_VideoDevInfoVector2_front, METH_O, NULL},
	 { "VideoDevInfoVector2_back", _wrap_VideoDevInfoVector2_back, METH_O, NULL},
	 { "VideoDevInfoVector2_assign", _wrap_VideoDevInfoVector2_assign, METH_VARARGS, NULL},
	 { "VideoDevInfoVector2_resize", _wrap_VideoDevInfoVector2_resize, METH_VARARGS, NULL},
	 { "VideoDevInfoVector2_insert", _wrap_VideoDevInfoVector2_insert, METH_VARARGS, NULL},
	 { "VideoDevInfoVector2_reserve", _wrap_VideoDevInfoVector2_reserve, METH_VARARGS, NULL},
	 { "VideoDevInfoVector2_capacity", _wrap_VideoDevInfoVector2_capacity, METH_O, NULL},
	 { "delete_VideoDevInfoVector2", _wrap_delete_VideoDevInfoVector2, METH_O, NULL},
	 { "VideoDevInfoVector2_swigregister", VideoDevInfoVector2_swigregister, METH_O, NULL},
	 { "VideoDevInfoVector2_swiginit", VideoDevInfoVector2_swiginit, METH_VARARGS, NULL},
	 { "CodecFmtpVector_iterator", _wrap_CodecFmtpVector_iterator, METH_O, NULL},
	 { "CodecFmtpVector___nonzero__", _wrap_CodecFmtpVector___nonzero__, METH_O, NULL},
	 { "CodecFmtpVector___bool__", _wrap_CodecFmtpVector___bool__, METH_O, NULL},
	 { "CodecFmtpVector___len__", _wrap_CodecFmtpVector___len__, METH_O, NULL},
	 { "CodecFmtpVector___getslice__", _wrap_CodecFmtpVector___getslice__, METH_VARARGS, NULL},
	 { "CodecFmtpVector___setslice__", _wrap_CodecFmtpVector___setslice__, METH_VARARGS, NULL},
	 { "CodecFmtpVector___delslice__", _wrap_CodecFmtpVector___delslice__, METH_VARARGS, NULL},
	 { "CodecFmtpVector___delitem__", _wrap_CodecFmtpVector___delitem__, METH_VARARGS, NULL},
	 { "CodecFmtpVector___getitem__", _wrap_CodecFmtpVector___getitem__, METH_VARARGS, NULL},
	 { "CodecFmtpVector___setitem__", _wrap_CodecFmtpVector___setitem__, METH_VARARGS, NULL},
	 { "CodecFmtpVector_pop", _wrap_CodecFmtpVector_pop, METH_O, NULL},
	 { "CodecFmtpVector_append", _wrap_CodecFmtpVector_append, METH_VARARGS, NULL},
	 { "CodecFmtpVector_empty", _wrap_CodecFmtpVector_empty, METH_O, NULL},
	 { "CodecFmtpVector_size", _wrap_CodecFmtpVector_size, METH_O, NULL},
	 { "CodecFmtpVector_swap", _wrap_CodecFmtpVector_swap, METH_VARARGS, NULL},
	 { "CodecFmtpVector_begin", _wrap_CodecFmtpVector_begin, METH_O, NULL},
	 { "CodecFmtpVector_end", _wrap_CodecFmtpVector_end, METH_O, NULL},
	 { "CodecFmtpVector_rbegin", _wrap_CodecFmtpVector_rbegin, METH_O, NULL},
	 { "CodecFmtpVector_rend", _wrap_CodecFmtpVector_rend, METH_O, NULL},
	 { "CodecFmtpVector_clear", _wrap_CodecFmtpVector_clear, METH_O, NULL},
	 { "CodecFmtpVector_get_allocator", _wrap_CodecFmtpVector_get_allocator, METH_O, NULL},
	 { "CodecFmtpVector_pop_back", _wrap_CodecFmtpVector_pop_back, METH_O, NULL},
	 { "CodecFmtpVector_erase", _wrap_CodecFmtpVector_erase, METH_VARARGS, NULL},
	 { "new_CodecFmtpVector", _wrap_new_CodecFmtpVector, METH_VARARGS, NULL},
	 { "CodecFmtpVector_push_back", _wrap_CodecFmtpVector_push_back, METH_VARARGS, NULL},
	 { "CodecFmtpVector_front", _wrap_CodecFmtpVector_front, METH_O, NULL},
	 { "CodecFmtpVector_back", _wrap_CodecFmtpVector_back, METH_O, NULL},
	 { "CodecFmtpVector_assign", _wrap_CodecFmtpVector_assign, METH_VARARGS, NULL},
	 { "CodecFmtpVector_resize", _wrap_CodecFmtpVector_resize, METH_VARARGS, NULL},
	 { "CodecFmtpVector_insert", _wrap_CodecFmtpVector_insert, METH_VARARGS, NULL},
	 { "CodecFmtpVector_reserve", _wrap_CodecFmtpVector_reserve, METH_VARARGS, NULL},
	 { "CodecFmtpVector_capacity", _wrap_CodecFmtpVector_capacity, METH_O, NULL},
	 { "delete_CodecFmtpVector", _wrap_delete_CodecFmtpVector, METH_O, NULL},
	 { "CodecFmtpVector_swigregister", CodecFmtpVector_swigregister, METH_O, NULL},
	 { "CodecFmtpVector_swiginit", CodecFmtpVector_swiginit, METH_VARARGS, NULL},
	 { "MediaFormatAudioVector_iterator", _wrap_MediaFormatAudioVector_iterator, METH_O, NULL},
	 { "MediaFormatAudioVector___nonzero__", _wrap_MediaFormatAudioVector___nonzero__, METH_O, NULL},
	 { "MediaFormatAudioVector___bool__", _wrap_MediaFormatAudioVector___bool__, METH_O, NULL},
	 { "MediaFormatAudioVector___len__", _wrap_MediaFormatAudioVector___len__, METH_O, NULL},
	 { "MediaFormatAudioVector___getslice__", _wrap_MediaFormatAudioVector___getslice__, METH_VARARGS, NULL},
	 { "MediaFormatAudioVector___setslice__", _wrap_MediaFormatAudioVector___setslice__, METH_VARARGS, NULL},
	 { "MediaFormatAudioVector___delslice__", _wrap_MediaFormatAudioVector___delslice__, METH_VARARGS, NULL},
	 { "MediaFormatAudioVector___delitem__", _wrap_MediaFormatAudioVector___delitem__, METH_VARARGS, NULL},
	 { "MediaFormatAudioVector___getitem__", _wrap_MediaFormatAudioVector___getitem__, METH_VARARGS, NULL},
	 { "MediaFormatAudioVector___setitem__", _wrap_MediaFormatAudioVector___setitem__, METH_VARARGS, NULL},
	 { "MediaFormatAudioVector_pop", _wrap_MediaFormatAudioVector_pop, METH_O, NULL},
	 { "MediaFormatAudioVector_append", _wrap_MediaFormatAudioVector_append, METH_VARARGS, NULL},
	 { "MediaFormatAudioVector_empty", _wrap_MediaFormatAudioVector_empty, METH_O, NULL},
	 { "MediaFormatAudioVector_size", _wrap_MediaFormatAudioVector_size, METH_O, NULL},
	 { "MediaFormatAudioVector_swap", _wrap_MediaFormatAudioVector_swap, METH_VARARGS, NULL},
	 { "MediaFormatAudioVector_begin", _wrap_MediaFormatAudioVector_begin, METH_O, NULL},
	 { "MediaFormatAudioVector_end", _wrap_MediaFormatAudioVector_end, METH_O, NULL},
	 { "MediaFormatAudioVector_rbegin", _wrap_MediaFormatAudioVector_rbegin, METH_O, NULL},
	 { "MediaFormatAudioVector_rend", _wrap_MediaFormatAudioVector_rend, METH_O, NULL},
	 { "MediaFormatAudioVector_clear", _wrap_MediaFormatAudioVector_clear, METH_O, NULL},
	 { "MediaFormatAudioVector_get_allocator", _wrap_MediaFormatAudioVector_get_allocator, METH_O, NULL},
	 { "MediaFormatAudioVector_pop_back", _wrap_MediaFormatAudioVector_pop_back, METH_O, NULL},
	 { "MediaFormatAudioVector_erase", _wrap_MediaFormatAudioVector_erase, METH_VARARGS, NULL},
	 { "new_MediaFormatAudioVector", _wrap_new_MediaFormatAudioVector, METH_VARARGS, NULL},
	 { "MediaFormatAudioVector_push_back", _wrap_MediaFormatAudioVector_push_back, METH_VARARGS, NULL},
	 { "MediaFormatAudioVector_front", _wrap_MediaFormatAudioVector_front, METH_O, NULL},
	 { "MediaFormatAudioVector_back", _wrap_MediaFormatAudioVector_back, METH_O, NULL},
	 { "MediaFormatAudioVector_assign", _wrap_MediaFormatAudioVector_assign, METH_VARARGS, NULL},
	 { "MediaFormatAudioVector_resize", _wrap_MediaFormatAudioVector_resize, METH_VARARGS, NULL},
	 { "MediaFormatAudioVector_insert", _wrap_MediaFormatAudioVector_insert, METH_VARARGS, NULL},
	 { "MediaFormatAudioVector_reserve", _wrap_MediaFormatAudioVector_reserve, METH_VARARGS, NULL},
	 { "MediaFormatAudioVector_capacity", _wrap_MediaFormatAudioVector_capacity, METH_O, NULL},
	 { "delete_MediaFormatAudioVector", _wrap_delete_MediaFormatAudioVector, METH_O, NULL},
	 { "MediaFormatAudioVector_swigregister", MediaFormatAudioVector_swigregister, METH_O, NULL},
	 { "MediaFormatAudioVector_swiginit", MediaFormatAudioVector_swiginit, METH_VARARGS, NULL},
	 { "MediaFormatVideoVector_iterator", _wrap_MediaFormatVideoVector_iterator, METH_O, NULL},
	 { "MediaFormatVideoVector___nonzero__", _wrap_MediaFormatVideoVector___nonzero__, METH_O, NULL},
	 { "MediaFormatVideoVector___bool__", _wrap_MediaFormatVideoVector___bool__, METH_O, NULL},
	 { "MediaFormatVideoVector___len__", _wrap_MediaFormatVideoVector___len__, METH_O, NULL},
	 { "MediaFormatVideoVector___getslice__", _wrap_MediaFormatVideoVector___getslice__, METH_VARARGS, NULL},
	 { "MediaFormatVideoVector___setslice__", _wrap_MediaFormatVideoVector___setslice__, METH_VARARGS, NULL},
	 { "MediaFormatVideoVector___delslice__", _wrap_MediaFormatVideoVector___delslice__, METH_VARARGS, NULL},
	 { "MediaFormatVideoVector___delitem__", _wrap_MediaFormatVideoVector___delitem__, METH_VARARGS, NULL},
	 { "MediaFormatVideoVector___getitem__", _wrap_MediaFormatVideoVector___getitem__, METH_VARARGS, NULL},
	 { "MediaFormatVideoVector___setitem__", _wrap_MediaFormatVideoVector___setitem__, METH_VARARGS, NULL},
	 { "MediaFormatVideoVector_pop", _wrap_MediaFormatVideoVector_pop, METH_O, NULL},
	 { "MediaFormatVideoVector_append", _wrap_MediaFormatVideoVector_append, METH_VARARGS, NULL},
	 { "MediaFormatVideoVector_empty", _wrap_MediaFormatVideoVector_empty, METH_O, NULL},
	 { "MediaFormatVideoVector_size", _wrap_MediaFormatVideoVector_size, METH_O, NULL},
	 { "MediaFormatVideoVector_swap", _wrap_MediaFormatVideoVector_swap, METH_VARARGS, NULL},
	 { "MediaFormatVideoVector_begin", _wrap_MediaFormatVideoVector_begin, METH_O, NULL},
	 { "MediaFormatVideoVector_end", _wrap_MediaFormatVideoVector_end, METH_O, NULL},
	 { "MediaFormatVideoVector_rbegin", _wrap_MediaFormatVideoVector_rbegin, METH_O, NULL},
	 { "MediaFormatVideoVector_rend", _wrap_MediaFormatVideoVector_rend, METH_O, NULL},
	 { "MediaFormatVideoVector_clear", _wrap_MediaFormatVideoVector_clear, METH_O, NULL},
	 { "MediaFormatVideoVector_get_allocator", _wrap_MediaFormatVideoVector_get_allocator, METH_O, NULL},
	 { "MediaFormatVideoVector_pop_back", _wrap_MediaFormatVideoVector_pop_back, METH_O, NULL},
	 { "MediaFormatVideoVector_erase", _wrap_MediaFormatVideoVector_erase, METH_VARARGS, NULL},
	 { "new_MediaFormatVideoVector", _wrap_new_MediaFormatVideoVector, METH_VARARGS, NULL},
	 { "MediaFormatVideoVector_push_back", _wrap_MediaFormatVideoVector_push_back, METH_VARARGS, NULL},
	 { "MediaFormatVideoVector_front", _wrap_MediaFormatVideoVector_front, METH_O, NULL},
	 { "MediaFormatVideoVector_back", _wrap_MediaFormatVideoVector_back, METH_O, NULL},
	 { "MediaFormatVideoVector_assign", _wrap_MediaFormatVideoVector_assign, METH_VARARGS, NULL},
	 { "MediaFormatVideoVector_resize", _wrap_MediaFormatVideoVector_resize, METH_VARARGS, NULL},
	 { "MediaFormatVideoVector_insert", _wrap_MediaFormatVideoVector_insert, METH_VARARGS, NULL},
	 { "MediaFormatVideoVector_reserve", _wrap_MediaFormatVideoVector_reserve, METH_VARARGS, NULL},
	 { "MediaFormatVideoVector_capacity", _wrap_MediaFormatVideoVector_capacity, METH_O, NULL},
	 { "delete_MediaFormatVideoVector", _wrap_delete_MediaFormatVideoVector, METH_O, NULL},
	 { "MediaFormatVideoVector_swigregister", MediaFormatVideoVector_swigregister, METH_O, NULL},
	 { "MediaFormatVideoVector_swiginit", MediaFormatVideoVector_swiginit, METH_VARARGS, NULL},
	 { "CallMediaInfoVector_iterator", _wrap_CallMediaInfoVector_iterator, METH_O, NULL},
	 { "CallMediaInfoVector___nonzero__", _wrap_CallMediaInfoVector___nonzero__, METH_O, NULL},
	 { "CallMediaInfoVector___bool__", _wrap_CallMediaInfoVector___bool__, METH_O, NULL},
	 { "CallMediaInfoVector___len__", _wrap_CallMediaInfoVector___len__, METH_O, NULL},
	 { "CallMediaInfoVector___getslice__", _wrap_CallMediaInfoVector___getslice__, METH_VARARGS, NULL},
	 { "CallMediaInfoVector___setslice__", _wrap_CallMediaInfoVector___setslice__, METH_VARARGS, NULL},
	 { "CallMediaInfoVector___delslice__", _wrap_CallMediaInfoVector___delslice__, METH_VARARGS, NULL},
	 { "CallMediaInfoVector___delitem__", _wrap_CallMediaInfoVector___delitem__, METH_VARARGS, NULL},
	 { "CallMediaInfoVector___getitem__", _wrap_CallMediaInfoVector___getitem__, METH_VARARGS, NULL},
	 { "CallMediaInfoVector___setitem__", _wrap_CallMediaInfoVector___setitem__, METH_VARARGS, NULL},
	 { "CallMediaInfoVector_pop", _wrap_CallMediaInfoVector_pop, METH_O, NULL},
	 { "CallMediaInfoVector_append", _wrap_CallMediaInfoVector_append, METH_VARARGS, NULL},
	 { "CallMediaInfoVector_empty", _wrap_CallMediaInfoVector_empty, METH_O, NULL},
	 { "CallMediaInfoVector_size", _wrap_CallMediaInfoVector_size, METH_O, NULL},
	 { "CallMediaInfoVector_swap", _wrap_CallMediaInfoVector_swap, METH_VARARGS, NULL},
	 { "CallMediaInfoVector_begin", _wrap_CallMediaInfoVector_begin, METH_O, NULL},
	 { "CallMediaInfoVector_end", _wrap_CallMediaInfoVector_end, METH_O, NULL},
	 { "CallMediaInfoVector_rbegin", _wrap_CallMediaInfoVector_rbegin, METH_O, NULL},
	 { "CallMediaInfoVector_rend", _wrap_CallMediaInfoVector_rend, METH_O, NULL},
	 { "CallMediaInfoVector_clear", _wrap_CallMediaInfoVector_clear, METH_O, NULL},
	 { "CallMediaInfoVector_get_allocator", _wrap_CallMediaInfoVector_get_allocator, METH_O, NULL},
	 { "CallMediaInfoVector_pop_back", _wrap_CallMediaInfoVector_pop_back, METH_O, NULL},
	 { "CallMediaInfoVector_erase", _wrap_CallMediaInfoVector_erase, METH_VARARGS, NULL},
	 { "new_CallMediaInfoVector", _wrap_new_CallMediaInfoVector, METH_VARARGS, NULL},
	 { "CallMediaInfoVector_push_back", _wrap_CallMediaInfoVector_push_back, METH_VARARGS, NULL},
	 { "CallMediaInfoVector_front", _wrap_CallMediaInfoVector_front, METH_O, NULL},
	 { "CallMediaInfoVector_back", _wrap_CallMediaInfoVector_back, METH_O, NULL},
	 { "CallMediaInfoVector_assign", _wrap_CallMediaInfoVector_assign, METH_VARARGS, NULL},
	 { "CallMediaInfoVector_resize", _wrap_CallMediaInfoVector_resize, METH_VARARGS, NULL},
	 { "CallMediaInfoVector_insert", _wrap_CallMediaInfoVector_insert, METH_VARARGS, NULL},
	 { "CallMediaInfoVector_reserve", _wrap_CallMediaInfoVector_reserve, METH_VARARGS, NULL},
	 { "CallMediaInfoVector_capacity", _wrap_CallMediaInfoVector_capacity, METH_O, NULL},
	 { "delete_CallMediaInfoVector", _wrap_delete_CallMediaInfoVector, METH_O, NULL},
	 { "CallMediaInfoVector_swigregister", CallMediaInfoVector_swigregister, METH_O, NULL},
	 { "CallMediaInfoVector_swiginit", CallMediaInfoVector_swiginit, METH_VARARGS, NULL},
	 { "RtcpFbCapVector_iterator", _wrap_RtcpFbCapVector_iterator, METH_O, NULL},
	 { "RtcpFbCapVector___nonzero__", _wrap_RtcpFbCapVector___nonzero__, METH_O, NULL},
	 { "RtcpFbCapVector___bool__", _wrap_RtcpFbCapVector___bool__, METH_O, NULL},
	 { "RtcpFbCapVector___len__", _wrap_RtcpFbCapVector___len__, METH_O, NULL},
	 { "RtcpFbCapVector___getslice__", _wrap_RtcpFbCapVector___getslice__, METH_VARARGS, NULL},
	 { "RtcpFbCapVector___setslice__", _wrap_RtcpFbCapVector___setslice__, METH_VARARGS, NULL},
	 { "RtcpFbCapVector___delslice__", _wrap_RtcpFbCapVector___delslice__, METH_VARARGS, NULL},
	 { "RtcpFbCapVector___delitem__", _wrap_RtcpFbCapVector___delitem__, METH_VARARGS, NULL},
	 { "RtcpFbCapVector___getitem__", _wrap_RtcpFbCapVector___getitem__, METH_VARARGS, NULL},
	 { "RtcpFbCapVector___setitem__", _wrap_RtcpFbCapVector___setitem__, METH_VARARGS, NULL},
	 { "RtcpFbCapVector_pop", _wrap_RtcpFbCapVector_pop, METH_O, NULL},
	 { "RtcpFbCapVector_append", _wrap_RtcpFbCapVector_append, METH_VARARGS, NULL},
	 { "RtcpFbCapVector_empty", _wrap_RtcpFbCapVector_empty, METH_O, NULL},
	 { "RtcpFbCapVector_size", _wrap_RtcpFbCapVector_size, METH_O, NULL},
	 { "RtcpFbCapVector_swap", _wrap_RtcpFbCapVector_swap, METH_VARARGS, NULL},
	 { "RtcpFbCapVector_begin", _wrap_RtcpFbCapVector_begin, METH_O, NULL},
	 { "RtcpFbCapVector_end", _wrap_RtcpFbCapVector_end, METH_O, NULL},
	 { "RtcpFbCapVector_rbegin", _wrap_RtcpFbCapVector_rbegin, METH_O, NULL},
	 { "RtcpFbCapVector_rend", _wrap_RtcpFbCapVector_rend, METH_O, NULL},
	 { "RtcpFbCapVector_clear", _wrap_RtcpFbCapVector_clear, METH_O, NULL},
	 { "RtcpFbCapVector_get_allocator", _wrap_RtcpFbCapVector_get_allocator, METH_O, NULL},
	 { "RtcpFbCapVector_pop_back", _wrap_RtcpFbCapVector_pop_back, METH_O, NULL},
	 { "RtcpFbCapVector_erase", _wrap_RtcpFbCapVector_erase, METH_VARARGS, NULL},
	 { "new_RtcpFbCapVector", _wrap_new_RtcpFbCapVector, METH_VARARGS, NULL},
	 { "RtcpFbCapVector_push_back", _wrap_RtcpFbCapVector_push_back, METH_VARARGS, NULL},
	 { "RtcpFbCapVector_front", _wrap_RtcpFbCapVector_front, METH_O, NULL},
	 { "RtcpFbCapVector_back", _wrap_RtcpFbCapVector_back, METH_O, NULL},
	 { "RtcpFbCapVector_assign", _wrap_RtcpFbCapVector_assign, METH_VARARGS, NULL},
	 { "RtcpFbCapVector_resize", _wrap_RtcpFbCapVector_resize, METH_VARARGS, NULL},
	 { "RtcpFbCapVector_insert", _wrap_RtcpFbCapVector_insert, METH_VARARGS, NULL},
	 { "RtcpFbCapVector_reserve", _wrap_RtcpFbCapVector_reserve, METH_VARARGS, NULL},
	 { "RtcpFbCapVector_capacity", _wrap_RtcpFbCapVector_capacity, METH_O, NULL},
	 { "delete_RtcpFbCapVector", _wrap_delete_RtcpFbCapVector, METH_O, NULL},
	 { "RtcpFbCapVector_swigregister", RtcpFbCapVector_swigregister, METH_O, NULL},
	 { "RtcpFbCapVector_swiginit", RtcpFbCapVector_swiginit, METH_VARARGS, NULL},
	 { "SslCertNameVector_iterator", _wrap_SslCertNameVector_iterator, METH_O, NULL},
	 { "SslCertNameVector___nonzero__", _wrap_SslCertNameVector___nonzero__, METH_O, NULL},
	 { "SslCertNameVector___bool__", _wrap_SslCertNameVector___bool__, METH_O, NULL},
	 { "SslCertNameVector___len__", _wrap_SslCertNameVector___len__, METH_O, NULL},
	 { "SslCertNameVector___getslice__", _wrap_SslCertNameVector___getslice__, METH_VARARGS, NULL},
	 { "SslCertNameVector___setslice__", _wrap_SslCertNameVector___setslice__, METH_VARARGS, NULL},
	 { "SslCertNameVector___delslice__", _wrap_SslCertNameVector___delslice__, METH_VARARGS, NULL},
	 { "SslCertNameVector___delitem__", _wrap_SslCertNameVector___delitem__, METH_VARARGS, NULL},
	 { "SslCertNameVector___getitem__", _wrap_SslCertNameVector___getitem__, METH_VARARGS, NULL},
	 { "SslCertNameVector___setitem__", _wrap_SslCertNameVector___setitem__, METH_VARARGS, NULL},
	 { "SslCertNameVector_pop", _wrap_SslCertNameVector_pop, METH_O, NULL},
	 { "SslCertNameVector_append", _wrap_SslCertNameVector_append, METH_VARARGS, NULL},
	 { "SslCertNameVector_empty", _wrap_SslCertNameVector_empty, METH_O, NULL},
	 { "SslCertNameVector_size", _wrap_SslCertNameVector_size, METH_O, NULL},
	 { "SslCertNameVector_swap", _wrap_SslCertNameVector_swap, METH_VARARGS, NULL},
	 { "SslCertNameVector_begin", _wrap_SslCertNameVector_begin, METH_O, NULL},
	 { "SslCertNameVector_end", _wrap_SslCertNameVector_end, METH_O, NULL},
	 { "SslCertNameVector_rbegin", _wrap_SslCertNameVector_rbegin, METH_O, NULL},
	 { "SslCertNameVector_rend", _wrap_SslCertNameVector_rend, METH_O, NULL},
	 { "SslCertNameVector_clear", _wrap_SslCertNameVector_clear, METH_O, NULL},
	 { "SslCertNameVector_get_allocator", _wrap_SslCertNameVector_get_allocator, METH_O, NULL},
	 { "SslCertNameVector_pop_back", _wrap_SslCertNameVector_pop_back, METH_O, NULL},
	 { "SslCertNameVector_erase", _wrap_SslCertNameVector_erase, METH_VARARGS, NULL},
	 { "new_SslCertNameVector", _wrap_new_SslCertNameVector, METH_VARARGS, NULL},
	 { "SslCertNameVector_push_back", _wrap_SslCertNameVector_push_back, METH_VARARGS, NULL},
	 { "SslCertNameVector_front", _wrap_SslCertNameVector_front, METH_O, NULL},
	 { "SslCertNameVector_back", _wrap_SslCertNameVector_back, METH_O, NULL},
	 { "SslCertNameVector_assign", _wrap_SslCertNameVector_assign, METH_VARARGS, NULL},
	 { "SslCertNameVector_resize", _wrap_SslCertNameVector_resize, METH_VARARGS, NULL},
	 { "SslCertNameVector_insert", _wrap_SslCertNameVector_insert, METH_VARARGS, NULL},
	 { "SslCertNameVector_reserve", _wrap_SslCertNameVector_reserve, METH_VARARGS, NULL},
	 { "SslCertNameVector_capacity", _wrap_SslCertNameVector_capacity, METH_O, NULL},
	 { "delete_SslCertNameVector", _wrap_delete_SslCertNameVector, METH_O, NULL},
	 { "SslCertNameVector_swigregister", SslCertNameVector_swigregister, METH_O, NULL},
	 { "SslCertNameVector_swiginit", SslCertNameVector_swiginit, METH_VARARGS, NULL},
	 { "MediaFormat_id_set", _wrap_MediaFormat_id_set, METH_VARARGS, NULL},
	 { "MediaFormat_id_get", _wrap_MediaFormat_id_get, METH_O, NULL},
	 { "MediaFormat_type_set", _wrap_MediaFormat_type_set, METH_VARARGS, NULL},
	 { "MediaFormat_type_get", _wrap_MediaFormat_type_get, METH_O, NULL},
	 { "new_MediaFormat", _wrap_new_MediaFormat, METH_NOARGS, NULL},
	 { "delete_MediaFormat", _wrap_delete_MediaFormat, METH_O, NULL},
	 { "MediaFormat_swigregister", MediaFormat_swigregister, METH_O, NULL},
	 { "MediaFormat_swiginit", MediaFormat_swiginit, METH_VARARGS, NULL},
	 { "MediaFormatAudio_clockRate_set", _wrap_MediaFormatAudio_clockRate_set, METH_VARARGS, NULL},
	 { "MediaFormatAudio_clockRate_get", _wrap_MediaFormatAudio_clockRate_get, METH_O, NULL},
	 { "MediaFormatAudio_channelCount_set", _wrap_MediaFormatAudio_channelCount_set, METH_VARARGS, NULL},
	 { "MediaFormatAudio_channelCount_get", _wrap_MediaFormatAudio_channelCount_get, METH_O, NULL},
	 { "MediaFormatAudio_frameTimeUsec_set", _wrap_MediaFormatAudio_frameTimeUsec_set, METH_VARARGS, NULL},
	 { "MediaFormatAudio_frameTimeUsec_get", _wrap_MediaFormatAudio_frameTimeUsec_get, METH_O, NULL},
	 { "MediaFormatAudio_bitsPerSample_set", _wrap_MediaFormatAudio_bitsPerSample_set, METH_VARARGS, NULL},
	 { "MediaFormatAudio_bitsPerSample_get", _wrap_MediaFormatAudio_bitsPerSample_get, METH_O, NULL},
	 { "MediaFormatAudio_avgBps_set", _wrap_MediaFormatAudio_avgBps_set, METH_VARARGS, NULL},
	 { "MediaFormatAudio_avgBps_get", _wrap_MediaFormatAudio_avgBps_get, METH_O, NULL},
	 { "MediaFormatAudio_maxBps_set", _wrap_MediaFormatAudio_maxBps_set, METH_VARARGS, NULL},
	 { "MediaFormatAudio_maxBps_get", _wrap_MediaFormatAudio_maxBps_get, METH_O, NULL},
	 { "new_MediaFormatAudio", _wrap_new_MediaFormatAudio, METH_NOARGS, NULL},
	 { "delete_MediaFormatAudio", _wrap_delete_MediaFormatAudio, METH_O, NULL},
	 { "MediaFormatAudio_swigregister", MediaFormatAudio_swigregister, METH_O, NULL},
	 { "MediaFormatAudio_swiginit", MediaFormatAudio_swiginit, METH_VARARGS, NULL},
	 { "MediaFormatVideo_width_set", _wrap_MediaFormatVideo_width_set, METH_VARARGS, NULL},
	 { "MediaFormatVideo_width_get", _wrap_MediaFormatVideo_width_get, METH_O, NULL},
	 { "MediaFormatVideo_height_set", _wrap_MediaFormatVideo_height_set, METH_VARARGS, NULL},
	 { "MediaFormatVideo_height_get", _wrap_MediaFormatVideo_height_get, METH_O, NULL},
	 { "MediaFormatVideo_fpsNum_set", _wrap_MediaFormatVideo_fpsNum_set, METH_VARARGS, NULL},
	 { "MediaFormatVideo_fpsNum_get", _wrap_MediaFormatVideo_fpsNum_get, METH_O, NULL},
	 { "MediaFormatVideo_fpsDenum_set", _wrap_MediaFormatVideo_fpsDenum_set, METH_VARARGS, NULL},
	 { "MediaFormatVideo_fpsDenum_get", _wrap_MediaFormatVideo_fpsDenum_get, METH_O, NULL},
	 { "MediaFormatVideo_avgBps_set", _wrap_MediaFormatVideo_avgBps_set, METH_VARARGS, NULL},
	 { "MediaFormatVideo_avgBps_get", _wrap_MediaFormatVideo_avgBps_get, METH_O, NULL},
	 { "MediaFormatVideo_maxBps_set", _wrap_MediaFormatVideo_maxBps_set, METH_VARARGS, NULL},
	 { "MediaFormatVideo_maxBps_get", _wrap_MediaFormatVideo_maxBps_get, METH_O, NULL},
	 { "new_MediaFormatVideo", _wrap_new_MediaFormatVideo, METH_NOARGS, NULL},
	 { "delete_MediaFormatVideo", _wrap_delete_MediaFormatVideo, METH_O, NULL},
	 { "MediaFormatVideo_swigregister", MediaFormatVideo_swigregister, METH_O, NULL},
	 { "MediaFormatVideo_swiginit", MediaFormatVideo_swiginit, METH_VARARGS, NULL},
	 { "ConfPortInfo_portId_set", _wrap_ConfPortInfo_portId_set, METH_VARARGS, NULL},
	 { "ConfPortInfo_portId_get", _wrap_ConfPortInfo_portId_get, METH_O, NULL},
	 { "ConfPortInfo_name_set", _wrap_ConfPortInfo_name_set, METH_VARARGS, NULL},
	 { "ConfPortInfo_name_get", _wrap_ConfPortInfo_name_get, METH_O, NULL},
	 { "ConfPortInfo_format_set", _wrap_ConfPortInfo_format_set, METH_VARARGS, NULL},
	 { "ConfPortInfo_format_get", _wrap_ConfPortInfo_format_get, METH_O, NULL},
	 { "ConfPortInfo_txLevelAdj_set", _wrap_ConfPortInfo_txLevelAdj_set, METH_VARARGS, NULL},
	 { "ConfPortInfo_txLevelAdj_get", _wrap_ConfPortInfo_txLevelAdj_get, METH_O, NULL},
	 { "ConfPortInfo_rxLevelAdj_set", _wrap_ConfPortInfo_rxLevelAdj_set, METH_VARARGS, NULL},
	 { "ConfPortInfo_rxLevelAdj_get", _wrap_ConfPortInfo_rxLevelAdj_get, METH_O, NULL},
	 { "ConfPortInfo_listeners_set", _wrap_ConfPortInfo_listeners_set, METH_VARARGS, NULL},
	 { "ConfPortInfo_listeners_get", _wrap_ConfPortInfo_listeners_get, METH_O, NULL},
	 { "new_ConfPortInfo", _wrap_new_ConfPortInfo, METH_NOARGS, NULL},
	 { "delete_ConfPortInfo", _wrap_delete_ConfPortInfo, METH_O, NULL},
	 { "ConfPortInfo_swigregister", ConfPortInfo_swigregister, METH_O, NULL},
	 { "ConfPortInfo_swiginit", ConfPortInfo_swiginit, METH_VARARGS, NULL},
	 { "delete_Media", _wrap_delete_Media, METH_O, NULL},
	 { "Media_getType", _wrap_Media_getType, METH_O, NULL},
	 { "Media_swigregister", Media_swigregister, METH_O, NULL},
	 { "AudioMediaTransmitParam_level_set", _wrap_AudioMediaTransmitParam_level_set, METH_VARARGS, NULL},
	 { "AudioMediaTransmitParam_level_get", _wrap_AudioMediaTransmitParam_level_get, METH_O, NULL},
	 { "new_AudioMediaTransmitParam", _wrap_new_AudioMediaTransmitParam, METH_NOARGS, NULL},
	 { "delete_AudioMediaTransmitParam", _wrap_delete_AudioMediaTransmitParam, METH_O, NULL},
	 { "AudioMediaTransmitParam_swigregister", AudioMediaTransmitParam_swigregister, METH_O, NULL},
	 { "AudioMediaTransmitParam_swiginit", AudioMediaTransmitParam_swiginit, METH_VARARGS, NULL},
	 { "AudioMedia_getPortInfo", _wrap_AudioMedia_getPortInfo, METH_O, NULL},
	 { "AudioMedia_getPortId", _wrap_AudioMedia_getPortId, METH_O, NULL},
	 { "AudioMedia_getPortInfoFromId", _wrap_AudioMedia_getPortInfoFromId, METH_O, NULL},
	 { "AudioMedia_startTransmit", _wrap_AudioMedia_startTransmit, METH_VARARGS, NULL},
	 { "AudioMedia_startTransmit2", _wrap_AudioMedia_startTransmit2, METH_VARARGS, NULL},
	 { "AudioMedia_stopTransmit", _wrap_AudioMedia_stopTransmit, METH_VARARGS, NULL},
	 { "AudioMedia_adjustRxLevel", _wrap_AudioMedia_adjustRxLevel, METH_VARARGS, NULL},
	 { "AudioMedia_adjustTxLevel", _wrap_AudioMedia_adjustTxLevel, METH_VARARGS, NULL},
	 { "AudioMedia_getRxLevel", _wrap_AudioMedia_getRxLevel, METH_O, NULL},
	 { "AudioMedia_getTxLevel", _wrap_AudioMedia_getTxLevel, METH_O, NULL},
	 { "AudioMedia_typecastFromMedia", _wrap_AudioMedia_typecastFromMedia, METH_O, NULL},
	 { "new_AudioMedia", _wrap_new_AudioMedia, METH_NOARGS, NULL},
	 { "delete_AudioMedia", _wrap_delete_AudioMedia, METH_O, NULL},
	 { "AudioMedia_swigregister", AudioMedia_swigregister, METH_O, NULL},
	 { "AudioMedia_swiginit", AudioMedia_swiginit, METH_VARARGS, NULL},
	 { "AudioMediaPlayerInfo_formatId_set", _wrap_AudioMediaPlayerInfo_formatId_set, METH_VARARGS, NULL},
	 { "AudioMediaPlayerInfo_formatId_get", _wrap_AudioMediaPlayerInfo_formatId_get, METH_O, NULL},
	 { "AudioMediaPlayerInfo_payloadBitsPerSample_set", _wrap_AudioMediaPlayerInfo_payloadBitsPerSample_set, METH_VARARGS, NULL},
	 { "AudioMediaPlayerInfo_payloadBitsPerSample_get", _wrap_AudioMediaPlayerInfo_payloadBitsPerSample_get, METH_O, NULL},
	 { "AudioMediaPlayerInfo_sizeBytes_set", _wrap_AudioMediaPlayerInfo_sizeBytes_set, METH_VARARGS, NULL},
	 { "AudioMediaPlayerInfo_sizeBytes_get", _wrap_AudioMediaPlayerInfo_sizeBytes_get, METH_O, NULL},
	 { "AudioMediaPlayerInfo_sizeSamples_set", _wrap_AudioMediaPlayerInfo_sizeSamples_set, METH_VARARGS, NULL},
	 { "AudioMediaPlayerInfo_sizeSamples_get", _wrap_AudioMediaPlayerInfo_sizeSamples_get, METH_O, NULL},
	 { "new_AudioMediaPlayerInfo", _wrap_new_AudioMediaPlayerInfo, METH_NOARGS, NULL},
	 { "delete_AudioMediaPlayerInfo", _wrap_delete_AudioMediaPlayerInfo, METH_O, NULL},
	 { "AudioMediaPlayerInfo_swigregister", AudioMediaPlayerInfo_swigregister, METH_O, NULL},
	 { "AudioMediaPlayerInfo_swiginit", AudioMediaPlayerInfo_swiginit, METH_VARARGS, NULL},
	 { "new_AudioMediaPlayer", _wrap_new_AudioMediaPlayer, METH_O, NULL},
	 { "AudioMediaPlayer_createPlayer", _wrap_AudioMediaPlayer_createPlayer, METH_VARARGS, NULL},
	 { "AudioMediaPlayer_createPlaylist", _wrap_AudioMediaPlayer_createPlaylist, METH_VARARGS, NULL},
	 { "AudioMediaPlayer_getInfo", _wrap_AudioMediaPlayer_getInfo, METH_O, NULL},
	 { "AudioMediaPlayer_getPos", _wrap_AudioMediaPlayer_getPos, METH_O, NULL},
	 { "AudioMediaPlayer_setPos", _wrap_AudioMediaPlayer_setPos, METH_VARARGS, NULL},
	 { "AudioMediaPlayer_typecastFromAudioMedia", _wrap_AudioMediaPlayer_typecastFromAudioMedia, METH_O, NULL},
	 { "delete_AudioMediaPlayer", _wrap_delete_AudioMediaPlayer, METH_O, NULL},
	 { "AudioMediaPlayer_onEof2", _wrap_AudioMediaPlayer_onEof2, METH_O, NULL},
	 { "disown_AudioMediaPlayer", _wrap_disown_AudioMediaPlayer, METH_O, NULL},
	 { "AudioMediaPlayer_swigregister", AudioMediaPlayer_swigregister, METH_O, NULL},
	 { "AudioMediaPlayer_swiginit", AudioMediaPlayer_swiginit, METH_VARARGS, NULL},
	 { "new_AudioMediaRecorder", _wrap_new_AudioMediaRecorder, METH_NOARGS, NULL},
	 { "AudioMediaRecorder_createRecorder", _wrap_AudioMediaRecorder_createRecorder, METH_VARARGS, NULL},
	 { "AudioMediaRecorder_typecastFromAudioMedia", _wrap_AudioMediaRecorder_typecastFromAudioMedia, METH_O, NULL},
	 { "delete_AudioMediaRecorder", _wrap_delete_AudioMediaRecorder, METH_O, NULL},
	 { "AudioMediaRecorder_swigregister", AudioMediaRecorder_swigregister, METH_O, NULL},
	 { "AudioMediaRecorder_swiginit", AudioMediaRecorder_swiginit, METH_VARARGS, NULL},
	 { "new_ToneDesc", _wrap_new_ToneDesc, METH_NOARGS, NULL},
	 { "delete_ToneDesc", _wrap_delete_ToneDesc, METH_O, NULL},
	 { "ToneDesc_swigregister", ToneDesc_swigregister, METH_O, NULL},
	 { "ToneDesc_swiginit", ToneDesc_swiginit, METH_VARARGS, NULL},
	 { "new_ToneDigit", _wrap_new_ToneDigit, METH_NOARGS, NULL},
	 { "delete_ToneDigit", _wrap_delete_ToneDigit, METH_O, NULL},
	 { "ToneDigit_swigregister", ToneDigit_swigregister, METH_O, NULL},
	 { "ToneDigit_swiginit", ToneDigit_swiginit, METH_VARARGS, NULL},
	 { "ToneDigitMapDigit_digit_set", _wrap_ToneDigitMapDigit_digit_set, METH_VARARGS, NULL},
	 { "ToneDigitMapDigit_digit_get", _wrap_ToneDigitMapDigit_digit_get, METH_O, NULL},
	 { "ToneDigitMapDigit_freq1_set", _wrap_ToneDigitMapDigit_freq1_set, METH_VARARGS, NULL},
	 { "ToneDigitMapDigit_freq1_get", _wrap_ToneDigitMapDigit_freq1_get, METH_O, NULL},
	 { "ToneDigitMapDigit_freq2_set", _wrap_ToneDigitMapDigit_freq2_set, METH_VARARGS, NULL},
	 { "ToneDigitMapDigit_freq2_get", _wrap_ToneDigitMapDigit_freq2_get, METH_O, NULL},
	 { "new_ToneDigitMapDigit", _wrap_new_ToneDigitMapDigit, METH_NOARGS, NULL},
	 { "delete_ToneDigitMapDigit", _wrap_delete_ToneDigitMapDigit, METH_O, NULL},
	 { "ToneDigitMapDigit_swigregister", ToneDigitMapDigit_swigregister, METH_O, NULL},
	 { "ToneDigitMapDigit_swiginit", ToneDigitMapDigit_swiginit, METH_VARARGS, NULL},
	 { "new_ToneGenerator", _wrap_new_ToneGenerator, METH_NOARGS, NULL},
	 { "delete_ToneGenerator", _wrap_delete_ToneGenerator, METH_O, NULL},
	 { "ToneGenerator_createToneGenerator", _wrap_ToneGenerator_createToneGenerator, METH_VARARGS, NULL},
	 { "ToneGenerator_isBusy", _wrap_ToneGenerator_isBusy, METH_O, NULL},
	 { "ToneGenerator_stop", _wrap_ToneGenerator_stop, METH_O, NULL},
	 { "ToneGenerator_rewind", _wrap_ToneGenerator_rewind, METH_O, NULL},
	 { "ToneGenerator_play", _wrap_ToneGenerator_play, METH_VARARGS, NULL},
	 { "ToneGenerator_playDigits", _wrap_ToneGenerator_playDigits, METH_VARARGS, NULL},
	 { "ToneGenerator_getDigitMap", _wrap_ToneGenerator_getDigitMap, METH_O, NULL},
	 { "ToneGenerator_setDigitMap", _wrap_ToneGenerator_setDigitMap, METH_VARARGS, NULL},
	 { "ToneGenerator_swigregister", ToneGenerator_swigregister, METH_O, NULL},
	 { "ToneGenerator_swiginit", ToneGenerator_swiginit, METH_VARARGS, NULL},
	 { "AudioDevInfo_name_set", _wrap_AudioDevInfo_name_set, METH_VARARGS, NULL},
	 { "AudioDevInfo_name_get", _wrap_AudioDevInfo_name_get, METH_O, NULL},
	 { "AudioDevInfo_inputCount_set", _wrap_AudioDevInfo_inputCount_set, METH_VARARGS, NULL},
	 { "AudioDevInfo_inputCount_get", _wrap_AudioDevInfo_inputCount_get, METH_O, NULL},
	 { "AudioDevInfo_outputCount_set", _wrap_AudioDevInfo_outputCount_set, METH_VARARGS, NULL},
	 { "AudioDevInfo_outputCount_get", _wrap_AudioDevInfo_outputCount_get, METH_O, NULL},
	 { "AudioDevInfo_defaultSamplesPerSec_set", _wrap_AudioDevInfo_defaultSamplesPerSec_set, METH_VARARGS, NULL},
	 { "AudioDevInfo_defaultSamplesPerSec_get", _wrap_AudioDevInfo_defaultSamplesPerSec_get, METH_O, NULL},
	 { "AudioDevInfo_driver_set", _wrap_AudioDevInfo_driver_set, METH_VARARGS, NULL},
	 { "AudioDevInfo_driver_get", _wrap_AudioDevInfo_driver_get, METH_O, NULL},
	 { "AudioDevInfo_caps_set", _wrap_AudioDevInfo_caps_set, METH_VARARGS, NULL},
	 { "AudioDevInfo_caps_get", _wrap_AudioDevInfo_caps_get, METH_O, NULL},
	 { "AudioDevInfo_routes_set", _wrap_AudioDevInfo_routes_set, METH_VARARGS, NULL},
	 { "AudioDevInfo_routes_get", _wrap_AudioDevInfo_routes_get, METH_O, NULL},
	 { "AudioDevInfo_extFmt_set", _wrap_AudioDevInfo_extFmt_set, METH_VARARGS, NULL},
	 { "AudioDevInfo_extFmt_get", _wrap_AudioDevInfo_extFmt_get, METH_O, NULL},
	 { "delete_AudioDevInfo", _wrap_delete_AudioDevInfo, METH_O, NULL},
	 { "new_AudioDevInfo", _wrap_new_AudioDevInfo, METH_NOARGS, NULL},
	 { "AudioDevInfo_swigregister", AudioDevInfo_swigregister, METH_O, NULL},
	 { "AudioDevInfo_swiginit", AudioDevInfo_swiginit, METH_VARARGS, NULL},
	 { "AudDevManager_getCaptureDev", _wrap_AudDevManager_getCaptureDev, METH_O, NULL},
	 { "AudDevManager_getCaptureDevMedia", _wrap_AudDevManager_getCaptureDevMedia, METH_O, NULL},
	 { "AudDevManager_getPlaybackDev", _wrap_AudDevManager_getPlaybackDev, METH_O, NULL},
	 { "AudDevManager_getPlaybackDevMedia", _wrap_AudDevManager_getPlaybackDevMedia, METH_O, NULL},
	 { "AudDevManager_setCaptureDev", _wrap_AudDevManager_setCaptureDev, METH_VARARGS, NULL},
	 { "AudDevManager_setPlaybackDev", _wrap_AudDevManager_setPlaybackDev, METH_VARARGS, NULL},
	 { "AudDevManager_enumDev2", _wrap_AudDevManager_enumDev2, METH_O, NULL},
	 { "AudDevManager_setNullDev", _wrap_AudDevManager_setNullDev, METH_O, NULL},
	 { "AudDevManager_setNoDev", _wrap_AudDevManager_setNoDev, METH_O, NULL},
	 { "AudDevManager_setSndDevMode", _wrap_AudDevManager_setSndDevMode, METH_VARARGS, NULL},
	 { "AudDevManager_setEcOptions", _wrap_AudDevManager_setEcOptions, METH_VARARGS, NULL},
	 { "AudDevManager_getEcTail", _wrap_AudDevManager_getEcTail, METH_O, NULL},
	 { "AudDevManager_sndIsActive", _wrap_AudDevManager_sndIsActive, METH_O, NULL},
	 { "AudDevManager_refreshDevs", _wrap_AudDevManager_refreshDevs, METH_O, NULL},
	 { "AudDevManager_getDevCount", _wrap_AudDevManager_getDevCount, METH_O, NULL},
	 { "AudDevManager_getDevInfo", _wrap_AudDevManager_getDevInfo, METH_VARARGS, NULL},
	 { "AudDevManager_lookupDev", _wrap_AudDevManager_lookupDev, METH_VARARGS, NULL},
	 { "AudDevManager_capName", _wrap_AudDevManager_capName, METH_VARARGS, NULL},
	 { "AudDevManager_setExtFormat", _wrap_AudDevManager_setExtFormat, METH_VARARGS, NULL},
	 { "AudDevManager_getExtFormat", _wrap_AudDevManager_getExtFormat, METH_O, NULL},
	 { "AudDevManager_setInputLatency", _wrap_AudDevManager_setInputLatency, METH_VARARGS, NULL},
	 { "AudDevManager_getInputLatency", _wrap_AudDevManager_getInputLatency, METH_O, NULL},
	 { "AudDevManager_setOutputLatency", _wrap_AudDevManager_setOutputLatency, METH_VARARGS, NULL},
	 { "AudDevManager_getOutputLatency", _wrap_AudDevManager_getOutputLatency, METH_O, NULL},
	 { "AudDevManager_setInputVolume", _wrap_AudDevManager_setInputVolume, METH_VARARGS, NULL},
	 { "AudDevManager_getInputVolume", _wrap_AudDevManager_getInputVolume, METH_O, NULL},
	 { "AudDevManager_setOutputVolume", _wrap_AudDevManager_setOutputVolume, METH_VARARGS, NULL},
	 { "AudDevManager_getOutputVolume", _wrap_AudDevManager_getOutputVolume, METH_O, NULL},
	 { "AudDevManager_getInputSignal", _wrap_AudDevManager_getInputSignal, METH_O, NULL},
	 { "AudDevManager_getOutputSignal", _wrap_AudDevManager_getOutputSignal, METH_O, NULL},
	 { "AudDevManager_setInputRoute", _wrap_AudDevManager_setInputRoute, METH_VARARGS, NULL},
	 { "AudDevManager_getInputRoute", _wrap_AudDevManager_getInputRoute, METH_O, NULL},
	 { "AudDevManager_setOutputRoute", _wrap_AudDevManager_setOutputRoute, METH_VARARGS, NULL},
	 { "AudDevManager_getOutputRoute", _wrap_AudDevManager_getOutputRoute, METH_O, NULL},
	 { "AudDevManager_setVad", _wrap_AudDevManager_setVad, METH_VARARGS, NULL},
	 { "AudDevManager_getVad", _wrap_AudDevManager_getVad, METH_O, NULL},
	 { "AudDevManager_setCng", _wrap_AudDevManager_setCng, METH_VARARGS, NULL},
	 { "AudDevManager_getCng", _wrap_AudDevManager_getCng, METH_O, NULL},
	 { "AudDevManager_setPlc", _wrap_AudDevManager_setPlc, METH_VARARGS, NULL},
	 { "AudDevManager_getPlc", _wrap_AudDevManager_getPlc, METH_O, NULL},
	 { "AudDevManager_swigregister", AudDevManager_swigregister, METH_O, NULL},
	 { "new_ExtraAudioDevice", _wrap_new_ExtraAudioDevice, METH_VARARGS, NULL},
	 { "delete_ExtraAudioDevice", _wrap_delete_ExtraAudioDevice, METH_O, NULL},
	 { "ExtraAudioDevice_open", _wrap_ExtraAudioDevice_open, METH_O, NULL},
	 { "ExtraAudioDevice_close", _wrap_ExtraAudioDevice_close, METH_O, NULL},
	 { "ExtraAudioDevice_isOpened", _wrap_ExtraAudioDevice_isOpened, METH_O, NULL},
	 { "ExtraAudioDevice_swigregister", ExtraAudioDevice_swigregister, METH_O, NULL},
	 { "ExtraAudioDevice_swiginit", ExtraAudioDevice_swiginit, METH_VARARGS, NULL},
	 { "MediaCoordinate_x_set", _wrap_MediaCoordinate_x_set, METH_VARARGS, NULL},
	 { "MediaCoordinate_x_get", _wrap_MediaCoordinate_x_get, METH_O, NULL},
	 { "MediaCoordinate_y_set", _wrap_MediaCoordinate_y_set, METH_VARARGS, NULL},
	 { "MediaCoordinate_y_get", _wrap_MediaCoordinate_y_get, METH_O, NULL},
	 { "new_MediaCoordinate", _wrap_new_MediaCoordinate, METH_NOARGS, NULL},
	 { "delete_MediaCoordinate", _wrap_delete_MediaCoordinate, METH_O, NULL},
	 { "MediaCoordinate_swigregister", MediaCoordinate_swigregister, METH_O, NULL},
	 { "MediaCoordinate_swiginit", MediaCoordinate_swiginit, METH_VARARGS, NULL},
	 { "MediaSize_w_set", _wrap_MediaSize_w_set, METH_VARARGS, NULL},
	 { "MediaSize_w_get", _wrap_MediaSize_w_get, METH_O, NULL},
	 { "MediaSize_h_set", _wrap_MediaSize_h_set, METH_VARARGS, NULL},
	 { "MediaSize_h_get", _wrap_MediaSize_h_get, METH_O, NULL},
	 { "new_MediaSize", _wrap_new_MediaSize, METH_NOARGS, NULL},
	 { "delete_MediaSize", _wrap_delete_MediaSize, METH_O, NULL},
	 { "MediaSize_swigregister", MediaSize_swigregister, METH_O, NULL},
	 { "MediaSize_swiginit", MediaSize_swiginit, METH_VARARGS, NULL},
	 { "VidConfPortInfo_portId_set", _wrap_VidConfPortInfo_portId_set, METH_VARARGS, NULL},
	 { "VidConfPortInfo_portId_get", _wrap_VidConfPortInfo_portId_get, METH_O, NULL},
	 { "VidConfPortInfo_name_set", _wrap_VidConfPortInfo_name_set, METH_VARARGS, NULL},
	 { "VidConfPortInfo_name_get", _wrap_VidConfPortInfo_name_get, METH_O, NULL},
	 { "VidConfPortInfo_format_set", _wrap_VidConfPortInfo_format_set, METH_VARARGS, NULL},
	 { "VidConfPortInfo_format_get", _wrap_VidConfPortInfo_format_get, METH_O, NULL},
	 { "VidConfPortInfo_listeners_set", _wrap_VidConfPortInfo_listeners_set, METH_VARARGS, NULL},
	 { "VidConfPortInfo_listeners_get", _wrap_VidConfPortInfo_listeners_get, METH_O, NULL},
	 { "VidConfPortInfo_transmitters_set", _wrap_VidConfPortInfo_transmitters_set, METH_VARARGS, NULL},
	 { "VidConfPortInfo_transmitters_get", _wrap_VidConfPortInfo_transmitters_get, METH_O, NULL},
	 { "new_VidConfPortInfo", _wrap_new_VidConfPortInfo, METH_NOARGS, NULL},
	 { "delete_VidConfPortInfo", _wrap_delete_VidConfPortInfo, METH_O, NULL},
	 { "VidConfPortInfo_swigregister", VidConfPortInfo_swigregister, METH_O, NULL},
	 { "VidConfPortInfo_swiginit", VidConfPortInfo_swiginit, METH_VARARGS, NULL},
	 { "new_VideoMediaTransmitParam", _wrap_new_VideoMediaTransmitParam, METH_NOARGS, NULL},
	 { "delete_VideoMediaTransmitParam", _wrap_delete_VideoMediaTransmitParam, METH_O, NULL},
	 { "VideoMediaTransmitParam_swigregister", VideoMediaTransmitParam_swigregister, METH_O, NULL},
	 { "VideoMediaTransmitParam_swiginit", VideoMediaTransmitParam_swiginit, METH_VARARGS, NULL},
	 { "VideoMedia_getPortInfo", _wrap_VideoMedia_getPortInfo, METH_O, NULL},
	 { "VideoMedia_getPortId", _wrap_VideoMedia_getPortId, METH_O, NULL},
	 { "VideoMedia_getPortInfoFromId", _wrap_VideoMedia_getPortInfoFromId, METH_O, NULL},
	 { "VideoMedia_startTransmit", _wrap_VideoMedia_startTransmit, METH_VARARGS, NULL},
	 { "VideoMedia_stopTransmit", _wrap_VideoMedia_stopTransmit, METH_VARARGS, NULL},
	 { "VideoMedia_update", _wrap_VideoMedia_update, METH_O, NULL},
	 { "new_VideoMedia", _wrap_new_VideoMedia, METH_NOARGS, NULL},
	 { "delete_VideoMedia", _wrap_delete_VideoMedia, METH_O, NULL},
	 { "VideoMedia_swigregister", VideoMedia_swigregister, METH_O, NULL},
	 { "VideoMedia_swiginit", VideoMedia_swiginit, METH_VARARGS, NULL},
	 { "WindowHandle_setWindow", _wrap_WindowHandle_setWindow, METH_VARARGS, NULL},
	 { "new_WindowHandle", _wrap_new_WindowHandle, METH_NOARGS, NULL},
	 { "delete_WindowHandle", _wrap_delete_WindowHandle, METH_O, NULL},
	 { "WindowHandle_swigregister", WindowHandle_swigregister, METH_O, NULL},
	 { "WindowHandle_swiginit", WindowHandle_swiginit, METH_VARARGS, NULL},
	 { "VideoWindowHandle_type_set", _wrap_VideoWindowHandle_type_set, METH_VARARGS, NULL},
	 { "VideoWindowHandle_type_get", _wrap_VideoWindowHandle_type_get, METH_O, NULL},
	 { "VideoWindowHandle_handle_set", _wrap_VideoWindowHandle_handle_set, METH_VARARGS, NULL},
	 { "VideoWindowHandle_handle_get", _wrap_VideoWindowHandle_handle_get, METH_O, NULL},
	 { "new_VideoWindowHandle", _wrap_new_VideoWindowHandle, METH_NOARGS, NULL},
	 { "delete_VideoWindowHandle", _wrap_delete_VideoWindowHandle, METH_O, NULL},
	 { "VideoWindowHandle_swigregister", VideoWindowHandle_swigregister, METH_O, NULL},
	 { "VideoWindowHandle_swiginit", VideoWindowHandle_swiginit, METH_VARARGS, NULL},
	 { "VideoWindowInfo_isNative_set", _wrap_VideoWindowInfo_isNative_set, METH_VARARGS, NULL},
	 { "VideoWindowInfo_isNative_get", _wrap_VideoWindowInfo_isNative_get, METH_O, NULL},
	 { "VideoWindowInfo_winHandle_set", _wrap_VideoWindowInfo_winHandle_set, METH_VARARGS, NULL},
	 { "VideoWindowInfo_winHandle_get", _wrap_VideoWindowInfo_winHandle_get, METH_O, NULL},
	 { "VideoWindowInfo_renderDeviceId_set", _wrap_VideoWindowInfo_renderDeviceId_set, METH_VARARGS, NULL},
	 { "VideoWindowInfo_renderDeviceId_get", _wrap_VideoWindowInfo_renderDeviceId_get, METH_O, NULL},
	 { "VideoWindowInfo_show_set", _wrap_VideoWindowInfo_show_set, METH_VARARGS, NULL},
	 { "VideoWindowInfo_show_get", _wrap_VideoWindowInfo_show_get, METH_O, NULL},
	 { "VideoWindowInfo_pos_set", _wrap_VideoWindowInfo_pos_set, METH_VARARGS, NULL},
	 { "VideoWindowInfo_pos_get", _wrap_VideoWindowInfo_pos_get, METH_O, NULL},
	 { "VideoWindowInfo_size_set", _wrap_VideoWindowInfo_size_set, METH_VARARGS, NULL},
	 { "VideoWindowInfo_size_get", _wrap_VideoWindowInfo_size_get, METH_O, NULL},
	 { "new_VideoWindowInfo", _wrap_new_VideoWindowInfo, METH_NOARGS, NULL},
	 { "delete_VideoWindowInfo", _wrap_delete_VideoWindowInfo, METH_O, NULL},
	 { "VideoWindowInfo_swigregister", VideoWindowInfo_swigregister, METH_O, NULL},
	 { "VideoWindowInfo_swiginit", VideoWindowInfo_swiginit, METH_VARARGS, NULL},
	 { "new_VideoWindow", _wrap_new_VideoWindow, METH_O, NULL},
	 { "VideoWindow_getInfo", _wrap_VideoWindow_getInfo, METH_O, NULL},
	 { "VideoWindow_getVideoMedia", _wrap_VideoWindow_getVideoMedia, METH_O, NULL},
	 { "VideoWindow_Show", _wrap_VideoWindow_Show, METH_VARARGS, NULL},
	 { "VideoWindow_setPos", _wrap_VideoWindow_setPos, METH_VARARGS, NULL},
	 { "VideoWindow_setSize", _wrap_VideoWindow_setSize, METH_VARARGS, NULL},
	 { "VideoWindow_rotate", _wrap_VideoWindow_rotate, METH_VARARGS, NULL},
	 { "VideoWindow_setWindow", _wrap_VideoWindow_setWindow, METH_VARARGS, NULL},
	 { "VideoWindow_setFullScreen", _wrap_VideoWindow_setFullScreen, METH_VARARGS, NULL},
	 { "VideoWindow_setFullScreen2", _wrap_VideoWindow_setFullScreen2, METH_VARARGS, NULL},
	 { "delete_VideoWindow", _wrap_delete_VideoWindow, METH_O, NULL},
	 { "VideoWindow_swigregister", VideoWindow_swigregister, METH_O, NULL},
	 { "VideoWindow_swiginit", VideoWindow_swiginit, METH_VARARGS, NULL},
	 { "VideoPreviewOpParam_rendId_set", _wrap_VideoPreviewOpParam_rendId_set, METH_VARARGS, NULL},
	 { "VideoPreviewOpParam_rendId_get", _wrap_VideoPreviewOpParam_rendId_get, METH_O, NULL},
	 { "VideoPreviewOpParam_show_set", _wrap_VideoPreviewOpParam_show_set, METH_VARARGS, NULL},
	 { "VideoPreviewOpParam_show_get", _wrap_VideoPreviewOpParam_show_get, METH_O, NULL},
	 { "VideoPreviewOpParam_windowFlags_set", _wrap_VideoPreviewOpParam_windowFlags_set, METH_VARARGS, NULL},
	 { "VideoPreviewOpParam_windowFlags_get", _wrap_VideoPreviewOpParam_windowFlags_get, METH_O, NULL},
	 { "VideoPreviewOpParam_format_set", _wrap_VideoPreviewOpParam_format_set, METH_VARARGS, NULL},
	 { "VideoPreviewOpParam_format_get", _wrap_VideoPreviewOpParam_format_get, METH_O, NULL},
	 { "VideoPreviewOpParam_window_set", _wrap_VideoPreviewOpParam_window_set, METH_VARARGS, NULL},
	 { "VideoPreviewOpParam_window_get", _wrap_VideoPreviewOpParam_window_get, METH_O, NULL},
	 { "new_VideoPreviewOpParam", _wrap_new_VideoPreviewOpParam, METH_NOARGS, NULL},
	 { "delete_VideoPreviewOpParam", _wrap_delete_VideoPreviewOpParam, METH_O, NULL},
	 { "VideoPreviewOpParam_swigregister", VideoPreviewOpParam_swigregister, METH_O, NULL},
	 { "VideoPreviewOpParam_swiginit", VideoPreviewOpParam_swiginit, METH_VARARGS, NULL},
	 { "new_VideoPreview", _wrap_new_VideoPreview, METH_O, NULL},
	 { "VideoPreview_hasNative", _wrap_VideoPreview_hasNative, METH_O, NULL},
	 { "VideoPreview_start", _wrap_VideoPreview_start, METH_VARARGS, NULL},
	 { "VideoPreview_stop", _wrap_VideoPreview_stop, METH_O, NULL},
	 { "VideoPreview_getVideoWindow", _wrap_VideoPreview_getVideoWindow, METH_O, NULL},
	 { "VideoPreview_getVideoMedia", _wrap_VideoPreview_getVideoMedia, METH_O, NULL},
	 { "delete_VideoPreview", _wrap_delete_VideoPreview, METH_O, NULL},
	 { "VideoPreview_swigregister", VideoPreview_swigregister, METH_O, NULL},
	 { "VideoPreview_swiginit", VideoPreview_swiginit, METH_VARARGS, NULL},
	 { "VideoDevInfo_id_set", _wrap_VideoDevInfo_id_set, METH_VARARGS, NULL},
	 { "VideoDevInfo_id_get", _wrap_VideoDevInfo_id_get, METH_O, NULL},
	 { "VideoDevInfo_name_set", _wrap_VideoDevInfo_name_set, METH_VARARGS, NULL},
	 { "VideoDevInfo_name_get", _wrap_VideoDevInfo_name_get, METH_O, NULL},
	 { "VideoDevInfo_driver_set", _wrap_VideoDevInfo_driver_set, METH_VARARGS, NULL},
	 { "VideoDevInfo_driver_get", _wrap_VideoDevInfo_driver_get, METH_O, NULL},
	 { "VideoDevInfo_dir_set", _wrap_VideoDevInfo_dir_set, METH_VARARGS, NULL},
	 { "VideoDevInfo_dir_get", _wrap_VideoDevInfo_dir_get, METH_O, NULL},
	 { "VideoDevInfo_caps_set", _wrap_VideoDevInfo_caps_set, METH_VARARGS, NULL},
	 { "VideoDevInfo_caps_get", _wrap_VideoDevInfo_caps_get, METH_O, NULL},
	 { "VideoDevInfo_fmt_set", _wrap_VideoDevInfo_fmt_set, METH_VARARGS, NULL},
	 { "VideoDevInfo_fmt_get", _wrap_VideoDevInfo_fmt_get, METH_O, NULL},
	 { "new_VideoDevInfo", _wrap_new_VideoDevInfo, METH_NOARGS, NULL},
	 { "delete_VideoDevInfo", _wrap_delete_VideoDevInfo, METH_O, NULL},
	 { "VideoDevInfo_swigregister", VideoDevInfo_swigregister, METH_O, NULL},
	 { "VideoDevInfo_swiginit", VideoDevInfo_swiginit, METH_VARARGS, NULL},
	 { "VideoSwitchParam_target_id_set", _wrap_VideoSwitchParam_target_id_set, METH_VARARGS, NULL},
	 { "VideoSwitchParam_target_id_get", _wrap_VideoSwitchParam_target_id_get, METH_O, NULL},
	 { "new_VideoSwitchParam", _wrap_new_VideoSwitchParam, METH_NOARGS, NULL},
	 { "delete_VideoSwitchParam", _wrap_delete_VideoSwitchParam, METH_O, NULL},
	 { "VideoSwitchParam_swigregister", VideoSwitchParam_swigregister, METH_O, NULL},
	 { "VideoSwitchParam_swiginit", VideoSwitchParam_swiginit, METH_VARARGS, NULL},
	 { "VidDevManager_initSubsys", _wrap_VidDevManager_initSubsys, METH_O, NULL},
	 { "VidDevManager_refreshDevs", _wrap_VidDevManager_refreshDevs, METH_O, NULL},
	 { "VidDevManager_getDevCount", _wrap_VidDevManager_getDevCount, METH_O, NULL},
	 { "VidDevManager_getDevInfo", _wrap_VidDevManager_getDevInfo, METH_VARARGS, NULL},
	 { "VidDevManager_enumDev2", _wrap_VidDevManager_enumDev2, METH_O, NULL},
	 { "VidDevManager_lookupDev", _wrap_VidDevManager_lookupDev, METH_VARARGS, NULL},
	 { "VidDevManager_capName", _wrap_VidDevManager_capName, METH_VARARGS, NULL},
	 { "VidDevManager_setFormat", _wrap_VidDevManager_setFormat, METH_VARARGS, NULL},
	 { "VidDevManager_getFormat", _wrap_VidDevManager_getFormat, METH_VARARGS, NULL},
	 { "VidDevManager_setInputScale", _wrap_VidDevManager_setInputScale, METH_VARARGS, NULL},
	 { "VidDevManager_getInputScale", _wrap_VidDevManager_getInputScale, METH_VARARGS, NULL},
	 { "VidDevManager_setOutputWindowFlags", _wrap_VidDevManager_setOutputWindowFlags, METH_VARARGS, NULL},
	 { "VidDevManager_getOutputWindowFlags", _wrap_VidDevManager_getOutputWindowFlags, METH_VARARGS, NULL},
	 { "VidDevManager_switchDev", _wrap_VidDevManager_switchDev, METH_VARARGS, NULL},
	 { "VidDevManager_isCaptureActive", _wrap_VidDevManager_isCaptureActive, METH_VARARGS, NULL},
	 { "VidDevManager_setCaptureOrient", _wrap_VidDevManager_setCaptureOrient, METH_VARARGS, NULL},
	 { "VidDevManager_swigregister", VidDevManager_swigregister, METH_O, NULL},
	 { "CodecInfo_codecId_set", _wrap_CodecInfo_codecId_set, METH_VARARGS, NULL},
	 { "CodecInfo_codecId_get", _wrap_CodecInfo_codecId_get, METH_O, NULL},
	 { "CodecInfo_priority_set", _wrap_CodecInfo_priority_set, METH_VARARGS, NULL},
	 { "CodecInfo_priority_get", _wrap_CodecInfo_priority_get, METH_O, NULL},
	 { "CodecInfo_desc_set", _wrap_CodecInfo_desc_set, METH_VARARGS, NULL},
	 { "CodecInfo_desc_get", _wrap_CodecInfo_desc_get, METH_O, NULL},
	 { "new_CodecInfo", _wrap_new_CodecInfo, METH_NOARGS, NULL},
	 { "delete_CodecInfo", _wrap_delete_CodecInfo, METH_O, NULL},
	 { "CodecInfo_swigregister", CodecInfo_swigregister, METH_O, NULL},
	 { "CodecInfo_swiginit", CodecInfo_swiginit, METH_VARARGS, NULL},
	 { "CodecFmtp_name_set", _wrap_CodecFmtp_name_set, METH_VARARGS, NULL},
	 { "CodecFmtp_name_get", _wrap_CodecFmtp_name_get, METH_O, NULL},
	 { "CodecFmtp_val_set", _wrap_CodecFmtp_val_set, METH_VARARGS, NULL},
	 { "CodecFmtp_val_get", _wrap_CodecFmtp_val_get, METH_O, NULL},
	 { "new_CodecFmtp", _wrap_new_CodecFmtp, METH_NOARGS, NULL},
	 { "delete_CodecFmtp", _wrap_delete_CodecFmtp, METH_O, NULL},
	 { "CodecFmtp_swigregister", CodecFmtp_swigregister, METH_O, NULL},
	 { "CodecFmtp_swiginit", CodecFmtp_swiginit, METH_VARARGS, NULL},
	 { "CodecParamInfo_clockRate_set", _wrap_CodecParamInfo_clockRate_set, METH_VARARGS, NULL},
	 { "CodecParamInfo_clockRate_get", _wrap_CodecParamInfo_clockRate_get, METH_O, NULL},
	 { "CodecParamInfo_channelCnt_set", _wrap_CodecParamInfo_channelCnt_set, METH_VARARGS, NULL},
	 { "CodecParamInfo_channelCnt_get", _wrap_CodecParamInfo_channelCnt_get, METH_O, NULL},
	 { "CodecParamInfo_avgBps_set", _wrap_CodecParamInfo_avgBps_set, METH_VARARGS, NULL},
	 { "CodecParamInfo_avgBps_get", _wrap_CodecParamInfo_avgBps_get, METH_O, NULL},
	 { "CodecParamInfo_maxBps_set", _wrap_CodecParamInfo_maxBps_set, METH_VARARGS, NULL},
	 { "CodecParamInfo_maxBps_get", _wrap_CodecParamInfo_maxBps_get, METH_O, NULL},
	 { "CodecParamInfo_maxRxFrameSize_set", _wrap_CodecParamInfo_maxRxFrameSize_set, METH_VARARGS, NULL},
	 { "CodecParamInfo_maxRxFrameSize_get", _wrap_CodecParamInfo_maxRxFrameSize_get, METH_O, NULL},
	 { "CodecParamInfo_frameLen_set", _wrap_CodecParamInfo_frameLen_set, METH_VARARGS, NULL},
	 { "CodecParamInfo_frameLen_get", _wrap_CodecParamInfo_frameLen_get, METH_O, NULL},
	 { "CodecParamInfo_pcmBitsPerSample_set", _wrap_CodecParamInfo_pcmBitsPerSample_set, METH_VARARGS, NULL},
	 { "CodecParamInfo_pcmBitsPerSample_get", _wrap_CodecParamInfo_pcmBitsPerSample_get, METH_O, NULL},
	 { "CodecParamInfo_pt_set", _wrap_CodecParamInfo_pt_set, METH_VARARGS, NULL},
	 { "CodecParamInfo_pt_get", _wrap_CodecParamInfo_pt_get, METH_O, NULL},
	 { "CodecParamInfo_fmtId_set", _wrap_CodecParamInfo_fmtId_set, METH_VARARGS, NULL},
	 { "CodecParamInfo_fmtId_get", _wrap_CodecParamInfo_fmtId_get, METH_O, NULL},
	 { "new_CodecParamInfo", _wrap_new_CodecParamInfo, METH_NOARGS, NULL},
	 { "delete_CodecParamInfo", _wrap_delete_CodecParamInfo, METH_O, NULL},
	 { "CodecParamInfo_swigregister", CodecParamInfo_swigregister, METH_O, NULL},
	 { "CodecParamInfo_swiginit", CodecParamInfo_swiginit, METH_VARARGS, NULL},
	 { "CodecParamSetting_frmPerPkt_set", _wrap_CodecParamSetting_frmPerPkt_set, METH_VARARGS, NULL},
	 { "CodecParamSetting_frmPerPkt_get", _wrap_CodecParamSetting_frmPerPkt_get, METH_O, NULL},
	 { "CodecParamSetting_vad_set", _wrap_CodecParamSetting_vad_set, METH_VARARGS, NULL},
	 { "CodecParamSetting_vad_get", _wrap_CodecParamSetting_vad_get, METH_O, NULL},
	 { "CodecParamSetting_cng_set", _wrap_CodecParamSetting_cng_set, METH_VARARGS, NULL},
	 { "CodecParamSetting_cng_get", _wrap_CodecParamSetting_cng_get, METH_O, NULL},
	 { "CodecParamSetting_penh_set", _wrap_CodecParamSetting_penh_set, METH_VARARGS, NULL},
	 { "CodecParamSetting_penh_get", _wrap_CodecParamSetting_penh_get, METH_O, NULL},
	 { "CodecParamSetting_plc_set", _wrap_CodecParamSetting_plc_set, METH_VARARGS, NULL},
	 { "CodecParamSetting_plc_get", _wrap_CodecParamSetting_plc_get, METH_O, NULL},
	 { "CodecParamSetting_reserved_set", _wrap_CodecParamSetting_reserved_set, METH_VARARGS, NULL},
	 { "CodecParamSetting_reserved_get", _wrap_CodecParamSetting_reserved_get, METH_O, NULL},
	 { "CodecParamSetting_encFmtp_set", _wrap_CodecParamSetting_encFmtp_set, METH_VARARGS, NULL},
	 { "CodecParamSetting_encFmtp_get", _wrap_CodecParamSetting_encFmtp_get, METH_O, NULL},
	 { "CodecParamSetting_decFmtp_set", _wrap_CodecParamSetting_decFmtp_set, METH_VARARGS, NULL},
	 { "CodecParamSetting_decFmtp_get", _wrap_CodecParamSetting_decFmtp_get, METH_O, NULL},
	 { "new_CodecParamSetting", _wrap_new_CodecParamSetting, METH_NOARGS, NULL},
	 { "delete_CodecParamSetting", _wrap_delete_CodecParamSetting, METH_O, NULL},
	 { "CodecParamSetting_swigregister", CodecParamSetting_swigregister, METH_O, NULL},
	 { "CodecParamSetting_swiginit", CodecParamSetting_swiginit, METH_VARARGS, NULL},
	 { "CodecParam_info_set", _wrap_CodecParam_info_set, METH_VARARGS, NULL},
	 { "CodecParam_info_get", _wrap_CodecParam_info_get, METH_O, NULL},
	 { "CodecParam_setting_set", _wrap_CodecParam_setting_set, METH_VARARGS, NULL},
	 { "CodecParam_setting_get", _wrap_CodecParam_setting_get, METH_O, NULL},
	 { "new_CodecParam", _wrap_new_CodecParam, METH_NOARGS, NULL},
	 { "delete_CodecParam", _wrap_delete_CodecParam, METH_O, NULL},
	 { "CodecParam_swigregister", CodecParam_swigregister, METH_O, NULL},
	 { "CodecParam_swiginit", CodecParam_swiginit, METH_VARARGS, NULL},
	 { "CodecOpusConfig_sample_rate_set", _wrap_CodecOpusConfig_sample_rate_set, METH_VARARGS, NULL},
	 { "CodecOpusConfig_sample_rate_get", _wrap_CodecOpusConfig_sample_rate_get, METH_O, NULL},
	 { "CodecOpusConfig_channel_cnt_set", _wrap_CodecOpusConfig_channel_cnt_set, METH_VARARGS, NULL},
	 { "CodecOpusConfig_channel_cnt_get", _wrap_CodecOpusConfig_channel_cnt_get, METH_O, NULL},
	 { "CodecOpusConfig_frm_ptime_set", _wrap_CodecOpusConfig_frm_ptime_set, METH_VARARGS, NULL},
	 { "CodecOpusConfig_frm_ptime_get", _wrap_CodecOpusConfig_frm_ptime_get, METH_O, NULL},
	 { "CodecOpusConfig_bit_rate_set", _wrap_CodecOpusConfig_bit_rate_set, METH_VARARGS, NULL},
	 { "CodecOpusConfig_bit_rate_get", _wrap_CodecOpusConfig_bit_rate_get, METH_O, NULL},
	 { "CodecOpusConfig_packet_loss_set", _wrap_CodecOpusConfig_packet_loss_set, METH_VARARGS, NULL},
	 { "CodecOpusConfig_packet_loss_get", _wrap_CodecOpusConfig_packet_loss_get, METH_O, NULL},
	 { "CodecOpusConfig_complexity_set", _wrap_CodecOpusConfig_complexity_set, METH_VARARGS, NULL},
	 { "CodecOpusConfig_complexity_get", _wrap_CodecOpusConfig_complexity_get, METH_O, NULL},
	 { "CodecOpusConfig_cbr_set", _wrap_CodecOpusConfig_cbr_set, METH_VARARGS, NULL},
	 { "CodecOpusConfig_cbr_get", _wrap_CodecOpusConfig_cbr_get, METH_O, NULL},
	 { "new_CodecOpusConfig", _wrap_new_CodecOpusConfig, METH_NOARGS, NULL},
	 { "delete_CodecOpusConfig", _wrap_delete_CodecOpusConfig, METH_O, NULL},
	 { "CodecOpusConfig_swigregister", CodecOpusConfig_swigregister, METH_O, NULL},
	 { "CodecOpusConfig_swiginit", CodecOpusConfig_swiginit, METH_VARARGS, NULL},
	 { "VidCodecParam_dir_set", _wrap_VidCodecParam_dir_set, METH_VARARGS, NULL},
	 { "VidCodecParam_dir_get", _wrap_VidCodecParam_dir_get, METH_O, NULL},
	 { "VidCodecParam_packing_set", _wrap_VidCodecParam_packing_set, METH_VARARGS, NULL},
	 { "VidCodecParam_packing_get", _wrap_VidCodecParam_packing_get, METH_O, NULL},
	 { "VidCodecParam_encFmt_set", _wrap_VidCodecParam_encFmt_set, METH_VARARGS, NULL},
	 { "VidCodecParam_encFmt_get", _wrap_VidCodecParam_encFmt_get, METH_O, NULL},
	 { "VidCodecParam_encFmtp_set", _wrap_VidCodecParam_encFmtp_set, METH_VARARGS, NULL},
	 { "VidCodecParam_encFmtp_get", _wrap_VidCodecParam_encFmtp_get, METH_O, NULL},
	 { "VidCodecParam_encMtu_set", _wrap_VidCodecParam_encMtu_set, METH_VARARGS, NULL},
	 { "VidCodecParam_encMtu_get", _wrap_VidCodecParam_encMtu_get, METH_O, NULL},
	 { "VidCodecParam_decFmt_set", _wrap_VidCodecParam_decFmt_set, METH_VARARGS, NULL},
	 { "VidCodecParam_decFmt_get", _wrap_VidCodecParam_decFmt_get, METH_O, NULL},
	 { "VidCodecParam_decFmtp_set", _wrap_VidCodecParam_decFmtp_set, METH_VARARGS, NULL},
	 { "VidCodecParam_decFmtp_get", _wrap_VidCodecParam_decFmtp_get, METH_O, NULL},
	 { "VidCodecParam_ignoreFmtp_set", _wrap_VidCodecParam_ignoreFmtp_set, METH_VARARGS, NULL},
	 { "VidCodecParam_ignoreFmtp_get", _wrap_VidCodecParam_ignoreFmtp_get, METH_O, NULL},
	 { "new_VidCodecParam", _wrap_new_VidCodecParam, METH_NOARGS, NULL},
	 { "delete_VidCodecParam", _wrap_delete_VidCodecParam, METH_O, NULL},
	 { "VidCodecParam_swigregister", VidCodecParam_swigregister, METH_O, NULL},
	 { "VidCodecParam_swiginit", VidCodecParam_swiginit, METH_VARARGS, NULL},
	 { "MediaFmtChangedEvent_newWidth_set", _wrap_MediaFmtChangedEvent_newWidth_set, METH_VARARGS, NULL},
	 { "MediaFmtChangedEvent_newWidth_get", _wrap_MediaFmtChangedEvent_newWidth_get, METH_O, NULL},
	 { "MediaFmtChangedEvent_newHeight_set", _wrap_MediaFmtChangedEvent_newHeight_set, METH_VARARGS, NULL},
	 { "MediaFmtChangedEvent_newHeight_get", _wrap_MediaFmtChangedEvent_newHeight_get, METH_O, NULL},
	 { "new_MediaFmtChangedEvent", _wrap_new_MediaFmtChangedEvent, METH_NOARGS, NULL},
	 { "delete_MediaFmtChangedEvent", _wrap_delete_MediaFmtChangedEvent, METH_O, NULL},
	 { "MediaFmtChangedEvent_swigregister", MediaFmtChangedEvent_swigregister, METH_O, NULL},
	 { "MediaFmtChangedEvent_swiginit", MediaFmtChangedEvent_swiginit, METH_VARARGS, NULL},
	 { "AudDevErrorEvent_dir_set", _wrap_AudDevErrorEvent_dir_set, METH_VARARGS, NULL},
	 { "AudDevErrorEvent_dir_get", _wrap_AudDevErrorEvent_dir_get, METH_O, NULL},
	 { "AudDevErrorEvent_id_set", _wrap_AudDevErrorEvent_id_set, METH_VARARGS, NULL},
	 { "AudDevErrorEvent_id_get", _wrap_AudDevErrorEvent_id_get, METH_O, NULL},
	 { "AudDevErrorEvent_status_set", _wrap_AudDevErrorEvent_status_set, METH_VARARGS, NULL},
	 { "AudDevErrorEvent_status_get", _wrap_AudDevErrorEvent_status_get, METH_O, NULL},
	 { "new_AudDevErrorEvent", _wrap_new_AudDevErrorEvent, METH_NOARGS, NULL},
	 { "delete_AudDevErrorEvent", _wrap_delete_AudDevErrorEvent, METH_O, NULL},
	 { "AudDevErrorEvent_swigregister", AudDevErrorEvent_swigregister, METH_O, NULL},
	 { "AudDevErrorEvent_swiginit", AudDevErrorEvent_swiginit, METH_VARARGS, NULL},
	 { "MediaEventData_fmtChanged_set", _wrap_MediaEventData_fmtChanged_set, METH_VARARGS, NULL},
	 { "MediaEventData_fmtChanged_get", _wrap_MediaEventData_fmtChanged_get, METH_O, NULL},
	 { "MediaEventData_audDevError_set", _wrap_MediaEventData_audDevError_set, METH_VARARGS, NULL},
	 { "MediaEventData_audDevError_get", _wrap_MediaEventData_audDevError_get, METH_O, NULL},
	 { "MediaEventData_ptr_set", _wrap_MediaEventData_ptr_set, METH_VARARGS, NULL},
	 { "MediaEventData_ptr_get", _wrap_MediaEventData_ptr_get, METH_O, NULL},
	 { "new_MediaEventData", _wrap_new_MediaEventData, METH_NOARGS, NULL},
	 { "delete_MediaEventData", _wrap_delete_MediaEventData, METH_O, NULL},
	 { "MediaEventData_swigregister", MediaEventData_swigregister, METH_O, NULL},
	 { "MediaEventData_swiginit", MediaEventData_swiginit, METH_VARARGS, NULL},
	 { "MediaEvent_type_set", _wrap_MediaEvent_type_set, METH_VARARGS, NULL},
	 { "MediaEvent_type_get", _wrap_MediaEvent_type_get, METH_O, NULL},
	 { "MediaEvent_data_set", _wrap_MediaEvent_data_set, METH_VARARGS, NULL},
	 { "MediaEvent_data_get", _wrap_MediaEvent_data_get, METH_O, NULL},
	 { "MediaEvent_pjMediaEvent_set", _wrap_MediaEvent_pjMediaEvent_set, METH_VARARGS, NULL},
	 { "MediaEvent_pjMediaEvent_get", _wrap_MediaEvent_pjMediaEvent_get, METH_O, NULL},
	 { "new_MediaEvent", _wrap_new_MediaEvent, METH_NOARGS, NULL},
	 { "delete_MediaEvent", _wrap_delete_MediaEvent, METH_O, NULL},
	 { "MediaEvent_swigregister", MediaEvent_swigregister, METH_O, NULL},
	 { "MediaEvent_swiginit", MediaEvent_swiginit, METH_VARARGS, NULL},
	 { "PresenceStatus_status_set", _wrap_PresenceStatus_status_set, METH_VARARGS, NULL},
	 { "PresenceStatus_status_get", _wrap_PresenceStatus_status_get, METH_O, NULL},
	 { "PresenceStatus_statusText_set", _wrap_PresenceStatus_statusText_set, METH_VARARGS, NULL},
	 { "PresenceStatus_statusText_get", _wrap_PresenceStatus_statusText_get, METH_O, NULL},
	 { "PresenceStatus_activity_set", _wrap_PresenceStatus_activity_set, METH_VARARGS, NULL},
	 { "PresenceStatus_activity_get", _wrap_PresenceStatus_activity_get, METH_O, NULL},
	 { "PresenceStatus_note_set", _wrap_PresenceStatus_note_set, METH_VARARGS, NULL},
	 { "PresenceStatus_note_get", _wrap_PresenceStatus_note_get, METH_O, NULL},
	 { "PresenceStatus_rpidId_set", _wrap_PresenceStatus_rpidId_set, METH_VARARGS, NULL},
	 { "PresenceStatus_rpidId_get", _wrap_PresenceStatus_rpidId_get, METH_O, NULL},
	 { "new_PresenceStatus", _wrap_new_PresenceStatus, METH_NOARGS, NULL},
	 { "delete_PresenceStatus", _wrap_delete_PresenceStatus, METH_O, NULL},
	 { "PresenceStatus_swigregister", PresenceStatus_swigregister, METH_O, NULL},
	 { "PresenceStatus_swiginit", PresenceStatus_swiginit, METH_VARARGS, NULL},
	 { "BuddyConfig_uri_set", _wrap_BuddyConfig_uri_set, METH_VARARGS, NULL},
	 { "BuddyConfig_uri_get", _wrap_BuddyConfig_uri_get, METH_O, NULL},
	 { "BuddyConfig_subscribe_set", _wrap_BuddyConfig_subscribe_set, METH_VARARGS, NULL},
	 { "BuddyConfig_subscribe_get", _wrap_BuddyConfig_subscribe_get, METH_O, NULL},
	 { "BuddyConfig_readObject", _wrap_BuddyConfig_readObject, METH_VARARGS, NULL},
	 { "BuddyConfig_writeObject", _wrap_BuddyConfig_writeObject, METH_VARARGS, NULL},
	 { "new_BuddyConfig", _wrap_new_BuddyConfig, METH_NOARGS, NULL},
	 { "delete_BuddyConfig", _wrap_delete_BuddyConfig, METH_O, NULL},
	 { "BuddyConfig_swigregister", BuddyConfig_swigregister, METH_O, NULL},
	 { "BuddyConfig_swiginit", BuddyConfig_swiginit, METH_VARARGS, NULL},
	 { "BuddyInfo_uri_set", _wrap_BuddyInfo_uri_set, METH_VARARGS, NULL},
	 { "BuddyInfo_uri_get", _wrap_BuddyInfo_uri_get, METH_O, NULL},
	 { "BuddyInfo_contact_set", _wrap_BuddyInfo_contact_set, METH_VARARGS, NULL},
	 { "BuddyInfo_contact_get", _wrap_BuddyInfo_contact_get, METH_O, NULL},
	 { "BuddyInfo_presMonitorEnabled_set", _wrap_BuddyInfo_presMonitorEnabled_set, METH_VARARGS, NULL},
	 { "BuddyInfo_presMonitorEnabled_get", _wrap_BuddyInfo_presMonitorEnabled_get, METH_O, NULL},
	 { "BuddyInfo_subState_set", _wrap_BuddyInfo_subState_set, METH_VARARGS, NULL},
	 { "BuddyInfo_subState_get", _wrap_BuddyInfo_subState_get, METH_O, NULL},
	 { "BuddyInfo_subStateName_set", _wrap_BuddyInfo_subStateName_set, METH_VARARGS, NULL},
	 { "BuddyInfo_subStateName_get", _wrap_BuddyInfo_subStateName_get, METH_O, NULL},
	 { "BuddyInfo_subTermCode_set", _wrap_BuddyInfo_subTermCode_set, METH_VARARGS, NULL},
	 { "BuddyInfo_subTermCode_get", _wrap_BuddyInfo_subTermCode_get, METH_O, NULL},
	 { "BuddyInfo_subTermReason_set", _wrap_BuddyInfo_subTermReason_set, METH_VARARGS, NULL},
	 { "BuddyInfo_subTermReason_get", _wrap_BuddyInfo_subTermReason_get, METH_O, NULL},
	 { "BuddyInfo_presStatus_set", _wrap_BuddyInfo_presStatus_set, METH_VARARGS, NULL},
	 { "BuddyInfo_presStatus_get", _wrap_BuddyInfo_presStatus_get, METH_O, NULL},
	 { "new_BuddyInfo", _wrap_new_BuddyInfo, METH_NOARGS, NULL},
	 { "delete_BuddyInfo", _wrap_delete_BuddyInfo, METH_O, NULL},
	 { "BuddyInfo_swigregister", BuddyInfo_swigregister, METH_O, NULL},
	 { "BuddyInfo_swiginit", BuddyInfo_swiginit, METH_VARARGS, NULL},
	 { "OnBuddyEvSubStateParam_e_set", _wrap_OnBuddyEvSubStateParam_e_set, METH_VARARGS, NULL},
	 { "OnBuddyEvSubStateParam_e_get", _wrap_OnBuddyEvSubStateParam_e_get, METH_O, NULL},
	 { "new_OnBuddyEvSubStateParam", _wrap_new_OnBuddyEvSubStateParam, METH_NOARGS, NULL},
	 { "delete_OnBuddyEvSubStateParam", _wrap_delete_OnBuddyEvSubStateParam, METH_O, NULL},
	 { "OnBuddyEvSubStateParam_swigregister", OnBuddyEvSubStateParam_swigregister, METH_O, NULL},
	 { "OnBuddyEvSubStateParam_swiginit", OnBuddyEvSubStateParam_swiginit, METH_VARARGS, NULL},
	 { "new_Buddy", _wrap_new_Buddy, METH_O, NULL},
	 { "delete_Buddy", _wrap_delete_Buddy, METH_O, NULL},
	 { "Buddy_create", _wrap_Buddy_create, METH_VARARGS, NULL},
	 { "Buddy_isValid", _wrap_Buddy_isValid, METH_O, NULL},
	 { "Buddy_getId", _wrap_Buddy_getId, METH_O, NULL},
	 { "Buddy_getInfo", _wrap_Buddy_getInfo, METH_O, NULL},
	 { "Buddy_subscribePresence", _wrap_Buddy_subscribePresence, METH_VARARGS, NULL},
	 { "Buddy_updatePresence", _wrap_Buddy_updatePresence, METH_O, NULL},
	 { "Buddy_sendInstantMessage", _wrap_Buddy_sendInstantMessage, METH_VARARGS, NULL},
	 { "Buddy_sendTypingIndication", _wrap_Buddy_sendTypingIndication, METH_VARARGS, NULL},
	 { "Buddy_onBuddyState", _wrap_Buddy_onBuddyState, METH_O, NULL},
	 { "Buddy_onBuddyEvSubState", _wrap_Buddy_onBuddyEvSubState, METH_VARARGS, NULL},
	 { "disown_Buddy", _wrap_disown_Buddy, METH_O, NULL},
	 { "Buddy_swigregister", Buddy_swigregister, METH_O, NULL},
	 { "Buddy_swiginit", Buddy_swiginit, METH_VARARGS, NULL},
	 { "AccountRegConfig_registrarUri_set", _wrap_AccountRegConfig_registrarUri_set, METH_VARARGS, NULL},
	 { "AccountRegConfig_registrarUri_get", _wrap_AccountRegConfig_registrarUri_get, METH_O, NULL},
	 { "AccountRegConfig_registerOnAdd_set", _wrap_AccountRegConfig_registerOnAdd_set, METH_VARARGS, NULL},
	 { "AccountRegConfig_registerOnAdd_get", _wrap_AccountRegConfig_registerOnAdd_get, METH_O, NULL},
	 { "AccountRegConfig_headers_set", _wrap_AccountRegConfig_headers_set, METH_VARARGS, NULL},
	 { "AccountRegConfig_headers_get", _wrap_AccountRegConfig_headers_get, METH_O, NULL},
	 { "AccountRegConfig_contactParams_set", _wrap_AccountRegConfig_contactParams_set, METH_VARARGS, NULL},
	 { "AccountRegConfig_contactParams_get", _wrap_AccountRegConfig_contactParams_get, METH_O, NULL},
	 { "AccountRegConfig_contactUriParams_set", _wrap_AccountRegConfig_contactUriParams_set, METH_VARARGS, NULL},
	 { "AccountRegConfig_contactUriParams_get", _wrap_AccountRegConfig_contactUriParams_get, METH_O, NULL},
	 { "AccountRegConfig_timeoutSec_set", _wrap_AccountRegConfig_timeoutSec_set, METH_VARARGS, NULL},
	 { "AccountRegConfig_timeoutSec_get", _wrap_AccountRegConfig_timeoutSec_get, METH_O, NULL},
	 { "AccountRegConfig_retryIntervalSec_set", _wrap_AccountRegConfig_retryIntervalSec_set, METH_VARARGS, NULL},
	 { "AccountRegConfig_retryIntervalSec_get", _wrap_AccountRegConfig_retryIntervalSec_get, METH_O, NULL},
	 { "AccountRegConfig_firstRetryIntervalSec_set", _wrap_AccountRegConfig_firstRetryIntervalSec_set, METH_VARARGS, NULL},
	 { "AccountRegConfig_firstRetryIntervalSec_get", _wrap_AccountRegConfig_firstRetryIntervalSec_get, METH_O, NULL},
	 { "AccountRegConfig_randomRetryIntervalSec_set", _wrap_AccountRegConfig_randomRetryIntervalSec_set, METH_VARARGS, NULL},
	 { "AccountRegConfig_randomRetryIntervalSec_get", _wrap_AccountRegConfig_randomRetryIntervalSec_get, METH_O, NULL},
	 { "AccountRegConfig_delayBeforeRefreshSec_set", _wrap_AccountRegConfig_delayBeforeRefreshSec_set, METH_VARARGS, NULL},
	 { "AccountRegConfig_delayBeforeRefreshSec_get", _wrap_AccountRegConfig_delayBeforeRefreshSec_get, METH_O, NULL},
	 { "AccountRegConfig_dropCallsOnFail_set", _wrap_AccountRegConfig_dropCallsOnFail_set, METH_VARARGS, NULL},
	 { "AccountRegConfig_dropCallsOnFail_get", _wrap_AccountRegConfig_dropCallsOnFail_get, METH_O, NULL},
	 { "AccountRegConfig_unregWaitMsec_set", _wrap_AccountRegConfig_unregWaitMsec_set, METH_VARARGS, NULL},
	 { "AccountRegConfig_unregWaitMsec_get", _wrap_AccountRegConfig_unregWaitMsec_get, METH_O, NULL},
	 { "AccountRegConfig_proxyUse_set", _wrap_AccountRegConfig_proxyUse_set, METH_VARARGS, NULL},
	 { "AccountRegConfig_proxyUse_get", _wrap_AccountRegConfig_proxyUse_get, METH_O, NULL},
	 { "AccountRegConfig_readObject", _wrap_AccountRegConfig_readObject, METH_VARARGS, NULL},
	 { "AccountRegConfig_writeObject", _wrap_AccountRegConfig_writeObject, METH_VARARGS, NULL},
	 { "new_AccountRegConfig", _wrap_new_AccountRegConfig, METH_NOARGS, NULL},
	 { "delete_AccountRegConfig", _wrap_delete_AccountRegConfig, METH_O, NULL},
	 { "AccountRegConfig_swigregister", AccountRegConfig_swigregister, METH_O, NULL},
	 { "AccountRegConfig_swiginit", AccountRegConfig_swiginit, METH_VARARGS, NULL},
	 { "AccountSipConfig_authCreds_set", _wrap_AccountSipConfig_authCreds_set, METH_VARARGS, NULL},
	 { "AccountSipConfig_authCreds_get", _wrap_AccountSipConfig_authCreds_get, METH_O, NULL},
	 { "AccountSipConfig_proxies_set", _wrap_AccountSipConfig_proxies_set, METH_VARARGS, NULL},
	 { "AccountSipConfig_proxies_get", _wrap_AccountSipConfig_proxies_get, METH_O, NULL},
	 { "AccountSipConfig_contactForced_set", _wrap_AccountSipConfig_contactForced_set, METH_VARARGS, NULL},
	 { "AccountSipConfig_contactForced_get", _wrap_AccountSipConfig_contactForced_get, METH_O, NULL},
	 { "AccountSipConfig_contactParams_set", _wrap_AccountSipConfig_contactParams_set, METH_VARARGS, NULL},
	 { "AccountSipConfig_contactParams_get", _wrap_AccountSipConfig_contactParams_get, METH_O, NULL},
	 { "AccountSipConfig_contactUriParams_set", _wrap_AccountSipConfig_contactUriParams_set, METH_VARARGS, NULL},
	 { "AccountSipConfig_contactUriParams_get", _wrap_AccountSipConfig_contactUriParams_get, METH_O, NULL},
	 { "AccountSipConfig_authInitialEmpty_set", _wrap_AccountSipConfig_authInitialEmpty_set, METH_VARARGS, NULL},
	 { "AccountSipConfig_authInitialEmpty_get", _wrap_AccountSipConfig_authInitialEmpty_get, METH_O, NULL},
	 { "AccountSipConfig_authInitialAlgorithm_set", _wrap_AccountSipConfig_authInitialAlgorithm_set, METH_VARARGS, NULL},
	 { "AccountSipConfig_authInitialAlgorithm_get", _wrap_AccountSipConfig_authInitialAlgorithm_get, METH_O, NULL},
	 { "AccountSipConfig_transportId_set", _wrap_AccountSipConfig_transportId_set, METH_VARARGS, NULL},
	 { "AccountSipConfig_transportId_get", _wrap_AccountSipConfig_transportId_get, METH_O, NULL},
	 { "AccountSipConfig_readObject", _wrap_AccountSipConfig_readObject, METH_VARARGS, NULL},
	 { "AccountSipConfig_writeObject", _wrap_AccountSipConfig_writeObject, METH_VARARGS, NULL},
	 { "new_AccountSipConfig", _wrap_new_AccountSipConfig, METH_NOARGS, NULL},
	 { "delete_AccountSipConfig", _wrap_delete_AccountSipConfig, METH_O, NULL},
	 { "AccountSipConfig_swigregister", AccountSipConfig_swigregister, METH_O, NULL},
	 { "AccountSipConfig_swiginit", AccountSipConfig_swiginit, METH_VARARGS, NULL},
	 { "AccountCallConfig_holdType_set", _wrap_AccountCallConfig_holdType_set, METH_VARARGS, NULL},
	 { "AccountCallConfig_holdType_get", _wrap_AccountCallConfig_holdType_get, METH_O, NULL},
	 { "AccountCallConfig_prackUse_set", _wrap_AccountCallConfig_prackUse_set, METH_VARARGS, NULL},
	 { "AccountCallConfig_prackUse_get", _wrap_AccountCallConfig_prackUse_get, METH_O, NULL},
	 { "AccountCallConfig_timerUse_set", _wrap_AccountCallConfig_timerUse_set, METH_VARARGS, NULL},
	 { "AccountCallConfig_timerUse_get", _wrap_AccountCallConfig_timerUse_get, METH_O, NULL},
	 { "AccountCallConfig_timerMinSESec_set", _wrap_AccountCallConfig_timerMinSESec_set, METH_VARARGS, NULL},
	 { "AccountCallConfig_timerMinSESec_get", _wrap_AccountCallConfig_timerMinSESec_get, METH_O, NULL},
	 { "AccountCallConfig_timerSessExpiresSec_set", _wrap_AccountCallConfig_timerSessExpiresSec_set, METH_VARARGS, NULL},
	 { "AccountCallConfig_timerSessExpiresSec_get", _wrap_AccountCallConfig_timerSessExpiresSec_get, METH_O, NULL},
	 { "new_AccountCallConfig", _wrap_new_AccountCallConfig, METH_NOARGS, NULL},
	 { "AccountCallConfig_readObject", _wrap_AccountCallConfig_readObject, METH_VARARGS, NULL},
	 { "AccountCallConfig_writeObject", _wrap_AccountCallConfig_writeObject, METH_VARARGS, NULL},
	 { "delete_AccountCallConfig", _wrap_delete_AccountCallConfig, METH_O, NULL},
	 { "AccountCallConfig_swigregister", AccountCallConfig_swigregister, METH_O, NULL},
	 { "AccountCallConfig_swiginit", AccountCallConfig_swiginit, METH_VARARGS, NULL},
	 { "AccountPresConfig_headers_set", _wrap_AccountPresConfig_headers_set, METH_VARARGS, NULL},
	 { "AccountPresConfig_headers_get", _wrap_AccountPresConfig_headers_get, METH_O, NULL},
	 { "AccountPresConfig_publishEnabled_set", _wrap_AccountPresConfig_publishEnabled_set, METH_VARARGS, NULL},
	 { "AccountPresConfig_publishEnabled_get", _wrap_AccountPresConfig_publishEnabled_get, METH_O, NULL},
	 { "AccountPresConfig_publishQueue_set", _wrap_AccountPresConfig_publishQueue_set, METH_VARARGS, NULL},
	 { "AccountPresConfig_publishQueue_get", _wrap_AccountPresConfig_publishQueue_get, METH_O, NULL},
	 { "AccountPresConfig_publishShutdownWaitMsec_set", _wrap_AccountPresConfig_publishShutdownWaitMsec_set, METH_VARARGS, NULL},
	 { "AccountPresConfig_publishShutdownWaitMsec_get", _wrap_AccountPresConfig_publishShutdownWaitMsec_get, METH_O, NULL},
	 { "AccountPresConfig_pidfTupleId_set", _wrap_AccountPresConfig_pidfTupleId_set, METH_VARARGS, NULL},
	 { "AccountPresConfig_pidfTupleId_get", _wrap_AccountPresConfig_pidfTupleId_get, METH_O, NULL},
	 { "AccountPresConfig_readObject", _wrap_AccountPresConfig_readObject, METH_VARARGS, NULL},
	 { "AccountPresConfig_writeObject", _wrap_AccountPresConfig_writeObject, METH_VARARGS, NULL},
	 { "new_AccountPresConfig", _wrap_new_AccountPresConfig, METH_NOARGS, NULL},
	 { "delete_AccountPresConfig", _wrap_delete_AccountPresConfig, METH_O, NULL},
	 { "AccountPresConfig_swigregister", AccountPresConfig_swigregister, METH_O, NULL},
	 { "AccountPresConfig_swiginit", AccountPresConfig_swiginit, METH_VARARGS, NULL},
	 { "AccountMwiConfig_enabled_set", _wrap_AccountMwiConfig_enabled_set, METH_VARARGS, NULL},
	 { "AccountMwiConfig_enabled_get", _wrap_AccountMwiConfig_enabled_get, METH_O, NULL},
	 { "AccountMwiConfig_expirationSec_set", _wrap_AccountMwiConfig_expirationSec_set, METH_VARARGS, NULL},
	 { "AccountMwiConfig_expirationSec_get", _wrap_AccountMwiConfig_expirationSec_get, METH_O, NULL},
	 { "AccountMwiConfig_readObject", _wrap_AccountMwiConfig_readObject, METH_VARARGS, NULL},
	 { "AccountMwiConfig_writeObject", _wrap_AccountMwiConfig_writeObject, METH_VARARGS, NULL},
	 { "new_AccountMwiConfig", _wrap_new_AccountMwiConfig, METH_NOARGS, NULL},
	 { "delete_AccountMwiConfig", _wrap_delete_AccountMwiConfig, METH_O, NULL},
	 { "AccountMwiConfig_swigregister", AccountMwiConfig_swigregister, METH_O, NULL},
	 { "AccountMwiConfig_swiginit", AccountMwiConfig_swiginit, METH_VARARGS, NULL},
	 { "AccountNatConfig_sipStunUse_set", _wrap_AccountNatConfig_sipStunUse_set, METH_VARARGS, NULL},
	 { "AccountNatConfig_sipStunUse_get", _wrap_AccountNatConfig_sipStunUse_get, METH_O, NULL},
	 { "AccountNatConfig_mediaStunUse_set", _wrap_AccountNatConfig_mediaStunUse_set, METH_VARARGS, NULL},
	 { "AccountNatConfig_mediaStunUse_get", _wrap_AccountNatConfig_mediaStunUse_get, METH_O, NULL},
	 { "AccountNatConfig_nat64Opt_set", _wrap_AccountNatConfig_nat64Opt_set, METH_VARARGS, NULL},
	 { "AccountNatConfig_nat64Opt_get", _wrap_AccountNatConfig_nat64Opt_get, METH_O, NULL},
	 { "AccountNatConfig_iceEnabled_set", _wrap_AccountNatConfig_iceEnabled_set, METH_VARARGS, NULL},
	 { "AccountNatConfig_iceEnabled_get", _wrap_AccountNatConfig_iceEnabled_get, METH_O, NULL},
	 { "AccountNatConfig_iceTrickle_set", _wrap_AccountNatConfig_iceTrickle_set, METH_VARARGS, NULL},
	 { "AccountNatConfig_iceTrickle_get", _wrap_AccountNatConfig_iceTrickle_get, METH_O, NULL},
	 { "AccountNatConfig_iceMaxHostCands_set", _wrap_AccountNatConfig_iceMaxHostCands_set, METH_VARARGS, NULL},
	 { "AccountNatConfig_iceMaxHostCands_get", _wrap_AccountNatConfig_iceMaxHostCands_get, METH_O, NULL},
	 { "AccountNatConfig_iceAggressiveNomination_set", _wrap_AccountNatConfig_iceAggressiveNomination_set, METH_VARARGS, NULL},
	 { "AccountNatConfig_iceAggressiveNomination_get", _wrap_AccountNatConfig_iceAggressiveNomination_get, METH_O, NULL},
	 { "AccountNatConfig_iceNominatedCheckDelayMsec_set", _wrap_AccountNatConfig_iceNominatedCheckDelayMsec_set, METH_VARARGS, NULL},
	 { "AccountNatConfig_iceNominatedCheckDelayMsec_get", _wrap_AccountNatConfig_iceNominatedCheckDelayMsec_get, METH_O, NULL},
	 { "AccountNatConfig_iceWaitNominationTimeoutMsec_set", _wrap_AccountNatConfig_iceWaitNominationTimeoutMsec_set, METH_VARARGS, NULL},
	 { "AccountNatConfig_iceWaitNominationTimeoutMsec_get", _wrap_AccountNatConfig_iceWaitNominationTimeoutMsec_get, METH_O, NULL},
	 { "AccountNatConfig_iceNoRtcp_set", _wrap_AccountNatConfig_iceNoRtcp_set, METH_VARARGS, NULL},
	 { "AccountNatConfig_iceNoRtcp_get", _wrap_AccountNatConfig_iceNoRtcp_get, METH_O, NULL},
	 { "AccountNatConfig_iceAlwaysUpdate_set", _wrap_AccountNatConfig_iceAlwaysUpdate_set, METH_VARARGS, NULL},
	 { "AccountNatConfig_iceAlwaysUpdate_get", _wrap_AccountNatConfig_iceAlwaysUpdate_get, METH_O, NULL},
	 { "AccountNatConfig_turnEnabled_set", _wrap_AccountNatConfig_turnEnabled_set, METH_VARARGS, NULL},
	 { "AccountNatConfig_turnEnabled_get", _wrap_AccountNatConfig_turnEnabled_get, METH_O, NULL},
	 { "AccountNatConfig_turnServer_set", _wrap_AccountNatConfig_turnServer_set, METH_VARARGS, NULL},
	 { "AccountNatConfig_turnServer_get", _wrap_AccountNatConfig_turnServer_get, METH_O, NULL},
	 { "AccountNatConfig_turnConnType_set", _wrap_AccountNatConfig_turnConnType_set, METH_VARARGS, NULL},
	 { "AccountNatConfig_turnConnType_get", _wrap_AccountNatConfig_turnConnType_get, METH_O, NULL},
	 { "AccountNatConfig_turnUserName_set", _wrap_AccountNatConfig_turnUserName_set, METH_VARARGS, NULL},
	 { "AccountNatConfig_turnUserName_get", _wrap_AccountNatConfig_turnUserName_get, METH_O, NULL},
	 { "AccountNatConfig_turnPasswordType_set", _wrap_AccountNatConfig_turnPasswordType_set, METH_VARARGS, NULL},
	 { "AccountNatConfig_turnPasswordType_get", _wrap_AccountNatConfig_turnPasswordType_get, METH_O, NULL},
	 { "AccountNatConfig_turnPassword_set", _wrap_AccountNatConfig_turnPassword_set, METH_VARARGS, NULL},
	 { "AccountNatConfig_turnPassword_get", _wrap_AccountNatConfig_turnPassword_get, METH_O, NULL},
	 { "AccountNatConfig_contactRewriteUse_set", _wrap_AccountNatConfig_contactRewriteUse_set, METH_VARARGS, NULL},
	 { "AccountNatConfig_contactRewriteUse_get", _wrap_AccountNatConfig_contactRewriteUse_get, METH_O, NULL},
	 { "AccountNatConfig_contactRewriteMethod_set", _wrap_AccountNatConfig_contactRewriteMethod_set, METH_VARARGS, NULL},
	 { "AccountNatConfig_contactRewriteMethod_get", _wrap_AccountNatConfig_contactRewriteMethod_get, METH_O, NULL},
	 { "AccountNatConfig_contactUseSrcPort_set", _wrap_AccountNatConfig_contactUseSrcPort_set, METH_VARARGS, NULL},
	 { "AccountNatConfig_contactUseSrcPort_get", _wrap_AccountNatConfig_contactUseSrcPort_get, METH_O, NULL},
	 { "AccountNatConfig_viaRewriteUse_set", _wrap_AccountNatConfig_viaRewriteUse_set, METH_VARARGS, NULL},
	 { "AccountNatConfig_viaRewriteUse_get", _wrap_AccountNatConfig_viaRewriteUse_get, METH_O, NULL},
	 { "AccountNatConfig_sdpNatRewriteUse_set", _wrap_AccountNatConfig_sdpNatRewriteUse_set, METH_VARARGS, NULL},
	 { "AccountNatConfig_sdpNatRewriteUse_get", _wrap_AccountNatConfig_sdpNatRewriteUse_get, METH_O, NULL},
	 { "AccountNatConfig_sipOutboundUse_set", _wrap_AccountNatConfig_sipOutboundUse_set, METH_VARARGS, NULL},
	 { "AccountNatConfig_sipOutboundUse_get", _wrap_AccountNatConfig_sipOutboundUse_get, METH_O, NULL},
	 { "AccountNatConfig_sipOutboundInstanceId_set", _wrap_AccountNatConfig_sipOutboundInstanceId_set, METH_VARARGS, NULL},
	 { "AccountNatConfig_sipOutboundInstanceId_get", _wrap_AccountNatConfig_sipOutboundInstanceId_get, METH_O, NULL},
	 { "AccountNatConfig_sipOutboundRegId_set", _wrap_AccountNatConfig_sipOutboundRegId_set, METH_VARARGS, NULL},
	 { "AccountNatConfig_sipOutboundRegId_get", _wrap_AccountNatConfig_sipOutboundRegId_get, METH_O, NULL},
	 { "AccountNatConfig_udpKaIntervalSec_set", _wrap_AccountNatConfig_udpKaIntervalSec_set, METH_VARARGS, NULL},
	 { "AccountNatConfig_udpKaIntervalSec_get", _wrap_AccountNatConfig_udpKaIntervalSec_get, METH_O, NULL},
	 { "AccountNatConfig_udpKaData_set", _wrap_AccountNatConfig_udpKaData_set, METH_VARARGS, NULL},
	 { "AccountNatConfig_udpKaData_get", _wrap_AccountNatConfig_udpKaData_get, METH_O, NULL},
	 { "new_AccountNatConfig", _wrap_new_AccountNatConfig, METH_NOARGS, NULL},
	 { "AccountNatConfig_readObject", _wrap_AccountNatConfig_readObject, METH_VARARGS, NULL},
	 { "AccountNatConfig_writeObject", _wrap_AccountNatConfig_writeObject, METH_VARARGS, NULL},
	 { "delete_AccountNatConfig", _wrap_delete_AccountNatConfig, METH_O, NULL},
	 { "AccountNatConfig_swigregister", AccountNatConfig_swigregister, METH_O, NULL},
	 { "AccountNatConfig_swiginit", AccountNatConfig_swiginit, METH_VARARGS, NULL},
	 { "SrtpCrypto_key_set", _wrap_SrtpCrypto_key_set, METH_VARARGS, NULL},
	 { "SrtpCrypto_key_get", _wrap_SrtpCrypto_key_get, METH_O, NULL},
	 { "SrtpCrypto_name_set", _wrap_SrtpCrypto_name_set, METH_VARARGS, NULL},
	 { "SrtpCrypto_name_get", _wrap_SrtpCrypto_name_get, METH_O, NULL},
	 { "SrtpCrypto_flags_set", _wrap_SrtpCrypto_flags_set, METH_VARARGS, NULL},
	 { "SrtpCrypto_flags_get", _wrap_SrtpCrypto_flags_get, METH_O, NULL},
	 { "new_SrtpCrypto", _wrap_new_SrtpCrypto, METH_NOARGS, NULL},
	 { "delete_SrtpCrypto", _wrap_delete_SrtpCrypto, METH_O, NULL},
	 { "SrtpCrypto_swigregister", SrtpCrypto_swigregister, METH_O, NULL},
	 { "SrtpCrypto_swiginit", SrtpCrypto_swiginit, METH_VARARGS, NULL},
	 { "SrtpOpt_cryptos_set", _wrap_SrtpOpt_cryptos_set, METH_VARARGS, NULL},
	 { "SrtpOpt_cryptos_get", _wrap_SrtpOpt_cryptos_get, METH_O, NULL},
	 { "SrtpOpt_keyings_set", _wrap_SrtpOpt_keyings_set, METH_VARARGS, NULL},
	 { "SrtpOpt_keyings_get", _wrap_SrtpOpt_keyings_get, METH_O, NULL},
	 { "new_SrtpOpt", _wrap_new_SrtpOpt, METH_NOARGS, NULL},
	 { "SrtpOpt_readObject", _wrap_SrtpOpt_readObject, METH_VARARGS, NULL},
	 { "SrtpOpt_writeObject", _wrap_SrtpOpt_writeObject, METH_VARARGS, NULL},
	 { "delete_SrtpOpt", _wrap_delete_SrtpOpt, METH_O, NULL},
	 { "SrtpOpt_swigregister", SrtpOpt_swigregister, METH_O, NULL},
	 { "SrtpOpt_swiginit", SrtpOpt_swiginit, METH_VARARGS, NULL},
	 { "RtcpFbCap_codecId_set", _wrap_RtcpFbCap_codecId_set, METH_VARARGS, NULL},
	 { "RtcpFbCap_codecId_get", _wrap_RtcpFbCap_codecId_get, METH_O, NULL},
	 { "RtcpFbCap_type_set", _wrap_RtcpFbCap_type_set, METH_VARARGS, NULL},
	 { "RtcpFbCap_type_get", _wrap_RtcpFbCap_type_get, METH_O, NULL},
	 { "RtcpFbCap_typeName_set", _wrap_RtcpFbCap_typeName_set, METH_VARARGS, NULL},
	 { "RtcpFbCap_typeName_get", _wrap_RtcpFbCap_typeName_get, METH_O, NULL},
	 { "RtcpFbCap_param_set", _wrap_RtcpFbCap_param_set, METH_VARARGS, NULL},
	 { "RtcpFbCap_param_get", _wrap_RtcpFbCap_param_get, METH_O, NULL},
	 { "new_RtcpFbCap", _wrap_new_RtcpFbCap, METH_NOARGS, NULL},
	 { "delete_RtcpFbCap", _wrap_delete_RtcpFbCap, METH_O, NULL},
	 { "RtcpFbCap_swigregister", RtcpFbCap_swigregister, METH_O, NULL},
	 { "RtcpFbCap_swiginit", RtcpFbCap_swiginit, METH_VARARGS, NULL},
	 { "RtcpFbConfig_dontUseAvpf_set", _wrap_RtcpFbConfig_dontUseAvpf_set, METH_VARARGS, NULL},
	 { "RtcpFbConfig_dontUseAvpf_get", _wrap_RtcpFbConfig_dontUseAvpf_get, METH_O, NULL},
	 { "RtcpFbConfig_caps_set", _wrap_RtcpFbConfig_caps_set, METH_VARARGS, NULL},
	 { "RtcpFbConfig_caps_get", _wrap_RtcpFbConfig_caps_get, METH_O, NULL},
	 { "new_RtcpFbConfig", _wrap_new_RtcpFbConfig, METH_NOARGS, NULL},
	 { "RtcpFbConfig_readObject", _wrap_RtcpFbConfig_readObject, METH_VARARGS, NULL},
	 { "RtcpFbConfig_writeObject", _wrap_RtcpFbConfig_writeObject, METH_VARARGS, NULL},
	 { "delete_RtcpFbConfig", _wrap_delete_RtcpFbConfig, METH_O, NULL},
	 { "RtcpFbConfig_swigregister", RtcpFbConfig_swigregister, METH_O, NULL},
	 { "RtcpFbConfig_swiginit", RtcpFbConfig_swiginit, METH_VARARGS, NULL},
	 { "AccountMediaConfig_transportConfig_set", _wrap_AccountMediaConfig_transportConfig_set, METH_VARARGS, NULL},
	 { "AccountMediaConfig_transportConfig_get", _wrap_AccountMediaConfig_transportConfig_get, METH_O, NULL},
	 { "AccountMediaConfig_lockCodecEnabled_set", _wrap_AccountMediaConfig_lockCodecEnabled_set, METH_VARARGS, NULL},
	 { "AccountMediaConfig_lockCodecEnabled_get", _wrap_AccountMediaConfig_lockCodecEnabled_get, METH_O, NULL},
	 { "AccountMediaConfig_streamKaEnabled_set", _wrap_AccountMediaConfig_streamKaEnabled_set, METH_VARARGS, NULL},
	 { "AccountMediaConfig_streamKaEnabled_get", _wrap_AccountMediaConfig_streamKaEnabled_get, METH_O, NULL},
	 { "AccountMediaConfig_srtpUse_set", _wrap_AccountMediaConfig_srtpUse_set, METH_VARARGS, NULL},
	 { "AccountMediaConfig_srtpUse_get", _wrap_AccountMediaConfig_srtpUse_get, METH_O, NULL},
	 { "AccountMediaConfig_srtpSecureSignaling_set", _wrap_AccountMediaConfig_srtpSecureSignaling_set, METH_VARARGS, NULL},
	 { "AccountMediaConfig_srtpSecureSignaling_get", _wrap_AccountMediaConfig_srtpSecureSignaling_get, METH_O, NULL},
	 { "AccountMediaConfig_srtpOpt_set", _wrap_AccountMediaConfig_srtpOpt_set, METH_VARARGS, NULL},
	 { "AccountMediaConfig_srtpOpt_get", _wrap_AccountMediaConfig_srtpOpt_get, METH_O, NULL},
	 { "AccountMediaConfig_ipv6Use_set", _wrap_AccountMediaConfig_ipv6Use_set, METH_VARARGS, NULL},
	 { "AccountMediaConfig_ipv6Use_get", _wrap_AccountMediaConfig_ipv6Use_get, METH_O, NULL},
	 { "AccountMediaConfig_rtcpMuxEnabled_set", _wrap_AccountMediaConfig_rtcpMuxEnabled_set, METH_VARARGS, NULL},
	 { "AccountMediaConfig_rtcpMuxEnabled_get", _wrap_AccountMediaConfig_rtcpMuxEnabled_get, METH_O, NULL},
	 { "AccountMediaConfig_rtcpFbConfig_set", _wrap_AccountMediaConfig_rtcpFbConfig_set, METH_VARARGS, NULL},
	 { "AccountMediaConfig_rtcpFbConfig_get", _wrap_AccountMediaConfig_rtcpFbConfig_get, METH_O, NULL},
	 { "AccountMediaConfig_useLoopMedTp_set", _wrap_AccountMediaConfig_useLoopMedTp_set, METH_VARARGS, NULL},
	 { "AccountMediaConfig_useLoopMedTp_get", _wrap_AccountMediaConfig_useLoopMedTp_get, METH_O, NULL},
	 { "AccountMediaConfig_enableLoopback_set", _wrap_AccountMediaConfig_enableLoopback_set, METH_VARARGS, NULL},
	 { "AccountMediaConfig_enableLoopback_get", _wrap_AccountMediaConfig_enableLoopback_get, METH_O, NULL},
	 { "new_AccountMediaConfig", _wrap_new_AccountMediaConfig, METH_NOARGS, NULL},
	 { "AccountMediaConfig_readObject", _wrap_AccountMediaConfig_readObject, METH_VARARGS, NULL},
	 { "AccountMediaConfig_writeObject", _wrap_AccountMediaConfig_writeObject, METH_VARARGS, NULL},
	 { "delete_AccountMediaConfig", _wrap_delete_AccountMediaConfig, METH_O, NULL},
	 { "AccountMediaConfig_swigregister", AccountMediaConfig_swigregister, METH_O, NULL},
	 { "AccountMediaConfig_swiginit", AccountMediaConfig_swiginit, METH_VARARGS, NULL},
	 { "AccountVideoConfig_autoShowIncoming_set", _wrap_AccountVideoConfig_autoShowIncoming_set, METH_VARARGS, NULL},
	 { "AccountVideoConfig_autoShowIncoming_get", _wrap_AccountVideoConfig_autoShowIncoming_get, METH_O, NULL},
	 { "AccountVideoConfig_autoTransmitOutgoing_set", _wrap_AccountVideoConfig_autoTransmitOutgoing_set, METH_VARARGS, NULL},
	 { "AccountVideoConfig_autoTransmitOutgoing_get", _wrap_AccountVideoConfig_autoTransmitOutgoing_get, METH_O, NULL},
	 { "AccountVideoConfig_windowFlags_set", _wrap_AccountVideoConfig_windowFlags_set, METH_VARARGS, NULL},
	 { "AccountVideoConfig_windowFlags_get", _wrap_AccountVideoConfig_windowFlags_get, METH_O, NULL},
	 { "AccountVideoConfig_defaultCaptureDevice_set", _wrap_AccountVideoConfig_defaultCaptureDevice_set, METH_VARARGS, NULL},
	 { "AccountVideoConfig_defaultCaptureDevice_get", _wrap_AccountVideoConfig_defaultCaptureDevice_get, METH_O, NULL},
	 { "AccountVideoConfig_defaultRenderDevice_set", _wrap_AccountVideoConfig_defaultRenderDevice_set, METH_VARARGS, NULL},
	 { "AccountVideoConfig_defaultRenderDevice_get", _wrap_AccountVideoConfig_defaultRenderDevice_get, METH_O, NULL},
	 { "AccountVideoConfig_rateControlMethod_set", _wrap_AccountVideoConfig_rateControlMethod_set, METH_VARARGS, NULL},
	 { "AccountVideoConfig_rateControlMethod_get", _wrap_AccountVideoConfig_rateControlMethod_get, METH_O, NULL},
	 { "AccountVideoConfig_rateControlBandwidth_set", _wrap_AccountVideoConfig_rateControlBandwidth_set, METH_VARARGS, NULL},
	 { "AccountVideoConfig_rateControlBandwidth_get", _wrap_AccountVideoConfig_rateControlBandwidth_get, METH_O, NULL},
	 { "AccountVideoConfig_startKeyframeCount_set", _wrap_AccountVideoConfig_startKeyframeCount_set, METH_VARARGS, NULL},
	 { "AccountVideoConfig_startKeyframeCount_get", _wrap_AccountVideoConfig_startKeyframeCount_get, METH_O, NULL},
	 { "AccountVideoConfig_startKeyframeInterval_set", _wrap_AccountVideoConfig_startKeyframeInterval_set, METH_VARARGS, NULL},
	 { "AccountVideoConfig_startKeyframeInterval_get", _wrap_AccountVideoConfig_startKeyframeInterval_get, METH_O, NULL},
	 { "new_AccountVideoConfig", _wrap_new_AccountVideoConfig, METH_NOARGS, NULL},
	 { "AccountVideoConfig_readObject", _wrap_AccountVideoConfig_readObject, METH_VARARGS, NULL},
	 { "AccountVideoConfig_writeObject", _wrap_AccountVideoConfig_writeObject, METH_VARARGS, NULL},
	 { "delete_AccountVideoConfig", _wrap_delete_AccountVideoConfig, METH_O, NULL},
	 { "AccountVideoConfig_swigregister", AccountVideoConfig_swigregister, METH_O, NULL},
	 { "AccountVideoConfig_swiginit", AccountVideoConfig_swiginit, METH_VARARGS, NULL},
	 { "AccountIpChangeConfig_shutdownTp_set", _wrap_AccountIpChangeConfig_shutdownTp_set, METH_VARARGS, NULL},
	 { "AccountIpChangeConfig_shutdownTp_get", _wrap_AccountIpChangeConfig_shutdownTp_get, METH_O, NULL},
	 { "AccountIpChangeConfig_hangupCalls_set", _wrap_AccountIpChangeConfig_hangupCalls_set, METH_VARARGS, NULL},
	 { "AccountIpChangeConfig_hangupCalls_get", _wrap_AccountIpChangeConfig_hangupCalls_get, METH_O, NULL},
	 { "AccountIpChangeConfig_reinviteFlags_set", _wrap_AccountIpChangeConfig_reinviteFlags_set, METH_VARARGS, NULL},
	 { "AccountIpChangeConfig_reinviteFlags_get", _wrap_AccountIpChangeConfig_reinviteFlags_get, METH_O, NULL},
	 { "delete_AccountIpChangeConfig", _wrap_delete_AccountIpChangeConfig, METH_O, NULL},
	 { "AccountIpChangeConfig_readObject", _wrap_AccountIpChangeConfig_readObject, METH_VARARGS, NULL},
	 { "AccountIpChangeConfig_writeObject", _wrap_AccountIpChangeConfig_writeObject, METH_VARARGS, NULL},
	 { "new_AccountIpChangeConfig", _wrap_new_AccountIpChangeConfig, METH_NOARGS, NULL},
	 { "AccountIpChangeConfig_swigregister", AccountIpChangeConfig_swigregister, METH_O, NULL},
	 { "AccountIpChangeConfig_swiginit", AccountIpChangeConfig_swiginit, METH_VARARGS, NULL},
	 { "AccountConfig_priority_set", _wrap_AccountConfig_priority_set, METH_VARARGS, NULL},
	 { "AccountConfig_priority_get", _wrap_AccountConfig_priority_get, METH_O, NULL},
	 { "AccountConfig_idUri_set", _wrap_AccountConfig_idUri_set, METH_VARARGS, NULL},
	 { "AccountConfig_idUri_get", _wrap_AccountConfig_idUri_get, METH_O, NULL},
	 { "AccountConfig_regConfig_set", _wrap_AccountConfig_regConfig_set, METH_VARARGS, NULL},
	 { "AccountConfig_regConfig_get", _wrap_AccountConfig_regConfig_get, METH_O, NULL},
	 { "AccountConfig_sipConfig_set", _wrap_AccountConfig_sipConfig_set, METH_VARARGS, NULL},
	 { "AccountConfig_sipConfig_get", _wrap_AccountConfig_sipConfig_get, METH_O, NULL},
	 { "AccountConfig_callConfig_set", _wrap_AccountConfig_callConfig_set, METH_VARARGS, NULL},
	 { "AccountConfig_callConfig_get", _wrap_AccountConfig_callConfig_get, METH_O, NULL},
	 { "AccountConfig_presConfig_set", _wrap_AccountConfig_presConfig_set, METH_VARARGS, NULL},
	 { "AccountConfig_presConfig_get", _wrap_AccountConfig_presConfig_get, METH_O, NULL},
	 { "AccountConfig_mwiConfig_set", _wrap_AccountConfig_mwiConfig_set, METH_VARARGS, NULL},
	 { "AccountConfig_mwiConfig_get", _wrap_AccountConfig_mwiConfig_get, METH_O, NULL},
	 { "AccountConfig_natConfig_set", _wrap_AccountConfig_natConfig_set, METH_VARARGS, NULL},
	 { "AccountConfig_natConfig_get", _wrap_AccountConfig_natConfig_get, METH_O, NULL},
	 { "AccountConfig_mediaConfig_set", _wrap_AccountConfig_mediaConfig_set, METH_VARARGS, NULL},
	 { "AccountConfig_mediaConfig_get", _wrap_AccountConfig_mediaConfig_get, METH_O, NULL},
	 { "AccountConfig_videoConfig_set", _wrap_AccountConfig_videoConfig_set, METH_VARARGS, NULL},
	 { "AccountConfig_videoConfig_get", _wrap_AccountConfig_videoConfig_get, METH_O, NULL},
	 { "AccountConfig_ipChangeConfig_set", _wrap_AccountConfig_ipChangeConfig_set, METH_VARARGS, NULL},
	 { "AccountConfig_ipChangeConfig_get", _wrap_AccountConfig_ipChangeConfig_get, METH_O, NULL},
	 { "new_AccountConfig", _wrap_new_AccountConfig, METH_NOARGS, NULL},
	 { "AccountConfig_readObject", _wrap_AccountConfig_readObject, METH_VARARGS, NULL},
	 { "AccountConfig_writeObject", _wrap_AccountConfig_writeObject, METH_VARARGS, NULL},
	 { "delete_AccountConfig", _wrap_delete_AccountConfig, METH_O, NULL},
	 { "AccountConfig_swigregister", AccountConfig_swigregister, METH_O, NULL},
	 { "AccountConfig_swiginit", AccountConfig_swiginit, METH_VARARGS, NULL},
	 { "AccountInfo_id_set", _wrap_AccountInfo_id_set, METH_VARARGS, NULL},
	 { "AccountInfo_id_get", _wrap_AccountInfo_id_get, METH_O, NULL},
	 { "AccountInfo_isDefault_set", _wrap_AccountInfo_isDefault_set, METH_VARARGS, NULL},
	 { "AccountInfo_isDefault_get", _wrap_AccountInfo_isDefault_get, METH_O, NULL},
	 { "AccountInfo_uri_set", _wrap_AccountInfo_uri_set, METH_VARARGS, NULL},
	 { "AccountInfo_uri_get", _wrap_AccountInfo_uri_get, METH_O, NULL},
	 { "AccountInfo_regIsConfigured_set", _wrap_AccountInfo_regIsConfigured_set, METH_VARARGS, NULL},
	 { "AccountInfo_regIsConfigured_get", _wrap_AccountInfo_regIsConfigured_get, METH_O, NULL},
	 { "AccountInfo_regIsActive_set", _wrap_AccountInfo_regIsActive_set, METH_VARARGS, NULL},
	 { "AccountInfo_regIsActive_get", _wrap_AccountInfo_regIsActive_get, METH_O, NULL},
	 { "AccountInfo_regExpiresSec_set", _wrap_AccountInfo_regExpiresSec_set, METH_VARARGS, NULL},
	 { "AccountInfo_regExpiresSec_get", _wrap_AccountInfo_regExpiresSec_get, METH_O, NULL},
	 { "AccountInfo_regStatus_set", _wrap_AccountInfo_regStatus_set, METH_VARARGS, NULL},
	 { "AccountInfo_regStatus_get", _wrap_AccountInfo_regStatus_get, METH_O, NULL},
	 { "AccountInfo_regStatusText_set", _wrap_AccountInfo_regStatusText_set, METH_VARARGS, NULL},
	 { "AccountInfo_regStatusText_get", _wrap_AccountInfo_regStatusText_get, METH_O, NULL},
	 { "AccountInfo_regLastErr_set", _wrap_AccountInfo_regLastErr_set, METH_VARARGS, NULL},
	 { "AccountInfo_regLastErr_get", _wrap_AccountInfo_regLastErr_get, METH_O, NULL},
	 { "AccountInfo_onlineStatus_set", _wrap_AccountInfo_onlineStatus_set, METH_VARARGS, NULL},
	 { "AccountInfo_onlineStatus_get", _wrap_AccountInfo_onlineStatus_get, METH_O, NULL},
	 { "AccountInfo_onlineStatusText_set", _wrap_AccountInfo_onlineStatusText_set, METH_VARARGS, NULL},
	 { "AccountInfo_onlineStatusText_get", _wrap_AccountInfo_onlineStatusText_get, METH_O, NULL},
	 { "new_AccountInfo", _wrap_new_AccountInfo, METH_NOARGS, NULL},
	 { "delete_AccountInfo", _wrap_delete_AccountInfo, METH_O, NULL},
	 { "AccountInfo_swigregister", AccountInfo_swigregister, METH_O, NULL},
	 { "AccountInfo_swiginit", AccountInfo_swiginit, METH_VARARGS, NULL},
	 { "OnIncomingCallParam_callId_set", _wrap_OnIncomingCallParam_callId_set, METH_VARARGS, NULL},
	 { "OnIncomingCallParam_callId_get", _wrap_OnIncomingCallParam_callId_get, METH_O, NULL},
	 { "OnIncomingCallParam_rdata_set", _wrap_OnIncomingCallParam_rdata_set, METH_VARARGS, NULL},
	 { "OnIncomingCallParam_rdata_get", _wrap_OnIncomingCallParam_rdata_get, METH_O, NULL},
	 { "new_OnIncomingCallParam", _wrap_new_OnIncomingCallParam, METH_NOARGS, NULL},
	 { "delete_OnIncomingCallParam", _wrap_delete_OnIncomingCallParam, METH_O, NULL},
	 { "OnIncomingCallParam_swigregister", OnIncomingCallParam_swigregister, METH_O, NULL},
	 { "OnIncomingCallParam_swiginit", OnIncomingCallParam_swiginit, METH_VARARGS, NULL},
	 { "OnRegStartedParam_renew_set", _wrap_OnRegStartedParam_renew_set, METH_VARARGS, NULL},
	 { "OnRegStartedParam_renew_get", _wrap_OnRegStartedParam_renew_get, METH_O, NULL},
	 { "new_OnRegStartedParam", _wrap_new_OnRegStartedParam, METH_NOARGS, NULL},
	 { "delete_OnRegStartedParam", _wrap_delete_OnRegStartedParam, METH_O, NULL},
	 { "OnRegStartedParam_swigregister", OnRegStartedParam_swigregister, METH_O, NULL},
	 { "OnRegStartedParam_swiginit", OnRegStartedParam_swiginit, METH_VARARGS, NULL},
	 { "OnRegStateParam_status_set", _wrap_OnRegStateParam_status_set, METH_VARARGS, NULL},
	 { "OnRegStateParam_status_get", _wrap_OnRegStateParam_status_get, METH_O, NULL},
	 { "OnRegStateParam_code_set", _wrap_OnRegStateParam_code_set, METH_VARARGS, NULL},
	 { "OnRegStateParam_code_get", _wrap_OnRegStateParam_code_get, METH_O, NULL},
	 { "OnRegStateParam_reason_set", _wrap_OnRegStateParam_reason_set, METH_VARARGS, NULL},
	 { "OnRegStateParam_reason_get", _wrap_OnRegStateParam_reason_get, METH_O, NULL},
	 { "OnRegStateParam_rdata_set", _wrap_OnRegStateParam_rdata_set, METH_VARARGS, NULL},
	 { "OnRegStateParam_rdata_get", _wrap_OnRegStateParam_rdata_get, METH_O, NULL},
	 { "OnRegStateParam_expiration_set", _wrap_OnRegStateParam_expiration_set, METH_VARARGS, NULL},
	 { "OnRegStateParam_expiration_get", _wrap_OnRegStateParam_expiration_get, METH_O, NULL},
	 { "new_OnRegStateParam", _wrap_new_OnRegStateParam, METH_NOARGS, NULL},
	 { "delete_OnRegStateParam", _wrap_delete_OnRegStateParam, METH_O, NULL},
	 { "OnRegStateParam_swigregister", OnRegStateParam_swigregister, METH_O, NULL},
	 { "OnRegStateParam_swiginit", OnRegStateParam_swiginit, METH_VARARGS, NULL},
	 { "OnIncomingSubscribeParam_srvPres_set", _wrap_OnIncomingSubscribeParam_srvPres_set, METH_VARARGS, NULL},
	 { "OnIncomingSubscribeParam_srvPres_get", _wrap_OnIncomingSubscribeParam_srvPres_get, METH_O, NULL},
	 { "OnIncomingSubscribeParam_fromUri_set", _wrap_OnIncomingSubscribeParam_fromUri_set, METH_VARARGS, NULL},
	 { "OnIncomingSubscribeParam_fromUri_get", _wrap_OnIncomingSubscribeParam_fromUri_get, METH_O, NULL},
	 { "OnIncomingSubscribeParam_rdata_set", _wrap_OnIncomingSubscribeParam_rdata_set, METH_VARARGS, NULL},
	 { "OnIncomingSubscribeParam_rdata_get", _wrap_OnIncomingSubscribeParam_rdata_get, METH_O, NULL},
	 { "OnIncomingSubscribeParam_code_set", _wrap_OnIncomingSubscribeParam_code_set, METH_VARARGS, NULL},
	 { "OnIncomingSubscribeParam_code_get", _wrap_OnIncomingSubscribeParam_code_get, METH_O, NULL},
	 { "OnIncomingSubscribeParam_reason_set", _wrap_OnIncomingSubscribeParam_reason_set, METH_VARARGS, NULL},
	 { "OnIncomingSubscribeParam_reason_get", _wrap_OnIncomingSubscribeParam_reason_get, METH_O, NULL},
	 { "OnIncomingSubscribeParam_txOption_set", _wrap_OnIncomingSubscribeParam_txOption_set, METH_VARARGS, NULL},
	 { "OnIncomingSubscribeParam_txOption_get", _wrap_OnIncomingSubscribeParam_txOption_get, METH_O, NULL},
	 { "new_OnIncomingSubscribeParam", _wrap_new_OnIncomingSubscribeParam, METH_NOARGS, NULL},
	 { "delete_OnIncomingSubscribeParam", _wrap_delete_OnIncomingSubscribeParam, METH_O, NULL},
	 { "OnIncomingSubscribeParam_swigregister", OnIncomingSubscribeParam_swigregister, METH_O, NULL},
	 { "OnIncomingSubscribeParam_swiginit", OnIncomingSubscribeParam_swiginit, METH_VARARGS, NULL},
	 { "OnInstantMessageParam_fromUri_set", _wrap_OnInstantMessageParam_fromUri_set, METH_VARARGS, NULL},
	 { "OnInstantMessageParam_fromUri_get", _wrap_OnInstantMessageParam_fromUri_get, METH_O, NULL},
	 { "OnInstantMessageParam_toUri_set", _wrap_OnInstantMessageParam_toUri_set, METH_VARARGS, NULL},
	 { "OnInstantMessageParam_toUri_get", _wrap_OnInstantMessageParam_toUri_get, METH_O, NULL},
	 { "OnInstantMessageParam_contactUri_set", _wrap_OnInstantMessageParam_contactUri_set, METH_VARARGS, NULL},
	 { "OnInstantMessageParam_contactUri_get", _wrap_OnInstantMessageParam_contactUri_get, METH_O, NULL},
	 { "OnInstantMessageParam_contentType_set", _wrap_OnInstantMessageParam_contentType_set, METH_VARARGS, NULL},
	 { "OnInstantMessageParam_contentType_get", _wrap_OnInstantMessageParam_contentType_get, METH_O, NULL},
	 { "OnInstantMessageParam_msgBody_set", _wrap_OnInstantMessageParam_msgBody_set, METH_VARARGS, NULL},
	 { "OnInstantMessageParam_msgBody_get", _wrap_OnInstantMessageParam_msgBody_get, METH_O, NULL},
	 { "OnInstantMessageParam_rdata_set", _wrap_OnInstantMessageParam_rdata_set, METH_VARARGS, NULL},
	 { "OnInstantMessageParam_rdata_get", _wrap_OnInstantMessageParam_rdata_get, METH_O, NULL},
	 { "new_OnInstantMessageParam", _wrap_new_OnInstantMessageParam, METH_NOARGS, NULL},
	 { "delete_OnInstantMessageParam", _wrap_delete_OnInstantMessageParam, METH_O, NULL},
	 { "OnInstantMessageParam_swigregister", OnInstantMessageParam_swigregister, METH_O, NULL},
	 { "OnInstantMessageParam_swiginit", OnInstantMessageParam_swiginit, METH_VARARGS, NULL},
	 { "OnInstantMessageStatusParam_userData_set", _wrap_OnInstantMessageStatusParam_userData_set, METH_VARARGS, NULL},
	 { "OnInstantMessageStatusParam_userData_get", _wrap_OnInstantMessageStatusParam_userData_get, METH_O, NULL},
	 { "OnInstantMessageStatusParam_toUri_set", _wrap_OnInstantMessageStatusParam_toUri_set, METH_VARARGS, NULL},
	 { "OnInstantMessageStatusParam_toUri_get", _wrap_OnInstantMessageStatusParam_toUri_get, METH_O, NULL},
	 { "OnInstantMessageStatusParam_msgBody_set", _wrap_OnInstantMessageStatusParam_msgBody_set, METH_VARARGS, NULL},
	 { "OnInstantMessageStatusParam_msgBody_get", _wrap_OnInstantMessageStatusParam_msgBody_get, METH_O, NULL},
	 { "OnInstantMessageStatusParam_code_set", _wrap_OnInstantMessageStatusParam_code_set, METH_VARARGS, NULL},
	 { "OnInstantMessageStatusParam_code_get", _wrap_OnInstantMessageStatusParam_code_get, METH_O, NULL},
	 { "OnInstantMessageStatusParam_reason_set", _wrap_OnInstantMessageStatusParam_reason_set, METH_VARARGS, NULL},
	 { "OnInstantMessageStatusParam_reason_get", _wrap_OnInstantMessageStatusParam_reason_get, METH_O, NULL},
	 { "OnInstantMessageStatusParam_rdata_set", _wrap_OnInstantMessageStatusParam_rdata_set, METH_VARARGS, NULL},
	 { "OnInstantMessageStatusParam_rdata_get", _wrap_OnInstantMessageStatusParam_rdata_get, METH_O, NULL},
	 { "new_OnInstantMessageStatusParam", _wrap_new_OnInstantMessageStatusParam, METH_NOARGS, NULL},
	 { "delete_OnInstantMessageStatusParam", _wrap_delete_OnInstantMessageStatusParam, METH_O, NULL},
	 { "OnInstantMessageStatusParam_swigregister", OnInstantMessageStatusParam_swigregister, METH_O, NULL},
	 { "OnInstantMessageStatusParam_swiginit", OnInstantMessageStatusParam_swiginit, METH_VARARGS, NULL},
	 { "OnTypingIndicationParam_fromUri_set", _wrap_OnTypingIndicationParam_fromUri_set, METH_VARARGS, NULL},
	 { "OnTypingIndicationParam_fromUri_get", _wrap_OnTypingIndicationParam_fromUri_get, METH_O, NULL},
	 { "OnTypingIndicationParam_toUri_set", _wrap_OnTypingIndicationParam_toUri_set, METH_VARARGS, NULL},
	 { "OnTypingIndicationParam_toUri_get", _wrap_OnTypingIndicationParam_toUri_get, METH_O, NULL},
	 { "OnTypingIndicationParam_contactUri_set", _wrap_OnTypingIndicationParam_contactUri_set, METH_VARARGS, NULL},
	 { "OnTypingIndicationParam_contactUri_get", _wrap_OnTypingIndicationParam_contactUri_get, METH_O, NULL},
	 { "OnTypingIndicationParam_isTyping_set", _wrap_OnTypingIndicationParam_isTyping_set, METH_VARARGS, NULL},
	 { "OnTypingIndicationParam_isTyping_get", _wrap_OnTypingIndicationParam_isTyping_get, METH_O, NULL},
	 { "OnTypingIndicationParam_rdata_set", _wrap_OnTypingIndicationParam_rdata_set, METH_VARARGS, NULL},
	 { "OnTypingIndicationParam_rdata_get", _wrap_OnTypingIndicationParam_rdata_get, METH_O, NULL},
	 { "new_OnTypingIndicationParam", _wrap_new_OnTypingIndicationParam, METH_NOARGS, NULL},
	 { "delete_OnTypingIndicationParam", _wrap_delete_OnTypingIndicationParam, METH_O, NULL},
	 { "OnTypingIndicationParam_swigregister", OnTypingIndicationParam_swigregister, METH_O, NULL},
	 { "OnTypingIndicationParam_swiginit", OnTypingIndicationParam_swiginit, METH_VARARGS, NULL},
	 { "OnMwiInfoParam_state_set", _wrap_OnMwiInfoParam_state_set, METH_VARARGS, NULL},
	 { "OnMwiInfoParam_state_get", _wrap_OnMwiInfoParam_state_get, METH_O, NULL},
	 { "OnMwiInfoParam_rdata_set", _wrap_OnMwiInfoParam_rdata_set, METH_VARARGS, NULL},
	 { "OnMwiInfoParam_rdata_get", _wrap_OnMwiInfoParam_rdata_get, METH_O, NULL},
	 { "new_OnMwiInfoParam", _wrap_new_OnMwiInfoParam, METH_NOARGS, NULL},
	 { "delete_OnMwiInfoParam", _wrap_delete_OnMwiInfoParam, METH_O, NULL},
	 { "OnMwiInfoParam_swigregister", OnMwiInfoParam_swigregister, METH_O, NULL},
	 { "OnMwiInfoParam_swiginit", OnMwiInfoParam_swiginit, METH_VARARGS, NULL},
	 { "PresNotifyParam_srvPres_set", _wrap_PresNotifyParam_srvPres_set, METH_VARARGS, NULL},
	 { "PresNotifyParam_srvPres_get", _wrap_PresNotifyParam_srvPres_get, METH_O, NULL},
	 { "PresNotifyParam_state_set", _wrap_PresNotifyParam_state_set, METH_VARARGS, NULL},
	 { "PresNotifyParam_state_get", _wrap_PresNotifyParam_state_get, METH_O, NULL},
	 { "PresNotifyParam_stateStr_set", _wrap_PresNotifyParam_stateStr_set, METH_VARARGS, NULL},
	 { "PresNotifyParam_stateStr_get", _wrap_PresNotifyParam_stateStr_get, METH_O, NULL},
	 { "PresNotifyParam_reason_set", _wrap_PresNotifyParam_reason_set, METH_VARARGS, NULL},
	 { "PresNotifyParam_reason_get", _wrap_PresNotifyParam_reason_get, METH_O, NULL},
	 { "PresNotifyParam_withBody_set", _wrap_PresNotifyParam_withBody_set, METH_VARARGS, NULL},
	 { "PresNotifyParam_withBody_get", _wrap_PresNotifyParam_withBody_get, METH_O, NULL},
	 { "PresNotifyParam_txOption_set", _wrap_PresNotifyParam_txOption_set, METH_VARARGS, NULL},
	 { "PresNotifyParam_txOption_get", _wrap_PresNotifyParam_txOption_get, METH_O, NULL},
	 { "new_PresNotifyParam", _wrap_new_PresNotifyParam, METH_NOARGS, NULL},
	 { "delete_PresNotifyParam", _wrap_delete_PresNotifyParam, METH_O, NULL},
	 { "PresNotifyParam_swigregister", PresNotifyParam_swigregister, METH_O, NULL},
	 { "PresNotifyParam_swiginit", PresNotifyParam_swiginit, METH_VARARGS, NULL},
	 { "FindBuddyMatch_match", _wrap_FindBuddyMatch_match, METH_VARARGS, NULL},
	 { "delete_FindBuddyMatch", _wrap_delete_FindBuddyMatch, METH_O, NULL},
	 { "new_FindBuddyMatch", _wrap_new_FindBuddyMatch, METH_O, NULL},
	 { "disown_FindBuddyMatch", _wrap_disown_FindBuddyMatch, METH_O, NULL},
	 { "FindBuddyMatch_swigregister", FindBuddyMatch_swigregister, METH_O, NULL},
	 { "FindBuddyMatch_swiginit", FindBuddyMatch_swiginit, METH_VARARGS, NULL},
	 { "new_Account", _wrap_new_Account, METH_O, NULL},
	 { "delete_Account", _wrap_delete_Account, METH_O, NULL},
	 { "Account_create", _wrap_Account_create, METH_VARARGS, NULL},
	 { "Account_shutdown", _wrap_Account_shutdown, METH_O, NULL},
	 { "Account_modify", _wrap_Account_modify, METH_VARARGS, NULL},
	 { "Account_isValid", _wrap_Account_isValid, METH_O, NULL},
	 { "Account_setDefault", _wrap_Account_setDefault, METH_O, NULL},
	 { "Account_isDefault", _wrap_Account_isDefault, METH_O, NULL},
	 { "Account_getId", _wrap_Account_getId, METH_O, NULL},
	 { "Account_lookup", _wrap_Account_lookup, METH_O, NULL},
	 { "Account_getInfo", _wrap_Account_getInfo, METH_O, NULL},
	 { "Account_setRegistration", _wrap_Account_setRegistration, METH_VARARGS, NULL},
	 { "Account_setOnlineStatus", _wrap_Account_setOnlineStatus, METH_VARARGS, NULL},
	 { "Account_setTransport", _wrap_Account_setTransport, METH_VARARGS, NULL},
	 { "Account_presNotify", _wrap_Account_presNotify, METH_VARARGS, NULL},
	 { "Account_enumBuddies2", _wrap_Account_enumBuddies2, METH_O, NULL},
	 { "Account_findBuddy2", _wrap_Account_findBuddy2, METH_VARARGS, NULL},
	 { "Account_onIncomingCall", _wrap_Account_onIncomingCall, METH_VARARGS, NULL},
	 { "Account_onRegStarted", _wrap_Account_onRegStarted, METH_VARARGS, NULL},
	 { "Account_onRegState", _wrap_Account_onRegState, METH_VARARGS, NULL},
	 { "Account_onIncomingSubscribe", _wrap_Account_onIncomingSubscribe, METH_VARARGS, NULL},
	 { "Account_onInstantMessage", _wrap_Account_onInstantMessage, METH_VARARGS, NULL},
	 { "Account_onInstantMessageStatus", _wrap_Account_onInstantMessageStatus, METH_VARARGS, NULL},
	 { "Account_onTypingIndication", _wrap_Account_onTypingIndication, METH_VARARGS, NULL},
	 { "Account_onMwiInfo", _wrap_Account_onMwiInfo, METH_VARARGS, NULL},
	 { "disown_Account", _wrap_disown_Account, METH_O, NULL},
	 { "Account_swigregister", Account_swigregister, METH_O, NULL},
	 { "Account_swiginit", Account_swiginit, METH_VARARGS, NULL},
	 { "MathStat_n_set", _wrap_MathStat_n_set, METH_VARARGS, NULL},
	 { "MathStat_n_get", _wrap_MathStat_n_get, METH_O, NULL},
	 { "MathStat_max_set", _wrap_MathStat_max_set, METH_VARARGS, NULL},
	 { "MathStat_max_get", _wrap_MathStat_max_get, METH_O, NULL},
	 { "MathStat_min_set", _wrap_MathStat_min_set, METH_VARARGS, NULL},
	 { "MathStat_min_get", _wrap_MathStat_min_get, METH_O, NULL},
	 { "MathStat_last_set", _wrap_MathStat_last_set, METH_VARARGS, NULL},
	 { "MathStat_last_get", _wrap_MathStat_last_get, METH_O, NULL},
	 { "MathStat_mean_set", _wrap_MathStat_mean_set, METH_VARARGS, NULL},
	 { "MathStat_mean_get", _wrap_MathStat_mean_get, METH_O, NULL},
	 { "new_MathStat", _wrap_new_MathStat, METH_NOARGS, NULL},
	 { "delete_MathStat", _wrap_delete_MathStat, METH_O, NULL},
	 { "MathStat_swigregister", MathStat_swigregister, METH_O, NULL},
	 { "MathStat_swiginit", MathStat_swiginit, METH_VARARGS, NULL},
	 { "LossType_burst_set", _wrap_LossType_burst_set, METH_VARARGS, NULL},
	 { "LossType_burst_get", _wrap_LossType_burst_get, METH_O, NULL},
	 { "LossType_random_set", _wrap_LossType_random_set, METH_VARARGS, NULL},
	 { "LossType_random_get", _wrap_LossType_random_get, METH_O, NULL},
	 { "new_LossType", _wrap_new_LossType, METH_NOARGS, NULL},
	 { "delete_LossType", _wrap_delete_LossType, METH_O, NULL},
	 { "LossType_swigregister", LossType_swigregister, METH_O, NULL},
	 { "LossType_swiginit", LossType_swiginit, METH_VARARGS, NULL},
	 { "RtcpStreamStat_update_set", _wrap_RtcpStreamStat_update_set, METH_VARARGS, NULL},
	 { "RtcpStreamStat_update_get", _wrap_RtcpStreamStat_update_get, METH_O, NULL},
	 { "RtcpStreamStat_updateCount_set", _wrap_RtcpStreamStat_updateCount_set, METH_VARARGS, NULL},
	 { "RtcpStreamStat_updateCount_get", _wrap_RtcpStreamStat_updateCount_get, METH_O, NULL},
	 { "RtcpStreamStat_pkt_set", _wrap_RtcpStreamStat_pkt_set, METH_VARARGS, NULL},
	 { "RtcpStreamStat_pkt_get", _wrap_RtcpStreamStat_pkt_get, METH_O, NULL},
	 { "RtcpStreamStat_bytes_set", _wrap_RtcpStreamStat_bytes_set, METH_VARARGS, NULL},
	 { "RtcpStreamStat_bytes_get", _wrap_RtcpStreamStat_bytes_get, METH_O, NULL},
	 { "RtcpStreamStat_discard_set", _wrap_RtcpStreamStat_discard_set, METH_VARARGS, NULL},
	 { "RtcpStreamStat_discard_get", _wrap_RtcpStreamStat_discard_get, METH_O, NULL},
	 { "RtcpStreamStat_loss_set", _wrap_RtcpStreamStat_loss_set, METH_VARARGS, NULL},
	 { "RtcpStreamStat_loss_get", _wrap_RtcpStreamStat_loss_get, METH_O, NULL},
	 { "RtcpStreamStat_reorder_set", _wrap_RtcpStreamStat_reorder_set, METH_VARARGS, NULL},
	 { "RtcpStreamStat_reorder_get", _wrap_RtcpStreamStat_reorder_get, METH_O, NULL},
	 { "RtcpStreamStat_dup_set", _wrap_RtcpStreamStat_dup_set, METH_VARARGS, NULL},
	 { "RtcpStreamStat_dup_get", _wrap_RtcpStreamStat_dup_get, METH_O, NULL},
	 { "RtcpStreamStat_lossPeriodUsec_set", _wrap_RtcpStreamStat_lossPeriodUsec_set, METH_VARARGS, NULL},
	 { "RtcpStreamStat_lossPeriodUsec_get", _wrap_RtcpStreamStat_lossPeriodUsec_get, METH_O, NULL},
	 { "RtcpStreamStat_lossType_set", _wrap_RtcpStreamStat_lossType_set, METH_VARARGS, NULL},
	 { "RtcpStreamStat_lossType_get", _wrap_RtcpStreamStat_lossType_get, METH_O, NULL},
	 { "RtcpStreamStat_jitterUsec_set", _wrap_RtcpStreamStat_jitterUsec_set, METH_VARARGS, NULL},
	 { "RtcpStreamStat_jitterUsec_get", _wrap_RtcpStreamStat_jitterUsec_get, METH_O, NULL},
	 { "new_RtcpStreamStat", _wrap_new_RtcpStreamStat, METH_NOARGS, NULL},
	 { "delete_RtcpStreamStat", _wrap_delete_RtcpStreamStat, METH_O, NULL},
	 { "RtcpStreamStat_swigregister", RtcpStreamStat_swigregister, METH_O, NULL},
	 { "RtcpStreamStat_swiginit", RtcpStreamStat_swiginit, METH_VARARGS, NULL},
	 { "RtcpSdes_cname_set", _wrap_RtcpSdes_cname_set, METH_VARARGS, NULL},
	 { "RtcpSdes_cname_get", _wrap_RtcpSdes_cname_get, METH_O, NULL},
	 { "RtcpSdes_name_set", _wrap_RtcpSdes_name_set, METH_VARARGS, NULL},
	 { "RtcpSdes_name_get", _wrap_RtcpSdes_name_get, METH_O, NULL},
	 { "RtcpSdes_email_set", _wrap_RtcpSdes_email_set, METH_VARARGS, NULL},
	 { "RtcpSdes_email_get", _wrap_RtcpSdes_email_get, METH_O, NULL},
	 { "RtcpSdes_phone_set", _wrap_RtcpSdes_phone_set, METH_VARARGS, NULL},
	 { "RtcpSdes_phone_get", _wrap_RtcpSdes_phone_get, METH_O, NULL},
	 { "RtcpSdes_loc_set", _wrap_RtcpSdes_loc_set, METH_VARARGS, NULL},
	 { "RtcpSdes_loc_get", _wrap_RtcpSdes_loc_get, METH_O, NULL},
	 { "RtcpSdes_tool_set", _wrap_RtcpSdes_tool_set, METH_VARARGS, NULL},
	 { "RtcpSdes_tool_get", _wrap_RtcpSdes_tool_get, METH_O, NULL},
	 { "RtcpSdes_note_set", _wrap_RtcpSdes_note_set, METH_VARARGS, NULL},
	 { "RtcpSdes_note_get", _wrap_RtcpSdes_note_get, METH_O, NULL},
	 { "new_RtcpSdes", _wrap_new_RtcpSdes, METH_NOARGS, NULL},
	 { "delete_RtcpSdes", _wrap_delete_RtcpSdes, METH_O, NULL},
	 { "RtcpSdes_swigregister", RtcpSdes_swigregister, METH_O, NULL},
	 { "RtcpSdes_swiginit", RtcpSdes_swiginit, METH_VARARGS, NULL},
	 { "RtcpStat_start_set", _wrap_RtcpStat_start_set, METH_VARARGS, NULL},
	 { "RtcpStat_start_get", _wrap_RtcpStat_start_get, METH_O, NULL},
	 { "RtcpStat_txStat_set", _wrap_RtcpStat_txStat_set, METH_VARARGS, NULL},
	 { "RtcpStat_txStat_get", _wrap_RtcpStat_txStat_get, METH_O, NULL},
	 { "RtcpStat_rxStat_set", _wrap_RtcpStat_rxStat_set, METH_VARARGS, NULL},
	 { "RtcpStat_rxStat_get", _wrap_RtcpStat_rxStat_get, METH_O, NULL},
	 { "RtcpStat_rttUsec_set", _wrap_RtcpStat_rttUsec_set, METH_VARARGS, NULL},
	 { "RtcpStat_rttUsec_get", _wrap_RtcpStat_rttUsec_get, METH_O, NULL},
	 { "RtcpStat_rtpTxLastTs_set", _wrap_RtcpStat_rtpTxLastTs_set, METH_VARARGS, NULL},
	 { "RtcpStat_rtpTxLastTs_get", _wrap_RtcpStat_rtpTxLastTs_get, METH_O, NULL},
	 { "RtcpStat_rtpTxLastSeq_set", _wrap_RtcpStat_rtpTxLastSeq_set, METH_VARARGS, NULL},
	 { "RtcpStat_rtpTxLastSeq_get", _wrap_RtcpStat_rtpTxLastSeq_get, METH_O, NULL},
	 { "RtcpStat_rxIpdvUsec_set", _wrap_RtcpStat_rxIpdvUsec_set, METH_VARARGS, NULL},
	 { "RtcpStat_rxIpdvUsec_get", _wrap_RtcpStat_rxIpdvUsec_get, METH_O, NULL},
	 { "RtcpStat_rxRawJitterUsec_set", _wrap_RtcpStat_rxRawJitterUsec_set, METH_VARARGS, NULL},
	 { "RtcpStat_rxRawJitterUsec_get", _wrap_RtcpStat_rxRawJitterUsec_get, METH_O, NULL},
	 { "RtcpStat_peerSdes_set", _wrap_RtcpStat_peerSdes_set, METH_VARARGS, NULL},
	 { "RtcpStat_peerSdes_get", _wrap_RtcpStat_peerSdes_get, METH_O, NULL},
	 { "new_RtcpStat", _wrap_new_RtcpStat, METH_NOARGS, NULL},
	 { "delete_RtcpStat", _wrap_delete_RtcpStat, METH_O, NULL},
	 { "RtcpStat_swigregister", RtcpStat_swigregister, METH_O, NULL},
	 { "RtcpStat_swiginit", RtcpStat_swiginit, METH_VARARGS, NULL},
	 { "JbufState_frameSize_set", _wrap_JbufState_frameSize_set, METH_VARARGS, NULL},
	 { "JbufState_frameSize_get", _wrap_JbufState_frameSize_get, METH_O, NULL},
	 { "JbufState_minPrefetch_set", _wrap_JbufState_minPrefetch_set, METH_VARARGS, NULL},
	 { "JbufState_minPrefetch_get", _wrap_JbufState_minPrefetch_get, METH_O, NULL},
	 { "JbufState_maxPrefetch_set", _wrap_JbufState_maxPrefetch_set, METH_VARARGS, NULL},
	 { "JbufState_maxPrefetch_get", _wrap_JbufState_maxPrefetch_get, METH_O, NULL},
	 { "JbufState_burst_set", _wrap_JbufState_burst_set, METH_VARARGS, NULL},
	 { "JbufState_burst_get", _wrap_JbufState_burst_get, METH_O, NULL},
	 { "JbufState_prefetch_set", _wrap_JbufState_prefetch_set, METH_VARARGS, NULL},
	 { "JbufState_prefetch_get", _wrap_JbufState_prefetch_get, METH_O, NULL},
	 { "JbufState_size_set", _wrap_JbufState_size_set, METH_VARARGS, NULL},
	 { "JbufState_size_get", _wrap_JbufState_size_get, METH_O, NULL},
	 { "JbufState_avgDelayMsec_set", _wrap_JbufState_avgDelayMsec_set, METH_VARARGS, NULL},
	 { "JbufState_avgDelayMsec_get", _wrap_JbufState_avgDelayMsec_get, METH_O, NULL},
	 { "JbufState_minDelayMsec_set", _wrap_JbufState_minDelayMsec_set, METH_VARARGS, NULL},
	 { "JbufState_minDelayMsec_get", _wrap_JbufState_minDelayMsec_get, METH_O, NULL},
	 { "JbufState_maxDelayMsec_set", _wrap_JbufState_maxDelayMsec_set, METH_VARARGS, NULL},
	 { "JbufState_maxDelayMsec_get", _wrap_JbufState_maxDelayMsec_get, METH_O, NULL},
	 { "JbufState_devDelayMsec_set", _wrap_JbufState_devDelayMsec_set, METH_VARARGS, NULL},
	 { "JbufState_devDelayMsec_get", _wrap_JbufState_devDelayMsec_get, METH_O, NULL},
	 { "JbufState_avgBurst_set", _wrap_JbufState_avgBurst_set, METH_VARARGS, NULL},
	 { "JbufState_avgBurst_get", _wrap_JbufState_avgBurst_get, METH_O, NULL},
	 { "JbufState_lost_set", _wrap_JbufState_lost_set, METH_VARARGS, NULL},
	 { "JbufState_lost_get", _wrap_JbufState_lost_get, METH_O, NULL},
	 { "JbufState_discard_set", _wrap_JbufState_discard_set, METH_VARARGS, NULL},
	 { "JbufState_discard_get", _wrap_JbufState_discard_get, METH_O, NULL},
	 { "JbufState_empty_set", _wrap_JbufState_empty_set, METH_VARARGS, NULL},
	 { "JbufState_empty_get", _wrap_JbufState_empty_get, METH_O, NULL},
	 { "new_JbufState", _wrap_new_JbufState, METH_NOARGS, NULL},
	 { "delete_JbufState", _wrap_delete_JbufState, METH_O, NULL},
	 { "JbufState_swigregister", JbufState_swigregister, METH_O, NULL},
	 { "JbufState_swiginit", JbufState_swiginit, METH_VARARGS, NULL},
	 { "SdpSession_wholeSdp_set", _wrap_SdpSession_wholeSdp_set, METH_VARARGS, NULL},
	 { "SdpSession_wholeSdp_get", _wrap_SdpSession_wholeSdp_get, METH_O, NULL},
	 { "SdpSession_pjSdpSession_set", _wrap_SdpSession_pjSdpSession_set, METH_VARARGS, NULL},
	 { "SdpSession_pjSdpSession_get", _wrap_SdpSession_pjSdpSession_get, METH_O, NULL},
	 { "new_SdpSession", _wrap_new_SdpSession, METH_NOARGS, NULL},
	 { "delete_SdpSession", _wrap_delete_SdpSession, METH_O, NULL},
	 { "SdpSession_swigregister", SdpSession_swigregister, METH_O, NULL},
	 { "SdpSession_swiginit", SdpSession_swiginit, METH_VARARGS, NULL},
	 { "MediaTransportInfo_localRtpName_set", _wrap_MediaTransportInfo_localRtpName_set, METH_VARARGS, NULL},
	 { "MediaTransportInfo_localRtpName_get", _wrap_MediaTransportInfo_localRtpName_get, METH_O, NULL},
	 { "MediaTransportInfo_localRtcpName_set", _wrap_MediaTransportInfo_localRtcpName_set, METH_VARARGS, NULL},
	 { "MediaTransportInfo_localRtcpName_get", _wrap_MediaTransportInfo_localRtcpName_get, METH_O, NULL},
	 { "MediaTransportInfo_srcRtpName_set", _wrap_MediaTransportInfo_srcRtpName_set, METH_VARARGS, NULL},
	 { "MediaTransportInfo_srcRtpName_get", _wrap_MediaTransportInfo_srcRtpName_get, METH_O, NULL},
	 { "MediaTransportInfo_srcRtcpName_set", _wrap_MediaTransportInfo_srcRtcpName_set, METH_VARARGS, NULL},
	 { "MediaTransportInfo_srcRtcpName_get", _wrap_MediaTransportInfo_srcRtcpName_get, METH_O, NULL},
	 { "new_MediaTransportInfo", _wrap_new_MediaTransportInfo, METH_NOARGS, NULL},
	 { "delete_MediaTransportInfo", _wrap_delete_MediaTransportInfo, METH_O, NULL},
	 { "MediaTransportInfo_swigregister", MediaTransportInfo_swigregister, METH_O, NULL},
	 { "MediaTransportInfo_swiginit", MediaTransportInfo_swiginit, METH_VARARGS, NULL},
	 { "CallSetting_flag_set", _wrap_CallSetting_flag_set, METH_VARARGS, NULL},
	 { "CallSetting_flag_get", _wrap_CallSetting_flag_get, METH_O, NULL},
	 { "CallSetting_reqKeyframeMethod_set", _wrap_CallSetting_reqKeyframeMethod_set, METH_VARARGS, NULL},
	 { "CallSetting_reqKeyframeMethod_get", _wrap_CallSetting_reqKeyframeMethod_get, METH_O, NULL},
	 { "CallSetting_audioCount_set", _wrap_CallSetting_audioCount_set, METH_VARARGS, NULL},
	 { "CallSetting_audioCount_get", _wrap_CallSetting_audioCount_get, METH_O, NULL},
	 { "CallSetting_videoCount_set", _wrap_CallSetting_videoCount_set, METH_VARARGS, NULL},
	 { "CallSetting_videoCount_get", _wrap_CallSetting_videoCount_get, METH_O, NULL},
	 { "CallSetting_mediaDir_set", _wrap_CallSetting_mediaDir_set, METH_VARARGS, NULL},
	 { "CallSetting_mediaDir_get", _wrap_CallSetting_mediaDir_get, METH_O, NULL},
	 { "new_CallSetting", _wrap_new_CallSetting, METH_VARARGS, NULL},
	 { "CallSetting_isEmpty", _wrap_CallSetting_isEmpty, METH_O, NULL},
	 { "delete_CallSetting", _wrap_delete_CallSetting, METH_O, NULL},
	 { "CallSetting_swigregister", CallSetting_swigregister, METH_O, NULL},
	 { "CallSetting_swiginit", CallSetting_swiginit, METH_VARARGS, NULL},
	 { "CallMediaInfo_index_set", _wrap_CallMediaInfo_index_set, METH_VARARGS, NULL},
	 { "CallMediaInfo_index_get", _wrap_CallMediaInfo_index_get, METH_O, NULL},
	 { "CallMediaInfo_type_set", _wrap_CallMediaInfo_type_set, METH_VARARGS, NULL},
	 { "CallMediaInfo_type_get", _wrap_CallMediaInfo_type_get, METH_O, NULL},
	 { "CallMediaInfo_dir_set", _wrap_CallMediaInfo_dir_set, METH_VARARGS, NULL},
	 { "CallMediaInfo_dir_get", _wrap_CallMediaInfo_dir_get, METH_O, NULL},
	 { "CallMediaInfo_status_set", _wrap_CallMediaInfo_status_set, METH_VARARGS, NULL},
	 { "CallMediaInfo_status_get", _wrap_CallMediaInfo_status_get, METH_O, NULL},
	 { "CallMediaInfo_audioConfSlot_set", _wrap_CallMediaInfo_audioConfSlot_set, METH_VARARGS, NULL},
	 { "CallMediaInfo_audioConfSlot_get", _wrap_CallMediaInfo_audioConfSlot_get, METH_O, NULL},
	 { "CallMediaInfo_videoIncomingWindowId_set", _wrap_CallMediaInfo_videoIncomingWindowId_set, METH_VARARGS, NULL},
	 { "CallMediaInfo_videoIncomingWindowId_get", _wrap_CallMediaInfo_videoIncomingWindowId_get, METH_O, NULL},
	 { "CallMediaInfo_videoWindow_set", _wrap_CallMediaInfo_videoWindow_set, METH_VARARGS, NULL},
	 { "CallMediaInfo_videoWindow_get", _wrap_CallMediaInfo_videoWindow_get, METH_O, NULL},
	 { "CallMediaInfo_videoCapDev_set", _wrap_CallMediaInfo_videoCapDev_set, METH_VARARGS, NULL},
	 { "CallMediaInfo_videoCapDev_get", _wrap_CallMediaInfo_videoCapDev_get, METH_O, NULL},
	 { "new_CallMediaInfo", _wrap_new_CallMediaInfo, METH_NOARGS, NULL},
	 { "delete_CallMediaInfo", _wrap_delete_CallMediaInfo, METH_O, NULL},
	 { "CallMediaInfo_swigregister", CallMediaInfo_swigregister, METH_O, NULL},
	 { "CallMediaInfo_swiginit", CallMediaInfo_swiginit, METH_VARARGS, NULL},
	 { "CallInfo_id_set", _wrap_CallInfo_id_set, METH_VARARGS, NULL},
	 { "CallInfo_id_get", _wrap_CallInfo_id_get, METH_O, NULL},
	 { "CallInfo_role_set", _wrap_CallInfo_role_set, METH_VARARGS, NULL},
	 { "CallInfo_role_get", _wrap_CallInfo_role_get, METH_O, NULL},
	 { "CallInfo_accId_set", _wrap_CallInfo_accId_set, METH_VARARGS, NULL},
	 { "CallInfo_accId_get", _wrap_CallInfo_accId_get, METH_O, NULL},
	 { "CallInfo_localUri_set", _wrap_CallInfo_localUri_set, METH_VARARGS, NULL},
	 { "CallInfo_localUri_get", _wrap_CallInfo_localUri_get, METH_O, NULL},
	 { "CallInfo_localContact_set", _wrap_CallInfo_localContact_set, METH_VARARGS, NULL},
	 { "CallInfo_localContact_get", _wrap_CallInfo_localContact_get, METH_O, NULL},
	 { "CallInfo_remoteUri_set", _wrap_CallInfo_remoteUri_set, METH_VARARGS, NULL},
	 { "CallInfo_remoteUri_get", _wrap_CallInfo_remoteUri_get, METH_O, NULL},
	 { "CallInfo_remoteContact_set", _wrap_CallInfo_remoteContact_set, METH_VARARGS, NULL},
	 { "CallInfo_remoteContact_get", _wrap_CallInfo_remoteContact_get, METH_O, NULL},
	 { "CallInfo_callIdString_set", _wrap_CallInfo_callIdString_set, METH_VARARGS, NULL},
	 { "CallInfo_callIdString_get", _wrap_CallInfo_callIdString_get, METH_O, NULL},
	 { "CallInfo_setting_set", _wrap_CallInfo_setting_set, METH_VARARGS, NULL},
	 { "CallInfo_setting_get", _wrap_CallInfo_setting_get, METH_O, NULL},
	 { "CallInfo_state_set", _wrap_CallInfo_state_set, METH_VARARGS, NULL},
	 { "CallInfo_state_get", _wrap_CallInfo_state_get, METH_O, NULL},
	 { "CallInfo_stateText_set", _wrap_CallInfo_stateText_set, METH_VARARGS, NULL},
	 { "CallInfo_stateText_get", _wrap_CallInfo_stateText_get, METH_O, NULL},
	 { "CallInfo_lastStatusCode_set", _wrap_CallInfo_lastStatusCode_set, METH_VARARGS, NULL},
	 { "CallInfo_lastStatusCode_get", _wrap_CallInfo_lastStatusCode_get, METH_O, NULL},
	 { "CallInfo_lastReason_set", _wrap_CallInfo_lastReason_set, METH_VARARGS, NULL},
	 { "CallInfo_lastReason_get", _wrap_CallInfo_lastReason_get, METH_O, NULL},
	 { "CallInfo_media_set", _wrap_CallInfo_media_set, METH_VARARGS, NULL},
	 { "CallInfo_media_get", _wrap_CallInfo_media_get, METH_O, NULL},
	 { "CallInfo_provMedia_set", _wrap_CallInfo_provMedia_set, METH_VARARGS, NULL},
	 { "CallInfo_provMedia_get", _wrap_CallInfo_provMedia_get, METH_O, NULL},
	 { "CallInfo_connectDuration_set", _wrap_CallInfo_connectDuration_set, METH_VARARGS, NULL},
	 { "CallInfo_connectDuration_get", _wrap_CallInfo_connectDuration_get, METH_O, NULL},
	 { "CallInfo_totalDuration_set", _wrap_CallInfo_totalDuration_set, METH_VARARGS, NULL},
	 { "CallInfo_totalDuration_get", _wrap_CallInfo_totalDuration_get, METH_O, NULL},
	 { "CallInfo_remOfferer_set", _wrap_CallInfo_remOfferer_set, METH_VARARGS, NULL},
	 { "CallInfo_remOfferer_get", _wrap_CallInfo_remOfferer_get, METH_O, NULL},
	 { "CallInfo_remAudioCount_set", _wrap_CallInfo_remAudioCount_set, METH_VARARGS, NULL},
	 { "CallInfo_remAudioCount_get", _wrap_CallInfo_remAudioCount_get, METH_O, NULL},
	 { "CallInfo_remVideoCount_set", _wrap_CallInfo_remVideoCount_set, METH_VARARGS, NULL},
	 { "CallInfo_remVideoCount_get", _wrap_CallInfo_remVideoCount_get, METH_O, NULL},
	 { "new_CallInfo", _wrap_new_CallInfo, METH_NOARGS, NULL},
	 { "delete_CallInfo", _wrap_delete_CallInfo, METH_O, NULL},
	 { "CallInfo_swigregister", CallInfo_swigregister, METH_O, NULL},
	 { "CallInfo_swiginit", CallInfo_swiginit, METH_VARARGS, NULL},
	 { "StreamInfo_type_set", _wrap_StreamInfo_type_set, METH_VARARGS, NULL},
	 { "StreamInfo_type_get", _wrap_StreamInfo_type_get, METH_O, NULL},
	 { "StreamInfo_proto_set", _wrap_StreamInfo_proto_set, METH_VARARGS, NULL},
	 { "StreamInfo_proto_get", _wrap_StreamInfo_proto_get, METH_O, NULL},
	 { "StreamInfo_dir_set", _wrap_StreamInfo_dir_set, METH_VARARGS, NULL},
	 { "StreamInfo_dir_get", _wrap_StreamInfo_dir_get, METH_O, NULL},
	 { "StreamInfo_remoteRtpAddress_set", _wrap_StreamInfo_remoteRtpAddress_set, METH_VARARGS, NULL},
	 { "StreamInfo_remoteRtpAddress_get", _wrap_StreamInfo_remoteRtpAddress_get, METH_O, NULL},
	 { "StreamInfo_remoteRtcpAddress_set", _wrap_StreamInfo_remoteRtcpAddress_set, METH_VARARGS, NULL},
	 { "StreamInfo_remoteRtcpAddress_get", _wrap_StreamInfo_remoteRtcpAddress_get, METH_O, NULL},
	 { "StreamInfo_txPt_set", _wrap_StreamInfo_txPt_set, METH_VARARGS, NULL},
	 { "StreamInfo_txPt_get", _wrap_StreamInfo_txPt_get, METH_O, NULL},
	 { "StreamInfo_rxPt_set", _wrap_StreamInfo_rxPt_set, METH_VARARGS, NULL},
	 { "StreamInfo_rxPt_get", _wrap_StreamInfo_rxPt_get, METH_O, NULL},
	 { "StreamInfo_codecName_set", _wrap_StreamInfo_codecName_set, METH_VARARGS, NULL},
	 { "StreamInfo_codecName_get", _wrap_StreamInfo_codecName_get, METH_O, NULL},
	 { "StreamInfo_codecClockRate_set", _wrap_StreamInfo_codecClockRate_set, METH_VARARGS, NULL},
	 { "StreamInfo_codecClockRate_get", _wrap_StreamInfo_codecClockRate_get, METH_O, NULL},
	 { "StreamInfo_audCodecParam_set", _wrap_StreamInfo_audCodecParam_set, METH_VARARGS, NULL},
	 { "StreamInfo_audCodecParam_get", _wrap_StreamInfo_audCodecParam_get, METH_O, NULL},
	 { "StreamInfo_vidCodecParam_set", _wrap_StreamInfo_vidCodecParam_set, METH_VARARGS, NULL},
	 { "StreamInfo_vidCodecParam_get", _wrap_StreamInfo_vidCodecParam_get, METH_O, NULL},
	 { "StreamInfo_jbInit_set", _wrap_StreamInfo_jbInit_set, METH_VARARGS, NULL},
	 { "StreamInfo_jbInit_get", _wrap_StreamInfo_jbInit_get, METH_O, NULL},
	 { "StreamInfo_jbMinPre_set", _wrap_StreamInfo_jbMinPre_set, METH_VARARGS, NULL},
	 { "StreamInfo_jbMinPre_get", _wrap_StreamInfo_jbMinPre_get, METH_O, NULL},
	 { "StreamInfo_jbMaxPre_set", _wrap_StreamInfo_jbMaxPre_set, METH_VARARGS, NULL},
	 { "StreamInfo_jbMaxPre_get", _wrap_StreamInfo_jbMaxPre_get, METH_O, NULL},
	 { "StreamInfo_jbMax_set", _wrap_StreamInfo_jbMax_set, METH_VARARGS, NULL},
	 { "StreamInfo_jbMax_get", _wrap_StreamInfo_jbMax_get, METH_O, NULL},
	 { "StreamInfo_jbDiscardAlgo_set", _wrap_StreamInfo_jbDiscardAlgo_set, METH_VARARGS, NULL},
	 { "StreamInfo_jbDiscardAlgo_get", _wrap_StreamInfo_jbDiscardAlgo_get, METH_O, NULL},
	 { "StreamInfo_rtcpSdesByeDisabled_set", _wrap_StreamInfo_rtcpSdesByeDisabled_set, METH_VARARGS, NULL},
	 { "StreamInfo_rtcpSdesByeDisabled_get", _wrap_StreamInfo_rtcpSdesByeDisabled_get, METH_O, NULL},
	 { "new_StreamInfo", _wrap_new_StreamInfo, METH_NOARGS, NULL},
	 { "delete_StreamInfo", _wrap_delete_StreamInfo, METH_O, NULL},
	 { "StreamInfo_swigregister", StreamInfo_swigregister, METH_O, NULL},
	 { "StreamInfo_swiginit", StreamInfo_swiginit, METH_VARARGS, NULL},
	 { "StreamStat_rtcp_set", _wrap_StreamStat_rtcp_set, METH_VARARGS, NULL},
	 { "StreamStat_rtcp_get", _wrap_StreamStat_rtcp_get, METH_O, NULL},
	 { "StreamStat_jbuf_set", _wrap_StreamStat_jbuf_set, METH_VARARGS, NULL},
	 { "StreamStat_jbuf_get", _wrap_StreamStat_jbuf_get, METH_O, NULL},
	 { "new_StreamStat", _wrap_new_StreamStat, METH_NOARGS, NULL},
	 { "delete_StreamStat", _wrap_delete_StreamStat, METH_O, NULL},
	 { "StreamStat_swigregister", StreamStat_swigregister, METH_O, NULL},
	 { "StreamStat_swiginit", StreamStat_swiginit, METH_VARARGS, NULL},
	 { "OnCallStateParam_e_set", _wrap_OnCallStateParam_e_set, METH_VARARGS, NULL},
	 { "OnCallStateParam_e_get", _wrap_OnCallStateParam_e_get, METH_O, NULL},
	 { "new_OnCallStateParam", _wrap_new_OnCallStateParam, METH_NOARGS, NULL},
	 { "delete_OnCallStateParam", _wrap_delete_OnCallStateParam, METH_O, NULL},
	 { "OnCallStateParam_swigregister", OnCallStateParam_swigregister, METH_O, NULL},
	 { "OnCallStateParam_swiginit", OnCallStateParam_swiginit, METH_VARARGS, NULL},
	 { "OnCallTsxStateParam_e_set", _wrap_OnCallTsxStateParam_e_set, METH_VARARGS, NULL},
	 { "OnCallTsxStateParam_e_get", _wrap_OnCallTsxStateParam_e_get, METH_O, NULL},
	 { "new_OnCallTsxStateParam", _wrap_new_OnCallTsxStateParam, METH_NOARGS, NULL},
	 { "delete_OnCallTsxStateParam", _wrap_delete_OnCallTsxStateParam, METH_O, NULL},
	 { "OnCallTsxStateParam_swigregister", OnCallTsxStateParam_swigregister, METH_O, NULL},
	 { "OnCallTsxStateParam_swiginit", OnCallTsxStateParam_swiginit, METH_VARARGS, NULL},
	 { "new_OnCallMediaStateParam", _wrap_new_OnCallMediaStateParam, METH_NOARGS, NULL},
	 { "delete_OnCallMediaStateParam", _wrap_delete_OnCallMediaStateParam, METH_O, NULL},
	 { "OnCallMediaStateParam_swigregister", OnCallMediaStateParam_swigregister, METH_O, NULL},
	 { "OnCallMediaStateParam_swiginit", OnCallMediaStateParam_swiginit, METH_VARARGS, NULL},
	 { "OnCallSdpCreatedParam_sdp_set", _wrap_OnCallSdpCreatedParam_sdp_set, METH_VARARGS, NULL},
	 { "OnCallSdpCreatedParam_sdp_get", _wrap_OnCallSdpCreatedParam_sdp_get, METH_O, NULL},
	 { "OnCallSdpCreatedParam_remSdp_set", _wrap_OnCallSdpCreatedParam_remSdp_set, METH_VARARGS, NULL},
	 { "OnCallSdpCreatedParam_remSdp_get", _wrap_OnCallSdpCreatedParam_remSdp_get, METH_O, NULL},
	 { "new_OnCallSdpCreatedParam", _wrap_new_OnCallSdpCreatedParam, METH_NOARGS, NULL},
	 { "delete_OnCallSdpCreatedParam", _wrap_delete_OnCallSdpCreatedParam, METH_O, NULL},
	 { "OnCallSdpCreatedParam_swigregister", OnCallSdpCreatedParam_swigregister, METH_O, NULL},
	 { "OnCallSdpCreatedParam_swiginit", OnCallSdpCreatedParam_swiginit, METH_VARARGS, NULL},
	 { "OnStreamPreCreateParam_streamIdx_set", _wrap_OnStreamPreCreateParam_streamIdx_set, METH_VARARGS, NULL},
	 { "OnStreamPreCreateParam_streamIdx_get", _wrap_OnStreamPreCreateParam_streamIdx_get, METH_O, NULL},
	 { "OnStreamPreCreateParam_streamInfo_set", _wrap_OnStreamPreCreateParam_streamInfo_set, METH_VARARGS, NULL},
	 { "OnStreamPreCreateParam_streamInfo_get", _wrap_OnStreamPreCreateParam_streamInfo_get, METH_O, NULL},
	 { "new_OnStreamPreCreateParam", _wrap_new_OnStreamPreCreateParam, METH_NOARGS, NULL},
	 { "delete_OnStreamPreCreateParam", _wrap_delete_OnStreamPreCreateParam, METH_O, NULL},
	 { "OnStreamPreCreateParam_swigregister", OnStreamPreCreateParam_swigregister, METH_O, NULL},
	 { "OnStreamPreCreateParam_swiginit", OnStreamPreCreateParam_swiginit, METH_VARARGS, NULL},
	 { "OnStreamCreatedParam_stream_set", _wrap_OnStreamCreatedParam_stream_set, METH_VARARGS, NULL},
	 { "OnStreamCreatedParam_stream_get", _wrap_OnStreamCreatedParam_stream_get, METH_O, NULL},
	 { "OnStreamCreatedParam_streamIdx_set", _wrap_OnStreamCreatedParam_streamIdx_set, METH_VARARGS, NULL},
	 { "OnStreamCreatedParam_streamIdx_get", _wrap_OnStreamCreatedParam_streamIdx_get, METH_O, NULL},
	 { "OnStreamCreatedParam_destroyPort_set", _wrap_OnStreamCreatedParam_destroyPort_set, METH_VARARGS, NULL},
	 { "OnStreamCreatedParam_destroyPort_get", _wrap_OnStreamCreatedParam_destroyPort_get, METH_O, NULL},
	 { "OnStreamCreatedParam_pPort_set", _wrap_OnStreamCreatedParam_pPort_set, METH_VARARGS, NULL},
	 { "OnStreamCreatedParam_pPort_get", _wrap_OnStreamCreatedParam_pPort_get, METH_O, NULL},
	 { "new_OnStreamCreatedParam", _wrap_new_OnStreamCreatedParam, METH_NOARGS, NULL},
	 { "delete_OnStreamCreatedParam", _wrap_delete_OnStreamCreatedParam, METH_O, NULL},
	 { "OnStreamCreatedParam_swigregister", OnStreamCreatedParam_swigregister, METH_O, NULL},
	 { "OnStreamCreatedParam_swiginit", OnStreamCreatedParam_swiginit, METH_VARARGS, NULL},
	 { "OnStreamDestroyedParam_stream_set", _wrap_OnStreamDestroyedParam_stream_set, METH_VARARGS, NULL},
	 { "OnStreamDestroyedParam_stream_get", _wrap_OnStreamDestroyedParam_stream_get, METH_O, NULL},
	 { "OnStreamDestroyedParam_streamIdx_set", _wrap_OnStreamDestroyedParam_streamIdx_set, METH_VARARGS, NULL},
	 { "OnStreamDestroyedParam_streamIdx_get", _wrap_OnStreamDestroyedParam_streamIdx_get, METH_O, NULL},
	 { "new_OnStreamDestroyedParam", _wrap_new_OnStreamDestroyedParam, METH_NOARGS, NULL},
	 { "delete_OnStreamDestroyedParam", _wrap_delete_OnStreamDestroyedParam, METH_O, NULL},
	 { "OnStreamDestroyedParam_swigregister", OnStreamDestroyedParam_swigregister, METH_O, NULL},
	 { "OnStreamDestroyedParam_swiginit", OnStreamDestroyedParam_swiginit, METH_VARARGS, NULL},
	 { "OnDtmfDigitParam_method_set", _wrap_OnDtmfDigitParam_method_set, METH_VARARGS, NULL},
	 { "OnDtmfDigitParam_method_get", _wrap_OnDtmfDigitParam_method_get, METH_O, NULL},
	 { "OnDtmfDigitParam_digit_set", _wrap_OnDtmfDigitParam_digit_set, METH_VARARGS, NULL},
	 { "OnDtmfDigitParam_digit_get", _wrap_OnDtmfDigitParam_digit_get, METH_O, NULL},
	 { "OnDtmfDigitParam_duration_set", _wrap_OnDtmfDigitParam_duration_set, METH_VARARGS, NULL},
	 { "OnDtmfDigitParam_duration_get", _wrap_OnDtmfDigitParam_duration_get, METH_O, NULL},
	 { "new_OnDtmfDigitParam", _wrap_new_OnDtmfDigitParam, METH_NOARGS, NULL},
	 { "delete_OnDtmfDigitParam", _wrap_delete_OnDtmfDigitParam, METH_O, NULL},
	 { "OnDtmfDigitParam_swigregister", OnDtmfDigitParam_swigregister, METH_O, NULL},
	 { "OnDtmfDigitParam_swiginit", OnDtmfDigitParam_swiginit, METH_VARARGS, NULL},
	 { "OnDtmfEventParam_method_set", _wrap_OnDtmfEventParam_method_set, METH_VARARGS, NULL},
	 { "OnDtmfEventParam_method_get", _wrap_OnDtmfEventParam_method_get, METH_O, NULL},
	 { "OnDtmfEventParam_timestamp_set", _wrap_OnDtmfEventParam_timestamp_set, METH_VARARGS, NULL},
	 { "OnDtmfEventParam_timestamp_get", _wrap_OnDtmfEventParam_timestamp_get, METH_O, NULL},
	 { "OnDtmfEventParam_digit_set", _wrap_OnDtmfEventParam_digit_set, METH_VARARGS, NULL},
	 { "OnDtmfEventParam_digit_get", _wrap_OnDtmfEventParam_digit_get, METH_O, NULL},
	 { "OnDtmfEventParam_duration_set", _wrap_OnDtmfEventParam_duration_set, METH_VARARGS, NULL},
	 { "OnDtmfEventParam_duration_get", _wrap_OnDtmfEventParam_duration_get, METH_O, NULL},
	 { "OnDtmfEventParam_flags_set", _wrap_OnDtmfEventParam_flags_set, METH_VARARGS, NULL},
	 { "OnDtmfEventParam_flags_get", _wrap_OnDtmfEventParam_flags_get, METH_O, NULL},
	 { "new_OnDtmfEventParam", _wrap_new_OnDtmfEventParam, METH_NOARGS, NULL},
	 { "delete_OnDtmfEventParam", _wrap_delete_OnDtmfEventParam, METH_O, NULL},
	 { "OnDtmfEventParam_swigregister", OnDtmfEventParam_swigregister, METH_O, NULL},
	 { "OnDtmfEventParam_swiginit", OnDtmfEventParam_swiginit, METH_VARARGS, NULL},
	 { "OnCallTransferRequestParam_dstUri_set", _wrap_OnCallTransferRequestParam_dstUri_set, METH_VARARGS, NULL},
	 { "OnCallTransferRequestParam_dstUri_get", _wrap_OnCallTransferRequestParam_dstUri_get, METH_O, NULL},
	 { "OnCallTransferRequestParam_statusCode_set", _wrap_OnCallTransferRequestParam_statusCode_set, METH_VARARGS, NULL},
	 { "OnCallTransferRequestParam_statusCode_get", _wrap_OnCallTransferRequestParam_statusCode_get, METH_O, NULL},
	 { "OnCallTransferRequestParam_opt_set", _wrap_OnCallTransferRequestParam_opt_set, METH_VARARGS, NULL},
	 { "OnCallTransferRequestParam_opt_get", _wrap_OnCallTransferRequestParam_opt_get, METH_O, NULL},
	 { "OnCallTransferRequestParam_newCall_set", _wrap_OnCallTransferRequestParam_newCall_set, METH_VARARGS, NULL},
	 { "OnCallTransferRequestParam_newCall_get", _wrap_OnCallTransferRequestParam_newCall_get, METH_O, NULL},
	 { "new_OnCallTransferRequestParam", _wrap_new_OnCallTransferRequestParam, METH_NOARGS, NULL},
	 { "delete_OnCallTransferRequestParam", _wrap_delete_OnCallTransferRequestParam, METH_O, NULL},
	 { "OnCallTransferRequestParam_swigregister", OnCallTransferRequestParam_swigregister, METH_O, NULL},
	 { "OnCallTransferRequestParam_swiginit", OnCallTransferRequestParam_swiginit, METH_VARARGS, NULL},
	 { "OnCallTransferStatusParam_statusCode_set", _wrap_OnCallTransferStatusParam_statusCode_set, METH_VARARGS, NULL},
	 { "OnCallTransferStatusParam_statusCode_get", _wrap_OnCallTransferStatusParam_statusCode_get, METH_O, NULL},
	 { "OnCallTransferStatusParam_reason_set", _wrap_OnCallTransferStatusParam_reason_set, METH_VARARGS, NULL},
	 { "OnCallTransferStatusParam_reason_get", _wrap_OnCallTransferStatusParam_reason_get, METH_O, NULL},
	 { "OnCallTransferStatusParam_finalNotify_set", _wrap_OnCallTransferStatusParam_finalNotify_set, METH_VARARGS, NULL},
	 { "OnCallTransferStatusParam_finalNotify_get", _wrap_OnCallTransferStatusParam_finalNotify_get, METH_O, NULL},
	 { "OnCallTransferStatusParam_cont_set", _wrap_OnCallTransferStatusParam_cont_set, METH_VARARGS, NULL},
	 { "OnCallTransferStatusParam_cont_get", _wrap_OnCallTransferStatusParam_cont_get, METH_O, NULL},
	 { "new_OnCallTransferStatusParam", _wrap_new_OnCallTransferStatusParam, METH_NOARGS, NULL},
	 { "delete_OnCallTransferStatusParam", _wrap_delete_OnCallTransferStatusParam, METH_O, NULL},
	 { "OnCallTransferStatusParam_swigregister", OnCallTransferStatusParam_swigregister, METH_O, NULL},
	 { "OnCallTransferStatusParam_swiginit", OnCallTransferStatusParam_swiginit, METH_VARARGS, NULL},
	 { "OnCallReplaceRequestParam_rdata_set", _wrap_OnCallReplaceRequestParam_rdata_set, METH_VARARGS, NULL},
	 { "OnCallReplaceRequestParam_rdata_get", _wrap_OnCallReplaceRequestParam_rdata_get, METH_O, NULL},
	 { "OnCallReplaceRequestParam_statusCode_set", _wrap_OnCallReplaceRequestParam_statusCode_set, METH_VARARGS, NULL},
	 { "OnCallReplaceRequestParam_statusCode_get", _wrap_OnCallReplaceRequestParam_statusCode_get, METH_O, NULL},
	 { "OnCallReplaceRequestParam_reason_set", _wrap_OnCallReplaceRequestParam_reason_set, METH_VARARGS, NULL},
	 { "OnCallReplaceRequestParam_reason_get", _wrap_OnCallReplaceRequestParam_reason_get, METH_O, NULL},
	 { "OnCallReplaceRequestParam_opt_set", _wrap_OnCallReplaceRequestParam_opt_set, METH_VARARGS, NULL},
	 { "OnCallReplaceRequestParam_opt_get", _wrap_OnCallReplaceRequestParam_opt_get, METH_O, NULL},
	 { "new_OnCallReplaceRequestParam", _wrap_new_OnCallReplaceRequestParam, METH_NOARGS, NULL},
	 { "delete_OnCallReplaceRequestParam", _wrap_delete_OnCallReplaceRequestParam, METH_O, NULL},
	 { "OnCallReplaceRequestParam_swigregister", OnCallReplaceRequestParam_swigregister, METH_O, NULL},
	 { "OnCallReplaceRequestParam_swiginit", OnCallReplaceRequestParam_swiginit, METH_VARARGS, NULL},
	 { "OnCallReplacedParam_newCallId_set", _wrap_OnCallReplacedParam_newCallId_set, METH_VARARGS, NULL},
	 { "OnCallReplacedParam_newCallId_get", _wrap_OnCallReplacedParam_newCallId_get, METH_O, NULL},
	 { "OnCallReplacedParam_newCall_set", _wrap_OnCallReplacedParam_newCall_set, METH_VARARGS, NULL},
	 { "OnCallReplacedParam_newCall_get", _wrap_OnCallReplacedParam_newCall_get, METH_O, NULL},
	 { "new_OnCallReplacedParam", _wrap_new_OnCallReplacedParam, METH_NOARGS, NULL},
	 { "delete_OnCallReplacedParam", _wrap_delete_OnCallReplacedParam, METH_O, NULL},
	 { "OnCallReplacedParam_swigregister", OnCallReplacedParam_swigregister, METH_O, NULL},
	 { "OnCallReplacedParam_swiginit", OnCallReplacedParam_swiginit, METH_VARARGS, NULL},
	 { "OnCallRxOfferParam_offer_set", _wrap_OnCallRxOfferParam_offer_set, METH_VARARGS, NULL},
	 { "OnCallRxOfferParam_offer_get", _wrap_OnCallRxOfferParam_offer_get, METH_O, NULL},
	 { "OnCallRxOfferParam_statusCode_set", _wrap_OnCallRxOfferParam_statusCode_set, METH_VARARGS, NULL},
	 { "OnCallRxOfferParam_statusCode_get", _wrap_OnCallRxOfferParam_statusCode_get, METH_O, NULL},
	 { "OnCallRxOfferParam_opt_set", _wrap_OnCallRxOfferParam_opt_set, METH_VARARGS, NULL},
	 { "OnCallRxOfferParam_opt_get", _wrap_OnCallRxOfferParam_opt_get, METH_O, NULL},
	 { "new_OnCallRxOfferParam", _wrap_new_OnCallRxOfferParam, METH_NOARGS, NULL},
	 { "delete_OnCallRxOfferParam", _wrap_delete_OnCallRxOfferParam, METH_O, NULL},
	 { "OnCallRxOfferParam_swigregister", OnCallRxOfferParam_swigregister, METH_O, NULL},
	 { "OnCallRxOfferParam_swiginit", OnCallRxOfferParam_swiginit, METH_VARARGS, NULL},
	 { "OnCallRxReinviteParam_offer_set", _wrap_OnCallRxReinviteParam_offer_set, METH_VARARGS, NULL},
	 { "OnCallRxReinviteParam_offer_get", _wrap_OnCallRxReinviteParam_offer_get, METH_O, NULL},
	 { "OnCallRxReinviteParam_rdata_set", _wrap_OnCallRxReinviteParam_rdata_set, METH_VARARGS, NULL},
	 { "OnCallRxReinviteParam_rdata_get", _wrap_OnCallRxReinviteParam_rdata_get, METH_O, NULL},
	 { "OnCallRxReinviteParam_isAsync_set", _wrap_OnCallRxReinviteParam_isAsync_set, METH_VARARGS, NULL},
	 { "OnCallRxReinviteParam_isAsync_get", _wrap_OnCallRxReinviteParam_isAsync_get, METH_O, NULL},
	 { "OnCallRxReinviteParam_statusCode_set", _wrap_OnCallRxReinviteParam_statusCode_set, METH_VARARGS, NULL},
	 { "OnCallRxReinviteParam_statusCode_get", _wrap_OnCallRxReinviteParam_statusCode_get, METH_O, NULL},
	 { "OnCallRxReinviteParam_opt_set", _wrap_OnCallRxReinviteParam_opt_set, METH_VARARGS, NULL},
	 { "OnCallRxReinviteParam_opt_get", _wrap_OnCallRxReinviteParam_opt_get, METH_O, NULL},
	 { "new_OnCallRxReinviteParam", _wrap_new_OnCallRxReinviteParam, METH_NOARGS, NULL},
	 { "delete_OnCallRxReinviteParam", _wrap_delete_OnCallRxReinviteParam, METH_O, NULL},
	 { "OnCallRxReinviteParam_swigregister", OnCallRxReinviteParam_swigregister, METH_O, NULL},
	 { "OnCallRxReinviteParam_swiginit", OnCallRxReinviteParam_swiginit, METH_VARARGS, NULL},
	 { "OnCallTxOfferParam_opt_set", _wrap_OnCallTxOfferParam_opt_set, METH_VARARGS, NULL},
	 { "OnCallTxOfferParam_opt_get", _wrap_OnCallTxOfferParam_opt_get, METH_O, NULL},
	 { "new_OnCallTxOfferParam", _wrap_new_OnCallTxOfferParam, METH_NOARGS, NULL},
	 { "delete_OnCallTxOfferParam", _wrap_delete_OnCallTxOfferParam, METH_O, NULL},
	 { "OnCallTxOfferParam_swigregister", OnCallTxOfferParam_swigregister, METH_O, NULL},
	 { "OnCallTxOfferParam_swiginit", OnCallTxOfferParam_swiginit, METH_VARARGS, NULL},
	 { "OnCallRedirectedParam_targetUri_set", _wrap_OnCallRedirectedParam_targetUri_set, METH_VARARGS, NULL},
	 { "OnCallRedirectedParam_targetUri_get", _wrap_OnCallRedirectedParam_targetUri_get, METH_O, NULL},
	 { "OnCallRedirectedParam_e_set", _wrap_OnCallRedirectedParam_e_set, METH_VARARGS, NULL},
	 { "OnCallRedirectedParam_e_get", _wrap_OnCallRedirectedParam_e_get, METH_O, NULL},
	 { "new_OnCallRedirectedParam", _wrap_new_OnCallRedirectedParam, METH_NOARGS, NULL},
	 { "delete_OnCallRedirectedParam", _wrap_delete_OnCallRedirectedParam, METH_O, NULL},
	 { "OnCallRedirectedParam_swigregister", OnCallRedirectedParam_swigregister, METH_O, NULL},
	 { "OnCallRedirectedParam_swiginit", OnCallRedirectedParam_swiginit, METH_VARARGS, NULL},
	 { "OnCallMediaEventParam_medIdx_set", _wrap_OnCallMediaEventParam_medIdx_set, METH_VARARGS, NULL},
	 { "OnCallMediaEventParam_medIdx_get", _wrap_OnCallMediaEventParam_medIdx_get, METH_O, NULL},
	 { "OnCallMediaEventParam_ev_set", _wrap_OnCallMediaEventParam_ev_set, METH_VARARGS, NULL},
	 { "OnCallMediaEventParam_ev_get", _wrap_OnCallMediaEventParam_ev_get, METH_O, NULL},
	 { "new_OnCallMediaEventParam", _wrap_new_OnCallMediaEventParam, METH_NOARGS, NULL},
	 { "delete_OnCallMediaEventParam", _wrap_delete_OnCallMediaEventParam, METH_O, NULL},
	 { "OnCallMediaEventParam_swigregister", OnCallMediaEventParam_swigregister, METH_O, NULL},
	 { "OnCallMediaEventParam_swiginit", OnCallMediaEventParam_swiginit, METH_VARARGS, NULL},
	 { "OnCallMediaTransportStateParam_medIdx_set", _wrap_OnCallMediaTransportStateParam_medIdx_set, METH_VARARGS, NULL},
	 { "OnCallMediaTransportStateParam_medIdx_get", _wrap_OnCallMediaTransportStateParam_medIdx_get, METH_O, NULL},
	 { "OnCallMediaTransportStateParam_state_set", _wrap_OnCallMediaTransportStateParam_state_set, METH_VARARGS, NULL},
	 { "OnCallMediaTransportStateParam_state_get", _wrap_OnCallMediaTransportStateParam_state_get, METH_O, NULL},
	 { "OnCallMediaTransportStateParam_status_set", _wrap_OnCallMediaTransportStateParam_status_set, METH_VARARGS, NULL},
	 { "OnCallMediaTransportStateParam_status_get", _wrap_OnCallMediaTransportStateParam_status_get, METH_O, NULL},
	 { "OnCallMediaTransportStateParam_sipErrorCode_set", _wrap_OnCallMediaTransportStateParam_sipErrorCode_set, METH_VARARGS, NULL},
	 { "OnCallMediaTransportStateParam_sipErrorCode_get", _wrap_OnCallMediaTransportStateParam_sipErrorCode_get, METH_O, NULL},
	 { "new_OnCallMediaTransportStateParam", _wrap_new_OnCallMediaTransportStateParam, METH_NOARGS, NULL},
	 { "delete_OnCallMediaTransportStateParam", _wrap_delete_OnCallMediaTransportStateParam, METH_O, NULL},
	 { "OnCallMediaTransportStateParam_swigregister", OnCallMediaTransportStateParam_swigregister, METH_O, NULL},
	 { "OnCallMediaTransportStateParam_swiginit", OnCallMediaTransportStateParam_swiginit, METH_VARARGS, NULL},
	 { "OnCreateMediaTransportParam_mediaIdx_set", _wrap_OnCreateMediaTransportParam_mediaIdx_set, METH_VARARGS, NULL},
	 { "OnCreateMediaTransportParam_mediaIdx_get", _wrap_OnCreateMediaTransportParam_mediaIdx_get, METH_O, NULL},
	 { "OnCreateMediaTransportParam_mediaTp_set", _wrap_OnCreateMediaTransportParam_mediaTp_set, METH_VARARGS, NULL},
	 { "OnCreateMediaTransportParam_mediaTp_get", _wrap_OnCreateMediaTransportParam_mediaTp_get, METH_O, NULL},
	 { "OnCreateMediaTransportParam_flags_set", _wrap_OnCreateMediaTransportParam_flags_set, METH_VARARGS, NULL},
	 { "OnCreateMediaTransportParam_flags_get", _wrap_OnCreateMediaTransportParam_flags_get, METH_O, NULL},
	 { "new_OnCreateMediaTransportParam", _wrap_new_OnCreateMediaTransportParam, METH_NOARGS, NULL},
	 { "delete_OnCreateMediaTransportParam", _wrap_delete_OnCreateMediaTransportParam, METH_O, NULL},
	 { "OnCreateMediaTransportParam_swigregister", OnCreateMediaTransportParam_swigregister, METH_O, NULL},
	 { "OnCreateMediaTransportParam_swiginit", OnCreateMediaTransportParam_swiginit, METH_VARARGS, NULL},
	 { "OnCreateMediaTransportSrtpParam_mediaIdx_set", _wrap_OnCreateMediaTransportSrtpParam_mediaIdx_set, METH_VARARGS, NULL},
	 { "OnCreateMediaTransportSrtpParam_mediaIdx_get", _wrap_OnCreateMediaTransportSrtpParam_mediaIdx_get, METH_O, NULL},
	 { "OnCreateMediaTransportSrtpParam_srtpUse_set", _wrap_OnCreateMediaTransportSrtpParam_srtpUse_set, METH_VARARGS, NULL},
	 { "OnCreateMediaTransportSrtpParam_srtpUse_get", _wrap_OnCreateMediaTransportSrtpParam_srtpUse_get, METH_O, NULL},
	 { "OnCreateMediaTransportSrtpParam_cryptos_set", _wrap_OnCreateMediaTransportSrtpParam_cryptos_set, METH_VARARGS, NULL},
	 { "OnCreateMediaTransportSrtpParam_cryptos_get", _wrap_OnCreateMediaTransportSrtpParam_cryptos_get, METH_O, NULL},
	 { "new_OnCreateMediaTransportSrtpParam", _wrap_new_OnCreateMediaTransportSrtpParam, METH_NOARGS, NULL},
	 { "delete_OnCreateMediaTransportSrtpParam", _wrap_delete_OnCreateMediaTransportSrtpParam, METH_O, NULL},
	 { "OnCreateMediaTransportSrtpParam_swigregister", OnCreateMediaTransportSrtpParam_swigregister, METH_O, NULL},
	 { "OnCreateMediaTransportSrtpParam_swiginit", OnCreateMediaTransportSrtpParam_swiginit, METH_VARARGS, NULL},
	 { "CallOpParam_opt_set", _wrap_CallOpParam_opt_set, METH_VARARGS, NULL},
	 { "CallOpParam_opt_get", _wrap_CallOpParam_opt_get, METH_O, NULL},
	 { "CallOpParam_statusCode_set", _wrap_CallOpParam_statusCode_set, METH_VARARGS, NULL},
	 { "CallOpParam_statusCode_get", _wrap_CallOpParam_statusCode_get, METH_O, NULL},
	 { "CallOpParam_reason_set", _wrap_CallOpParam_reason_set, METH_VARARGS, NULL},
	 { "CallOpParam_reason_get", _wrap_CallOpParam_reason_get, METH_O, NULL},
	 { "CallOpParam_options_set", _wrap_CallOpParam_options_set, METH_VARARGS, NULL},
	 { "CallOpParam_options_get", _wrap_CallOpParam_options_get, METH_O, NULL},
	 { "CallOpParam_txOption_set", _wrap_CallOpParam_txOption_set, METH_VARARGS, NULL},
	 { "CallOpParam_txOption_get", _wrap_CallOpParam_txOption_get, METH_O, NULL},
	 { "CallOpParam_sdp_set", _wrap_CallOpParam_sdp_set, METH_VARARGS, NULL},
	 { "CallOpParam_sdp_get", _wrap_CallOpParam_sdp_get, METH_O, NULL},
	 { "new_CallOpParam", _wrap_new_CallOpParam, METH_VARARGS, NULL},
	 { "delete_CallOpParam", _wrap_delete_CallOpParam, METH_O, NULL},
	 { "CallOpParam_swigregister", CallOpParam_swigregister, METH_O, NULL},
	 { "CallOpParam_swiginit", CallOpParam_swiginit, METH_VARARGS, NULL},
	 { "CallSendRequestParam_method_set", _wrap_CallSendRequestParam_method_set, METH_VARARGS, NULL},
	 { "CallSendRequestParam_method_get", _wrap_CallSendRequestParam_method_get, METH_O, NULL},
	 { "CallSendRequestParam_txOption_set", _wrap_CallSendRequestParam_txOption_set, METH_VARARGS, NULL},
	 { "CallSendRequestParam_txOption_get", _wrap_CallSendRequestParam_txOption_get, METH_O, NULL},
	 { "new_CallSendRequestParam", _wrap_new_CallSendRequestParam, METH_NOARGS, NULL},
	 { "delete_CallSendRequestParam", _wrap_delete_CallSendRequestParam, METH_O, NULL},
	 { "CallSendRequestParam_swigregister", CallSendRequestParam_swigregister, METH_O, NULL},
	 { "CallSendRequestParam_swiginit", CallSendRequestParam_swiginit, METH_VARARGS, NULL},
	 { "CallVidSetStreamParam_medIdx_set", _wrap_CallVidSetStreamParam_medIdx_set, METH_VARARGS, NULL},
	 { "CallVidSetStreamParam_medIdx_get", _wrap_CallVidSetStreamParam_medIdx_get, METH_O, NULL},
	 { "CallVidSetStreamParam_dir_set", _wrap_CallVidSetStreamParam_dir_set, METH_VARARGS, NULL},
	 { "CallVidSetStreamParam_dir_get", _wrap_CallVidSetStreamParam_dir_get, METH_O, NULL},
	 { "CallVidSetStreamParam_capDev_set", _wrap_CallVidSetStreamParam_capDev_set, METH_VARARGS, NULL},
	 { "CallVidSetStreamParam_capDev_get", _wrap_CallVidSetStreamParam_capDev_get, METH_O, NULL},
	 { "new_CallVidSetStreamParam", _wrap_new_CallVidSetStreamParam, METH_NOARGS, NULL},
	 { "delete_CallVidSetStreamParam", _wrap_delete_CallVidSetStreamParam, METH_O, NULL},
	 { "CallVidSetStreamParam_swigregister", CallVidSetStreamParam_swigregister, METH_O, NULL},
	 { "CallVidSetStreamParam_swiginit", CallVidSetStreamParam_swiginit, METH_VARARGS, NULL},
	 { "CallSendDtmfParam_method_set", _wrap_CallSendDtmfParam_method_set, METH_VARARGS, NULL},
	 { "CallSendDtmfParam_method_get", _wrap_CallSendDtmfParam_method_get, METH_O, NULL},
	 { "CallSendDtmfParam_duration_set", _wrap_CallSendDtmfParam_duration_set, METH_VARARGS, NULL},
	 { "CallSendDtmfParam_duration_get", _wrap_CallSendDtmfParam_duration_get, METH_O, NULL},
	 { "CallSendDtmfParam_digits_set", _wrap_CallSendDtmfParam_digits_set, METH_VARARGS, NULL},
	 { "CallSendDtmfParam_digits_get", _wrap_CallSendDtmfParam_digits_get, METH_O, NULL},
	 { "new_CallSendDtmfParam", _wrap_new_CallSendDtmfParam, METH_NOARGS, NULL},
	 { "delete_CallSendDtmfParam", _wrap_delete_CallSendDtmfParam, METH_O, NULL},
	 { "CallSendDtmfParam_swigregister", CallSendDtmfParam_swigregister, METH_O, NULL},
	 { "CallSendDtmfParam_swiginit", CallSendDtmfParam_swiginit, METH_VARARGS, NULL},
	 { "new_Call", _wrap_new_Call, METH_VARARGS, NULL},
	 { "delete_Call", _wrap_delete_Call, METH_O, NULL},
	 { "Call_getInfo", _wrap_Call_getInfo, METH_O, NULL},
	 { "Call_isActive", _wrap_Call_isActive, METH_O, NULL},
	 { "Call_getId", _wrap_Call_getId, METH_O, NULL},
	 { "Call_lookup", _wrap_Call_lookup, METH_O, NULL},
	 { "Call_hasMedia", _wrap_Call_hasMedia, METH_O, NULL},
	 { "Call_getMedia", _wrap_Call_getMedia, METH_VARARGS, NULL},
	 { "Call_getAudioMedia", _wrap_Call_getAudioMedia, METH_VARARGS, NULL},
	 { "Call_getEncodingVideoMedia", _wrap_Call_getEncodingVideoMedia, METH_VARARGS, NULL},
	 { "Call_getDecodingVideoMedia", _wrap_Call_getDecodingVideoMedia, METH_VARARGS, NULL},
	 { "Call_remoteHasCap", _wrap_Call_remoteHasCap, METH_VARARGS, NULL},
	 { "Call_setUserData", _wrap_Call_setUserData, METH_VARARGS, NULL},
	 { "Call_getUserData", _wrap_Call_getUserData, METH_O, NULL},
	 { "Call_getRemNatType", _wrap_Call_getRemNatType, METH_O, NULL},
	 { "Call_makeCall", _wrap_Call_makeCall, METH_VARARGS, NULL},
	 { "Call_answer", _wrap_Call_answer, METH_VARARGS, NULL},
	 { "Call_hangup", _wrap_Call_hangup, METH_VARARGS, NULL},
	 { "Call_setHold", _wrap_Call_setHold, METH_VARARGS, NULL},
	 { "Call_reinvite", _wrap_Call_reinvite, METH_VARARGS, NULL},
	 { "Call_update", _wrap_Call_update, METH_VARARGS, NULL},
	 { "Call_xfer", _wrap_Call_xfer, METH_VARARGS, NULL},
	 { "Call_xferReplaces", _wrap_Call_xferReplaces, METH_VARARGS, NULL},
	 { "Call_processRedirect", _wrap_Call_processRedirect, METH_VARARGS, NULL},
	 { "Call_dialDtmf", _wrap_Call_dialDtmf, METH_VARARGS, NULL},
	 { "Call_sendDtmf", _wrap_Call_sendDtmf, METH_VARARGS, NULL},
	 { "Call_sendInstantMessage", _wrap_Call_sendInstantMessage, METH_VARARGS, NULL},
	 { "Call_sendTypingIndication", _wrap_Call_sendTypingIndication, METH_VARARGS, NULL},
	 { "Call_sendRequest", _wrap_Call_sendRequest, METH_VARARGS, NULL},
	 { "Call_dump", _wrap_Call_dump, METH_VARARGS, NULL},
	 { "Call_vidGetStreamIdx", _wrap_Call_vidGetStreamIdx, METH_O, NULL},
	 { "Call_vidStreamIsRunning", _wrap_Call_vidStreamIsRunning, METH_VARARGS, NULL},
	 { "Call_vidSetStream", _wrap_Call_vidSetStream, METH_VARARGS, NULL},
	 { "Call_getStreamInfo", _wrap_Call_getStreamInfo, METH_VARARGS, NULL},
	 { "Call_getStreamStat", _wrap_Call_getStreamStat, METH_VARARGS, NULL},
	 { "Call_getMedTransportInfo", _wrap_Call_getMedTransportInfo, METH_VARARGS, NULL},
	 { "Call_processMediaUpdate", _wrap_Call_processMediaUpdate, METH_VARARGS, NULL},
	 { "Call_processStateChange", _wrap_Call_processStateChange, METH_VARARGS, NULL},
	 { "Call_onCallState", _wrap_Call_onCallState, METH_VARARGS, NULL},
	 { "Call_onCallTsxState", _wrap_Call_onCallTsxState, METH_VARARGS, NULL},
	 { "Call_onCallMediaState", _wrap_Call_onCallMediaState, METH_VARARGS, NULL},
	 { "Call_onCallSdpCreated", _wrap_Call_onCallSdpCreated, METH_VARARGS, NULL},
	 { "Call_onStreamPreCreate", _wrap_Call_onStreamPreCreate, METH_VARARGS, NULL},
	 { "Call_onStreamCreated", _wrap_Call_onStreamCreated, METH_VARARGS, NULL},
	 { "Call_onStreamDestroyed", _wrap_Call_onStreamDestroyed, METH_VARARGS, NULL},
	 { "Call_onDtmfDigit", _wrap_Call_onDtmfDigit, METH_VARARGS, NULL},
	 { "Call_onDtmfEvent", _wrap_Call_onDtmfEvent, METH_VARARGS, NULL},
	 { "Call_onCallTransferRequest", _wrap_Call_onCallTransferRequest, METH_VARARGS, NULL},
	 { "Call_onCallTransferStatus", _wrap_Call_onCallTransferStatus, METH_VARARGS, NULL},
	 { "Call_onCallReplaceRequest", _wrap_Call_onCallReplaceRequest, METH_VARARGS, NULL},
	 { "Call_onCallReplaced", _wrap_Call_onCallReplaced, METH_VARARGS, NULL},
	 { "Call_onCallRxOffer", _wrap_Call_onCallRxOffer, METH_VARARGS, NULL},
	 { "Call_onCallRxReinvite", _wrap_Call_onCallRxReinvite, METH_VARARGS, NULL},
	 { "Call_onCallTxOffer", _wrap_Call_onCallTxOffer, METH_VARARGS, NULL},
	 { "Call_onInstantMessage", _wrap_Call_onInstantMessage, METH_VARARGS, NULL},
	 { "Call_onInstantMessageStatus", _wrap_Call_onInstantMessageStatus, METH_VARARGS, NULL},
	 { "Call_onTypingIndication", _wrap_Call_onTypingIndication, METH_VARARGS, NULL},
	 { "Call_onCallRedirected", _wrap_Call_onCallRedirected, METH_VARARGS, NULL},
	 { "Call_onCallMediaTransportState", _wrap_Call_onCallMediaTransportState, METH_VARARGS, NULL},
	 { "Call_onCallMediaEvent", _wrap_Call_onCallMediaEvent, METH_VARARGS, NULL},
	 { "Call_onCreateMediaTransport", _wrap_Call_onCreateMediaTransport, METH_VARARGS, NULL},
	 { "Call_onCreateMediaTransportSrtp", _wrap_Call_onCreateMediaTransportSrtp, METH_VARARGS, NULL},
	 { "disown_Call", _wrap_disown_Call, METH_O, NULL},
	 { "Call_swigregister", Call_swigregister, METH_O, NULL},
	 { "Call_swiginit", Call_swiginit, METH_VARARGS, NULL},
	 { "new_JsonDocument", _wrap_new_JsonDocument, METH_NOARGS, NULL},
	 { "delete_JsonDocument", _wrap_delete_JsonDocument, METH_O, NULL},
	 { "JsonDocument_loadFile", _wrap_JsonDocument_loadFile, METH_VARARGS, NULL},
	 { "JsonDocument_loadString", _wrap_JsonDocument_loadString, METH_VARARGS, NULL},
	 { "JsonDocument_saveFile", _wrap_JsonDocument_saveFile, METH_VARARGS, NULL},
	 { "JsonDocument_saveString", _wrap_JsonDocument_saveString, METH_O, NULL},
	 { "JsonDocument_getRootContainer", _wrap_JsonDocument_getRootContainer, METH_O, NULL},
	 { "JsonDocument_swigregister", JsonDocument_swigregister, METH_O, NULL},
	 { "JsonDocument_swiginit", JsonDocument_swiginit, METH_VARARGS, NULL},
	 { "OnNatDetectionCompleteParam_status_set", _wrap_OnNatDetectionCompleteParam_status_set, METH_VARARGS, NULL},
	 { "OnNatDetectionCompleteParam_status_get", _wrap_OnNatDetectionCompleteParam_status_get, METH_O, NULL},
	 { "OnNatDetectionCompleteParam_reason_set", _wrap_OnNatDetectionCompleteParam_reason_set, METH_VARARGS, NULL},
	 { "OnNatDetectionCompleteParam_reason_get", _wrap_OnNatDetectionCompleteParam_reason_get, METH_O, NULL},
	 { "OnNatDetectionCompleteParam_natType_set", _wrap_OnNatDetectionCompleteParam_natType_set, METH_VARARGS, NULL},
	 { "OnNatDetectionCompleteParam_natType_get", _wrap_OnNatDetectionCompleteParam_natType_get, METH_O, NULL},
	 { "OnNatDetectionCompleteParam_natTypeName_set", _wrap_OnNatDetectionCompleteParam_natTypeName_set, METH_VARARGS, NULL},
	 { "OnNatDetectionCompleteParam_natTypeName_get", _wrap_OnNatDetectionCompleteParam_natTypeName_get, METH_O, NULL},
	 { "new_OnNatDetectionCompleteParam", _wrap_new_OnNatDetectionCompleteParam, METH_NOARGS, NULL},
	 { "delete_OnNatDetectionCompleteParam", _wrap_delete_OnNatDetectionCompleteParam, METH_O, NULL},
	 { "OnNatDetectionCompleteParam_swigregister", OnNatDetectionCompleteParam_swigregister, METH_O, NULL},
	 { "OnNatDetectionCompleteParam_swiginit", OnNatDetectionCompleteParam_swiginit, METH_VARARGS, NULL},
	 { "OnNatCheckStunServersCompleteParam_userData_set", _wrap_OnNatCheckStunServersCompleteParam_userData_set, METH_VARARGS, NULL},
	 { "OnNatCheckStunServersCompleteParam_userData_get", _wrap_OnNatCheckStunServersCompleteParam_userData_get, METH_O, NULL},
	 { "OnNatCheckStunServersCompleteParam_status_set", _wrap_OnNatCheckStunServersCompleteParam_status_set, METH_VARARGS, NULL},
	 { "OnNatCheckStunServersCompleteParam_status_get", _wrap_OnNatCheckStunServersCompleteParam_status_get, METH_O, NULL},
	 { "OnNatCheckStunServersCompleteParam_name_set", _wrap_OnNatCheckStunServersCompleteParam_name_set, METH_VARARGS, NULL},
	 { "OnNatCheckStunServersCompleteParam_name_get", _wrap_OnNatCheckStunServersCompleteParam_name_get, METH_O, NULL},
	 { "OnNatCheckStunServersCompleteParam_addr_set", _wrap_OnNatCheckStunServersCompleteParam_addr_set, METH_VARARGS, NULL},
	 { "OnNatCheckStunServersCompleteParam_addr_get", _wrap_OnNatCheckStunServersCompleteParam_addr_get, METH_O, NULL},
	 { "new_OnNatCheckStunServersCompleteParam", _wrap_new_OnNatCheckStunServersCompleteParam, METH_NOARGS, NULL},
	 { "delete_OnNatCheckStunServersCompleteParam", _wrap_delete_OnNatCheckStunServersCompleteParam, METH_O, NULL},
	 { "OnNatCheckStunServersCompleteParam_swigregister", OnNatCheckStunServersCompleteParam_swigregister, METH_O, NULL},
	 { "OnNatCheckStunServersCompleteParam_swiginit", OnNatCheckStunServersCompleteParam_swiginit, METH_VARARGS, NULL},
	 { "OnTimerParam_userData_set", _wrap_OnTimerParam_userData_set, METH_VARARGS, NULL},
	 { "OnTimerParam_userData_get", _wrap_OnTimerParam_userData_get, METH_O, NULL},
	 { "OnTimerParam_msecDelay_set", _wrap_OnTimerParam_msecDelay_set, METH_VARARGS, NULL},
	 { "OnTimerParam_msecDelay_get", _wrap_OnTimerParam_msecDelay_get, METH_O, NULL},
	 { "new_OnTimerParam", _wrap_new_OnTimerParam, METH_NOARGS, NULL},
	 { "delete_OnTimerParam", _wrap_delete_OnTimerParam, METH_O, NULL},
	 { "OnTimerParam_swigregister", OnTimerParam_swigregister, METH_O, NULL},
	 { "OnTimerParam_swiginit", OnTimerParam_swiginit, METH_VARARGS, NULL},
	 { "SslCertName_type_set", _wrap_SslCertName_type_set, METH_VARARGS, NULL},
	 { "SslCertName_type_get", _wrap_SslCertName_type_get, METH_O, NULL},
	 { "SslCertName_name_set", _wrap_SslCertName_name_set, METH_VARARGS, NULL},
	 { "SslCertName_name_get", _wrap_SslCertName_name_get, METH_O, NULL},
	 { "new_SslCertName", _wrap_new_SslCertName, METH_NOARGS, NULL},
	 { "delete_SslCertName", _wrap_delete_SslCertName, METH_O, NULL},
	 { "SslCertName_swigregister", SslCertName_swigregister, METH_O, NULL},
	 { "SslCertName_swiginit", SslCertName_swiginit, METH_VARARGS, NULL},
	 { "SslCertInfo_version_set", _wrap_SslCertInfo_version_set, METH_VARARGS, NULL},
	 { "SslCertInfo_version_get", _wrap_SslCertInfo_version_get, METH_O, NULL},
	 { "SslCertInfo_serialNo_set", _wrap_SslCertInfo_serialNo_set, METH_VARARGS, NULL},
	 { "SslCertInfo_serialNo_get", _wrap_SslCertInfo_serialNo_get, METH_O, NULL},
	 { "SslCertInfo_subjectCn_set", _wrap_SslCertInfo_subjectCn_set, METH_VARARGS, NULL},
	 { "SslCertInfo_subjectCn_get", _wrap_SslCertInfo_subjectCn_get, METH_O, NULL},
	 { "SslCertInfo_subjectInfo_set", _wrap_SslCertInfo_subjectInfo_set, METH_VARARGS, NULL},
	 { "SslCertInfo_subjectInfo_get", _wrap_SslCertInfo_subjectInfo_get, METH_O, NULL},
	 { "SslCertInfo_issuerCn_set", _wrap_SslCertInfo_issuerCn_set, METH_VARARGS, NULL},
	 { "SslCertInfo_issuerCn_get", _wrap_SslCertInfo_issuerCn_get, METH_O, NULL},
	 { "SslCertInfo_issuerInfo_set", _wrap_SslCertInfo_issuerInfo_set, METH_VARARGS, NULL},
	 { "SslCertInfo_issuerInfo_get", _wrap_SslCertInfo_issuerInfo_get, METH_O, NULL},
	 { "SslCertInfo_validityStart_set", _wrap_SslCertInfo_validityStart_set, METH_VARARGS, NULL},
	 { "SslCertInfo_validityStart_get", _wrap_SslCertInfo_validityStart_get, METH_O, NULL},
	 { "SslCertInfo_validityEnd_set", _wrap_SslCertInfo_validityEnd_set, METH_VARARGS, NULL},
	 { "SslCertInfo_validityEnd_get", _wrap_SslCertInfo_validityEnd_get, METH_O, NULL},
	 { "SslCertInfo_validityGmt_set", _wrap_SslCertInfo_validityGmt_set, METH_VARARGS, NULL},
	 { "SslCertInfo_validityGmt_get", _wrap_SslCertInfo_validityGmt_get, METH_O, NULL},
	 { "SslCertInfo_subjectAltName_set", _wrap_SslCertInfo_subjectAltName_set, METH_VARARGS, NULL},
	 { "SslCertInfo_subjectAltName_get", _wrap_SslCertInfo_subjectAltName_get, METH_O, NULL},
	 { "SslCertInfo_raw_set", _wrap_SslCertInfo_raw_set, METH_VARARGS, NULL},
	 { "SslCertInfo_raw_get", _wrap_SslCertInfo_raw_get, METH_O, NULL},
	 { "new_SslCertInfo", _wrap_new_SslCertInfo, METH_NOARGS, NULL},
	 { "SslCertInfo_isEmpty", _wrap_SslCertInfo_isEmpty, METH_O, NULL},
	 { "delete_SslCertInfo", _wrap_delete_SslCertInfo, METH_O, NULL},
	 { "SslCertInfo_swigregister", SslCertInfo_swigregister, METH_O, NULL},
	 { "SslCertInfo_swiginit", SslCertInfo_swiginit, METH_VARARGS, NULL},
	 { "TlsInfo_established_set", _wrap_TlsInfo_established_set, METH_VARARGS, NULL},
	 { "TlsInfo_established_get", _wrap_TlsInfo_established_get, METH_O, NULL},
	 { "TlsInfo_protocol_set", _wrap_TlsInfo_protocol_set, METH_VARARGS, NULL},
	 { "TlsInfo_protocol_get", _wrap_TlsInfo_protocol_get, METH_O, NULL},
	 { "TlsInfo_cipher_set", _wrap_TlsInfo_cipher_set, METH_VARARGS, NULL},
	 { "TlsInfo_cipher_get", _wrap_TlsInfo_cipher_get, METH_O, NULL},
	 { "TlsInfo_cipherName_set", _wrap_TlsInfo_cipherName_set, METH_VARARGS, NULL},
	 { "TlsInfo_cipherName_get", _wrap_TlsInfo_cipherName_get, METH_O, NULL},
	 { "TlsInfo_localAddr_set", _wrap_TlsInfo_localAddr_set, METH_VARARGS, NULL},
	 { "TlsInfo_localAddr_get", _wrap_TlsInfo_localAddr_get, METH_O, NULL},
	 { "TlsInfo_remoteAddr_set", _wrap_TlsInfo_remoteAddr_set, METH_VARARGS, NULL},
	 { "TlsInfo_remoteAddr_get", _wrap_TlsInfo_remoteAddr_get, METH_O, NULL},
	 { "TlsInfo_localCertInfo_set", _wrap_TlsInfo_localCertInfo_set, METH_VARARGS, NULL},
	 { "TlsInfo_localCertInfo_get", _wrap_TlsInfo_localCertInfo_get, METH_O, NULL},
	 { "TlsInfo_remoteCertInfo_set", _wrap_TlsInfo_remoteCertInfo_set, METH_VARARGS, NULL},
	 { "TlsInfo_remoteCertInfo_get", _wrap_TlsInfo_remoteCertInfo_get, METH_O, NULL},
	 { "TlsInfo_verifyStatus_set", _wrap_TlsInfo_verifyStatus_set, METH_VARARGS, NULL},
	 { "TlsInfo_verifyStatus_get", _wrap_TlsInfo_verifyStatus_get, METH_O, NULL},
	 { "TlsInfo_verifyMsgs_set", _wrap_TlsInfo_verifyMsgs_set, METH_VARARGS, NULL},
	 { "TlsInfo_verifyMsgs_get", _wrap_TlsInfo_verifyMsgs_get, METH_O, NULL},
	 { "new_TlsInfo", _wrap_new_TlsInfo, METH_NOARGS, NULL},
	 { "TlsInfo_isEmpty", _wrap_TlsInfo_isEmpty, METH_O, NULL},
	 { "delete_TlsInfo", _wrap_delete_TlsInfo, METH_O, NULL},
	 { "TlsInfo_swigregister", TlsInfo_swigregister, METH_O, NULL},
	 { "TlsInfo_swiginit", TlsInfo_swiginit, METH_VARARGS, NULL},
	 { "OnTransportStateParam_hnd_set", _wrap_OnTransportStateParam_hnd_set, METH_VARARGS, NULL},
	 { "OnTransportStateParam_hnd_get", _wrap_OnTransportStateParam_hnd_get, METH_O, NULL},
	 { "OnTransportStateParam_type_set", _wrap_OnTransportStateParam_type_set, METH_VARARGS, NULL},
	 { "OnTransportStateParam_type_get", _wrap_OnTransportStateParam_type_get, METH_O, NULL},
	 { "OnTransportStateParam_state_set", _wrap_OnTransportStateParam_state_set, METH_VARARGS, NULL},
	 { "OnTransportStateParam_state_get", _wrap_OnTransportStateParam_state_get, METH_O, NULL},
	 { "OnTransportStateParam_lastError_set", _wrap_OnTransportStateParam_lastError_set, METH_VARARGS, NULL},
	 { "OnTransportStateParam_lastError_get", _wrap_OnTransportStateParam_lastError_get, METH_O, NULL},
	 { "OnTransportStateParam_tlsInfo_set", _wrap_OnTransportStateParam_tlsInfo_set, METH_VARARGS, NULL},
	 { "OnTransportStateParam_tlsInfo_get", _wrap_OnTransportStateParam_tlsInfo_get, METH_O, NULL},
	 { "new_OnTransportStateParam", _wrap_new_OnTransportStateParam, METH_NOARGS, NULL},
	 { "delete_OnTransportStateParam", _wrap_delete_OnTransportStateParam, METH_O, NULL},
	 { "OnTransportStateParam_swigregister", OnTransportStateParam_swigregister, METH_O, NULL},
	 { "OnTransportStateParam_swiginit", OnTransportStateParam_swiginit, METH_VARARGS, NULL},
	 { "OnSelectAccountParam_rdata_set", _wrap_OnSelectAccountParam_rdata_set, METH_VARARGS, NULL},
	 { "OnSelectAccountParam_rdata_get", _wrap_OnSelectAccountParam_rdata_get, METH_O, NULL},
	 { "OnSelectAccountParam_accountIndex_set", _wrap_OnSelectAccountParam_accountIndex_set, METH_VARARGS, NULL},
	 { "OnSelectAccountParam_accountIndex_get", _wrap_OnSelectAccountParam_accountIndex_get, METH_O, NULL},
	 { "new_OnSelectAccountParam", _wrap_new_OnSelectAccountParam, METH_NOARGS, NULL},
	 { "delete_OnSelectAccountParam", _wrap_delete_OnSelectAccountParam, METH_O, NULL},
	 { "OnSelectAccountParam_swigregister", OnSelectAccountParam_swigregister, METH_O, NULL},
	 { "OnSelectAccountParam_swiginit", OnSelectAccountParam_swiginit, METH_VARARGS, NULL},
	 { "IpChangeParam_restartListener_set", _wrap_IpChangeParam_restartListener_set, METH_VARARGS, NULL},
	 { "IpChangeParam_restartListener_get", _wrap_IpChangeParam_restartListener_get, METH_O, NULL},
	 { "IpChangeParam_restartLisDelay_set", _wrap_IpChangeParam_restartLisDelay_set, METH_VARARGS, NULL},
	 { "IpChangeParam_restartLisDelay_get", _wrap_IpChangeParam_restartLisDelay_get, METH_O, NULL},
	 { "new_IpChangeParam", _wrap_new_IpChangeParam, METH_NOARGS, NULL},
	 { "delete_IpChangeParam", _wrap_delete_IpChangeParam, METH_O, NULL},
	 { "IpChangeParam_swigregister", IpChangeParam_swigregister, METH_O, NULL},
	 { "IpChangeParam_swiginit", IpChangeParam_swiginit, METH_VARARGS, NULL},
	 { "RegProgressParam_isRegister_set", _wrap_RegProgressParam_isRegister_set, METH_VARARGS, NULL},
	 { "RegProgressParam_isRegister_get", _wrap_RegProgressParam_isRegister_get, METH_O, NULL},
	 { "RegProgressParam_code_set", _wrap_RegProgressParam_code_set, METH_VARARGS, NULL},
	 { "RegProgressParam_code_get", _wrap_RegProgressParam_code_get, METH_O, NULL},
	 { "new_RegProgressParam", _wrap_new_RegProgressParam, METH_NOARGS, NULL},
	 { "delete_RegProgressParam", _wrap_delete_RegProgressParam, METH_O, NULL},
	 { "RegProgressParam_swigregister", RegProgressParam_swigregister, METH_O, NULL},
	 { "RegProgressParam_swiginit", RegProgressParam_swiginit, METH_VARARGS, NULL},
	 { "OnIpChangeProgressParam_op_set", _wrap_OnIpChangeProgressParam_op_set, METH_VARARGS, NULL},
	 { "OnIpChangeProgressParam_op_get", _wrap_OnIpChangeProgressParam_op_get, METH_O, NULL},
	 { "OnIpChangeProgressParam_status_set", _wrap_OnIpChangeProgressParam_status_set, METH_VARARGS, NULL},
	 { "OnIpChangeProgressParam_status_get", _wrap_OnIpChangeProgressParam_status_get, METH_O, NULL},
	 { "OnIpChangeProgressParam_transportId_set", _wrap_OnIpChangeProgressParam_transportId_set, METH_VARARGS, NULL},
	 { "OnIpChangeProgressParam_transportId_get", _wrap_OnIpChangeProgressParam_transportId_get, METH_O, NULL},
	 { "OnIpChangeProgressParam_accId_set", _wrap_OnIpChangeProgressParam_accId_set, METH_VARARGS, NULL},
	 { "OnIpChangeProgressParam_accId_get", _wrap_OnIpChangeProgressParam_accId_get, METH_O, NULL},
	 { "OnIpChangeProgressParam_callId_set", _wrap_OnIpChangeProgressParam_callId_set, METH_VARARGS, NULL},
	 { "OnIpChangeProgressParam_callId_get", _wrap_OnIpChangeProgressParam_callId_get, METH_O, NULL},
	 { "OnIpChangeProgressParam_regInfo_set", _wrap_OnIpChangeProgressParam_regInfo_set, METH_VARARGS, NULL},
	 { "OnIpChangeProgressParam_regInfo_get", _wrap_OnIpChangeProgressParam_regInfo_get, METH_O, NULL},
	 { "new_OnIpChangeProgressParam", _wrap_new_OnIpChangeProgressParam, METH_NOARGS, NULL},
	 { "delete_OnIpChangeProgressParam", _wrap_delete_OnIpChangeProgressParam, METH_O, NULL},
	 { "OnIpChangeProgressParam_swigregister", OnIpChangeProgressParam_swigregister, METH_O, NULL},
	 { "OnIpChangeProgressParam_swiginit", OnIpChangeProgressParam_swiginit, METH_VARARGS, NULL},
	 { "OnMediaEventParam_ev_set", _wrap_OnMediaEventParam_ev_set, METH_VARARGS, NULL},
	 { "OnMediaEventParam_ev_get", _wrap_OnMediaEventParam_ev_get, METH_O, NULL},
	 { "new_OnMediaEventParam", _wrap_new_OnMediaEventParam, METH_NOARGS, NULL},
	 { "delete_OnMediaEventParam", _wrap_delete_OnMediaEventParam, METH_O, NULL},
	 { "OnMediaEventParam_swigregister", OnMediaEventParam_swigregister, METH_O, NULL},
	 { "OnMediaEventParam_swiginit", OnMediaEventParam_swiginit, METH_VARARGS, NULL},
	 { "DigestChallenge_realm_set", _wrap_DigestChallenge_realm_set, METH_VARARGS, NULL},
	 { "DigestChallenge_realm_get", _wrap_DigestChallenge_realm_get, METH_O, NULL},
	 { "DigestChallenge_otherParam_set", _wrap_DigestChallenge_otherParam_set, METH_VARARGS, NULL},
	 { "DigestChallenge_otherParam_get", _wrap_DigestChallenge_otherParam_get, METH_O, NULL},
	 { "DigestChallenge_domain_set", _wrap_DigestChallenge_domain_set, METH_VARARGS, NULL},
	 { "DigestChallenge_domain_get", _wrap_DigestChallenge_domain_get, METH_O, NULL},
	 { "DigestChallenge_nonce_set", _wrap_DigestChallenge_nonce_set, METH_VARARGS, NULL},
	 { "DigestChallenge_nonce_get", _wrap_DigestChallenge_nonce_get, METH_O, NULL},
	 { "DigestChallenge_opaque_set", _wrap_DigestChallenge_opaque_set, METH_VARARGS, NULL},
	 { "DigestChallenge_opaque_get", _wrap_DigestChallenge_opaque_get, METH_O, NULL},
	 { "DigestChallenge_stale_set", _wrap_DigestChallenge_stale_set, METH_VARARGS, NULL},
	 { "DigestChallenge_stale_get", _wrap_DigestChallenge_stale_get, METH_O, NULL},
	 { "DigestChallenge_algorithm_set", _wrap_DigestChallenge_algorithm_set, METH_VARARGS, NULL},
	 { "DigestChallenge_algorithm_get", _wrap_DigestChallenge_algorithm_get, METH_O, NULL},
	 { "DigestChallenge_qop_set", _wrap_DigestChallenge_qop_set, METH_VARARGS, NULL},
	 { "DigestChallenge_qop_get", _wrap_DigestChallenge_qop_get, METH_O, NULL},
	 { "new_DigestChallenge", _wrap_new_DigestChallenge, METH_NOARGS, NULL},
	 { "delete_DigestChallenge", _wrap_delete_DigestChallenge, METH_O, NULL},
	 { "DigestChallenge_swigregister", DigestChallenge_swigregister, METH_O, NULL},
	 { "DigestChallenge_swiginit", DigestChallenge_swiginit, METH_VARARGS, NULL},
	 { "DigestCredential_realm_set", _wrap_DigestCredential_realm_set, METH_VARARGS, NULL},
	 { "DigestCredential_realm_get", _wrap_DigestCredential_realm_get, METH_O, NULL},
	 { "DigestCredential_otherParam_set", _wrap_DigestCredential_otherParam_set, METH_VARARGS, NULL},
	 { "DigestCredential_otherParam_get", _wrap_DigestCredential_otherParam_get, METH_O, NULL},
	 { "DigestCredential_username_set", _wrap_DigestCredential_username_set, METH_VARARGS, NULL},
	 { "DigestCredential_username_get", _wrap_DigestCredential_username_get, METH_O, NULL},
	 { "DigestCredential_nonce_set", _wrap_DigestCredential_nonce_set, METH_VARARGS, NULL},
	 { "DigestCredential_nonce_get", _wrap_DigestCredential_nonce_get, METH_O, NULL},
	 { "DigestCredential_uri_set", _wrap_DigestCredential_uri_set, METH_VARARGS, NULL},
	 { "DigestCredential_uri_get", _wrap_DigestCredential_uri_get, METH_O, NULL},
	 { "DigestCredential_response_set", _wrap_DigestCredential_response_set, METH_VARARGS, NULL},
	 { "DigestCredential_response_get", _wrap_DigestCredential_response_get, METH_O, NULL},
	 { "DigestCredential_algorithm_set", _wrap_DigestCredential_algorithm_set, METH_VARARGS, NULL},
	 { "DigestCredential_algorithm_get", _wrap_DigestCredential_algorithm_get, METH_O, NULL},
	 { "DigestCredential_cnonce_set", _wrap_DigestCredential_cnonce_set, METH_VARARGS, NULL},
	 { "DigestCredential_cnonce_get", _wrap_DigestCredential_cnonce_get, METH_O, NULL},
	 { "DigestCredential_opaque_set", _wrap_DigestCredential_opaque_set, METH_VARARGS, NULL},
	 { "DigestCredential_opaque_get", _wrap_DigestCredential_opaque_get, METH_O, NULL},
	 { "DigestCredential_qop_set", _wrap_DigestCredential_qop_set, METH_VARARGS, NULL},
	 { "DigestCredential_qop_get", _wrap_DigestCredential_qop_get, METH_O, NULL},
	 { "DigestCredential_nc_set", _wrap_DigestCredential_nc_set, METH_VARARGS, NULL},
	 { "DigestCredential_nc_get", _wrap_DigestCredential_nc_get, METH_O, NULL},
	 { "new_DigestCredential", _wrap_new_DigestCredential, METH_NOARGS, NULL},
	 { "delete_DigestCredential", _wrap_delete_DigestCredential, METH_O, NULL},
	 { "DigestCredential_swigregister", DigestCredential_swigregister, METH_O, NULL},
	 { "DigestCredential_swiginit", DigestCredential_swiginit, METH_VARARGS, NULL},
	 { "OnCredAuthParam_digestChallenge_set", _wrap_OnCredAuthParam_digestChallenge_set, METH_VARARGS, NULL},
	 { "OnCredAuthParam_digestChallenge_get", _wrap_OnCredAuthParam_digestChallenge_get, METH_O, NULL},
	 { "OnCredAuthParam_credentialInfo_set", _wrap_OnCredAuthParam_credentialInfo_set, METH_VARARGS, NULL},
	 { "OnCredAuthParam_credentialInfo_get", _wrap_OnCredAuthParam_credentialInfo_get, METH_O, NULL},
	 { "OnCredAuthParam_method_set", _wrap_OnCredAuthParam_method_set, METH_VARARGS, NULL},
	 { "OnCredAuthParam_method_get", _wrap_OnCredAuthParam_method_get, METH_O, NULL},
	 { "OnCredAuthParam_digestCredential_set", _wrap_OnCredAuthParam_digestCredential_set, METH_VARARGS, NULL},
	 { "OnCredAuthParam_digestCredential_get", _wrap_OnCredAuthParam_digestCredential_get, METH_O, NULL},
	 { "new_OnCredAuthParam", _wrap_new_OnCredAuthParam, METH_NOARGS, NULL},
	 { "delete_OnCredAuthParam", _wrap_delete_OnCredAuthParam, METH_O, NULL},
	 { "OnCredAuthParam_swigregister", OnCredAuthParam_swigregister, METH_O, NULL},
	 { "OnCredAuthParam_swiginit", OnCredAuthParam_swiginit, METH_VARARGS, NULL},
	 { "UaConfig_maxCalls_set", _wrap_UaConfig_maxCalls_set, METH_VARARGS, NULL},
	 { "UaConfig_maxCalls_get", _wrap_UaConfig_maxCalls_get, METH_O, NULL},
	 { "UaConfig_threadCnt_set", _wrap_UaConfig_threadCnt_set, METH_VARARGS, NULL},
	 { "UaConfig_threadCnt_get", _wrap_UaConfig_threadCnt_get, METH_O, NULL},
	 { "UaConfig_mainThreadOnly_set", _wrap_UaConfig_mainThreadOnly_set, METH_VARARGS, NULL},
	 { "UaConfig_mainThreadOnly_get", _wrap_UaConfig_mainThreadOnly_get, METH_O, NULL},
	 { "UaConfig_nameserver_set", _wrap_UaConfig_nameserver_set, METH_VARARGS, NULL},
	 { "UaConfig_nameserver_get", _wrap_UaConfig_nameserver_get, METH_O, NULL},
	 { "UaConfig_outboundProxies_set", _wrap_UaConfig_outboundProxies_set, METH_VARARGS, NULL},
	 { "UaConfig_outboundProxies_get", _wrap_UaConfig_outboundProxies_get, METH_O, NULL},
	 { "UaConfig_userAgent_set", _wrap_UaConfig_userAgent_set, METH_VARARGS, NULL},
	 { "UaConfig_userAgent_get", _wrap_UaConfig_userAgent_get, METH_O, NULL},
	 { "UaConfig_stunServer_set", _wrap_UaConfig_stunServer_set, METH_VARARGS, NULL},
	 { "UaConfig_stunServer_get", _wrap_UaConfig_stunServer_get, METH_O, NULL},
	 { "UaConfig_stunTryIpv6_set", _wrap_UaConfig_stunTryIpv6_set, METH_VARARGS, NULL},
	 { "UaConfig_stunTryIpv6_get", _wrap_UaConfig_stunTryIpv6_get, METH_O, NULL},
	 { "UaConfig_stunIgnoreFailure_set", _wrap_UaConfig_stunIgnoreFailure_set, METH_VARARGS, NULL},
	 { "UaConfig_stunIgnoreFailure_get", _wrap_UaConfig_stunIgnoreFailure_get, METH_O, NULL},
	 { "UaConfig_natTypeInSdp_set", _wrap_UaConfig_natTypeInSdp_set, METH_VARARGS, NULL},
	 { "UaConfig_natTypeInSdp_get", _wrap_UaConfig_natTypeInSdp_get, METH_O, NULL},
	 { "UaConfig_mwiUnsolicitedEnabled_set", _wrap_UaConfig_mwiUnsolicitedEnabled_set, METH_VARARGS, NULL},
	 { "UaConfig_mwiUnsolicitedEnabled_get", _wrap_UaConfig_mwiUnsolicitedEnabled_get, METH_O, NULL},
	 { "new_UaConfig", _wrap_new_UaConfig, METH_NOARGS, NULL},
	 { "UaConfig_readObject", _wrap_UaConfig_readObject, METH_VARARGS, NULL},
	 { "UaConfig_writeObject", _wrap_UaConfig_writeObject, METH_VARARGS, NULL},
	 { "delete_UaConfig", _wrap_delete_UaConfig, METH_O, NULL},
	 { "UaConfig_swigregister", UaConfig_swigregister, METH_O, NULL},
	 { "UaConfig_swiginit", UaConfig_swiginit, METH_VARARGS, NULL},
	 { "LogEntry_level_set", _wrap_LogEntry_level_set, METH_VARARGS, NULL},
	 { "LogEntry_level_get", _wrap_LogEntry_level_get, METH_O, NULL},
	 { "LogEntry_msg_set", _wrap_LogEntry_msg_set, METH_VARARGS, NULL},
	 { "LogEntry_msg_get", _wrap_LogEntry_msg_get, METH_O, NULL},
	 { "LogEntry_threadId_set", _wrap_LogEntry_threadId_set, METH_VARARGS, NULL},
	 { "LogEntry_threadId_get", _wrap_LogEntry_threadId_get, METH_O, NULL},
	 { "LogEntry_threadName_set", _wrap_LogEntry_threadName_set, METH_VARARGS, NULL},
	 { "LogEntry_threadName_get", _wrap_LogEntry_threadName_get, METH_O, NULL},
	 { "new_LogEntry", _wrap_new_LogEntry, METH_NOARGS, NULL},
	 { "delete_LogEntry", _wrap_delete_LogEntry, METH_O, NULL},
	 { "LogEntry_swigregister", LogEntry_swigregister, METH_O, NULL},
	 { "LogEntry_swiginit", LogEntry_swiginit, METH_VARARGS, NULL},
	 { "delete_LogWriter", _wrap_delete_LogWriter, METH_O, NULL},
	 { "LogWriter_write", _wrap_LogWriter_write, METH_VARARGS, NULL},
	 { "new_LogWriter", _wrap_new_LogWriter, METH_O, NULL},
	 { "disown_LogWriter", _wrap_disown_LogWriter, METH_O, NULL},
	 { "LogWriter_swigregister", LogWriter_swigregister, METH_O, NULL},
	 { "LogWriter_swiginit", LogWriter_swiginit, METH_VARARGS, NULL},
	 { "LogConfig_msgLogging_set", _wrap_LogConfig_msgLogging_set, METH_VARARGS, NULL},
	 { "LogConfig_msgLogging_get", _wrap_LogConfig_msgLogging_get, METH_O, NULL},
	 { "LogConfig_level_set", _wrap_LogConfig_level_set, METH_VARARGS, NULL},
	 { "LogConfig_level_get", _wrap_LogConfig_level_get, METH_O, NULL},
	 { "LogConfig_consoleLevel_set", _wrap_LogConfig_consoleLevel_set, METH_VARARGS, NULL},
	 { "LogConfig_consoleLevel_get", _wrap_LogConfig_consoleLevel_get, METH_O, NULL},
	 { "LogConfig_decor_set", _wrap_LogConfig_decor_set, METH_VARARGS, NULL},
	 { "LogConfig_decor_get", _wrap_LogConfig_decor_get, METH_O, NULL},
	 { "LogConfig_filename_set", _wrap_LogConfig_filename_set, METH_VARARGS, NULL},
	 { "LogConfig_filename_get", _wrap_LogConfig_filename_get, METH_O, NULL},
	 { "LogConfig_fileFlags_set", _wrap_LogConfig_fileFlags_set, METH_VARARGS, NULL},
	 { "LogConfig_fileFlags_get", _wrap_LogConfig_fileFlags_get, METH_O, NULL},
	 { "LogConfig_writer_set", _wrap_LogConfig_writer_set, METH_VARARGS, NULL},
	 { "LogConfig_writer_get", _wrap_LogConfig_writer_get, METH_O, NULL},
	 { "new_LogConfig", _wrap_new_LogConfig, METH_NOARGS, NULL},
	 { "LogConfig_readObject", _wrap_LogConfig_readObject, METH_VARARGS, NULL},
	 { "LogConfig_writeObject", _wrap_LogConfig_writeObject, METH_VARARGS, NULL},
	 { "delete_LogConfig", _wrap_delete_LogConfig, METH_O, NULL},
	 { "LogConfig_swigregister", LogConfig_swigregister, METH_O, NULL},
	 { "LogConfig_swiginit", LogConfig_swiginit, METH_VARARGS, NULL},
	 { "MediaConfig_clockRate_set", _wrap_MediaConfig_clockRate_set, METH_VARARGS, NULL},
	 { "MediaConfig_clockRate_get", _wrap_MediaConfig_clockRate_get, METH_O, NULL},
	 { "MediaConfig_sndClockRate_set", _wrap_MediaConfig_sndClockRate_set, METH_VARARGS, NULL},
	 { "MediaConfig_sndClockRate_get", _wrap_MediaConfig_sndClockRate_get, METH_O, NULL},
	 { "MediaConfig_channelCount_set", _wrap_MediaConfig_channelCount_set, METH_VARARGS, NULL},
	 { "MediaConfig_channelCount_get", _wrap_MediaConfig_channelCount_get, METH_O, NULL},
	 { "MediaConfig_audioFramePtime_set", _wrap_MediaConfig_audioFramePtime_set, METH_VARARGS, NULL},
	 { "MediaConfig_audioFramePtime_get", _wrap_MediaConfig_audioFramePtime_get, METH_O, NULL},
	 { "MediaConfig_maxMediaPorts_set", _wrap_MediaConfig_maxMediaPorts_set, METH_VARARGS, NULL},
	 { "MediaConfig_maxMediaPorts_get", _wrap_MediaConfig_maxMediaPorts_get, METH_O, NULL},
	 { "MediaConfig_hasIoqueue_set", _wrap_MediaConfig_hasIoqueue_set, METH_VARARGS, NULL},
	 { "MediaConfig_hasIoqueue_get", _wrap_MediaConfig_hasIoqueue_get, METH_O, NULL},
	 { "MediaConfig_threadCnt_set", _wrap_MediaConfig_threadCnt_set, METH_VARARGS, NULL},
	 { "MediaConfig_threadCnt_get", _wrap_MediaConfig_threadCnt_get, METH_O, NULL},
	 { "MediaConfig_quality_set", _wrap_MediaConfig_quality_set, METH_VARARGS, NULL},
	 { "MediaConfig_quality_get", _wrap_MediaConfig_quality_get, METH_O, NULL},
	 { "MediaConfig_ptime_set", _wrap_MediaConfig_ptime_set, METH_VARARGS, NULL},
	 { "MediaConfig_ptime_get", _wrap_MediaConfig_ptime_get, METH_O, NULL},
	 { "MediaConfig_noVad_set", _wrap_MediaConfig_noVad_set, METH_VARARGS, NULL},
	 { "MediaConfig_noVad_get", _wrap_MediaConfig_noVad_get, METH_O, NULL},
	 { "MediaConfig_ilbcMode_set", _wrap_MediaConfig_ilbcMode_set, METH_VARARGS, NULL},
	 { "MediaConfig_ilbcMode_get", _wrap_MediaConfig_ilbcMode_get, METH_O, NULL},
	 { "MediaConfig_txDropPct_set", _wrap_MediaConfig_txDropPct_set, METH_VARARGS, NULL},
	 { "MediaConfig_txDropPct_get", _wrap_MediaConfig_txDropPct_get, METH_O, NULL},
	 { "MediaConfig_rxDropPct_set", _wrap_MediaConfig_rxDropPct_set, METH_VARARGS, NULL},
	 { "MediaConfig_rxDropPct_get", _wrap_MediaConfig_rxDropPct_get, METH_O, NULL},
	 { "MediaConfig_ecOptions_set", _wrap_MediaConfig_ecOptions_set, METH_VARARGS, NULL},
	 { "MediaConfig_ecOptions_get", _wrap_MediaConfig_ecOptions_get, METH_O, NULL},
	 { "MediaConfig_ecTailLen_set", _wrap_MediaConfig_ecTailLen_set, METH_VARARGS, NULL},
	 { "MediaConfig_ecTailLen_get", _wrap_MediaConfig_ecTailLen_get, METH_O, NULL},
	 { "MediaConfig_sndRecLatency_set", _wrap_MediaConfig_sndRecLatency_set, METH_VARARGS, NULL},
	 { "MediaConfig_sndRecLatency_get", _wrap_MediaConfig_sndRecLatency_get, METH_O, NULL},
	 { "MediaConfig_sndPlayLatency_set", _wrap_MediaConfig_sndPlayLatency_set, METH_VARARGS, NULL},
	 { "MediaConfig_sndPlayLatency_get", _wrap_MediaConfig_sndPlayLatency_get, METH_O, NULL},
	 { "MediaConfig_jbInit_set", _wrap_MediaConfig_jbInit_set, METH_VARARGS, NULL},
	 { "MediaConfig_jbInit_get", _wrap_MediaConfig_jbInit_get, METH_O, NULL},
	 { "MediaConfig_jbMinPre_set", _wrap_MediaConfig_jbMinPre_set, METH_VARARGS, NULL},
	 { "MediaConfig_jbMinPre_get", _wrap_MediaConfig_jbMinPre_get, METH_O, NULL},
	 { "MediaConfig_jbMaxPre_set", _wrap_MediaConfig_jbMaxPre_set, METH_VARARGS, NULL},
	 { "MediaConfig_jbMaxPre_get", _wrap_MediaConfig_jbMaxPre_get, METH_O, NULL},
	 { "MediaConfig_jbMax_set", _wrap_MediaConfig_jbMax_set, METH_VARARGS, NULL},
	 { "MediaConfig_jbMax_get", _wrap_MediaConfig_jbMax_get, METH_O, NULL},
	 { "MediaConfig_jbDiscardAlgo_set", _wrap_MediaConfig_jbDiscardAlgo_set, METH_VARARGS, NULL},
	 { "MediaConfig_jbDiscardAlgo_get", _wrap_MediaConfig_jbDiscardAlgo_get, METH_O, NULL},
	 { "MediaConfig_sndAutoCloseTime_set", _wrap_MediaConfig_sndAutoCloseTime_set, METH_VARARGS, NULL},
	 { "MediaConfig_sndAutoCloseTime_get", _wrap_MediaConfig_sndAutoCloseTime_get, METH_O, NULL},
	 { "MediaConfig_vidPreviewEnableNative_set", _wrap_MediaConfig_vidPreviewEnableNative_set, METH_VARARGS, NULL},
	 { "MediaConfig_vidPreviewEnableNative_get", _wrap_MediaConfig_vidPreviewEnableNative_get, METH_O, NULL},
	 { "new_MediaConfig", _wrap_new_MediaConfig, METH_NOARGS, NULL},
	 { "MediaConfig_readObject", _wrap_MediaConfig_readObject, METH_VARARGS, NULL},
	 { "MediaConfig_writeObject", _wrap_MediaConfig_writeObject, METH_VARARGS, NULL},
	 { "delete_MediaConfig", _wrap_delete_MediaConfig, METH_O, NULL},
	 { "MediaConfig_swigregister", MediaConfig_swigregister, METH_O, NULL},
	 { "MediaConfig_swiginit", MediaConfig_swiginit, METH_VARARGS, NULL},
	 { "EpConfig_uaConfig_set", _wrap_EpConfig_uaConfig_set, METH_VARARGS, NULL},
	 { "EpConfig_uaConfig_get", _wrap_EpConfig_uaConfig_get, METH_O, NULL},
	 { "EpConfig_logConfig_set", _wrap_EpConfig_logConfig_set, METH_VARARGS, NULL},
	 { "EpConfig_logConfig_get", _wrap_EpConfig_logConfig_get, METH_O, NULL},
	 { "EpConfig_medConfig_set", _wrap_EpConfig_medConfig_set, METH_VARARGS, NULL},
	 { "EpConfig_medConfig_get", _wrap_EpConfig_medConfig_get, METH_O, NULL},
	 { "EpConfig_readObject", _wrap_EpConfig_readObject, METH_VARARGS, NULL},
	 { "EpConfig_writeObject", _wrap_EpConfig_writeObject, METH_VARARGS, NULL},
	 { "new_EpConfig", _wrap_new_EpConfig, METH_NOARGS, NULL},
	 { "delete_EpConfig", _wrap_delete_EpConfig, METH_O, NULL},
	 { "EpConfig_swigregister", EpConfig_swigregister, METH_O, NULL},
	 { "EpConfig_swiginit", EpConfig_swiginit, METH_VARARGS, NULL},
	 { "PendingJob_execute", _wrap_PendingJob_execute, METH_VARARGS, NULL},
	 { "delete_PendingJob", _wrap_delete_PendingJob, METH_O, NULL},
	 { "PendingJob_swigregister", PendingJob_swigregister, METH_O, NULL},
	 { "Endpoint_instance", _wrap_Endpoint_instance, METH_NOARGS, NULL},
	 { "new_Endpoint", _wrap_new_Endpoint, METH_O, NULL},
	 { "delete_Endpoint", _wrap_delete_Endpoint, METH_O, NULL},
	 { "Endpoint_libVersion", _wrap_Endpoint_libVersion, METH_O, NULL},
	 { "Endpoint_libCreate", _wrap_Endpoint_libCreate, METH_O, NULL},
	 { "Endpoint_libGetState", _wrap_Endpoint_libGetState, METH_O, NULL},
	 { "Endpoint_libInit", _wrap_Endpoint_libInit, METH_VARARGS, NULL},
	 { "Endpoint_libStart", _wrap_Endpoint_libStart, METH_O, NULL},
	 { "Endpoint_libRegisterThread", _wrap_Endpoint_libRegisterThread, METH_VARARGS, NULL},
	 { "Endpoint_libIsThreadRegistered", _wrap_Endpoint_libIsThreadRegistered, METH_O, NULL},
	 { "Endpoint_libStopWorkerThreads", _wrap_Endpoint_libStopWorkerThreads, METH_O, NULL},
	 { "Endpoint_libHandleEvents", _wrap_Endpoint_libHandleEvents, METH_VARARGS, NULL},
	 { "Endpoint_libDestroy", _wrap_Endpoint_libDestroy, METH_VARARGS, NULL},
	 { "Endpoint_utilStrError", _wrap_Endpoint_utilStrError, METH_VARARGS, NULL},
	 { "Endpoint_utilLogWrite", _wrap_Endpoint_utilLogWrite, METH_VARARGS, NULL},
	 { "Endpoint_utilVerifySipUri", _wrap_Endpoint_utilVerifySipUri, METH_VARARGS, NULL},
	 { "Endpoint_utilVerifyUri", _wrap_Endpoint_utilVerifyUri, METH_VARARGS, NULL},
	 { "Endpoint_utilTimerSchedule", _wrap_Endpoint_utilTimerSchedule, METH_VARARGS, NULL},
	 { "Endpoint_utilTimerCancel", _wrap_Endpoint_utilTimerCancel, METH_VARARGS, NULL},
	 { "Endpoint_utilAddPendingJob", _wrap_Endpoint_utilAddPendingJob, METH_VARARGS, NULL},
	 { "Endpoint_utilSslGetAvailableCiphers", _wrap_Endpoint_utilSslGetAvailableCiphers, METH_O, NULL},
	 { "Endpoint_natDetectType", _wrap_Endpoint_natDetectType, METH_O, NULL},
	 { "Endpoint_natGetType", _wrap_Endpoint_natGetType, METH_O, NULL},
	 { "Endpoint_natUpdateStunServers", _wrap_Endpoint_natUpdateStunServers, METH_VARARGS, NULL},
	 { "Endpoint_natCheckStunServers", _wrap_Endpoint_natCheckStunServers, METH_VARARGS, NULL},
	 { "Endpoint_natCancelCheckStunServers", _wrap_Endpoint_natCancelCheckStunServers, METH_VARARGS, NULL},
	 { "Endpoint_transportCreate", _wrap_Endpoint_transportCreate, METH_VARARGS, NULL},
	 { "Endpoint_transportEnum", _wrap_Endpoint_transportEnum, METH_O, NULL},
	 { "Endpoint_transportGetInfo", _wrap_Endpoint_transportGetInfo, METH_VARARGS, NULL},
	 { "Endpoint_transportSetEnable", _wrap_Endpoint_transportSetEnable, METH_VARARGS, NULL},
	 { "Endpoint_transportClose", _wrap_Endpoint_transportClose, METH_VARARGS, NULL},
	 { "Endpoint_transportShutdown", _wrap_Endpoint_transportShutdown, METH_VARARGS, NULL},
	 { "Endpoint_hangupAllCalls", _wrap_Endpoint_hangupAllCalls, METH_O, NULL},
	 { "Endpoint_mediaAdd", _wrap_Endpoint_mediaAdd, METH_VARARGS, NULL},
	 { "Endpoint_mediaRemove", _wrap_Endpoint_mediaRemove, METH_VARARGS, NULL},
	 { "Endpoint_mediaExists", _wrap_Endpoint_mediaExists, METH_VARARGS, NULL},
	 { "Endpoint_mediaMaxPorts", _wrap_Endpoint_mediaMaxPorts, METH_O, NULL},
	 { "Endpoint_mediaActivePorts", _wrap_Endpoint_mediaActivePorts, METH_O, NULL},
	 { "Endpoint_mediaEnumPorts2", _wrap_Endpoint_mediaEnumPorts2, METH_O, NULL},
	 { "Endpoint_mediaEnumVidPorts", _wrap_Endpoint_mediaEnumVidPorts, METH_O, NULL},
	 { "Endpoint_audDevManager", _wrap_Endpoint_audDevManager, METH_O, NULL},
	 { "Endpoint_vidDevManager", _wrap_Endpoint_vidDevManager, METH_O, NULL},
	 { "Endpoint_codecEnum2", _wrap_Endpoint_codecEnum2, METH_O, NULL},
	 { "Endpoint_codecSetPriority", _wrap_Endpoint_codecSetPriority, METH_VARARGS, NULL},
	 { "Endpoint_codecGetParam", _wrap_Endpoint_codecGetParam, METH_VARARGS, NULL},
	 { "Endpoint_codecSetParam", _wrap_Endpoint_codecSetParam, METH_VARARGS, NULL},
	 { "Endpoint_videoCodecEnum2", _wrap_Endpoint_videoCodecEnum2, METH_O, NULL},
	 { "Endpoint_videoCodecSetPriority", _wrap_Endpoint_videoCodecSetPriority, METH_VARARGS, NULL},
	 { "Endpoint_getVideoCodecParam", _wrap_Endpoint_getVideoCodecParam, METH_VARARGS, NULL},
	 { "Endpoint_setVideoCodecParam", _wrap_Endpoint_setVideoCodecParam, METH_VARARGS, NULL},
	 { "Endpoint_resetVideoCodecParam", _wrap_Endpoint_resetVideoCodecParam, METH_VARARGS, NULL},
	 { "Endpoint_srtpCryptoEnum", _wrap_Endpoint_srtpCryptoEnum, METH_O, NULL},
	 { "Endpoint_handleIpChange", _wrap_Endpoint_handleIpChange, METH_VARARGS, NULL},
	 { "Endpoint_onNatDetectionComplete", _wrap_Endpoint_onNatDetectionComplete, METH_VARARGS, NULL},
	 { "Endpoint_onNatCheckStunServersComplete", _wrap_Endpoint_onNatCheckStunServersComplete, METH_VARARGS, NULL},
	 { "Endpoint_onTransportState", _wrap_Endpoint_onTransportState, METH_VARARGS, NULL},
	 { "Endpoint_onTimer", _wrap_Endpoint_onTimer, METH_VARARGS, NULL},
	 { "Endpoint_onSelectAccount", _wrap_Endpoint_onSelectAccount, METH_VARARGS, NULL},
	 { "Endpoint_onIpChangeProgress", _wrap_Endpoint_onIpChangeProgress, METH_VARARGS, NULL},
	 { "Endpoint_onMediaEvent", _wrap_Endpoint_onMediaEvent, METH_VARARGS, NULL},
	 { "Endpoint_onCredAuth", _wrap_Endpoint_onCredAuth, METH_VARARGS, NULL},
	 { "disown_Endpoint", _wrap_disown_Endpoint, METH_O, NULL},
	 { "Endpoint_swigregister", Endpoint_swigregister, METH_O, NULL},
	 { "Endpoint_swiginit", Endpoint_swiginit, METH_VARARGS, NULL},
	 { NULL, NULL, 0, NULL }
};

static PyMethodDef SwigMethods_proxydocs[] = {
	 { NULL, NULL, 0, NULL }
};


/* -------- TYPE CONVERSION AND EQUIVALENCE RULES (BEGIN) -------- */

static void *_p_pj__AuthCredInfoTo_p_pj__PersistentObject(void *x, int *SWIGUNUSEDPARM(newmemory)) {
    return (void *)((pj::PersistentObject *)  ((pj::AuthCredInfo *) x));
}
static void *_p_pj__AccountVideoConfigTo_p_pj__PersistentObject(void *x, int *SWIGUNUSEDPARM(newmemory)) {
    return (void *)((pj::PersistentObject *)  ((pj::AccountVideoConfig *) x));
}
static void *_p_pj__AccountMediaConfigTo_p_pj__PersistentObject(void *x, int *SWIGUNUSEDPARM(newmemory)) {
    return (void *)((pj::PersistentObject *)  ((pj::AccountMediaConfig *) x));
}
static void *_p_pj__AccountMwiConfigTo_p_pj__PersistentObject(void *x, int *SWIGUNUSEDPARM(newmemory)) {
    return (void *)((pj::PersistentObject *)  ((pj::AccountMwiConfig *) x));
}
static void *_p_pj__AccountPresConfigTo_p_pj__PersistentObject(void *x, int *SWIGUNUSEDPARM(newmemory)) {
    return (void *)((pj::PersistentObject *)  ((pj::AccountPresConfig *) x));
}
static void *_p_pj__AccountRegConfigTo_p_pj__PersistentObject(void *x, int *SWIGUNUSEDPARM(newmemory)) {
    return (void *)((pj::PersistentObject *)  ((pj::AccountRegConfig *) x));
}
static void *_p_pj__BuddyConfigTo_p_pj__PersistentObject(void *x, int *SWIGUNUSEDPARM(newmemory)) {
    return (void *)((pj::PersistentObject *)  ((pj::BuddyConfig *) x));
}
static void *_p_pj__TlsConfigTo_p_pj__PersistentObject(void *x, int *SWIGUNUSEDPARM(newmemory)) {
    return (void *)((pj::PersistentObject *)  ((pj::TlsConfig *) x));
}
static void *_p_pj__UaConfigTo_p_pj__PersistentObject(void *x, int *SWIGUNUSEDPARM(newmemory)) {
    return (void *)((pj::PersistentObject *)  ((pj::UaConfig *) x));
}
static void *_p_pj__LogConfigTo_p_pj__PersistentObject(void *x, int *SWIGUNUSEDPARM(newmemory)) {
    return (void *)((pj::PersistentObject *)  ((pj::LogConfig *) x));
}
static void *_p_pj__MediaConfigTo_p_pj__PersistentObject(void *x, int *SWIGUNUSEDPARM(newmemory)) {
    return (void *)((pj::PersistentObject *)  ((pj::MediaConfig *) x));
}
static void *_p_pj__RtcpFbConfigTo_p_pj__PersistentObject(void *x, int *SWIGUNUSEDPARM(newmemory)) {
    return (void *)((pj::PersistentObject *)  ((pj::RtcpFbConfig *) x));
}
static void *_p_pj__AccountNatConfigTo_p_pj__PersistentObject(void *x, int *SWIGUNUSEDPARM(newmemory)) {
    return (void *)((pj::PersistentObject *)  ((pj::AccountNatConfig *) x));
}
static void *_p_pj__AccountCallConfigTo_p_pj__PersistentObject(void *x, int *SWIGUNUSEDPARM(newmemory)) {
    return (void *)((pj::PersistentObject *)  ((pj::AccountCallConfig *) x));
}
static void *_p_pj__AccountSipConfigTo_p_pj__PersistentObject(void *x, int *SWIGUNUSEDPARM(newmemory)) {
    return (void *)((pj::PersistentObject *)  ((pj::AccountSipConfig *) x));
}
static void *_p_pj__TransportConfigTo_p_pj__PersistentObject(void *x, int *SWIGUNUSEDPARM(newmemory)) {
    return (void *)((pj::PersistentObject *)  ((pj::TransportConfig *) x));
}
static void *_p_pj__AccountConfigTo_p_pj__PersistentObject(void *x, int *SWIGUNUSEDPARM(newmemory)) {
    return (void *)((pj::PersistentObject *)  ((pj::AccountConfig *) x));
}
static void *_p_pj__EpConfigTo_p_pj__PersistentObject(void *x, int *SWIGUNUSEDPARM(newmemory)) {
    return (void *)((pj::PersistentObject *)  ((pj::EpConfig *) x));
}
static void *_p_pj__SrtpOptTo_p_pj__PersistentObject(void *x, int *SWIGUNUSEDPARM(newmemory)) {
    return (void *)((pj::PersistentObject *)  ((pj::SrtpOpt *) x));
}
static void *_p_pj__ToneDigitTo_p_pjmedia_tone_digit(void *x, int *SWIGUNUSEDPARM(newmemory)) {
    return (void *)((pjmedia_tone_digit *)  ((pj::ToneDigit *) x));
}
static void *_p_pj__MediaFormatAudioTo_p_pj__MediaFormat(void *x, int *SWIGUNUSEDPARM(newmemory)) {
    return (void *)((pj::MediaFormat *)  ((pj::MediaFormatAudio *) x));
}
static void *_p_pj__MediaFormatVideoTo_p_pj__MediaFormat(void *x, int *SWIGUNUSEDPARM(newmemory)) {
    return (void *)((pj::MediaFormat *)  ((pj::MediaFormatVideo *) x));
}
static void *_p_pj__JsonDocumentTo_p_pj__PersistentDocument(void *x, int *SWIGUNUSEDPARM(newmemory)) {
    return (void *)((pj::PersistentDocument *)  ((pj::JsonDocument *) x));
}
static void *_p_pj__AudioMediaTo_p_pj__Media(void *x, int *SWIGUNUSEDPARM(newmemory)) {
    return (void *)((pj::Media *)  ((pj::AudioMedia *) x));
}
static void *_p_pj__AudioMediaRecorderTo_p_pj__Media(void *x, int *SWIGUNUSEDPARM(newmemory)) {
    return (void *)((pj::Media *) (pj::AudioMedia *) ((pj::AudioMediaRecorder *) x));
}
static void *_p_pj__VideoMediaTo_p_pj__Media(void *x, int *SWIGUNUSEDPARM(newmemory)) {
    return (void *)((pj::Media *)  ((pj::VideoMedia *) x));
}
static void *_p_pj__ToneGeneratorTo_p_pj__Media(void *x, int *SWIGUNUSEDPARM(newmemory)) {
    return (void *)((pj::Media *) (pj::AudioMedia *) ((pj::ToneGenerator *) x));
}
static void *_p_pj__AudioMediaPlayerTo_p_pj__Media(void *x, int *SWIGUNUSEDPARM(newmemory)) {
    return (void *)((pj::Media *) (pj::AudioMedia *) ((pj::AudioMediaPlayer *) x));
}
static void *_p_pj__ExtraAudioDeviceTo_p_pj__Media(void *x, int *SWIGUNUSEDPARM(newmemory)) {
    return (void *)((pj::Media *) (pj::AudioMedia *) ((pj::ExtraAudioDevice *) x));
}
static void *_p_pj__AudioMediaRecorderTo_p_pj__AudioMedia(void *x, int *SWIGUNUSEDPARM(newmemory)) {
    return (void *)((pj::AudioMedia *)  ((pj::AudioMediaRecorder *) x));
}
static void *_p_pj__ToneGeneratorTo_p_pj__AudioMedia(void *x, int *SWIGUNUSEDPARM(newmemory)) {
    return (void *)((pj::AudioMedia *)  ((pj::ToneGenerator *) x));
}
static void *_p_pj__AudioMediaPlayerTo_p_pj__AudioMedia(void *x, int *SWIGUNUSEDPARM(newmemory)) {
    return (void *)((pj::AudioMedia *)  ((pj::AudioMediaPlayer *) x));
}
static void *_p_pj__ExtraAudioDeviceTo_p_pj__AudioMedia(void *x, int *SWIGUNUSEDPARM(newmemory)) {
    return (void *)((pj::AudioMedia *)  ((pj::ExtraAudioDevice *) x));
}
static void *_p_pj__ToneDescTo_p_pjmedia_tone_desc(void *x, int *SWIGUNUSEDPARM(newmemory)) {
    return (void *)((pjmedia_tone_desc *)  ((pj::ToneDesc *) x));
}
static swig_type_info _swigt__p_allocator_type = {"_p_allocator_type", "allocator_type *", 0, 0, (void*)0, 0};
static swig_type_info _swigt__p_char = {"_p_char", "char *", 0, 0, (void*)0, 0};
static swig_type_info _swigt__p_difference_type = {"_p_difference_type", "difference_type *", 0, 0, (void*)0, 0};
static swig_type_info _swigt__p_int = {"_p_int", "pjsua_acc_id *|int *|pjmedia_vid_dev_index *|pj_int32_t *|pjsua_vid_win_id *|pj::TransportId *|pjsua_call_id *|pj_status_t *", 0, 0, (void*)0, 0};
static swig_type_info _swigt__p_key_type = {"_p_key_type", "key_type *", 0, 0, (void*)0, 0};
static swig_type_info _swigt__p_mapped_type = {"_p_mapped_type", "mapped_type *", 0, 0, (void*)0, 0};
static swig_type_info _swigt__p_p_PyObject = {"_p_p_PyObject", "PyObject **", 0, 0, (void*)0, 0};
static swig_type_info _swigt__p_p_void = {"_p_p_void", "void **|pj::MediaPort *", 0, 0, (void*)0, 0};
static swig_type_info _swigt__p_pj__Account = {"_p_pj__Account", "pj::Account *", 0, 0, (void*)0, 0};
static swig_type_info _swigt__p_pj__AccountCallConfig = {"_p_pj__AccountCallConfig", "pj::AccountCallConfig *", 0, 0, (void*)0, 0};
static swig_type_info _swigt__p_pj__AccountConfig = {"_p_pj__AccountConfig", "pj::AccountConfig *", 0, 0, (void*)0, 0};
static swig_type_info _swigt__p_pj__AccountInfo = {"_p_pj__AccountInfo", "pj::AccountInfo *", 0, 0, (void*)0, 0};
static swig_type_info _swigt__p_pj__AccountIpChangeConfig = {"_p_pj__AccountIpChangeConfig", "pj::AccountIpChangeConfig *", 0, 0, (void*)0, 0};
static swig_type_info _swigt__p_pj__AccountMediaConfig = {"_p_pj__AccountMediaConfig", "pj::AccountMediaConfig *", 0, 0, (void*)0, 0};
static swig_type_info _swigt__p_pj__AccountMwiConfig = {"_p_pj__AccountMwiConfig", "pj::AccountMwiConfig *", 0, 0, (void*)0, 0};
static swig_type_info _swigt__p_pj__AccountNatConfig = {"_p_pj__AccountNatConfig", "pj::AccountNatConfig *", 0, 0, (void*)0, 0};
static swig_type_info _swigt__p_pj__AccountPresConfig = {"_p_pj__AccountPresConfig", "pj::AccountPresConfig *", 0, 0, (void*)0, 0};
static swig_type_info _swigt__p_pj__AccountRegConfig = {"_p_pj__AccountRegConfig", "pj::AccountRegConfig *", 0, 0, (void*)0, 0};
static swig_type_info _swigt__p_pj__AccountSipConfig = {"_p_pj__AccountSipConfig", "pj::AccountSipConfig *", 0, 0, (void*)0, 0};
static swig_type_info _swigt__p_pj__AccountVideoConfig = {"_p_pj__AccountVideoConfig", "pj::AccountVideoConfig *", 0, 0, (void*)0, 0};
static swig_type_info _swigt__p_pj__AudDevErrorEvent = {"_p_pj__AudDevErrorEvent", "pj::AudDevErrorEvent *", 0, 0, (void*)0, 0};
static swig_type_info _swigt__p_pj__AudDevManager = {"_p_pj__AudDevManager", "pj::AudDevManager *", 0, 0, (void*)0, 0};
static swig_type_info _swigt__p_pj__AudioDevInfo = {"_p_pj__AudioDevInfo", "pj::AudioDevInfo *|std::vector< pj::AudioDevInfo >::value_type *|std::vector< pj::AudioDevInfo * >::value_type", 0, 0, (void*)0, 0};
static swig_type_info _swigt__p_pj__AudioMedia = {"_p_pj__AudioMedia", "std::vector< pj::AudioMedia >::value_type *|std::vector< pj::AudioMedia * >::value_type|pj::AudioMedia *", 0, 0, (void*)0, 0};
static swig_type_info _swigt__p_pj__AudioMediaPlayer = {"_p_pj__AudioMediaPlayer", "pj::AudioMediaPlayer *", 0, 0, (void*)0, 0};
static swig_type_info _swigt__p_pj__AudioMediaPlayerInfo = {"_p_pj__AudioMediaPlayerInfo", "pj::AudioMediaPlayerInfo *", 0, 0, (void*)0, 0};
static swig_type_info _swigt__p_pj__AudioMediaRecorder = {"_p_pj__AudioMediaRecorder", "pj::AudioMediaRecorder *", 0, 0, (void*)0, 0};
static swig_type_info _swigt__p_pj__AudioMediaTransmitParam = {"_p_pj__AudioMediaTransmitParam", "pj::AudioMediaTransmitParam *", 0, 0, (void*)0, 0};
static swig_type_info _swigt__p_pj__AuthCredInfo = {"_p_pj__AuthCredInfo", "pj::AuthCredInfo *|std::vector< pj::AuthCredInfo >::value_type *", 0, 0, (void*)0, 0};
static swig_type_info _swigt__p_pj__Buddy = {"_p_pj__Buddy", "std::vector< pj::Buddy >::value_type *|std::vector< pj::Buddy * >::value_type|pj::Buddy *", 0, 0, (void*)0, 0};
static swig_type_info _swigt__p_pj__BuddyConfig = {"_p_pj__BuddyConfig", "pj::BuddyConfig *", 0, 0, (void*)0, 0};
static swig_type_info _swigt__p_pj__BuddyInfo = {"_p_pj__BuddyInfo", "pj::BuddyInfo *", 0, 0, (void*)0, 0};
static swig_type_info _swigt__p_pj__Call = {"_p_pj__Call", "pj::Call *", 0, 0, (void*)0, 0};
static swig_type_info _swigt__p_pj__CallInfo = {"_p_pj__CallInfo", "pj::CallInfo *", 0, 0, (void*)0, 0};
static swig_type_info _swigt__p_pj__CallMediaInfo = {"_p_pj__CallMediaInfo", "std::vector< pj::CallMediaInfo >::value_type *|pj::CallMediaInfo *", 0, 0, (void*)0, 0};
static swig_type_info _swigt__p_pj__CallOpParam = {"_p_pj__CallOpParam", "pj::CallOpParam *", 0, 0, (void*)0, 0};
static swig_type_info _swigt__p_pj__CallSendDtmfParam = {"_p_pj__CallSendDtmfParam", "pj::CallSendDtmfParam *", 0, 0, (void*)0, 0};
static swig_type_info _swigt__p_pj__CallSendRequestParam = {"_p_pj__CallSendRequestParam", "pj::CallSendRequestParam *", 0, 0, (void*)0, 0};
static swig_type_info _swigt__p_pj__CallSetting = {"_p_pj__CallSetting", "pj::CallSetting *", 0, 0, (void*)0, 0};
static swig_type_info _swigt__p_pj__CallVidSetStreamParam = {"_p_pj__CallVidSetStreamParam", "pj::CallVidSetStreamParam *", 0, 0, (void*)0, 0};
static swig_type_info _swigt__p_pj__CodecFmtp = {"_p_pj__CodecFmtp", "pj::CodecFmtp *|std::vector< pj::CodecFmtp >::value_type *", 0, 0, (void*)0, 0};
static swig_type_info _swigt__p_pj__CodecInfo = {"_p_pj__CodecInfo", "std::vector< pj::CodecInfo >::value_type *|pj::CodecInfo *|std::vector< pj::CodecInfo * >::value_type", 0, 0, (void*)0, 0};
static swig_type_info _swigt__p_pj__CodecOpusConfig = {"_p_pj__CodecOpusConfig", "pj::CodecOpusConfig *", 0, 0, (void*)0, 0};
static swig_type_info _swigt__p_pj__CodecParam = {"_p_pj__CodecParam", "pj::CodecParam *", 0, 0, (void*)0, 0};
static swig_type_info _swigt__p_pj__CodecParamInfo = {"_p_pj__CodecParamInfo", "pj::CodecParamInfo *", 0, 0, (void*)0, 0};
static swig_type_info _swigt__p_pj__CodecParamSetting = {"_p_pj__CodecParamSetting", "pj::CodecParamSetting *", 0, 0, (void*)0, 0};
static swig_type_info _swigt__p_pj__ConfPortInfo = {"_p_pj__ConfPortInfo", "pj::ConfPortInfo *", 0, 0, (void*)0, 0};
static swig_type_info _swigt__p_pj__ContainerNode = {"_p_pj__ContainerNode", "pj::ContainerNode *", 0, 0, (void*)0, 0};
static swig_type_info _swigt__p_pj__DigestChallenge = {"_p_pj__DigestChallenge", "pj::DigestChallenge *", 0, 0, (void*)0, 0};
static swig_type_info _swigt__p_pj__DigestCredential = {"_p_pj__DigestCredential", "pj::DigestCredential *", 0, 0, (void*)0, 0};
static swig_type_info _swigt__p_pj__Endpoint = {"_p_pj__Endpoint", "pj::Endpoint *", 0, 0, (void*)0, 0};
static swig_type_info _swigt__p_pj__EpConfig = {"_p_pj__EpConfig", "pj::EpConfig *", 0, 0, (void*)0, 0};
static swig_type_info _swigt__p_pj__Error = {"_p_pj__Error", "pj::Error *", 0, 0, (void*)0, 0};
static swig_type_info _swigt__p_pj__ExtraAudioDevice = {"_p_pj__ExtraAudioDevice", "pj::ExtraAudioDevice *", 0, 0, (void*)0, 0};
static swig_type_info _swigt__p_pj__FindBuddyMatch = {"_p_pj__FindBuddyMatch", "pj::FindBuddyMatch *", 0, 0, (void*)0, 0};
static swig_type_info _swigt__p_pj__IpChangeParam = {"_p_pj__IpChangeParam", "pj::IpChangeParam *", 0, 0, (void*)0, 0};
static swig_type_info _swigt__p_pj__JbufState = {"_p_pj__JbufState", "pj::JbufState *", 0, 0, (void*)0, 0};
static swig_type_info _swigt__p_pj__JsonDocument = {"_p_pj__JsonDocument", "pj::JsonDocument *", 0, 0, (void*)0, 0};
static swig_type_info _swigt__p_pj__LogConfig = {"_p_pj__LogConfig", "pj::LogConfig *", 0, 0, (void*)0, 0};
static swig_type_info _swigt__p_pj__LogEntry = {"_p_pj__LogEntry", "pj::LogEntry *", 0, 0, (void*)0, 0};
static swig_type_info _swigt__p_pj__LogWriter = {"_p_pj__LogWriter", "pj::LogWriter *", 0, 0, (void*)0, 0};
static swig_type_info _swigt__p_pj__LossType = {"_p_pj__LossType", "pj::LossType *", 0, 0, (void*)0, 0};
static swig_type_info _swigt__p_pj__MathStat = {"_p_pj__MathStat", "pj::MathStat *", 0, 0, (void*)0, 0};
static swig_type_info _swigt__p_pj__Media = {"_p_pj__Media", "pj::Media *", 0, 0, (void*)0, 0};
static swig_type_info _swigt__p_pj__MediaConfig = {"_p_pj__MediaConfig", "pj::MediaConfig *", 0, 0, (void*)0, 0};
static swig_type_info _swigt__p_pj__MediaCoordinate = {"_p_pj__MediaCoordinate", "pj::MediaCoordinate *", 0, 0, (void*)0, 0};
static swig_type_info _swigt__p_pj__MediaEvent = {"_p_pj__MediaEvent", "pj::MediaEvent *", 0, 0, (void*)0, 0};
static swig_type_info _swigt__p_pj__MediaEventData = {"_p_pj__MediaEventData", "pj::MediaEventData *", 0, 0, (void*)0, 0};
static swig_type_info _swigt__p_pj__MediaFmtChangedEvent = {"_p_pj__MediaFmtChangedEvent", "pj::MediaFmtChangedEvent *", 0, 0, (void*)0, 0};
static swig_type_info _swigt__p_pj__MediaFormat = {"_p_pj__MediaFormat", "pj::MediaFormat *", 0, 0, (void*)0, 0};
static swig_type_info _swigt__p_pj__MediaFormatAudio = {"_p_pj__MediaFormatAudio", "std::vector< pj::MediaFormatAudio >::value_type *|pj::MediaFormatAudio *", 0, 0, (void*)0, 0};
static swig_type_info _swigt__p_pj__MediaFormatVideo = {"_p_pj__MediaFormatVideo", "std::vector< pj::MediaFormatVideo >::value_type *|pj::MediaFormatVideo *", 0, 0, (void*)0, 0};
static swig_type_info _swigt__p_pj__MediaSize = {"_p_pj__MediaSize", "pj::MediaSize *", 0, 0, (void*)0, 0};
static swig_type_info _swigt__p_pj__MediaTransportInfo = {"_p_pj__MediaTransportInfo", "pj::MediaTransportInfo *", 0, 0, (void*)0, 0};
static swig_type_info _swigt__p_pj__OnBuddyEvSubStateParam = {"_p_pj__OnBuddyEvSubStateParam", "pj::OnBuddyEvSubStateParam *", 0, 0, (void*)0, 0};
static swig_type_info _swigt__p_pj__OnCallMediaEventParam = {"_p_pj__OnCallMediaEventParam", "pj::OnCallMediaEventParam *", 0, 0, (void*)0, 0};
static swig_type_info _swigt__p_pj__OnCallMediaStateParam = {"_p_pj__OnCallMediaStateParam", "pj::OnCallMediaStateParam *", 0, 0, (void*)0, 0};
static swig_type_info _swigt__p_pj__OnCallMediaTransportStateParam = {"_p_pj__OnCallMediaTransportStateParam", "pj::OnCallMediaTransportStateParam *", 0, 0, (void*)0, 0};
static swig_type_info _swigt__p_pj__OnCallRedirectedParam = {"_p_pj__OnCallRedirectedParam", "pj::OnCallRedirectedParam *", 0, 0, (void*)0, 0};
static swig_type_info _swigt__p_pj__OnCallReplaceRequestParam = {"_p_pj__OnCallReplaceRequestParam", "pj::OnCallReplaceRequestParam *", 0, 0, (void*)0, 0};
static swig_type_info _swigt__p_pj__OnCallReplacedParam = {"_p_pj__OnCallReplacedParam", "pj::OnCallReplacedParam *", 0, 0, (void*)0, 0};
static swig_type_info _swigt__p_pj__OnCallRxOfferParam = {"_p_pj__OnCallRxOfferParam", "pj::OnCallRxOfferParam *", 0, 0, (void*)0, 0};
static swig_type_info _swigt__p_pj__OnCallRxReinviteParam = {"_p_pj__OnCallRxReinviteParam", "pj::OnCallRxReinviteParam *", 0, 0, (void*)0, 0};
static swig_type_info _swigt__p_pj__OnCallSdpCreatedParam = {"_p_pj__OnCallSdpCreatedParam", "pj::OnCallSdpCreatedParam *", 0, 0, (void*)0, 0};
static swig_type_info _swigt__p_pj__OnCallStateParam = {"_p_pj__OnCallStateParam", "pj::OnCallStateParam *", 0, 0, (void*)0, 0};
static swig_type_info _swigt__p_pj__OnCallTransferRequestParam = {"_p_pj__OnCallTransferRequestParam", "pj::OnCallTransferRequestParam *", 0, 0, (void*)0, 0};
static swig_type_info _swigt__p_pj__OnCallTransferStatusParam = {"_p_pj__OnCallTransferStatusParam", "pj::OnCallTransferStatusParam *", 0, 0, (void*)0, 0};
static swig_type_info _swigt__p_pj__OnCallTsxStateParam = {"_p_pj__OnCallTsxStateParam", "pj::OnCallTsxStateParam *", 0, 0, (void*)0, 0};
static swig_type_info _swigt__p_pj__OnCallTxOfferParam = {"_p_pj__OnCallTxOfferParam", "pj::OnCallTxOfferParam *", 0, 0, (void*)0, 0};
static swig_type_info _swigt__p_pj__OnCreateMediaTransportParam = {"_p_pj__OnCreateMediaTransportParam", "pj::OnCreateMediaTransportParam *", 0, 0, (void*)0, 0};
static swig_type_info _swigt__p_pj__OnCreateMediaTransportSrtpParam = {"_p_pj__OnCreateMediaTransportSrtpParam", "pj::OnCreateMediaTransportSrtpParam *", 0, 0, (void*)0, 0};
static swig_type_info _swigt__p_pj__OnCredAuthParam = {"_p_pj__OnCredAuthParam", "pj::OnCredAuthParam *", 0, 0, (void*)0, 0};
static swig_type_info _swigt__p_pj__OnDtmfDigitParam = {"_p_pj__OnDtmfDigitParam", "pj::OnDtmfDigitParam *", 0, 0, (void*)0, 0};
static swig_type_info _swigt__p_pj__OnDtmfEventParam = {"_p_pj__OnDtmfEventParam", "pj::OnDtmfEventParam *", 0, 0, (void*)0, 0};
static swig_type_info _swigt__p_pj__OnIncomingCallParam = {"_p_pj__OnIncomingCallParam", "pj::OnIncomingCallParam *", 0, 0, (void*)0, 0};
static swig_type_info _swigt__p_pj__OnIncomingSubscribeParam = {"_p_pj__OnIncomingSubscribeParam", "pj::OnIncomingSubscribeParam *", 0, 0, (void*)0, 0};
static swig_type_info _swigt__p_pj__OnInstantMessageParam = {"_p_pj__OnInstantMessageParam", "pj::OnInstantMessageParam *", 0, 0, (void*)0, 0};
static swig_type_info _swigt__p_pj__OnInstantMessageStatusParam = {"_p_pj__OnInstantMessageStatusParam", "pj::OnInstantMessageStatusParam *", 0, 0, (void*)0, 0};
static swig_type_info _swigt__p_pj__OnIpChangeProgressParam = {"_p_pj__OnIpChangeProgressParam", "pj::OnIpChangeProgressParam *", 0, 0, (void*)0, 0};
static swig_type_info _swigt__p_pj__OnMediaEventParam = {"_p_pj__OnMediaEventParam", "pj::OnMediaEventParam *", 0, 0, (void*)0, 0};
static swig_type_info _swigt__p_pj__OnMwiInfoParam = {"_p_pj__OnMwiInfoParam", "pj::OnMwiInfoParam *", 0, 0, (void*)0, 0};
static swig_type_info _swigt__p_pj__OnNatCheckStunServersCompleteParam = {"_p_pj__OnNatCheckStunServersCompleteParam", "pj::OnNatCheckStunServersCompleteParam *", 0, 0, (void*)0, 0};
static swig_type_info _swigt__p_pj__OnNatDetectionCompleteParam = {"_p_pj__OnNatDetectionCompleteParam", "pj::OnNatDetectionCompleteParam *", 0, 0, (void*)0, 0};
static swig_type_info _swigt__p_pj__OnRegStartedParam = {"_p_pj__OnRegStartedParam", "pj::OnRegStartedParam *", 0, 0, (void*)0, 0};
static swig_type_info _swigt__p_pj__OnRegStateParam = {"_p_pj__OnRegStateParam", "pj::OnRegStateParam *", 0, 0, (void*)0, 0};
static swig_type_info _swigt__p_pj__OnSelectAccountParam = {"_p_pj__OnSelectAccountParam", "pj::OnSelectAccountParam *", 0, 0, (void*)0, 0};
static swig_type_info _swigt__p_pj__OnStreamCreatedParam = {"_p_pj__OnStreamCreatedParam", "pj::OnStreamCreatedParam *", 0, 0, (void*)0, 0};
static swig_type_info _swigt__p_pj__OnStreamDestroyedParam = {"_p_pj__OnStreamDestroyedParam", "pj::OnStreamDestroyedParam *", 0, 0, (void*)0, 0};
static swig_type_info _swigt__p_pj__OnStreamPreCreateParam = {"_p_pj__OnStreamPreCreateParam", "pj::OnStreamPreCreateParam *", 0, 0, (void*)0, 0};
static swig_type_info _swigt__p_pj__OnTimerParam = {"_p_pj__OnTimerParam", "pj::OnTimerParam *", 0, 0, (void*)0, 0};
static swig_type_info _swigt__p_pj__OnTransportStateParam = {"_p_pj__OnTransportStateParam", "pj::OnTransportStateParam *", 0, 0, (void*)0, 0};
static swig_type_info _swigt__p_pj__OnTypingIndicationParam = {"_p_pj__OnTypingIndicationParam", "pj::OnTypingIndicationParam *", 0, 0, (void*)0, 0};
static swig_type_info _swigt__p_pj__PendingJob = {"_p_pj__PendingJob", "pj::PendingJob *", 0, 0, (void*)0, 0};
static swig_type_info _swigt__p_pj__PersistentDocument = {"_p_pj__PersistentDocument", "pj::PersistentDocument *", 0, 0, (void*)0, 0};
static swig_type_info _swigt__p_pj__PersistentObject = {"_p_pj__PersistentObject", "pj::PersistentObject *", 0, 0, (void*)0, 0};
static swig_type_info _swigt__p_pj__PresNotifyParam = {"_p_pj__PresNotifyParam", "pj::PresNotifyParam *", 0, 0, (void*)0, 0};
static swig_type_info _swigt__p_pj__PresenceStatus = {"_p_pj__PresenceStatus", "pj::PresenceStatus *", 0, 0, (void*)0, 0};
static swig_type_info _swigt__p_pj__RegProgressParam = {"_p_pj__RegProgressParam", "pj::RegProgressParam *", 0, 0, (void*)0, 0};
static swig_type_info _swigt__p_pj__RtcpFbCap = {"_p_pj__RtcpFbCap", "std::vector< pj::RtcpFbCap >::value_type *|pj::RtcpFbCap *", 0, 0, (void*)0, 0};
static swig_type_info _swigt__p_pj__RtcpFbConfig = {"_p_pj__RtcpFbConfig", "pj::RtcpFbConfig *", 0, 0, (void*)0, 0};
static swig_type_info _swigt__p_pj__RtcpSdes = {"_p_pj__RtcpSdes", "pj::RtcpSdes *", 0, 0, (void*)0, 0};
static swig_type_info _swigt__p_pj__RtcpStat = {"_p_pj__RtcpStat", "pj::RtcpStat *", 0, 0, (void*)0, 0};
static swig_type_info _swigt__p_pj__RtcpStreamStat = {"_p_pj__RtcpStreamStat", "pj::RtcpStreamStat *", 0, 0, (void*)0, 0};
static swig_type_info _swigt__p_pj__RxMsgEvent = {"_p_pj__RxMsgEvent", "pj::RxMsgEvent *", 0, 0, (void*)0, 0};
static swig_type_info _swigt__p_pj__SdpSession = {"_p_pj__SdpSession", "pj::SdpSession *", 0, 0, (void*)0, 0};
static swig_type_info _swigt__p_pj__SendInstantMessageParam = {"_p_pj__SendInstantMessageParam", "pj::SendInstantMessageParam *", 0, 0, (void*)0, 0};
static swig_type_info _swigt__p_pj__SendTypingIndicationParam = {"_p_pj__SendTypingIndicationParam", "pj::SendTypingIndicationParam *", 0, 0, (void*)0, 0};
static swig_type_info _swigt__p_pj__SipEvent = {"_p_pj__SipEvent", "pj::SipEvent *", 0, 0, (void*)0, 0};
static swig_type_info _swigt__p_pj__SipEventBody = {"_p_pj__SipEventBody", "pj::SipEventBody *", 0, 0, (void*)0, 0};
static swig_type_info _swigt__p_pj__SipHeader = {"_p_pj__SipHeader", "std::vector< pj::SipHeader >::value_type *|pj::SipHeader *", 0, 0, (void*)0, 0};
static swig_type_info _swigt__p_pj__SipMediaType = {"_p_pj__SipMediaType", "pj::SipMediaType *", 0, 0, (void*)0, 0};
static swig_type_info _swigt__p_pj__SipMultipartPart = {"_p_pj__SipMultipartPart", "std::vector< pj::SipMultipartPart >::value_type *|pj::SipMultipartPart *", 0, 0, (void*)0, 0};
static swig_type_info _swigt__p_pj__SipRxData = {"_p_pj__SipRxData", "pj::SipRxData *", 0, 0, (void*)0, 0};
static swig_type_info _swigt__p_pj__SipTransaction = {"_p_pj__SipTransaction", "pj::SipTransaction *", 0, 0, (void*)0, 0};
static swig_type_info _swigt__p_pj__SipTxData = {"_p_pj__SipTxData", "pj::SipTxData *", 0, 0, (void*)0, 0};
static swig_type_info _swigt__p_pj__SipTxOption = {"_p_pj__SipTxOption", "pj::SipTxOption *", 0, 0, (void*)0, 0};
static swig_type_info _swigt__p_pj__SrtpCrypto = {"_p_pj__SrtpCrypto", "std::vector< pj::SrtpCrypto >::value_type *|pj::SrtpCrypto *", 0, 0, (void*)0, 0};
static swig_type_info _swigt__p_pj__SrtpOpt = {"_p_pj__SrtpOpt", "pj::SrtpOpt *", 0, 0, (void*)0, 0};
static swig_type_info _swigt__p_pj__SslCertInfo = {"_p_pj__SslCertInfo", "pj::SslCertInfo *", 0, 0, (void*)0, 0};
static swig_type_info _swigt__p_pj__SslCertName = {"_p_pj__SslCertName", "std::vector< pj::SslCertName >::value_type *|pj::SslCertName *", 0, 0, (void*)0, 0};
static swig_type_info _swigt__p_pj__StreamInfo = {"_p_pj__StreamInfo", "pj::StreamInfo *", 0, 0, (void*)0, 0};
static swig_type_info _swigt__p_pj__StreamStat = {"_p_pj__StreamStat", "pj::StreamStat *", 0, 0, (void*)0, 0};
static swig_type_info _swigt__p_pj__TimeVal = {"_p_pj__TimeVal", "pj::TimeVal *", 0, 0, (void*)0, 0};
static swig_type_info _swigt__p_pj__TimerEvent = {"_p_pj__TimerEvent", "pj::TimerEvent *", 0, 0, (void*)0, 0};
static swig_type_info _swigt__p_pj__TlsConfig = {"_p_pj__TlsConfig", "pj::TlsConfig *", 0, 0, (void*)0, 0};
static swig_type_info _swigt__p_pj__TlsInfo = {"_p_pj__TlsInfo", "pj::TlsInfo *", 0, 0, (void*)0, 0};
static swig_type_info _swigt__p_pj__ToneDesc = {"_p_pj__ToneDesc", "pj::ToneDesc *|std::vector< pj::ToneDesc >::value_type *", 0, 0, (void*)0, 0};
static swig_type_info _swigt__p_pj__ToneDigit = {"_p_pj__ToneDigit", "pj::ToneDigit *|std::vector< pj::ToneDigit >::value_type *", 0, 0, (void*)0, 0};
static swig_type_info _swigt__p_pj__ToneDigitMapDigit = {"_p_pj__ToneDigitMapDigit", "pj::ToneDigitMapDigit *|std::vector< pj::ToneDigitMapDigit >::value_type *", 0, 0, (void*)0, 0};
static swig_type_info _swigt__p_pj__ToneGenerator = {"_p_pj__ToneGenerator", "pj::ToneGenerator *", 0, 0, (void*)0, 0};
static swig_type_info _swigt__p_pj__TransportConfig = {"_p_pj__TransportConfig", "pj::TransportConfig *", 0, 0, (void*)0, 0};
static swig_type_info _swigt__p_pj__TransportInfo = {"_p_pj__TransportInfo", "pj::TransportInfo *", 0, 0, (void*)0, 0};
static swig_type_info _swigt__p_pj__TsxStateEvent = {"_p_pj__TsxStateEvent", "pj::TsxStateEvent *", 0, 0, (void*)0, 0};
static swig_type_info _swigt__p_pj__TsxStateEventSrc = {"_p_pj__TsxStateEventSrc", "pj::TsxStateEventSrc *", 0, 0, (void*)0, 0};
static swig_type_info _swigt__p_pj__TxErrorEvent = {"_p_pj__TxErrorEvent", "pj::TxErrorEvent *", 0, 0, (void*)0, 0};
static swig_type_info _swigt__p_pj__TxMsgEvent = {"_p_pj__TxMsgEvent", "pj::TxMsgEvent *", 0, 0, (void*)0, 0};
static swig_type_info _swigt__p_pj__UaConfig = {"_p_pj__UaConfig", "pj::UaConfig *", 0, 0, (void*)0, 0};
static swig_type_info _swigt__p_pj__UserEvent = {"_p_pj__UserEvent", "pj::UserEvent *", 0, 0, (void*)0, 0};
static swig_type_info _swigt__p_pj__Version = {"_p_pj__Version", "pj::Version *", 0, 0, (void*)0, 0};
static swig_type_info _swigt__p_pj__VidCodecParam = {"_p_pj__VidCodecParam", "pj::VidCodecParam *", 0, 0, (void*)0, 0};
static swig_type_info _swigt__p_pj__VidConfPortInfo = {"_p_pj__VidConfPortInfo", "pj::VidConfPortInfo *", 0, 0, (void*)0, 0};
static swig_type_info _swigt__p_pj__VidDevManager = {"_p_pj__VidDevManager", "pj::VidDevManager *", 0, 0, (void*)0, 0};
static swig_type_info _swigt__p_pj__VideoDevInfo = {"_p_pj__VideoDevInfo", "pj::VideoDevInfo *|std::vector< pj::VideoDevInfo >::value_type *|std::vector< pj::VideoDevInfo * >::value_type", 0, 0, (void*)0, 0};
static swig_type_info _swigt__p_pj__VideoMedia = {"_p_pj__VideoMedia", "std::vector< pj::VideoMedia >::value_type *|pj::VideoMedia *", 0, 0, (void*)0, 0};
static swig_type_info _swigt__p_pj__VideoMediaTransmitParam = {"_p_pj__VideoMediaTransmitParam", "pj::VideoMediaTransmitParam *", 0, 0, (void*)0, 0};
static swig_type_info _swigt__p_pj__VideoPreview = {"_p_pj__VideoPreview", "pj::VideoPreview *", 0, 0, (void*)0, 0};
static swig_type_info _swigt__p_pj__VideoPreviewOpParam = {"_p_pj__VideoPreviewOpParam", "pj::VideoPreviewOpParam *", 0, 0, (void*)0, 0};
static swig_type_info _swigt__p_pj__VideoSwitchParam = {"_p_pj__VideoSwitchParam", "pj::VideoSwitchParam *", 0, 0, (void*)0, 0};
static swig_type_info _swigt__p_pj__VideoWindow = {"_p_pj__VideoWindow", "pj::VideoWindow *", 0, 0, (void*)0, 0};
static swig_type_info _swigt__p_pj__VideoWindowHandle = {"_p_pj__VideoWindowHandle", "pj::VideoWindowHandle *", 0, 0, (void*)0, 0};
static swig_type_info _swigt__p_pj__VideoWindowInfo = {"_p_pj__VideoWindowInfo", "pj::VideoWindowInfo *", 0, 0, (void*)0, 0};
static swig_type_info _swigt__p_pj__WindowHandle = {"_p_pj__WindowHandle", "pj::WindowHandle *", 0, 0, (void*)0, 0};
static swig_type_info _swigt__p_pj_ice_sess_trickle = {"_p_pj_ice_sess_trickle", "enum pj_ice_sess_trickle *|pj_ice_sess_trickle *", 0, 0, (void*)0, 0};
static swig_type_info _swigt__p_pj_qos_flag = {"_p_pj_qos_flag", "enum pj_qos_flag *|pj_qos_flag *", 0, 0, (void*)0, 0};
static swig_type_info _swigt__p_pj_qos_params = {"_p_pj_qos_params", "pj_qos_params *", 0, 0, (void*)0, 0};
static swig_type_info _swigt__p_pj_qos_type = {"_p_pj_qos_type", "enum pj_qos_type *|pj_qos_type *", 0, 0, (void*)0, 0};
static swig_type_info _swigt__p_pj_qos_wmm_prio = {"_p_pj_qos_wmm_prio", "enum pj_qos_wmm_prio *|pj_qos_wmm_prio *", 0, 0, (void*)0, 0};
static swig_type_info _swigt__p_pj_ssl_cert_name_type = {"_p_pj_ssl_cert_name_type", "enum pj_ssl_cert_name_type *|pj_ssl_cert_name_type *", 0, 0, (void*)0, 0};
static swig_type_info _swigt__p_pj_ssl_cert_verify_flag_t = {"_p_pj_ssl_cert_verify_flag_t", "enum pj_ssl_cert_verify_flag_t *|pj_ssl_cert_verify_flag_t *", 0, 0, (void*)0, 0};
static swig_type_info _swigt__p_pj_ssl_cipher = {"_p_pj_ssl_cipher", "enum pj_ssl_cipher *|pj_ssl_cipher *", 0, 0, (void*)0, 0};
static swig_type_info _swigt__p_pj_ssl_sock_proto = {"_p_pj_ssl_sock_proto", "enum pj_ssl_sock_proto *|pj_ssl_sock_proto *", 0, 0, (void*)0, 0};
static swig_type_info _swigt__p_pj_stun_nat_type = {"_p_pj_stun_nat_type", "enum pj_stun_nat_type *|pj_stun_nat_type *", 0, 0, (void*)0, 0};
static swig_type_info _swigt__p_pj_turn_tp_type = {"_p_pj_turn_tp_type", "enum pj_turn_tp_type *|pj_turn_tp_type *", 0, 0, (void*)0, 0};
static swig_type_info _swigt__p_pjmedia_aud_dev_cap = {"_p_pjmedia_aud_dev_cap", "enum pjmedia_aud_dev_cap *|pjmedia_aud_dev_cap *", 0, 0, (void*)0, 0};
static swig_type_info _swigt__p_pjmedia_aud_dev_route = {"_p_pjmedia_aud_dev_route", "enum pjmedia_aud_dev_route *|pjmedia_aud_dev_route *", 0, 0, (void*)0, 0};
static swig_type_info _swigt__p_pjmedia_dir = {"_p_pjmedia_dir", "enum pjmedia_dir *|pjmedia_dir *", 0, 0, (void*)0, 0};
static swig_type_info _swigt__p_pjmedia_echo_flag = {"_p_pjmedia_echo_flag", "enum pjmedia_echo_flag *|pjmedia_echo_flag *", 0, 0, (void*)0, 0};
static swig_type_info _swigt__p_pjmedia_event_type = {"_p_pjmedia_event_type", "enum pjmedia_event_type *|pjmedia_event_type *", 0, 0, (void*)0, 0};
static swig_type_info _swigt__p_pjmedia_format_id = {"_p_pjmedia_format_id", "enum pjmedia_format_id *|pjmedia_format_id *", 0, 0, (void*)0, 0};
static swig_type_info _swigt__p_pjmedia_jb_discard_algo = {"_p_pjmedia_jb_discard_algo", "pjmedia_jb_discard_algo *", 0, 0, (void*)0, 0};
static swig_type_info _swigt__p_pjmedia_orient = {"_p_pjmedia_orient", "enum pjmedia_orient *|pjmedia_orient *", 0, 0, (void*)0, 0};
static swig_type_info _swigt__p_pjmedia_rtcp_fb_type = {"_p_pjmedia_rtcp_fb_type", "enum pjmedia_rtcp_fb_type *|pjmedia_rtcp_fb_type *", 0, 0, (void*)0, 0};
static swig_type_info _swigt__p_pjmedia_srtp_crypto_option = {"_p_pjmedia_srtp_crypto_option", "enum pjmedia_srtp_crypto_option *|pjmedia_srtp_crypto_option *", 0, 0, (void*)0, 0};
static swig_type_info _swigt__p_pjmedia_srtp_keying_method = {"_p_pjmedia_srtp_keying_method", "enum pjmedia_srtp_keying_method *|pjmedia_srtp_keying_method *", 0, 0, (void*)0, 0};
static swig_type_info _swigt__p_pjmedia_srtp_use = {"_p_pjmedia_srtp_use", "enum pjmedia_srtp_use *|pjmedia_srtp_use *", 0, 0, (void*)0, 0};
static swig_type_info _swigt__p_pjmedia_tone_desc = {"_p_pjmedia_tone_desc", "pjmedia_tone_desc *", 0, 0, (void*)0, 0};
static swig_type_info _swigt__p_pjmedia_tone_digit = {"_p_pjmedia_tone_digit", "pjmedia_tone_digit *", 0, 0, (void*)0, 0};
static swig_type_info _swigt__p_pjmedia_tone_digit_map = {"_p_pjmedia_tone_digit_map", "pjmedia_tone_digit_map *", 0, 0, (void*)0, 0};
static swig_type_info _swigt__p_pjmedia_tp_proto = {"_p_pjmedia_tp_proto", "enum pjmedia_tp_proto *|pjmedia_tp_proto *", 0, 0, (void*)0, 0};
static swig_type_info _swigt__p_pjmedia_type = {"_p_pjmedia_type", "enum pjmedia_type *|pjmedia_type *", 0, 0, (void*)0, 0};
static swig_type_info _swigt__p_pjmedia_vid_dev_cap = {"_p_pjmedia_vid_dev_cap", "enum pjmedia_vid_dev_cap *|pjmedia_vid_dev_cap *", 0, 0, (void*)0, 0};
static swig_type_info _swigt__p_pjmedia_vid_dev_fullscreen_flag = {"_p_pjmedia_vid_dev_fullscreen_flag", "enum pjmedia_vid_dev_fullscreen_flag *|pjmedia_vid_dev_fullscreen_flag *", 0, 0, (void*)0, 0};
static swig_type_info _swigt__p_pjmedia_vid_dev_hwnd_type = {"_p_pjmedia_vid_dev_hwnd_type", "pjmedia_vid_dev_hwnd_type *", 0, 0, (void*)0, 0};
static swig_type_info _swigt__p_pjmedia_vid_packing = {"_p_pjmedia_vid_packing", "enum pjmedia_vid_packing *|pjmedia_vid_packing *", 0, 0, (void*)0, 0};
static swig_type_info _swigt__p_pjmedia_vid_stream_rc_method = {"_p_pjmedia_vid_stream_rc_method", "enum pjmedia_vid_stream_rc_method *|pjmedia_vid_stream_rc_method *", 0, 0, (void*)0, 0};
static swig_type_info _swigt__p_pjrpid_activity = {"_p_pjrpid_activity", "enum pjrpid_activity *|pjrpid_activity *", 0, 0, (void*)0, 0};
static swig_type_info _swigt__p_pjsip_cred_data_type = {"_p_pjsip_cred_data_type", "enum pjsip_cred_data_type *|pjsip_cred_data_type *", 0, 0, (void*)0, 0};
static swig_type_info _swigt__p_pjsip_dialog_cap_status = {"_p_pjsip_dialog_cap_status", "enum pjsip_dialog_cap_status *|pjsip_dialog_cap_status *", 0, 0, (void*)0, 0};
static swig_type_info _swigt__p_pjsip_event_id_e = {"_p_pjsip_event_id_e", "enum pjsip_event_id_e *|pjsip_event_id_e *", 0, 0, (void*)0, 0};
static swig_type_info _swigt__p_pjsip_evsub_state = {"_p_pjsip_evsub_state", "enum pjsip_evsub_state *|pjsip_evsub_state *", 0, 0, (void*)0, 0};
static swig_type_info _swigt__p_pjsip_hdr_e = {"_p_pjsip_hdr_e", "enum pjsip_hdr_e *|pjsip_hdr_e *", 0, 0, (void*)0, 0};
static swig_type_info _swigt__p_pjsip_inv_state = {"_p_pjsip_inv_state", "enum pjsip_inv_state *|pjsip_inv_state *", 0, 0, (void*)0, 0};
static swig_type_info _swigt__p_pjsip_redirect_op = {"_p_pjsip_redirect_op", "enum pjsip_redirect_op *|pjsip_redirect_op *", 0, 0, (void*)0, 0};
static swig_type_info _swigt__p_pjsip_role_e = {"_p_pjsip_role_e", "enum pjsip_role_e *|pjsip_role_e *", 0, 0, (void*)0, 0};
static swig_type_info _swigt__p_pjsip_ssl_method = {"_p_pjsip_ssl_method", "enum pjsip_ssl_method *|pjsip_ssl_method *", 0, 0, (void*)0, 0};
static swig_type_info _swigt__p_pjsip_status_code = {"_p_pjsip_status_code", "enum pjsip_status_code *|pjsip_status_code *", 0, 0, (void*)0, 0};
static swig_type_info _swigt__p_pjsip_transport_state = {"_p_pjsip_transport_state", "enum pjsip_transport_state *|pjsip_transport_state *", 0, 0, (void*)0, 0};
static swig_type_info _swigt__p_pjsip_transport_type_e = {"_p_pjsip_transport_type_e", "enum pjsip_transport_type_e *|pjsip_transport_type_e *", 0, 0, (void*)0, 0};
static swig_type_info _swigt__p_pjsip_tsx_state_e = {"_p_pjsip_tsx_state_e", "enum pjsip_tsx_state_e *|pjsip_tsx_state_e *", 0, 0, (void*)0, 0};
static swig_type_info _swigt__p_pjsua_100rel_use = {"_p_pjsua_100rel_use", "enum pjsua_100rel_use *|pjsua_100rel_use *", 0, 0, (void*)0, 0};
static swig_type_info _swigt__p_pjsua_buddy_status = {"_p_pjsua_buddy_status", "enum pjsua_buddy_status *|pjsua_buddy_status *", 0, 0, (void*)0, 0};
static swig_type_info _swigt__p_pjsua_call_flag = {"_p_pjsua_call_flag", "enum pjsua_call_flag *|pjsua_call_flag *", 0, 0, (void*)0, 0};
static swig_type_info _swigt__p_pjsua_call_hold_type = {"_p_pjsua_call_hold_type", "enum pjsua_call_hold_type *|pjsua_call_hold_type *", 0, 0, (void*)0, 0};
static swig_type_info _swigt__p_pjsua_call_media_status = {"_p_pjsua_call_media_status", "enum pjsua_call_media_status *|pjsua_call_media_status *", 0, 0, (void*)0, 0};
static swig_type_info _swigt__p_pjsua_call_vid_strm_op = {"_p_pjsua_call_vid_strm_op", "enum pjsua_call_vid_strm_op *|pjsua_call_vid_strm_op *", 0, 0, (void*)0, 0};
static swig_type_info _swigt__p_pjsua_create_media_transport_flag = {"_p_pjsua_create_media_transport_flag", "enum pjsua_create_media_transport_flag *|pjsua_create_media_transport_flag *", 0, 0, (void*)0, 0};
static swig_type_info _swigt__p_pjsua_destroy_flag = {"_p_pjsua_destroy_flag", "enum pjsua_destroy_flag *|pjsua_destroy_flag *", 0, 0, (void*)0, 0};
static swig_type_info _swigt__p_pjsua_dtmf_method = {"_p_pjsua_dtmf_method", "enum pjsua_dtmf_method *|pjsua_dtmf_method *", 0, 0, (void*)0, 0};
static swig_type_info _swigt__p_pjsua_ip_change_op = {"_p_pjsua_ip_change_op", "enum pjsua_ip_change_op *|pjsua_ip_change_op *", 0, 0, (void*)0, 0};
static swig_type_info _swigt__p_pjsua_ipv6_use = {"_p_pjsua_ipv6_use", "enum pjsua_ipv6_use *|pjsua_ipv6_use *", 0, 0, (void*)0, 0};
static swig_type_info _swigt__p_pjsua_med_tp_st = {"_p_pjsua_med_tp_st", "enum pjsua_med_tp_st *|pjsua_med_tp_st *", 0, 0, (void*)0, 0};
static swig_type_info _swigt__p_pjsua_nat64_opt = {"_p_pjsua_nat64_opt", "enum pjsua_nat64_opt *|pjsua_nat64_opt *", 0, 0, (void*)0, 0};
static swig_type_info _swigt__p_pjsua_sip_timer_use = {"_p_pjsua_sip_timer_use", "enum pjsua_sip_timer_use *|pjsua_sip_timer_use *", 0, 0, (void*)0, 0};
static swig_type_info _swigt__p_pjsua_snd_dev_id = {"_p_pjsua_snd_dev_id", "enum pjsua_snd_dev_id *|pjsua_snd_dev_id *", 0, 0, (void*)0, 0};
static swig_type_info _swigt__p_pjsua_snd_dev_mode = {"_p_pjsua_snd_dev_mode", "enum pjsua_snd_dev_mode *|pjsua_snd_dev_mode *", 0, 0, (void*)0, 0};
static swig_type_info _swigt__p_pjsua_state = {"_p_pjsua_state", "enum pjsua_state *|pjsua_state *", 0, 0, (void*)0, 0};
static swig_type_info _swigt__p_pjsua_stun_use = {"_p_pjsua_stun_use", "enum pjsua_stun_use *|pjsua_stun_use *", 0, 0, (void*)0, 0};
static swig_type_info _swigt__p_pjsua_vid_req_keyframe_method = {"_p_pjsua_vid_req_keyframe_method", "enum pjsua_vid_req_keyframe_method *|pjsua_vid_req_keyframe_method *", 0, 0, (void*)0, 0};
static swig_type_info _swigt__p_size_type = {"_p_size_type", "size_type *", 0, 0, (void*)0, 0};
static swig_type_info _swigt__p_std__allocatorT_int_t = {"_p_std__allocatorT_int_t", "std::vector< int >::allocator_type *|std::allocator< int > *", 0, 0, (void*)0, 0};
static swig_type_info _swigt__p_std__allocatorT_pj__AudioDevInfo_p_t = {"_p_std__allocatorT_pj__AudioDevInfo_p_t", "std::allocator< pj::AudioDevInfo * > *|std::vector< pj::AudioDevInfo * >::allocator_type *", 0, 0, (void*)0, 0};
static swig_type_info _swigt__p_std__allocatorT_pj__AudioDevInfo_t = {"_p_std__allocatorT_pj__AudioDevInfo_t", "std::vector< pj::AudioDevInfo >::allocator_type *|std::allocator< pj::AudioDevInfo > *", 0, 0, (void*)0, 0};
static swig_type_info _swigt__p_std__allocatorT_pj__AudioMedia_p_t = {"_p_std__allocatorT_pj__AudioMedia_p_t", "std::vector< pj::AudioMedia * >::allocator_type *|std::allocator< pj::AudioMedia * > *", 0, 0, (void*)0, 0};
static swig_type_info _swigt__p_std__allocatorT_pj__AudioMedia_t = {"_p_std__allocatorT_pj__AudioMedia_t", "std::vector< pj::AudioMedia >::allocator_type *|std::allocator< pj::AudioMedia > *", 0, 0, (void*)0, 0};
static swig_type_info _swigt__p_std__allocatorT_pj__AuthCredInfo_t = {"_p_std__allocatorT_pj__AuthCredInfo_t", "std::vector< pj::AuthCredInfo >::allocator_type *|std::allocator< pj::AuthCredInfo > *", 0, 0, (void*)0, 0};
static swig_type_info _swigt__p_std__allocatorT_pj__Buddy_p_t = {"_p_std__allocatorT_pj__Buddy_p_t", "std::vector< pj::Buddy * >::allocator_type *|std::allocator< pj::Buddy * > *", 0, 0, (void*)0, 0};
static swig_type_info _swigt__p_std__allocatorT_pj__Buddy_t = {"_p_std__allocatorT_pj__Buddy_t", "std::allocator< pj::Buddy > *|std::vector< pj::Buddy >::allocator_type *", 0, 0, (void*)0, 0};
static swig_type_info _swigt__p_std__allocatorT_pj__CallMediaInfo_t = {"_p_std__allocatorT_pj__CallMediaInfo_t", "std::vector< pj::CallMediaInfo >::allocator_type *|std::allocator< pj::CallMediaInfo > *", 0, 0, (void*)0, 0};
static swig_type_info _swigt__p_std__allocatorT_pj__CodecFmtp_t = {"_p_std__allocatorT_pj__CodecFmtp_t", "std::vector< pj::CodecFmtp >::allocator_type *|std::allocator< pj::CodecFmtp > *", 0, 0, (void*)0, 0};
static swig_type_info _swigt__p_std__allocatorT_pj__CodecInfo_p_t = {"_p_std__allocatorT_pj__CodecInfo_p_t", "std::vector< pj::CodecInfo * >::allocator_type *|std::allocator< pj::CodecInfo * > *", 0, 0, (void*)0, 0};
static swig_type_info _swigt__p_std__allocatorT_pj__CodecInfo_t = {"_p_std__allocatorT_pj__CodecInfo_t", "std::vector< pj::CodecInfo >::allocator_type *|std::allocator< pj::CodecInfo > *", 0, 0, (void*)0, 0};
static swig_type_info _swigt__p_std__allocatorT_pj__MediaFormatAudio_t = {"_p_std__allocatorT_pj__MediaFormatAudio_t", "std::vector< pj::MediaFormatAudio >::allocator_type *|std::allocator< pj::MediaFormatAudio > *", 0, 0, (void*)0, 0};
static swig_type_info _swigt__p_std__allocatorT_pj__MediaFormatVideo_t = {"_p_std__allocatorT_pj__MediaFormatVideo_t", "std::vector< pj::MediaFormatVideo >::allocator_type *|std::allocator< pj::MediaFormatVideo > *", 0, 0, (void*)0, 0};
static swig_type_info _swigt__p_std__allocatorT_pj__RtcpFbCap_t = {"_p_std__allocatorT_pj__RtcpFbCap_t", "std::vector< pj::RtcpFbCap >::allocator_type *|std::allocator< pj::RtcpFbCap > *", 0, 0, (void*)0, 0};
static swig_type_info _swigt__p_std__allocatorT_pj__SipHeader_t = {"_p_std__allocatorT_pj__SipHeader_t", "std::vector< pj::SipHeader >::allocator_type *|std::allocator< pj::SipHeader > *", 0, 0, (void*)0, 0};
static swig_type_info _swigt__p_std__allocatorT_pj__SipMultipartPart_t = {"_p_std__allocatorT_pj__SipMultipartPart_t", "std::allocator< pj::SipMultipartPart > *|std::vector< pj::SipMultipartPart >::allocator_type *", 0, 0, (void*)0, 0};
static swig_type_info _swigt__p_std__allocatorT_pj__SrtpCrypto_t = {"_p_std__allocatorT_pj__SrtpCrypto_t", "std::vector< pj::SrtpCrypto >::allocator_type *|std::allocator< pj::SrtpCrypto > *", 0, 0, (void*)0, 0};
static swig_type_info _swigt__p_std__allocatorT_pj__SslCertName_t = {"_p_std__allocatorT_pj__SslCertName_t", "std::allocator< pj::SslCertName > *|std::vector< pj::SslCertName >::allocator_type *", 0, 0, (void*)0, 0};
static swig_type_info _swigt__p_std__allocatorT_pj__ToneDesc_t = {"_p_std__allocatorT_pj__ToneDesc_t", "std::vector< pj::ToneDesc >::allocator_type *|std::allocator< pj::ToneDesc > *", 0, 0, (void*)0, 0};
static swig_type_info _swigt__p_std__allocatorT_pj__ToneDigitMapDigit_t = {"_p_std__allocatorT_pj__ToneDigitMapDigit_t", "std::vector< pj::ToneDigitMapDigit >::allocator_type *|std::allocator< pj::ToneDigitMapDigit > *", 0, 0, (void*)0, 0};
static swig_type_info _swigt__p_std__allocatorT_pj__ToneDigit_t = {"_p_std__allocatorT_pj__ToneDigit_t", "std::vector< pj::ToneDigit >::allocator_type *|std::allocator< pj::ToneDigit > *", 0, 0, (void*)0, 0};
static swig_type_info _swigt__p_std__allocatorT_pj__VideoDevInfo_p_t = {"_p_std__allocatorT_pj__VideoDevInfo_p_t", "std::allocator< pj::VideoDevInfo * > *|std::vector< pj::VideoDevInfo * >::allocator_type *", 0, 0, (void*)0, 0};
static swig_type_info _swigt__p_std__allocatorT_pj__VideoDevInfo_t = {"_p_std__allocatorT_pj__VideoDevInfo_t", "std::vector< pj::VideoDevInfo >::allocator_type *|std::allocator< pj::VideoDevInfo > *", 0, 0, (void*)0, 0};
static swig_type_info _swigt__p_std__allocatorT_pj__VideoMedia_t = {"_p_std__allocatorT_pj__VideoMedia_t", "std::vector< pj::VideoMedia >::allocator_type *|std::allocator< pj::VideoMedia > *", 0, 0, (void*)0, 0};
static swig_type_info _swigt__p_std__allocatorT_std__pairT_std__string_const_std__string_t_t = {"_p_std__allocatorT_std__pairT_std__string_const_std__string_t_t", "std::map< string,string >::allocator_type *|std::allocator< std::pair< std::string const,std::string > > *", 0, 0, (void*)0, 0};
static swig_type_info _swigt__p_std__allocatorT_std__string_t = {"_p_std__allocatorT_std__string_t", "std::vector< std::string >::allocator_type *|std::allocator< std::string > *", 0, 0, (void*)0, 0};
static swig_type_info _swigt__p_std__invalid_argument = {"_p_std__invalid_argument", "std::invalid_argument *", 0, 0, (void*)0, 0};
static swig_type_info _swigt__p_std__lessT_std__string_t = {"_p_std__lessT_std__string_t", "std::less< std::string > *", 0, 0, (void*)0, 0};
static swig_type_info _swigt__p_std__mapT_std__string_std__string_std__lessT_std__string_t_std__allocatorT_std__pairT_std__string_const_std__string_t_t_t = {"_p_std__mapT_std__string_std__string_std__lessT_std__string_t_std__allocatorT_std__pairT_std__string_const_std__string_t_t_t", "pj::StringToStringMap *|std::map< string,string > *|std::map< std::string,std::string,std::less< std::string >,std::allocator< std::pair< std::string const,std::string > > > *|std::map< std::string,std::string > *", 0, 0, (void*)0, 0};
static swig_type_info _swigt__p_std__string = {"_p_std__string", "pj::SocketAddress *|std::string *", 0, 0, (void*)0, 0};
static swig_type_info _swigt__p_std__vectorT_int_std__allocatorT_int_t_t = {"_p_std__vectorT_int_std__allocatorT_int_t_t", "std::vector< int,std::allocator< int > > *|pj::IntVector *|pj::MediaDirVector *|std::vector< int > *", 0, 0, (void*)0, 0};
static swig_type_info _swigt__p_std__vectorT_pj__AudioDevInfo_p_std__allocatorT_pj__AudioDevInfo_p_t_t = {"_p_std__vectorT_pj__AudioDevInfo_p_std__allocatorT_pj__AudioDevInfo_p_t_t", "std::vector< pj::AudioDevInfo *,std::allocator< pj::AudioDevInfo * > > *|std::vector< pj::AudioDevInfo * > *|pj::AudioDevInfoVector *", 0, 0, (void*)0, 0};
static swig_type_info _swigt__p_std__vectorT_pj__AudioDevInfo_std__allocatorT_pj__AudioDevInfo_t_t = {"_p_std__vectorT_pj__AudioDevInfo_std__allocatorT_pj__AudioDevInfo_t_t", "pj::AudioDevInfoVector2 *|std::vector< pj::AudioDevInfo,std::allocator< pj::AudioDevInfo > > *|std::vector< pj::AudioDevInfo > *", 0, 0, (void*)0, 0};
static swig_type_info _swigt__p_std__vectorT_pj__AudioMedia_p_std__allocatorT_pj__AudioMedia_p_t_t = {"_p_std__vectorT_pj__AudioMedia_p_std__allocatorT_pj__AudioMedia_p_t_t", "std::vector< pj::AudioMedia *,std::allocator< pj::AudioMedia * > > *|std::vector< pj::AudioMedia * > *|pj::AudioMediaVector *", 0, 0, (void*)0, 0};
static swig_type_info _swigt__p_std__vectorT_pj__AudioMedia_std__allocatorT_pj__AudioMedia_t_t = {"_p_std__vectorT_pj__AudioMedia_std__allocatorT_pj__AudioMedia_t_t", "std::vector< pj::AudioMedia,std::allocator< pj::AudioMedia > > *|pj::AudioMediaVector2 *|std::vector< pj::AudioMedia > *", 0, 0, (void*)0, 0};
static swig_type_info _swigt__p_std__vectorT_pj__AuthCredInfo_std__allocatorT_pj__AuthCredInfo_t_t = {"_p_std__vectorT_pj__AuthCredInfo_std__allocatorT_pj__AuthCredInfo_t_t", "std::vector< pj::AuthCredInfo,std::allocator< pj::AuthCredInfo > > *|std::vector< pj::AuthCredInfo > *|pj::AuthCredInfoVector *", 0, 0, (void*)0, 0};
static swig_type_info _swigt__p_std__vectorT_pj__Buddy_p_std__allocatorT_pj__Buddy_p_t_t = {"_p_std__vectorT_pj__Buddy_p_std__allocatorT_pj__Buddy_p_t_t", "std::vector< pj::Buddy *,std::allocator< pj::Buddy * > > *|std::vector< pj::Buddy * > *|pj::BuddyVector *", 0, 0, (void*)0, 0};
static swig_type_info _swigt__p_std__vectorT_pj__Buddy_std__allocatorT_pj__Buddy_t_t = {"_p_std__vectorT_pj__Buddy_std__allocatorT_pj__Buddy_t_t", "std::vector< pj::Buddy > *|pj::BuddyVector2 *|std::vector< pj::Buddy,std::allocator< pj::Buddy > > *", 0, 0, (void*)0, 0};
static swig_type_info _swigt__p_std__vectorT_pj__CallMediaInfo_std__allocatorT_pj__CallMediaInfo_t_t = {"_p_std__vectorT_pj__CallMediaInfo_std__allocatorT_pj__CallMediaInfo_t_t", "std::vector< pj::CallMediaInfo > *|std::vector< pj::CallMediaInfo,std::allocator< pj::CallMediaInfo > > *|pj::CallMediaInfoVector *", 0, 0, (void*)0, 0};
static swig_type_info _swigt__p_std__vectorT_pj__CodecFmtp_std__allocatorT_pj__CodecFmtp_t_t = {"_p_std__vectorT_pj__CodecFmtp_std__allocatorT_pj__CodecFmtp_t_t", "std::vector< pj::CodecFmtp > *|std::vector< pj::CodecFmtp,std::allocator< pj::CodecFmtp > > *|pj::CodecFmtpVector *", 0, 0, (void*)0, 0};
static swig_type_info _swigt__p_std__vectorT_pj__CodecInfo_p_std__allocatorT_pj__CodecInfo_p_t_t = {"_p_std__vectorT_pj__CodecInfo_p_std__allocatorT_pj__CodecInfo_p_t_t", "std::vector< pj::CodecInfo * > *|std::vector< pj::CodecInfo *,std::allocator< pj::CodecInfo * > > *|pj::CodecInfoVector *", 0, 0, (void*)0, 0};
static swig_type_info _swigt__p_std__vectorT_pj__CodecInfo_std__allocatorT_pj__CodecInfo_t_t = {"_p_std__vectorT_pj__CodecInfo_std__allocatorT_pj__CodecInfo_t_t", "pj::CodecInfoVector2 *|std::vector< pj::CodecInfo,std::allocator< pj::CodecInfo > > *|std::vector< pj::CodecInfo > *", 0, 0, (void*)0, 0};
static swig_type_info _swigt__p_std__vectorT_pj__MediaFormatAudio_std__allocatorT_pj__MediaFormatAudio_t_t = {"_p_std__vectorT_pj__MediaFormatAudio_std__allocatorT_pj__MediaFormatAudio_t_t", "std::vector< pj::MediaFormatAudio > *|std::vector< pj::MediaFormatAudio,std::allocator< pj::MediaFormatAudio > > *|pj::MediaFormatAudioVector *", 0, 0, (void*)0, 0};
static swig_type_info _swigt__p_std__vectorT_pj__MediaFormatVideo_std__allocatorT_pj__MediaFormatVideo_t_t = {"_p_std__vectorT_pj__MediaFormatVideo_std__allocatorT_pj__MediaFormatVideo_t_t", "std::vector< pj::MediaFormatVideo > *|std::vector< pj::MediaFormatVideo,std::allocator< pj::MediaFormatVideo > > *|pj::MediaFormatVideoVector *", 0, 0, (void*)0, 0};
static swig_type_info _swigt__p_std__vectorT_pj__RtcpFbCap_std__allocatorT_pj__RtcpFbCap_t_t = {"_p_std__vectorT_pj__RtcpFbCap_std__allocatorT_pj__RtcpFbCap_t_t", "std::vector< pj::RtcpFbCap,std::allocator< pj::RtcpFbCap > > *|pj::RtcpFbCapVector *|std::vector< pj::RtcpFbCap > *", 0, 0, (void*)0, 0};
static swig_type_info _swigt__p_std__vectorT_pj__SipHeader_std__allocatorT_pj__SipHeader_t_t = {"_p_std__vectorT_pj__SipHeader_std__allocatorT_pj__SipHeader_t_t", "std::vector< pj::SipHeader,std::allocator< pj::SipHeader > > *|std::vector< pj::SipHeader > *|pj::SipHeaderVector *", 0, 0, (void*)0, 0};
static swig_type_info _swigt__p_std__vectorT_pj__SipMultipartPart_std__allocatorT_pj__SipMultipartPart_t_t = {"_p_std__vectorT_pj__SipMultipartPart_std__allocatorT_pj__SipMultipartPart_t_t", "std::vector< pj::SipMultipartPart > *|std::vector< pj::SipMultipartPart,std::allocator< pj::SipMultipartPart > > *|pj::SipMultipartPartVector *", 0, 0, (void*)0, 0};
static swig_type_info _swigt__p_std__vectorT_pj__SrtpCrypto_std__allocatorT_pj__SrtpCrypto_t_t = {"_p_std__vectorT_pj__SrtpCrypto_std__allocatorT_pj__SrtpCrypto_t_t", "std::vector< pj::SrtpCrypto,std::allocator< pj::SrtpCrypto > > *|pj::SrtpCryptoVector *|std::vector< pj::SrtpCrypto > *", 0, 0, (void*)0, 0};
static swig_type_info _swigt__p_std__vectorT_pj__SslCertName_std__allocatorT_pj__SslCertName_t_t = {"_p_std__vectorT_pj__SslCertName_std__allocatorT_pj__SslCertName_t_t", "std::vector< pj::SslCertName > *|std::vector< pj::SslCertName,std::allocator< pj::SslCertName > > *|pj::SslCertNameVector *", 0, 0, (void*)0, 0};
static swig_type_info _swigt__p_std__vectorT_pj__ToneDesc_std__allocatorT_pj__ToneDesc_t_t = {"_p_std__vectorT_pj__ToneDesc_std__allocatorT_pj__ToneDesc_t_t", "std::vector< pj::ToneDesc > *|std::vector< pj::ToneDesc,std::allocator< pj::ToneDesc > > *|pj::ToneDescVector *", 0, 0, (void*)0, 0};
static swig_type_info _swigt__p_std__vectorT_pj__ToneDigitMapDigit_std__allocatorT_pj__ToneDigitMapDigit_t_t = {"_p_std__vectorT_pj__ToneDigitMapDigit_std__allocatorT_pj__ToneDigitMapDigit_t_t", "std::vector< pj::ToneDigitMapDigit,std::allocator< pj::ToneDigitMapDigit > > *|std::vector< pj::ToneDigitMapDigit > *|pj::ToneDigitMapVector *", 0, 0, (void*)0, 0};
static swig_type_info _swigt__p_std__vectorT_pj__ToneDigit_std__allocatorT_pj__ToneDigit_t_t = {"_p_std__vectorT_pj__ToneDigit_std__allocatorT_pj__ToneDigit_t_t", "std::vector< pj::ToneDigit > *|std::vector< pj::ToneDigit,std::allocator< pj::ToneDigit > > *|pj::ToneDigitVector *", 0, 0, (void*)0, 0};
static swig_type_info _swigt__p_std__vectorT_pj__VideoDevInfo_p_std__allocatorT_pj__VideoDevInfo_p_t_t = {"_p_std__vectorT_pj__VideoDevInfo_p_std__allocatorT_pj__VideoDevInfo_p_t_t", "std::vector< pj::VideoDevInfo *,std::allocator< pj::VideoDevInfo * > > *|std::vector< pj::VideoDevInfo * > *|pj::VideoDevInfoVector *", 0, 0, (void*)0, 0};
static swig_type_info _swigt__p_std__vectorT_pj__VideoDevInfo_std__allocatorT_pj__VideoDevInfo_t_t = {"_p_std__vectorT_pj__VideoDevInfo_std__allocatorT_pj__VideoDevInfo_t_t", "pj::VideoDevInfoVector2 *|std::vector< pj::VideoDevInfo,std::allocator< pj::VideoDevInfo > > *|std::vector< pj::VideoDevInfo > *", 0, 0, (void*)0, 0};
static swig_type_info _swigt__p_std__vectorT_pj__VideoMedia_std__allocatorT_pj__VideoMedia_t_t = {"_p_std__vectorT_pj__VideoMedia_std__allocatorT_pj__VideoMedia_t_t", "std::vector< pj::VideoMedia,std::allocator< pj::VideoMedia > > *|std::vector< pj::VideoMedia > *|pj::VideoMediaVector *", 0, 0, (void*)0, 0};
static swig_type_info _swigt__p_std__vectorT_std__string_std__allocatorT_std__string_t_t = {"_p_std__vectorT_std__string_std__allocatorT_std__string_t_t", "std::vector< std::string,std::allocator< std::string > > *|std::vector< std::string > *|pj::StringVector *", 0, 0, (void*)0, 0};
static swig_type_info _swigt__p_swig__SwigPyIterator = {"_p_swig__SwigPyIterator", "swig::SwigPyIterator *", 0, 0, (void*)0, 0};
static swig_type_info _swigt__p_unsigned_char = {"_p_unsigned_char", "unsigned char *|pj_uint8_t *", 0, 0, (void*)0, 0};
static swig_type_info _swigt__p_unsigned_int = {"_p_unsigned_int", "pj_uint32_t *|unsigned int *", 0, 0, (void*)0, 0};
static swig_type_info _swigt__p_unsigned_short = {"_p_unsigned_short", "unsigned short *|pj_uint16_t *", 0, 0, (void*)0, 0};
static swig_type_info _swigt__p_value_type = {"_p_value_type", "value_type *", 0, 0, (void*)0, 0};
static swig_type_info _swigt__p_void = {"_p_void", "pj::MediaStream|pj::MediaPort|pj::MediaTransport|pj::TransportHandle|pj::Token|void *|pj::TimerEntry|pj::GenericData", 0, 0, (void*)0, 0};

static swig_type_info *swig_type_initial[] = {
  &_swigt__p_allocator_type,
  &_swigt__p_char,
  &_swigt__p_difference_type,
  &_swigt__p_int,
  &_swigt__p_key_type,
  &_swigt__p_mapped_type,
  &_swigt__p_p_PyObject,
  &_swigt__p_p_void,
  &_swigt__p_pj__Account,
  &_swigt__p_pj__AccountCallConfig,
  &_swigt__p_pj__AccountConfig,
  &_swigt__p_pj__AccountInfo,
  &_swigt__p_pj__AccountIpChangeConfig,
  &_swigt__p_pj__AccountMediaConfig,
  &_swigt__p_pj__AccountMwiConfig,
  &_swigt__p_pj__AccountNatConfig,
  &_swigt__p_pj__AccountPresConfig,
  &_swigt__p_pj__AccountRegConfig,
  &_swigt__p_pj__AccountSipConfig,
  &_swigt__p_pj__AccountVideoConfig,
  &_swigt__p_pj__AudDevErrorEvent,
  &_swigt__p_pj__AudDevManager,
  &_swigt__p_pj__AudioDevInfo,
  &_swigt__p_pj__AudioMedia,
  &_swigt__p_pj__AudioMediaPlayer,
  &_swigt__p_pj__AudioMediaPlayerInfo,
  &_swigt__p_pj__AudioMediaRecorder,
  &_swigt__p_pj__AudioMediaTransmitParam,
  &_swigt__p_pj__AuthCredInfo,
  &_swigt__p_pj__Buddy,
  &_swigt__p_pj__BuddyConfig,
  &_swigt__p_pj__BuddyInfo,
  &_swigt__p_pj__Call,
  &_swigt__p_pj__CallInfo,
  &_swigt__p_pj__CallMediaInfo,
  &_swigt__p_pj__CallOpParam,
  &_swigt__p_pj__CallSendDtmfParam,
  &_swigt__p_pj__CallSendRequestParam,
  &_swigt__p_pj__CallSetting,
  &_swigt__p_pj__CallVidSetStreamParam,
  &_swigt__p_pj__CodecFmtp,
  &_swigt__p_pj__CodecInfo,
  &_swigt__p_pj__CodecOpusConfig,
  &_swigt__p_pj__CodecParam,
  &_swigt__p_pj__CodecParamInfo,
  &_swigt__p_pj__CodecParamSetting,
  &_swigt__p_pj__ConfPortInfo,
  &_swigt__p_pj__ContainerNode,
  &_swigt__p_pj__DigestChallenge,
  &_swigt__p_pj__DigestCredential,
  &_swigt__p_pj__Endpoint,
  &_swigt__p_pj__EpConfig,
  &_swigt__p_pj__Error,
  &_swigt__p_pj__ExtraAudioDevice,
  &_swigt__p_pj__FindBuddyMatch,
  &_swigt__p_pj__IpChangeParam,
  &_swigt__p_pj__JbufState,
  &_swigt__p_pj__JsonDocument,
  &_swigt__p_pj__LogConfig,
  &_swigt__p_pj__LogEntry,
  &_swigt__p_pj__LogWriter,
  &_swigt__p_pj__LossType,
  &_swigt__p_pj__MathStat,
  &_swigt__p_pj__Media,
  &_swigt__p_pj__MediaConfig,
  &_swigt__p_pj__MediaCoordinate,
  &_swigt__p_pj__MediaEvent,
  &_swigt__p_pj__MediaEventData,
  &_swigt__p_pj__MediaFmtChangedEvent,
  &_swigt__p_pj__MediaFormat,
  &_swigt__p_pj__MediaFormatAudio,
  &_swigt__p_pj__MediaFormatVideo,
  &_swigt__p_pj__MediaSize,
  &_swigt__p_pj__MediaTransportInfo,
  &_swigt__p_pj__OnBuddyEvSubStateParam,
  &_swigt__p_pj__OnCallMediaEventParam,
  &_swigt__p_pj__OnCallMediaStateParam,
  &_swigt__p_pj__OnCallMediaTransportStateParam,
  &_swigt__p_pj__OnCallRedirectedParam,
  &_swigt__p_pj__OnCallReplaceRequestParam,
  &_swigt__p_pj__OnCallReplacedParam,
  &_swigt__p_pj__OnCallRxOfferParam,
  &_swigt__p_pj__OnCallRxReinviteParam,
  &_swigt__p_pj__OnCallSdpCreatedParam,
  &_swigt__p_pj__OnCallStateParam,
  &_swigt__p_pj__OnCallTransferRequestParam,
  &_swigt__p_pj__OnCallTransferStatusParam,
  &_swigt__p_pj__OnCallTsxStateParam,
  &_swigt__p_pj__OnCallTxOfferParam,
  &_swigt__p_pj__OnCreateMediaTransportParam,
  &_swigt__p_pj__OnCreateMediaTransportSrtpParam,
  &_swigt__p_pj__OnCredAuthParam,
  &_swigt__p_pj__OnDtmfDigitParam,
  &_swigt__p_pj__OnDtmfEventParam,
  &_swigt__p_pj__OnIncomingCallParam,
  &_swigt__p_pj__OnIncomingSubscribeParam,
  &_swigt__p_pj__OnInstantMessageParam,
  &_swigt__p_pj__OnInstantMessageStatusParam,
  &_swigt__p_pj__OnIpChangeProgressParam,
  &_swigt__p_pj__OnMediaEventParam,
  &_swigt__p_pj__OnMwiInfoParam,
  &_swigt__p_pj__OnNatCheckStunServersCompleteParam,
  &_swigt__p_pj__OnNatDetectionCompleteParam,
  &_swigt__p_pj__OnRegStartedParam,
  &_swigt__p_pj__OnRegStateParam,
  &_swigt__p_pj__OnSelectAccountParam,
  &_swigt__p_pj__OnStreamCreatedParam,
  &_swigt__p_pj__OnStreamDestroyedParam,
  &_swigt__p_pj__OnStreamPreCreateParam,
  &_swigt__p_pj__OnTimerParam,
  &_swigt__p_pj__OnTransportStateParam,
  &_swigt__p_pj__OnTypingIndicationParam,
  &_swigt__p_pj__PendingJob,
  &_swigt__p_pj__PersistentDocument,
  &_swigt__p_pj__PersistentObject,
  &_swigt__p_pj__PresNotifyParam,
  &_swigt__p_pj__PresenceStatus,
  &_swigt__p_pj__RegProgressParam,
  &_swigt__p_pj__RtcpFbCap,
  &_swigt__p_pj__RtcpFbConfig,
  &_swigt__p_pj__RtcpSdes,
  &_swigt__p_pj__RtcpStat,
  &_swigt__p_pj__RtcpStreamStat,
  &_swigt__p_pj__RxMsgEvent,
  &_swigt__p_pj__SdpSession,
  &_swigt__p_pj__SendInstantMessageParam,
  &_swigt__p_pj__SendTypingIndicationParam,
  &_swigt__p_pj__SipEvent,
  &_swigt__p_pj__SipEventBody,
  &_swigt__p_pj__SipHeader,
  &_swigt__p_pj__SipMediaType,
  &_swigt__p_pj__SipMultipartPart,
  &_swigt__p_pj__SipRxData,
  &_swigt__p_pj__SipTransaction,
  &_swigt__p_pj__SipTxData,
  &_swigt__p_pj__SipTxOption,
  &_swigt__p_pj__SrtpCrypto,
  &_swigt__p_pj__SrtpOpt,
  &_swigt__p_pj__SslCertInfo,
  &_swigt__p_pj__SslCertName,
  &_swigt__p_pj__StreamInfo,
  &_swigt__p_pj__StreamStat,
  &_swigt__p_pj__TimeVal,
  &_swigt__p_pj__TimerEvent,
  &_swigt__p_pj__TlsConfig,
  &_swigt__p_pj__TlsInfo,
  &_swigt__p_pj__ToneDesc,
  &_swigt__p_pj__ToneDigit,
  &_swigt__p_pj__ToneDigitMapDigit,
  &_swigt__p_pj__ToneGenerator,
  &_swigt__p_pj__TransportConfig,
  &_swigt__p_pj__TransportInfo,
  &_swigt__p_pj__TsxStateEvent,
  &_swigt__p_pj__TsxStateEventSrc,
  &_swigt__p_pj__TxErrorEvent,
  &_swigt__p_pj__TxMsgEvent,
  &_swigt__p_pj__UaConfig,
  &_swigt__p_pj__UserEvent,
  &_swigt__p_pj__Version,
  &_swigt__p_pj__VidCodecParam,
  &_swigt__p_pj__VidConfPortInfo,
  &_swigt__p_pj__VidDevManager,
  &_swigt__p_pj__VideoDevInfo,
  &_swigt__p_pj__VideoMedia,
  &_swigt__p_pj__VideoMediaTransmitParam,
  &_swigt__p_pj__VideoPreview,
  &_swigt__p_pj__VideoPreviewOpParam,
  &_swigt__p_pj__VideoSwitchParam,
  &_swigt__p_pj__VideoWindow,
  &_swigt__p_pj__VideoWindowHandle,
  &_swigt__p_pj__VideoWindowInfo,
  &_swigt__p_pj__WindowHandle,
  &_swigt__p_pj_ice_sess_trickle,
  &_swigt__p_pj_qos_flag,
  &_swigt__p_pj_qos_params,
  &_swigt__p_pj_qos_type,
  &_swigt__p_pj_qos_wmm_prio,
  &_swigt__p_pj_ssl_cert_name_type,
  &_swigt__p_pj_ssl_cert_verify_flag_t,
  &_swigt__p_pj_ssl_cipher,
  &_swigt__p_pj_ssl_sock_proto,
  &_swigt__p_pj_stun_nat_type,
  &_swigt__p_pj_turn_tp_type,
  &_swigt__p_pjmedia_aud_dev_cap,
  &_swigt__p_pjmedia_aud_dev_route,
  &_swigt__p_pjmedia_dir,
  &_swigt__p_pjmedia_echo_flag,
  &_swigt__p_pjmedia_event_type,
  &_swigt__p_pjmedia_format_id,
  &_swigt__p_pjmedia_jb_discard_algo,
  &_swigt__p_pjmedia_orient,
  &_swigt__p_pjmedia_rtcp_fb_type,
  &_swigt__p_pjmedia_srtp_crypto_option,
  &_swigt__p_pjmedia_srtp_keying_method,
  &_swigt__p_pjmedia_srtp_use,
  &_swigt__p_pjmedia_tone_desc,
  &_swigt__p_pjmedia_tone_digit,
  &_swigt__p_pjmedia_tone_digit_map,
  &_swigt__p_pjmedia_tp_proto,
  &_swigt__p_pjmedia_type,
  &_swigt__p_pjmedia_vid_dev_cap,
  &_swigt__p_pjmedia_vid_dev_fullscreen_flag,
  &_swigt__p_pjmedia_vid_dev_hwnd_type,
  &_swigt__p_pjmedia_vid_packing,
  &_swigt__p_pjmedia_vid_stream_rc_method,
  &_swigt__p_pjrpid_activity,
  &_swigt__p_pjsip_cred_data_type,
  &_swigt__p_pjsip_dialog_cap_status,
  &_swigt__p_pjsip_event_id_e,
  &_swigt__p_pjsip_evsub_state,
  &_swigt__p_pjsip_hdr_e,
  &_swigt__p_pjsip_inv_state,
  &_swigt__p_pjsip_redirect_op,
  &_swigt__p_pjsip_role_e,
  &_swigt__p_pjsip_ssl_method,
  &_swigt__p_pjsip_status_code,
  &_swigt__p_pjsip_transport_state,
  &_swigt__p_pjsip_transport_type_e,
  &_swigt__p_pjsip_tsx_state_e,
  &_swigt__p_pjsua_100rel_use,
  &_swigt__p_pjsua_buddy_status,
  &_swigt__p_pjsua_call_flag,
  &_swigt__p_pjsua_call_hold_type,
  &_swigt__p_pjsua_call_media_status,
  &_swigt__p_pjsua_call_vid_strm_op,
  &_swigt__p_pjsua_create_media_transport_flag,
  &_swigt__p_pjsua_destroy_flag,
  &_swigt__p_pjsua_dtmf_method,
  &_swigt__p_pjsua_ip_change_op,
  &_swigt__p_pjsua_ipv6_use,
  &_swigt__p_pjsua_med_tp_st,
  &_swigt__p_pjsua_nat64_opt,
  &_swigt__p_pjsua_sip_timer_use,
  &_swigt__p_pjsua_snd_dev_id,
  &_swigt__p_pjsua_snd_dev_mode,
  &_swigt__p_pjsua_state,
  &_swigt__p_pjsua_stun_use,
  &_swigt__p_pjsua_vid_req_keyframe_method,
  &_swigt__p_size_type,
  &_swigt__p_std__allocatorT_int_t,
  &_swigt__p_std__allocatorT_pj__AudioDevInfo_p_t,
  &_swigt__p_std__allocatorT_pj__AudioDevInfo_t,
  &_swigt__p_std__allocatorT_pj__AudioMedia_p_t,
  &_swigt__p_std__allocatorT_pj__AudioMedia_t,
  &_swigt__p_std__allocatorT_pj__AuthCredInfo_t,
  &_swigt__p_std__allocatorT_pj__Buddy_p_t,
  &_swigt__p_std__allocatorT_pj__Buddy_t,
  &_swigt__p_std__allocatorT_pj__CallMediaInfo_t,
  &_swigt__p_std__allocatorT_pj__CodecFmtp_t,
  &_swigt__p_std__allocatorT_pj__CodecInfo_p_t,
  &_swigt__p_std__allocatorT_pj__CodecInfo_t,
  &_swigt__p_std__allocatorT_pj__MediaFormatAudio_t,
  &_swigt__p_std__allocatorT_pj__MediaFormatVideo_t,
  &_swigt__p_std__allocatorT_pj__RtcpFbCap_t,
  &_swigt__p_std__allocatorT_pj__SipHeader_t,
  &_swigt__p_std__allocatorT_pj__SipMultipartPart_t,
  &_swigt__p_std__allocatorT_pj__SrtpCrypto_t,
  &_swigt__p_std__allocatorT_pj__SslCertName_t,
  &_swigt__p_std__allocatorT_pj__ToneDesc_t,
  &_swigt__p_std__allocatorT_pj__ToneDigitMapDigit_t,
  &_swigt__p_std__allocatorT_pj__ToneDigit_t,
  &_swigt__p_std__allocatorT_pj__VideoDevInfo_p_t,
  &_swigt__p_std__allocatorT_pj__VideoDevInfo_t,
  &_swigt__p_std__allocatorT_pj__VideoMedia_t,
  &_swigt__p_std__allocatorT_std__pairT_std__string_const_std__string_t_t,
  &_swigt__p_std__allocatorT_std__string_t,
  &_swigt__p_std__invalid_argument,
  &_swigt__p_std__lessT_std__string_t,
  &_swigt__p_std__mapT_std__string_std__string_std__lessT_std__string_t_std__allocatorT_std__pairT_std__string_const_std__string_t_t_t,
  &_swigt__p_std__string,
  &_swigt__p_std__vectorT_int_std__allocatorT_int_t_t,
  &_swigt__p_std__vectorT_pj__AudioDevInfo_p_std__allocatorT_pj__AudioDevInfo_p_t_t,
  &_swigt__p_std__vectorT_pj__AudioDevInfo_std__allocatorT_pj__AudioDevInfo_t_t,
  &_swigt__p_std__vectorT_pj__AudioMedia_p_std__allocatorT_pj__AudioMedia_p_t_t,
  &_swigt__p_std__vectorT_pj__AudioMedia_std__allocatorT_pj__AudioMedia_t_t,
  &_swigt__p_std__vectorT_pj__AuthCredInfo_std__allocatorT_pj__AuthCredInfo_t_t,
  &_swigt__p_std__vectorT_pj__Buddy_p_std__allocatorT_pj__Buddy_p_t_t,
  &_swigt__p_std__vectorT_pj__Buddy_std__allocatorT_pj__Buddy_t_t,
  &_swigt__p_std__vectorT_pj__CallMediaInfo_std__allocatorT_pj__CallMediaInfo_t_t,
  &_swigt__p_std__vectorT_pj__CodecFmtp_std__allocatorT_pj__CodecFmtp_t_t,
  &_swigt__p_std__vectorT_pj__CodecInfo_p_std__allocatorT_pj__CodecInfo_p_t_t,
  &_swigt__p_std__vectorT_pj__CodecInfo_std__allocatorT_pj__CodecInfo_t_t,
  &_swigt__p_std__vectorT_pj__MediaFormatAudio_std__allocatorT_pj__MediaFormatAudio_t_t,
  &_swigt__p_std__vectorT_pj__MediaFormatVideo_std__allocatorT_pj__MediaFormatVideo_t_t,
  &_swigt__p_std__vectorT_pj__RtcpFbCap_std__allocatorT_pj__RtcpFbCap_t_t,
  &_swigt__p_std__vectorT_pj__SipHeader_std__allocatorT_pj__SipHeader_t_t,
  &_swigt__p_std__vectorT_pj__SipMultipartPart_std__allocatorT_pj__SipMultipartPart_t_t,
  &_swigt__p_std__vectorT_pj__SrtpCrypto_std__allocatorT_pj__SrtpCrypto_t_t,
  &_swigt__p_std__vectorT_pj__SslCertName_std__allocatorT_pj__SslCertName_t_t,
  &_swigt__p_std__vectorT_pj__ToneDesc_std__allocatorT_pj__ToneDesc_t_t,
  &_swigt__p_std__vectorT_pj__ToneDigitMapDigit_std__allocatorT_pj__ToneDigitMapDigit_t_t,
  &_swigt__p_std__vectorT_pj__ToneDigit_std__allocatorT_pj__ToneDigit_t_t,
  &_swigt__p_std__vectorT_pj__VideoDevInfo_p_std__allocatorT_pj__VideoDevInfo_p_t_t,
  &_swigt__p_std__vectorT_pj__VideoDevInfo_std__allocatorT_pj__VideoDevInfo_t_t,
  &_swigt__p_std__vectorT_pj__VideoMedia_std__allocatorT_pj__VideoMedia_t_t,
  &_swigt__p_std__vectorT_std__string_std__allocatorT_std__string_t_t,
  &_swigt__p_swig__SwigPyIterator,
  &_swigt__p_unsigned_char,
  &_swigt__p_unsigned_int,
  &_swigt__p_unsigned_short,
  &_swigt__p_value_type,
  &_swigt__p_void,
};

static swig_cast_info _swigc__p_allocator_type[] = {  {&_swigt__p_allocator_type, 0, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p_char[] = {  {&_swigt__p_char, 0, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p_difference_type[] = {  {&_swigt__p_difference_type, 0, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p_int[] = {  {&_swigt__p_int, 0, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p_key_type[] = {  {&_swigt__p_key_type, 0, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p_mapped_type[] = {  {&_swigt__p_mapped_type, 0, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p_p_PyObject[] = {  {&_swigt__p_p_PyObject, 0, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p_p_void[] = {  {&_swigt__p_p_void, 0, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p_pj__Account[] = {  {&_swigt__p_pj__Account, 0, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p_pj__AccountCallConfig[] = {  {&_swigt__p_pj__AccountCallConfig, 0, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p_pj__AccountConfig[] = {  {&_swigt__p_pj__AccountConfig, 0, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p_pj__AccountInfo[] = {  {&_swigt__p_pj__AccountInfo, 0, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p_pj__AccountIpChangeConfig[] = {  {&_swigt__p_pj__AccountIpChangeConfig, 0, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p_pj__AccountMediaConfig[] = {  {&_swigt__p_pj__AccountMediaConfig, 0, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p_pj__AccountMwiConfig[] = {  {&_swigt__p_pj__AccountMwiConfig, 0, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p_pj__AccountNatConfig[] = {  {&_swigt__p_pj__AccountNatConfig, 0, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p_pj__AccountPresConfig[] = {  {&_swigt__p_pj__AccountPresConfig, 0, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p_pj__AccountRegConfig[] = {  {&_swigt__p_pj__AccountRegConfig, 0, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p_pj__AccountSipConfig[] = {  {&_swigt__p_pj__AccountSipConfig, 0, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p_pj__AccountVideoConfig[] = {  {&_swigt__p_pj__AccountVideoConfig, 0, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p_pj__AudDevErrorEvent[] = {  {&_swigt__p_pj__AudDevErrorEvent, 0, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p_pj__AudDevManager[] = {  {&_swigt__p_pj__AudDevManager, 0, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p_pj__AudioDevInfo[] = {  {&_swigt__p_pj__AudioDevInfo, 0, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p_pj__AudioMedia[] = {  {&_swigt__p_pj__AudioMedia, 0, 0, 0},  {&_swigt__p_pj__AudioMediaRecorder, _p_pj__AudioMediaRecorderTo_p_pj__AudioMedia, 0, 0},  {&_swigt__p_pj__ToneGenerator, _p_pj__ToneGeneratorTo_p_pj__AudioMedia, 0, 0},  {&_swigt__p_pj__AudioMediaPlayer, _p_pj__AudioMediaPlayerTo_p_pj__AudioMedia, 0, 0},  {&_swigt__p_pj__ExtraAudioDevice, _p_pj__ExtraAudioDeviceTo_p_pj__AudioMedia, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p_pj__AudioMediaPlayer[] = {  {&_swigt__p_pj__AudioMediaPlayer, 0, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p_pj__AudioMediaPlayerInfo[] = {  {&_swigt__p_pj__AudioMediaPlayerInfo, 0, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p_pj__AudioMediaRecorder[] = {  {&_swigt__p_pj__AudioMediaRecorder, 0, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p_pj__AudioMediaTransmitParam[] = {  {&_swigt__p_pj__AudioMediaTransmitParam, 0, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p_pj__AuthCredInfo[] = {  {&_swigt__p_pj__AuthCredInfo, 0, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p_pj__Buddy[] = {  {&_swigt__p_pj__Buddy, 0, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p_pj__BuddyConfig[] = {  {&_swigt__p_pj__BuddyConfig, 0, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p_pj__BuddyInfo[] = {  {&_swigt__p_pj__BuddyInfo, 0, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p_pj__Call[] = {  {&_swigt__p_pj__Call, 0, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p_pj__CallInfo[] = {  {&_swigt__p_pj__CallInfo, 0, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p_pj__CallMediaInfo[] = {  {&_swigt__p_pj__CallMediaInfo, 0, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p_pj__CallOpParam[] = {  {&_swigt__p_pj__CallOpParam, 0, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p_pj__CallSendDtmfParam[] = {  {&_swigt__p_pj__CallSendDtmfParam, 0, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p_pj__CallSendRequestParam[] = {  {&_swigt__p_pj__CallSendRequestParam, 0, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p_pj__CallSetting[] = {  {&_swigt__p_pj__CallSetting, 0, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p_pj__CallVidSetStreamParam[] = {  {&_swigt__p_pj__CallVidSetStreamParam, 0, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p_pj__CodecFmtp[] = {  {&_swigt__p_pj__CodecFmtp, 0, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p_pj__CodecInfo[] = {  {&_swigt__p_pj__CodecInfo, 0, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p_pj__CodecOpusConfig[] = {  {&_swigt__p_pj__CodecOpusConfig, 0, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p_pj__CodecParam[] = {  {&_swigt__p_pj__CodecParam, 0, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p_pj__CodecParamInfo[] = {  {&_swigt__p_pj__CodecParamInfo, 0, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p_pj__CodecParamSetting[] = {  {&_swigt__p_pj__CodecParamSetting, 0, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p_pj__ConfPortInfo[] = {  {&_swigt__p_pj__ConfPortInfo, 0, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p_pj__ContainerNode[] = {  {&_swigt__p_pj__ContainerNode, 0, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p_pj__DigestChallenge[] = {  {&_swigt__p_pj__DigestChallenge, 0, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p_pj__DigestCredential[] = {  {&_swigt__p_pj__DigestCredential, 0, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p_pj__Endpoint[] = {  {&_swigt__p_pj__Endpoint, 0, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p_pj__EpConfig[] = {  {&_swigt__p_pj__EpConfig, 0, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p_pj__Error[] = {  {&_swigt__p_pj__Error, 0, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p_pj__ExtraAudioDevice[] = {  {&_swigt__p_pj__ExtraAudioDevice, 0, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p_pj__FindBuddyMatch[] = {  {&_swigt__p_pj__FindBuddyMatch, 0, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p_pj__IpChangeParam[] = {  {&_swigt__p_pj__IpChangeParam, 0, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p_pj__JbufState[] = {  {&_swigt__p_pj__JbufState, 0, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p_pj__JsonDocument[] = {  {&_swigt__p_pj__JsonDocument, 0, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p_pj__LogConfig[] = {  {&_swigt__p_pj__LogConfig, 0, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p_pj__LogEntry[] = {  {&_swigt__p_pj__LogEntry, 0, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p_pj__LogWriter[] = {  {&_swigt__p_pj__LogWriter, 0, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p_pj__LossType[] = {  {&_swigt__p_pj__LossType, 0, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p_pj__MathStat[] = {  {&_swigt__p_pj__MathStat, 0, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p_pj__Media[] = {  {&_swigt__p_pj__AudioMedia, _p_pj__AudioMediaTo_p_pj__Media, 0, 0},  {&_swigt__p_pj__AudioMediaRecorder, _p_pj__AudioMediaRecorderTo_p_pj__Media, 0, 0},  {&_swigt__p_pj__VideoMedia, _p_pj__VideoMediaTo_p_pj__Media, 0, 0},  {&_swigt__p_pj__ToneGenerator, _p_pj__ToneGeneratorTo_p_pj__Media, 0, 0},  {&_swigt__p_pj__Media, 0, 0, 0},  {&_swigt__p_pj__AudioMediaPlayer, _p_pj__AudioMediaPlayerTo_p_pj__Media, 0, 0},  {&_swigt__p_pj__ExtraAudioDevice, _p_pj__ExtraAudioDeviceTo_p_pj__Media, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p_pj__MediaConfig[] = {  {&_swigt__p_pj__MediaConfig, 0, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p_pj__MediaCoordinate[] = {  {&_swigt__p_pj__MediaCoordinate, 0, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p_pj__MediaEvent[] = {  {&_swigt__p_pj__MediaEvent, 0, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p_pj__MediaEventData[] = {  {&_swigt__p_pj__MediaEventData, 0, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p_pj__MediaFmtChangedEvent[] = {  {&_swigt__p_pj__MediaFmtChangedEvent, 0, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p_pj__MediaFormat[] = {  {&_swigt__p_pj__MediaFormatAudio, _p_pj__MediaFormatAudioTo_p_pj__MediaFormat, 0, 0},  {&_swigt__p_pj__MediaFormatVideo, _p_pj__MediaFormatVideoTo_p_pj__MediaFormat, 0, 0},  {&_swigt__p_pj__MediaFormat, 0, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p_pj__MediaFormatAudio[] = {  {&_swigt__p_pj__MediaFormatAudio, 0, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p_pj__MediaFormatVideo[] = {  {&_swigt__p_pj__MediaFormatVideo, 0, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p_pj__MediaSize[] = {  {&_swigt__p_pj__MediaSize, 0, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p_pj__MediaTransportInfo[] = {  {&_swigt__p_pj__MediaTransportInfo, 0, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p_pj__OnBuddyEvSubStateParam[] = {  {&_swigt__p_pj__OnBuddyEvSubStateParam, 0, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p_pj__OnCallMediaEventParam[] = {  {&_swigt__p_pj__OnCallMediaEventParam, 0, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p_pj__OnCallMediaStateParam[] = {  {&_swigt__p_pj__OnCallMediaStateParam, 0, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p_pj__OnCallMediaTransportStateParam[] = {  {&_swigt__p_pj__OnCallMediaTransportStateParam, 0, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p_pj__OnCallRedirectedParam[] = {  {&_swigt__p_pj__OnCallRedirectedParam, 0, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p_pj__OnCallReplaceRequestParam[] = {  {&_swigt__p_pj__OnCallReplaceRequestParam, 0, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p_pj__OnCallReplacedParam[] = {  {&_swigt__p_pj__OnCallReplacedParam, 0, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p_pj__OnCallRxOfferParam[] = {  {&_swigt__p_pj__OnCallRxOfferParam, 0, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p_pj__OnCallRxReinviteParam[] = {  {&_swigt__p_pj__OnCallRxReinviteParam, 0, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p_pj__OnCallSdpCreatedParam[] = {  {&_swigt__p_pj__OnCallSdpCreatedParam, 0, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p_pj__OnCallStateParam[] = {  {&_swigt__p_pj__OnCallStateParam, 0, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p_pj__OnCallTransferRequestParam[] = {  {&_swigt__p_pj__OnCallTransferRequestParam, 0, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p_pj__OnCallTransferStatusParam[] = {  {&_swigt__p_pj__OnCallTransferStatusParam, 0, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p_pj__OnCallTsxStateParam[] = {  {&_swigt__p_pj__OnCallTsxStateParam, 0, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p_pj__OnCallTxOfferParam[] = {  {&_swigt__p_pj__OnCallTxOfferParam, 0, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p_pj__OnCreateMediaTransportParam[] = {  {&_swigt__p_pj__OnCreateMediaTransportParam, 0, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p_pj__OnCreateMediaTransportSrtpParam[] = {  {&_swigt__p_pj__OnCreateMediaTransportSrtpParam, 0, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p_pj__OnCredAuthParam[] = {  {&_swigt__p_pj__OnCredAuthParam, 0, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p_pj__OnDtmfDigitParam[] = {  {&_swigt__p_pj__OnDtmfDigitParam, 0, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p_pj__OnDtmfEventParam[] = {  {&_swigt__p_pj__OnDtmfEventParam, 0, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p_pj__OnIncomingCallParam[] = {  {&_swigt__p_pj__OnIncomingCallParam, 0, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p_pj__OnIncomingSubscribeParam[] = {  {&_swigt__p_pj__OnIncomingSubscribeParam, 0, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p_pj__OnInstantMessageParam[] = {  {&_swigt__p_pj__OnInstantMessageParam, 0, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p_pj__OnInstantMessageStatusParam[] = {  {&_swigt__p_pj__OnInstantMessageStatusParam, 0, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p_pj__OnIpChangeProgressParam[] = {  {&_swigt__p_pj__OnIpChangeProgressParam, 0, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p_pj__OnMediaEventParam[] = {  {&_swigt__p_pj__OnMediaEventParam, 0, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p_pj__OnMwiInfoParam[] = {  {&_swigt__p_pj__OnMwiInfoParam, 0, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p_pj__OnNatCheckStunServersCompleteParam[] = {  {&_swigt__p_pj__OnNatCheckStunServersCompleteParam, 0, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p_pj__OnNatDetectionCompleteParam[] = {  {&_swigt__p_pj__OnNatDetectionCompleteParam, 0, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p_pj__OnRegStartedParam[] = {  {&_swigt__p_pj__OnRegStartedParam, 0, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p_pj__OnRegStateParam[] = {  {&_swigt__p_pj__OnRegStateParam, 0, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p_pj__OnSelectAccountParam[] = {  {&_swigt__p_pj__OnSelectAccountParam, 0, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p_pj__OnStreamCreatedParam[] = {  {&_swigt__p_pj__OnStreamCreatedParam, 0, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p_pj__OnStreamDestroyedParam[] = {  {&_swigt__p_pj__OnStreamDestroyedParam, 0, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p_pj__OnStreamPreCreateParam[] = {  {&_swigt__p_pj__OnStreamPreCreateParam, 0, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p_pj__OnTimerParam[] = {  {&_swigt__p_pj__OnTimerParam, 0, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p_pj__OnTransportStateParam[] = {  {&_swigt__p_pj__OnTransportStateParam, 0, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p_pj__OnTypingIndicationParam[] = {  {&_swigt__p_pj__OnTypingIndicationParam, 0, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p_pj__PendingJob[] = {  {&_swigt__p_pj__PendingJob, 0, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p_pj__PersistentDocument[] = {  {&_swigt__p_pj__PersistentDocument, 0, 0, 0},  {&_swigt__p_pj__JsonDocument, _p_pj__JsonDocumentTo_p_pj__PersistentDocument, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p_pj__PersistentObject[] = {  {&_swigt__p_pj__PersistentObject, 0, 0, 0},  {&_swigt__p_pj__AuthCredInfo, _p_pj__AuthCredInfoTo_p_pj__PersistentObject, 0, 0},  {&_swigt__p_pj__AccountVideoConfig, _p_pj__AccountVideoConfigTo_p_pj__PersistentObject, 0, 0},  {&_swigt__p_pj__AccountMediaConfig, _p_pj__AccountMediaConfigTo_p_pj__PersistentObject, 0, 0},  {&_swigt__p_pj__AccountMwiConfig, _p_pj__AccountMwiConfigTo_p_pj__PersistentObject, 0, 0},  {&_swigt__p_pj__AccountPresConfig, _p_pj__AccountPresConfigTo_p_pj__PersistentObject, 0, 0},  {&_swigt__p_pj__AccountRegConfig, _p_pj__AccountRegConfigTo_p_pj__PersistentObject, 0, 0},  {&_swigt__p_pj__BuddyConfig, _p_pj__BuddyConfigTo_p_pj__PersistentObject, 0, 0},  {&_swigt__p_pj__TlsConfig, _p_pj__TlsConfigTo_p_pj__PersistentObject, 0, 0},  {&_swigt__p_pj__UaConfig, _p_pj__UaConfigTo_p_pj__PersistentObject, 0, 0},  {&_swigt__p_pj__LogConfig, _p_pj__LogConfigTo_p_pj__PersistentObject, 0, 0},  {&_swigt__p_pj__MediaConfig, _p_pj__MediaConfigTo_p_pj__PersistentObject, 0, 0},  {&_swigt__p_pj__RtcpFbConfig, _p_pj__RtcpFbConfigTo_p_pj__PersistentObject, 0, 0},  {&_swigt__p_pj__AccountNatConfig, _p_pj__AccountNatConfigTo_p_pj__PersistentObject, 0, 0},  {&_swigt__p_pj__AccountCallConfig, _p_pj__AccountCallConfigTo_p_pj__PersistentObject, 0, 0},  {&_swigt__p_pj__AccountSipConfig, _p_pj__AccountSipConfigTo_p_pj__PersistentObject, 0, 0},  {&_swigt__p_pj__TransportConfig, _p_pj__TransportConfigTo_p_pj__PersistentObject, 0, 0},  {&_swigt__p_pj__AccountConfig, _p_pj__AccountConfigTo_p_pj__PersistentObject, 0, 0},  {&_swigt__p_pj__EpConfig, _p_pj__EpConfigTo_p_pj__PersistentObject, 0, 0},  {&_swigt__p_pj__SrtpOpt, _p_pj__SrtpOptTo_p_pj__PersistentObject, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p_pj__PresNotifyParam[] = {  {&_swigt__p_pj__PresNotifyParam, 0, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p_pj__PresenceStatus[] = {  {&_swigt__p_pj__PresenceStatus, 0, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p_pj__RegProgressParam[] = {  {&_swigt__p_pj__RegProgressParam, 0, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p_pj__RtcpFbCap[] = {  {&_swigt__p_pj__RtcpFbCap, 0, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p_pj__RtcpFbConfig[] = {  {&_swigt__p_pj__RtcpFbConfig, 0, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p_pj__RtcpSdes[] = {  {&_swigt__p_pj__RtcpSdes, 0, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p_pj__RtcpStat[] = {  {&_swigt__p_pj__RtcpStat, 0, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p_pj__RtcpStreamStat[] = {  {&_swigt__p_pj__RtcpStreamStat, 0, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p_pj__RxMsgEvent[] = {  {&_swigt__p_pj__RxMsgEvent, 0, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p_pj__SdpSession[] = {  {&_swigt__p_pj__SdpSession, 0, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p_pj__SendInstantMessageParam[] = {  {&_swigt__p_pj__SendInstantMessageParam, 0, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p_pj__SendTypingIndicationParam[] = {  {&_swigt__p_pj__SendTypingIndicationParam, 0, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p_pj__SipEvent[] = {  {&_swigt__p_pj__SipEvent, 0, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p_pj__SipEventBody[] = {  {&_swigt__p_pj__SipEventBody, 0, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p_pj__SipHeader[] = {  {&_swigt__p_pj__SipHeader, 0, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p_pj__SipMediaType[] = {  {&_swigt__p_pj__SipMediaType, 0, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p_pj__SipMultipartPart[] = {  {&_swigt__p_pj__SipMultipartPart, 0, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p_pj__SipRxData[] = {  {&_swigt__p_pj__SipRxData, 0, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p_pj__SipTransaction[] = {  {&_swigt__p_pj__SipTransaction, 0, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p_pj__SipTxData[] = {  {&_swigt__p_pj__SipTxData, 0, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p_pj__SipTxOption[] = {  {&_swigt__p_pj__SipTxOption, 0, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p_pj__SrtpCrypto[] = {  {&_swigt__p_pj__SrtpCrypto, 0, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p_pj__SrtpOpt[] = {  {&_swigt__p_pj__SrtpOpt, 0, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p_pj__SslCertInfo[] = {  {&_swigt__p_pj__SslCertInfo, 0, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p_pj__SslCertName[] = {  {&_swigt__p_pj__SslCertName, 0, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p_pj__StreamInfo[] = {  {&_swigt__p_pj__StreamInfo, 0, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p_pj__StreamStat[] = {  {&_swigt__p_pj__StreamStat, 0, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p_pj__TimeVal[] = {  {&_swigt__p_pj__TimeVal, 0, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p_pj__TimerEvent[] = {  {&_swigt__p_pj__TimerEvent, 0, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p_pj__TlsConfig[] = {  {&_swigt__p_pj__TlsConfig, 0, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p_pj__TlsInfo[] = {  {&_swigt__p_pj__TlsInfo, 0, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p_pj__ToneDesc[] = {  {&_swigt__p_pj__ToneDesc, 0, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p_pj__ToneDigit[] = {  {&_swigt__p_pj__ToneDigit, 0, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p_pj__ToneDigitMapDigit[] = {  {&_swigt__p_pj__ToneDigitMapDigit, 0, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p_pj__ToneGenerator[] = {  {&_swigt__p_pj__ToneGenerator, 0, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p_pj__TransportConfig[] = {  {&_swigt__p_pj__TransportConfig, 0, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p_pj__TransportInfo[] = {  {&_swigt__p_pj__TransportInfo, 0, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p_pj__TsxStateEvent[] = {  {&_swigt__p_pj__TsxStateEvent, 0, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p_pj__TsxStateEventSrc[] = {  {&_swigt__p_pj__TsxStateEventSrc, 0, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p_pj__TxErrorEvent[] = {  {&_swigt__p_pj__TxErrorEvent, 0, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p_pj__TxMsgEvent[] = {  {&_swigt__p_pj__TxMsgEvent, 0, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p_pj__UaConfig[] = {  {&_swigt__p_pj__UaConfig, 0, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p_pj__UserEvent[] = {  {&_swigt__p_pj__UserEvent, 0, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p_pj__Version[] = {  {&_swigt__p_pj__Version, 0, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p_pj__VidCodecParam[] = {  {&_swigt__p_pj__VidCodecParam, 0, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p_pj__VidConfPortInfo[] = {  {&_swigt__p_pj__VidConfPortInfo, 0, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p_pj__VidDevManager[] = {  {&_swigt__p_pj__VidDevManager, 0, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p_pj__VideoDevInfo[] = {  {&_swigt__p_pj__VideoDevInfo, 0, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p_pj__VideoMedia[] = {  {&_swigt__p_pj__VideoMedia, 0, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p_pj__VideoMediaTransmitParam[] = {  {&_swigt__p_pj__VideoMediaTransmitParam, 0, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p_pj__VideoPreview[] = {  {&_swigt__p_pj__VideoPreview, 0, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p_pj__VideoPreviewOpParam[] = {  {&_swigt__p_pj__VideoPreviewOpParam, 0, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p_pj__VideoSwitchParam[] = {  {&_swigt__p_pj__VideoSwitchParam, 0, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p_pj__VideoWindow[] = {  {&_swigt__p_pj__VideoWindow, 0, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p_pj__VideoWindowHandle[] = {  {&_swigt__p_pj__VideoWindowHandle, 0, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p_pj__VideoWindowInfo[] = {  {&_swigt__p_pj__VideoWindowInfo, 0, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p_pj__WindowHandle[] = {  {&_swigt__p_pj__WindowHandle, 0, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p_pj_ice_sess_trickle[] = {  {&_swigt__p_pj_ice_sess_trickle, 0, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p_pj_qos_flag[] = {  {&_swigt__p_pj_qos_flag, 0, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p_pj_qos_params[] = {  {&_swigt__p_pj_qos_params, 0, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p_pj_qos_type[] = {  {&_swigt__p_pj_qos_type, 0, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p_pj_qos_wmm_prio[] = {  {&_swigt__p_pj_qos_wmm_prio, 0, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p_pj_ssl_cert_name_type[] = {  {&_swigt__p_pj_ssl_cert_name_type, 0, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p_pj_ssl_cert_verify_flag_t[] = {  {&_swigt__p_pj_ssl_cert_verify_flag_t, 0, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p_pj_ssl_cipher[] = {  {&_swigt__p_pj_ssl_cipher, 0, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p_pj_ssl_sock_proto[] = {  {&_swigt__p_pj_ssl_sock_proto, 0, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p_pj_stun_nat_type[] = {  {&_swigt__p_pj_stun_nat_type, 0, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p_pj_turn_tp_type[] = {  {&_swigt__p_pj_turn_tp_type, 0, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p_pjmedia_aud_dev_cap[] = {  {&_swigt__p_pjmedia_aud_dev_cap, 0, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p_pjmedia_aud_dev_route[] = {  {&_swigt__p_pjmedia_aud_dev_route, 0, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p_pjmedia_dir[] = {  {&_swigt__p_pjmedia_dir, 0, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p_pjmedia_echo_flag[] = {  {&_swigt__p_pjmedia_echo_flag, 0, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p_pjmedia_event_type[] = {  {&_swigt__p_pjmedia_event_type, 0, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p_pjmedia_format_id[] = {  {&_swigt__p_pjmedia_format_id, 0, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p_pjmedia_jb_discard_algo[] = {  {&_swigt__p_pjmedia_jb_discard_algo, 0, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p_pjmedia_orient[] = {  {&_swigt__p_pjmedia_orient, 0, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p_pjmedia_rtcp_fb_type[] = {  {&_swigt__p_pjmedia_rtcp_fb_type, 0, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p_pjmedia_srtp_crypto_option[] = {  {&_swigt__p_pjmedia_srtp_crypto_option, 0, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p_pjmedia_srtp_keying_method[] = {  {&_swigt__p_pjmedia_srtp_keying_method, 0, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p_pjmedia_srtp_use[] = {  {&_swigt__p_pjmedia_srtp_use, 0, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p_pjmedia_tone_desc[] = {  {&_swigt__p_pj__ToneDesc, _p_pj__ToneDescTo_p_pjmedia_tone_desc, 0, 0},  {&_swigt__p_pjmedia_tone_desc, 0, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p_pjmedia_tone_digit[] = {  {&_swigt__p_pj__ToneDigit, _p_pj__ToneDigitTo_p_pjmedia_tone_digit, 0, 0},  {&_swigt__p_pjmedia_tone_digit, 0, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p_pjmedia_tone_digit_map[] = {  {&_swigt__p_pjmedia_tone_digit_map, 0, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p_pjmedia_tp_proto[] = {  {&_swigt__p_pjmedia_tp_proto, 0, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p_pjmedia_type[] = {  {&_swigt__p_pjmedia_type, 0, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p_pjmedia_vid_dev_cap[] = {  {&_swigt__p_pjmedia_vid_dev_cap, 0, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p_pjmedia_vid_dev_fullscreen_flag[] = {  {&_swigt__p_pjmedia_vid_dev_fullscreen_flag, 0, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p_pjmedia_vid_dev_hwnd_type[] = {  {&_swigt__p_pjmedia_vid_dev_hwnd_type, 0, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p_pjmedia_vid_packing[] = {  {&_swigt__p_pjmedia_vid_packing, 0, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p_pjmedia_vid_stream_rc_method[] = {  {&_swigt__p_pjmedia_vid_stream_rc_method, 0, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p_pjrpid_activity[] = {  {&_swigt__p_pjrpid_activity, 0, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p_pjsip_cred_data_type[] = {  {&_swigt__p_pjsip_cred_data_type, 0, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p_pjsip_dialog_cap_status[] = {  {&_swigt__p_pjsip_dialog_cap_status, 0, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p_pjsip_event_id_e[] = {  {&_swigt__p_pjsip_event_id_e, 0, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p_pjsip_evsub_state[] = {  {&_swigt__p_pjsip_evsub_state, 0, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p_pjsip_hdr_e[] = {  {&_swigt__p_pjsip_hdr_e, 0, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p_pjsip_inv_state[] = {  {&_swigt__p_pjsip_inv_state, 0, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p_pjsip_redirect_op[] = {  {&_swigt__p_pjsip_redirect_op, 0, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p_pjsip_role_e[] = {  {&_swigt__p_pjsip_role_e, 0, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p_pjsip_ssl_method[] = {  {&_swigt__p_pjsip_ssl_method, 0, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p_pjsip_status_code[] = {  {&_swigt__p_pjsip_status_code, 0, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p_pjsip_transport_state[] = {  {&_swigt__p_pjsip_transport_state, 0, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p_pjsip_transport_type_e[] = {  {&_swigt__p_pjsip_transport_type_e, 0, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p_pjsip_tsx_state_e[] = {  {&_swigt__p_pjsip_tsx_state_e, 0, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p_pjsua_100rel_use[] = {  {&_swigt__p_pjsua_100rel_use, 0, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p_pjsua_buddy_status[] = {  {&_swigt__p_pjsua_buddy_status, 0, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p_pjsua_call_flag[] = {  {&_swigt__p_pjsua_call_flag, 0, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p_pjsua_call_hold_type[] = {  {&_swigt__p_pjsua_call_hold_type, 0, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p_pjsua_call_media_status[] = {  {&_swigt__p_pjsua_call_media_status, 0, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p_pjsua_call_vid_strm_op[] = {  {&_swigt__p_pjsua_call_vid_strm_op, 0, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p_pjsua_create_media_transport_flag[] = {  {&_swigt__p_pjsua_create_media_transport_flag, 0, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p_pjsua_destroy_flag[] = {  {&_swigt__p_pjsua_destroy_flag, 0, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p_pjsua_dtmf_method[] = {  {&_swigt__p_pjsua_dtmf_method, 0, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p_pjsua_ip_change_op[] = {  {&_swigt__p_pjsua_ip_change_op, 0, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p_pjsua_ipv6_use[] = {  {&_swigt__p_pjsua_ipv6_use, 0, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p_pjsua_med_tp_st[] = {  {&_swigt__p_pjsua_med_tp_st, 0, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p_pjsua_nat64_opt[] = {  {&_swigt__p_pjsua_nat64_opt, 0, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p_pjsua_sip_timer_use[] = {  {&_swigt__p_pjsua_sip_timer_use, 0, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p_pjsua_snd_dev_id[] = {  {&_swigt__p_pjsua_snd_dev_id, 0, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p_pjsua_snd_dev_mode[] = {  {&_swigt__p_pjsua_snd_dev_mode, 0, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p_pjsua_state[] = {  {&_swigt__p_pjsua_state, 0, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p_pjsua_stun_use[] = {  {&_swigt__p_pjsua_stun_use, 0, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p_pjsua_vid_req_keyframe_method[] = {  {&_swigt__p_pjsua_vid_req_keyframe_method, 0, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p_size_type[] = {  {&_swigt__p_size_type, 0, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p_std__allocatorT_int_t[] = {  {&_swigt__p_std__allocatorT_int_t, 0, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p_std__allocatorT_pj__AudioDevInfo_p_t[] = {  {&_swigt__p_std__allocatorT_pj__AudioDevInfo_p_t, 0, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p_std__allocatorT_pj__AudioDevInfo_t[] = {  {&_swigt__p_std__allocatorT_pj__AudioDevInfo_t, 0, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p_std__allocatorT_pj__AudioMedia_p_t[] = {  {&_swigt__p_std__allocatorT_pj__AudioMedia_p_t, 0, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p_std__allocatorT_pj__AudioMedia_t[] = {  {&_swigt__p_std__allocatorT_pj__AudioMedia_t, 0, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p_std__allocatorT_pj__AuthCredInfo_t[] = {  {&_swigt__p_std__allocatorT_pj__AuthCredInfo_t, 0, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p_std__allocatorT_pj__Buddy_p_t[] = {  {&_swigt__p_std__allocatorT_pj__Buddy_p_t, 0, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p_std__allocatorT_pj__Buddy_t[] = {  {&_swigt__p_std__allocatorT_pj__Buddy_t, 0, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p_std__allocatorT_pj__CallMediaInfo_t[] = {  {&_swigt__p_std__allocatorT_pj__CallMediaInfo_t, 0, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p_std__allocatorT_pj__CodecFmtp_t[] = {  {&_swigt__p_std__allocatorT_pj__CodecFmtp_t, 0, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p_std__allocatorT_pj__CodecInfo_p_t[] = {  {&_swigt__p_std__allocatorT_pj__CodecInfo_p_t, 0, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p_std__allocatorT_pj__CodecInfo_t[] = {  {&_swigt__p_std__allocatorT_pj__CodecInfo_t, 0, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p_std__allocatorT_pj__MediaFormatAudio_t[] = {  {&_swigt__p_std__allocatorT_pj__MediaFormatAudio_t, 0, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p_std__allocatorT_pj__MediaFormatVideo_t[] = {  {&_swigt__p_std__allocatorT_pj__MediaFormatVideo_t, 0, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p_std__allocatorT_pj__RtcpFbCap_t[] = {  {&_swigt__p_std__allocatorT_pj__RtcpFbCap_t, 0, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p_std__allocatorT_pj__SipHeader_t[] = {  {&_swigt__p_std__allocatorT_pj__SipHeader_t, 0, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p_std__allocatorT_pj__SipMultipartPart_t[] = {  {&_swigt__p_std__allocatorT_pj__SipMultipartPart_t, 0, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p_std__allocatorT_pj__SrtpCrypto_t[] = {  {&_swigt__p_std__allocatorT_pj__SrtpCrypto_t, 0, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p_std__allocatorT_pj__SslCertName_t[] = {  {&_swigt__p_std__allocatorT_pj__SslCertName_t, 0, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p_std__allocatorT_pj__ToneDesc_t[] = {  {&_swigt__p_std__allocatorT_pj__ToneDesc_t, 0, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p_std__allocatorT_pj__ToneDigitMapDigit_t[] = {  {&_swigt__p_std__allocatorT_pj__ToneDigitMapDigit_t, 0, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p_std__allocatorT_pj__ToneDigit_t[] = {  {&_swigt__p_std__allocatorT_pj__ToneDigit_t, 0, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p_std__allocatorT_pj__VideoDevInfo_p_t[] = {  {&_swigt__p_std__allocatorT_pj__VideoDevInfo_p_t, 0, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p_std__allocatorT_pj__VideoDevInfo_t[] = {  {&_swigt__p_std__allocatorT_pj__VideoDevInfo_t, 0, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p_std__allocatorT_pj__VideoMedia_t[] = {  {&_swigt__p_std__allocatorT_pj__VideoMedia_t, 0, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p_std__allocatorT_std__pairT_std__string_const_std__string_t_t[] = {  {&_swigt__p_std__allocatorT_std__pairT_std__string_const_std__string_t_t, 0, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p_std__allocatorT_std__string_t[] = {  {&_swigt__p_std__allocatorT_std__string_t, 0, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p_std__invalid_argument[] = {  {&_swigt__p_std__invalid_argument, 0, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p_std__lessT_std__string_t[] = {  {&_swigt__p_std__lessT_std__string_t, 0, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p_std__mapT_std__string_std__string_std__lessT_std__string_t_std__allocatorT_std__pairT_std__string_const_std__string_t_t_t[] = {  {&_swigt__p_std__mapT_std__string_std__string_std__lessT_std__string_t_std__allocatorT_std__pairT_std__string_const_std__string_t_t_t, 0, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p_std__string[] = {  {&_swigt__p_std__string, 0, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p_std__vectorT_int_std__allocatorT_int_t_t[] = {  {&_swigt__p_std__vectorT_int_std__allocatorT_int_t_t, 0, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p_std__vectorT_pj__AudioDevInfo_p_std__allocatorT_pj__AudioDevInfo_p_t_t[] = {  {&_swigt__p_std__vectorT_pj__AudioDevInfo_p_std__allocatorT_pj__AudioDevInfo_p_t_t, 0, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p_std__vectorT_pj__AudioDevInfo_std__allocatorT_pj__AudioDevInfo_t_t[] = {  {&_swigt__p_std__vectorT_pj__AudioDevInfo_std__allocatorT_pj__AudioDevInfo_t_t, 0, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p_std__vectorT_pj__AudioMedia_p_std__allocatorT_pj__AudioMedia_p_t_t[] = {  {&_swigt__p_std__vectorT_pj__AudioMedia_p_std__allocatorT_pj__AudioMedia_p_t_t, 0, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p_std__vectorT_pj__AudioMedia_std__allocatorT_pj__AudioMedia_t_t[] = {  {&_swigt__p_std__vectorT_pj__AudioMedia_std__allocatorT_pj__AudioMedia_t_t, 0, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p_std__vectorT_pj__AuthCredInfo_std__allocatorT_pj__AuthCredInfo_t_t[] = {  {&_swigt__p_std__vectorT_pj__AuthCredInfo_std__allocatorT_pj__AuthCredInfo_t_t, 0, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p_std__vectorT_pj__Buddy_p_std__allocatorT_pj__Buddy_p_t_t[] = {  {&_swigt__p_std__vectorT_pj__Buddy_p_std__allocatorT_pj__Buddy_p_t_t, 0, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p_std__vectorT_pj__Buddy_std__allocatorT_pj__Buddy_t_t[] = {  {&_swigt__p_std__vectorT_pj__Buddy_std__allocatorT_pj__Buddy_t_t, 0, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p_std__vectorT_pj__CallMediaInfo_std__allocatorT_pj__CallMediaInfo_t_t[] = {  {&_swigt__p_std__vectorT_pj__CallMediaInfo_std__allocatorT_pj__CallMediaInfo_t_t, 0, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p_std__vectorT_pj__CodecFmtp_std__allocatorT_pj__CodecFmtp_t_t[] = {  {&_swigt__p_std__vectorT_pj__CodecFmtp_std__allocatorT_pj__CodecFmtp_t_t, 0, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p_std__vectorT_pj__CodecInfo_p_std__allocatorT_pj__CodecInfo_p_t_t[] = {  {&_swigt__p_std__vectorT_pj__CodecInfo_p_std__allocatorT_pj__CodecInfo_p_t_t, 0, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p_std__vectorT_pj__CodecInfo_std__allocatorT_pj__CodecInfo_t_t[] = {  {&_swigt__p_std__vectorT_pj__CodecInfo_std__allocatorT_pj__CodecInfo_t_t, 0, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p_std__vectorT_pj__MediaFormatAudio_std__allocatorT_pj__MediaFormatAudio_t_t[] = {  {&_swigt__p_std__vectorT_pj__MediaFormatAudio_std__allocatorT_pj__MediaFormatAudio_t_t, 0, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p_std__vectorT_pj__MediaFormatVideo_std__allocatorT_pj__MediaFormatVideo_t_t[] = {  {&_swigt__p_std__vectorT_pj__MediaFormatVideo_std__allocatorT_pj__MediaFormatVideo_t_t, 0, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p_std__vectorT_pj__RtcpFbCap_std__allocatorT_pj__RtcpFbCap_t_t[] = {  {&_swigt__p_std__vectorT_pj__RtcpFbCap_std__allocatorT_pj__RtcpFbCap_t_t, 0, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p_std__vectorT_pj__SipHeader_std__allocatorT_pj__SipHeader_t_t[] = {  {&_swigt__p_std__vectorT_pj__SipHeader_std__allocatorT_pj__SipHeader_t_t, 0, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p_std__vectorT_pj__SipMultipartPart_std__allocatorT_pj__SipMultipartPart_t_t[] = {  {&_swigt__p_std__vectorT_pj__SipMultipartPart_std__allocatorT_pj__SipMultipartPart_t_t, 0, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p_std__vectorT_pj__SrtpCrypto_std__allocatorT_pj__SrtpCrypto_t_t[] = {  {&_swigt__p_std__vectorT_pj__SrtpCrypto_std__allocatorT_pj__SrtpCrypto_t_t, 0, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p_std__vectorT_pj__SslCertName_std__allocatorT_pj__SslCertName_t_t[] = {  {&_swigt__p_std__vectorT_pj__SslCertName_std__allocatorT_pj__SslCertName_t_t, 0, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p_std__vectorT_pj__ToneDesc_std__allocatorT_pj__ToneDesc_t_t[] = {  {&_swigt__p_std__vectorT_pj__ToneDesc_std__allocatorT_pj__ToneDesc_t_t, 0, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p_std__vectorT_pj__ToneDigitMapDigit_std__allocatorT_pj__ToneDigitMapDigit_t_t[] = {  {&_swigt__p_std__vectorT_pj__ToneDigitMapDigit_std__allocatorT_pj__ToneDigitMapDigit_t_t, 0, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p_std__vectorT_pj__ToneDigit_std__allocatorT_pj__ToneDigit_t_t[] = {  {&_swigt__p_std__vectorT_pj__ToneDigit_std__allocatorT_pj__ToneDigit_t_t, 0, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p_std__vectorT_pj__VideoDevInfo_p_std__allocatorT_pj__VideoDevInfo_p_t_t[] = {  {&_swigt__p_std__vectorT_pj__VideoDevInfo_p_std__allocatorT_pj__VideoDevInfo_p_t_t, 0, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p_std__vectorT_pj__VideoDevInfo_std__allocatorT_pj__VideoDevInfo_t_t[] = {  {&_swigt__p_std__vectorT_pj__VideoDevInfo_std__allocatorT_pj__VideoDevInfo_t_t, 0, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p_std__vectorT_pj__VideoMedia_std__allocatorT_pj__VideoMedia_t_t[] = {  {&_swigt__p_std__vectorT_pj__VideoMedia_std__allocatorT_pj__VideoMedia_t_t, 0, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p_std__vectorT_std__string_std__allocatorT_std__string_t_t[] = {  {&_swigt__p_std__vectorT_std__string_std__allocatorT_std__string_t_t, 0, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p_swig__SwigPyIterator[] = {  {&_swigt__p_swig__SwigPyIterator, 0, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p_unsigned_char[] = {  {&_swigt__p_unsigned_char, 0, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p_unsigned_int[] = {  {&_swigt__p_unsigned_int, 0, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p_unsigned_short[] = {  {&_swigt__p_unsigned_short, 0, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p_value_type[] = {  {&_swigt__p_value_type, 0, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p_void[] = {  {&_swigt__p_void, 0, 0, 0},{0, 0, 0, 0}};

static swig_cast_info *swig_cast_initial[] = {
  _swigc__p_allocator_type,
  _swigc__p_char,
  _swigc__p_difference_type,
  _swigc__p_int,
  _swigc__p_key_type,
  _swigc__p_mapped_type,
  _swigc__p_p_PyObject,
  _swigc__p_p_void,
  _swigc__p_pj__Account,
  _swigc__p_pj__AccountCallConfig,
  _swigc__p_pj__AccountConfig,
  _swigc__p_pj__AccountInfo,
  _swigc__p_pj__AccountIpChangeConfig,
  _swigc__p_pj__AccountMediaConfig,
  _swigc__p_pj__AccountMwiConfig,
  _swigc__p_pj__AccountNatConfig,
  _swigc__p_pj__AccountPresConfig,
  _swigc__p_pj__AccountRegConfig,
  _swigc__p_pj__AccountSipConfig,
  _swigc__p_pj__AccountVideoConfig,
  _swigc__p_pj__AudDevErrorEvent,
  _swigc__p_pj__AudDevManager,
  _swigc__p_pj__AudioDevInfo,
  _swigc__p_pj__AudioMedia,
  _swigc__p_pj__AudioMediaPlayer,
  _swigc__p_pj__AudioMediaPlayerInfo,
  _swigc__p_pj__AudioMediaRecorder,
  _swigc__p_pj__AudioMediaTransmitParam,
  _swigc__p_pj__AuthCredInfo,
  _swigc__p_pj__Buddy,
  _swigc__p_pj__BuddyConfig,
  _swigc__p_pj__BuddyInfo,
  _swigc__p_pj__Call,
  _swigc__p_pj__CallInfo,
  _swigc__p_pj__CallMediaInfo,
  _swigc__p_pj__CallOpParam,
  _swigc__p_pj__CallSendDtmfParam,
  _swigc__p_pj__CallSendRequestParam,
  _swigc__p_pj__CallSetting,
  _swigc__p_pj__CallVidSetStreamParam,
  _swigc__p_pj__CodecFmtp,
  _swigc__p_pj__CodecInfo,
  _swigc__p_pj__CodecOpusConfig,
  _swigc__p_pj__CodecParam,
  _swigc__p_pj__CodecParamInfo,
  _swigc__p_pj__CodecParamSetting,
  _swigc__p_pj__ConfPortInfo,
  _swigc__p_pj__ContainerNode,
  _swigc__p_pj__DigestChallenge,
  _swigc__p_pj__DigestCredential,
  _swigc__p_pj__Endpoint,
  _swigc__p_pj__EpConfig,
  _swigc__p_pj__Error,
  _swigc__p_pj__ExtraAudioDevice,
  _swigc__p_pj__FindBuddyMatch,
  _swigc__p_pj__IpChangeParam,
  _swigc__p_pj__JbufState,
  _swigc__p_pj__JsonDocument,
  _swigc__p_pj__LogConfig,
  _swigc__p_pj__LogEntry,
  _swigc__p_pj__LogWriter,
  _swigc__p_pj__LossType,
  _swigc__p_pj__MathStat,
  _swigc__p_pj__Media,
  _swigc__p_pj__MediaConfig,
  _swigc__p_pj__MediaCoordinate,
  _swigc__p_pj__MediaEvent,
  _swigc__p_pj__MediaEventData,
  _swigc__p_pj__MediaFmtChangedEvent,
  _swigc__p_pj__MediaFormat,
  _swigc__p_pj__MediaFormatAudio,
  _swigc__p_pj__MediaFormatVideo,
  _swigc__p_pj__MediaSize,
  _swigc__p_pj__MediaTransportInfo,
  _swigc__p_pj__OnBuddyEvSubStateParam,
  _swigc__p_pj__OnCallMediaEventParam,
  _swigc__p_pj__OnCallMediaStateParam,
  _swigc__p_pj__OnCallMediaTransportStateParam,
  _swigc__p_pj__OnCallRedirectedParam,
  _swigc__p_pj__OnCallReplaceRequestParam,
  _swigc__p_pj__OnCallReplacedParam,
  _swigc__p_pj__OnCallRxOfferParam,
  _swigc__p_pj__OnCallRxReinviteParam,
  _swigc__p_pj__OnCallSdpCreatedParam,
  _swigc__p_pj__OnCallStateParam,
  _swigc__p_pj__OnCallTransferRequestParam,
  _swigc__p_pj__OnCallTransferStatusParam,
  _swigc__p_pj__OnCallTsxStateParam,
  _swigc__p_pj__OnCallTxOfferParam,
  _swigc__p_pj__OnCreateMediaTransportParam,
  _swigc__p_pj__OnCreateMediaTransportSrtpParam,
  _swigc__p_pj__OnCredAuthParam,
  _swigc__p_pj__OnDtmfDigitParam,
  _swigc__p_pj__OnDtmfEventParam,
  _swigc__p_pj__OnIncomingCallParam,
  _swigc__p_pj__OnIncomingSubscribeParam,
  _swigc__p_pj__OnInstantMessageParam,
  _swigc__p_pj__OnInstantMessageStatusParam,
  _swigc__p_pj__OnIpChangeProgressParam,
  _swigc__p_pj__OnMediaEventParam,
  _swigc__p_pj__OnMwiInfoParam,
  _swigc__p_pj__OnNatCheckStunServersCompleteParam,
  _swigc__p_pj__OnNatDetectionCompleteParam,
  _swigc__p_pj__OnRegStartedParam,
  _swigc__p_pj__OnRegStateParam,
  _swigc__p_pj__OnSelectAccountParam,
  _swigc__p_pj__OnStreamCreatedParam,
  _swigc__p_pj__OnStreamDestroyedParam,
  _swigc__p_pj__OnStreamPreCreateParam,
  _swigc__p_pj__OnTimerParam,
  _swigc__p_pj__OnTransportStateParam,
  _swigc__p_pj__OnTypingIndicationParam,
  _swigc__p_pj__PendingJob,
  _swigc__p_pj__PersistentDocument,
  _swigc__p_pj__PersistentObject,
  _swigc__p_pj__PresNotifyParam,
  _swigc__p_pj__PresenceStatus,
  _swigc__p_pj__RegProgressParam,
  _swigc__p_pj__RtcpFbCap,
  _swigc__p_pj__RtcpFbConfig,
  _swigc__p_pj__RtcpSdes,
  _swigc__p_pj__RtcpStat,
  _swigc__p_pj__RtcpStreamStat,
  _swigc__p_pj__RxMsgEvent,
  _swigc__p_pj__SdpSession,
  _swigc__p_pj__SendInstantMessageParam,
  _swigc__p_pj__SendTypingIndicationParam,
  _swigc__p_pj__SipEvent,
  _swigc__p_pj__SipEventBody,
  _swigc__p_pj__SipHeader,
  _swigc__p_pj__SipMediaType,
  _swigc__p_pj__SipMultipartPart,
  _swigc__p_pj__SipRxData,
  _swigc__p_pj__SipTransaction,
  _swigc__p_pj__SipTxData,
  _swigc__p_pj__SipTxOption,
  _swigc__p_pj__SrtpCrypto,
  _swigc__p_pj__SrtpOpt,
  _swigc__p_pj__SslCertInfo,
  _swigc__p_pj__SslCertName,
  _swigc__p_pj__StreamInfo,
  _swigc__p_pj__StreamStat,
  _swigc__p_pj__TimeVal,
  _swigc__p_pj__TimerEvent,
  _swigc__p_pj__TlsConfig,
  _swigc__p_pj__TlsInfo,
  _swigc__p_pj__ToneDesc,
  _swigc__p_pj__ToneDigit,
  _swigc__p_pj__ToneDigitMapDigit,
  _swigc__p_pj__ToneGenerator,
  _swigc__p_pj__TransportConfig,
  _swigc__p_pj__TransportInfo,
  _swigc__p_pj__TsxStateEvent,
  _swigc__p_pj__TsxStateEventSrc,
  _swigc__p_pj__TxErrorEvent,
  _swigc__p_pj__TxMsgEvent,
  _swigc__p_pj__UaConfig,
  _swigc__p_pj__UserEvent,
  _swigc__p_pj__Version,
  _swigc__p_pj__VidCodecParam,
  _swigc__p_pj__VidConfPortInfo,
  _swigc__p_pj__VidDevManager,
  _swigc__p_pj__VideoDevInfo,
  _swigc__p_pj__VideoMedia,
  _swigc__p_pj__VideoMediaTransmitParam,
  _swigc__p_pj__VideoPreview,
  _swigc__p_pj__VideoPreviewOpParam,
  _swigc__p_pj__VideoSwitchParam,
  _swigc__p_pj__VideoWindow,
  _swigc__p_pj__VideoWindowHandle,
  _swigc__p_pj__VideoWindowInfo,
  _swigc__p_pj__WindowHandle,
  _swigc__p_pj_ice_sess_trickle,
  _swigc__p_pj_qos_flag,
  _swigc__p_pj_qos_params,
  _swigc__p_pj_qos_type,
  _swigc__p_pj_qos_wmm_prio,
  _swigc__p_pj_ssl_cert_name_type,
  _swigc__p_pj_ssl_cert_verify_flag_t,
  _swigc__p_pj_ssl_cipher,
  _swigc__p_pj_ssl_sock_proto,
  _swigc__p_pj_stun_nat_type,
  _swigc__p_pj_turn_tp_type,
  _swigc__p_pjmedia_aud_dev_cap,
  _swigc__p_pjmedia_aud_dev_route,
  _swigc__p_pjmedia_dir,
  _swigc__p_pjmedia_echo_flag,
  _swigc__p_pjmedia_event_type,
  _swigc__p_pjmedia_format_id,
  _swigc__p_pjmedia_jb_discard_algo,
  _swigc__p_pjmedia_orient,
  _swigc__p_pjmedia_rtcp_fb_type,
  _swigc__p_pjmedia_srtp_crypto_option,
  _swigc__p_pjmedia_srtp_keying_method,
  _swigc__p_pjmedia_srtp_use,
  _swigc__p_pjmedia_tone_desc,
  _swigc__p_pjmedia_tone_digit,
  _swigc__p_pjmedia_tone_digit_map,
  _swigc__p_pjmedia_tp_proto,
  _swigc__p_pjmedia_type,
  _swigc__p_pjmedia_vid_dev_cap,
  _swigc__p_pjmedia_vid_dev_fullscreen_flag,
  _swigc__p_pjmedia_vid_dev_hwnd_type,
  _swigc__p_pjmedia_vid_packing,
  _swigc__p_pjmedia_vid_stream_rc_method,
  _swigc__p_pjrpid_activity,
  _swigc__p_pjsip_cred_data_type,
  _swigc__p_pjsip_dialog_cap_status,
  _swigc__p_pjsip_event_id_e,
  _swigc__p_pjsip_evsub_state,
  _swigc__p_pjsip_hdr_e,
  _swigc__p_pjsip_inv_state,
  _swigc__p_pjsip_redirect_op,
  _swigc__p_pjsip_role_e,
  _swigc__p_pjsip_ssl_method,
  _swigc__p_pjsip_status_code,
  _swigc__p_pjsip_transport_state,
  _swigc__p_pjsip_transport_type_e,
  _swigc__p_pjsip_tsx_state_e,
  _swigc__p_pjsua_100rel_use,
  _swigc__p_pjsua_buddy_status,
  _swigc__p_pjsua_call_flag,
  _swigc__p_pjsua_call_hold_type,
  _swigc__p_pjsua_call_media_status,
  _swigc__p_pjsua_call_vid_strm_op,
  _swigc__p_pjsua_create_media_transport_flag,
  _swigc__p_pjsua_destroy_flag,
  _swigc__p_pjsua_dtmf_method,
  _swigc__p_pjsua_ip_change_op,
  _swigc__p_pjsua_ipv6_use,
  _swigc__p_pjsua_med_tp_st,
  _swigc__p_pjsua_nat64_opt,
  _swigc__p_pjsua_sip_timer_use,
  _swigc__p_pjsua_snd_dev_id,
  _swigc__p_pjsua_snd_dev_mode,
  _swigc__p_pjsua_state,
  _swigc__p_pjsua_stun_use,
  _swigc__p_pjsua_vid_req_keyframe_method,
  _swigc__p_size_type,
  _swigc__p_std__allocatorT_int_t,
  _swigc__p_std__allocatorT_pj__AudioDevInfo_p_t,
  _swigc__p_std__allocatorT_pj__AudioDevInfo_t,
  _swigc__p_std__allocatorT_pj__AudioMedia_p_t,
  _swigc__p_std__allocatorT_pj__AudioMedia_t,
  _swigc__p_std__allocatorT_pj__AuthCredInfo_t,
  _swigc__p_std__allocatorT_pj__Buddy_p_t,
  _swigc__p_std__allocatorT_pj__Buddy_t,
  _swigc__p_std__allocatorT_pj__CallMediaInfo_t,
  _swigc__p_std__allocatorT_pj__CodecFmtp_t,
  _swigc__p_std__allocatorT_pj__CodecInfo_p_t,
  _swigc__p_std__allocatorT_pj__CodecInfo_t,
  _swigc__p_std__allocatorT_pj__MediaFormatAudio_t,
  _swigc__p_std__allocatorT_pj__MediaFormatVideo_t,
  _swigc__p_std__allocatorT_pj__RtcpFbCap_t,
  _swigc__p_std__allocatorT_pj__SipHeader_t,
  _swigc__p_std__allocatorT_pj__SipMultipartPart_t,
  _swigc__p_std__allocatorT_pj__SrtpCrypto_t,
  _swigc__p_std__allocatorT_pj__SslCertName_t,
  _swigc__p_std__allocatorT_pj__ToneDesc_t,
  _swigc__p_std__allocatorT_pj__ToneDigitMapDigit_t,
  _swigc__p_std__allocatorT_pj__ToneDigit_t,
  _swigc__p_std__allocatorT_pj__VideoDevInfo_p_t,
  _swigc__p_std__allocatorT_pj__VideoDevInfo_t,
  _swigc__p_std__allocatorT_pj__VideoMedia_t,
  _swigc__p_std__allocatorT_std__pairT_std__string_const_std__string_t_t,
  _swigc__p_std__allocatorT_std__string_t,
  _swigc__p_std__invalid_argument,
  _swigc__p_std__lessT_std__string_t,
  _swigc__p_std__mapT_std__string_std__string_std__lessT_std__string_t_std__allocatorT_std__pairT_std__string_const_std__string_t_t_t,
  _swigc__p_std__string,
  _swigc__p_std__vectorT_int_std__allocatorT_int_t_t,
  _swigc__p_std__vectorT_pj__AudioDevInfo_p_std__allocatorT_pj__AudioDevInfo_p_t_t,
  _swigc__p_std__vectorT_pj__AudioDevInfo_std__allocatorT_pj__AudioDevInfo_t_t,
  _swigc__p_std__vectorT_pj__AudioMedia_p_std__allocatorT_pj__AudioMedia_p_t_t,
  _swigc__p_std__vectorT_pj__AudioMedia_std__allocatorT_pj__AudioMedia_t_t,
  _swigc__p_std__vectorT_pj__AuthCredInfo_std__allocatorT_pj__AuthCredInfo_t_t,
  _swigc__p_std__vectorT_pj__Buddy_p_std__allocatorT_pj__Buddy_p_t_t,
  _swigc__p_std__vectorT_pj__Buddy_std__allocatorT_pj__Buddy_t_t,
  _swigc__p_std__vectorT_pj__CallMediaInfo_std__allocatorT_pj__CallMediaInfo_t_t,
  _swigc__p_std__vectorT_pj__CodecFmtp_std__allocatorT_pj__CodecFmtp_t_t,
  _swigc__p_std__vectorT_pj__CodecInfo_p_std__allocatorT_pj__CodecInfo_p_t_t,
  _swigc__p_std__vectorT_pj__CodecInfo_std__allocatorT_pj__CodecInfo_t_t,
  _swigc__p_std__vectorT_pj__MediaFormatAudio_std__allocatorT_pj__MediaFormatAudio_t_t,
  _swigc__p_std__vectorT_pj__MediaFormatVideo_std__allocatorT_pj__MediaFormatVideo_t_t,
  _swigc__p_std__vectorT_pj__RtcpFbCap_std__allocatorT_pj__RtcpFbCap_t_t,
  _swigc__p_std__vectorT_pj__SipHeader_std__allocatorT_pj__SipHeader_t_t,
  _swigc__p_std__vectorT_pj__SipMultipartPart_std__allocatorT_pj__SipMultipartPart_t_t,
  _swigc__p_std__vectorT_pj__SrtpCrypto_std__allocatorT_pj__SrtpCrypto_t_t,
  _swigc__p_std__vectorT_pj__SslCertName_std__allocatorT_pj__SslCertName_t_t,
  _swigc__p_std__vectorT_pj__ToneDesc_std__allocatorT_pj__ToneDesc_t_t,
  _swigc__p_std__vectorT_pj__ToneDigitMapDigit_std__allocatorT_pj__ToneDigitMapDigit_t_t,
  _swigc__p_std__vectorT_pj__ToneDigit_std__allocatorT_pj__ToneDigit_t_t,
  _swigc__p_std__vectorT_pj__VideoDevInfo_p_std__allocatorT_pj__VideoDevInfo_p_t_t,
  _swigc__p_std__vectorT_pj__VideoDevInfo_std__allocatorT_pj__VideoDevInfo_t_t,
  _swigc__p_std__vectorT_pj__VideoMedia_std__allocatorT_pj__VideoMedia_t_t,
  _swigc__p_std__vectorT_std__string_std__allocatorT_std__string_t_t,
  _swigc__p_swig__SwigPyIterator,
  _swigc__p_unsigned_char,
  _swigc__p_unsigned_int,
  _swigc__p_unsigned_short,
  _swigc__p_value_type,
  _swigc__p_void,
};


/* -------- TYPE CONVERSION AND EQUIVALENCE RULES (END) -------- */

static swig_const_info swig_const_table[] = {
{0, 0, 0, 0.0, 0, 0}};

#ifdef __cplusplus
}
#endif
/* -----------------------------------------------------------------------------
 * Type initialization:
 * This problem is tough by the requirement that no dynamic
 * memory is used. Also, since swig_type_info structures store pointers to
 * swig_cast_info structures and swig_cast_info structures store pointers back
 * to swig_type_info structures, we need some lookup code at initialization.
 * The idea is that swig generates all the structures that are needed.
 * The runtime then collects these partially filled structures.
 * The SWIG_InitializeModule function takes these initial arrays out of
 * swig_module, and does all the lookup, filling in the swig_module.types
 * array with the correct data and linking the correct swig_cast_info
 * structures together.
 *
 * The generated swig_type_info structures are assigned statically to an initial
 * array. We just loop through that array, and handle each type individually.
 * First we lookup if this type has been already loaded, and if so, use the
 * loaded structure instead of the generated one. Then we have to fill in the
 * cast linked list. The cast data is initially stored in something like a
 * two-dimensional array. Each row corresponds to a type (there are the same
 * number of rows as there are in the swig_type_initial array). Each entry in
 * a column is one of the swig_cast_info structures for that type.
 * The cast_initial array is actually an array of arrays, because each row has
 * a variable number of columns. So to actually build the cast linked list,
 * we find the array of casts associated with the type, and loop through it
 * adding the casts to the list. The one last trick we need to do is making
 * sure the type pointer in the swig_cast_info struct is correct.
 *
 * First off, we lookup the cast->type name to see if it is already loaded.
 * There are three cases to handle:
 *  1) If the cast->type has already been loaded AND the type we are adding
 *     casting info to has not been loaded (it is in this module), THEN we
 *     replace the cast->type pointer with the type pointer that has already
 *     been loaded.
 *  2) If BOTH types (the one we are adding casting info to, and the
 *     cast->type) are loaded, THEN the cast info has already been loaded by
 *     the previous module so we just ignore it.
 *  3) Finally, if cast->type has not already been loaded, then we add that
 *     swig_cast_info to the linked list (because the cast->type) pointer will
 *     be correct.
 * ----------------------------------------------------------------------------- */

#ifdef __cplusplus
extern "C" {
#if 0
} /* c-mode */
#endif
#endif

#if 0
#define SWIGRUNTIME_DEBUG
#endif


SWIGRUNTIME void
SWIG_InitializeModule(void *clientdata) {
  size_t i;
  swig_module_info *module_head, *iter;
  int init;
  
  /* check to see if the circular list has been setup, if not, set it up */
  if (swig_module.next==0) {
    /* Initialize the swig_module */
    swig_module.type_initial = swig_type_initial;
    swig_module.cast_initial = swig_cast_initial;
    swig_module.next = &swig_module;
    init = 1;
  } else {
    init = 0;
  }
  
  /* Try and load any already created modules */
  module_head = SWIG_GetModule(clientdata);
  if (!module_head) {
    /* This is the first module loaded for this interpreter */
    /* so set the swig module into the interpreter */
    SWIG_SetModule(clientdata, &swig_module);
  } else {
    /* the interpreter has loaded a SWIG module, but has it loaded this one? */
    iter=module_head;
    do {
      if (iter==&swig_module) {
        /* Our module is already in the list, so there's nothing more to do. */
        return;
      }
      iter=iter->next;
    } while (iter!= module_head);
    
    /* otherwise we must add our module into the list */
    swig_module.next = module_head->next;
    module_head->next = &swig_module;
  }
  
  /* When multiple interpreters are used, a module could have already been initialized in
       a different interpreter, but not yet have a pointer in this interpreter.
       In this case, we do not want to continue adding types... everything should be
       set up already */
  if (init == 0) return;
  
  /* Now work on filling in swig_module.types */
#ifdef SWIGRUNTIME_DEBUG
  printf("SWIG_InitializeModule: size %lu\n", (unsigned long)swig_module.size);
#endif
  for (i = 0; i < swig_module.size; ++i) {
    swig_type_info *type = 0;
    swig_type_info *ret;
    swig_cast_info *cast;
    
#ifdef SWIGRUNTIME_DEBUG
    printf("SWIG_InitializeModule: type %lu %s\n", (unsigned long)i, swig_module.type_initial[i]->name);
#endif
    
    /* if there is another module already loaded */
    if (swig_module.next != &swig_module) {
      type = SWIG_MangledTypeQueryModule(swig_module.next, &swig_module, swig_module.type_initial[i]->name);
    }
    if (type) {
      /* Overwrite clientdata field */
#ifdef SWIGRUNTIME_DEBUG
      printf("SWIG_InitializeModule: found type %s\n", type->name);
#endif
      if (swig_module.type_initial[i]->clientdata) {
        type->clientdata = swig_module.type_initial[i]->clientdata;
#ifdef SWIGRUNTIME_DEBUG
        printf("SWIG_InitializeModule: found and overwrite type %s \n", type->name);
#endif
      }
    } else {
      type = swig_module.type_initial[i];
    }
    
    /* Insert casting types */
    cast = swig_module.cast_initial[i];
    while (cast->type) {
      /* Don't need to add information already in the list */
      ret = 0;
#ifdef SWIGRUNTIME_DEBUG
      printf("SWIG_InitializeModule: look cast %s\n", cast->type->name);
#endif
      if (swig_module.next != &swig_module) {
        ret = SWIG_MangledTypeQueryModule(swig_module.next, &swig_module, cast->type->name);
#ifdef SWIGRUNTIME_DEBUG
        if (ret) printf("SWIG_InitializeModule: found cast %s\n", ret->name);
#endif
      }
      if (ret) {
        if (type == swig_module.type_initial[i]) {
#ifdef SWIGRUNTIME_DEBUG
          printf("SWIG_InitializeModule: skip old type %s\n", ret->name);
#endif
          cast->type = ret;
          ret = 0;
        } else {
          /* Check for casting already in the list */
          swig_cast_info *ocast = SWIG_TypeCheck(ret->name, type);
#ifdef SWIGRUNTIME_DEBUG
          if (ocast) printf("SWIG_InitializeModule: skip old cast %s\n", ret->name);
#endif
          if (!ocast) ret = 0;
        }
      }
      
      if (!ret) {
#ifdef SWIGRUNTIME_DEBUG
        printf("SWIG_InitializeModule: adding cast %s\n", cast->type->name);
#endif
        if (type->cast) {
          type->cast->prev = cast;
          cast->next = type->cast;
        }
        type->cast = cast;
      }
      cast++;
    }
    /* Set entry in modules->types array equal to the type */
    swig_module.types[i] = type;
  }
  swig_module.types[i] = 0;
  
#ifdef SWIGRUNTIME_DEBUG
  printf("**** SWIG_InitializeModule: Cast List ******\n");
  for (i = 0; i < swig_module.size; ++i) {
    int j = 0;
    swig_cast_info *cast = swig_module.cast_initial[i];
    printf("SWIG_InitializeModule: type %lu %s\n", (unsigned long)i, swig_module.type_initial[i]->name);
    while (cast->type) {
      printf("SWIG_InitializeModule: cast type %s\n", cast->type->name);
      cast++;
      ++j;
    }
    printf("---- Total casts: %d\n",j);
  }
  printf("**** SWIG_InitializeModule: Cast List ******\n");
#endif
}

/* This function will propagate the clientdata field of type to
* any new swig_type_info structures that have been added into the list
* of equivalent types.  It is like calling
* SWIG_TypeClientData(type, clientdata) a second time.
*/
SWIGRUNTIME void
SWIG_PropagateClientData(void) {
  size_t i;
  swig_cast_info *equiv;
  static int init_run = 0;
  
  if (init_run) return;
  init_run = 1;
  
  for (i = 0; i < swig_module.size; i++) {
    if (swig_module.types[i]->clientdata) {
      equiv = swig_module.types[i]->cast;
      while (equiv) {
        if (!equiv->converter) {
          if (equiv->type && !equiv->type->clientdata)
          SWIG_TypeClientData(equiv->type, swig_module.types[i]->clientdata);
        }
        equiv = equiv->next;
      }
    }
  }
}

#ifdef __cplusplus
#if 0
{
  /* c-mode */
#endif
}
#endif



#ifdef __cplusplus
extern "C" {
#endif
  
  /* Python-specific SWIG API */
#define SWIG_newvarlink()                             SWIG_Python_newvarlink()
#define SWIG_addvarlink(p, name, get_attr, set_attr)  SWIG_Python_addvarlink(p, name, get_attr, set_attr)
#define SWIG_InstallConstants(d, constants)           SWIG_Python_InstallConstants(d, constants)
  
  /* -----------------------------------------------------------------------------
   * global variable support code.
   * ----------------------------------------------------------------------------- */
  
  typedef struct swig_globalvar {
    char       *name;                  /* Name of global variable */
    PyObject *(*get_attr)(void);       /* Return the current value */
    int       (*set_attr)(PyObject *); /* Set the value */
    struct swig_globalvar *next;
  } swig_globalvar;
  
  typedef struct swig_varlinkobject {
    PyObject_HEAD
    swig_globalvar *vars;
  } swig_varlinkobject;
  
  SWIGINTERN PyObject *
  swig_varlink_repr(swig_varlinkobject *SWIGUNUSEDPARM(v)) {
#if PY_VERSION_HEX >= 0x03000000
    return PyUnicode_InternFromString("<Swig global variables>");
#else
    return PyString_FromString("<Swig global variables>");
#endif
  }
  
  SWIGINTERN PyObject *
  swig_varlink_str(swig_varlinkobject *v) {
#if PY_VERSION_HEX >= 0x03000000
    PyObject *str = PyUnicode_InternFromString("(");
    PyObject *tail;
    PyObject *joined;
    swig_globalvar *var;
    for (var = v->vars; var; var=var->next) {
      tail = PyUnicode_FromString(var->name);
      joined = PyUnicode_Concat(str, tail);
      Py_DecRef(str);
      Py_DecRef(tail);
      str = joined;
      if (var->next) {
        tail = PyUnicode_InternFromString(", ");
        joined = PyUnicode_Concat(str, tail);
        Py_DecRef(str);
        Py_DecRef(tail);
        str = joined;
      }
    }
    tail = PyUnicode_InternFromString(")");
    joined = PyUnicode_Concat(str, tail);
    Py_DecRef(str);
    Py_DecRef(tail);
    str = joined;
#else
    PyObject *str = PyString_FromString("(");
    swig_globalvar *var;
    for (var = v->vars; var; var=var->next) {
      PyString_ConcatAndDel(&str,PyString_FromString(var->name));
      if (var->next) PyString_ConcatAndDel(&str,PyString_FromString(", "));
    }
    PyString_ConcatAndDel(&str,PyString_FromString(")"));
#endif
    return str;
  }
  
  SWIGINTERN void
  swig_varlink_dealloc(swig_varlinkobject *v) {
    swig_globalvar *var = v->vars;
    while (var) {
      swig_globalvar *n = var->next;
      free(var->name);
      free(var);
      var = n;
    }
  }
  
  SWIGINTERN PyObject *
  swig_varlink_getattr(swig_varlinkobject *v, char *n) {
    PyObject *res = NULL;
    swig_globalvar *var = v->vars;
    while (var) {
      if (strcmp(var->name,n) == 0) {
        res = (*var->get_attr)();
        break;
      }
      var = var->next;
    }
    if (res == NULL && !PyErr_Occurred()) {
      PyErr_Format(PyExc_AttributeError, "Unknown C global variable '%s'", n);
    }
    return res;
  }
  
  SWIGINTERN int
  swig_varlink_setattr(swig_varlinkobject *v, char *n, PyObject *p) {
    int res = 1;
    swig_globalvar *var = v->vars;
    while (var) {
      if (strcmp(var->name,n) == 0) {
        res = (*var->set_attr)(p);
        break;
      }
      var = var->next;
    }
    if (res == 1 && !PyErr_Occurred()) {
      PyErr_Format(PyExc_AttributeError, "Unknown C global variable '%s'", n);
    }
    return res;
  }
  
  SWIGINTERN PyTypeObject*
  swig_varlink_type(void) {
    static char varlink__doc__[] = "Swig var link object";
    static PyTypeObject varlink_type;
    static int type_init = 0;
    if (!type_init) {
      const PyTypeObject tmp = {
#if PY_VERSION_HEX >= 0x03000000
        PyVarObject_HEAD_INIT(NULL, 0)
#else
        PyObject_HEAD_INIT(NULL)
        0,                                  /* ob_size */
#endif
        "swigvarlink",                      /* tp_name */
        sizeof(swig_varlinkobject),         /* tp_basicsize */
        0,                                  /* tp_itemsize */
        (destructor) swig_varlink_dealloc,  /* tp_dealloc */
        0,                                  /* tp_print */
        (getattrfunc) swig_varlink_getattr, /* tp_getattr */
        (setattrfunc) swig_varlink_setattr, /* tp_setattr */
        0,                                  /* tp_compare */
        (reprfunc) swig_varlink_repr,       /* tp_repr */
        0,                                  /* tp_as_number */
        0,                                  /* tp_as_sequence */
        0,                                  /* tp_as_mapping */
        0,                                  /* tp_hash */
        0,                                  /* tp_call */
        (reprfunc) swig_varlink_str,        /* tp_str */
        0,                                  /* tp_getattro */
        0,                                  /* tp_setattro */
        0,                                  /* tp_as_buffer */
        0,                                  /* tp_flags */
        varlink__doc__,                     /* tp_doc */
        0,                                  /* tp_traverse */
        0,                                  /* tp_clear */
        0,                                  /* tp_richcompare */
        0,                                  /* tp_weaklistoffset */
        0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0, /* tp_iter -> tp_weaklist */
        0,                                  /* tp_del */
        0,                                  /* tp_version_tag */
#if PY_VERSION_HEX >= 0x03040000
        0,                                  /* tp_finalize */
#endif
#ifdef COUNT_ALLOCS
        0,                                  /* tp_allocs */
        0,                                  /* tp_frees */
        0,                                  /* tp_maxalloc */
        0,                                  /* tp_prev */
        0                                   /* tp_next */
#endif
      };
      varlink_type = tmp;
      type_init = 1;
      if (PyType_Ready(&varlink_type) < 0)
      return NULL;
    }
    return &varlink_type;
  }
  
  /* Create a variable linking object for use later */
  SWIGINTERN PyObject *
  SWIG_Python_newvarlink(void) {
    swig_varlinkobject *result = PyObject_NEW(swig_varlinkobject, swig_varlink_type());
    if (result) {
      result->vars = 0;
    }
    return ((PyObject*) result);
  }
  
  SWIGINTERN void 
  SWIG_Python_addvarlink(PyObject *p, const char *name, PyObject *(*get_attr)(void), int (*set_attr)(PyObject *p)) {
    swig_varlinkobject *v = (swig_varlinkobject *) p;
    swig_globalvar *gv = (swig_globalvar *) malloc(sizeof(swig_globalvar));
    if (gv) {
      size_t size = strlen(name)+1;
      gv->name = (char *)malloc(size);
      if (gv->name) {
        memcpy(gv->name, name, size);
        gv->get_attr = get_attr;
        gv->set_attr = set_attr;
        gv->next = v->vars;
      }
    }
    v->vars = gv;
  }
  
  SWIGINTERN PyObject *
  SWIG_globals(void) {
    static PyObject *globals = 0;
    if (!globals) {
      globals = SWIG_newvarlink();
    }
    return globals;
  }
  
  /* -----------------------------------------------------------------------------
   * constants/methods manipulation
   * ----------------------------------------------------------------------------- */
  
  /* Install Constants */
  SWIGINTERN void
  SWIG_Python_InstallConstants(PyObject *d, swig_const_info constants[]) {
    PyObject *obj = 0;
    size_t i;
    for (i = 0; constants[i].type; ++i) {
      switch(constants[i].type) {
      case SWIG_PY_POINTER:
        obj = SWIG_InternalNewPointerObj(constants[i].pvalue, *(constants[i]).ptype,0);
        break;
      case SWIG_PY_BINARY:
        obj = SWIG_NewPackedObj(constants[i].pvalue, constants[i].lvalue, *(constants[i].ptype));
        break;
      default:
        obj = 0;
        break;
      }
      if (obj) {
        PyDict_SetItemString(d, constants[i].name, obj);
        Py_DECREF(obj);
      }
    }
  }
  
  /* -----------------------------------------------------------------------------*/
  /* Fix SwigMethods to carry the callback ptrs when needed */
  /* -----------------------------------------------------------------------------*/
  
  SWIGINTERN void
  SWIG_Python_FixMethods(PyMethodDef *methods,
    swig_const_info *const_table,
    swig_type_info **types,
    swig_type_info **types_initial) {
    size_t i;
    for (i = 0; methods[i].ml_name; ++i) {
      const char *c = methods[i].ml_doc;
      if (!c) continue;
      c = strstr(c, "swig_ptr: ");
      if (c) {
        int j;
        swig_const_info *ci = 0;
        const char *name = c + 10;
        for (j = 0; const_table[j].type; ++j) {
          if (strncmp(const_table[j].name, name, 
              strlen(const_table[j].name)) == 0) {
            ci = &(const_table[j]);
            break;
          }
        }
        if (ci) {
          void *ptr = (ci->type == SWIG_PY_POINTER) ? ci->pvalue : 0;
          if (ptr) {
            size_t shift = (ci->ptype) - types;
            swig_type_info *ty = types_initial[shift];
            size_t ldoc = (c - methods[i].ml_doc);
            size_t lptr = strlen(ty->name)+2*sizeof(void*)+2;
            char *ndoc = (char*)malloc(ldoc + lptr + 10);
            if (ndoc) {
              char *buff = ndoc;
              memcpy(buff, methods[i].ml_doc, ldoc);
              buff += ldoc;
              memcpy(buff, "swig_ptr: ", 10);
              buff += 10;
              SWIG_PackVoidPtr(buff, ptr, ty->name, lptr);
              methods[i].ml_doc = ndoc;
            }
          }
        }
      }
    }
  } 
  
  /* -----------------------------------------------------------------------------
   * Method creation and docstring support functions
   * ----------------------------------------------------------------------------- */
  
  /* -----------------------------------------------------------------------------
   * Function to find the method definition with the correct docstring for the
   * proxy module as opposed to the low-level API
   * ----------------------------------------------------------------------------- */
  
  SWIGINTERN PyMethodDef *SWIG_PythonGetProxyDoc(const char *name) {
    /* Find the function in the modified method table */
    size_t offset = 0;
    int found = 0;
    while (SwigMethods_proxydocs[offset].ml_meth != NULL) {
      if (strcmp(SwigMethods_proxydocs[offset].ml_name, name) == 0) {
        found = 1;
        break;
      }
      offset++;
    }
    /* Use the copy with the modified docstring if available */
    return found ? &SwigMethods_proxydocs[offset] : NULL;
  }
  
  /* -----------------------------------------------------------------------------
   * Wrapper of PyInstanceMethod_New() used in Python 3
   * It is exported to the generated module, used for -fastproxy
   * ----------------------------------------------------------------------------- */
  
  SWIGINTERN PyObject *SWIG_PyInstanceMethod_New(PyObject *SWIGUNUSEDPARM(self), PyObject *func) {
    if (PyCFunction_Check(func)) {
      PyCFunctionObject *funcobj = (PyCFunctionObject *)func;
      PyMethodDef *ml = SWIG_PythonGetProxyDoc(funcobj->m_ml->ml_name);
      if (ml)
      func = PyCFunction_NewEx(ml, funcobj->m_self, funcobj->m_module);
    }
#if PY_VERSION_HEX >= 0x03000000
    return PyInstanceMethod_New(func);
#else
    return PyMethod_New(func, NULL, NULL);
#endif
  }
  
  /* -----------------------------------------------------------------------------
   * Wrapper of PyStaticMethod_New()
   * It is exported to the generated module, used for -fastproxy
   * ----------------------------------------------------------------------------- */
  
  SWIGINTERN PyObject *SWIG_PyStaticMethod_New(PyObject *SWIGUNUSEDPARM(self), PyObject *func) {
    if (PyCFunction_Check(func)) {
      PyCFunctionObject *funcobj = (PyCFunctionObject *)func;
      PyMethodDef *ml = SWIG_PythonGetProxyDoc(funcobj->m_ml->ml_name);
      if (ml)
      func = PyCFunction_NewEx(ml, funcobj->m_self, funcobj->m_module);
    }
    return PyStaticMethod_New(func);
  }
  
#ifdef __cplusplus
}
#endif

/* -----------------------------------------------------------------------------*
 *  Partial Init method
 * -----------------------------------------------------------------------------*/

#ifdef __cplusplus
extern "C"
#endif

SWIGEXPORT 
#if PY_VERSION_HEX >= 0x03000000
PyObject*
#else
void
#endif
SWIG_init(void) {
  PyObject *m, *d, *md, *globals;
  
#if PY_VERSION_HEX >= 0x03000000
  static struct PyModuleDef SWIG_module = {
    PyModuleDef_HEAD_INIT,
    SWIG_name,
    NULL,
    -1,
    SwigMethods,
    NULL,
    NULL,
    NULL,
    NULL
  };
#endif
  
#if defined(SWIGPYTHON_BUILTIN)
  static SwigPyClientData SwigPyObject_clientdata = {
    0, 0, 0, 0, 0, 0, 0
  };
  static PyGetSetDef this_getset_def = {
    (char *)"this", &SwigPyBuiltin_ThisClosure, NULL, NULL, NULL
  };
  static SwigPyGetSet thisown_getset_closure = {
    SwigPyObject_own,
    SwigPyObject_own
  };
  static PyGetSetDef thisown_getset_def = {
    (char *)"thisown", SwigPyBuiltin_GetterClosure, SwigPyBuiltin_SetterClosure, NULL, &thisown_getset_closure
  };
  PyTypeObject *builtin_pytype;
  int builtin_base_count;
  swig_type_info *builtin_basetype;
  PyObject *tuple;
  PyGetSetDescrObject *static_getset;
  PyTypeObject *metatype;
  PyTypeObject *swigpyobject;
  SwigPyClientData *cd;
  PyObject *public_interface, *public_symbol;
  PyObject *this_descr;
  PyObject *thisown_descr;
  PyObject *self = 0;
  int i;
  
  (void)builtin_pytype;
  (void)builtin_base_count;
  (void)builtin_basetype;
  (void)tuple;
  (void)static_getset;
  (void)self;
  
  /* Metaclass is used to implement static member variables */
  metatype = SwigPyObjectType();
  assert(metatype);
#endif
  
  (void)globals;
  
  /* Create singletons now to avoid potential deadlocks with multi-threaded usage after module initialization */
  SWIG_This();
  SWIG_Python_TypeCache();
  SwigPyPacked_type();
#ifndef SWIGPYTHON_BUILTIN
  SwigPyObject_type();
#endif
  
  /* Fix SwigMethods to carry the callback ptrs when needed */
  SWIG_Python_FixMethods(SwigMethods, swig_const_table, swig_types, swig_type_initial);
  
#if PY_VERSION_HEX >= 0x03000000
  m = PyModule_Create(&SWIG_module);
#else
  m = Py_InitModule(SWIG_name, SwigMethods);
#endif
  
  md = d = PyModule_GetDict(m);
  (void)md;
  
  SWIG_InitializeModule(0);
  
#ifdef SWIGPYTHON_BUILTIN
  swigpyobject = SwigPyObject_TypeOnce();
  
  SwigPyObject_stype = SWIG_MangledTypeQuery("_p_SwigPyObject");
  assert(SwigPyObject_stype);
  cd = (SwigPyClientData*) SwigPyObject_stype->clientdata;
  if (!cd) {
    SwigPyObject_stype->clientdata = &SwigPyObject_clientdata;
    SwigPyObject_clientdata.pytype = swigpyobject;
  } else if (swigpyobject->tp_basicsize != cd->pytype->tp_basicsize) {
    PyErr_SetString(PyExc_RuntimeError, "Import error: attempted to load two incompatible swig-generated modules.");
# if PY_VERSION_HEX >= 0x03000000
    return NULL;
# else
    return;
# endif
  }
  
  /* All objects have a 'this' attribute */
  this_descr = PyDescr_NewGetSet(SwigPyObject_type(), &this_getset_def);
  (void)this_descr;
  
  /* All objects have a 'thisown' attribute */
  thisown_descr = PyDescr_NewGetSet(SwigPyObject_type(), &thisown_getset_def);
  (void)thisown_descr;
  
  public_interface = PyList_New(0);
  public_symbol = 0;
  (void)public_symbol;
  
  PyDict_SetItemString(md, "__all__", public_interface);
  Py_DECREF(public_interface);
  for (i = 0; SwigMethods[i].ml_name != NULL; ++i)
  SwigPyBuiltin_AddPublicSymbol(public_interface, SwigMethods[i].ml_name);
  for (i = 0; swig_const_table[i].name != 0; ++i)
  SwigPyBuiltin_AddPublicSymbol(public_interface, swig_const_table[i].name);
#endif
  
  SWIG_InstallConstants(d,swig_const_table);
  
  SWIG_Python_SetConstant(d, "PJ_SUCCESS",SWIG_From_int(static_cast< int >(PJ_SUCCESS)));
  SWIG_Python_SetConstant(d, "PJ_TRUE",SWIG_From_int(static_cast< int >(PJ_TRUE)));
  SWIG_Python_SetConstant(d, "PJ_FALSE",SWIG_From_int(static_cast< int >(PJ_FALSE)));
  SWIG_Python_SetConstant(d, "PJ_O_RDONLY",SWIG_From_int(static_cast< int >(PJ_O_RDONLY)));
  SWIG_Python_SetConstant(d, "PJ_O_WRONLY",SWIG_From_int(static_cast< int >(PJ_O_WRONLY)));
  SWIG_Python_SetConstant(d, "PJ_O_RDWR",SWIG_From_int(static_cast< int >(PJ_O_RDWR)));
  SWIG_Python_SetConstant(d, "PJ_O_APPEND",SWIG_From_int(static_cast< int >(PJ_O_APPEND)));
  SWIG_Python_SetConstant(d, "PJ_LOG_HAS_DAY_NAME",SWIG_From_int(static_cast< int >(PJ_LOG_HAS_DAY_NAME)));
  SWIG_Python_SetConstant(d, "PJ_LOG_HAS_YEAR",SWIG_From_int(static_cast< int >(PJ_LOG_HAS_YEAR)));
  SWIG_Python_SetConstant(d, "PJ_LOG_HAS_MONTH",SWIG_From_int(static_cast< int >(PJ_LOG_HAS_MONTH)));
  SWIG_Python_SetConstant(d, "PJ_LOG_HAS_DAY_OF_MON",SWIG_From_int(static_cast< int >(PJ_LOG_HAS_DAY_OF_MON)));
  SWIG_Python_SetConstant(d, "PJ_LOG_HAS_TIME",SWIG_From_int(static_cast< int >(PJ_LOG_HAS_TIME)));
  SWIG_Python_SetConstant(d, "PJ_LOG_HAS_MICRO_SEC",SWIG_From_int(static_cast< int >(PJ_LOG_HAS_MICRO_SEC)));
  SWIG_Python_SetConstant(d, "PJ_LOG_HAS_SENDER",SWIG_From_int(static_cast< int >(PJ_LOG_HAS_SENDER)));
  SWIG_Python_SetConstant(d, "PJ_LOG_HAS_NEWLINE",SWIG_From_int(static_cast< int >(PJ_LOG_HAS_NEWLINE)));
  SWIG_Python_SetConstant(d, "PJ_LOG_HAS_CR",SWIG_From_int(static_cast< int >(PJ_LOG_HAS_CR)));
  SWIG_Python_SetConstant(d, "PJ_LOG_HAS_SPACE",SWIG_From_int(static_cast< int >(PJ_LOG_HAS_SPACE)));
  SWIG_Python_SetConstant(d, "PJ_LOG_HAS_COLOR",SWIG_From_int(static_cast< int >(PJ_LOG_HAS_COLOR)));
  SWIG_Python_SetConstant(d, "PJ_LOG_HAS_LEVEL_TEXT",SWIG_From_int(static_cast< int >(PJ_LOG_HAS_LEVEL_TEXT)));
  SWIG_Python_SetConstant(d, "PJ_LOG_HAS_THREAD_ID",SWIG_From_int(static_cast< int >(PJ_LOG_HAS_THREAD_ID)));
  SWIG_Python_SetConstant(d, "PJ_LOG_HAS_THREAD_SWC",SWIG_From_int(static_cast< int >(PJ_LOG_HAS_THREAD_SWC)));
  SWIG_Python_SetConstant(d, "PJ_LOG_HAS_INDENT",SWIG_From_int(static_cast< int >(PJ_LOG_HAS_INDENT)));
  SWIG_Python_SetConstant(d, "PJ_QOS_TYPE_BEST_EFFORT",SWIG_From_int(static_cast< int >(PJ_QOS_TYPE_BEST_EFFORT)));
  SWIG_Python_SetConstant(d, "PJ_QOS_TYPE_BACKGROUND",SWIG_From_int(static_cast< int >(PJ_QOS_TYPE_BACKGROUND)));
  SWIG_Python_SetConstant(d, "PJ_QOS_TYPE_VIDEO",SWIG_From_int(static_cast< int >(PJ_QOS_TYPE_VIDEO)));
  SWIG_Python_SetConstant(d, "PJ_QOS_TYPE_VOICE",SWIG_From_int(static_cast< int >(PJ_QOS_TYPE_VOICE)));
  SWIG_Python_SetConstant(d, "PJ_QOS_TYPE_CONTROL",SWIG_From_int(static_cast< int >(PJ_QOS_TYPE_CONTROL)));
  SWIG_Python_SetConstant(d, "PJ_QOS_TYPE_SIGNALLING",SWIG_From_int(static_cast< int >(PJ_QOS_TYPE_SIGNALLING)));
  SWIG_Python_SetConstant(d, "PJ_QOS_PARAM_HAS_DSCP",SWIG_From_int(static_cast< int >(PJ_QOS_PARAM_HAS_DSCP)));
  SWIG_Python_SetConstant(d, "PJ_QOS_PARAM_HAS_SO_PRIO",SWIG_From_int(static_cast< int >(PJ_QOS_PARAM_HAS_SO_PRIO)));
  SWIG_Python_SetConstant(d, "PJ_QOS_PARAM_HAS_WMM",SWIG_From_int(static_cast< int >(PJ_QOS_PARAM_HAS_WMM)));
  SWIG_Python_SetConstant(d, "PJ_QOS_WMM_PRIO_BULK_EFFORT",SWIG_From_int(static_cast< int >(PJ_QOS_WMM_PRIO_BULK_EFFORT)));
  SWIG_Python_SetConstant(d, "PJ_QOS_WMM_PRIO_BULK",SWIG_From_int(static_cast< int >(PJ_QOS_WMM_PRIO_BULK)));
  SWIG_Python_SetConstant(d, "PJ_QOS_WMM_PRIO_VIDEO",SWIG_From_int(static_cast< int >(PJ_QOS_WMM_PRIO_VIDEO)));
  SWIG_Python_SetConstant(d, "PJ_QOS_WMM_PRIO_VOICE",SWIG_From_int(static_cast< int >(PJ_QOS_WMM_PRIO_VOICE)));
  SWIG_Python_SetConstant(d, "PJ_TLS_UNKNOWN_CIPHER",SWIG_From_int(static_cast< int >(PJ_TLS_UNKNOWN_CIPHER)));
  SWIG_Python_SetConstant(d, "PJ_TLS_NULL_WITH_NULL_NULL",SWIG_From_int(static_cast< int >(PJ_TLS_NULL_WITH_NULL_NULL)));
  SWIG_Python_SetConstant(d, "PJ_TLS_RSA_WITH_NULL_MD5",SWIG_From_int(static_cast< int >(PJ_TLS_RSA_WITH_NULL_MD5)));
  SWIG_Python_SetConstant(d, "PJ_TLS_RSA_WITH_NULL_SHA",SWIG_From_int(static_cast< int >(PJ_TLS_RSA_WITH_NULL_SHA)));
  SWIG_Python_SetConstant(d, "PJ_TLS_RSA_WITH_NULL_SHA256",SWIG_From_int(static_cast< int >(PJ_TLS_RSA_WITH_NULL_SHA256)));
  SWIG_Python_SetConstant(d, "PJ_TLS_RSA_WITH_RC4_128_MD5",SWIG_From_int(static_cast< int >(PJ_TLS_RSA_WITH_RC4_128_MD5)));
  SWIG_Python_SetConstant(d, "PJ_TLS_RSA_WITH_RC4_128_SHA",SWIG_From_int(static_cast< int >(PJ_TLS_RSA_WITH_RC4_128_SHA)));
  SWIG_Python_SetConstant(d, "PJ_TLS_RSA_WITH_3DES_EDE_CBC_SHA",SWIG_From_int(static_cast< int >(PJ_TLS_RSA_WITH_3DES_EDE_CBC_SHA)));
  SWIG_Python_SetConstant(d, "PJ_TLS_RSA_WITH_AES_128_CBC_SHA",SWIG_From_int(static_cast< int >(PJ_TLS_RSA_WITH_AES_128_CBC_SHA)));
  SWIG_Python_SetConstant(d, "PJ_TLS_RSA_WITH_AES_256_CBC_SHA",SWIG_From_int(static_cast< int >(PJ_TLS_RSA_WITH_AES_256_CBC_SHA)));
  SWIG_Python_SetConstant(d, "PJ_TLS_RSA_WITH_AES_128_CBC_SHA256",SWIG_From_int(static_cast< int >(PJ_TLS_RSA_WITH_AES_128_CBC_SHA256)));
  SWIG_Python_SetConstant(d, "PJ_TLS_RSA_WITH_AES_256_CBC_SHA256",SWIG_From_int(static_cast< int >(PJ_TLS_RSA_WITH_AES_256_CBC_SHA256)));
  SWIG_Python_SetConstant(d, "PJ_TLS_DH_DSS_WITH_3DES_EDE_CBC_SHA",SWIG_From_int(static_cast< int >(PJ_TLS_DH_DSS_WITH_3DES_EDE_CBC_SHA)));
  SWIG_Python_SetConstant(d, "PJ_TLS_DH_RSA_WITH_3DES_EDE_CBC_SHA",SWIG_From_int(static_cast< int >(PJ_TLS_DH_RSA_WITH_3DES_EDE_CBC_SHA)));
  SWIG_Python_SetConstant(d, "PJ_TLS_DHE_DSS_WITH_3DES_EDE_CBC_SHA",SWIG_From_int(static_cast< int >(PJ_TLS_DHE_DSS_WITH_3DES_EDE_CBC_SHA)));
  SWIG_Python_SetConstant(d, "PJ_TLS_DHE_RSA_WITH_3DES_EDE_CBC_SHA",SWIG_From_int(static_cast< int >(PJ_TLS_DHE_RSA_WITH_3DES_EDE_CBC_SHA)));
  SWIG_Python_SetConstant(d, "PJ_TLS_DH_DSS_WITH_AES_128_CBC_SHA",SWIG_From_int(static_cast< int >(PJ_TLS_DH_DSS_WITH_AES_128_CBC_SHA)));
  SWIG_Python_SetConstant(d, "PJ_TLS_DH_RSA_WITH_AES_128_CBC_SHA",SWIG_From_int(static_cast< int >(PJ_TLS_DH_RSA_WITH_AES_128_CBC_SHA)));
  SWIG_Python_SetConstant(d, "PJ_TLS_DHE_DSS_WITH_AES_128_CBC_SHA",SWIG_From_int(static_cast< int >(PJ_TLS_DHE_DSS_WITH_AES_128_CBC_SHA)));
  SWIG_Python_SetConstant(d, "PJ_TLS_DHE_RSA_WITH_AES_128_CBC_SHA",SWIG_From_int(static_cast< int >(PJ_TLS_DHE_RSA_WITH_AES_128_CBC_SHA)));
  SWIG_Python_SetConstant(d, "PJ_TLS_DH_DSS_WITH_AES_256_CBC_SHA",SWIG_From_int(static_cast< int >(PJ_TLS_DH_DSS_WITH_AES_256_CBC_SHA)));
  SWIG_Python_SetConstant(d, "PJ_TLS_DH_RSA_WITH_AES_256_CBC_SHA",SWIG_From_int(static_cast< int >(PJ_TLS_DH_RSA_WITH_AES_256_CBC_SHA)));
  SWIG_Python_SetConstant(d, "PJ_TLS_DHE_DSS_WITH_AES_256_CBC_SHA",SWIG_From_int(static_cast< int >(PJ_TLS_DHE_DSS_WITH_AES_256_CBC_SHA)));
  SWIG_Python_SetConstant(d, "PJ_TLS_DHE_RSA_WITH_AES_256_CBC_SHA",SWIG_From_int(static_cast< int >(PJ_TLS_DHE_RSA_WITH_AES_256_CBC_SHA)));
  SWIG_Python_SetConstant(d, "PJ_TLS_DH_DSS_WITH_AES_128_CBC_SHA256",SWIG_From_int(static_cast< int >(PJ_TLS_DH_DSS_WITH_AES_128_CBC_SHA256)));
  SWIG_Python_SetConstant(d, "PJ_TLS_DH_RSA_WITH_AES_128_CBC_SHA256",SWIG_From_int(static_cast< int >(PJ_TLS_DH_RSA_WITH_AES_128_CBC_SHA256)));
  SWIG_Python_SetConstant(d, "PJ_TLS_DHE_DSS_WITH_AES_128_CBC_SHA256",SWIG_From_int(static_cast< int >(PJ_TLS_DHE_DSS_WITH_AES_128_CBC_SHA256)));
  SWIG_Python_SetConstant(d, "PJ_TLS_DHE_RSA_WITH_AES_128_CBC_SHA256",SWIG_From_int(static_cast< int >(PJ_TLS_DHE_RSA_WITH_AES_128_CBC_SHA256)));
  SWIG_Python_SetConstant(d, "PJ_TLS_DH_DSS_WITH_AES_256_CBC_SHA256",SWIG_From_int(static_cast< int >(PJ_TLS_DH_DSS_WITH_AES_256_CBC_SHA256)));
  SWIG_Python_SetConstant(d, "PJ_TLS_DH_RSA_WITH_AES_256_CBC_SHA256",SWIG_From_int(static_cast< int >(PJ_TLS_DH_RSA_WITH_AES_256_CBC_SHA256)));
  SWIG_Python_SetConstant(d, "PJ_TLS_DHE_DSS_WITH_AES_256_CBC_SHA256",SWIG_From_int(static_cast< int >(PJ_TLS_DHE_DSS_WITH_AES_256_CBC_SHA256)));
  SWIG_Python_SetConstant(d, "PJ_TLS_DHE_RSA_WITH_AES_256_CBC_SHA256",SWIG_From_int(static_cast< int >(PJ_TLS_DHE_RSA_WITH_AES_256_CBC_SHA256)));
  SWIG_Python_SetConstant(d, "PJ_TLS_DH_anon_WITH_RC4_128_MD5",SWIG_From_int(static_cast< int >(PJ_TLS_DH_anon_WITH_RC4_128_MD5)));
  SWIG_Python_SetConstant(d, "PJ_TLS_DH_anon_WITH_3DES_EDE_CBC_SHA",SWIG_From_int(static_cast< int >(PJ_TLS_DH_anon_WITH_3DES_EDE_CBC_SHA)));
  SWIG_Python_SetConstant(d, "PJ_TLS_DH_anon_WITH_AES_128_CBC_SHA",SWIG_From_int(static_cast< int >(PJ_TLS_DH_anon_WITH_AES_128_CBC_SHA)));
  SWIG_Python_SetConstant(d, "PJ_TLS_DH_anon_WITH_AES_256_CBC_SHA",SWIG_From_int(static_cast< int >(PJ_TLS_DH_anon_WITH_AES_256_CBC_SHA)));
  SWIG_Python_SetConstant(d, "PJ_TLS_DH_anon_WITH_AES_128_CBC_SHA256",SWIG_From_int(static_cast< int >(PJ_TLS_DH_anon_WITH_AES_128_CBC_SHA256)));
  SWIG_Python_SetConstant(d, "PJ_TLS_DH_anon_WITH_AES_256_CBC_SHA256",SWIG_From_int(static_cast< int >(PJ_TLS_DH_anon_WITH_AES_256_CBC_SHA256)));
  SWIG_Python_SetConstant(d, "PJ_TLS_RSA_EXPORT_WITH_RC4_40_MD5",SWIG_From_int(static_cast< int >(PJ_TLS_RSA_EXPORT_WITH_RC4_40_MD5)));
  SWIG_Python_SetConstant(d, "PJ_TLS_RSA_EXPORT_WITH_RC2_CBC_40_MD5",SWIG_From_int(static_cast< int >(PJ_TLS_RSA_EXPORT_WITH_RC2_CBC_40_MD5)));
  SWIG_Python_SetConstant(d, "PJ_TLS_RSA_WITH_IDEA_CBC_SHA",SWIG_From_int(static_cast< int >(PJ_TLS_RSA_WITH_IDEA_CBC_SHA)));
  SWIG_Python_SetConstant(d, "PJ_TLS_RSA_EXPORT_WITH_DES40_CBC_SHA",SWIG_From_int(static_cast< int >(PJ_TLS_RSA_EXPORT_WITH_DES40_CBC_SHA)));
  SWIG_Python_SetConstant(d, "PJ_TLS_RSA_WITH_DES_CBC_SHA",SWIG_From_int(static_cast< int >(PJ_TLS_RSA_WITH_DES_CBC_SHA)));
  SWIG_Python_SetConstant(d, "PJ_TLS_DH_DSS_EXPORT_WITH_DES40_CBC_SHA",SWIG_From_int(static_cast< int >(PJ_TLS_DH_DSS_EXPORT_WITH_DES40_CBC_SHA)));
  SWIG_Python_SetConstant(d, "PJ_TLS_DH_DSS_WITH_DES_CBC_SHA",SWIG_From_int(static_cast< int >(PJ_TLS_DH_DSS_WITH_DES_CBC_SHA)));
  SWIG_Python_SetConstant(d, "PJ_TLS_DH_RSA_EXPORT_WITH_DES40_CBC_SHA",SWIG_From_int(static_cast< int >(PJ_TLS_DH_RSA_EXPORT_WITH_DES40_CBC_SHA)));
  SWIG_Python_SetConstant(d, "PJ_TLS_DH_RSA_WITH_DES_CBC_SHA",SWIG_From_int(static_cast< int >(PJ_TLS_DH_RSA_WITH_DES_CBC_SHA)));
  SWIG_Python_SetConstant(d, "PJ_TLS_DHE_DSS_EXPORT_WITH_DES40_CBC_SHA",SWIG_From_int(static_cast< int >(PJ_TLS_DHE_DSS_EXPORT_WITH_DES40_CBC_SHA)));
  SWIG_Python_SetConstant(d, "PJ_TLS_DHE_DSS_WITH_DES_CBC_SHA",SWIG_From_int(static_cast< int >(PJ_TLS_DHE_DSS_WITH_DES_CBC_SHA)));
  SWIG_Python_SetConstant(d, "PJ_TLS_DHE_RSA_EXPORT_WITH_DES40_CBC_SHA",SWIG_From_int(static_cast< int >(PJ_TLS_DHE_RSA_EXPORT_WITH_DES40_CBC_SHA)));
  SWIG_Python_SetConstant(d, "PJ_TLS_DHE_RSA_WITH_DES_CBC_SHA",SWIG_From_int(static_cast< int >(PJ_TLS_DHE_RSA_WITH_DES_CBC_SHA)));
  SWIG_Python_SetConstant(d, "PJ_TLS_DH_anon_EXPORT_WITH_RC4_40_MD5",SWIG_From_int(static_cast< int >(PJ_TLS_DH_anon_EXPORT_WITH_RC4_40_MD5)));
  SWIG_Python_SetConstant(d, "PJ_TLS_DH_anon_EXPORT_WITH_DES40_CBC_SHA",SWIG_From_int(static_cast< int >(PJ_TLS_DH_anon_EXPORT_WITH_DES40_CBC_SHA)));
  SWIG_Python_SetConstant(d, "PJ_TLS_DH_anon_WITH_DES_CBC_SHA",SWIG_From_int(static_cast< int >(PJ_TLS_DH_anon_WITH_DES_CBC_SHA)));
  SWIG_Python_SetConstant(d, "PJ_SSL_FORTEZZA_KEA_WITH_NULL_SHA",SWIG_From_int(static_cast< int >(PJ_SSL_FORTEZZA_KEA_WITH_NULL_SHA)));
  SWIG_Python_SetConstant(d, "PJ_SSL_FORTEZZA_KEA_WITH_FORTEZZA_CBC_SHA",SWIG_From_int(static_cast< int >(PJ_SSL_FORTEZZA_KEA_WITH_FORTEZZA_CBC_SHA)));
  SWIG_Python_SetConstant(d, "PJ_SSL_FORTEZZA_KEA_WITH_RC4_128_SHA",SWIG_From_int(static_cast< int >(PJ_SSL_FORTEZZA_KEA_WITH_RC4_128_SHA)));
  SWIG_Python_SetConstant(d, "PJ_SSL_CK_RC4_128_WITH_MD5",SWIG_From_int(static_cast< int >(PJ_SSL_CK_RC4_128_WITH_MD5)));
  SWIG_Python_SetConstant(d, "PJ_SSL_CK_RC4_128_EXPORT40_WITH_MD5",SWIG_From_int(static_cast< int >(PJ_SSL_CK_RC4_128_EXPORT40_WITH_MD5)));
  SWIG_Python_SetConstant(d, "PJ_SSL_CK_RC2_128_CBC_WITH_MD5",SWIG_From_int(static_cast< int >(PJ_SSL_CK_RC2_128_CBC_WITH_MD5)));
  SWIG_Python_SetConstant(d, "PJ_SSL_CK_RC2_128_CBC_EXPORT40_WITH_MD5",SWIG_From_int(static_cast< int >(PJ_SSL_CK_RC2_128_CBC_EXPORT40_WITH_MD5)));
  SWIG_Python_SetConstant(d, "PJ_SSL_CK_IDEA_128_CBC_WITH_MD5",SWIG_From_int(static_cast< int >(PJ_SSL_CK_IDEA_128_CBC_WITH_MD5)));
  SWIG_Python_SetConstant(d, "PJ_SSL_CK_DES_64_CBC_WITH_MD5",SWIG_From_int(static_cast< int >(PJ_SSL_CK_DES_64_CBC_WITH_MD5)));
  SWIG_Python_SetConstant(d, "PJ_SSL_CK_DES_192_EDE3_CBC_WITH_MD5",SWIG_From_int(static_cast< int >(PJ_SSL_CK_DES_192_EDE3_CBC_WITH_MD5)));
  SWIG_Python_SetConstant(d, "PJ_SSL_SOCK_PROTO_DEFAULT",SWIG_From_int(static_cast< int >(PJ_SSL_SOCK_PROTO_DEFAULT)));
  SWIG_Python_SetConstant(d, "PJ_SSL_SOCK_PROTO_SSL2",SWIG_From_int(static_cast< int >(PJ_SSL_SOCK_PROTO_SSL2)));
  SWIG_Python_SetConstant(d, "PJ_SSL_SOCK_PROTO_SSL3",SWIG_From_int(static_cast< int >(PJ_SSL_SOCK_PROTO_SSL3)));
  SWIG_Python_SetConstant(d, "PJ_SSL_SOCK_PROTO_TLS1",SWIG_From_int(static_cast< int >(PJ_SSL_SOCK_PROTO_TLS1)));
  SWIG_Python_SetConstant(d, "PJ_SSL_SOCK_PROTO_TLS1_1",SWIG_From_int(static_cast< int >(PJ_SSL_SOCK_PROTO_TLS1_1)));
  SWIG_Python_SetConstant(d, "PJ_SSL_SOCK_PROTO_TLS1_2",SWIG_From_int(static_cast< int >(PJ_SSL_SOCK_PROTO_TLS1_2)));
  SWIG_Python_SetConstant(d, "PJ_SSL_SOCK_PROTO_TLS1_3",SWIG_From_int(static_cast< int >(PJ_SSL_SOCK_PROTO_TLS1_3)));
  SWIG_Python_SetConstant(d, "PJ_SSL_SOCK_PROTO_SSL23",SWIG_From_int(static_cast< int >(PJ_SSL_SOCK_PROTO_SSL23)));
  SWIG_Python_SetConstant(d, "PJ_SSL_SOCK_PROTO_ALL",SWIG_From_int(static_cast< int >(PJ_SSL_SOCK_PROTO_ALL)));
  SWIG_Python_SetConstant(d, "PJ_SSL_SOCK_PROTO_DTLS1",SWIG_From_int(static_cast< int >(PJ_SSL_SOCK_PROTO_DTLS1)));
  SWIG_Python_SetConstant(d, "PJ_SSL_CERT_NAME_UNKNOWN",SWIG_From_int(static_cast< int >(PJ_SSL_CERT_NAME_UNKNOWN)));
  SWIG_Python_SetConstant(d, "PJ_SSL_CERT_NAME_RFC822",SWIG_From_int(static_cast< int >(PJ_SSL_CERT_NAME_RFC822)));
  SWIG_Python_SetConstant(d, "PJ_SSL_CERT_NAME_DNS",SWIG_From_int(static_cast< int >(PJ_SSL_CERT_NAME_DNS)));
  SWIG_Python_SetConstant(d, "PJ_SSL_CERT_NAME_URI",SWIG_From_int(static_cast< int >(PJ_SSL_CERT_NAME_URI)));
  SWIG_Python_SetConstant(d, "PJ_SSL_CERT_NAME_IP",SWIG_From_int(static_cast< int >(PJ_SSL_CERT_NAME_IP)));
  SWIG_Python_SetConstant(d, "PJ_SSL_CERT_ESUCCESS",SWIG_From_int(static_cast< int >(PJ_SSL_CERT_ESUCCESS)));
  SWIG_Python_SetConstant(d, "PJ_SSL_CERT_EISSUER_NOT_FOUND",SWIG_From_int(static_cast< int >(PJ_SSL_CERT_EISSUER_NOT_FOUND)));
  SWIG_Python_SetConstant(d, "PJ_SSL_CERT_EUNTRUSTED",SWIG_From_int(static_cast< int >(PJ_SSL_CERT_EUNTRUSTED)));
  SWIG_Python_SetConstant(d, "PJ_SSL_CERT_EVALIDITY_PERIOD",SWIG_From_int(static_cast< int >(PJ_SSL_CERT_EVALIDITY_PERIOD)));
  SWIG_Python_SetConstant(d, "PJ_SSL_CERT_EINVALID_FORMAT",SWIG_From_int(static_cast< int >(PJ_SSL_CERT_EINVALID_FORMAT)));
  SWIG_Python_SetConstant(d, "PJ_SSL_CERT_EINVALID_PURPOSE",SWIG_From_int(static_cast< int >(PJ_SSL_CERT_EINVALID_PURPOSE)));
  SWIG_Python_SetConstant(d, "PJ_SSL_CERT_EISSUER_MISMATCH",SWIG_From_int(static_cast< int >(PJ_SSL_CERT_EISSUER_MISMATCH)));
  SWIG_Python_SetConstant(d, "PJ_SSL_CERT_ECRL_FAILURE",SWIG_From_int(static_cast< int >(PJ_SSL_CERT_ECRL_FAILURE)));
  SWIG_Python_SetConstant(d, "PJ_SSL_CERT_EREVOKED",SWIG_From_int(static_cast< int >(PJ_SSL_CERT_EREVOKED)));
  SWIG_Python_SetConstant(d, "PJ_SSL_CERT_ECHAIN_TOO_LONG",SWIG_From_int(static_cast< int >(PJ_SSL_CERT_ECHAIN_TOO_LONG)));
  SWIG_Python_SetConstant(d, "PJ_SSL_CERT_EIDENTITY_NOT_MATCH",SWIG_From_int(static_cast< int >(PJ_SSL_CERT_EIDENTITY_NOT_MATCH)));
  SWIG_Python_SetConstant(d, "PJ_SSL_CERT_EUNKNOWN",SWIG_From_int(static_cast< int >(PJ_SSL_CERT_EUNKNOWN)));
  SWIG_Python_SetConstant(d, "PJ_ICE_SESS_TRICKLE_DISABLED",SWIG_From_int(static_cast< int >(PJ_ICE_SESS_TRICKLE_DISABLED)));
  SWIG_Python_SetConstant(d, "PJ_ICE_SESS_TRICKLE_HALF",SWIG_From_int(static_cast< int >(PJ_ICE_SESS_TRICKLE_HALF)));
  SWIG_Python_SetConstant(d, "PJ_ICE_SESS_TRICKLE_FULL",SWIG_From_int(static_cast< int >(PJ_ICE_SESS_TRICKLE_FULL)));
  SWIG_Python_SetConstant(d, "PJ_STUN_NAT_TYPE_UNKNOWN",SWIG_From_int(static_cast< int >(PJ_STUN_NAT_TYPE_UNKNOWN)));
  SWIG_Python_SetConstant(d, "PJ_STUN_NAT_TYPE_ERR_UNKNOWN",SWIG_From_int(static_cast< int >(PJ_STUN_NAT_TYPE_ERR_UNKNOWN)));
  SWIG_Python_SetConstant(d, "PJ_STUN_NAT_TYPE_OPEN",SWIG_From_int(static_cast< int >(PJ_STUN_NAT_TYPE_OPEN)));
  SWIG_Python_SetConstant(d, "PJ_STUN_NAT_TYPE_BLOCKED",SWIG_From_int(static_cast< int >(PJ_STUN_NAT_TYPE_BLOCKED)));
  SWIG_Python_SetConstant(d, "PJ_STUN_NAT_TYPE_SYMMETRIC_UDP",SWIG_From_int(static_cast< int >(PJ_STUN_NAT_TYPE_SYMMETRIC_UDP)));
  SWIG_Python_SetConstant(d, "PJ_STUN_NAT_TYPE_FULL_CONE",SWIG_From_int(static_cast< int >(PJ_STUN_NAT_TYPE_FULL_CONE)));
  SWIG_Python_SetConstant(d, "PJ_STUN_NAT_TYPE_SYMMETRIC",SWIG_From_int(static_cast< int >(PJ_STUN_NAT_TYPE_SYMMETRIC)));
  SWIG_Python_SetConstant(d, "PJ_STUN_NAT_TYPE_RESTRICTED",SWIG_From_int(static_cast< int >(PJ_STUN_NAT_TYPE_RESTRICTED)));
  SWIG_Python_SetConstant(d, "PJ_STUN_NAT_TYPE_PORT_RESTRICTED",SWIG_From_int(static_cast< int >(PJ_STUN_NAT_TYPE_PORT_RESTRICTED)));
  SWIG_Python_SetConstant(d, "PJ_TURN_TP_UDP",SWIG_From_int(static_cast< int >(PJ_TURN_TP_UDP)));
  SWIG_Python_SetConstant(d, "PJ_TURN_TP_TCP",SWIG_From_int(static_cast< int >(PJ_TURN_TP_TCP)));
  SWIG_Python_SetConstant(d, "PJ_TURN_TP_TLS",SWIG_From_int(static_cast< int >(PJ_TURN_TP_TLS)));
  SWIG_Python_SetConstant(d, "PJMEDIA_ECHO_DEFAULT",SWIG_From_int(static_cast< int >(PJMEDIA_ECHO_DEFAULT)));
  SWIG_Python_SetConstant(d, "PJMEDIA_ECHO_SPEEX",SWIG_From_int(static_cast< int >(PJMEDIA_ECHO_SPEEX)));
  SWIG_Python_SetConstant(d, "PJMEDIA_ECHO_SIMPLE",SWIG_From_int(static_cast< int >(PJMEDIA_ECHO_SIMPLE)));
  SWIG_Python_SetConstant(d, "PJMEDIA_ECHO_WEBRTC",SWIG_From_int(static_cast< int >(PJMEDIA_ECHO_WEBRTC)));
  SWIG_Python_SetConstant(d, "PJMEDIA_ECHO_ALGO_MASK",SWIG_From_int(static_cast< int >(PJMEDIA_ECHO_ALGO_MASK)));
  SWIG_Python_SetConstant(d, "PJMEDIA_ECHO_NO_LOCK",SWIG_From_int(static_cast< int >(PJMEDIA_ECHO_NO_LOCK)));
  SWIG_Python_SetConstant(d, "PJMEDIA_ECHO_USE_SIMPLE_FIFO",SWIG_From_int(static_cast< int >(PJMEDIA_ECHO_USE_SIMPLE_FIFO)));
  SWIG_Python_SetConstant(d, "PJMEDIA_ECHO_USE_SW_ECHO",SWIG_From_int(static_cast< int >(PJMEDIA_ECHO_USE_SW_ECHO)));
  SWIG_Python_SetConstant(d, "PJMEDIA_ECHO_USE_NOISE_SUPPRESSOR",SWIG_From_int(static_cast< int >(PJMEDIA_ECHO_USE_NOISE_SUPPRESSOR)));
  SWIG_Python_SetConstant(d, "PJMEDIA_ECHO_AGGRESSIVENESS_DEFAULT",SWIG_From_int(static_cast< int >(PJMEDIA_ECHO_AGGRESSIVENESS_DEFAULT)));
  SWIG_Python_SetConstant(d, "PJMEDIA_ECHO_AGGRESSIVENESS_CONSERVATIVE",SWIG_From_int(static_cast< int >(PJMEDIA_ECHO_AGGRESSIVENESS_CONSERVATIVE)));
  SWIG_Python_SetConstant(d, "PJMEDIA_ECHO_AGGRESSIVENESS_MODERATE",SWIG_From_int(static_cast< int >(PJMEDIA_ECHO_AGGRESSIVENESS_MODERATE)));
  SWIG_Python_SetConstant(d, "PJMEDIA_ECHO_AGGRESSIVENESS_AGGRESSIVE",SWIG_From_int(static_cast< int >(PJMEDIA_ECHO_AGGRESSIVENESS_AGGRESSIVE)));
  SWIG_Python_SetConstant(d, "PJMEDIA_ECHO_AGGRESSIVENESS_MASK",SWIG_From_int(static_cast< int >(PJMEDIA_ECHO_AGGRESSIVENESS_MASK)));
  SWIG_Python_SetConstant(d, "PJMEDIA_EVENT_NONE",SWIG_From_int(static_cast< int >(PJMEDIA_EVENT_NONE)));
  SWIG_Python_SetConstant(d, "PJMEDIA_EVENT_FMT_CHANGED",SWIG_From_int(static_cast< int >(PJMEDIA_EVENT_FMT_CHANGED)));
  SWIG_Python_SetConstant(d, "PJMEDIA_EVENT_WND_CLOSING",SWIG_From_int(static_cast< int >(PJMEDIA_EVENT_WND_CLOSING)));
  SWIG_Python_SetConstant(d, "PJMEDIA_EVENT_WND_CLOSED",SWIG_From_int(static_cast< int >(PJMEDIA_EVENT_WND_CLOSED)));
  SWIG_Python_SetConstant(d, "PJMEDIA_EVENT_WND_RESIZED",SWIG_From_int(static_cast< int >(PJMEDIA_EVENT_WND_RESIZED)));
  SWIG_Python_SetConstant(d, "PJMEDIA_EVENT_MOUSE_BTN_DOWN",SWIG_From_int(static_cast< int >(PJMEDIA_EVENT_MOUSE_BTN_DOWN)));
  SWIG_Python_SetConstant(d, "PJMEDIA_EVENT_KEYFRAME_FOUND",SWIG_From_int(static_cast< int >(PJMEDIA_EVENT_KEYFRAME_FOUND)));
  SWIG_Python_SetConstant(d, "PJMEDIA_EVENT_KEYFRAME_MISSING",SWIG_From_int(static_cast< int >(PJMEDIA_EVENT_KEYFRAME_MISSING)));
  SWIG_Python_SetConstant(d, "PJMEDIA_EVENT_ORIENT_CHANGED",SWIG_From_int(static_cast< int >(PJMEDIA_EVENT_ORIENT_CHANGED)));
  SWIG_Python_SetConstant(d, "PJMEDIA_EVENT_RX_RTCP_FB",SWIG_From_int(static_cast< int >(PJMEDIA_EVENT_RX_RTCP_FB)));
  SWIG_Python_SetConstant(d, "PJMEDIA_EVENT_AUD_DEV_ERROR",SWIG_From_int(static_cast< int >(PJMEDIA_EVENT_AUD_DEV_ERROR)));
  SWIG_Python_SetConstant(d, "PJMEDIA_EVENT_VID_DEV_ERROR",SWIG_From_int(static_cast< int >(PJMEDIA_EVENT_VID_DEV_ERROR)));
  SWIG_Python_SetConstant(d, "PJMEDIA_EVENT_MEDIA_TP_ERR",SWIG_From_int(static_cast< int >(PJMEDIA_EVENT_MEDIA_TP_ERR)));
  SWIG_Python_SetConstant(d, "PJMEDIA_EVENT_CALLBACK",SWIG_From_int(static_cast< int >(PJMEDIA_EVENT_CALLBACK)));
  SWIG_Python_SetConstant(d, "PJMEDIA_SRTP_DISABLED",SWIG_From_int(static_cast< int >(PJMEDIA_SRTP_DISABLED)));
  SWIG_Python_SetConstant(d, "PJMEDIA_SRTP_UNKNOWN",SWIG_From_int(static_cast< int >(PJMEDIA_SRTP_UNKNOWN)));
  SWIG_Python_SetConstant(d, "PJMEDIA_SRTP_OPTIONAL",SWIG_From_int(static_cast< int >(PJMEDIA_SRTP_OPTIONAL)));
  SWIG_Python_SetConstant(d, "PJMEDIA_SRTP_MANDATORY",SWIG_From_int(static_cast< int >(PJMEDIA_SRTP_MANDATORY)));
  SWIG_Python_SetConstant(d, "PJMEDIA_SRTP_NO_ENCRYPTION",SWIG_From_int(static_cast< int >(PJMEDIA_SRTP_NO_ENCRYPTION)));
  SWIG_Python_SetConstant(d, "PJMEDIA_SRTP_NO_AUTHENTICATION",SWIG_From_int(static_cast< int >(PJMEDIA_SRTP_NO_AUTHENTICATION)));
  SWIG_Python_SetConstant(d, "PJMEDIA_SRTP_KEYING_SDES",SWIG_From_int(static_cast< int >(PJMEDIA_SRTP_KEYING_SDES)));
  SWIG_Python_SetConstant(d, "PJMEDIA_SRTP_KEYING_DTLS_SRTP",SWIG_From_int(static_cast< int >(PJMEDIA_SRTP_KEYING_DTLS_SRTP)));
  SWIG_Python_SetConstant(d, "PJMEDIA_SRTP_KEYINGS_COUNT",SWIG_From_int(static_cast< int >(PJMEDIA_SRTP_KEYINGS_COUNT)));
  SWIG_Python_SetConstant(d, "PJMEDIA_VID_STREAM_RC_NONE",SWIG_From_int(static_cast< int >(PJMEDIA_VID_STREAM_RC_NONE)));
  SWIG_Python_SetConstant(d, "PJMEDIA_VID_STREAM_RC_SIMPLE_BLOCKING",SWIG_From_int(static_cast< int >(PJMEDIA_VID_STREAM_RC_SIMPLE_BLOCKING)));
  SWIG_Python_SetConstant(d, "PJMEDIA_VID_DEFAULT_CAPTURE_DEV",SWIG_From_int(static_cast< int >(PJMEDIA_VID_DEFAULT_CAPTURE_DEV)));
  SWIG_Python_SetConstant(d, "PJMEDIA_VID_DEFAULT_RENDER_DEV",SWIG_From_int(static_cast< int >(PJMEDIA_VID_DEFAULT_RENDER_DEV)));
  SWIG_Python_SetConstant(d, "PJMEDIA_VID_INVALID_DEV",SWIG_From_int(static_cast< int >(PJMEDIA_VID_INVALID_DEV)));
  SWIG_Python_SetConstant(d, "PJMEDIA_VID_DEV_CAP_FORMAT",SWIG_From_int(static_cast< int >(PJMEDIA_VID_DEV_CAP_FORMAT)));
  SWIG_Python_SetConstant(d, "PJMEDIA_VID_DEV_CAP_INPUT_SCALE",SWIG_From_int(static_cast< int >(PJMEDIA_VID_DEV_CAP_INPUT_SCALE)));
  SWIG_Python_SetConstant(d, "PJMEDIA_VID_DEV_CAP_OUTPUT_WINDOW",SWIG_From_int(static_cast< int >(PJMEDIA_VID_DEV_CAP_OUTPUT_WINDOW)));
  SWIG_Python_SetConstant(d, "PJMEDIA_VID_DEV_CAP_OUTPUT_RESIZE",SWIG_From_int(static_cast< int >(PJMEDIA_VID_DEV_CAP_OUTPUT_RESIZE)));
  SWIG_Python_SetConstant(d, "PJMEDIA_VID_DEV_CAP_OUTPUT_POSITION",SWIG_From_int(static_cast< int >(PJMEDIA_VID_DEV_CAP_OUTPUT_POSITION)));
  SWIG_Python_SetConstant(d, "PJMEDIA_VID_DEV_CAP_OUTPUT_HIDE",SWIG_From_int(static_cast< int >(PJMEDIA_VID_DEV_CAP_OUTPUT_HIDE)));
  SWIG_Python_SetConstant(d, "PJMEDIA_VID_DEV_CAP_INPUT_PREVIEW",SWIG_From_int(static_cast< int >(PJMEDIA_VID_DEV_CAP_INPUT_PREVIEW)));
  SWIG_Python_SetConstant(d, "PJMEDIA_VID_DEV_CAP_ORIENTATION",SWIG_From_int(static_cast< int >(PJMEDIA_VID_DEV_CAP_ORIENTATION)));
  SWIG_Python_SetConstant(d, "PJMEDIA_VID_DEV_CAP_SWITCH",SWIG_From_int(static_cast< int >(PJMEDIA_VID_DEV_CAP_SWITCH)));
  SWIG_Python_SetConstant(d, "PJMEDIA_VID_DEV_CAP_OUTPUT_WINDOW_FLAGS",SWIG_From_int(static_cast< int >(PJMEDIA_VID_DEV_CAP_OUTPUT_WINDOW_FLAGS)));
  SWIG_Python_SetConstant(d, "PJMEDIA_VID_DEV_CAP_OUTPUT_FULLSCREEN",SWIG_From_int(static_cast< int >(PJMEDIA_VID_DEV_CAP_OUTPUT_FULLSCREEN)));
  SWIG_Python_SetConstant(d, "PJMEDIA_VID_DEV_CAP_MAX",SWIG_From_int(static_cast< int >(PJMEDIA_VID_DEV_CAP_MAX)));
  SWIG_Python_SetConstant(d, "PJMEDIA_VID_DEV_WINDOWED",SWIG_From_int(static_cast< int >(PJMEDIA_VID_DEV_WINDOWED)));
  SWIG_Python_SetConstant(d, "PJMEDIA_VID_DEV_FULLSCREEN",SWIG_From_int(static_cast< int >(PJMEDIA_VID_DEV_FULLSCREEN)));
  SWIG_Python_SetConstant(d, "PJMEDIA_VID_DEV_FULLSCREEN_DESKTOP",SWIG_From_int(static_cast< int >(PJMEDIA_VID_DEV_FULLSCREEN_DESKTOP)));
  SWIG_Python_SetConstant(d, "PJMEDIA_AUD_DEV_ROUTE_DEFAULT",SWIG_From_int(static_cast< int >(PJMEDIA_AUD_DEV_ROUTE_DEFAULT)));
  SWIG_Python_SetConstant(d, "PJMEDIA_AUD_DEV_ROUTE_LOUDSPEAKER",SWIG_From_int(static_cast< int >(PJMEDIA_AUD_DEV_ROUTE_LOUDSPEAKER)));
  SWIG_Python_SetConstant(d, "PJMEDIA_AUD_DEV_ROUTE_EARPIECE",SWIG_From_int(static_cast< int >(PJMEDIA_AUD_DEV_ROUTE_EARPIECE)));
  SWIG_Python_SetConstant(d, "PJMEDIA_AUD_DEV_ROUTE_BLUETOOTH",SWIG_From_int(static_cast< int >(PJMEDIA_AUD_DEV_ROUTE_BLUETOOTH)));
  SWIG_Python_SetConstant(d, "PJMEDIA_AUD_DEV_ROUTE_CUSTOM",SWIG_From_int(static_cast< int >(PJMEDIA_AUD_DEV_ROUTE_CUSTOM)));
  SWIG_Python_SetConstant(d, "PJMEDIA_AUD_DEV_CAP_EXT_FORMAT",SWIG_From_int(static_cast< int >(PJMEDIA_AUD_DEV_CAP_EXT_FORMAT)));
  SWIG_Python_SetConstant(d, "PJMEDIA_AUD_DEV_CAP_INPUT_LATENCY",SWIG_From_int(static_cast< int >(PJMEDIA_AUD_DEV_CAP_INPUT_LATENCY)));
  SWIG_Python_SetConstant(d, "PJMEDIA_AUD_DEV_CAP_OUTPUT_LATENCY",SWIG_From_int(static_cast< int >(PJMEDIA_AUD_DEV_CAP_OUTPUT_LATENCY)));
  SWIG_Python_SetConstant(d, "PJMEDIA_AUD_DEV_CAP_INPUT_VOLUME_SETTING",SWIG_From_int(static_cast< int >(PJMEDIA_AUD_DEV_CAP_INPUT_VOLUME_SETTING)));
  SWIG_Python_SetConstant(d, "PJMEDIA_AUD_DEV_CAP_OUTPUT_VOLUME_SETTING",SWIG_From_int(static_cast< int >(PJMEDIA_AUD_DEV_CAP_OUTPUT_VOLUME_SETTING)));
  SWIG_Python_SetConstant(d, "PJMEDIA_AUD_DEV_CAP_INPUT_SIGNAL_METER",SWIG_From_int(static_cast< int >(PJMEDIA_AUD_DEV_CAP_INPUT_SIGNAL_METER)));
  SWIG_Python_SetConstant(d, "PJMEDIA_AUD_DEV_CAP_OUTPUT_SIGNAL_METER",SWIG_From_int(static_cast< int >(PJMEDIA_AUD_DEV_CAP_OUTPUT_SIGNAL_METER)));
  SWIG_Python_SetConstant(d, "PJMEDIA_AUD_DEV_CAP_INPUT_ROUTE",SWIG_From_int(static_cast< int >(PJMEDIA_AUD_DEV_CAP_INPUT_ROUTE)));
  SWIG_Python_SetConstant(d, "PJMEDIA_AUD_DEV_CAP_INPUT_SOURCE",SWIG_From_int(static_cast< int >(PJMEDIA_AUD_DEV_CAP_INPUT_SOURCE)));
  SWIG_Python_SetConstant(d, "PJMEDIA_AUD_DEV_CAP_OUTPUT_ROUTE",SWIG_From_int(static_cast< int >(PJMEDIA_AUD_DEV_CAP_OUTPUT_ROUTE)));
  SWIG_Python_SetConstant(d, "PJMEDIA_AUD_DEV_CAP_EC",SWIG_From_int(static_cast< int >(PJMEDIA_AUD_DEV_CAP_EC)));
  SWIG_Python_SetConstant(d, "PJMEDIA_AUD_DEV_CAP_EC_TAIL",SWIG_From_int(static_cast< int >(PJMEDIA_AUD_DEV_CAP_EC_TAIL)));
  SWIG_Python_SetConstant(d, "PJMEDIA_AUD_DEV_CAP_VAD",SWIG_From_int(static_cast< int >(PJMEDIA_AUD_DEV_CAP_VAD)));
  SWIG_Python_SetConstant(d, "PJMEDIA_AUD_DEV_CAP_CNG",SWIG_From_int(static_cast< int >(PJMEDIA_AUD_DEV_CAP_CNG)));
  SWIG_Python_SetConstant(d, "PJMEDIA_AUD_DEV_CAP_PLC",SWIG_From_int(static_cast< int >(PJMEDIA_AUD_DEV_CAP_PLC)));
  SWIG_Python_SetConstant(d, "PJMEDIA_AUD_DEV_CAP_MAX",SWIG_From_int(static_cast< int >(PJMEDIA_AUD_DEV_CAP_MAX)));
  SWIG_Python_SetConstant(d, "PJMEDIA_FILE_WRITE_PCM",SWIG_From_int(static_cast< int >(PJMEDIA_FILE_WRITE_PCM)));
  SWIG_Python_SetConstant(d, "PJMEDIA_FILE_WRITE_ALAW",SWIG_From_int(static_cast< int >(PJMEDIA_FILE_WRITE_ALAW)));
  SWIG_Python_SetConstant(d, "PJMEDIA_FILE_WRITE_ULAW",SWIG_From_int(static_cast< int >(PJMEDIA_FILE_WRITE_ULAW)));
  SWIG_Python_SetConstant(d, "PJMEDIA_FILE_NO_LOOP",SWIG_From_int(static_cast< int >(PJMEDIA_FILE_NO_LOOP)));
  SWIG_Python_SetConstant(d, "PJMEDIA_TYPE_NONE",SWIG_From_int(static_cast< int >(PJMEDIA_TYPE_NONE)));
  SWIG_Python_SetConstant(d, "PJMEDIA_TYPE_AUDIO",SWIG_From_int(static_cast< int >(PJMEDIA_TYPE_AUDIO)));
  SWIG_Python_SetConstant(d, "PJMEDIA_TYPE_VIDEO",SWIG_From_int(static_cast< int >(PJMEDIA_TYPE_VIDEO)));
  SWIG_Python_SetConstant(d, "PJMEDIA_TYPE_APPLICATION",SWIG_From_int(static_cast< int >(PJMEDIA_TYPE_APPLICATION)));
  SWIG_Python_SetConstant(d, "PJMEDIA_TYPE_UNKNOWN",SWIG_From_int(static_cast< int >(PJMEDIA_TYPE_UNKNOWN)));
  SWIG_Python_SetConstant(d, "PJMEDIA_DIR_NONE",SWIG_From_int(static_cast< int >(PJMEDIA_DIR_NONE)));
  SWIG_Python_SetConstant(d, "PJMEDIA_DIR_ENCODING",SWIG_From_int(static_cast< int >(PJMEDIA_DIR_ENCODING)));
  SWIG_Python_SetConstant(d, "PJMEDIA_DIR_CAPTURE",SWIG_From_int(static_cast< int >(PJMEDIA_DIR_CAPTURE)));
  SWIG_Python_SetConstant(d, "PJMEDIA_DIR_DECODING",SWIG_From_int(static_cast< int >(PJMEDIA_DIR_DECODING)));
  SWIG_Python_SetConstant(d, "PJMEDIA_DIR_PLAYBACK",SWIG_From_int(static_cast< int >(PJMEDIA_DIR_PLAYBACK)));
  SWIG_Python_SetConstant(d, "PJMEDIA_DIR_RENDER",SWIG_From_int(static_cast< int >(PJMEDIA_DIR_RENDER)));
  SWIG_Python_SetConstant(d, "PJMEDIA_DIR_ENCODING_DECODING",SWIG_From_int(static_cast< int >(PJMEDIA_DIR_ENCODING_DECODING)));
  SWIG_Python_SetConstant(d, "PJMEDIA_DIR_CAPTURE_PLAYBACK",SWIG_From_int(static_cast< int >(PJMEDIA_DIR_CAPTURE_PLAYBACK)));
  SWIG_Python_SetConstant(d, "PJMEDIA_DIR_CAPTURE_RENDER",SWIG_From_int(static_cast< int >(PJMEDIA_DIR_CAPTURE_RENDER)));
  SWIG_Python_SetConstant(d, "PJMEDIA_TP_PROTO_NONE",SWIG_From_int(static_cast< int >(PJMEDIA_TP_PROTO_NONE)));
  SWIG_Python_SetConstant(d, "PJMEDIA_TP_PROTO_UNKNOWN",SWIG_From_int(static_cast< int >(PJMEDIA_TP_PROTO_UNKNOWN)));
  SWIG_Python_SetConstant(d, "PJMEDIA_TP_PROTO_UDP",SWIG_From_int(static_cast< int >(PJMEDIA_TP_PROTO_UDP)));
  SWIG_Python_SetConstant(d, "PJMEDIA_TP_PROTO_RTP",SWIG_From_int(static_cast< int >(PJMEDIA_TP_PROTO_RTP)));
  SWIG_Python_SetConstant(d, "PJMEDIA_TP_PROTO_DTLS",SWIG_From_int(static_cast< int >(PJMEDIA_TP_PROTO_DTLS)));
  SWIG_Python_SetConstant(d, "PJMEDIA_TP_PROFILE_RTCP_FB",SWIG_From_int(static_cast< int >(PJMEDIA_TP_PROFILE_RTCP_FB)));
  SWIG_Python_SetConstant(d, "PJMEDIA_TP_PROFILE_SRTP",SWIG_From_int(static_cast< int >(PJMEDIA_TP_PROFILE_SRTP)));
  SWIG_Python_SetConstant(d, "PJMEDIA_TP_PROFILE_AVP",SWIG_From_int(static_cast< int >(PJMEDIA_TP_PROFILE_AVP)));
  SWIG_Python_SetConstant(d, "PJMEDIA_TP_PROTO_RTP_AVP",SWIG_From_int(static_cast< int >(PJMEDIA_TP_PROTO_RTP_AVP)));
  SWIG_Python_SetConstant(d, "PJMEDIA_TP_PROTO_RTP_SAVP",SWIG_From_int(static_cast< int >(PJMEDIA_TP_PROTO_RTP_SAVP)));
  SWIG_Python_SetConstant(d, "PJMEDIA_TP_PROTO_DTLS_SRTP",SWIG_From_int(static_cast< int >(PJMEDIA_TP_PROTO_DTLS_SRTP)));
  SWIG_Python_SetConstant(d, "PJMEDIA_TP_PROTO_RTP_AVPF",SWIG_From_int(static_cast< int >(PJMEDIA_TP_PROTO_RTP_AVPF)));
  SWIG_Python_SetConstant(d, "PJMEDIA_TP_PROTO_RTP_SAVPF",SWIG_From_int(static_cast< int >(PJMEDIA_TP_PROTO_RTP_SAVPF)));
  SWIG_Python_SetConstant(d, "PJMEDIA_TP_PROTO_DTLS_SRTPF",SWIG_From_int(static_cast< int >(PJMEDIA_TP_PROTO_DTLS_SRTPF)));
  SWIG_Python_SetConstant(d, "PJMEDIA_ORIENT_UNKNOWN",SWIG_From_int(static_cast< int >(PJMEDIA_ORIENT_UNKNOWN)));
  SWIG_Python_SetConstant(d, "PJMEDIA_ORIENT_NATURAL",SWIG_From_int(static_cast< int >(PJMEDIA_ORIENT_NATURAL)));
  SWIG_Python_SetConstant(d, "PJMEDIA_ORIENT_ROTATE_90DEG",SWIG_From_int(static_cast< int >(PJMEDIA_ORIENT_ROTATE_90DEG)));
  SWIG_Python_SetConstant(d, "PJMEDIA_ORIENT_ROTATE_180DEG",SWIG_From_int(static_cast< int >(PJMEDIA_ORIENT_ROTATE_180DEG)));
  SWIG_Python_SetConstant(d, "PJMEDIA_ORIENT_ROTATE_270DEG",SWIG_From_int(static_cast< int >(PJMEDIA_ORIENT_ROTATE_270DEG)));
  SWIG_Python_SetConstant(d, "PJMEDIA_FORMAT_L16",SWIG_From_int(static_cast< int >(PJMEDIA_FORMAT_L16)));
  SWIG_Python_SetConstant(d, "PJMEDIA_FORMAT_PCM",SWIG_From_int(static_cast< int >(PJMEDIA_FORMAT_PCM)));
  SWIG_Python_SetConstant(d, "PJMEDIA_FORMAT_PCMA",SWIG_From_int(static_cast< int >(PJMEDIA_FORMAT_PCMA)));
  SWIG_Python_SetConstant(d, "PJMEDIA_FORMAT_ALAW",SWIG_From_int(static_cast< int >(PJMEDIA_FORMAT_ALAW)));
  SWIG_Python_SetConstant(d, "PJMEDIA_FORMAT_PCMU",SWIG_From_int(static_cast< int >(PJMEDIA_FORMAT_PCMU)));
  SWIG_Python_SetConstant(d, "PJMEDIA_FORMAT_ULAW",SWIG_From_int(static_cast< int >(PJMEDIA_FORMAT_ULAW)));
  SWIG_Python_SetConstant(d, "PJMEDIA_FORMAT_AMR",SWIG_From_int(static_cast< int >(PJMEDIA_FORMAT_AMR)));
  SWIG_Python_SetConstant(d, "PJMEDIA_FORMAT_G729",SWIG_From_int(static_cast< int >(PJMEDIA_FORMAT_G729)));
  SWIG_Python_SetConstant(d, "PJMEDIA_FORMAT_ILBC",SWIG_From_int(static_cast< int >(PJMEDIA_FORMAT_ILBC)));
  SWIG_Python_SetConstant(d, "PJMEDIA_FORMAT_RGB24",SWIG_From_int(static_cast< int >(PJMEDIA_FORMAT_RGB24)));
  SWIG_Python_SetConstant(d, "PJMEDIA_FORMAT_RGBA",SWIG_From_int(static_cast< int >(PJMEDIA_FORMAT_RGBA)));
  SWIG_Python_SetConstant(d, "PJMEDIA_FORMAT_BGRA",SWIG_From_int(static_cast< int >(PJMEDIA_FORMAT_BGRA)));
  SWIG_Python_SetConstant(d, "PJMEDIA_FORMAT_RGB32",SWIG_From_int(static_cast< int >(PJMEDIA_FORMAT_RGB32)));
  SWIG_Python_SetConstant(d, "PJMEDIA_FORMAT_DIB",SWIG_From_int(static_cast< int >(PJMEDIA_FORMAT_DIB)));
  SWIG_Python_SetConstant(d, "PJMEDIA_FORMAT_GBRP",SWIG_From_int(static_cast< int >(PJMEDIA_FORMAT_GBRP)));
  SWIG_Python_SetConstant(d, "PJMEDIA_FORMAT_AYUV",SWIG_From_int(static_cast< int >(PJMEDIA_FORMAT_AYUV)));
  SWIG_Python_SetConstant(d, "PJMEDIA_FORMAT_YUY2",SWIG_From_int(static_cast< int >(PJMEDIA_FORMAT_YUY2)));
  SWIG_Python_SetConstant(d, "PJMEDIA_FORMAT_UYVY",SWIG_From_int(static_cast< int >(PJMEDIA_FORMAT_UYVY)));
  SWIG_Python_SetConstant(d, "PJMEDIA_FORMAT_YVYU",SWIG_From_int(static_cast< int >(PJMEDIA_FORMAT_YVYU)));
  SWIG_Python_SetConstant(d, "PJMEDIA_FORMAT_I420",SWIG_From_int(static_cast< int >(PJMEDIA_FORMAT_I420)));
  SWIG_Python_SetConstant(d, "PJMEDIA_FORMAT_IYUV",SWIG_From_int(static_cast< int >(PJMEDIA_FORMAT_IYUV)));
  SWIG_Python_SetConstant(d, "PJMEDIA_FORMAT_YV12",SWIG_From_int(static_cast< int >(PJMEDIA_FORMAT_YV12)));
  SWIG_Python_SetConstant(d, "PJMEDIA_FORMAT_NV12",SWIG_From_int(static_cast< int >(PJMEDIA_FORMAT_NV12)));
  SWIG_Python_SetConstant(d, "PJMEDIA_FORMAT_NV21",SWIG_From_int(static_cast< int >(PJMEDIA_FORMAT_NV21)));
  SWIG_Python_SetConstant(d, "PJMEDIA_FORMAT_I422",SWIG_From_int(static_cast< int >(PJMEDIA_FORMAT_I422)));
  SWIG_Python_SetConstant(d, "PJMEDIA_FORMAT_I420JPEG",SWIG_From_int(static_cast< int >(PJMEDIA_FORMAT_I420JPEG)));
  SWIG_Python_SetConstant(d, "PJMEDIA_FORMAT_I422JPEG",SWIG_From_int(static_cast< int >(PJMEDIA_FORMAT_I422JPEG)));
  SWIG_Python_SetConstant(d, "PJMEDIA_FORMAT_H261",SWIG_From_int(static_cast< int >(PJMEDIA_FORMAT_H261)));
  SWIG_Python_SetConstant(d, "PJMEDIA_FORMAT_H263",SWIG_From_int(static_cast< int >(PJMEDIA_FORMAT_H263)));
  SWIG_Python_SetConstant(d, "PJMEDIA_FORMAT_H263P",SWIG_From_int(static_cast< int >(PJMEDIA_FORMAT_H263P)));
  SWIG_Python_SetConstant(d, "PJMEDIA_FORMAT_H264",SWIG_From_int(static_cast< int >(PJMEDIA_FORMAT_H264)));
  SWIG_Python_SetConstant(d, "PJMEDIA_FORMAT_VP8",SWIG_From_int(static_cast< int >(PJMEDIA_FORMAT_VP8)));
  SWIG_Python_SetConstant(d, "PJMEDIA_FORMAT_VP9",SWIG_From_int(static_cast< int >(PJMEDIA_FORMAT_VP9)));
  SWIG_Python_SetConstant(d, "PJMEDIA_FORMAT_MJPEG",SWIG_From_int(static_cast< int >(PJMEDIA_FORMAT_MJPEG)));
  SWIG_Python_SetConstant(d, "PJMEDIA_FORMAT_MPEG1VIDEO",SWIG_From_int(static_cast< int >(PJMEDIA_FORMAT_MPEG1VIDEO)));
  SWIG_Python_SetConstant(d, "PJMEDIA_FORMAT_MPEG2VIDEO",SWIG_From_int(static_cast< int >(PJMEDIA_FORMAT_MPEG2VIDEO)));
  SWIG_Python_SetConstant(d, "PJMEDIA_FORMAT_MPEG4",SWIG_From_int(static_cast< int >(PJMEDIA_FORMAT_MPEG4)));
  SWIG_Python_SetConstant(d, "PJMEDIA_FORMAT_INVALID",SWIG_From_int(static_cast< int >(PJMEDIA_FORMAT_INVALID)));
  SWIG_Python_SetConstant(d, "PJMEDIA_VID_PACKING_UNKNOWN",SWIG_From_int(static_cast< int >(PJMEDIA_VID_PACKING_UNKNOWN)));
  SWIG_Python_SetConstant(d, "PJMEDIA_VID_PACKING_PACKETS",SWIG_From_int(static_cast< int >(PJMEDIA_VID_PACKING_PACKETS)));
  SWIG_Python_SetConstant(d, "PJMEDIA_VID_PACKING_WHOLE",SWIG_From_int(static_cast< int >(PJMEDIA_VID_PACKING_WHOLE)));
  SWIG_Python_SetConstant(d, "PJMEDIA_RTCP_FB_ACK",SWIG_From_int(static_cast< int >(PJMEDIA_RTCP_FB_ACK)));
  SWIG_Python_SetConstant(d, "PJMEDIA_RTCP_FB_NACK",SWIG_From_int(static_cast< int >(PJMEDIA_RTCP_FB_NACK)));
  SWIG_Python_SetConstant(d, "PJMEDIA_RTCP_FB_TRR_INT",SWIG_From_int(static_cast< int >(PJMEDIA_RTCP_FB_TRR_INT)));
  SWIG_Python_SetConstant(d, "PJMEDIA_RTCP_FB_OTHER",SWIG_From_int(static_cast< int >(PJMEDIA_RTCP_FB_OTHER)));
  SWIG_Python_SetConstant(d, "PJSIP_CRED_DATA_PLAIN_PASSWD",SWIG_From_int(static_cast< int >(PJSIP_CRED_DATA_PLAIN_PASSWD)));
  SWIG_Python_SetConstant(d, "PJSIP_CRED_DATA_DIGEST",SWIG_From_int(static_cast< int >(PJSIP_CRED_DATA_DIGEST)));
  SWIG_Python_SetConstant(d, "PJSIP_CRED_DATA_EXT_AKA",SWIG_From_int(static_cast< int >(PJSIP_CRED_DATA_EXT_AKA)));
  SWIG_Python_SetConstant(d, "PJSIP_DIALOG_CAP_UNSUPPORTED",SWIG_From_int(static_cast< int >(PJSIP_DIALOG_CAP_UNSUPPORTED)));
  SWIG_Python_SetConstant(d, "PJSIP_DIALOG_CAP_SUPPORTED",SWIG_From_int(static_cast< int >(PJSIP_DIALOG_CAP_SUPPORTED)));
  SWIG_Python_SetConstant(d, "PJSIP_DIALOG_CAP_UNKNOWN",SWIG_From_int(static_cast< int >(PJSIP_DIALOG_CAP_UNKNOWN)));
  SWIG_Python_SetConstant(d, "PJSIP_EVENT_UNKNOWN",SWIG_From_int(static_cast< int >(PJSIP_EVENT_UNKNOWN)));
  SWIG_Python_SetConstant(d, "PJSIP_EVENT_TIMER",SWIG_From_int(static_cast< int >(PJSIP_EVENT_TIMER)));
  SWIG_Python_SetConstant(d, "PJSIP_EVENT_TX_MSG",SWIG_From_int(static_cast< int >(PJSIP_EVENT_TX_MSG)));
  SWIG_Python_SetConstant(d, "PJSIP_EVENT_RX_MSG",SWIG_From_int(static_cast< int >(PJSIP_EVENT_RX_MSG)));
  SWIG_Python_SetConstant(d, "PJSIP_EVENT_TRANSPORT_ERROR",SWIG_From_int(static_cast< int >(PJSIP_EVENT_TRANSPORT_ERROR)));
  SWIG_Python_SetConstant(d, "PJSIP_EVENT_TSX_STATE",SWIG_From_int(static_cast< int >(PJSIP_EVENT_TSX_STATE)));
  SWIG_Python_SetConstant(d, "PJSIP_EVENT_USER",SWIG_From_int(static_cast< int >(PJSIP_EVENT_USER)));
  SWIG_Python_SetConstant(d, "PJSIP_SC_NULL",SWIG_From_int(static_cast< int >(PJSIP_SC_NULL)));
  SWIG_Python_SetConstant(d, "PJSIP_SC_TRYING",SWIG_From_int(static_cast< int >(PJSIP_SC_TRYING)));
  SWIG_Python_SetConstant(d, "PJSIP_SC_RINGING",SWIG_From_int(static_cast< int >(PJSIP_SC_RINGING)));
  SWIG_Python_SetConstant(d, "PJSIP_SC_CALL_BEING_FORWARDED",SWIG_From_int(static_cast< int >(PJSIP_SC_CALL_BEING_FORWARDED)));
  SWIG_Python_SetConstant(d, "PJSIP_SC_QUEUED",SWIG_From_int(static_cast< int >(PJSIP_SC_QUEUED)));
  SWIG_Python_SetConstant(d, "PJSIP_SC_PROGRESS",SWIG_From_int(static_cast< int >(PJSIP_SC_PROGRESS)));
  SWIG_Python_SetConstant(d, "PJSIP_SC_EARLY_DIALOG_TERMINATED",SWIG_From_int(static_cast< int >(PJSIP_SC_EARLY_DIALOG_TERMINATED)));
  SWIG_Python_SetConstant(d, "PJSIP_SC_OK",SWIG_From_int(static_cast< int >(PJSIP_SC_OK)));
  SWIG_Python_SetConstant(d, "PJSIP_SC_ACCEPTED",SWIG_From_int(static_cast< int >(PJSIP_SC_ACCEPTED)));
  SWIG_Python_SetConstant(d, "PJSIP_SC_NO_NOTIFICATION",SWIG_From_int(static_cast< int >(PJSIP_SC_NO_NOTIFICATION)));
  SWIG_Python_SetConstant(d, "PJSIP_SC_MULTIPLE_CHOICES",SWIG_From_int(static_cast< int >(PJSIP_SC_MULTIPLE_CHOICES)));
  SWIG_Python_SetConstant(d, "PJSIP_SC_MOVED_PERMANENTLY",SWIG_From_int(static_cast< int >(PJSIP_SC_MOVED_PERMANENTLY)));
  SWIG_Python_SetConstant(d, "PJSIP_SC_MOVED_TEMPORARILY",SWIG_From_int(static_cast< int >(PJSIP_SC_MOVED_TEMPORARILY)));
  SWIG_Python_SetConstant(d, "PJSIP_SC_USE_PROXY",SWIG_From_int(static_cast< int >(PJSIP_SC_USE_PROXY)));
  SWIG_Python_SetConstant(d, "PJSIP_SC_ALTERNATIVE_SERVICE",SWIG_From_int(static_cast< int >(PJSIP_SC_ALTERNATIVE_SERVICE)));
  SWIG_Python_SetConstant(d, "PJSIP_SC_BAD_REQUEST",SWIG_From_int(static_cast< int >(PJSIP_SC_BAD_REQUEST)));
  SWIG_Python_SetConstant(d, "PJSIP_SC_UNAUTHORIZED",SWIG_From_int(static_cast< int >(PJSIP_SC_UNAUTHORIZED)));
  SWIG_Python_SetConstant(d, "PJSIP_SC_PAYMENT_REQUIRED",SWIG_From_int(static_cast< int >(PJSIP_SC_PAYMENT_REQUIRED)));
  SWIG_Python_SetConstant(d, "PJSIP_SC_FORBIDDEN",SWIG_From_int(static_cast< int >(PJSIP_SC_FORBIDDEN)));
  SWIG_Python_SetConstant(d, "PJSIP_SC_NOT_FOUND",SWIG_From_int(static_cast< int >(PJSIP_SC_NOT_FOUND)));
  SWIG_Python_SetConstant(d, "PJSIP_SC_METHOD_NOT_ALLOWED",SWIG_From_int(static_cast< int >(PJSIP_SC_METHOD_NOT_ALLOWED)));
  SWIG_Python_SetConstant(d, "PJSIP_SC_NOT_ACCEPTABLE",SWIG_From_int(static_cast< int >(PJSIP_SC_NOT_ACCEPTABLE)));
  SWIG_Python_SetConstant(d, "PJSIP_SC_PROXY_AUTHENTICATION_REQUIRED",SWIG_From_int(static_cast< int >(PJSIP_SC_PROXY_AUTHENTICATION_REQUIRED)));
  SWIG_Python_SetConstant(d, "PJSIP_SC_REQUEST_TIMEOUT",SWIG_From_int(static_cast< int >(PJSIP_SC_REQUEST_TIMEOUT)));
  SWIG_Python_SetConstant(d, "PJSIP_SC_CONFLICT",SWIG_From_int(static_cast< int >(PJSIP_SC_CONFLICT)));
  SWIG_Python_SetConstant(d, "PJSIP_SC_GONE",SWIG_From_int(static_cast< int >(PJSIP_SC_GONE)));
  SWIG_Python_SetConstant(d, "PJSIP_SC_LENGTH_REQUIRED",SWIG_From_int(static_cast< int >(PJSIP_SC_LENGTH_REQUIRED)));
  SWIG_Python_SetConstant(d, "PJSIP_SC_CONDITIONAL_REQUEST_FAILED",SWIG_From_int(static_cast< int >(PJSIP_SC_CONDITIONAL_REQUEST_FAILED)));
  SWIG_Python_SetConstant(d, "PJSIP_SC_REQUEST_ENTITY_TOO_LARGE",SWIG_From_int(static_cast< int >(PJSIP_SC_REQUEST_ENTITY_TOO_LARGE)));
  SWIG_Python_SetConstant(d, "PJSIP_SC_REQUEST_URI_TOO_LONG",SWIG_From_int(static_cast< int >(PJSIP_SC_REQUEST_URI_TOO_LONG)));
  SWIG_Python_SetConstant(d, "PJSIP_SC_UNSUPPORTED_MEDIA_TYPE",SWIG_From_int(static_cast< int >(PJSIP_SC_UNSUPPORTED_MEDIA_TYPE)));
  SWIG_Python_SetConstant(d, "PJSIP_SC_UNSUPPORTED_URI_SCHEME",SWIG_From_int(static_cast< int >(PJSIP_SC_UNSUPPORTED_URI_SCHEME)));
  SWIG_Python_SetConstant(d, "PJSIP_SC_UNKNOWN_RESOURCE_PRIORITY",SWIG_From_int(static_cast< int >(PJSIP_SC_UNKNOWN_RESOURCE_PRIORITY)));
  SWIG_Python_SetConstant(d, "PJSIP_SC_BAD_EXTENSION",SWIG_From_int(static_cast< int >(PJSIP_SC_BAD_EXTENSION)));
  SWIG_Python_SetConstant(d, "PJSIP_SC_EXTENSION_REQUIRED",SWIG_From_int(static_cast< int >(PJSIP_SC_EXTENSION_REQUIRED)));
  SWIG_Python_SetConstant(d, "PJSIP_SC_SESSION_TIMER_TOO_SMALL",SWIG_From_int(static_cast< int >(PJSIP_SC_SESSION_TIMER_TOO_SMALL)));
  SWIG_Python_SetConstant(d, "PJSIP_SC_INTERVAL_TOO_BRIEF",SWIG_From_int(static_cast< int >(PJSIP_SC_INTERVAL_TOO_BRIEF)));
  SWIG_Python_SetConstant(d, "PJSIP_SC_BAD_LOCATION_INFORMATION",SWIG_From_int(static_cast< int >(PJSIP_SC_BAD_LOCATION_INFORMATION)));
  SWIG_Python_SetConstant(d, "PJSIP_SC_USE_IDENTITY_HEADER",SWIG_From_int(static_cast< int >(PJSIP_SC_USE_IDENTITY_HEADER)));
  SWIG_Python_SetConstant(d, "PJSIP_SC_PROVIDE_REFERRER_HEADER",SWIG_From_int(static_cast< int >(PJSIP_SC_PROVIDE_REFERRER_HEADER)));
  SWIG_Python_SetConstant(d, "PJSIP_SC_FLOW_FAILED",SWIG_From_int(static_cast< int >(PJSIP_SC_FLOW_FAILED)));
  SWIG_Python_SetConstant(d, "PJSIP_SC_ANONIMITY_DISALLOWED",SWIG_From_int(static_cast< int >(PJSIP_SC_ANONIMITY_DISALLOWED)));
  SWIG_Python_SetConstant(d, "PJSIP_SC_BAD_IDENTITY_INFO",SWIG_From_int(static_cast< int >(PJSIP_SC_BAD_IDENTITY_INFO)));
  SWIG_Python_SetConstant(d, "PJSIP_SC_UNSUPPORTED_CERTIFICATE",SWIG_From_int(static_cast< int >(PJSIP_SC_UNSUPPORTED_CERTIFICATE)));
  SWIG_Python_SetConstant(d, "PJSIP_SC_INVALID_IDENTITY_HEADER",SWIG_From_int(static_cast< int >(PJSIP_SC_INVALID_IDENTITY_HEADER)));
  SWIG_Python_SetConstant(d, "PJSIP_SC_FIRST_HOP_LACKS_OUTBOUND_SUPPORT",SWIG_From_int(static_cast< int >(PJSIP_SC_FIRST_HOP_LACKS_OUTBOUND_SUPPORT)));
  SWIG_Python_SetConstant(d, "PJSIP_SC_MAX_BREADTH_EXCEEDED",SWIG_From_int(static_cast< int >(PJSIP_SC_MAX_BREADTH_EXCEEDED)));
  SWIG_Python_SetConstant(d, "PJSIP_SC_BAD_INFO_PACKAGE",SWIG_From_int(static_cast< int >(PJSIP_SC_BAD_INFO_PACKAGE)));
  SWIG_Python_SetConstant(d, "PJSIP_SC_CONSENT_NEEDED",SWIG_From_int(static_cast< int >(PJSIP_SC_CONSENT_NEEDED)));
  SWIG_Python_SetConstant(d, "PJSIP_SC_TEMPORARILY_UNAVAILABLE",SWIG_From_int(static_cast< int >(PJSIP_SC_TEMPORARILY_UNAVAILABLE)));
  SWIG_Python_SetConstant(d, "PJSIP_SC_CALL_TSX_DOES_NOT_EXIST",SWIG_From_int(static_cast< int >(PJSIP_SC_CALL_TSX_DOES_NOT_EXIST)));
  SWIG_Python_SetConstant(d, "PJSIP_SC_LOOP_DETECTED",SWIG_From_int(static_cast< int >(PJSIP_SC_LOOP_DETECTED)));
  SWIG_Python_SetConstant(d, "PJSIP_SC_TOO_MANY_HOPS",SWIG_From_int(static_cast< int >(PJSIP_SC_TOO_MANY_HOPS)));
  SWIG_Python_SetConstant(d, "PJSIP_SC_ADDRESS_INCOMPLETE",SWIG_From_int(static_cast< int >(PJSIP_SC_ADDRESS_INCOMPLETE)));
  SWIG_Python_SetConstant(d, "PJSIP_AC_AMBIGUOUS",SWIG_From_int(static_cast< int >(PJSIP_AC_AMBIGUOUS)));
  SWIG_Python_SetConstant(d, "PJSIP_SC_BUSY_HERE",SWIG_From_int(static_cast< int >(PJSIP_SC_BUSY_HERE)));
  SWIG_Python_SetConstant(d, "PJSIP_SC_REQUEST_TERMINATED",SWIG_From_int(static_cast< int >(PJSIP_SC_REQUEST_TERMINATED)));
  SWIG_Python_SetConstant(d, "PJSIP_SC_NOT_ACCEPTABLE_HERE",SWIG_From_int(static_cast< int >(PJSIP_SC_NOT_ACCEPTABLE_HERE)));
  SWIG_Python_SetConstant(d, "PJSIP_SC_BAD_EVENT",SWIG_From_int(static_cast< int >(PJSIP_SC_BAD_EVENT)));
  SWIG_Python_SetConstant(d, "PJSIP_SC_REQUEST_UPDATED",SWIG_From_int(static_cast< int >(PJSIP_SC_REQUEST_UPDATED)));
  SWIG_Python_SetConstant(d, "PJSIP_SC_REQUEST_PENDING",SWIG_From_int(static_cast< int >(PJSIP_SC_REQUEST_PENDING)));
  SWIG_Python_SetConstant(d, "PJSIP_SC_UNDECIPHERABLE",SWIG_From_int(static_cast< int >(PJSIP_SC_UNDECIPHERABLE)));
  SWIG_Python_SetConstant(d, "PJSIP_SC_SECURITY_AGREEMENT_NEEDED",SWIG_From_int(static_cast< int >(PJSIP_SC_SECURITY_AGREEMENT_NEEDED)));
  SWIG_Python_SetConstant(d, "PJSIP_SC_INTERNAL_SERVER_ERROR",SWIG_From_int(static_cast< int >(PJSIP_SC_INTERNAL_SERVER_ERROR)));
  SWIG_Python_SetConstant(d, "PJSIP_SC_NOT_IMPLEMENTED",SWIG_From_int(static_cast< int >(PJSIP_SC_NOT_IMPLEMENTED)));
  SWIG_Python_SetConstant(d, "PJSIP_SC_BAD_GATEWAY",SWIG_From_int(static_cast< int >(PJSIP_SC_BAD_GATEWAY)));
  SWIG_Python_SetConstant(d, "PJSIP_SC_SERVICE_UNAVAILABLE",SWIG_From_int(static_cast< int >(PJSIP_SC_SERVICE_UNAVAILABLE)));
  SWIG_Python_SetConstant(d, "PJSIP_SC_SERVER_TIMEOUT",SWIG_From_int(static_cast< int >(PJSIP_SC_SERVER_TIMEOUT)));
  SWIG_Python_SetConstant(d, "PJSIP_SC_VERSION_NOT_SUPPORTED",SWIG_From_int(static_cast< int >(PJSIP_SC_VERSION_NOT_SUPPORTED)));
  SWIG_Python_SetConstant(d, "PJSIP_SC_MESSAGE_TOO_LARGE",SWIG_From_int(static_cast< int >(PJSIP_SC_MESSAGE_TOO_LARGE)));
  SWIG_Python_SetConstant(d, "PJSIP_SC_PUSH_NOTIFICATION_SERVICE_NOT_SUPPORTED",SWIG_From_int(static_cast< int >(PJSIP_SC_PUSH_NOTIFICATION_SERVICE_NOT_SUPPORTED)));
  SWIG_Python_SetConstant(d, "PJSIP_SC_PRECONDITION_FAILURE",SWIG_From_int(static_cast< int >(PJSIP_SC_PRECONDITION_FAILURE)));
  SWIG_Python_SetConstant(d, "PJSIP_SC_BUSY_EVERYWHERE",SWIG_From_int(static_cast< int >(PJSIP_SC_BUSY_EVERYWHERE)));
  SWIG_Python_SetConstant(d, "PJSIP_SC_DECLINE",SWIG_From_int(static_cast< int >(PJSIP_SC_DECLINE)));
  SWIG_Python_SetConstant(d, "PJSIP_SC_DOES_NOT_EXIST_ANYWHERE",SWIG_From_int(static_cast< int >(PJSIP_SC_DOES_NOT_EXIST_ANYWHERE)));
  SWIG_Python_SetConstant(d, "PJSIP_SC_NOT_ACCEPTABLE_ANYWHERE",SWIG_From_int(static_cast< int >(PJSIP_SC_NOT_ACCEPTABLE_ANYWHERE)));
  SWIG_Python_SetConstant(d, "PJSIP_SC_UNWANTED",SWIG_From_int(static_cast< int >(PJSIP_SC_UNWANTED)));
  SWIG_Python_SetConstant(d, "PJSIP_SC_REJECTED",SWIG_From_int(static_cast< int >(PJSIP_SC_REJECTED)));
  SWIG_Python_SetConstant(d, "PJSIP_SC_TSX_TIMEOUT",SWIG_From_int(static_cast< int >(PJSIP_SC_TSX_TIMEOUT)));
  SWIG_Python_SetConstant(d, "PJSIP_SC_TSX_TRANSPORT_ERROR",SWIG_From_int(static_cast< int >(PJSIP_SC_TSX_TRANSPORT_ERROR)));
  SWIG_Python_SetConstant(d, "PJSIP_SC__force_32bit",SWIG_From_int(static_cast< int >(PJSIP_SC__force_32bit)));
  SWIG_Python_SetConstant(d, "PJSIP_H_ACCEPT",SWIG_From_int(static_cast< int >(PJSIP_H_ACCEPT)));
  SWIG_Python_SetConstant(d, "PJSIP_H_ACCEPT_ENCODING_UNIMP",SWIG_From_int(static_cast< int >(PJSIP_H_ACCEPT_ENCODING_UNIMP)));
  SWIG_Python_SetConstant(d, "PJSIP_H_ACCEPT_LANGUAGE_UNIMP",SWIG_From_int(static_cast< int >(PJSIP_H_ACCEPT_LANGUAGE_UNIMP)));
  SWIG_Python_SetConstant(d, "PJSIP_H_ALERT_INFO_UNIMP",SWIG_From_int(static_cast< int >(PJSIP_H_ALERT_INFO_UNIMP)));
  SWIG_Python_SetConstant(d, "PJSIP_H_ALLOW",SWIG_From_int(static_cast< int >(PJSIP_H_ALLOW)));
  SWIG_Python_SetConstant(d, "PJSIP_H_AUTHENTICATION_INFO_UNIMP",SWIG_From_int(static_cast< int >(PJSIP_H_AUTHENTICATION_INFO_UNIMP)));
  SWIG_Python_SetConstant(d, "PJSIP_H_AUTHORIZATION",SWIG_From_int(static_cast< int >(PJSIP_H_AUTHORIZATION)));
  SWIG_Python_SetConstant(d, "PJSIP_H_CALL_ID",SWIG_From_int(static_cast< int >(PJSIP_H_CALL_ID)));
  SWIG_Python_SetConstant(d, "PJSIP_H_CALL_INFO_UNIMP",SWIG_From_int(static_cast< int >(PJSIP_H_CALL_INFO_UNIMP)));
  SWIG_Python_SetConstant(d, "PJSIP_H_CONTACT",SWIG_From_int(static_cast< int >(PJSIP_H_CONTACT)));
  SWIG_Python_SetConstant(d, "PJSIP_H_CONTENT_DISPOSITION_UNIMP",SWIG_From_int(static_cast< int >(PJSIP_H_CONTENT_DISPOSITION_UNIMP)));
  SWIG_Python_SetConstant(d, "PJSIP_H_CONTENT_ENCODING_UNIMP",SWIG_From_int(static_cast< int >(PJSIP_H_CONTENT_ENCODING_UNIMP)));
  SWIG_Python_SetConstant(d, "PJSIP_H_CONTENT_LANGUAGE_UNIMP",SWIG_From_int(static_cast< int >(PJSIP_H_CONTENT_LANGUAGE_UNIMP)));
  SWIG_Python_SetConstant(d, "PJSIP_H_CONTENT_LENGTH",SWIG_From_int(static_cast< int >(PJSIP_H_CONTENT_LENGTH)));
  SWIG_Python_SetConstant(d, "PJSIP_H_CONTENT_TYPE",SWIG_From_int(static_cast< int >(PJSIP_H_CONTENT_TYPE)));
  SWIG_Python_SetConstant(d, "PJSIP_H_CSEQ",SWIG_From_int(static_cast< int >(PJSIP_H_CSEQ)));
  SWIG_Python_SetConstant(d, "PJSIP_H_DATE_UNIMP",SWIG_From_int(static_cast< int >(PJSIP_H_DATE_UNIMP)));
  SWIG_Python_SetConstant(d, "PJSIP_H_ERROR_INFO_UNIMP",SWIG_From_int(static_cast< int >(PJSIP_H_ERROR_INFO_UNIMP)));
  SWIG_Python_SetConstant(d, "PJSIP_H_EXPIRES",SWIG_From_int(static_cast< int >(PJSIP_H_EXPIRES)));
  SWIG_Python_SetConstant(d, "PJSIP_H_FROM",SWIG_From_int(static_cast< int >(PJSIP_H_FROM)));
  SWIG_Python_SetConstant(d, "PJSIP_H_IN_REPLY_TO_UNIMP",SWIG_From_int(static_cast< int >(PJSIP_H_IN_REPLY_TO_UNIMP)));
  SWIG_Python_SetConstant(d, "PJSIP_H_MAX_FORWARDS",SWIG_From_int(static_cast< int >(PJSIP_H_MAX_FORWARDS)));
  SWIG_Python_SetConstant(d, "PJSIP_H_MIME_VERSION_UNIMP",SWIG_From_int(static_cast< int >(PJSIP_H_MIME_VERSION_UNIMP)));
  SWIG_Python_SetConstant(d, "PJSIP_H_MIN_EXPIRES",SWIG_From_int(static_cast< int >(PJSIP_H_MIN_EXPIRES)));
  SWIG_Python_SetConstant(d, "PJSIP_H_ORGANIZATION_UNIMP",SWIG_From_int(static_cast< int >(PJSIP_H_ORGANIZATION_UNIMP)));
  SWIG_Python_SetConstant(d, "PJSIP_H_PRIORITY_UNIMP",SWIG_From_int(static_cast< int >(PJSIP_H_PRIORITY_UNIMP)));
  SWIG_Python_SetConstant(d, "PJSIP_H_PROXY_AUTHENTICATE",SWIG_From_int(static_cast< int >(PJSIP_H_PROXY_AUTHENTICATE)));
  SWIG_Python_SetConstant(d, "PJSIP_H_PROXY_AUTHORIZATION",SWIG_From_int(static_cast< int >(PJSIP_H_PROXY_AUTHORIZATION)));
  SWIG_Python_SetConstant(d, "PJSIP_H_PROXY_REQUIRE_UNIMP",SWIG_From_int(static_cast< int >(PJSIP_H_PROXY_REQUIRE_UNIMP)));
  SWIG_Python_SetConstant(d, "PJSIP_H_RECORD_ROUTE",SWIG_From_int(static_cast< int >(PJSIP_H_RECORD_ROUTE)));
  SWIG_Python_SetConstant(d, "PJSIP_H_REPLY_TO_UNIMP",SWIG_From_int(static_cast< int >(PJSIP_H_REPLY_TO_UNIMP)));
  SWIG_Python_SetConstant(d, "PJSIP_H_REQUIRE",SWIG_From_int(static_cast< int >(PJSIP_H_REQUIRE)));
  SWIG_Python_SetConstant(d, "PJSIP_H_RETRY_AFTER",SWIG_From_int(static_cast< int >(PJSIP_H_RETRY_AFTER)));
  SWIG_Python_SetConstant(d, "PJSIP_H_ROUTE",SWIG_From_int(static_cast< int >(PJSIP_H_ROUTE)));
  SWIG_Python_SetConstant(d, "PJSIP_H_SERVER_UNIMP",SWIG_From_int(static_cast< int >(PJSIP_H_SERVER_UNIMP)));
  SWIG_Python_SetConstant(d, "PJSIP_H_SUBJECT_UNIMP",SWIG_From_int(static_cast< int >(PJSIP_H_SUBJECT_UNIMP)));
  SWIG_Python_SetConstant(d, "PJSIP_H_SUPPORTED",SWIG_From_int(static_cast< int >(PJSIP_H_SUPPORTED)));
  SWIG_Python_SetConstant(d, "PJSIP_H_TIMESTAMP_UNIMP",SWIG_From_int(static_cast< int >(PJSIP_H_TIMESTAMP_UNIMP)));
  SWIG_Python_SetConstant(d, "PJSIP_H_TO",SWIG_From_int(static_cast< int >(PJSIP_H_TO)));
  SWIG_Python_SetConstant(d, "PJSIP_H_UNSUPPORTED",SWIG_From_int(static_cast< int >(PJSIP_H_UNSUPPORTED)));
  SWIG_Python_SetConstant(d, "PJSIP_H_USER_AGENT_UNIMP",SWIG_From_int(static_cast< int >(PJSIP_H_USER_AGENT_UNIMP)));
  SWIG_Python_SetConstant(d, "PJSIP_H_VIA",SWIG_From_int(static_cast< int >(PJSIP_H_VIA)));
  SWIG_Python_SetConstant(d, "PJSIP_H_WARNING_UNIMP",SWIG_From_int(static_cast< int >(PJSIP_H_WARNING_UNIMP)));
  SWIG_Python_SetConstant(d, "PJSIP_H_WWW_AUTHENTICATE",SWIG_From_int(static_cast< int >(PJSIP_H_WWW_AUTHENTICATE)));
  SWIG_Python_SetConstant(d, "PJSIP_H_OTHER",SWIG_From_int(static_cast< int >(PJSIP_H_OTHER)));
  SWIG_Python_SetConstant(d, "PJSIP_TRANSPORT_UNSPECIFIED",SWIG_From_int(static_cast< int >(PJSIP_TRANSPORT_UNSPECIFIED)));
  SWIG_Python_SetConstant(d, "PJSIP_TRANSPORT_UDP",SWIG_From_int(static_cast< int >(PJSIP_TRANSPORT_UDP)));
  SWIG_Python_SetConstant(d, "PJSIP_TRANSPORT_TCP",SWIG_From_int(static_cast< int >(PJSIP_TRANSPORT_TCP)));
  SWIG_Python_SetConstant(d, "PJSIP_TRANSPORT_TLS",SWIG_From_int(static_cast< int >(PJSIP_TRANSPORT_TLS)));
  SWIG_Python_SetConstant(d, "PJSIP_TRANSPORT_DTLS",SWIG_From_int(static_cast< int >(PJSIP_TRANSPORT_DTLS)));
  SWIG_Python_SetConstant(d, "PJSIP_TRANSPORT_SCTP",SWIG_From_int(static_cast< int >(PJSIP_TRANSPORT_SCTP)));
  SWIG_Python_SetConstant(d, "PJSIP_TRANSPORT_LOOP",SWIG_From_int(static_cast< int >(PJSIP_TRANSPORT_LOOP)));
  SWIG_Python_SetConstant(d, "PJSIP_TRANSPORT_LOOP_DGRAM",SWIG_From_int(static_cast< int >(PJSIP_TRANSPORT_LOOP_DGRAM)));
  SWIG_Python_SetConstant(d, "PJSIP_TRANSPORT_START_OTHER",SWIG_From_int(static_cast< int >(PJSIP_TRANSPORT_START_OTHER)));
  SWIG_Python_SetConstant(d, "PJSIP_TRANSPORT_IPV6",SWIG_From_int(static_cast< int >(PJSIP_TRANSPORT_IPV6)));
  SWIG_Python_SetConstant(d, "PJSIP_TRANSPORT_UDP6",SWIG_From_int(static_cast< int >(PJSIP_TRANSPORT_UDP6)));
  SWIG_Python_SetConstant(d, "PJSIP_TRANSPORT_TCP6",SWIG_From_int(static_cast< int >(PJSIP_TRANSPORT_TCP6)));
  SWIG_Python_SetConstant(d, "PJSIP_TRANSPORT_TLS6",SWIG_From_int(static_cast< int >(PJSIP_TRANSPORT_TLS6)));
  SWIG_Python_SetConstant(d, "PJSIP_TRANSPORT_DTLS6",SWIG_From_int(static_cast< int >(PJSIP_TRANSPORT_DTLS6)));
  SWIG_Python_SetConstant(d, "PJSIP_TRANSPORT_RELIABLE",SWIG_From_int(static_cast< int >(PJSIP_TRANSPORT_RELIABLE)));
  SWIG_Python_SetConstant(d, "PJSIP_TRANSPORT_SECURE",SWIG_From_int(static_cast< int >(PJSIP_TRANSPORT_SECURE)));
  SWIG_Python_SetConstant(d, "PJSIP_TRANSPORT_DATAGRAM",SWIG_From_int(static_cast< int >(PJSIP_TRANSPORT_DATAGRAM)));
  SWIG_Python_SetConstant(d, "PJSIP_TP_STATE_CONNECTED",SWIG_From_int(static_cast< int >(PJSIP_TP_STATE_CONNECTED)));
  SWIG_Python_SetConstant(d, "PJSIP_TP_STATE_DISCONNECTED",SWIG_From_int(static_cast< int >(PJSIP_TP_STATE_DISCONNECTED)));
  SWIG_Python_SetConstant(d, "PJSIP_TP_STATE_SHUTDOWN",SWIG_From_int(static_cast< int >(PJSIP_TP_STATE_SHUTDOWN)));
  SWIG_Python_SetConstant(d, "PJSIP_TP_STATE_DESTROY",SWIG_From_int(static_cast< int >(PJSIP_TP_STATE_DESTROY)));
  SWIG_Python_SetConstant(d, "PJSIP_SSL_UNSPECIFIED_METHOD",SWIG_From_int(static_cast< int >(PJSIP_SSL_UNSPECIFIED_METHOD)));
  SWIG_Python_SetConstant(d, "PJSIP_SSLV2_METHOD",SWIG_From_int(static_cast< int >(PJSIP_SSLV2_METHOD)));
  SWIG_Python_SetConstant(d, "PJSIP_SSLV3_METHOD",SWIG_From_int(static_cast< int >(PJSIP_SSLV3_METHOD)));
  SWIG_Python_SetConstant(d, "PJSIP_TLSV1_METHOD",SWIG_From_int(static_cast< int >(PJSIP_TLSV1_METHOD)));
  SWIG_Python_SetConstant(d, "PJSIP_TLSV1_1_METHOD",SWIG_From_int(static_cast< int >(PJSIP_TLSV1_1_METHOD)));
  SWIG_Python_SetConstant(d, "PJSIP_TLSV1_2_METHOD",SWIG_From_int(static_cast< int >(PJSIP_TLSV1_2_METHOD)));
  SWIG_Python_SetConstant(d, "PJSIP_TLSV1_3_METHOD",SWIG_From_int(static_cast< int >(PJSIP_TLSV1_3_METHOD)));
  SWIG_Python_SetConstant(d, "PJSIP_SSLV23_METHOD",SWIG_From_int(static_cast< int >(PJSIP_SSLV23_METHOD)));
  SWIG_Python_SetConstant(d, "PJSIP_TSX_STATE_NULL",SWIG_From_int(static_cast< int >(PJSIP_TSX_STATE_NULL)));
  SWIG_Python_SetConstant(d, "PJSIP_TSX_STATE_CALLING",SWIG_From_int(static_cast< int >(PJSIP_TSX_STATE_CALLING)));
  SWIG_Python_SetConstant(d, "PJSIP_TSX_STATE_TRYING",SWIG_From_int(static_cast< int >(PJSIP_TSX_STATE_TRYING)));
  SWIG_Python_SetConstant(d, "PJSIP_TSX_STATE_PROCEEDING",SWIG_From_int(static_cast< int >(PJSIP_TSX_STATE_PROCEEDING)));
  SWIG_Python_SetConstant(d, "PJSIP_TSX_STATE_COMPLETED",SWIG_From_int(static_cast< int >(PJSIP_TSX_STATE_COMPLETED)));
  SWIG_Python_SetConstant(d, "PJSIP_TSX_STATE_CONFIRMED",SWIG_From_int(static_cast< int >(PJSIP_TSX_STATE_CONFIRMED)));
  SWIG_Python_SetConstant(d, "PJSIP_TSX_STATE_TERMINATED",SWIG_From_int(static_cast< int >(PJSIP_TSX_STATE_TERMINATED)));
  SWIG_Python_SetConstant(d, "PJSIP_TSX_STATE_DESTROYED",SWIG_From_int(static_cast< int >(PJSIP_TSX_STATE_DESTROYED)));
  SWIG_Python_SetConstant(d, "PJSIP_TSX_STATE_MAX",SWIG_From_int(static_cast< int >(PJSIP_TSX_STATE_MAX)));
  SWIG_Python_SetConstant(d, "PJSIP_ROLE_UAC",SWIG_From_int(static_cast< int >(PJSIP_ROLE_UAC)));
  SWIG_Python_SetConstant(d, "PJSIP_ROLE_UAS",SWIG_From_int(static_cast< int >(PJSIP_ROLE_UAS)));
  SWIG_Python_SetConstant(d, "PJSIP_UAC_ROLE",SWIG_From_int(static_cast< int >(PJSIP_UAC_ROLE)));
  SWIG_Python_SetConstant(d, "PJSIP_UAS_ROLE",SWIG_From_int(static_cast< int >(PJSIP_UAS_ROLE)));
  SWIG_Python_SetConstant(d, "PJSIP_REDIRECT_REJECT",SWIG_From_int(static_cast< int >(PJSIP_REDIRECT_REJECT)));
  SWIG_Python_SetConstant(d, "PJSIP_REDIRECT_ACCEPT",SWIG_From_int(static_cast< int >(PJSIP_REDIRECT_ACCEPT)));
  SWIG_Python_SetConstant(d, "PJSIP_REDIRECT_ACCEPT_REPLACE",SWIG_From_int(static_cast< int >(PJSIP_REDIRECT_ACCEPT_REPLACE)));
  SWIG_Python_SetConstant(d, "PJSIP_REDIRECT_PENDING",SWIG_From_int(static_cast< int >(PJSIP_REDIRECT_PENDING)));
  SWIG_Python_SetConstant(d, "PJSIP_REDIRECT_STOP",SWIG_From_int(static_cast< int >(PJSIP_REDIRECT_STOP)));
  SWIG_Python_SetConstant(d, "PJRPID_ACTIVITY_UNKNOWN",SWIG_From_int(static_cast< int >(PJRPID_ACTIVITY_UNKNOWN)));
  SWIG_Python_SetConstant(d, "PJRPID_ACTIVITY_AWAY",SWIG_From_int(static_cast< int >(PJRPID_ACTIVITY_AWAY)));
  SWIG_Python_SetConstant(d, "PJRPID_ACTIVITY_BUSY",SWIG_From_int(static_cast< int >(PJRPID_ACTIVITY_BUSY)));
  SWIG_Python_SetConstant(d, "PJSIP_EVSUB_STATE_NULL",SWIG_From_int(static_cast< int >(PJSIP_EVSUB_STATE_NULL)));
  SWIG_Python_SetConstant(d, "PJSIP_EVSUB_STATE_SENT",SWIG_From_int(static_cast< int >(PJSIP_EVSUB_STATE_SENT)));
  SWIG_Python_SetConstant(d, "PJSIP_EVSUB_STATE_ACCEPTED",SWIG_From_int(static_cast< int >(PJSIP_EVSUB_STATE_ACCEPTED)));
  SWIG_Python_SetConstant(d, "PJSIP_EVSUB_STATE_PENDING",SWIG_From_int(static_cast< int >(PJSIP_EVSUB_STATE_PENDING)));
  SWIG_Python_SetConstant(d, "PJSIP_EVSUB_STATE_ACTIVE",SWIG_From_int(static_cast< int >(PJSIP_EVSUB_STATE_ACTIVE)));
  SWIG_Python_SetConstant(d, "PJSIP_EVSUB_STATE_TERMINATED",SWIG_From_int(static_cast< int >(PJSIP_EVSUB_STATE_TERMINATED)));
  SWIG_Python_SetConstant(d, "PJSIP_EVSUB_STATE_UNKNOWN",SWIG_From_int(static_cast< int >(PJSIP_EVSUB_STATE_UNKNOWN)));
  SWIG_Python_SetConstant(d, "PJSIP_INV_STATE_NULL",SWIG_From_int(static_cast< int >(PJSIP_INV_STATE_NULL)));
  SWIG_Python_SetConstant(d, "PJSIP_INV_STATE_CALLING",SWIG_From_int(static_cast< int >(PJSIP_INV_STATE_CALLING)));
  SWIG_Python_SetConstant(d, "PJSIP_INV_STATE_INCOMING",SWIG_From_int(static_cast< int >(PJSIP_INV_STATE_INCOMING)));
  SWIG_Python_SetConstant(d, "PJSIP_INV_STATE_EARLY",SWIG_From_int(static_cast< int >(PJSIP_INV_STATE_EARLY)));
  SWIG_Python_SetConstant(d, "PJSIP_INV_STATE_CONNECTING",SWIG_From_int(static_cast< int >(PJSIP_INV_STATE_CONNECTING)));
  SWIG_Python_SetConstant(d, "PJSIP_INV_STATE_CONFIRMED",SWIG_From_int(static_cast< int >(PJSIP_INV_STATE_CONFIRMED)));
  SWIG_Python_SetConstant(d, "PJSIP_INV_STATE_DISCONNECTED",SWIG_From_int(static_cast< int >(PJSIP_INV_STATE_DISCONNECTED)));
  SWIG_Python_SetConstant(d, "PJSUA_INVALID_ID",SWIG_From_int(static_cast< int >(PJSUA_INVALID_ID)));
  SWIG_Python_SetConstant(d, "PJSUA_STATE_NULL",SWIG_From_int(static_cast< int >(PJSUA_STATE_NULL)));
  SWIG_Python_SetConstant(d, "PJSUA_STATE_CREATED",SWIG_From_int(static_cast< int >(PJSUA_STATE_CREATED)));
  SWIG_Python_SetConstant(d, "PJSUA_STATE_INIT",SWIG_From_int(static_cast< int >(PJSUA_STATE_INIT)));
  SWIG_Python_SetConstant(d, "PJSUA_STATE_STARTING",SWIG_From_int(static_cast< int >(PJSUA_STATE_STARTING)));
  SWIG_Python_SetConstant(d, "PJSUA_STATE_RUNNING",SWIG_From_int(static_cast< int >(PJSUA_STATE_RUNNING)));
  SWIG_Python_SetConstant(d, "PJSUA_STATE_CLOSING",SWIG_From_int(static_cast< int >(PJSUA_STATE_CLOSING)));
  SWIG_Python_SetConstant(d, "PJSUA_STUN_USE_DEFAULT",SWIG_From_int(static_cast< int >(PJSUA_STUN_USE_DEFAULT)));
  SWIG_Python_SetConstant(d, "PJSUA_STUN_USE_DISABLED",SWIG_From_int(static_cast< int >(PJSUA_STUN_USE_DISABLED)));
  SWIG_Python_SetConstant(d, "PJSUA_STUN_RETRY_ON_FAILURE",SWIG_From_int(static_cast< int >(PJSUA_STUN_RETRY_ON_FAILURE)));
  SWIG_Python_SetConstant(d, "PJSUA_CALL_HOLD_TYPE_RFC3264",SWIG_From_int(static_cast< int >(PJSUA_CALL_HOLD_TYPE_RFC3264)));
  SWIG_Python_SetConstant(d, "PJSUA_CALL_HOLD_TYPE_RFC2543",SWIG_From_int(static_cast< int >(PJSUA_CALL_HOLD_TYPE_RFC2543)));
  SWIG_Python_SetConstant(d, "PJSUA_DESTROY_NO_RX_MSG",SWIG_From_int(static_cast< int >(PJSUA_DESTROY_NO_RX_MSG)));
  SWIG_Python_SetConstant(d, "PJSUA_DESTROY_NO_TX_MSG",SWIG_From_int(static_cast< int >(PJSUA_DESTROY_NO_TX_MSG)));
  SWIG_Python_SetConstant(d, "PJSUA_DESTROY_NO_NETWORK",SWIG_From_int(static_cast< int >(PJSUA_DESTROY_NO_NETWORK)));
  SWIG_Python_SetConstant(d, "PJSUA_100REL_NOT_USED",SWIG_From_int(static_cast< int >(PJSUA_100REL_NOT_USED)));
  SWIG_Python_SetConstant(d, "PJSUA_100REL_MANDATORY",SWIG_From_int(static_cast< int >(PJSUA_100REL_MANDATORY)));
  SWIG_Python_SetConstant(d, "PJSUA_100REL_OPTIONAL",SWIG_From_int(static_cast< int >(PJSUA_100REL_OPTIONAL)));
  SWIG_Python_SetConstant(d, "PJSUA_SIP_TIMER_INACTIVE",SWIG_From_int(static_cast< int >(PJSUA_SIP_TIMER_INACTIVE)));
  SWIG_Python_SetConstant(d, "PJSUA_SIP_TIMER_OPTIONAL",SWIG_From_int(static_cast< int >(PJSUA_SIP_TIMER_OPTIONAL)));
  SWIG_Python_SetConstant(d, "PJSUA_SIP_TIMER_REQUIRED",SWIG_From_int(static_cast< int >(PJSUA_SIP_TIMER_REQUIRED)));
  SWIG_Python_SetConstant(d, "PJSUA_SIP_TIMER_ALWAYS",SWIG_From_int(static_cast< int >(PJSUA_SIP_TIMER_ALWAYS)));
  SWIG_Python_SetConstant(d, "PJSUA_IPV6_DISABLED",SWIG_From_int(static_cast< int >(PJSUA_IPV6_DISABLED)));
  SWIG_Python_SetConstant(d, "PJSUA_IPV6_ENABLED",SWIG_From_int(static_cast< int >(PJSUA_IPV6_ENABLED)));
  SWIG_Python_SetConstant(d, "PJSUA_NAT64_DISABLED",SWIG_From_int(static_cast< int >(PJSUA_NAT64_DISABLED)));
  SWIG_Python_SetConstant(d, "PJSUA_NAT64_ENABLED",SWIG_From_int(static_cast< int >(PJSUA_NAT64_ENABLED)));
  SWIG_Python_SetConstant(d, "PJSUA_BUDDY_STATUS_UNKNOWN",SWIG_From_int(static_cast< int >(PJSUA_BUDDY_STATUS_UNKNOWN)));
  SWIG_Python_SetConstant(d, "PJSUA_BUDDY_STATUS_ONLINE",SWIG_From_int(static_cast< int >(PJSUA_BUDDY_STATUS_ONLINE)));
  SWIG_Python_SetConstant(d, "PJSUA_BUDDY_STATUS_OFFLINE",SWIG_From_int(static_cast< int >(PJSUA_BUDDY_STATUS_OFFLINE)));
  SWIG_Python_SetConstant(d, "PJSUA_CALL_MEDIA_NONE",SWIG_From_int(static_cast< int >(PJSUA_CALL_MEDIA_NONE)));
  SWIG_Python_SetConstant(d, "PJSUA_CALL_MEDIA_ACTIVE",SWIG_From_int(static_cast< int >(PJSUA_CALL_MEDIA_ACTIVE)));
  SWIG_Python_SetConstant(d, "PJSUA_CALL_MEDIA_LOCAL_HOLD",SWIG_From_int(static_cast< int >(PJSUA_CALL_MEDIA_LOCAL_HOLD)));
  SWIG_Python_SetConstant(d, "PJSUA_CALL_MEDIA_REMOTE_HOLD",SWIG_From_int(static_cast< int >(PJSUA_CALL_MEDIA_REMOTE_HOLD)));
  SWIG_Python_SetConstant(d, "PJSUA_CALL_MEDIA_ERROR",SWIG_From_int(static_cast< int >(PJSUA_CALL_MEDIA_ERROR)));
  SWIG_Python_SetConstant(d, "PJSUA_MED_TP_NULL",SWIG_From_int(static_cast< int >(PJSUA_MED_TP_NULL)));
  SWIG_Python_SetConstant(d, "PJSUA_MED_TP_CREATING",SWIG_From_int(static_cast< int >(PJSUA_MED_TP_CREATING)));
  SWIG_Python_SetConstant(d, "PJSUA_MED_TP_IDLE",SWIG_From_int(static_cast< int >(PJSUA_MED_TP_IDLE)));
  SWIG_Python_SetConstant(d, "PJSUA_MED_TP_INIT",SWIG_From_int(static_cast< int >(PJSUA_MED_TP_INIT)));
  SWIG_Python_SetConstant(d, "PJSUA_MED_TP_RUNNING",SWIG_From_int(static_cast< int >(PJSUA_MED_TP_RUNNING)));
  SWIG_Python_SetConstant(d, "PJSUA_MED_TP_DISABLED",SWIG_From_int(static_cast< int >(PJSUA_MED_TP_DISABLED)));
  SWIG_Python_SetConstant(d, "PJSUA_CALL_VID_STRM_NO_OP",SWIG_From_int(static_cast< int >(PJSUA_CALL_VID_STRM_NO_OP)));
  SWIG_Python_SetConstant(d, "PJSUA_CALL_VID_STRM_ADD",SWIG_From_int(static_cast< int >(PJSUA_CALL_VID_STRM_ADD)));
  SWIG_Python_SetConstant(d, "PJSUA_CALL_VID_STRM_REMOVE",SWIG_From_int(static_cast< int >(PJSUA_CALL_VID_STRM_REMOVE)));
  SWIG_Python_SetConstant(d, "PJSUA_CALL_VID_STRM_CHANGE_DIR",SWIG_From_int(static_cast< int >(PJSUA_CALL_VID_STRM_CHANGE_DIR)));
  SWIG_Python_SetConstant(d, "PJSUA_CALL_VID_STRM_CHANGE_CAP_DEV",SWIG_From_int(static_cast< int >(PJSUA_CALL_VID_STRM_CHANGE_CAP_DEV)));
  SWIG_Python_SetConstant(d, "PJSUA_CALL_VID_STRM_START_TRANSMIT",SWIG_From_int(static_cast< int >(PJSUA_CALL_VID_STRM_START_TRANSMIT)));
  SWIG_Python_SetConstant(d, "PJSUA_CALL_VID_STRM_STOP_TRANSMIT",SWIG_From_int(static_cast< int >(PJSUA_CALL_VID_STRM_STOP_TRANSMIT)));
  SWIG_Python_SetConstant(d, "PJSUA_CALL_VID_STRM_SEND_KEYFRAME",SWIG_From_int(static_cast< int >(PJSUA_CALL_VID_STRM_SEND_KEYFRAME)));
  SWIG_Python_SetConstant(d, "PJSUA_VID_REQ_KEYFRAME_SIP_INFO",SWIG_From_int(static_cast< int >(PJSUA_VID_REQ_KEYFRAME_SIP_INFO)));
  SWIG_Python_SetConstant(d, "PJSUA_VID_REQ_KEYFRAME_RTCP_PLI",SWIG_From_int(static_cast< int >(PJSUA_VID_REQ_KEYFRAME_RTCP_PLI)));
  SWIG_Python_SetConstant(d, "PJSUA_CALL_UNHOLD",SWIG_From_int(static_cast< int >(PJSUA_CALL_UNHOLD)));
  SWIG_Python_SetConstant(d, "PJSUA_CALL_UPDATE_CONTACT",SWIG_From_int(static_cast< int >(PJSUA_CALL_UPDATE_CONTACT)));
  SWIG_Python_SetConstant(d, "PJSUA_CALL_INCLUDE_DISABLED_MEDIA",SWIG_From_int(static_cast< int >(PJSUA_CALL_INCLUDE_DISABLED_MEDIA)));
  SWIG_Python_SetConstant(d, "PJSUA_CALL_NO_SDP_OFFER",SWIG_From_int(static_cast< int >(PJSUA_CALL_NO_SDP_OFFER)));
  SWIG_Python_SetConstant(d, "PJSUA_CALL_REINIT_MEDIA",SWIG_From_int(static_cast< int >(PJSUA_CALL_REINIT_MEDIA)));
  SWIG_Python_SetConstant(d, "PJSUA_CALL_UPDATE_VIA",SWIG_From_int(static_cast< int >(PJSUA_CALL_UPDATE_VIA)));
  SWIG_Python_SetConstant(d, "PJSUA_CALL_UPDATE_TARGET",SWIG_From_int(static_cast< int >(PJSUA_CALL_UPDATE_TARGET)));
  SWIG_Python_SetConstant(d, "PJSUA_CALL_SET_MEDIA_DIR",SWIG_From_int(static_cast< int >(PJSUA_CALL_SET_MEDIA_DIR)));
  SWIG_Python_SetConstant(d, "PJSUA_MED_TP_CLOSE_MEMBER",SWIG_From_int(static_cast< int >(PJSUA_MED_TP_CLOSE_MEMBER)));
  SWIG_Python_SetConstant(d, "PJSUA_SND_DEFAULT_CAPTURE_DEV",SWIG_From_int(static_cast< int >(PJSUA_SND_DEFAULT_CAPTURE_DEV)));
  SWIG_Python_SetConstant(d, "PJSUA_SND_DEFAULT_PLAYBACK_DEV",SWIG_From_int(static_cast< int >(PJSUA_SND_DEFAULT_PLAYBACK_DEV)));
  SWIG_Python_SetConstant(d, "PJSUA_SND_NO_DEV",SWIG_From_int(static_cast< int >(PJSUA_SND_NO_DEV)));
  SWIG_Python_SetConstant(d, "PJSUA_SND_NULL_DEV",SWIG_From_int(static_cast< int >(PJSUA_SND_NULL_DEV)));
  SWIG_Python_SetConstant(d, "PJSUA_SND_DEV_SPEAKER_ONLY",SWIG_From_int(static_cast< int >(PJSUA_SND_DEV_SPEAKER_ONLY)));
  SWIG_Python_SetConstant(d, "PJSUA_SND_DEV_NO_IMMEDIATE_OPEN",SWIG_From_int(static_cast< int >(PJSUA_SND_DEV_NO_IMMEDIATE_OPEN)));
  SWIG_Python_SetConstant(d, "PJSUA_IP_CHANGE_OP_NULL",SWIG_From_int(static_cast< int >(PJSUA_IP_CHANGE_OP_NULL)));
  SWIG_Python_SetConstant(d, "PJSUA_IP_CHANGE_OP_RESTART_LIS",SWIG_From_int(static_cast< int >(PJSUA_IP_CHANGE_OP_RESTART_LIS)));
  SWIG_Python_SetConstant(d, "PJSUA_IP_CHANGE_OP_ACC_SHUTDOWN_TP",SWIG_From_int(static_cast< int >(PJSUA_IP_CHANGE_OP_ACC_SHUTDOWN_TP)));
  SWIG_Python_SetConstant(d, "PJSUA_IP_CHANGE_OP_ACC_UPDATE_CONTACT",SWIG_From_int(static_cast< int >(PJSUA_IP_CHANGE_OP_ACC_UPDATE_CONTACT)));
  SWIG_Python_SetConstant(d, "PJSUA_IP_CHANGE_OP_ACC_HANGUP_CALLS",SWIG_From_int(static_cast< int >(PJSUA_IP_CHANGE_OP_ACC_HANGUP_CALLS)));
  SWIG_Python_SetConstant(d, "PJSUA_IP_CHANGE_OP_ACC_REINVITE_CALLS",SWIG_From_int(static_cast< int >(PJSUA_IP_CHANGE_OP_ACC_REINVITE_CALLS)));
  SWIG_Python_SetConstant(d, "PJSUA_IP_CHANGE_OP_COMPLETED",SWIG_From_int(static_cast< int >(PJSUA_IP_CHANGE_OP_COMPLETED)));
  SWIG_Python_SetConstant(d, "PJSUA_DTMF_METHOD_RFC2833",SWIG_From_int(static_cast< int >(PJSUA_DTMF_METHOD_RFC2833)));
  SWIG_Python_SetConstant(d, "PJSUA_DTMF_METHOD_SIP_INFO",SWIG_From_int(static_cast< int >(PJSUA_DTMF_METHOD_SIP_INFO)));
  
  // thread safe initialization
  swig::container_owner_attribute();
  
  SWIG_Python_SetConstant(d, "INVALID_ID",SWIG_From_int(static_cast< int >(pj::INVALID_ID)));
  SWIG_Python_SetConstant(d, "SUCCESS",SWIG_From_int(static_cast< int >(pj::SUCCESS)));
#if PY_VERSION_HEX >= 0x03000000
  return m;
#else
  return;
#endif
}

